(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  22514643,     800236]*)
(*NotebookOutlinePosition[  22515659,     800268]*)
(*  CellTagsIndexPosition[  22515615,     800264]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Pulse Propagation along close Conductors", "Title"],

Cell["\<\
Numerical solution of the telegraph equations using \
Mathematica\
\>", "Subtitle"],

Cell["\<\
Andreas Dieckmann
Physikalisches Institut der Uni Bonn
Elektronik Abteilung
Oktober 2000 - September 2001\
\>", "Subsubtitle",
  TextAlignment->Center],

Cell[TextData[{
  StyleBox["\n\nAbstract\n",
    FontSize->24],
  "\nThe propagation and reflection of arbitrarily shaped pulses on \
non-dispersive parallel conductors of finite length with user defined cross \
section is simulated employing the discretized telegraph equation. The \
geometry of the system of conductors and the presence of dielectric material \
determine the capacities and inductances that enter the calculation. The \
values of these parameters are found using an iterative Laplace equation \
solving procedure and confirmed for certain calculable geometries including \
the line charge inside a box. The evolving pulses and the resulting crosstalk \
can be plotted at any instant and \[Dash] in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebook version of this report ",
  StyleBox["(http://www.physik.uni-bonn.de/~dieckman/)",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" ",
    FontWeight->"Bold"],
  "\[Dash] be looked at in an animation. As an example a differential pair of \
microstrips as used in the ATLAS vertex detector is analysed.\n\n"
}], "Text"],

Cell[TextData[{
  StyleBox["                                               \nContents\n\n",
    FontSize->24],
  StyleBox["Introduction\t\t\t\t\t\t\t\t  2\n\nIntegration of the Telegraph \
Equations \t\t\t\t  3\n\nNumerical Calculation of Capacities and Inductances\t\
\t\t15\n\nThe Pigtail\t\t\t\t\t\t\t\t37\n\nConclusion\t\t\t\t\t\t\t\t60\n\n\
References\t\t\t\t\t\t\t\t60",
    FontSize->12]
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  PageBreakAbove->True],

Cell[TextData[{
  "Electrical pulses travelling on a conductor will induce voltages and \
currents onto the neighbor conductors.To estimate the size of this influence \
called ",
  StyleBox["crosstalk",
    FontSlant->"Italic"],
  " either simulation and/or measurement of the effect is needed. Fig. 1 \
shows the basic schematic of coupled lines ",
  StyleBox["(",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["Ref. 1",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[",",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" ",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["p.196)",
    FontVariations->{"CompatibilityType"->0}],
  ":"
}], "Text"],

Cell[GraphicsData["PICT", "\<\
fM8000000@X1T@0A0_l<0?on0001;0000B`000000004E@J90000002Q09H02P40
000000000000X02H0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G
0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40000000000000X02H
0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G0:40UP0:0@000000
0000002P09P0X02I0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F
00X10000000000000:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I
0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F00X1000000000000
0:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40
000000000000X02H0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G
0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40000000000000X02H
0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G0:40UP0:0@000000
0000002P09P0X02I0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F
00X10000000000000:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I
0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F00X1000000000000
0:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40
000000000000X02H0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G
0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40000000000000X02H
0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G0:40UP0:0@000000
0000002P09P0X02I0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F
00X10000000000000:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I
0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F00X1000000000000
0:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I0:00U`0N00402P00
0004E@J902`0300E2DQUK7IUM6USH@0301D03@0<02h01000o`00:`<30B00:@01
80001`0000008`000:00_P2Q0<003F=eLW9UKWA`KfU^M0d00:00_`0R0@X1T@00
0:00_P2Q0<00cF=eLW9UKWA`KfU^M20b86U^I6Eh87=eHR1UN6=X83<PJFiTIGPP
LgER3B0d<34P86AYMR1UN6=X80dP<SHf821TJGHP<b1YKVAUN20=830P87=eHR0c
86U^I6Eh80dP<20PLgER83@P<R1bKfa/83DPJFiTIGPP=B1YKVAUN21dLV5^LfaQ
M6D=KVEW87=SHFaU3C@P<R1bKfa/86iUIb1UN6=X86iUIb1UN6=X87AbHFicK65d
IB0=838f=R0PLgER87AbHFicK65dI@d00:40`0549B5@Dbe1I6mRIBdc;S0PAE1C
ARdc;S0=9BE2KgE^I6U^Id9_N3XP830P<20d<34P<SHf80dU9EAYM6aU>R0X@g9_
Lg=dHFa[;T=>ERTP3BDU@g9UHGA_LSXP@f5^MV5c82Pg;S0^<RTP3BDU@g9UHGAY
Kfi4HGAU>R0X<38_<SD_<34P@20a<CXb=B11CBTP3BDUA6mSMFeUKWA@LVmSDfEd
LcXPA6E^IF9QGd=QKWIQLd=eLgA_KD=_K6mbL`dU9B/P@eI4JF=d3BDUA6mSMFeU
KWA6KfidLcXP3BDUA6mSMFeUKWA>IFETIFA6KfidLcXP3BDUA6mSMFeUKWA@LVmS
IG=c@fm/Kg9c>R13NF5^84eQIfE^M64PFFE/K6mg849/HF=[3BDUAFiT@fm]KFE^
M7<=9BE2IFMYKU1bKfa_Ib0=0:40`4009BE2IFMYKU9ULfmeLV=U>R1`LVmSLfEd
84=FA6USM0dU9EAYM6aU>R14IFiUHV4PLgAQKVAQLV@PIg9QL6QYHg<=9BEFIG9c
JFm^>R0a;S0b3BDU@g9UHGAYKfi4HGAU>R0a<2la=2li>@dU9D=_L7UbJFMXM3XP
:4<Y834i>C@/834i>CTPA6E^IF9Q85=iLgAUKG<^845/K21BJFMXM7<PDVEcIG9f
IF@=MG=ULVAYHg@P;d=FA6USM20b<30PI6USM21`MG@=@eI4JF=d869UIfU^3BmY
KWIQK6UTHfm/Kg9dHF9/IClPM79eIB1TIFHP820=;faUMVE/<R0_K65^IgEQIfE/
IGIUK21gJ6EbIB1kL6m`86aQKVMeHFMUK6EfIF`P<R1WIGekIV5/LfEm86UVIFac
IB1TIFH=K6EfIF`b86i_M21k82mhLfQ_Mb1k3C0PHgEbLVE^M71_JFid83DP;C4P
LVm/K21kL6m`871_L21]KgIUM6lPI7E`834PHFAT83<P<B1bKfa/86EhHfPPI7E`
83@P<B1bKfa/86EhHfPPIfEd830PLVe_MVEdKb1SMG9bIFidL6mYKWAm86EhHfPP
Jg=XKgL=L6m`871_L21`Kg0PL6m`OB1TIFHPOB1YIPd_JFiYM6UQK6UjI@ek@eI4
JF=d3G]TMG0PN6=XIF=[Nf9YKVAmJFHPL6m`871_L7eVKg9QK6`=HgEbLVE^M7=S
LVEUKR0_Gg=`86EhHfPPI6EV82mOLf4PIGQSJ21TIFHP;emcIR1UN6=X86AUIPd_
A6EVHGE/M5=SLVEUKW]OLfHPGg=Q82mOLg0PK6mQI7eTIFH=;dAUIV5eK7ACHg9U
IFi@LVmSNb0_Gg=`86a_HFAmI6EV3BmcIGAcM79_JfEQI6YeLg@PMfQULVEkL6m`
87AbMFEmNfIQK7=UOFUVIFacI@ek;g=Q82mcIGAcM79_JfEQI6YeLg@PK6mQI21T
IFH=;faY82m/JFiUM6lPK6mQI21TIFH=;fed82m]KgIUM6lPK6mQI21TIFH=;f=d
82mSMG9fIGA_86a_HF@PI6EV3Bm/J21k86=eLW9UKWA`KfU^M21UN6=X871_L21/
JFiUM6mmHVU^I21TIFH=;faf87/PHgEbLVE^M71_JFid871_L21UN6=X86aYKVEd
KgeRJFiT86AUIWd=NbmcHG]kHgEbLVE^M6AYHg@PDgAbKf]U@FAZMG=dA6USM21^
IG]CM79_JfE1I6YeLgA4JF=d869UIfU^OFUVOG/PHgEbLVE^M6AYHg@PDgAbKf]U
@FAZMG=dA6USM21ULG]UKVAmJFImJFIUK7=UOB1RJFiT86AUIPeeLfEbI6USM20_
DgAbKf]U@FAZMG=dA6USM20a<30PI6USM21`MG@=DgAbKf]U@FAZMG=dA6USM21R
IFMYKPd_GgQ/3G]dLV5^LfI_LVd=;S8e87=eHR1bKgE^I20^<SDPHFAT86EhHfP=
;S8e87=eHR1bKgE^I20^<SDPHFAT86EhHfP=JGAbHFicIVmbK@emHVU^I21TIFH=
;faYNb1ON6`PK6U^IGA_OF9YKV@PI6EV3Bm]M7/PGgQ/86e_MVEdKgeRJFiT86AU
IPd_HgAk85mhK21SMG9fIGA_OF9YKV@PI6EV3Bm/J21k86AeL21ON6`PL6m`86=e
LW9UKWA`KfU^M21UN6=X871_L21/JFiUM6mmHVU^I21TIFH=;faf87/PI7E`85mh
K21`Kg0PHgEbLVE^M71_JFid871_L21UN6=X86aYKVEdKgeRJFiT86AUIPd_LW1k
GgQ/;f=fGf8PN6AV;f=fGg8PN6AV3EmhK2mSMUmd87QTIRmSMUm/87QTIPeSMUm/
86=fGg@PKFmfIGA_3F=fGg8PHgIOM21/JFiUM6l=HgIOLR1SMUmR86aYKVEdK`eS
MUm/86=fGf8PK6U^IGA_3F=/Kg=UL65dJ0emHVU^I21TIFH=IFiTOFUVIFacIGeT
IFH=;gAULVeYKV5dI@ekMG=ULVAYHg@P;e=dLVm[ID5TJWEcM4AYHg@PJfi_MfhP
Nf=eLW9UKWATJF=d85=dLVm[ID5TJWEcM4AYHg@PIG5kIFiTOFUVOFUV3F=eLW9U
KWATJF=d84=FA6USM21ULG]UKVAmJFImI6EV3Bm]N4eQN20f=21TIFH=;fehDgA[
85]]N4eQN21kKF5dLVUhOB1bIG1UHGAMI6EV3Bm]N4UTN20`86AUIPd_LgA]Nfeh
DgA[86ehBFAh830PK7@PNbm]N4UTN20`87=dKg9UOFUV86ehBFAh86MUM21SMG9b
IFidKF5dLVUh871_L20_KGQ9I7PPKGQ9I7PP<B1QI6@PLgA_LVEmI6EV3BmbM6ek
KGQ9I7PP<B1WIB1k;fehBFAh86ehBFAh834PLgER87=dKg9U86ehDgA[86ehBFAh
86MUM21cIGA]HGAbJGQmJFHPOFAUIPd_Lf=/87/P=c8PI6Uf86EhHfPP=c8PI6Uf
86EhHfPPLf=QK6DPOB1TIFH=;g=SK6TPNb0g<R1UN6=X86AYMR1UN6=X83Lb86Eh
HfPPI6Uf86EhHfPPLf=QK6DPOB1TIFH=;emSMVedN21]HGAbJGPPI6EV3BmOM7Qd
KGAh86eQM79YN21TIFH=;emYKVUdKGAh86eQM79YN21TIFH=;gQTIW]UN6=X86AU
IWeTIFH=;feYKW/b86=_L7TPIgAkIGQSJ7eYIR1`Kg1mI6EV3Bm]HGQk<R1SKg1i
86adNfEhHfQmJFHPL6m`OFAUIPd_@eIfIF<P<SDf865bLV5i86AUIPd_E21dLWEU
86AUIPd_AR1VHFacIB1TIFH=;emYI20`86AUIPd_GfE^HfmTJFiTIGPP<21TIFH=
;emUKV=_I45bLR0c865bLV5i86AUIPd_GfIT830PI6EV3BmOM6EhM5=QMVDPKWE/
K21TIFH=;em/IGAdIG9CL65SIB0`86AUIPd_Gg=`HF=UF7AbHB0`86AUIPd_Ge1Q
IfECHGIU86ieK6`PI6EV3BmOL6E^J20a;S0PI6EV3BmOL6E^MR0a;S0PI6EV3Bmc
HGIU<21^MFa/86AUIPd_GgLP<21TIFH=;emX830PI6EV3BmOI7<P<21TIFH=;fQS
M21VHFacIB1TIFH=;g1g830PI6EV3BmgI6UV830PI6EV3BmdIFe`830PI6EV3BmS
MG9bKg@P<21TIFH=;g=QMVEXHFiTK6Eb86ieK6`PI6EV3BmYHB0`86AUIPd_JGPP
<21TIFH=;fUhKR0a86AUIPd_CGE/M6U`K6E4HGAQDfmeLV=ULb1VHFacIB1TIFHP
3BmTIF9eI`ekI7E`82lTIG1c86EhHfPPKVmd86AUIW/_Lf5fIFQQKVA/IG8PIG9b
Kg9TJF=d82mXHFiTK6EULW9_LR1WIG@PI6EV3FEbLVmbI6USM0d_J65^I6aUIG9b
Kg9k96EbLVmb869UIfU^3FiUMfEbLVmbNbm^IGMULW9_LR1VHFacIB1TIFH=LfQ_
Mg1QIfD==c8P=c8PLf=QK6D=;dQUK7IUM6USHB1VJFiTIVm^M20^<R1cHf5/IFI_
KW@PLfEdIVm^M0d^<SDP>Bhf86e_MVEdK`dXAG9bKg8j82UcJ6mg3FEbLVmbKV5]
I@ekI7E`87AiL6D_LgAbJFiWM7U`IB1^I@ek:6=_KWIULWAUI21ULW9_LR1^HFeU
87MYK6`PIFiT87E`86U^87AXJG<PLgAbJFiW:F=fLgeYIPecJ6mgOFEhIF<=;S8e
83T^=21]KgIUM6l=:4mVIVE^I6U^Ib13Kfe]HFiT>R0YLfQ_M`d_Hfm]KF5^I21/
Kf5T3G]TMG0PM7U`IBmcM79YKVMdNG1U86iU3G/XHfm^MVEbM6ET86=_KFeQKV@P
KV5]IB1gJFa/86E^I21eL21YKR1dJ6Uc87=dLVU^IbUSMW=mJFH=LfQ_MgeUN6ES
3Bhb=B0i;S8PKFmfIGA_3BQCM65SJcXP:G=XKgL=Kg=dHF=[3G/^<SDPHgEbLVE^
M71_JFid82hb87=eHR1UN6=X871_L21]KgIUM6l=I7E`87AiL6D_LgAbJFiWM7U`
IB1^IG]TMG0PM7U`IBmYKWAUIfEbM7U`IB1UL@da86U^I6Eh87AiL6D_LVEQK7Ai
L6DPIG4PKg8=<B1YKVAUN21dNG1U;fiQKFEdNG1U86Ea86mb3Fi_M21kM7U`IGeY
IPdXHfm^MVEbM6ET87=dHF=[87MYK6`PIFiT87E`86U^87AXJG<PLgAbJFiW:F=f
LgeYIPecJ6mgOFI_LV5/K0ecJ6mgL65WI@e3ETAYHg@P;g=QMVEXHFiTK6Eb86MU
M21UN6ESOFUV3FE^I7e`MGAmJFImI6EV3Bm/Hg]cIGA/JFiUHf5`OFAUIPd_K6Yk
LfEdK6U^IFY_JFimI6EV3Bm/KG]cIGA]JGAULVaYKFUdOFAUIPd_K6IkLfEdIVaQ
M7eTIFH=;f=`Nf=/Kg=UL65dJ7eTIFH=;fi`NfiUMg1QM6QmI6EV3BlTL7=j83<`
865bLV5i86AUIPd_971YN20`86AUIPd_Ig=kIg=QMVDP971cNR1TMG0P971YN21O
L6E^J21`MG@P971YN20a865TI21OL6E^MR1`MG@P;bA`JGPP971YN20b865TI21T
IFImI6EV3BmWLW]WLVEcM6mbIBlTL6Uh82A`JGPP<R1cMF8PI6EV82A`LgXPI7E`
82A`JGPPIfEd82mOL6E^J21UN6=X86AUIR0TL6Uh834PHFAT86MUM20_Gg1UKWHP
IGQSJ21TIFImI6EV3Bm/JG]/JFiUM6mm86AUIPd_K6QkHgEbLVE^M71_JFid86Eh
HfPPL6m`86aYKVEdKgeTIFH=;fafNf=eLW9UKWA`KfU^M21`Kg0PIGQSJ21/JFiU
M6mmI6EV3Bm]M7]]KgIUM6mm86AUIPd_Gf=fGfeXNf=eLW9UKWA`KfU^M21UN6=X
871_L21]KgIUM6mmI6EV3BmOHgIOKGIkHgEbLVE^M71_JFid871_L21UN6=X86e_
MVEdKgeTIFH=;f=dNf=eLWIUM6mm86AUIPd_LWAk=20]<R1bKfa/86e_MVEdK`eT
MG0P<21UN6=X879/JFiUM6l=IGQSJ20`879/JFiUM6l=KVEW830PIGQSJ21bK6U^
IGA_3F=/Kg=UL65dJ7eTIFH=;emXLPek3G/_@6EbLR1VHFacIB1TIFHPHgEbLVE^
M6I/HG@PI7E`NfMcHGIUNfE_HfaYL7ecM6m`L6ETNfMbIG=dKg9U838PKGE/86Ae
L21cIGAVK65d86AeL20b<30PIfEk:2DU84=QKWIQLcY3K6U`86IQJFaUI5ab:G1b
JFid82m0IG9b87AbMFDPI6EV871_L21UN6UdOFUVOG]WLVEcM6mbIB1cIGAVK65d
86EhJGAmJFIUK7=UOFa_Kg0P@6EbLR1^Kg@PNfE_HfaYL7eYIR1cIGAVK65dO@ek
;d1ULW8PIV5/LfDPI6EV86=eLW9UKWAVK65d86AeL7]WLf5fIG]SK6U`OG=dKg1`
IFAkIg9ULgA_LVDP<R1]MF`PI7E`87=UM6I/HG@PI7E`838`<21WIG/X9BDP@f5^
MV5c>T=/JG0PIV5YK6ETG78YL79YKW@P;d1ULW8PM79eIB1TIFHPL6m`86EhJGAm
JFImNfMbIG=dKg9U87=UM6I/HG@PIGQYM7eYIVE/LfEmK6m_L210IG9b86i_M21k
HfaYL7eYIR1cIGAVK65dO@emI6EV3BmOHg<PKWE/K21TIFH=;fIWNg=UM6MbHGUm
I6EV3BmcIGASKGU[Hfm/Kg8PMfQULVDPNg1_L21dLWEUOG]VHFacIGeYIVE/LfD=
NbmV=7/PLfEdHfeiJf=_K6mbOFAUIWek;fHdNc4PLgER83@P<B1bKfa/83=k<b1Y
KVAUN21QI6@PKVEW86AeL20`86adNg1_L20`OFUV83<P<B1bKfa/OG9UL6EQM21c
IGAbIf9SKfa_LR1`Kg1mI6EVOFUVIFacI@d_LfEdHfm/Kg9cL65SIB1gJ6EbIB1k
L6m`87AbMFEmNfIQK7=UOFUVIFacI@ek;g=SLg/PI7E`87=UM6=_K6mbLg1QHfDP
;emSLb1UN6=X86AUIWeTIFH_IS=k85mSLb1cIGASKfa_LW=`HF=U87=UM6=_K6mb
OFAUIPemNbmV<g/PLfEdLVMRHfm/Kg9mI6EV;g=SLg/PL6m`OFAUIWeYIVE/LfD=
;bASHb0e865bLV5i86AUIPd_IVU^I6=]NF]SMG=dKfeSKfa_LR1gJ6EbIB1kL6m`
87AbMFEmNfIQK7=UOFUVIFacI@e^Kg@PNbmVJFiTHfeiJf=eLgA_KF=_K6mbNbAS
Hb1QLgA_LVEmI6EVOFUV3BmcIGASMG=dKfeSKfa_LR1gJ6EbIB1kL6m`87AbMFEm
NfIQK7=UOFUVIFacI@e^KgAk;g=UM6=eLgA_KF=_K6mbNfEhHfPPHFa_HF@PL6m`
871_L20dNc@PJFiTIGPPKGE/83@P<B1bKfa/OG9UL6EQM21cIGASKGU[Hfm/Kg8P
L6m`OFAUIWeYIPd_IV=k=R0a879_K6`PIVU^I6=]NF]SMG=dKfeSKfa_LR1UN6=X
87=UM6=eLgA_KF=_K6mbOFAUIPd_LfEdLfE`HG9QM6U_KVMbHGTPMfQULVDPNg1_
L21dLWEUOG]VHFacIGeYIVE/LfD=KVmdNbmcIGAcIG1QLV5dJFm^Ig9QNB1kLgUc
M6E]I6USM20_LfEdIg9QNB1WIG@PIGQUHgdPI6EVOFUV3BmcIg/PLfEdLfE`HG9Q
M6U_KVMbHGUmI6EV3BmcL7/_Gg1UKWHPN6AV;em`IFiX87QTIWeTIFH=;g9`3G/_
HgIOHR1hI6H_HgIOLR1hI6H=;f=fGg@PN6AV;f=fGf`PN6AV3F=fGf`PHgIOM21]
KgIUM6l=HgIOLR1SMUmd86aYKVEdK`eSMUmb86=fGf8PK6U^IGA_3F=fGf`PHgIO
HR1/JFiUM6l=Hfa_LfE`HGAXOFAUIPd_LW9k;gUbHFAYMG<PN6AV3BmhLV5TJGEc
87QTIPd_HgIOHR1hI6H=;f=fGg8PN6AV3BmSMUmd87QTIPd_HgIOK21hI6H=HgIO
K21hLV5TJGEc865TI21SMUmd86e_MVEdK`eSMUmb87QbHFAYMG<PLgER86=fGg@P
K6U^IGA_3EmSMVedN21SMG9bIFidKF5dLVUh871_L0eSMG9bIFidL6mYKW@PM79Q
KW=/HGAU3GQbHFAYMG<PNG9QI6UeLb1cHf5/I@da830P<B0a834PHG9SM6lP=7]`
Kg1mLVE`IF5d3EmSMVedN21cIGA]HGAbJGP=HgIOLR1SMUmR87UbHFAYMG<PLgER
86aYKVEdK`eOHgI]M7PPHgEbLVE^M6eQM79YN21`Kg0=HgEbLVE^M71_JFid87Ab
HFicK65dI@ehLV5TJGEc87UbHFAYMG<PLf=QK6D=<20a82da834P<B1QLV=dKb0d
Ng1_L7ebIG1UHG@=Gf=fKGAh87=UM6eQM79YN0eSMUm/87QbHFAYMG<PHFAT86=f
Gf8PK6U^IGA_3EmSMVedN21SMG9bIFidKF5dLVUh871_L0eSMG9bIFidL6mYKW@P
M79QKW=/HGAU3GQbHFAYMG<PNG9QI6UeLb1cHf5/I@d]<B0`82da82da834PHG9S
M6lP=7]`Kg1mLVE`IF5d3EmSMVedN21cIGA]HGAbJGP=HgIOK21SMUmd87UbHFAY
MG<PHFAT86aYKVEdK`eOHgI]M7PPHgEbLVE^M6eQM79YN21`Kg0=HgEbLVE^M71_
JFid87AbHFicK65dI@ehLV5TJGEc87UbHFAYMG<PLf=QK6D=<20]<B0a82da834P
HG9SM6lP=7]`Kg1mLVE`IF5d3EmSMVedN21cIGA]HGAbJGP=Hfa_LfE`HGAXOFAU
IPd_IG1kGf=fKGAh86=eLW9UKWA]HGAbJGPPL6m`3GAbHFicK65dI@ecHf5/I@da
830PKFmfIGA_3C0P<20a830P<cH`865bH`eSK6mcIG1QM6P=Gf=fKGAh87=UM6eQ
M79YN7eTIFH=;gMTNemSMVedN21SMG9bIFidKF5dLVUh871_L0edLV5^LfaQM6D=
Lf=QK6D=<20`86e_MVEdK`d`830P<B0e82db879_K6`PHG9SKPeSK6mcIG1QM6P=
Gf=fKGAh87=UM6eQM79YN7eTIFH=;f5cNemSMVedN21SMG9bIFidKF5dLVUh871_
L0edLV5^LfaQM6D=Lf=QK6D=<20`834P=B0]<R1bKfa/865bHfh=Gf=fKGAh87=U
M6eQM79YN7eTIFH=;fAc3G]OL6E^MR1OL6E^J21^IB1TMG1kLgA]85m`IFiX86Ae
L20`86aUNg1_L20aOFUV85m`IFif86AeL20`86aUNg1_L20aOFUV87=SHFaUOG]O
L6E^J21cIGA/JFiUMfUTM6QmJFIUK7=U87=dLVm[IB1kLWA]OFUVOFAUIPd_I6Ik
IVU/K7eTIFH=;fAUNfE_IVU/K7eTIFH=;emWLgA[83DPHG9bHGTPI6EV3BmOIg=d
Jf<P<21TIFH=;emWLgAk83TPI6USM21RIFMYKR1/IGIUK39k;emSHg<PHgEbLVE^
M6=_K6mbLg1QHfDPI6EV82mOHf<PFf=eLW9UKWASKfa_LUdPI6EVOG/_Gf=S85]S
MG9bIFidLVMRHfm/Kg9MI6EVOFUVIFacIB1kHgEbLVE^M71_JFidOG=dKg1`IF@P
NbmOHg0PKWE/K21TIFImNb0b865bLV5i865cM6mbIB0_Gf=`86EhHfPPI6EVOFUV
IFacIB0_Gf=V86=eLW9UKWAVKfid86AUIPd_Gf=/Mb1SMG9bIFidK6U^IGMYI7AX
86AUIR0_Gf=/Hb1SMG9bIFidK6U^IF=QL21TIFHP;emSK6XPHgEbLVE^M6aYKVEZ
KfU^86AUIR0_Gf=]K21SMG9bIFidKFUdIG9/JFeYM21TIFHPHgEbLVE^M6AYHg@P
IFiTOFAUIPd_J7=kKVEgL65dJ21WLf5fIB1cM6emI6EV3BmXHg/_GfQb86a_HF@P
IGQSJ21WIG@PIGQUHb1^IGM`HGAXOFAUIPd_J6EkGfMcM6/PGfMcM6]S85mWLg@P
L7Ed82mOIg=dJf<PGfMcM6]S834PHFAT87=dKg9U80eWLVEcM6mbIB1bM6dP;emW
LgA[Hb1OIg=dJf<P<B1cMF8PLgA_LVDPGfMcM6/PGfMcM6]S86MUM21/IGIUK39k
I7E`82mOHf=c86MUM21cIGASKfa_LW=`HF=U86AeL20_Gf=S86MUM21QK6mQI21`
Kg0PLfEdHfm/Kg9mNfAeL20_Gf=S86MUM21QK6mQI21`Kg0PLfEdLVMRHfm/Kg9m
JFIUK7=U86AeL20_Gf=`86MUM21TMG0PKWE/K21ULB0=KVmdNf5/Kf5T871_L21]
KgIUM6mmNg1_L7eYIVE/LfDPI7E`82mOHfHPIfEd87=UM6I_KW@=I7E`;emSK7LP
IfEd87=UM6aYKVEgJFAdJ21TMG0_Gf=/Hb1WIG@PLfEdK6U^IF=QL21TMG0_Gf=/
JR1WIG@PLfEdK6U^IFY_JFhPI7E`;emSKF`PIfEd87=UM6eYM6EbK6U]JG@PL6m`
OFAUIPd_JFAk82mOJF@PN6AVOFAUIPd_GfU]HGAbJGQkGgLP<20`85mX85mYI20`
86iUNfiUIb0`85mXOG/`831mJFIUK7=U85mSMVedN21QLgA_LVEmI6EV3BDP@fm`
NG9YIfQd82Q3:B0a>CT`;20a>CTa869i845TKf9U85=iLgAUKG<PBFiSKg9`Kg9Q
M6ET;PdU845/K21bJFMXM7<PLVEcIG9fIF@^3FaUMVE/<R1k87=QMVDP;fA_KWA/
Kf5TK6EfIF`a87QTIR1mJFH=;g=dHG9dKVm/Kf5TNg/_KVm/Kf5T87=QMVDPI6EV
OB1YIWeTIFH=;fE^I6i_K6mQI7]kKVm/Kf5T879ULgA_LVEmJFHPOFAUIPd_M6Ec
M7=iLgAUKFAYHgAkMfQULVEkLgUcM6E]I6USM21ULG]dLWEUOG]VHFacIGeYIVE/
LfEmNfIQK7=UOFUVIFacIGeTIFH=;fiSKfa_LW<P<B1TIFH=;f=_K6mbJFeQIfDP
MfQULVEkL6m`87AbMFEmNfIQK7=UOFUVIFacIG/_KV=_K6mbLb0`3G=dHGAeLfAY
Hg@PHVEWJFhP3Bm`LVmSIG=cHfm/Kg9c87MXIG9UNg1_L21`Kg0PL79_HfEcLf=_
K6mbLgek;fAUMVUSIFU^IVlPMfQULVEkL6m`86AUMVUSIFU^IVlP;d=_K6mbLb1[
KVmgKPekL6m`87]TIGIYHfEYKVI_82m3Kfa_LW<PIfEdOGeYIWeYIWeYIVE/LfDP
IFiT86AUIPe^Hfm/Kg9c830PKVEk;f=_K6mbJFeQIfDPM6EcM7=iLgAUKFAYHg@=
;g=UM6=_K6mbM79QKW=VIG8PM6EcM7=iLgAUKFAYHg@=;f=eLW9UKWASKfa_LWAb
HFicIVEb87AULgAcNG=dIFeTJF=d3BmSMG9bIFidHfeiJf=_K6mb87AULgAcNG=d
IFeTJF=d3F5^I21QKV@PHFiT86i_M7/_KV=_K6mbLb0`86AUIWeYIWeYIWeYIPe^
Hfm/Kg9c86AeL20a86iU86EhHfPPI7E`83<PKVDPIGQSJ20d86iU865^I21QKV@P
Nbm^Hfm/Kg9c830PI6EVOFUV3FiSKfa_LW<P<B1ULB1TMG0PI7E`86i_M21cM65b
M6i_K6mQI0ek;fA_HfaeM6U]HFMUNe]k<SDe86eeK21bKgE^I21SMVTPHWMSK7Ed
86EhHfPPIfEd838e=B1TJGIm82mUN6ES86a_HF@PI7E`86=eLW9UKWAdLV5^LfIU
LR1UN6=XGB0=HgIh869YKV@PLfEdM79QKW=VIG8PGgLPGfPP>21OJFeQM79YN21O
I7<PJFeQIfEmI6EVOFUV3Fi_M21UKVA^Kfa_HF@=KV=_K6mbLb1TMG0P<b1ULB1U
N6=X83@PIG4PKg8=I7E`86AeL21^Kg@PLgAQLWA^Kfa_HF@=Nbm^MFa/L79_Hg]k
OGeTIFH_Hfm^Hf5dMGAYK7/_IGQUHb1/Kf5T3CLP;C4PLVm/K20_IGQUHb1/Kf5T
OFAUIPd_I6EVLgERHfaeM0ek<B1QI6@PIfEdJFidIG9fHF`PI6EVOFAUIPd_Lg1S
KfiSHGAdLV5^LfIULR0P80ek;dASK7Ed86EhHfPPI6EV;d=SK7Ed86EhHfPPI6EV
;d9SK7Ed86EhHfPPI6EV;d5SK7Ed86EhHfPPI6EV;fiSKfe`MGAU86EhHfPPK6@=
HgEbLVE^M6=_K6mbM79QKW=VIG8=Fg]1HfaeM21^Hfm]L7EdIGeSKfiSHGAeM6U/
GB1SMWP=Fg]2HfaeM21^Hfm]L7EdIGeSKfiSHGAeM6U/GB1SMWP=Fg]3HfaeM21^
Hfm]L7EdIGeSKfiSHGAeM6U/GB1SMWP=Fg]4HfaeM21^Hfm]L7EdIGeSKfiSHGAe
M6U/GB1SMWP=LfEdHfm/Kg9dLV5^LfIULWeTIFH=;g=UM7E`LVMRHfaeM7<=NbmR
JG@cN21bIf9SK7Ed86aUKVMdJ20c87=eHR1TIFH=;f9YM35h869YM3=h83<PJFAY
MR1TIFH_LV=/MG@PLVMRHfaeM21TIFH=;fMSK7Ed879SK7Ed834PHVUd<gPPI6EV
LgERHfaeM2mRHfaeM21bHfaeM20b869YM3=h86AUIW=eHV=/MGAmI6EVOFUV86i_
M20P3FE^I6i_K6mQI21^Hfm/Kg9c83<PIG4PI7E`86AeL21^Kg@PLgAQLWA^Kfa_
HF@=NblcHfm]L7EdIG]UN6=X869YM3=h86eeK0ebKgE^I21SMVTPIfEd838e=B1T
JGImI6EV3BmTKf=/MGAYKF5WIG/U;g9WHV=/MG@PN6AV871_L20=LfEdMG1bIf9S
K7EdLblcHfm]L7EdIB1bHfaeM21WHfaeM21RHfaeM21TMG0=Lg1SKfiSHGAdLV5^
LfIULR1OMb1OJ20h85mYKF5dLVUh3E/_GfAc86a_HF@P;fEhIF<PK6mQI20_I7E`
86a_HF@PI7E`GF=fN0e^MFa/L79_Hb1^MFa/L79_Hb1dLWEU83<PHfm/Kg9YKF5W
IGeTIFImJFHPKVmd86E^I6i_K6mQI21^Hfm/Kg9c83@PIG4PI7E`86AeL21^Kg@P
LgAQLWA^Kfa_HF@=NbmcM7EVIV=/MGAkHfeiJfU^I6Eh83<P;C4PLVm/K21`MGAm
I6EV3BmVM6mYKWAk<B1UN6=X87=eHR0b=CDPKGE/879_MFiT86=fJGeTIFH=;cAS
Kfe`MGAU87/PIGQSJ21RJG@dN21]MF`PLVmeKV@PHgIY86MUM20b=CDPI6Uf87dP
I6EV3BmSKfe`MGAUHfeiJf=/MGAkLfEdMG1bIf9SK7EdLbmRJG@dN21bIf9SK7Ed
86aUKVMdJ20c86UTJGHP=21]MF`P=21cMF8PI6EV3BmSKGU[HfaeM21RJG@dN20d
865TI21cM79YKVLPI6EV3BmSHfaeM21SKGU[HfaeM21TIFH=;feSK7Ed86=SK7Ed
834PHVUd=7PPI6EVLgERHfaeM0d_NF=/MG@PHf=/MG@P<R1RJG@dN21TIFIcMF9S
K7Ed3Bm[HfaeM21SHfaeM20c869YM3Ah86AUIW=eHV=/MG@=;f=]NF]YKVAUN20`
86AUIPd`834PHVUd<GP=NfAeL20_HfeiJfU^I6Eh86EhHfPPHVUd<GPPIGQSJ21c
MF8P=21]MF`PI6EV3C<PKGE/86AeL21bHfaeM21UN6=X86MUM20b=CDPI6Uf86Eh
HfPPI7E`86MSK7Ed86EhHfPPIfEd838e=B1TJGH=IGQSJ21RHfaeM21UN6=X86MU
M20b=CDPI6Uf3G=UM79WHV=_K6mb86=eLW9UKWASKGU[Hfm/Kg8=IWA_JFid86]S
K7Ed87=dMFIVHfaeM0eVM6mYKW@PNF=/MG@PLgAeIVISK7Ed3FIdKfU^M21]Hfae
M21cM7EVIV=/MG@=IWA_JFid86=SK7Ed87=dMFIVHfaeM0emIVmbOFAUIPd_I6mS
K7EdJFeQIfEkJFifHFaYI6=_K6mbM65RK6DoNf=_KG1eM6ESKGU[HfaeM7eYIPd_
=6=_KG1eM6DPHf=/MG@PKF=/MG@PNF=/MG@PJf=/MG@PLg1SKfiSHGAdLV5^LfIU
LPeOMb1OJ20h85mYKF5dLVUhFbmOI7<PK6mQI20_IGQUHb1/Kf5T;fAeL21/Kf5T
86AeL21TMG1M86=fN20=KWE/K71bKf<PKWE/K71bKf<PKWE/K71bKf<PM79eIB0d
86=_K6mbJFeQIfEmI6EVOFUV3Fi_M21UKVA^Kfa_HF@=KV=_K6mbLb0`86Ea3FAe
L21TMG0PKVmd87=dHG9dKVm/Kf5T3G/_Hfm/Kg9UN71QKVAkKGUcM79YKVMUN70P
<21bIf9SK7Ed3C<PHfm`N@dg82da879_K6`=Nc<PKGE/83<PIfEdJFidIG9fHF`P
L7EdJFidIG9fHF`PIGQSJ20c865TI21UN6=X83<PHfm`NGeVKg9QK6`=L6m`871_
L21`Kg0PL6m`871_L7eTIFH=;f=bIF5dIFEhL65^I7=dLW/_KGUcM79YKVMUN70P
IGQSJ21cM30PK6E^IgAX86eeK21cM79YKVLPI6EVOFAUIPd_I6mSK7EdJFeQIfEk
;g9WHV=/MG@PN6AV871_L20c86=bIF5dIFEhL65^I7=dLR1OMb1OJ20h85mYKF5d
LVUh3E/_GfAc86a_HF@P;fEhIF<PK6mQI20_Hfm/Kg9UN71QKV@PK6mQI20_IGQU
Hb1/Kf5TGB1SMWP=IV5/LfDP<b1SKfa_LVU]HFMUOFAUIWeYIR1^Kg@PIFiTKVm/
Kf5T3FaUMVE/<R1k86A_KWA/Kf5TK6EfIF`a879ULgA_LVDPOFUV3FaUMVE/<R1^
KgAk87=QMVDP;fA_KWA/Kf5TK6EfIF`b87QTIR1mJFH=;g9WHV=/MG@P<21TIFH=
;fA_HfaeM6U]HFMUNbmXJGIQK20b=CDPI6EV80eK;dU^I6EhIF@P;dAUMVUSIE97
@R1XJGIQK21bIf9SK7EdGB1cIGASKfa_LW=`HF=U3EmYKF5WIFAYHg@PI7E`869U
IfU^80d_EfUTM6PPGgLPI6EV80d_B6EYIfQd85mX86AUIR0P3Bm4IF=_I6DPFc0P
J6UfHFaM86AUIR0P3Bm9KF5WIDeQM79YN21OJFeQM79YN21TIFH=;d9YM7=@IG93
Kfe`KfiUKW@P>21TIFHP3Bm9KWAULW1_K65dIB1VHFacIB1TIFH=IFiT86U]HFMU
OFAUIPe/IGIUK38PKVmdNb1TKfidK6mQI6aUMVE/<R1bIG=dKg9U87eYIPdU9DE^
I51bKf=CIG@=;emYKF5WIFAYHg@P<CDPI6USM21RIFMYKR0_BFeQIfEDNG1U834P
I6EV;d9YM7=@IG93Kfe`KfiUKW@P>21TIFH_BFidIG9`KfaQM6DPIV5/LfDPI6EV
86=eLW9UKWATJF=d86E^I21TIFH=;fQQLf=_K6mb87AbMFDPI6EV3Bm/IGIUK38P
LgUcM6E]I6USM20_K65^IgEQIfE/IGIUK21[KVmgKPekK65^IgEQIfE/IGIUK20b
86MUOG]VHFacIGeYIVE/LfDPI6EV3BmVKgEbIG4PNc@PJFiTIGPPIG4P>20a879_
K6`==21YKVAUN21ULB0h834PLVm/K0dd86U^I6Eh86Ea83PP<B1bKfa/3C@PJFiT
IGPPIG4P>20a879_K6`=L6m`871_L21`Kg0PL6m`865^I21QKV@PHFiTOB1TIFH=
;g=UM7E`HV5^I7=kIg=QMVD=;emcIGAdLV5^LfIULR1cNG=dIFeTJF=d82mcIGAd
LV5^LfIULR1WIG@PI6EV3BmOHgEbLVE^M7AbHFicIVEb87=iLgAUKFAYHg@P;f=e
LW9UKWAdLV5^LfIULR1WIG@PI6EV3BmOJFeQIfDPLgUcM6E]I6USM20_JFeQIfDP
IfEd86AUIPd_HVaQKV/P<21OHgEbLVE^M7AbHFicIVEb86EhIF<=<B1OHgEbLVE^
M7AbHFicIVEb86EhIF<PIG4PI6EV3Bm^IFMQM6UfIB1RK65^Jg/`85mSMG9bIFid
M79QKW=VIG8PIGQUHb0`;SDPK7Am3G/`85mSMG9bIFidM79QKW=VIG8PIGQUHb0a
85mSMG9bIFidM79QKW=VIG8PIGQUHb1WM7eYIVE/LfDPI6EV3BmYKWIULWAUI3lP
KVEWHGAYMVDPI6EV3BmOHgEbLVE^M6MbHGTPLgUcM6E]I6USM20_HgEbLVE^M6Mb
HGTPIfEd86AUIPeXHG=SKfa_LW/_968P<21TIFIm87/_968P=B1TIFIm86UVIFac
I@d_LfEdHfeiJf=_K6mb87MXIG9UNg1_L20a830P<20`87=UM6=]NF]SKfa_LR1O
HgEbLVE^M6MbHGTP<B1UN6=X87=eHPd`834P<20`87=UM6=]NF]SKfa_LR1OHgEb
LVE^M6MbHGTP<B1UN6=X87=eHPd`830P<B0`87=UM6=]NF]SKfa_LR1OHgEbLVE^
M6MbHGTP<B1UN6=X87=eHPd`830P<20a87=UM6=]NF]SKfa_LR1OHgEbLVE^M6Mb
HGTP<B1UN6=X87=eHPdd87/d86=_L7Um879UL6EQM0da830P<20`86I_MG9ULG/_
968P<B1cM6mbIGeYIPd`834P<20`86I_MG9ULG/_968P<R1cM6mbIGeYIPd`830P
<B0`86I_MG9ULG/_968P<b1cM6mbIGeYIPd`830P<20a86I_MG9ULG/_968P=21c
M6mbIGeYIPd`830P<20`86I_MG9ULG/_968P=R1cM6mbIGeYIWeYIPeRK65^Jg/_
968P=R1cM6mbIGeYIPdTHR0`86Ea82AR83DPIG4PKg9k;bATM20`86AUIWeYIRlT
I7@P;C4PI6EV86MbIG=dKg9UOFAUIPd_I6mYKF5WIG/=K6EfIF`bNfU]HFMUOG]R
IFMYKPeGJFAdJ218IFUWJ7@P@VUdLe1ULT=_KG1_KVE^M219KF5WIDeQM79YN0e4
IF=_I6DPK6E^IgAX838PIG4=Nbm4HGAQDfmeLV=U86a_HF@PIFiT86U]HFMUOG/=
A6ESKfAU86aUKVMdJ20f86Ea3G]=MFadJG1/IDAQM65CKgEbHfEcNdAQM65CKgEb
HfDP<21WIG@PA65dHE=_MG9SIB0a86MUM214HGAQDfmeLV=U838PIfEdOG/_A65d
HE=_MG9SIB1/Kf5TOFUVIFacI@e=MFadJG1/IDAQM65CKgEbHfEc83<PIFiT84AC
BD=_K6mbBFeQIfEmN`e4IF=_I6DPK6E^IgAX83PPIG5kCGE/M6U`K6E4HGAQDfme
LV=ULg]4HGAQDfmeLV=U830PIfEd84AQM65CKgEbHfDP<B1WIG@=A65dHE=_MG9S
IB0b86MUM214HGAQDfmeLV=U83<PIfEdOG/_A65dHE=_MG9SIB1/Kf5TOFUVIFac
I@e=MFadJG1/IDAQM65CKgEbHfEc83@PIFiT84ACBD=_K6mbBFeQIfEmJFImJFIU
K7=U3GeYIVE/LfD=OFUVIFacIGeTIFH=;fAdNbmbIf9SK7Ed87QTIR0_HWMSK7Ed
87QTIWeTIFH=;f=/NbAY87=UM6eQM79YN21dLV5^LfaQM6DPLf=QK6D=;emg85mY
KF5WIFAYHg@P;eMYI7AX86MUM21TIFH=;emX85mYKF5WIFAYHg@P;dQUJFMXM21W
IG@PI6EV3BmOI7<PGfU]HFMUI6USM20_A65dHE=_MG9SIB1WIG@PI6EV3FA_Hfae
M6U]HFMUOB1TIFH=;f=TNbAY87=UM6eQM79YN21dLV5^LfaQM6DPLf=QK6D=K6Ef
IF`bNemYKF5WIFAYHg@P;d=_K6mbDg1QHfDPIfEd87=UM6=_K6mbLg1QHfEmJFH=
;emg85mYKF5WIFAYHg@P;eMYI7AX86MUM21TIFH=;emX85mYKF5WIFAYHg@P;dQU
JFMXM21WIG@PI6EV3BmOI7<PGfU]HFMUI6USM20_A65dHE=_MG9SIB1WIG@PI6EV
3EmYKF5WIFAYHg@PHVEWJFh=;dU]HFMUCF5dLVUh85mYKF5dLVUh86AUIPeSMG9b
IFidI6USM21UKV@=I6mYKF5WIGdPI6EV3BmYKG/TJB1cIGA]HGAbJGPPM79QKW=/
HGAU87=SHFaU80e/IGIUK39k;dAUMVUSIDMbHGTPLfEdHfm/Kg9cL65SIB0`87=U
M6MbHGUmJFH=;emg85mYKF5WIFAYHg@P;eMYI7AX86MUM21TIFH=;emX85mYKF5W
IFAYHg@P;dQUJFMXM21WIG@PI6EV3BmOI7<PGfU]HFMUI6USM20_A65dHE=_MG9S
IB1WIG@PI6EV3EmYKF5WIFAYHg@PHVEWJFh=9Bm4IF=_I6DPFc0P<EdPI6EV820=
9BmGJFAdJ21OMb1TIFH=9Bm8IFUWJ7@PGfPPI6EV3Bm9KF5WIDeQM79YN21OJFeQ
M79YN21TIFH=HgEbLVE^M6AYHg@PIFiT80eTKfU]HFMU87eTIFH=;f=_K6mbJFeQ
IfDPMfQULVEkL6m`;dACBD=_K6mbBFeQIfDPNf=_K6mbJFeQIfEm86AUIWek;dAC
BD=_K6mbBFeQIfEk3BlTKV<PN6AV871_L20_L79_Hc0PN6AV83<PJFiTIGPP<R1Y
KVAUN21]MF`P=b1QI6@P>21TJGHPHgIY87=dLVU^Ib0_Lg@a87QTIPdTKV<P<b1U
LG]kL79_Hc0PI7E`;g=d<21hI6HP<21UN6=X83<PIGQSJ21/IFiWM6PP<b1cMF8=
NfAeL21cM30PIGQSJ21WIG@P;S<PKGE/834PJFiTIGPP<B1QI6@PLg@`86EhHfPP
IfEd82he>B1]MF`PHFAT834PJFiTIGPP<R1QI6@PLg@`86EhHfPPIfEd82ha<B1]
MF`PHFAT3F=fJB1UN6=X83<PI6Uf86=fJB1UN6=X87=d<B0c834PLVm/K21`MGAm
IVmb87=d<GemNg]`LVmS<21TMG0_Lg@`87QTIR0`86EhHfPP=21UN6=X86aUKVMd
J20d87=eHW]TMG0=Lg@`86EhHfPPIfEd82hc86eeK0da86U^I6Eh834PHFAT87=d
<21UN6=X86MUM20^=CTPKGE/865TI0da86U^I6Eh838PHFAT87=d<21UN6=X86MU
M20^<C4PKGE/865TI0da86U^I6Eh83<PHFAT87=d<21UN6=X86MUM21QI6@PI7E`
838e=Bh`86MdNg1_L20b=CD^<7eYIPdb=CD^<21UN6=X87=eHR1SMVT=IGQSJ20d
86AYMR1SMVTPIGQSJ0ecM34P<b0a879_K6`PL7EdOFI_LR1cM35mOFUVIFacI@eY
KF5WIGeTIFImJFIUK7=U3Bm?D4UYKF5WIG]YKF5WIGeTIFH=;bAY86eQM79YN21T
IFH=;f9YNg=SHFaU87AbHFicK65dIB0TJB1SMG9bIFidKF5dLVUh871_L21dLV5^
LfaQM6DPLf=QK6DPLfEdMG1RHFiTLgeTIFH=;fEYNbAY87=UM6eQM79YN7eTIFH=
;fU[NbAY87=UM6eQM79YN21dLV5^LfaQM6DPLf=QK6DP3BmOMb1OJFeQIfETJF=d
82mGJFAdJ21WIG@PI6EV3BmOJ21OJFeQIfETJF=d82m8IFUWJ7@PIfEd86AUIPd_
GfAc85mYKF5WIFAYHg@P;dAQM65CKgEbHfDPIfEd86AUIPeOMb1OJ21VHFacIB1O
JFeQM79YN20e82da879_K6`PGfAc86U]HFMUKF5cJgeTIFH=;g9cNc8PHfm`NB1d
LV5^LfaQM6D=<b0]<B1bKfa/86iUIb1bKgAQM6D=KVEW86EhHfPPKVEW86EhHfPP
M79QKW=/HGAU3GeTIFH=;f=cNemSMVedN21QLgA_LVDPHfm^Hf5dOB1TIFH=;fIT
NbmOIV@PN6AVOFAUIPd_GfI_KWA=HGAbJGQk<B0`830PGfIT830PKVEk;C4P<20`
OG/a830P<7eYIVE/LfDPGf=fKGAh865cM6mbIGeTIFH=;g9VNbmOIFiSKfAYKVAU
N21hI6H=AVm^M4AYLVESM6mbNB1UN6=X86]^KgM^87/=IVU^I6I_KW@PI7E`86aU
KVMdJ20a865TI21TJF=d869UIfU^Nc4PJFiTIGP_ATU486iUNfAUIWekL6m`871_
L7eYIVE/LfEmIVmbHFa/3FAeL20_AVm^M4iQKFDPIGQSJ21TIFHPAVm^M5AiL6DP
<21^IG/_AFiSKfAYKVLPAFiSKfAYKVLP<SDf865bLV5i86=_L7TPI6EV3EmUKV=_
I6U^I6Eh830PIfEk<21OIFiSKfA1LW8PGfE^HfmTJFiTIGPPIfEdNfAeL21dNG1U
;fiQKFEdNG1U86EaNdE^HfmTJFiW838PJFiTIGPP<R1YKVAUN21`MG@PL6m`834P
HFATO@ekIGQSJ21`Kg1mJFIUK7=UOFI_LV5/K21`Kg1mJFImJFH=HgEbLVE^M6AY
Hg@PIFiT3FAUIVU^IFI_KW@PL6m`87ekL6m`871_L7eYIVE/LfEm86AUIPd_HgIc
IW/PIVU^I6I_KW@PIWACJGYU830P<21VM5=YNVDPGfIT830PKVEk;C4PKGE/OFUV
830P<21OHgI]M7PPHG=dKg9U80e]HF]UIVm^M21cIGAVKfidOFAUIPd_KFIk<b0]
<B1bKfa/86IYKVAVKfid83<P<B1bKfa/86EhHfPPIWACJGYU86eeK21UN6=X86Id
DfUjIB1]MF`P<21UN6=X830PIGQSJ20=GfIT830PKVEk;C4PKGE/OFUV830P<21O
HgI]M7PPHG=dKg9U86eQJfEVKfid87=UM6I_KWAmI6EV3BmgLV/a82PP:B1TIFH=
;gMTJF=d834f86AYHg@PI6EV3BmGKg9[=cDP=cDPLgAbJFiW86AUIPd_CVe[NeM_
LV/g=B1SMW<PI7E`OFAUIPd_CW1dNg1eM21SMVimI6EV3BmTJ4mTJ7]>KF/P<R0g
>B1>L7AmI6EV3BmTJ49TJ7]>KF/P<R0a<C4PCW1dOFAUIPd_I6QCI6QkCVe[838P
>3<PCW1dOFAUIPd_LfIGJFAdJ7]WLf5fIB0`830PKFmfIGA_830P<21/JFiUM6lP
<20`86aYKVEdKb0`830PK6U^IGA_86=/Kg=UL65dJ21SK6U`87=dLVU^IgMYI7AX
86MbIG=dKg9UOFAUIPd_IWAcNbmVM5=YNVDPIGQSJ21TIFImI6EV3Bm]JdIDNfAe
L2m6KfidE7U`IB1WIG@P<21ULG]TMG0PKF5hK6E^IgAX86AYHg@PHVEWJFh=Nc4P
JFiTIGP_ATU486iU838PJFiTIGPP;eE^JG5eIDU486iU865^I7]TIFImNg1_L21`
Kg1mJFIUK7=UOFI_LV5/K0eSMG9bIFidI6USM21UKV@=I7E`;dI4IG1FIF=dKg8P
<R1SKg1i86MUM0eKIGQSJ20f86U^I6Eh86EhHfPP=R1YKVAUN21UN6=XNfe[AU@P
<b0a879_K6amIVmbHFa/871_L21`Kg1M871eM21TMG1mNbmdIFe`AU@P<C8PI6US
M21TIFH=M6E]L4ID869UIfU^3Bm6KfidCF5dLVUh85/a830P<20a830P<5dPI6EV
3Bm6KfidE7U`IB0c86AUIPeTMG0_AFiSKfAYKVLPIfEd;dE^HfmTJFiW86EhHfPP
I6EV3Bm`LVmS<R0b86U^I6Eh86AUIPeTMG0_IW@a86EhHfPPI6EV3BmVM38P<B1Q
LW9QNB1TIFH=;dI_KWA2@Vmh85/`830P<B0aGB1TIFH=;d9eJFaT@fQQLW]3ETAY
Hg@PHVEWJFh=IGQSJ21TMG0_IWATM21hI6HPHVEWJFh=MfAYHg@PHVEWJFh=;f=X
LR1hI6H_HfQbLg@PMg9[<B1TMG0P<21SJ78PL7Ed86AUIPeVM38P<21WIG@PKWE/
K21ULG]VM34PI7E`86aUKVMdJ20b865TI21TJF=d869UIfU^3G/a86U^I6Eh;dI9
A21^IB0b86U^I6Eh82mEKVUaMFE9A21^IB1QKVAkI6EVOG]`Kg0PL6m`OFUVIFac
IGeVKg9QK6`=;e1QJFidE7U`IB0b86AUIRmCM79_JfEGJFAdJ20^<38d830PAVm^
M4eQM79YN21YI7AbHFicIVmbKB1`Kg0PI6EV3F=eLW9UKWATJF=d86E^I0d_LB1U
N6=X86AUIVU^IFI_KW@=IW@b86EhHfPP<21UN6=X871eM7eYIPeVM6Ad;g1bKf<b
86MUM21UN6ES86E^I21UKV@PIFiTOFAUIR1UKV@PM6E]L4IDOFUVIFacI@dc86U^
I6Eh86EhHfP=I6EVJFiUIVm^M21UN6=X871_L7eTIFH=;feRNfAeL21TJ49TJ216
KfidA6UbIF=dKg9i834PJFiTIGPPJfi_Mfh=NfEhHfPPL6m`OG]TM@0S0000X@30
5Za`838PJFiTIGP=IVU^I6I_KWAkHVm/I71bKf=m86EhHfP=KF]6E21`Kg0PL6m`
871_L21UN6=X871_L0emJFIUK7=U87eTIFH=;fe_NfAeL21TJ4mTJ216KfidA6Ub
IF=dKg9i834PJFiTIGPPJfi_Mfh=NfEhHfPPL6m`OG]TMG0P<R1YKVAUN0eVJFiT
IVm^M7]_MGA`LVmSOB1UN6=X3Fe[AU@PL6m`871_L21`Kg0PIGQSJ21`Kg0=OFUV
IFacIB1mI6EV3Bm]Lg]TMG0PI6QCI6PPAVm^M4AYLVESM6mbNB0a86U^I6Eh86]^
KgM^3G]UN6=X871_L7ekI7E`838PJFiTIGP=IVU^I6I_KWAkDfQQI4=XHG9m86Eh
HfP=KF]6E20PL6m`871_L21`Kg0PIGQSJ21`Kg0=OFUVIFacIB1mI6EV3Bm_MGA`
LVmSNfId<B1cIGAVKfid3FMcHGIU86=XLW=d87=VEfUTM6PPIg9ULgA_LVD=LfEd
HfQQLWMYI7AX86ARK7=XOFAUIPd_HVm/I71bKf=kIW@a87=UM6I_KW@=Ig=QMVD=
HfQbLg@PLfIGJFAdJ20a86U^I6Eh830PKVEkIGQSJ20^<3DPHFAT86EhHfQmJFH=
Ig9ULgA_LVD=LfEdHfQQLWMYI7AX3FId<B0_D65YKWADNG1U86MUM20b86iU3G/`
830PKFmfIGA_86McHGIU86Id<R0`86MUM21cIGAVKfid86=XLW=d87=XKgLPIg9U
LgA_LVDPHfQbLg@PLfQ_Mgd=Nc0P<21]KgIUM6lPIg=QMVDPHfQbLg@PLfQ_Mb1W
LVEcM6mbIB0^<3DP<21]KgIUM6lPHfQbLg@PLfQ_MgeYIVE/LfEmI6EV3BmTHVac
J7]SMG9bIFidHfm/Kg8PHgEbLVE^M6=_K6mbLg1QHfDP<Bh`87=UM6MbHGT=HfQb
Lg@P<20`86e_MVEdKb1cJ6mg87=UM6=_K6mbLg1QHfDPLfEdHfm/Kg8=IW@b830P
IfEd87=UM6I_KW@PHfQbLg@P<20`86e_MVEdKb1cJ6mgOFAUIPd_DfQQI4=XHG9k
3FId<B1cIGAVKfid3FMcHGIU3F=XLW=d87=VEfUTM6PP<B1YKVAUN20`86iUNfEh
HfPP;S0e865TI21UN6=XOFUV3FMbIG=dKg9U3G=UM6=XHG9gJFAdJ0eSJ79cM20^
<3HP<21]KgIUM6lPLfQ_M`d`82h`=B1dLV5^LfaQM6DPI69/LfQmI6EV3BmdLg]c
J6mgOFAUIPd_M65k;em/IGAdIG9CL65SIB1hI6H_Gg=`HF=UF7AbHB1hI6ImI6EV
3BmdIW/_GgAUN7AGJFAdJ21hI6H=;em^MFeCL65SIG<PN6AV3BmOLgAbJFiWC6E^
IgAX87QTIPeTMG09LgAbJFiWMfUTM6PPL6m`3Em/IGAdIG9CL65SIB1OLgAbJFiW
C6E^IgAX834PLgER86eeK21QI6@=Gg=`HF=UF7AbHB1OKWE]Dg1QHfEc86eeK21Q
I6@=GgAUN7AGJFAdJ21UN6=X87=eHR0_MfAYIR1hI6H=Gg=`HF=UF7AbHB0`83<b
3GMTJFHPGg=dLVU^IdaUKVMdJ21TJGH=GfaUM7AULU=`HF=U865TI0d`83HP;C4P
LVm/K21QMfUTM6QcJ6mgOFAUIPd_L69k;em@HFMUDf5fIB1cHGIU86AUIRmcJ6mg
L65WIG]mI6EVOFAUIPd_L6EkGe1QIfECHGIU879ULgA_LVEmI6EV3Bm`KG]OL6dP
HgEbLVE^M6eQM79YN21`Kg1mI6EV3BmOL6dPKF5dLVUh86AUIPd_L7=kLfQ_Mg1Q
IfDPGg1]87=UM6eQM79YN7eTIFH=K6EfIF`bNbmUIR1kIg=QMVDP=R1QLW9QNB1Q
LgA_LVDPHfm^Hf5d86AeL21UN6ESIVmbKB1WLVEcM6mbIGeTIFIm3G/_IFIkIg=Q
MVDP=R1QLW9QNB1QLgA_LVDPHfm^Hf5d86iUMg1QM6PPI7E`869UIfU^84eQM79Y
N21SKfiSHG@=@T9_N21TMG0PI7E`830PIfEd86EhHfPP<B1WIG@PKFmfIGA_3FAe
L21TMG0P<21WIG@PIGQSJ20c86MUM21/JFiUM6l=I7E`86AeL20b86MUM21UN6=X
83<PIfEd86aYKVEdK`eTMG0P<R1WIG@PIGQSJ20a86MUM21/JFiUM6lPHfa_LfE`
HGAX3F=/JG0PKVEgL65dJ21@HFU^M51bKf<PIFiT86MbIG=dKg9UOFAUIWeYIVE/
LfD=;f9SNg=QMVDP<C4P<B1bKfa/834`86AYHg@PHVEWJFhP;d92KgPP=B0a879_
K6`P=21QLW9QNB1QLgA_LVDPI6EV3Bm=HGAbJGPP=b0a879_K6`P=R1QLW9QNB1Q
LgA_LVDPI6EV82m6Kg9]E7U`IB0a86AUIRm@HFU^M51bKf=k;g1`86MUM21UN6ES
OFAUIWeTIFH=;fESNg1_L21bIG=dKg9UOFAUIPd_L79YKWAfKG/a87I]LVESK65Y
KB1fKG=dHGAeLb1`Kg0PIGQSJ21`Kg0P:20P820P820P820P820P820P820P820P
820YHgIc871bJFid82QLKRU`LVU^M21VK7EcJ7eTIFH=;g=UM6mfIG9`LVU^M21g
J6EbIB1kL6m`OG/_LfEdKgIULW1bJFidNg1_L7eTIFImJFIUK7=U3BmcLgAb87/P
;bAcLgAbLb1UN6=X86AUIR0_97=cM78PIGQSJ21TIFHP;bAcLgAbNB1UN6=X86AU
IR0_97=cM79h86EhHfPPI6EV82m3KgEbJFEb86IYKVAVKfid82AcLgAbLb0=Lf=Q
K6EVKfid87=UM6I_KW@P97=cM79h82AcLgAbNB1]M21cM6dP<B0]<B1cHf5/IB0T
Lg=dLR1cJ6mg879dKB1m86AUIPd_A5=9@VEWJFi@HFU^M51bKf=k;g1`86eQLV]k
HgEbLVE^M6IYK6DPM6m[IFhPKVmdNgeYIR1TMG0_A5=9AFiTD65YKWA@LVmS3@UU
LG]`Kg0PHfmeKWAdKfeQLV/PHG9bHGTPHG=dKg9U86=fN21RJFiT82mUN6ES86a_
HFAMHgIh86AUIR14DdU5KVA@HFU^M51bKf<PIGQYM7d=2G]SKgE^M7A_KF5bJb0c
<30PIgAkHfmeKWAdKfeQLV/PHG9bHGTPHG=dKg9U86=fN21RJFiT82mUN6ES86a_
HFAmJFImJFIUK7=UOFa_Kg1mI6EV3Bm4DdU5KVA@HFU^M51bKf=kHgEbLVE^M6AY
Hg@PIFiTOFAUIPd_A5=9@VEWJFi@HFU^M5=eHU1bKf<PNg=QMVDP<C4P<B1bKfa/
834`86AYHg@PI7E`82m`A21UN6=X86AUIR1RIFMYKR0=2Bm2@Vmh83DP<B1bKfa/
83@PHG9bHGTPHG=dKg9U86AUIR0_CF5dLVUh83LP<B1bKfa/83HPHG9bHGTPHG=d
Kg9U86AUIR0=2Bm6Kg9]E7U`IB0a86AUIR0_D65YKWA@LVmS87/P;g1`86MUM21U
N6ES87dPI6EV82m`L7dPI6EV3Bm4DdU5KVA@HFU^M5=eHU1bKf<PNf9YKV@PI6EV
86E^I21`A7dPI6EV3BmYHF4PNbmYN21YN21YN6hPHFAT86AUIWdPI6EV3BmYHG<b
87/_JFMQL21UN6=X86AUIR0_Gg=d<21YHB1YN21YIf5`865TI21WIG@PI6EV85mc
M31m86AUIPd_JF5c87/_Lg@`86UQ86Uh86MUM21TIFHPJF5Q87=d<7dPI6EV3BmY
>3Ec87/`86UQLc8P;d5C@dU9>3E4IF=_I6DPIVU/M6Eb87=d<21bIF5TLgAbJFiW
871_L21YHF5m86AUIPd_JG9/IG<PNc0PJF5c<R0_@E=3BDTh=DAUHfmTIB1VJFad
IG8P;e9eKTaUKVMdJ4AUHfmTIB1VJFadIG8PLg@`879UHFAcM79YKVLPL6m`86UQ
HGdPI6EV3FU^JGAYHFaYNVD=IFiT3BDUAFiTDVEcKgEbHfD=@eI4JF=d869UIfU^
830PJF@P<B1VI0eOIFiSKfA1LW8P<0eK3C<i;g5eKgAULfU^IfaU83Tf;fMbHGIU
3C4b>2mRMFa/IG@_HWE/K6Ed;g5eKgAULfU^IfaRHG=U;fI/Kg9YKRmaMFmdIFAR
K69QLfD_IFa/JG1cJG<_I65WIfEb;fAQIfMULVARK2mSJG9SMFeVK6Eh;g1ULWAX
KgEcHFiT;e=SHG9_KRmWMFU/LfU^Ifa/IFId;dm5;f9eK6aUM2mRMFa/IG@_HWE/
K6Ed3BmRMFa/IG@_LGE_M6E/IFId;g5eKgAULVUWJ7@_LGE_M6ETHVa/IFId;g5e
KgAUI69/LVUWJ7@_HWE/K6Ed;fE^I65cJ2mUKFAQLfP_M6U/I6D_M79QI6E]HG9[
3BmcHf5bKfh=;fMeJFacJFiWK79YIfQd;fmU;f9eK6aUM2mRMFa/IG@_FFAYIG9U
LfUc3BmRMFa/IG@_IGQSK65]I6mgKRmSIFid;g=dIG9/JFiW;f=eLW9UKV=i;gUU
KRmRLVm[IFiRHG8_LfESM6U_KRmTJFEbIG=YLbmSKg1iLVUWJ7@_Kg9TIVE]JFiY
KVD_IgEYK6aUKFmdK6EVM2m/KfMYHf5/KVmd;fQiL6QUKRmbIFMYLgAULVET;feQ
Hg9_KPd_I6EWLVEU;g1/MG=]JFieLbmdMfmcMG1ULVU_LRmdJ79UIG=eL6EbJFmb
;f5SMGAU;fee;g1QLV5WLV5`J2m`IG9YKfASIFidIG9UI2mSIFAYK6aQ;fm^IG=e
L6EbJFmb;fmbI6eQLf=eK6U^IBmWMFU/K6E]KgAbJFMXM2m_KVEaMF5bM6Eb;fm^
IFQQK6H_M6QbIFEaMF5bM6EbLbmaMFEcM6U_KVA_Mfh=;d5WLV5fIBm1HF=eM6D_
@F=YLV=eKFI/IGP_@GAYK6AU;d5TJFEbIG=YL`d_@G9YKVL=;d55;d=SIFAYK6aQ
;dEWLV5fIBm5HF=eM6D_AFMbHGIU;dETJFEbIG=YLbm9Ig9QMVD_BF5SMGAU;dUS
JG9SMFeVK6Eh;dUTJFEbIG=YL`d_AGAX;didJFaTIBm?Ig9QMVD_Cf5SMGAU;dmS
JG9SMFeVK6Eh;dmdJFaTIBm?I6UULVEcJG<_KGE/M6U`K7T_Cg=/HG=X;eEWLV5f
IBmEHF=eM6D_EF=YLV=eKFI/IGP_EFAYIG9ULfUc;eUQHgEdIBmDJ6mbKRmWIG9]
HFiTHVac3BmQIg9QMVD_HF5SMGAU;f5SJG9SMFeVK6Eh;f5dJFaTIBmQI6UULVEc
JG<=;f5bJFiW3BmQIBmSHfETJFa/HBmUIg9QMVD_IF5SMGAU;fESJG9SMFeVK6Eh
;fETJFEbIG=YL`d_JFMbHGIU3BmYHF=eM6D=;fUSJG9SMFeVK6Eh3BmYI6UULVEc
JG<=;fEdJ2m^M6U/I6D_KfMbHGIU;fmQHgEdIBm_HfUbHgE]IVaUN2m_M6U/I6D_
KfAYIG9ULfUc;fAYMVUTIBm_LfaQLfP_MFMbHGIU;gEQHgEdIBmeHfUbHgE]IVaU
N2meI6UULVEcJG<_NF5SMGAU;gAXKg9^;gUTJFEbIG=YL`eM871eM0eOIFiSKfA1
LW8P<@eK3C<i;g5eKgAULfU^IfaU83Tf;fMbHGIU3C4b>2m1I6UULVEcJG<_@G9Y
KVL_@f=UI6U/K64_AF5SMGAU;didJFaTIBm?I6UULVEcJG<_EFAYIG9ULfUc;f5Q
HgEdI@d_HFMbHGIU;f5SJG9SMFeVK6Eh;f5TJFEbIG=YLbmQM6U/I6D_HG9YKVL_
Hf=UI6U/K64_IF5SMGAU;fEWLV5fI@d_IF=YLV=eKFI/IGP_IFAYIG9ULfUc;fUQ
HgEdIBmYIg9QMVD_JF=YLV=eKFI/IGP_JFAYIG9ULfUc;fidJFaTIBm_HF=eM6D=
;fmWLV5fIBm_HfUbHgE]IVaUN2m_I6UULVEcJG<_KgAYK6AU;gEQHgEdIBmeIg9Q
MVD_MF=YLV=eKFI/IGP_MFAYIG9ULfUc3BmTHFMWIG8_I6EWLVEU;f=UKW@_LgAU
LVaYKVL_LfESM6U_KRmRMFa/IG@_L65bHFMbHG1X;fMULVeQKVARK7<=;g9UIfUc
M6EbIF@_Hfm`NG9YIfQd;gAbHFAUKF5bJbmQHgEdIBmTJFEbIG=YLbm^KgAULGEQ
K2m1ABm?LfaQLfP=;fU^IVU^JGAi;g1/MG=]JFieLbm/IG=cIG5eHF`_Ig9UHGAU
LVEaMF5/;gUUKRm]MBm`HG9dJF5/I6UVIRmcMFe]HGAYKfh=;g1bKfAeHg@_L6T_
JFidIFMbHF`_Kg9TIVE]JFiYKVD_Kg9TKF5cHgE/JFiU;dm]IFMQ;f5U;fmcK65c
J0d_LGEULgAYKfiTKgM^;fEhHfaQKFA_Mfh_K6mWJF=QK6i_M2mbHFAYHf5/;fI/
Kg9YKRmQL71bKgQULGEQK2m4IFadHBmWMFU/K6E]KgA/IFId3BmWMFU/K6E]KgAb
JFMXM2mUK6aYL7=YLbmRK65^Jbm1Ig9QMVD_@GAYK6AU;dmdJFaTIBm?ABm_I@d_
IFiTHG=X;fE]I65cJ2maMFmdIFARK6aUIW@_LGE_M6ETHVabJFMXM2maMFmdIFaU
IW@_LGE_M6EbJFMXM2mTJGIYI6D_K6mjIFiWI@d_NFAYIG9ULfUc;eUTJFEbIG=Y
LbmVLV5SM6U_KRmSMG9bIFiSNBmWMFU/LfU^Ifa/IFId;fMeJFacJFiWK79YIfQd
;fIY;fI/3BmTHFMWIG9THV`_L6EbJFmTHfE^M6EbIF@_LGE_M6EcJFiWK69QLfD_
LGE_M6ETHVaRHG=U;g1ULWAXKgEcHFiT;d5SJG9SMFeVK6Eh;dESJG9SMFeVK6Eh
;d5QHgEdI@d_AFAYIG9ULfUc;dEWLV5fIBm9HF=eM6D_BF=YLV=eKFI/IGP_BFAY
IG9ULfUc;dUWLV5fIBm?HF=eM6D_Cf=YLV=eKFI/IGP=;f5`L6aU;dmWLV5fIBmE
HF=eM6D_EF=YLV=eKFI/IGP_EFMbHGIU;fA_M6aULg=Y;f=YLV=eKFI/IGP_M6U/
I6D=;feQHg9_KRmRLVEfIBmTKgAQHf=UKW@_LVU^IbmSIFAYK6aQ;fQeKVMQLWE]
K65eM2m_Ifm^IF/_Hf5bKfh=GB1`MG@=IFiT3BDUAFiTD79_K6mW80dU9D9UIfU^
DfEdMG0P3D=FA6USM21RIFMYKPd=;emOGdI><b0_B6E/MVEdJF=Q86AeL20PI7E`
86IYKVAVKfid86AeL20_@fQQLU=dLVU^Ig<PJfi_MfhPNf9UIfU^84=XHG9CM79Y
KVMc82m1I6UULVEcJG<PJfi_MfhPNc4POG/]<GdPJFIUK7=U86E^I7dPNg1_L20]
<GdPJFIUK7=U879V3C0PJF@=<B1VI0d`838f=R1dLV5^LfaQM6D=<c0`82dc<30P
Lf=/J@dU9DE^I5=UM7E`80dU9D9UIfU^D65WIE=UM7E`80e`K@dU9DE^I51QIfEC
IGAeL0d_A6EfJF=UDTM287=SL`d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3B0`
86aS3B0b86aZ3E@PLf4=9G1QIfDPLVESM3XP>CTP<CPP=3Ti838h<b0=LgA]3@2Q
0<000fMc3@00X@3008EXL`de>34e;STd<SLP<cDa;SDf<3LPKG@==CPc<bhc<3<g
83<e<Bhe=S0g86aY3CDh<c<^<c0c=b0d<S0e;SL`=cPPK6T==CPa=Bhi=38g83@b
<3D^=c0g>21/J@de>34e;STd<SLP<cDa;SDf<3LPK6T=Hg0=834PJ6<=Lf5fIB1c
M6d=002Q0<000fMc3@00X@300K1cHGIU87=dK@ecHGIU3BmXHg@PIV5/LfDPI6EV
3G=dK@da;S0`<30P<2h`<30`830^<30`<20a;S0`<30P=c8b<Rha>3De83De=Bhe
=C8g86=c3C4b=3T^>CTc=b0a<S@i;STi<cLPLf=/3BDP@g9_L59UHg@j830P<20c
<R0c<Pda834P<20`830P<20a834PHVT=83<b82mcM30PIGQSJ21cM79YKVLPI6EV
3EmYKF5WIFAYHg@PHVEWJFh=;dAUHfmTIB1K<20aGB1TIFH=;d=_K6mbDg1QHfDP
;dAUMVUSIDMbHGTPI6EV3DHP82m=MFadJG1/IDAQM65CKgEbHfEc86EhHfPPI6EV
3B0c<R0_EfUTM6PPIGQSJ21TIFH=83<b82m8IFUWJ7@PIGQSJ21TIFH=;dAQM65C
KgEbHfDPNf=eLW9UKWAVJFaU87=d<21bIF5TJ6EhLgAbJFiW871_L7dPI6EV3FE^
I0dU9D9UIfU^I4AQM64j830`<30`<30`<30`<218IGPPC6U^IG<=<c8^83<b;R0]
>CP^>38f<R0]<CL^>3La<b1YK@d0X@30220`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30=<30`<4I6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6APe6ATI6<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH=ATI6AS0`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6ATH`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30=<30`
<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH=
ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI63DI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI60:40`00<
3@dU9DE^I4AQM64=0:40`00KIFT=LWA]3G9ULgA_LVD=LWA]879ULgA_LVD=002Q
0<000fMb3@00X@3001EbM6dPLVEcM6mbI@ecHGIU87=dK@d00:40`003Ig<=002Q
0<01/G=QMVDPLgA]3G=QMVD=;fQSM21VHFacIB1TIFH=LgA]3C4^<30`<20`;S0`
<30P<2h`<30`834^<30`<20g<S8b;S4h=CDP<C4a<Bha<3De86=c3C4b=3T^>CTc
=b0a<S@i;STi<cLPLf=/3BDP@g9_L59UHg@j830P<20c<R0c<Pda834P<20`830P
<20a834PHVT=83<b82mcM30PIGQSJ21cM79YKVLPI6EV3EmYKF5WIFAYHg@PHVEW
JFh=;dAUHfmTIB1K<20aGB1TIFH=;d=_K6mbDg1QHfDP;dAUMVUSIDMbHGTPI6EV
3DHP82m=MFadJG1/IDAQM65CKgEbHfEc86EhHfPPI6EV3B0c<R0_EfUTM6PPIGQS
J21TIFH=83<b82m8IFUWJ7@PIGQSJ21TIFH=;dAQM65CKgEbHfDPNf=eLW9UKWAV
JFaU87=d<21bIF5TJ6EhLgAbJFiW871_L7dPI6EV3FE^I0dU9D9UIfU^I4AQM64j
830`<30`<30`<30`<218IGPPC6U^IG<=<c8^83<b;R0]>CP^>38f<R0]<CL^>3La
<b1YK@d00:40`0PP<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH=ATI6AS0`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6ATH`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30=<30`
<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH=
ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI63DI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH=ATI6AP2Q0<0030d=9BE5KVA4HGAQ3@2Q
0<006fEY3G9dK@ebIG=dKg9U3G9dKB1bIG=dKg9U3@00X@3000=WLPd00:40`00E
LWA]879ULgA_LVD=Lf5fIB1cM6d=002Q0<000fMc3@00X@300K5cHGIU87=dK@ec
HGIU3BmXHg@PIV5/LfDPI6EV3G=dK@da;S0`<30P<2h`<30`830^<30`<20a;S0`
<30P=c8b<Rha>3De834f=SH^=SDh<R1SL`da<S@i;STi<cLP<C8d>Bhi>C<g87=S
K0dU84=bKg1BIF=d>R0`830P<c8P<c8=<B0a830P<20`830P<B0a869Y3B0c<R0_
Lg@`86EhHfPPLgAbJFiW86AUIPeOJFeQIfETJF=d869UIfU^3Bm4IF=_I6DPFc0P
<EdPI6EV3Bm3Kfa_LU=`HF=U82m4IGIYHfE7LV5i86AUIPe6820_CGE/M6U`K6E4
HGAQDfmeLV=ULb1UN6=X86AUIPdP<c8P;eMYI7AX86EhHfPPI6EV3B0c<R0_B6EY
IfQd86EhHfPPI6EV3Bm4HGAQDfmeLV=U87]SMG9bIFidIVU/IB1cM30PLVEQI6QU
N7=dLVU^Ib1`Kg1m86AUIPeUKV@=9BE2IFMYKVA4HGAQ>R0`<30`<30`<30`<30P
B6Eh84aYKVEc3C<b;R0c<RhP;CTh;SPb=S8P;C4g;SPg<C<PJFd=002Q0<08830`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6ATH`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30=<30`
<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH=
ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI63DI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI63DI6ATH0X@3000`=3BDUAFiTA65dH@d0X@3001]UJ@ebM6d=LVEc
M6mbI@ebM6dPLVEcM6mbI@d00:40`003Ig8=002Q0<005G9dKB1bIG=dKg9U3G=Q
MVDPLgA]3@00X@3000=WL`d00:40`06aLf5fIB1cM6d=Lf5fI@d_J6=d86IQK7=U
86AUIPecM6d=<Bh`<30`830^<30`<20`;S0`<30P<Bh`<30`83Lb<S8^<CPe=B0b
<S8b;S8a<3TPHg<=<C8d>Bhi>C<g834b=3T^>CTc=b1cHf`=9B13LVm`DVESM3XP
<20`83<b83<b3C4P<B0`830P<20`834P<B1RJ@dP<c8P;g=d<21UN6=X87=dLVU^
Ib1TIFH=GfU]HFMUI6USM21RIFMYKPd_A6ESKfAU85/`835M86AUIPd_@fm/Kg9C
L65SIB0_A6EfJF=UAg9QNB1TIFH=AR0P;deeK7AYL6aUA65dHE=_MG9SIG<PIGQS
J21TIFH=83<b82mGJFAdJ21UN6=X86AUIPdP<c8P;dQUJFMXM21UN6=X86AUIPd_
A65dHE=_MG9SIB1kHgEbLVE^M6IYK6DPLg@`879UHFAXIGQcM79YKVLPL6m`OB1T
IFH=IFiT3BDU@VEWJFiTA65dHCXP<30`<30`<30`<30`84QUN21<JFiUL`dc<RhP
<c8^82di>2hh<SHb82da=bhh=c4c86U]3@00X@30220`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30=<30`
<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH=
ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI63DI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI63DI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6
0:40`00<3@dU9DE^I4AQM64=0:40`00KIFT=LWA]3G9ULgA_LVD=LWA]879ULgA_
LVD=002Q0<000fMb3@00X@3001EbM6dPLVEcM6mbI@ecHGIU87=dK@d00:40`003
Ig<=002Q0<01/G=QMVDPLgA]3G=QMVD=;fQSM21VHFacIB1TIFH=LgA]3C4^<30`
<20`;S0`<30P<2h`<30`834^<30`<20g<S8b;S4h=CDP<SLg=bhg=S<g86=c3C4b
=3T^>CTc=b0a<S@i;STi<cLPLf=/3BDP@g9_L59UHg@j830P<20c<R0c<Pda834P
<20`830P<20a834PHVT=83<b82mcM30PIGQSJ21cM79YKVLPI6EV3EmYKF5WIFAY
Hg@PHVEWJFh=;dAUHfmTIB1K<20aGB1TIFH=;d=_K6mbDg1QHfDP;dAUMVUSIDMb
HGTPI6EV3DHP82m=MFadJG1/IDAQM65CKgEbHfEc86EhHfPPI6EV3B0c<R0_EfUT
M6PPIGQSJ21TIFH=83<b82m8IFUWJ7@PIGQSJ21TIFH=;dAQM65CKgEbHfDPNf=e
LW9UKWAVJFaU87=d<21bIF5TJ6EhLgAbJFiW871_L7dPI6EV3FE^I0dU9D9UIfU^
I4AQM64j830`<30`<30`<30`<218IGPPC6U^IG<=<c8^83<b;R0]>CP^>38f<R0]
<CL^>3La<b1YK@d00:40`0PP<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH=
ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI63DI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI63DI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH=ATI6AP2Q0<0030d=9BE5KVA4
HGAQ3@2Q0<006fEY3G9dK@ebIG=dKg9U3G9dKB1bIG=dKg9U3@00X@3000=WLPd0
0:40`00ELWA]879ULgA_LVD=Lf5fIB1cM6d=002Q0<000fMc3@00X@300K5cHGIU
87=dK@ecHGIU3BmXHg@PIV5/LfDPI6EV3G=dK@da;S0`<30P<2h`<30`830^<30`
<20a;S0`<30P=c8b<Rha>3De83<c<c<^<c4f=21SL`da<S@i;STi<cLP<C8d>Bhi
>C<g87=SK0dU84=bKg1BIF=d>R0`830P<c8P<c8=<B0a830P<20`830P<B0a869Y
3B0c<R0_Lg@`86EhHfPPLgAbJFiW86AUIPeOJFeQIfETJF=d869UIfU^3Bm4IF=_
I6DPFc0P<EdPI6EV3Bm3Kfa_LU=`HF=U82m4IGIYHfE7LV5i86AUIPe6820_CGE/
M6U`K6E4HGAQDfmeLV=ULb1UN6=X86AUIPdP<c8P;eMYI7AX86EhHfPPI6EV3B0c
<R0_B6EYIfQd86EhHfPPI6EV3Bm4HGAQDfmeLV=U87]SMG9bIFidIVU/IB1cM30P
LVEQI6QUN7=dLVU^Ib1`Kg1m86AUIPeUKV@=9BE2IFMYKVA4HGAQ>R0`<30`<30`
<30`<30PB6Eh84aYKVEc3C<b;R0c<RhP;CTh;SPb=S8P;C4g;SPg<C<PJFd=002Q
0<08830`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI63DI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI63DI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`
<30`ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI63DI6ATH0X@3000`=3BDUAFiTA65dH@d0X@3001]UJ@eb
M6d=LVEcM6mbI@ebM6dPLVEcM6mbI@d00:40`003Ig8=002Q0<005G9dKB1bIG=d
Kg9U3G=QMVDPLgA]3@00X@3000=WL`d00:40`06aLf5fIB1cM6d=Lf5fI@d_J6=d
86IQK7=U86AUIPecM6d=<Bh`<30`830^<30`<20`;S0`<30P<Bh`<30`83Lb<S8^
<CPe=B0c>3Ph;SPf>C4PHg<=<C8d>Bhi>C<g834b=3T^>CTc=b1cHf`=9B13LVm`
DVESM3XP<20`83<b83<b3C4P<B0`830P<20`834P<B1RJ@dP<c8P;g=d<21UN6=X
87=dLVU^Ib1TIFH=GfU]HFMUI6USM21RIFMYKPd_A6ESKfAU85/`835M86AUIPd_
@fm/Kg9CL65SIB0_A6EfJF=UAg9QNB1TIFH=AR0P;deeK7AYL6aUA65dHE=_MG9S
IG<PIGQSJ21TIFH=83<b82mGJFAdJ21UN6=X86AUIPdP<c8P;dQUJFMXM21UN6=X
86AUIPd_A65dHE=_MG9SIB1kHgEbLVE^M6IYK6DPLg@`879UHFAXIGQcM79YKVLP
L6m`OB1TIFH=IFiT3BDU@VEWJFiTA65dHCXP<30`<30`<30`<30`84QUN21<JFiU
L`dc<RhP<c8^82di>2hh<SHb82da=bhh=c4c86U]3@00X@30220`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI63DI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI63DI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`
<30`ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI63DI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
APe6ATI60:40`00<3@dU9DE^I4AQM64=0:40`00KIFT=LWA]3G9ULgA_LVD=LWA]
879ULgA_LVD=002Q0<000fMb3@00X@3001EbM6dPLVEcM6mbI@ecHGIU87=dK@d0
0:40`003Ig<=002Q0<01/G=QMVDPLgA]3G=QMVD=;fQSM21VHFacIB1TIFH=LgA]
3C4^<30`<20`;S0`<30P<2h`<30`834^<30`<20g<S8b;S4h=CDP=3@d=2hd<S4i
86=c3C4b=3T^>CTc=b0a<S@i;STi<cLPLf=/3BDP@g9_L59UHg@j830P<20c<R0c
<Pda834P<20`830P<20a834PHVT=83<b82mcM30PIGQSJ21cM79YKVLPI6EV3EmY
KF5WIFAYHg@PHVEWJFh=;dAUHfmTIB1K<20aGB1TIFH=;d=_K6mbDg1QHfDP;dAU
MVUSIDMbHGTPI6EV3DHP82m=MFadJG1/IDAQM65CKgEbHfEc86EhHfPPI6EV3B0c
<R0_EfUTM6PPIGQSJ21TIFH=838g82m8IFUWJ7@PIGQSJ21TIFH=;dAQM65CKgEb
HfDPNf=eLW9UKWAVJFaU87=d<21bIF5TJ6EhLgAbJFiW871_L7dPI6EV3FE^I0dU
9D9UIfU^I4AQM64j830`<30`<30`<30`<218IGPPC6U^IG<=<c8^838g;R0]>CP^
>38f<R0]<CL^>3La<b1YK@d00:40`0KK<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`3C0`<316
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI63DI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI63DI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`<30`ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI63DI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30=<30`<4I6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6APe6ATI6
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`3C0`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH=ATI6AS0`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<0d`
<30`002Q0<0030d=9BE5KVA4HGAQ3@2Q0<006fEY3G9dK@ebIG=dKg9U3G9dKB1b
IG=dKg9U3@00X@3000=WLPd00:40`00?LWA]879ULgA_LVD=J6D=002Q0<000fMb
3@00X@3000AbM6d=0:40`004LgA]3@2Q0<000fMc3@00X@30081XL`db<3P^<c<b
<b0c=S0^<S@a<R1]M0db<SD^=STc<b0c=S0^<S@a<R1/J@db<SD^=STc<b0d<S4d
;S<h>3<PK6T=<S0h;S<c<S<P=38a=2hc>3Pc86aY3C8`>2hc<c8c83<f<2hb=34b
86aY3F=`3B0a86QS3G=QMVDPLgA]3@2Q0<000fMc3@00X@300K1cHGIU87=dK@ec
HGIU3BmXHg@PIV5/LfDPI6EV3G=dK@da;S0`<30P<2h`<30`830^<30`<20a;S0`
<30P<CHf=Rhf=CPb83De=Bhe=C8g86=c3C4b=3T^>CTc=b0a<S@i;STi<cLPLf=/
3BDP@g9_L59UHg@j830P<20c<R0c<Pda834P<20`830P<20a834PHVT=83<`82mc
M30PIGQSJ21cM79YKVLPI6EV3EmYKF5WIFAYHg@PHVEWJFh=;dAUHfmTIB1K<20a
GB1TIFH=;d=_K6mbDg1QHfDP;dAUMVUSIDMbHGTPI6EV3DHP82m=MFadJG1/IDAQ
M65CKgEbHfEc86EhHfPPI6EV3B0c<20_EfUTM6PPIGQSJ21TIFH=83<b82m8IFUW
J7@PIGQSJ21TIFH=;dAQM65CKgEbHfDPNf=eLW9UKWAVJFaU87=d<21bIF5TJ6Eh
LgAbJFiW871_L7dPI6EV3FE^I0dU9D9UIfU^I4AQM64j830`<30`<30`<30`<218
IGPPC6U^IG<=<c0^83<b;R0]>CH^>38f<R0]<CL^>3La<b1YK@d0X@301h0`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH0X@30
00`=3BDUAFiTA65dH@d0X@3001]UJ@ebM6d=LVEcM6mbI@ebM6dPLVEcM6mbI@d0
0:40`003Ig8=002Q0<005G9dKB1bIG=dKg9U3G=QMVDPLgA]3@00X@3000=WL`d0
0:40`06aLf5fIB1cM6d=Lf5fI@d_J6=d86IQK7=U86AUIPecM6d=<Bh`<30`830^
<30`<20`;S0`<30P<Bh`<30`834f=SH^=SDh<R0a<C4a;S4`=CDPHg<=<C8d>Bhi
>C<g834b=3T^>CTc=b1cHf`=9B13LVm`DVESM3XP<20`83<b83<b3C4P<B0`830P
<20`834P<B1RJ@dP<c0P;g=d<21UN6=X87=dLVU^Ib1TIFH=GfU]HFMUI6USM21R
IFMYKPd_A6ESKfAU85/`835M86AUIPd_@fm/Kg9CL65SIB0_A6EfJF=UAg9QNB1T
IFH=AR0P;deeK7AYL6aUA65dHE=_MG9SIG<PIGQSJ21TIFH=83<`82mGJFAdJ21U
N6=X86AUIPdP<c8P;dQUJFMXM21UN6=X86AUIPd_A65dHE=_MG9SIB1kHgEbLVE^
M6IYK6DPLg@`879UHFAXIGQcM79YKVLPL6m`OB1TIFH=IFiT3BDU@VEWJFiTA65d
HCXP<30`<30`<30`<30`84QUN21<JFiUL`dc<2hP<c8^82di=Rhh<SHb82da=bhh
=c4c86U]3@00X@301h0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATH0X@3000`=3BDUAFiTA65dH@d0X@3001]UJ@ebM6d=LVEc
M6mbI@ebM6dPLVEcM6mbI@d00:40`003Ig8=002Q0<005G9dKB1bIG=dKg9U3G=Q
MVDPLgA]3@00X@3000=WL`d00:40`06aLf5fIB1cM6d=Lf5fI@d_J6=d86IQK7=U
86AUIPecM6d=<Bh`<30`830^<30`<20`;S0`<30P<Bh`<30`834f=SH^=SDh<R0a
=SHf;SHe>38PHg<=<C8d>Bhi>C<g834b=3T^>CTc=b1cHf`=9B13LVm`DVESM3XP
<20`83<b83<b3C4P<B0`830P<20`834P<B1RJ@dP<c0P;g=d<21UN6=X87=dLVU^
Ib1TIFH=GfU]HFMUI6USM21RIFMYKPd_A6ESKfAU85/`835M86AUIPd_@fm/Kg9C
L65SIB0_A6EfJF=UAg9QNB1TIFH=AR0P;deeK7AYL6aUA65dHE=_MG9SIG<PIGQS
J21TIFH=83<`82mGJFAdJ21UN6=X86AUIPdP<c8P;dQUJFMXM21UN6=X86AUIPd_
A65dHE=_MG9SIB1kHgEbLVE^M6IYK6DPLg@`879UHFAXIGQcM79YKVLPL6m`OB1T
IFH=IFiT3BDU@VEWJFiTA65dHCXP<30`<30`<30`<30`84QUN21<JFiUL`dc<2hP
<c8^82di=Rhh<SHb82da=bhh=c4c86U]3@00X@301h0`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH0X@3000`=3BDUAFiTA65d
H@d0X@3001]UJ@ebM6d=LVEcM6mbI@ebM6dPLVEcM6mbI@d00:40`003Ig8=002Q
0<005G9dKB1bIG=dKg9U3G=QMVDPLgA]3@00X@3000=WL`d00:40`06aLf5fIB1c
M6d=Lf5fI@d_J6=d86IQK7=U86AUIPecM6d=<Bh`<30`830^<30`<20`;S0`<30P
<Bh`<30`834f=SH^=SDh<R0b<S8b;S8a<3TPHg<=<C8d>Bhi>C<g834b=3T^>CTc
=b1cHf`=9B13LVm`DVESM3XP<20`83<b83<b3C4P<B0`830P<20`834P<B1RJ@dP
<c0P;g=d<21UN6=X87=dLVU^Ib1TIFH=GfU]HFMUI6USM21RIFMYKPd_A6ESKfAU
85/`835M86AUIPd_@fm/Kg9CL65SIB0_A6EfJF=UAg9QNB1TIFH=AR0P;deeK7AY
L6aUA65dHE=_MG9SIG<PIGQSJ21TIFH=83<`82mGJFAdJ21UN6=X86AUIPdP<c8P
;dQUJFMXM21UN6=X86AUIPd_A65dHE=_MG9SIB1kHgEbLVE^M6IYK6DPLg@`879U
HFAXIGQcM79YKVLPL6m`OB1TIFH=IFiT3BDU@VEWJFiTA65dHCXP<30`<30`<30`
<30`84QUN21<JFiUL`dc<2hP<c8^82di=Rhh<SHb82da=bhh=c4c86U]3@00X@30
1h0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATH0X@3000`=3BDUAFiTA65dH@d0X@3001]UJ@ebM6d=LVEcM6mbI@ebM6dPLVEc
M6mbI@d00:40`003Ig8=002Q0<005G9dKB1bIG=dKg9U3G=QMVDPLgA]3@00X@30
00=WL`d00:40`06aLf5fIB1cM6d=Lf5fI@d_J6=d86IQK7=U86AUIPecM6d=<Bh`
<30`830^<30`<20`;S0`<30P<Bh`<30`834f=SH^=SDh<R0b=cLg;SLf<cLPHg<=
<C8d>Bhi>C<g834b=3T^>CTc=b1cHf`=9B13LVm`DVESM3XP<20`83<b83<b3C4P
<B0`830P<20`834P<B1RJ@dP<c0P;g=d<21UN6=X87=dLVU^Ib1TIFH=GfU]HFMU
I6USM21RIFMYKPd_A6ESKfAU85/`835M86AUIPd_@fm/Kg9CL65SIB0_A6EfJF=U
Ag9QNB1TIFH=AR0P;deeK7AYL6aUA65dHE=_MG9SIG<PIGQSJ21TIFH=83<`82mG
JFAdJ21UN6=X86AUIPdP<c8P;dQUJFMXM21UN6=X86AUIPd_A65dHE=_MG9SIB1k
HgEbLVE^M6IYK6DPLg@`879UHFAXIGQcM79YKVLPL6m`OB1TIFH=IFiT3BDU@VEW
JFiTA65dHCXP<30`<30`<30`<30`84QUN21<JFiUL`dc<2hP<c8^82di=Rhh<SHb
82da=bhh=c4c86U]3@00X@301h0`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATH0X@3000`=3BDUAFiTA65dH@d0X@3001]UJ@eb
M6d=LVEcM6mbI@ebM6dPLVEcM6mbI@d00:40`003Ig8=002Q0<005G9dKB1bIG=d
Kg9U3G=QMVDPLgA]3@00X@3000=WL`d00:40`06aLf5fIB1cM6d=Lf5fI@d_J6=d
86IQK7=U86AUIPecM6d=<Bh`<30`830^<30`<20`;S0`<30P<Bh`<30`834f=SH^
=SDh<R0c<c<c;S<a=S@PHg<=<C8d>Bhi>C<g834b=3T^>CTc=b1cHf`=9B13LVm`
DVESM3XP<20`83<b83<b3C4P<B0`830P<20`834P<B1RJ@dP<c0P;g=d<21UN6=X
87=dLVU^Ib1TIFH=GfU]HFMUI6USM21RIFMYKPd_A6ESKfAU85/`835M86AUIPd_
@fm/Kg9CL65SIB0_A6EfJF=UAg9QNB1TIFH=AR0P;deeK7AYL6aUA65dHE=_MG9S
IG<PIGQSJ21TIFH=83<`82mGJFAdJ21UN6=X86AUIPdP<c8P;dQUJFMXM21UN6=X
86AUIPd_A65dHE=_MG9SIB1kHgEbLVE^M6IYK6DPLg@`879UHFAXIGQcM79YKVLP
L6m`OB1TIFH=IFiT3BDU@VEWJFiTA65dHCXP<30`<30`<30`<30`84QUN21<JFiU
L`dc<2hP<c8^82di=Rhh<SHb82da=bhh=c4c86U]3@00X@301h0`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH0X@3000`=3BDU
AFiTA65dH@d0X@3001]UJ@ebM6d=LVEcM6mbI@ebM6dPLVEcM6mbI@d00:40`003
Ig8=002Q0<005G9dKB1bIG=dKg9U3G=QMVDPLgA]3@00X@3000=WL`d00:40`06a
Lf5fIB1cM6d=Lf5fI@d_J6=d86IQK7=U86AUIPecM6d=<Bh`<30`830^<30`<20`
;S0`<30P<Bh`<30`834f=SH^=SDh<R0c>3Ph;SPf>C4PHg<=<C8d>Bhi>C<g834b
=3T^>CTc=b1cHf`=9B13LVm`DVESM3XP<20`83<b83<b3C4P<B0`830P<20`834P
<B1RJ@dP<c0P;g=d<21UN6=X87=dLVU^Ib1TIFH=GfU]HFMUI6USM21RIFMYKPd_
A6ESKfAU85/`835M86AUIPd_@fm/Kg9CL65SIB0_A6EfJF=UAg9QNB1TIFH=AR0P
;deeK7AYL6aUA65dHE=_MG9SIG<PIGQSJ21TIFH=83<`82mGJFAdJ21UN6=X86AU
IPdP<c8P;dQUJFMXM21UN6=X86AUIPd_A65dHE=_MG9SIB1kHgEbLVE^M6IYK6DP
Lg@`879UHFAXIGQcM79YKVLPL6m`OB1TIFH=IFiT3BDU@VEWJFiTA65dHCXP<30`
<30`<30`<30`84QUN21<JFiUL`dc<2hP<c8^82di=Rhh<SHb82da=bhh=c4c86U]
3@00X@301h0`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATH0X@3000`=3BDUAFiTA65dH@d0X@3001]UJ@ebM6d=LVEcM6mbI@eb
M6dPLVEcM6mbI@d00:40`003Ig8=002Q0<005G9dKB1bIG=dKg9U3G=QMVDPLgA]
3@00X@3000=WL`d00:40`06aLf5fIB1cM6d=Lf5fI@d_J6=d86IQK7=U86AUIPec
M6d=<Bh`<30`830^<30`<20`;S0`<30P<Bh`<30`834f=SH^=SDh<R0d=3@d;S@b
<CTPHg<=<C8d>Bhi>C<g834b=3T^>CTc=b1cHf`=9B13LVm`DVESM3XP<20`83<b
83<b3C4P<B0`830P<20`834P<B1RJ@dP<c0P;g=d<21UN6=X87=dLVU^Ib1TIFH=
GfU]HFMUI6USM21RIFMYKPd_A6ESKfAU85/`835M86AUIPd_@fm/Kg9CL65SIB0_
A6EfJF=UAg9QNB1TIFH=AR0P;deeK7AYL6aUA65dHE=_MG9SIG<PIGQSJ21TIFH=
83<`82mGJFAdJ21UN6=X86AUIPdP<SLP;dQUJFMXM21UN6=X86AUIPd_A65dHE=_
MG9SIB1kHgEbLVE^M6IYK6DPLg@`879UHFAXIGQcM79YKVLPL6m`OB1TIFH=IFiT
3BDU@VEWJFiTA65dHCXP<30`<30`<30`<30`84QUN21<JFiUL`dc<2hP<SL^82di
=Rhh<SHb82da=bhh=c4c86U]3@00X@301U@`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<316ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATH`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<316ATI6ATI6ATI6
ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6ATI6
ATH`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`
<30`<30`<30`<30`<300X@3000`=3BDUAFiTA65dH@d0X@3001]UJ@ebM6d=LVEc
M6mbI@ebM6dPLVEcM6mbI@d00:40`003Ig8=002Q0<003g9dKB1bIG=dKg9U3FQU
3@00X@3000=WLPd00:40`004LWA]3@2Q0<00IG=dK@d`830P<21V<`da=bhc=S4`
834g;S<f<C0PLg0==C0^<21/K@dP<21/JPe^L0dd=3L`;S@f<c@P<cH`;S8d<C8P
KG@==3@g<2hd=S<d83<c<C4^=S4e<B1/J@eTL`ebM6d=002Q0<00>g=dK@d`830P
<21V<`e^L0df>C@d;S@`>C8P<cDa;SDf<3LPKG@=<20c=C4^=CH`=b1/J@eTL`eb
M6d=002Q0<00>g=dK@d`830P<21V<`e^L0df>C@d;S@`>C8P<C<d<Bha<cTPKG@=
<20a<c@a;S4c>B1/J@eTL`ebM6d=002Q0<00?G=dK@d`830P<21V<`e^L0df>C@d
;S@`>C8P<S<c<2hg<CLc86ed3C0P<S<c<2hg<CLc86aY3FAc3G9dK@d00:40`00m
LgA]3C0P<20`86Hc3Fi`3CHi=3@^=30i<R0c<c0b;STc=3HPKG@=<20c<c0b;STc
=3HPK6T=I7<=LWA]3@00X@3007mcM6d=<BhP<BhP<BhPIS<=KW0=<C4h<2he=3Tf
834b<c8^=S<b=R0a>38b;ST`=c@P<C@d<2hi=S@i879`3FAU3C0P<20`86Hc3Fi`
3C4a>30^=C@i=R0a<S<b;SHc<SHP<CPb<Rhi<3Ld834d=30^>CHd>B1bL0eTL`eb
M6d=002Q0<00Og=dK@da;R0a;R0a;R1V<`e^L0da<CP`;SDd>CHP<S8c<2hh>C4d
834h<S8^>C0g=20b=38a;SPf<SLPLW0=I6D=<20`830PIS<=KW0=<C4h<2he=3Tf
838b<c0^>3Ta=20a>38b;ST`=c@P<S@b<Bhh=S8g879`3FAc3G9dK@d00:40`02=
LgA]3C4^834^834^86Hc3Fi`3C@e=c@^=S8i=B0e<c<^>3Da=B1]M0dd<cHf;S8i
=c<P=C<c;SPe<CDPK6T==3<f=Rhb>CLc834a=cH^<S0i<b1/J@dd=CLd;SHb>CDP
<C4g=Rhb<3Tc86aY3C@e=c@^=S8i=B0e<c<^>3Da=B1/J@eSL0eTI@ebM6d=002Q
0<00@G=dK@d`830P<21V<`e^L0dd=CLd;SHb>CDP=C@b;SDc<R1]M0dd<cHf;S8i
=c<P=C@b;SDc<R1/J@eTL`ebM6d=002Q0<00A7=dK@d`830P<21V<`e^L0dd<cL`
;SHc=cDP=C<c;SPe<CDPKG@==3<g<2hf<cLe834a=cH^<S0i<b1/J@eTL`ebM6d=
0:40`013LgA]3C0P<20`86Hc3Fi`3C@c=SH^<STg<b0a<CLa;SPf>B1]M0dd=CLd
;SHb>CDP<C4g<Bhh=STPK6T=I7<=LWA]3@00X@3004AcM6d=<20`830PIS<=KW0=
=3Dg<2hb>3Tc834a=cH^<S0i<b1]M0dd=CL`;S8h>C<P=C<c;SPe<CDPK6T=I7<=
LWA]3@2Q0<00SG=dK@da;R0a;R0a;R1V<`e^L0dd=CHe;STd>B0a=C@`;SLi<3PP
KG@==3<e=bhf<CHh834e=30^=cT`>21/J@dd<cDg;SHa=SPP<S4f=Bhg>3Lf86aY
3C@e=SD^>C@i838a=SD^=cPg=R1/J@dd=CHe;STd>B0a=C@`;SLi<3PPK6T=Hg0=
I6D=LWA]3@00X@3004AcM6d=<20`830PIS<=KW0==3Df=Bhi=3TP<CDd>Bhd=c4c
86ed3C@c=CL^=S4f>20a=C@i;S@g<C<PK6T=I7<=LWA]3@2Q0<00AG=dK@d`830P
<21V<`e^L0dd<cHd;S4b=c4P<CDd<2hg>C0h86ed3C@c=S@^<C8g<B0b<CHe;SLh
=cHPK6T=I7<=LWA]3@00X@3004AcM6d=<20`830PIS<=KW0==3<e=bhf<CHh838a
=CL^<C0g<B1]M0dd=CHe;STd>B0b<CDg;S4`=c4PK6T=I7<=LWA]3@2Q0<00AG=d
K@d`830P<21V<`e^L0dd=CDi;S@c>3LP<S4f=Bhg>3Lf86ed3C@e=CT^=3<h=b0a
=C@`;SLi<3PPK6T=I7<=LWA]3@00X@3008YcM6d=<BhP<BhP<BhPIS<=KW0==3Dd
>2he>3PP<S@g>2hb>3HPKG@==3<e=bhf<CHh838d=cP^<SPf86aY3C@c=CL^=S4f
>20c<C8`;SHd<cTPK6T==3Dd>2he>3PP<c4b<2hf=3<i86aY3C@e=3P^=CPh838d
=cP^<SPf86aY3F=`3FAU3G9dK@d0X@3004AcM6d=<20`830PIS<=KW0==3Dd>2he
>3PP<S@h=Rhi=SHe86ed3C@c=CL^=S4f>20b=3Pf;STf=SDPK6T=I7<=LWA]3@2Q
0<00A7=dK@d`830P<21V<`e^L0dd<cHf;S8i=c<P<S@g>2hb>3HPKG@==3<f=Rhb
>CLc83<a<S0^=S@c>B1/J@eTL`ebM6d=0:40`014LgA]3C0P<20`86Hc3Fi`3C@c
=CL^=S4f>20c<C4a;STf<c@PKG@==3Dd>2he>3PP<c4a<Bhi=S<d86aY3FAc3G9d
K@d0X@3004AcM6d=<20`830PIS<=KW0==3Dc>Bhi<3Le83<a<S0^=S@c>B1]M0dd
=C<i;ST`=cDP<S@g>2hb>3HPK6T=I7<=LWA]3@2Q0<00O7=dK@d`830P<21V<`e^
L0db<CDb;SLf=SPP<C8d<Bhc<C<a838g>CD^<C8d=b0a=3<b;S8h=3@PLW0=I6D=
<20`830PIS<=KW0=<S4e<Rhg=SHh834b=34^<c4c<B0b=cTe;S4b=3LP<C@c<Rhb
>3@d879`3FAc3G9dK@d0X@3007acM6d=<20`830PIS<=KW0=<S4e<Rhg=SHh838b
<S@^<cPa<B0b=cTe;S4b=3LP<S@c<Rhg<C<c879`3FAU3C0P<20`86Hc3Fi`3C8a
=C8^=cHf>20b<S8d;S<h<C4P<SLi=Bha<S@g838d<c8^=c4c<b1bL0eTL`ebM6d=
0:40`01FLgA]3C0P<20`86Hc3CDb;S0h<c4P=C8^<3Pc<B1cL0e^L0dc=STg;SPi
=cTP=cHh;S8b=C<PKG@=<c4i=2hd<SPb83Lf>2hb<SDc86aY3FAc3G9dK@d0X@30
04=cM6d=<20`830PIS<=KW0=<cHi=bhh>CLi83Pe=Bh`<c0d86ed3C<a>C@^=38h
<R0h=CD^<3<`=21/J@eTL`ebM6d=002Q0<00AG=dK@d`830P<21V<`e^L0dc=STg
;SPi=cTP<CLg=Bha=S@f86ed3C<a>C@^=38h<R0a=cLe;S4f=3HPK6T=I7<=LWA]
3@00X@3004EcM6d=<20`830PIS<=KW0=<cHi=bhh>CLi834h=S4^>CHi=b1]M0dc
<CTd;S@b>38P<CPf<Bhi=STg86aY3FAc3G9dK@d00:40`015LgA]3C0P<20`86Hc
3Fi`3C<f>CL^>3Tg>B0b=c@g;S<h<CTPKG@=<c4i=2hd<SPb838g=3L^<cPa>B1/
J@eTL`ebM6d=002Q0<00@g=dK@d`830P<21V<`e^L0dc=STg;SPi=cTP<SPc=2ha
>3LPKG@=<c4i=2hd<SPb838h<c@^<CPg86aY3FAc3G9dK@d00:40`01ELgA]3C0P
<20`86Hc3C4g;S<f<C0P<CL^<cHa<21cL0e^L0dc=3@f;S4f<c4P<cDe;ST`<B1]
M0dc=3@f;S4f<c4P=cPi;STb=SDPK6T=I7<=LWA]3@00X@3004AcM6d=<20`830P
IS<=KW0=<c@d=Rha=S<a83Ph<Bh`=c4i86ed3C<d=3H^<CHc<B0a<c4e;S0i=cDP
K6T=I7<=LWA]3@2Q0<00@W=dK@d`830P<21V<`e^L0dc=3@f;S4f<c4P<C<e>2he
86ed3C<d=3H^<CHc<B0a=cTb;SDb=CHPK6T=I7<=LWA]3@2Q0<00AG=dK@d`830P
<21V<`e^L0dc=3@f;S4f<c4P<CPh=Bhh=34a86ed3C<d=3H^<CHc<B0b<c4i;SPf
=SLPK6T=I7<=LWA]3@00X@3004EcM6d=<20`830PIS<=KW0=<c@d=Rha=S<a838c
<cD^<3Dg=R1]M0dc=3@f;S4f<c4P<SLf>Bh`>3<b86aY3FAc3G9dK@d00:40`014
LgA]3C0P<20`86Hc3Fi`3C<d=3H^<CHc<B0b>3Da;SDd>21]M0dc=3@f;S4f<c4P
<c8h=Bhe=c<f86aY3FAc3G9dK@d0X@3005AcM6d=<20`830PIS<==C8^<3Pc<B0e
<Rh`>3<a87=`3Fi`3C<e=cH^<cL`=b0b=Rh`=34e86ed3C<c<CD^>CDe=20b=Rh`
=34e86aY3FAc3G9dK@d0X@3005EcM6d=<20`830PIS<=<CL^<cHa<20a=bhc=S4`
87=`3Fi`3C<d=3H^<CHc<B0d=bhg=38h86ed3C<d=3H^<CHc<B0c=S0^<S@a<R1/
J@eTL`ebM6d=002Q0<00EW=dK@d`830P<21V<`de<Rh`>3<a83Db;S0h<c4PLg0=
KW0=<cDf<bhc=B0c=CLh;SDd<3TPKG@=<c<`<Rhi<c@f83<e=cP^=C@`>B1/J@eT
L`ebM6d=0:40`01HLgA]3C0P<20`86Hc3C4g;S<f<C0P<CL^<cHa<21cL0e^L0dc
=3@c;STi<STP<c8h=bhg=3<g86ed3C<d=3<^>CTb>B0c=S0`;S8d<S4PK6T=I7<=
LWA]3@2Q0<00KW=dK@d`830P<21V<`e^L0de<3<^=3Hi=b0c=S0^<S@a<R1]M0de
=c8^>C4c>20e=C4^<S4b=B1/J@dd<c@^<38e=R0e=C4^<S4b=B1/J@de<3<^=3Hi
=b0c=S0^<S@a<R1/J@eSL0eTI@ebM6d=0:40`012LgA]3C0P<20`86Hc3Fi`3CD`
=bhh<3Ti83<i=2hi=S<c86ed3CD`=bhh<3Ti834c<c8^=3Dh=B1/J@eTL`ebM6d=
0:40`01aLgA]3C0P<20`86Hc3Fi`3C@i<2hd=3Pi83<c<38^>C<d=R1]M0dd<S4^
<30d>20c<C4a;STf<c@PK6T==CDi;SPi<b0c<C4a;STf<c@PK6T==3T`;S@d>3TP
<c<`<Rhi<c@f86aY3F=`3FAU3G9dK@d00:40`011LgA]3C0P<20`86Hc3Fi`3C@i
<Rhf<CTP<S<b<Rh`<cHh86ed3C@i<Rhf<CTP<c8e>Bhe<c8a86aY3FAc3G9dK@d0
0:40`01^LgA]3C0P<20`86Hc3Fi`3CTc=bhd>CDb834c=34^<C<i86ed3CLd=Rhe
<S@P<C@a<2he>3<a86aY3CLd=Rhe<S@P<C8g<Bhf>C@i86aY3CTc=bhd>CDb834c
=34^<C<i86aY3F=`3FAU3G9dK@d0X@30045cM6d=<20`830PIS<=KW0=>3Pe;S@a
<S8P<C<d<Bha<cTPKG@=<cHd;SDh<CDP<C<d<Bha<cTPK6T=I7<=LWA]3@00X@30
06mcM6d=<20`830PIS<=KW0=>CDd;SPe=S<P<S<b=Rhc=cLa86ed3CLf<bhh>3DP
<S<i=Bhh<S4b86aY3CLf<bhh>3DP<S8e=Rhi<c<PK6T=>CDd;SPe=S<P<S<b=Rhc
=cLa86aY3F=`3FAU3G9dK@d00:40`013LgA]3C0P<20`86Hc3Fi`3CT`<Rhg=c<b
838c<c0^=c4g<b1]M0dc>34^>C@b=B0b<c<`;SLa=c<PK6T=I7<=LWA]3@00X@30
02McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`01E
LgA]3C8d<bh`=C@c86IdL`d_GemOAThc86=fLfH=<20`830PIS<=AR1cH@da=3P^
=CHh=b0d=C@`;S@b=CLPKG@=:7PY821cJ6mg3E@PLf4=LWA]3@00X@3000AbM6d=
0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q
0<01e7=dK@d`830P<21V<`e687=Q3CDe=S@^<S0g>B0d=C@`;S@b=CLPKG@=:7P[
:B1K<C8a;SDc830PGB1hLfQ_M`eD87=Q3G9dK@eWL`ecM6d=KW0==S0`=2hc=cTf
83@e=30^=38e=b1]M0de>3De;SDe=S<P=3Dd<2hd<SDg86aY3CDh=CD^=CDf<b0d
=C@`;S@b=CLPK6T==CTa=Rhf=cDi83@c=SH^<3Pf=21/J@de>C4f;SHg=CTP=3<f
=Rh`>3Hd86aY3CDi=38^<CTa>20d<cHf;S0h=S@PK6T==CTd<Rha>C4h83@c=SH^
<3Pf=21/J@df<30d;S<g>CHP=3Dd<2hd<SDg86aY3F=`3CDi=c@^>38h=B0d=C8a
;S0h<B1]M0de>C8i;S0a>3DP=3<h>2hh=c8g86aY3CDi<ST^<34h=B0d<cPh;SPg
<SLPK6T==CPh=Bha<3Lc83@e<S4^<3Pa86aY3CDh>3D^<C0g<b0d=C8a;S0h<B1/
J@de>CLd;SPb>3DP=3Db<Bh`>34PK6T=Hg0=I6D=LWA]3FMb3G=dK@e687=Q3CDi
=cL^<SPg=20d=C@`;S@b=CLPKG@=:7PY821cJ6mg3E@PLf4=LWA]3@2Q0<00179d
K@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d0
0:40`01?LgA]3C0P<20`86Hc3DHPLf4==CDe;SDe<SLP>3Lg;S8d>CPPKG@=:7DP
G2PY85/a<cD^<CPP=SL^=C<P<21M87QcJ6mg3E@PLf4=LWA]3@00X@3002<`830P
<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@3004icM6d=<20`830P
IS<=AR1cH@dh<cT^<CTe<R0h=cL^<S@i>21]M0dXN2ad:B1K<C8a;SDc83Hg;SDc
830PGB1hLfQ_M`eD87=Q3G9dK@d0X@3002<`830P<21V<`d`;S4b=C0P<2ha<SD`
87=`3C0P<20`86Hc3@00X@3003acM6d=<20`830PIS<=AR1cH@da<3Te;SLb<CHP
>3Lg;S8d>CPPKG@=:5`Y:B0PLfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=0:40`00W
LgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00E7=d
K@da=c<^=S4`<R1VM7<=;emOGdI><b1SMW=V3C0P<20`86Hc3DHPLf4==SLh;S0g
>CTP>C@e;S<`=CPPKG@=:34Y821cJ6mg3E@PLf4=LWA]3@2Q0<00179dK@d0X@30
02McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`01Z
LgA]3C8d<bh`=C@c86IdL`d_GemOAThc86=fLfH=<20`830PIS<=AR1cH@de<cP^
<CTa=b0b>3<i;S0d=C@PKG@=:7DPG2PY85/a<cD^<CPP=SL^=C<P<21M87QcJ6mg
3E@PLf4=LWA]3@2Q0<008c0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830P
IS<=002Q0<00Cg=dK@d`830P<21V<`e687=Q3CPb<Bhh<c@b838h<cT^<3@e=21]
M0dXN2ad:B1K<C8a;SDc83Hg;SDc830PGB1hLfQ_M`eD87=Q3G9dK@d00:40`00S
<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`00mLgA]3C0P
<20`86Hc3DHPLf4=<C0g>2hc=S0f838h<cT^<3@e=21]M0dXG2TY821cJ6mg3E@P
Lf4=LWA]3@00X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b
=C0PLg0=<20`830PIS<=002Q0<00EG=dK@da=c<^=S4`<R1VM7<=;emOGdI><b1S
MW=V3C0P<20`86Hc3DHPLf4==SDf;S<g>3HP<ST`=bha<34d86ed3BPb:B0PLfQ_
M`eD87=Q3G9dK@d00:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P
<2ha<SD`87=`3C0P<20`86Hc3@00X@3008McM6d=<S@c;S0e=3<PIWAc3BmOGem6
CS<PHgIcIPd`830P<21V<`e687=Q3C<a<Rhd>CPd834e>3T^<3Da>21]M0dXJB1L
:7P/M5`Y:B1K=C@^<30P=SL^=C<P>30^>C@P<C8a;SDc83Hg;SDc83Hg;SDc830P
GB1hLfQ_M`eD87=Q3G9dK@d00:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`
;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@3005EcM6d=<CLc;SHa<38PIWAc
3BmOGem6CS<PHgIcIPd`830P<21V<`e687=Q3C<f<Bhb=34b834f<cT^=c@f=b1]
M0dX<BTP87=XKgL=E21cH@ebM6d=002Q0<00179dK@d0X@3002McM6d=<20`830P
IS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`027LgA]3C8d<bh`=C@c
86IdL`d_GemOAThc86=fLfH=<20`830PIS<=AR1cH@dc<ST^>3Di=20b<CLi;S<b
=SDPKG@=:6TPG2Qh;7AL:BTPFcDd;S0`83Hg;SDc83P`;STd834b<Bhe<b0f=bhe
<b0f=bhe<b0`85dPN7=XKgL=E21cH@ebM6d=002Q0<00179dK@d0X@3002McM6d=
<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`01DLgA]3C4g
<bhf<C0b86IdL`d_GemOAThc86=fLfH=<20`830PIS<=AR1cH@dc=c@^<SHb838b
=C4^=c8b>21]M0dX<RTP87=XKgL=E21cH@ebM6d=0:40`004LWA]3@2Q0<009g=d
K@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@300OAcM6d=
<S@c;S0e=3<PIWAc3BmOGem6CS<PHgIcIPd`830P<21V<`e687=Q3C4b<CD^<SLa
=R0a<C<g;SHf=C8PKG@=:59L<c8d82TPFc4g=Bhe<b0e=2h`<20`85dPN7=XKgL=
E21cH@ebM6d=Ig<=LgA]3Fi`3C4f>3T^<38a>20a<C<g;SHf=C8PKG@=<CDd<2ha
>CPe834a<cL^=SHe<R1/J@da=C@`;S4i>3DP<C4c=bhf=SDb86aY3C4f<34^<c4h
<B0i=S<^<c8e>B1/J@da=S0a;S<a>34P>CHc;S<b=CTPK6T=<CHb=Rhh<c@P>CHc
;S<b=CTPK6T=<CHb=Rhh<c@P>CHc;S<b=CTPK6T=<CHh>Bh`<S4h834a<cL^=SHe
<R1/J@eSL0da=SDi;S@g<3LP<C4a>2hc<S0e86ed3C4f<C<^=SH`=b0i>3H^<C4b
<R1/J@da=S4c;SHf<3LP>CPf;S4a<S8PK6T=<CDf>Bhg=3Te834a<CP^<c8`=B1/
J@da=CHi;SLd>CDP<C4a>2hc<S0e86aY3C4f=CT^=3L`=b0a<C4h;S<b<3DPK6T=
Hg0=I6D=LWA]3FMb3G=dK@e687=Q3C4f=S4^>C8i>20a<C<g;SHf=C8PKG@=:7PY
821cJ6mg3E@PLf4=LWA]3@2Q0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha
<SD`830^<C8e<21cL0d`830P<21V<`d00:40`01FLgA]3C4g<bhf<C0b86IdL`d_
GemOAThc86=fLfH=<20`830PIS<=AR1cH@da=30g;S8d<STP<C8`=Bhg<S4a86ed
3BPa:B0PLfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc
3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q0<01nW=dK@db=3<^<3Dd<b1V
M7<=;emOGdI><b1SMW=V3C0P<20`86Hc3DHPLf4=<C8a=Bhb=c4f838f<c0^=c4c
<B1]M0dXDU`c<S@P:B1K<CLe;SDc83Dd;S0`830PGB1hLfQ_M`eD87=Q3G9dK@eW
L`ecM6d=KW0=<CHh>Bh`<S4h838f<c0^=c4c<B1]M0da=C@`;S4i>3DP<SHc<2hg
<C<a86aY3C4e=30^<CTh=B0b=S<`;SLa<c4PK6T=<CH`<Bhc<CPa838d=CH^<cLc
>B1/J@da=S0a;S<a>34P<S@e=Rhc=c<i86aY3C4f<SH^>3<d838d=CH^<cLc>B1/
J@da=S8f;SPc=20b=3Df;S<g<cTPK6T=<CHh>Bh`<S4h838f<c0^=c4c<B1/J@eS
L0da=SDi;S@g<3LP<SHa<Bhc=SPe86ed3C4f<C<^=SH`=b0b=3Li;S4f<38PK6T=
<CHa<bhf=S0g838d=cT^<CH`<R1/J@da=CHi;SLd>CDP<SHa<Bhc=SPe86aY3C4e
=ST^=c@i=B0b=S4a;S<f>3DPK6T=<CHe>Bhd=c0g838f<C4^<cHh=B1/J@eSL0eT
I@ebM6d=Ig8=LgA]3DHPLf4=<CHf<Bhi<STh838f<c0^=c4c<B1]M0dXN2TP87=X
KgL=E21cH@ebM6d=0:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P
<2ha<SD`87=`3C0P<20`86Hc3@00X@3005IcM6d=<CLc;SHa<38PIWAc3BmOGem6
CS<PHgIcIPd`830P<21V<`e687=Q3C4c>CH^<cTb<R0b=STh;SLf>C4PKG@=:38Y
821cJ6mg3E@PLf4=LWA]3@2Q0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha
<SD`830^<C8e<21cL0d`830P<21V<`d00:40`07fLgA]3C8d<bh`=C@c86IdL`d_
GemOAThc86=fLfH=<20`830PIS<=AR1cH@db<CL`;S4b=cTP<C4c=bhf=SDb86ed
3BQ<G3<b=20Y85/a<cD^<CPP=C@^<30P<21M87QcJ6mg3E@PLf4=LWA]3FMc3G=d
K@e^L0db=S0c;SDc=S8P<C4c=bhf=SDb86ed3C8d=C@^=c4b>B0a<C<g;SHf=C8P
K6T=<S@e=2hg<C8i834a<cL^=SHe<R1/J@db=C4e;SPc<SDP>CHc;S<b=CTPK6T=
<SDa=Bhh<c8e83Tf<bhc<SDi86aY3C8e=34^<c@h=B0i=S<^<c8e>B1/J@db=C@a
;S<d>3DP>CHc;S<b=CTPK6T=<SH`<bhe<cHb834a<cL^=SHe<R1/J@eSL0db=CLc
;STh=C8P<C4a>2hc<S0e86ed3C8e<SP^<CLe<B0i>3H^<C4b<R1/J@db=C8h;S4g
=C4P>CPf;S4a<S8PK6T=<S@h=2hb=S<i834a<CP^<c8`=B1/J@db=3Pd;S8f<cTP
<C4a>2hc<S0e86aY3C8e=c<^>CPe<R0a<C4h;S<b<3DPK6T=Hg0=I6D=LWA]3FMb
3G=dK@e687=Q3C8e=cH^=3@d<b0a<C<g;SHf=C8PKG@=:7PY821cJ6mg3E@PLf4=
LWA]3@2Q0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21c
L0d`830P<21V<`d00:40`01FLgA]3C4g<bhf<C0b86IdL`d_GemOAThc86=fLfH=
<20`830PIS<=AR1cH@db<c8g;S<g=c4P<C8`=Bhg<S4a86ed3BPa:B0PLfQ_M`eD
87=Q3G9dK@d0X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b
=C0PLg0=<20`830PIS<=002Q0<01o7=dK@db=3<^<3Dd<b1VM7<=;emOGdI><b1S
MW=V3C0P<20`86Hc3DHPLf4=<S4g<2ha<SLi838f<c0^=c4c<B1]M0dXC5`c<S@P
:B1K<C<e;S4h83Dd;S0`830PGB1hLfQ_M`eD87=Q3G9dK@eWL`ecM6d=KW0=<SH`
<bhe<cHb838f<c0^=c4c<B1]M0db=3Dd;SLa<STP<SHc<2hg<C<a86aY3C8d=C@^
=c4b>B0b=S<`;SLa<c4PK6T=<SDa=Bhh<c8e838d=CH^<cLc>B1/J@db=C4e;SPc
<SDP<S@e=Rhc=c<i86aY3C8e=34^<c@h=B0b=3Df;S<g<cTPK6T=<SDd<Bhc=3Pe
838d=CH^<cLc>B1/J@db=S0c;SDc=S8P<SHc<2hg<C<a86aY3F=`3C8e=c<^>CPe
<R0b=S4a;S<f>3DPKG@=<SDb>2ha=cDa838d=cT^<CH`<R1/J@db=C8h;S4g=C4P
<S@g>Bha=S0b86aY3C8d>3@^<SHc>B0b=S4a;S<f>3DPK6T=<S@h=2hb=S<i838f
<C4^<cHh=B1/J@db=CLc;STh=C8P<SHa<Bhc=SPe86aY3F=`3FAU3G9dK@eWLPec
M6d=AR1cH@db=CLf;S@d=3<P<SHc<2hg<C<a86ed3BQh:B0PLfQ_M`eD87=Q3G9d
K@d0X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=
<20`830PIS<=002Q0<00EW=dK@da=c<^=S4`<R1VM7<=;emOGdI><b1SMW=V3C0P
<20`86Hc3DHPLf4=<S<a>2hf>CHf838f>CP^=cHi<B1]M0dX<RTP87=XKgL=E21c
H@ebM6d=0:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`
87=`3C0P<20`86Hc3@00X@300OIcM6d=<S@c;S0e=3<PIWAc3BmOGem6CS<PHgIc
IPd`830P<21V<`e687=Q3C<e<S@^<SPg=b0a<C8`;S<`=34PKG@=:4=L<c8d82TP
Fc4g=Bhe<b0e=2h`<20`85dPN7=XKgL=E21cH@ebM6d=Ig<=LgA]3Fi`3C<i>CP^
<3<g>20a<C8`;S<`=34PKG@=<cPd>Bhb<C@e834a<S0^<c0d<B1/J@dc>3@i;S8a
=3DP<C4b<2hc<3@a86aY3C<i<C0^<c<d<B0i=3D^>CHd>B1/J@dc>C4`;S<c=34P
>C@e;STf=3TPK6T=<cTc=Bhh=C0a83Td=Bhi=S@i86aY3C<i<cD^>3D`<B0i=3D^
>CHd>B1/J@dc>CTh;S0c=cPP<C4b<2hc<3@a86aY3F=`3C<i=SP^=3Pf>20a<C0`
;STe>CDPKG@=<cTb<Rhf=cHg83Tf>2hg=C4b86aY3C<i<S8^=SLf=b0i=SP^=cDa
<R1/J@dc>3Lh;SLf=CDP<C4`<2hi=CTe86aY3C<h=cP^=cHe=B0a<C0`;STe>CDP
K6T=<cTf>2hd>3Hh834a<30^>CDi=B1/J@eSL0eTI@ebM6d=Ig8=LgA]3DHPLf4=
<cTg<2hi=3Di834a<S0^<c0d<B1]M0dXN2TP87=XKgL=E21cH@ebM6d=0:40`004
LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc
3@00X@3005IcM6d=<CLc;SHa<38PIWAc3BmOGem6CS<PHgIcIPd`830P<21V<`e6
87=Q3C<g<CH^<SDh>B0a<CPh;S<f<34PKG@=:34Y821cJ6mg3E@PLf4=LWA]3@2Q
0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P
<21V<`d00:40`080LgA]3C8d<bh`=C@c86IdL`d_GemOAThc86=fLfH=<20`830P
IS<=AR1cH@dc=C8d;S8h=cLP<S4`>Bhh>38d86ed3BQ3G3<b=20P:B1K<CLe;SDc
83Dd;S0`83Hg;SDc830PGB1hLfQ_M`eD87=Q3G9dK@eWL`ecM6d=KW0==30f=Bhe
=C4P<S4`>Bhh>38d86ed3C<i<CH^=c8g=b0b<C0i;SPh<S@PK6T=<cTa=Rhg<SLg
838a<3T^>3Pb=21/J@dc>CLg;SPd=c<P<CTc=Bhe=3<b86aY3C<i=cL^>3@g<b0a
>C<e;SDd<c8PK6T==30`<bhc=S<c834i<cD^=C@c<R1/J@dd<30c;S<f<c<P<CTc
=Bhe=3<b86aY3C@`=SD^=CDa838a<3T^>3Pb=21/J@eSL0dd<3<e;STi>CTP<S0i
<2he<cLh86ed3C<i>C0^<CPi>B0a>CDh;S<b>CDPK6T=<cTi<2ha>3Ti834i=CP^
<c8i=B1/J@dc>C@f;S8g>3LP<S0i<2he<cLh86aY3C<i=3H^<SLh=b0b<3T`;SDc
=cPPK6T==30c=Bhi>CTi838`>C0^=C<g>21/J@eSL0eTI@ebM6d=Ig8=LgA]3DHP
Lf4==30c>2hd=CTP<S4`>Bhh>38d86ed3BQh:B0PLfQ_M`eD87=Q3G9dK@d0X@30
00AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830P
IS<=002Q0<00HW=dK@da=CH^<S@i<R1VM7<=;emOGdI><b1SMW=V3C0P<20`86Hc
3DHPLf4=<cHi<bhe=CLf838a=S@^=CL`=R1]M0dX<C8Y85/h=Rhi<20`85dPN7=X
KgL=E21cH@ebM6d=0:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P
<2ha<SD`87=`3C0P<20`86Hc3@00X@300OacM6d=<S@c;S0e=3<PIWAc3BmOGem6
CS<PHgIcIPd`830P<21V<`e687=Q3C<e<S@^<SPg=b0c<3Pb;S0i>CLPKG@=:4=L
<c8d82TPFc4g=Bhe<b0e=2h`<20`85dPN7=XKgL=E21cH@ebM6d=Ig<=LgA]3Fi`
3C<i>CP^<3<g>20c<3Pb;S0i>CLPKG@=<cPd>Bhb<C@e83<`>38^<3Ti=b1/J@dc
>3@i;S8a=3DP<c0h<Rh`>CTg86aY3C<i<C0^<c<d<B0b>C0g;SLf<3DPK6T=<cTa
<2hc<c@a838i<3L^=cH`=B1/J@dc>C<e;SPe<34P<ST`=bhg=S0e86aY3C<i<cD^
>3D`<B0b>C0g;SLf<3DPK6T=<cTi>2h`<cLh83<`>38^<3Ti=b1/J@eSL0dc>CHh
;S@h=SPP<c0f<Rhg=CDa86ed3C<i<S8^=SLf=b0b>C<`;SDd=SPPK6T=<cTb<Rhf
=cHg838i<c0^=C@f>21/J@dc>3Lh;SLf=CDP<c0f<Rhg=CDa86aY3C<h=cP^=cHe
=B0c<3Hb;SLe=C4PK6T=<cTf>2hd>3Hh83<`=S8^=cDe<B1/J@eSL0eTI@ebM6d=
Ig8=LgA]3DHPLf4=<cTg<2hi=3Di83<`>38^<3Ti=b1]M0dXN2TP87=XKgL=E21c
H@ebM6d=0:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`
87=`3C0P<20`86Hc3@00X@3005IcM6d=<CLc;SHa<38PIWAc3BmOGem6CS<PHgIc
IPd`830P<21V<`e687=Q3C<g<3<^<S<h<B0c<CD`;S4e=CLPKG@=:38Y821cJ6mg
3E@PLf4=LWA]3@2Q0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^
<C8e<21cL0d`830P<21V<`d00:40`07XLgA]3C8d<bh`=C@c86IdL`d_GemOAThc
86=fLfH=<20`830PIS<=AR1cH@dd=S4h;S0c<S4P>3Td;SHa<3PPKG@=:4ML<c8d
82TPFc4h>Bh`=R0e=2h`<20`85dPN7=XKgL=E21cH@ebM6d=Ig<=LgA]3Fi`3CDa
<3D^<c0h=b0h>C@^=S4`>21]M0dd>CDf;S@h=C@P>3Td;SHa<3PPK6T==3Te=Rhd
>3Dd83Pi=2hf<C0h86aY3CD`<CL^=S0e83Lb<2hb=c4f86aY3CD`<CL^=S0e83Lb
<2hb=c4f86aY3CD`=3<^<C8a83Lb<2hb=c4f86aY3CD`=3<^<C8a83Lb<2hb=c4f
86aY3CDa<3D^<c0h=b0h>C@^=S4`>21/J@eSL0de<3Le;SLe=cLP>3Le;S8f=S8P
KG@==C0b>Bhi=3Lf83Ld<bh`=CLi86aY3CD`<ST^>C@g=R0g=3<^<3Dg>B1/J@dd
>CPf;S0c=SDP>3Le;S8f=S8PK6T==3Th=Rh`<cHe83Pg=Bhb=SHb86aY3CD`=cD^
=cDg=b0h=cD^<SHf<R1/J@eSL0eTI@ebM6d=Ig8=LgA]3DHPLf4==C0g>2hb<CHg
83Pi=2hf<C0h86ed3BQh:B0PLfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=0:40`00W
LgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00EG=d
K@da=c<^=S4`<R1VM7<=;emOGdI><b1SMW=V3C0P<20`86Hc3DHPLf4==3Pa<2h`
<3<d83Tf<Rhf=SHh86ed3BPa:B0PLfQ_M`eD87=Q3G9dK@d00:40`004LWA]3@2Q
0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@30
0P=cM6d=<S@c;S0e=3<PIWAc3BmOGem6CS<PHgIcIPd`830P<21V<`e687=Q3C@f
<CP^<3<b<B0a>3Pd;S4h>C4PKG@=:4ML<c8d820Y85/a>3T^<3HP=C@^<30P=SL^
=C<P<21M87QcJ6mg3E@PLf4=LWA]3FMc3G=dK@e^L0de<CLb;SPb<CTP<CPh=2ha
>3Tb86ed3CD`<S<^>CTh=R0a>3Pd;S4h>C8PK6T==C0b<bhi>CPf834h>3@^<CPi
<R1/J@de<3Pe;S4a>38P<CL`>Bhh=3Ti86aY3CD`>3D^<C4h<R0a=c0i;SPd>CTP
K6T==C4a<2hf<c@b834g<3T^>3@i>B1/J@de<C4`;SHc=38P<CL`>Bhh=3Ti86aY
3CDa=c8^>38a>B0a>3Pd;S4h>C8PK6T=Hg0==C4d<bhb=c0i834h=S@^>3@d=B1]
M0de<3Tg;S@f<3PP<CLc<Rhf<cHb86aY3CD`>CL^=3H`>20a=c<b;SHc=S8PK6T=
=C0e<bhe=3Tf834h=S@^>3@d=B1/J@de<3Dc;SDd>CHP<CPf=2hh=3@e86aY3CDa
=3<^<SL`>B0a>3Hd;SPd=3DPK6T=Hg0=I6D=LWA]3FMb3G=dK@e687=Q3CDa=3D^
=c8i>B0a>3Pd;S4h>C4PKG@=:7PY821cJ6mg3E@PLf4=LWA]3@00X@3000AbM6d=
0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q
0<00HW=dK@da=CH^<S@i<R1VM7<=;emOGdI><b1SMW=V3C0P<20`86Hc3DHPLf4=
=3P`=Rhh<c<b834i=3<^<S4g=R1]M0dX<C8Y85/h=Rhi<20`85dPN7=XKgL=E21c
H@ebM6d=0:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`
87=`3C0P<20`86Hc3@00X@300OQcM6d=<S@c;S0e=3<PIWAc3BmOGem6CS<PHgIc
IPd`830P<21V<`e687=Q3C@f<CP^<3<b<B0b>3Lc;SLf=cDPKG@=:4ML<c8d82TP
Fc4h>Bh`=R0e=2h`<20`85dPN7=XKgL=E21cH@ebM6d=Ig<=LgA]3Fi`3CDa<3D^
<c0h=b0b>3Lc;SLf=cDPKG@==3Te=Rhd>3Dd838h=c<^=cHg=B1/J@dd>CDf;S@h
=C@P<SPg<bhg=SLe86aY3CD`<CL^=S0e838f>CT^=38h<R1/J@de<34g;SH`=B0b
=STi;S@b>38PK6T==C0d<bha<S4P<SHi>Bhd<SPb86aY3CD`=3<^<C8a838f>CT^
=38h<R1/J@de<C0e;S<`>3LP<SPg<bhg=SLe86aY3F=`3CD`=cD^=cDg=b0b>3Dd
;S@b<SPPKG@==C0b>Bhi=3Lf838g<S8^<S4d=B1/J@de<38i;STd=cHP<SLb<Rhb
<C@e86aY3C@i>3H^<3<f=B0b>3Dd;S@b<SPPK6T==3Th=Rh`<cHe838h=C@^=38b
>21/J@de<3Le;SLe=cLP<SPe=2hd<S8h86aY3F=`3FAU3G9dK@eWLPecM6d=AR1c
H@de<3Lh;S8a=SLP<SPg<bhg=SLe86ed3BQh:B0PLfQ_M`eD87=Q3G9dK@d0X@30
00AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830P
IS<=002Q0<00EW=dK@da=c<^=S4`<R1VM7<=;emOGdI><b1SMW=V3C0P<20`86Hc
3DHPLf4==3Pa<2h`<3<d838i=34^>38c=21]M0dX<RTP87=XKgL=E21cH@ebM6d=
0:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P
<20`86Hc3@00X@300P=cM6d=<S@c;S0e=3<PIWAc3BmOGem6CS<PHgIcIPd`830P
<21V<`e687=Q3C8b<S8^<S4`>B0a>C0a;SDe<38PKG@=:4aL<c8d820Y85/a<cD^
<CPP=C@^<30P=SL^=C<P<21M87QcJ6mg3E@PLf4=LWA]3FMc3G=dK@e^L0db=c8c
;S4c<SDP<CT`<Bhe=C0b86ed3C8e=c@^<c0i<R0a>C0a;SDe<38PK6T=<SDg=2hc
<3Tb834i<34^=CD`<R1/J@db=S<e;S@b>3PP<CLb=bhb<C0i86aY3C8f<cD^=38h
>20a=c8g;S8a<3TPK6T=<SHf<2hi=3@g834g<SL^<S4`>B1/J@db=SH`;STd=3LP
<CLb=bhb<C0i86aY3C8g<S<^<C<b=B0a>C0a;SDe<38PK6T=Hg0=<SHi<bhe>34d
834h>38^<S0e=B1]M0db=S@g;SLg<C@P<CLd>Bhi>CLc86aY3C8f=3L^=cLa=20a
=c@i;STi=c<PK6T=<SH`<bhh=S0b834h>38^<S0e=B1/J@db=S0c;SPf<38P<CPh
<Rhb<3De86aY3C8f>C<^=CPa=20a>3Pb;S8`=CDPK6T=Hg0=I6D=LWA]3FMb3G=d
K@e687=Q3C8f>CH^<3@`=B0a>C0a;SDe<38PKG@=:7PY821cJ6mg3E@PLf4=LWA]
3@00X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=
<20`830PIS<=002Q0<00HW=dK@da=CH^<S@i<R1VM7<=;emOGdI><b1SMW=V3C0P
<20`86Hc3DHPLf4=<S<f<Bh`>CTa834i<cP^>3Lg<b1]M0dX<C8Y85/h=Rhi<20`
85dPN7=XKgL=E21cH@ebM6d=0:40`004LWA]3@2Q0<00Pg=dK@d`830P<21V<`e^
L0dd<bhd<38f83@c;S@`<SHP<c@d<Bhh<S8h83<e=Bhi<34PIG0=I6D=<20`830P
IS<=<CL^<cHa<20a=bhc=S4`87=`3Fi`3C@c;S@`<SHP=3<^=30b=R0c=3@a;SPb
<SPP<cDe;ST`<B1UL0eTL`ebM6d=002Q0<00LW=dK@d`830P<21V<`e^L0dd<bhd
<38f83@c;S@`<SHP=3@g<Rhf<c<e83<e<Bhe=S0g86E`3FAU3C0P<20`86Hc3Fi`
3C@c;S@`<SHP=3<^=30b=R0d=3Lb;SHc<cDP<cDa;SDf<3LPIG0=I7<=LWA]3@2Q
0<00M7=dK@d`830P<21V<`e^L0dd<bhd<38f83@c;S@`<SHP<c@d=Rha=S<a834c
=3D^=3Li<b1UL0eTI@d`830P<21V<`e^L0dd<bhd<38f83@c;S@`<SHP<c@d=Rha
=S<a834c=3D^=3Li<b1UL0eTL`ebM6d=0:40`01bLgA]3C0P<20`86Hc3Fi`3C@c
;S@`<SHP=3<^=30b=R0d=3L`;S@f<c@P<C<d<Bha<cTPIG0=I6D=<20`830PIS<=
KW0==3<^=30b=R0d<bhd<38f83@d=c0^=3Hc=20a<c@a;S4c>B1UL0eTL`ebM6d=
0:40`01dLgA]3C0P<20`86Hc3Fi`3C@c;S@`<SHP=3<^=30b=R0c=3@f;S4f<c4P
<S<c<2hg<CLc86E`3FAU3C0P<20`86Hc3Fi`3C@c;S@`<SHP=3<^=30b=R0c=3@f
;S4f<c4P<S<c<2hg<CLc86E`3FAc3G9dK@d0X@3007AcM6d=<20`830PIS<=KW0=
=3<^=30b=R0d<bhd<38f83@d=c8^=S<c=B0b<c<`;SLa=c<PIG0=I6D=<20`830P
IS<=KW0==3<^=30b=R0d<bhd<38f83@d=c8^=S<c=B0b<c<`;SLa=c<PIG0=I7<=
LWA]3@2Q0<00M7=dK@d`830P<21V<`e^L0dd<bhd<38f83@c;S@`<SHP<c@d<bhi
>C8i83<c<30^=cHd=B1UL0eTI@d`830P<21V<`e^L0dd<bhd<38f83@c;S@`<SHP
<c@d<bhi>C8i83<c<30^=cHd=B1UL0eTL`ebM6d=0:40`01dLgA]3C0P<20`86Hc
3Fi`3C@c;S@`<SHP=3<^=30b=R0d=3L`;S@f<c@P<c<`<Rhi<c@f86E`3FAU3C0P
<20`86Hc3Fi`3C@c;S@`<SHP=3<^=30b=R0d=3L`;S@f<c@P<c<`<Rhi<c@f86E`
3FAc3G9dK@d0X@300>1cM6d=<BhP<BhP<BhPIS<=KW0=<S4b=2he=CDb834e>C8^
>3Lc>B1]M0db<3Lb;S@g<S4P<CLd>Bha<S<a86aY3C8`=c8^=3Lb<B0a>C@`;S0i
=3<PK6T=<S4b=2he=CDb838`>CH^<c@c=B1/J@eTI@d`830P<21V<`e^L0db<C4f
;S<b<34P<CDi<2ha<SPh86ed3C8`=S<^=cTa=R0a=c@g;SLa=3@PK6T=<S0f<bhg
>C4f834i=34^=C0c86aY3C8a<CH^<c8`<B0b<3Ti;S0h>3DPK6T=I7<=LWA]3@2Q
0<00MG=dK@d`830P<21V<`e^L0db<CD`;SDi=SLP<C@i<2hh=cLh86ed3C8a=C0^
=CTf=b0a=SPa;SPd>C4PK6T=<S0a<Bhg<3Pe834f<ST^=cHf86aY3C8a=C0^=CTf
=b0a=3T`;SPg=cPPK6T=Hg0=I6D=LWA]3@00X@3007IcM6d=<20`830PIS<=KW0=
<S4d=Rhb=CHe838a>30^>CLh=B1]M0db<30g;S<f>3<P<S0d<Rh`>C0c86aY3C8a
=3H^<SDf=B0a>CT`;S0`=c<PK6T=<S4d=Rhb=CHe838a>30^>CLh=B1/J@eSL0eT
I@ebM6d=0:40`00:M6EbKFU^HGAU3@2P0;l0X02n09X0003oSj0000000nP3j000
00@0000004P000180000400P00<02000000000000NXQW0000003j0?X000000?Y
0n/0000`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo03R1oh7oPOn1oh7oPOoQol<0POn1oh7oPOn1oh7oPOoGol<0
POn1oh7oPOn1oh7oPOoGol<0POogo`0hPOn1oh7oPOn1oh7ohOo3087oPOn1oh7o
POn1oh7oeoo3087oPOn1oh7oPOn1oh7oeoo3087omol0>87oPOn1oh7oPOn1on7o
``21oh7oPOn1oh7oPOn1omOo``21oh7oPOn1oh7oPOn1omOo``21ooOo03R1oh7o
POn1oh7oPOoQol<0POn1oh7oPOn1oh7oPOoGol<0POn1oh7oPOn1oh7oPOoGol<0
POogo`0hPOn1oh7oPOn1oh7ohOo3087oPOn1oh7oPOn1oh7oeoo3087oPOn1oh7o
POn1oh7oeoo3087omol0>87oPOn1oh7oPOn1on7o``21oh7oPOn1oh7oPOn1omOo
``21oh7oPOn1oh7oPOn1omOo``21ooOo03R1oh7oPOn1oh7oPOoQol<0POn1oh7o
POn1oh7oPOoGol<0POn1oh7oPOn1oh7oPOoGol<0POogo`0hPOn1oh7oPOn1oh7o
hOo3087oPOn1oh7oPOn1oh7oeoo3087oPOn1oh7oPOn1oh7oeoo3087omol0>87o
POn1oh7oPOn1on7o``21oh7oPOn1oh7oPOn1omOo``21oh7oPOn1oh7oPOn1omOo
``21ooOo03R1oh7oPOn1oh7oPOoQol<0POn1oh7oPOn1oh7oPOoGol<0POn1oh7o
POn1oh7oPOoGol<0POogo`0hPOn1oh7oPOn1oh7ohOo3087oPOn1oh7oPOn1oh7o
eoo3087oPOn1oh7oPOn1oh7oeoo3087omol0>87oPOn1oh7oPOn1on7o``21oh7o
POn1oh7oPOn1omOo``21oh7oPOn1oh7oPOn1omOo``21ooOo03R1oh7oPOn1oh7o
POoQol<0POn1oh7oPOn1oh7oPOoGol<0POn1oh7oPOn1oh7oPOoGol<0POogo`0h
POn1oh7oPOn1oh7oa?om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7o
WOom087of_l0>87oPOn1oh7oPOn1olCoo@21oh7oPOn1oh7oPOn1oigoo@21oh7o
POn1oh7oPOn1oigoo@21om[o03R1oh7oPOn1oh7oPOo4ood0POn1oh7oPOn1oh7o
POnMood0POn1oh7oPOn1oh7oPOnMood0POoJo`0hPOn1oh7oPOn1oh7oa?om087o
POn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087of_l0>87oPOn1oh7o
POn1olCoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21om[o
03R1oh7oPOn1oh7oPOo4ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7o
POnMood0POoJo`0hPOn1oh7oPOn1oh7oa?om087oPOn1oh7oPOn1oh7oWOom087o
POn1oh7oPOn1oh7oWOom087of_l0>87oPOn1oh7oPOn1olCoo@21oh7oPOn1oh7o
POn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21om[o03R1oh7oPOn1oh7oPOo4ood0
POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POoJo`0hPOn1oh7o
POn1oh7oa?om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087o
f_l0>87oPOn1oh7oPOn1olCoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7o
POn1oigoo@21om[o03R1oh7oPOn1oh7oPOo4ood0POn1oh7oPOn1oh7oPOnMood0
POn1oh7oPOn1oh7oPOnMood0POoJo`0hPOn1oh7oPOn1oh7oa?om087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087of_l0>87oPOn1oh7oPOn1olCo
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21om[o03R1oh7o
POn1oh7oPOo4ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0
POoJo`0hPOn1oh7oPOn1oh7oa?om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7o
POn1oh7oWOom087of_l0>87oPOn1oh7oPOn1olCoo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1oigoo@21om[o03R1oh7oPOn1oh7oPOo4ood0POn1oh7o
POn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POoJo`0hPOn1oh7oPOn1oh7o
a?om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087of_l0>87o
POn1oh7oPOn1olCoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigo
o@21om[o03R1oh7oPOn1oh7oPOo4ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7o
POn1oh7oPOnMood0POoJo`0hPOn1oh7oPOn1oh7oa?om087oPOn1oh7oPOn1oh7o
WOom087oPOn1oh7oPOn1oh7oWOom087of_l0>87oPOn1oh7oPOn1olCoo@21oh7o
POn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21om[o03R1oh7oPOn1oh7o
POo4ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POoJo`0h
POn1oh7oPOn1oh7oa?om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7o
WOom087of_l0>87oPOn1oh7oPOn1olCoo@21oh7oPOn1oh7oPOn1oigoo@21oh7o
POn1oh7oPOn1oigoo@21om[o03R1oh7oPOn1oh7oPOo4ood0POn1oh7oPOn1oh7o
POnMood0POn1oh7oPOn1oh7oPOnMood0POoJo`0hPOn1oh7oPOn1oh7oa?om087o
POn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087of_l0>87oPOn1oh7o
POn1olCoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21om[o
03R1oh7oPOn1oh7oPOo4ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7o
POnMood0POoJo`0hPOn1oh7oPOn1oh7oa?om087oPOn1oh7oPOn1oh7oWOom087o
POn1oh7oPOn1oh7oWOom087of_l0>87oPOn1oh7oPOn1olCoo@21oh7oPOn1oh7o
POn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21om[o03R1oh7oPOn1oh7oPOo4ood0
POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POoJo`0hPOn1oh7o
POn1oh7oa?om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087o
f_l0>87oPOn1oh7oPOn1olCoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7o
POn1oigoo@21om[o03R1oh7oPOn1oh7oPOo4ood0POn1oh7oPOn1oh7oPOnMood0
POn1oh7oPOn1oh7oPOnMood0POoJo`0hPOn1oh7oPOn1oh7oa?om087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087of_l0>87oPOn1oh7oPOn1olCo
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21om[o03R1oh7o
POn1oh7oPOo4ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0
POoJo`0hPOn1oh7oPOn1oh7oa?om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7o
POn1oh7oWOom087of_l0>87oPOn1oh7oPOn1olCoo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1oigoo@21om[o03R1oh7oPOn1oh7oPOo4ood0POn1oh7o
POn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POoJo`0hPOn1oh7oPOn1oh7o
a?om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087of_l0>87o
POn1oh7oPOn1olCoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigo
o@21om[o03R1oh7oPOn1oh7oPOo4ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7o
POn1oh7oPOnMood0POoJo`0hPOn1oh7oPOn1oh7oa?om087oPOn1oh7oPOn1oh7o
WOom087oPOn1oh7oPOn1oh7oWOom087of_l0>87oPOn1oh7oPOn1olCoo@21oh7o
POn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21om[o03R1oh7oPOn1oh7o
POo4ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POoJo`0h
POn1oh7oPOn1oh7oa?om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7o
WOom087of_l0>87oPOn1oh7oPOn1olCoo@21oh7oPOn1oh7oPOn1oigoo@21oh7o
POn1oh7oPOn1oigoo@21om[o03R1oh7oPOn1oh7oPOo4ood0POn1oh7oPOn1oh7o
POnMood0POn1oh7oPOn1oh7oPOnMood0POoJo`0hPOn1oh7oPOn1oh7oa?om087o
POn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087of_l0>87oPOn1oh7o
POn1olCoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21om[o
03R1oh7oPOn1oh7oPOo4ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7o
POnMood0POoJo`0hPOn1oh7oPOn1oh7oa?om087oPOn1oh7oPOn1oh7oWOom087o
POn1oh7oPOn1oh7oWOom087of_l0>87oPOn1oh7oPOn1olCoo@21oh7oPOn1oh7o
POn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21om[o03R1oh7oPOn1oh7oPOo4ood0
POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POoJo`0hPOn1oh7o
POn1oh7oa?om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087o
f_l0>87oPOn1oh7oPOn1olCoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7o
POn1oigoo@21om[o03R1oh7oPOn1oh7oPOo4ood0POn1oh7oPOn1oh7oPOnMood0
POn1oh7oPOn1oh7oPOnMood0POoJo`0hPOn1oh7oPOn1oh7oa?om087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087of_l0>87oPOn1oh7oPOn1olCo
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21om[o03R1oh7o
POn1oh7oPOo4ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0
POoJo`0hPOn1oh7oPOn1oh7oaooh087oPOn1oh7oPOn1oh7oX_oh087oPOn1oh7o
POn1oh7oX_oh087og?l0>87oPOn1oh7oPOn1olSomP21oh7oPOn1oh7oPOn1ojCo
mP21oh7oPOn1oh7oPOn1ojComP21omgo03R1oh7oPOn1oh7oPOo:oo80POn1oh7o
POn1oh7oPOnXoo80POn1oh7oPOn1oh7oPOnXoo80POoOo`0hPOn1oh7oPOn1oh7o
b_oa087oPOn1oh7oPOn1oh7oZOoa087oPOn1oh7oPOn1oh7oZOoa087oh?l0>87o
POn1oh7oPOn1ol_ol021oh7oPOn1oh7oPOn1oj[ol021oh7oPOn1oh7oPOn1oj[o
l021on3o03R1oh7oPOn1oh7oPOo<onh0POn1oh7oPOn1oh7oPOn/onh0POn1oh7o
POn1oh7oPOn/onh0POoQo`0foOn10840P@210840P@2109d0oOn10840P@210840
P@2109d0oOn10840P@210840P@2109d003Kmoh40P@210840P@210840W@3moh40
P@210840P@210840W@3moh40P@210840P@210840W@00=_goP@210840P@210840
P@2M0?goP@210840P@210840P@2M0?goP@210840P@210840P@2M000foOn10840
P@210840P@2109d0oOn10840P@210840P@2109d0oOn10840P@210840P@2109d0
03Kmoh40P@210840P@210840W@3moh40P@210840P@210840W@3moh40P@210840
P@210840W@00?/_oo@21oh7oPOn1oh7oQoo/087o[?om087oPOn1oh7oPOn7on`0
POn/ood0POn1oh7oPOn1ohOok021on;o03k;ood0POn1oh7oPOn1ohKok@21ojco
o@21oh7oPOn1oh7oQ_o]087o[?om087oPOn1oh7oPOn6ond0POoRo`15QOl10021
oh7oPOn1oh7ob_o^087oPOoUo`40087oPOn1oh7oPOo:onh0POn1onGo0@00POn1
oh7oPOn1ol[okP21on7o04F5o`40087oPOn1oh7oPOo:onh0POn1onGo0@00POn1
oh7oPOn1ol[okP21oh7oiOl10021oh7oPOn1oh7ob_o^087ohOl0@XKoo@21oh7o
POn1oh7ob_o`087oPOoUood0POn1oh7oPOn1ol[ol021oh7oiOom087oPOn1oh7o
POo:oo00POoPo`12Q_om087oPOn1oh7oPOo9oo40POn1onGoo@21oh7oPOn1oh7o
bOoa087oPOoUood0POn1oh7oPOn1olWol@21on3o04[;ood0`?om087oPOn1oh7o
POo9oo80POnYood0`?om087oPOn1oh7oPOo9oo80POnYood0`?om087oPOn1oh7o
POo9oo80POoOo`1:boom0<7on`21oh7oPOn1oh7ob?of087oYoom0<7on`21oh7o
POn1oh7ob?of087oYoom0<7on`21oh7oPOn1oh7ob?of087ogOl0B/_oo@31oo/0
POn1oh7oPOn1olOon@21ojGoo@31oo/0POn1oh7oPOn1olOon@21ojGoo@31oo/0
POn1oh7oPOn1olOon@21om_o04[;ood0`Ook087oPOn1oh7oPOo4ood0POnTood0
`Ook087oPOn1oh7oPOo4ood0POnTood0`Ook087oPOn1oh7oPOo4ood0POoJo`12
R?oi087oPOn1oh7oPOo5ood0POn1on7on@21oh7oPOn1oh7oaOom087oPOoQooT0
POn1oh7oPOn1olGoo@21om[o04:8ooT0POn1oh7oPOn1olGoo@21oh7ohOoi087o
POn1oh7oPOo5ood0POn1on7on@21oh7oPOn1oh7oaOom087of_l0@XWom`21oh7o
POn1oh7oa_om087oPOoRooL0POn1oh7oPOn1olKoo@21oh7oh_og087oPOn1oh7o
POo6ood0POoJo`12ROog087oPOn1oh7oPOo6ood0POn1on;om`21oh7oPOn1oh7o
a_om087oPOoRooL0POn1oh7oPOn1olKoo@21om[o04[;ood0`oog087oPOn1oh7o
POo6ood0POnTood0`oog087oPOn1oh7oPOo6ood0POnTood0`oog087oPOn1oh7o
POo6ood0POoJo`1:boom0<Com@21oh7oPOn1oh7oaoom087oY?om0<Com@21oh7o
POn1oh7oaoom087oY?om0<Com@21oh7oPOn1oh7oaoom087of_l0B/_oo@34ooD0
POn1oh7oPOn1olOoo@21ojCoo@34ooD0POn1oh7oPOn1olOoo@21ojCoo@34ooD0
POn1oh7oPOn1olOoo@21om[o04[;ood0a?oe087oPOn1oh7oPOo7ood0POnTood0
a?oe087oPOn1oh7oPOo7ood0POnTood0a?oe087oPOn1oh7oPOo7ood0POoJo`12
Rooc087oPOn1oh7oPOo8ood0POn1onCol`21oh7oPOn1oh7ob?om087oPOoToo<0
POn1oh7oPOn1olSoo@21om[o04:;oo<0POn1oh7oPOn1olSoo@21oh7oi?oc087o
POn1oh7oPOo8ood0POn1onCol`21oh7oPOn1oh7ob?om087of_l0@Xcol@21oh7o
POn1oh7obOom087oPOoUoo40POn1oh7oPOn1olWoo@21oh7oiOoa087oPOn1oh7o
POo9ood0POoJo`12S?oa087oPOn1oh7oPOo9ood0POn1onGol@21oh7oPOn1oh7o
bOom087oPOoUoo40POn1oh7oPOn1olWoo@21om[o04:<oo40POn1oh7oPOn1olWo
o@21oh7oiOoa087oPOn1oh7oPOo9ood0POn1onGol@21oh7oPOn1oh7obOom087o
f_l0B/_oo@37onl0POn1oh7oPOn1ol[oo@21ojCoo@37onl0POn1oh7oPOn1ol[o
o@21ojCoo@37onl0POn1oh7oPOn1ol[oo@21om[o04[;ood0aoo_087oPOn1oh7o
POo:ood0POnTood0aoo_087oPOn1oh7oPOo:ood0POnTood0aoo_087oPOn1oh7o
POo:ood0POoJo`1:boom0<Ook`21oh7oPOn1oh7ob_om087oY?om0<Ook`21oh7o
POn1oh7ob_om087oY?om0<Ook`21oh7oPOn1oh7ob_om087of_l0B/_oo@38ond0
POn1oh7oPOn1ol_oo@21ojCoo@38ond0POn1oh7oPOn1ol_oo@21ojCoo@38ond0
POn1oh7oPOn1ol_oo@21om[o04:>ond0POn1oh7oPOn1ol_oo@21oh7oioo]087o
POn1oh7oPOo;ood0POn1onOok@21oh7oPOn1oh7oboom087of_l0@Xooj`21oh7o
POn1oh7oc?om087oPOoXon/0POn1oh7oPOn1olcoo@21oh7oj?o[087oPOn1oh7o
POo<ood0POoJo`12Soo[087oPOn1oh7oPOo<ood0POn1onSoj`21oh7oPOn1oh7o
c?om087oPOoXon/0POn1oh7oPOn1olcoo@21om[o04:?on/0POn1oh7oPOn1olco
o@21oh7oj?o[087oPOn1oh7oPOo<ood0POn1onSoj`21oh7oPOn1oh7oc?om087o
f_l0B/_oo@3:onT0POn1oh7oPOn1olgoo@21ojCoo@3:onT0POn1oh7oPOn1olgo
o@21ojCoo@3:onT0POn1oh7oPOn1olgoo@21om[o04[;ood0b_oY087oPOn1oh7o
POo=ood0POnTood0b_oY087oPOn1oh7oPOo=ood0POnTood0b_oY087oPOn1oh7o
POo=ood0POoJo`1:boom0<[oj@21oh7oPOn1oh7ocOom087oY?om0<[oj@21oh7o
POn1oh7ocOom087oY?om0<[oj@21oh7oPOn1oh7ocOom087of_l0B/_oo@3;onL0
POn1oh7oPOn1olkoo@21ojCoo@3;onL0POn1oh7oPOn1olkoo@21ojCoo@3;onL0
POn1oh7oPOn1olkoo@21om[o04:AonL0POn1oh7oPOn1olkoo@21oh7oj_oW087o
POn1oh7oPOo>ood0POn1on[oi`21oh7oPOn1oh7oc_om087of_l0@Y;oi@21oh7o
POn1oh7ocoom087oPOo[onD0POn1oh7oPOn1olooo@21oh7ojooU087oPOn1oh7o
POo?ood0POoJo`12T_oU087oPOn1oh7oPOo?ood0POn1on_oi@21oh7oPOn1oh7o
coom087oPOo[onD0POn1oh7oPOn1olooo@21om[o04:BonD0POn1oh7oPOn1oloo
o@21oh7ojooU087oPOn1oh7oPOo?ood0POn1on_oi@21oh7oPOn1oh7ocoom087o
f_l0B/_oo@3=on<0POn1oh7oPOn1om3oo@21ojCoo@3=on<0POn1oh7oPOn1om3o
o@21ojCoo@3=on<0POn1oh7oPOn1om3oo@21om[o04[;ood0cOoS087oPOn1oh7o
POo@ood0POnTood0cOoS087oPOn1oh7oPOo@ood0POnTood0cOoS087oPOn1oh7o
POo@ood0POoJo`1:boom0<gohP21oh7oPOn1oh7odOom087oY?om0<gohP21oh7o
POn1oh7odOom087oY?om0<gohP21oh7oPOn1oh7odOom087of_l0B/_oo@3>on40
POn1oh7oPOn1om7oo@21ojCoo@3>on40POn1oh7oPOn1om7oo@21ojCoo@3>on40
POn1oh7oPOn1om7oo@21om[o04:Don40POn1oh7oPOn1om7oo@21oh7okOoQ087o
POn1oh7oPOoAood0POn1ongoh@21oh7oPOn1oh7odOom087of_l0@YGog`21oh7o
POn1oh7od_om087oPOo^oml0POn1oh7oPOn1om;oo@21oh7ok_oO087oPOn1oh7o
POoBood0POoJo`12QOom087oPOn1oh7oPOo4ood0POn1omkoo@21oh7oPOn1oh7o
a?om087oPOoNood0POn1oh7oPOn1olCoo@21om[o04:5ood0POn1oh7oPOn1olCo
o@21oh7og_om087oPOn1oh7oPOo4ood0POn1omkoo@21oh7oPOn1oh7oa?om087o
f_l0@XGoo@21oh7oPOn1oh7oa?om087oPOoNood0POn1oh7oPOn1olCoo@21oh7o
g_om087oPOn1oh7oPOo4ood0POoJo`1:boom0;ooo@21oh7oPOn1oh7oa?om087o
Y?om0;ooo@21oh7oPOn1oh7oa?om087oY?om0;ooo@21oh7oPOn1oh7oa?om087o
f_l0B/_oo@2oood0POn1oh7oPOn1olCoo@21ojCoo@2oood0POn1oh7oPOn1olCo
o@21ojCoo@2oood0POn1oh7oPOn1olCoo@21om[o04[;ood0_oom087oPOn1oh7o
POo4ood0POnTood0_oom087oPOn1oh7oPOo4ood0POnTood0_oom087oPOn1oh7o
POo4ood0POoJo`1:boom0;ooo@21oh7oPOn1oh7oa?om087oY?om0;ooo@21oh7o
POn1oh7oa?om087oY?om0;ooo@21oh7oPOn1oh7oa?om087of_l0@XGoo@21oh7o
POn1oh7oa?om087oPOoNood0POn1oh7oPOn1olCoo@21oh7og_om087oPOn1oh7o
POo4ood0POoJo`12QOom087oPOn1oh7oPOo4ood0POn1omkoo@21oh7oPOn1oh7o
a?om087oPOoNood0POn1oh7oPOn1olCoo@21om[o04:5ood0POn1oh7oPOn1olCo
o@21oh7og_om087oPOn1oh7oPOo4ood0POn1omkoo@21oh7oPOn1oh7oa?om087o
f_l0@XGoo@21oh7oPOn1oh7oa?om087oPOoNood0POn1oh7oPOn1olCoo@21oh7o
g_om087oPOn1oh7oPOo4ood0POoJo`1:boom0;ooo@21oh7oPOn1oh7oa?om087o
Y?om0;ooo@21oh7oPOn1oh7oa?om087oY?om0;ooo@21oh7oPOn1oh7oa?om087o
f_l0B/_oo@2oood0POn1oh7oPOn1olCoo@21ojCoo@2oood0POn1oh7oPOn1olCo
o@21ojCoo@2oood0POn1oh7oPOn1olCoo@21om[o04[;ood0_oom087oPOn1oh7o
POo4ood0POnTood0_oom087oPOn1oh7oPOo4ood0POnTood0_oom087oPOn1oh7o
POo4ood0POoJo`1:boom0;ooo@21oh7oPOn1oh7oa?om087oY?om0;ooo@21oh7o
POn1oh7oa?om087oY?om0;ooo@21oh7oPOn1oh7oa?om087of_l0@XGoo@21oh7o
POn1oh7oa?om087oPOoNood0POn1oh7oPOn1olCoo@21oh7og_om087oPOn1oh7o
POo4ood0POoJo`12QOom087oPOn1oh7oPOo4ood0POn1omkoo@21oh7oPOn1oh7o
a?om087oPOoNood0POn1oh7oPOn1olCoo@21om[o04:5ood0POn1oh7oPOn1olCo
o@21oh7og_om087oPOn1oh7oPOo4ood0POn1omkoo@21oh7oPOn1oh7oa?om087o
f_l0@XGoo@21oh7oPOn1oh7oa?om087oPOoNood0POn1oh7oPOn1olCoo@21oh7o
g_om087oPOn1oh7oPOo4ood0POoJo`1:boom0;ooo@21oh7oPOn1oh7oa?om087o
Y?om0;ooo@21oh7oPOn1oh7oa?om087oY?om0;ooo@21oh7oPOn1oh7oa?om087o
f_l0B/_oo@2oood0POn1oh7oPOn1olCoo@21ojCoo@2oood0POn1oh7oPOn1olCo
o@21ojCoo@2oood0POn1oh7oPOn1olCoo@21om[o04[;ood0_oom087oPOn1oh7o
POo4ood0POnTood0_oom087oPOn1oh7oPOo4ood0POnTood0_oom087oPOn1oh7o
POo4ood0POoJo`1:boom0;ooo@21oh7oPOn1oh7oa?om087oY?om0;ooo@21oh7o
POn1oh7oa?om087oY?om0;ooo@21oh7oPOn1oh7oa?om087of_l0@XGoo@21oh7o
POn1oh7oa?om087oPOoNood0POn1oh7oPOn1olCoo@21oh7og_om087oPOn1oh7o
POo4ood0POoJo`12QOom087oPOn1oh7oPOo4ood0POn1omkoo@21oh7oPOn1oh7o
a?om087oPOoNood0POn1oh7oPOn1olCoo@21om[o04:5ood0POn1oh7oPOn1olCo
o@21oh7og_om087oPOn1oh7oPOo4ood0POn1omkoo@21oh7oPOn1oh7oa?om087o
f_l0@XGoo@21oh7oPOn1oh7oa?om087oPOoNood0POn1oh7oPOn1olCoo@21oh7o
g_om087oPOn1oh7oPOo4ood0POoJo`12QOom087oPOn1oh7oPOo4ood0POn1omko
o@21oh7oPOn1oh7oa?om087oPOoNood0POn1oh7oPOn1olCoo@21om[o04[;ood0
_oom087oPOn1oh7oPOo4ood0POnTood0_oom087oPOn1oh7oPOo4ood0POnTood0
_oom087oPOn1oh7oPOo4ood0POoJo`1:boom0;ooo@21oh7oPOn1oh7oa?om087o
Y?om0;ooo@21oh7oPOn1oh7oa?om087oY?om0;ooo@21oh7oPOn1oh7oa?om087o
f_l0B/_oo@2oood0POn1oh7oPOn1olCoo@21ojCoo@2oood0POn1oh7oPOn1olCo
o@21ojCoo@2oood0POn1oh7oPOn1olCoo@21om[o04[;ood0_oom087oPOn1oh7o
POo4ood0POnTood0_oom087oPOn1oh7oPOo4ood0POnTood0_oom087oPOn1oh7o
POo4ood0POoJo`12QOom087oPOn1oh7oPOo4ood0POn1omkoo@21oh7oPOn1oh7o
a?om087oPOoNood0POn1oh7oPOn1olCoo@21om[o04:5ood0POn1oh7oPOn1olCo
o@21oh7og_om087oPOn1oh7oPOo4ood0POn1omkoo@21oh7oPOn1oh7oa?om087o
f_l0@XGoo@21oh7oPOn1oh7oa?om087oPOoNood0POn1oh7oPOn1olCoo@21oh7o
g_om087oPOn1oh7oPOo4ood0POoJo`12QOom087oPOn1oh7oPOo4ood0POn1omko
o@21oh7oPOn1oh7oa?om087oPOoNood0POn1oh7oPOn1olCoo@21om[o04[;ood0
_oom087oPOn1oh7oPOo4ood0POnTood0_oom087oPOn1oh7oPOo4ood0POnTood0
_oom087oPOn1oh7oPOo4ood0POoJo`1Lboom0;ooo@2iooh0_oon087oPOn1oh7o
e?om087oY?om0;ooo@2iooh0_oon087oPOn1oh7oe?om087oY?om0;ooo@2iooh0
_oon087oPOn1oh7oe?om087of_l0G<_oo@2oood0^_on0;gooP21oh7oPOn1omGo
o@21ojCoo@2oood0^_on0;gooP21oh7oPOn1omGoo@21ojCoo@2oood0^_on0;go
oP21oh7oPOn1omGoo@21om[o06S;ood0_oom0;_oo@3;oo`0n?om087oPOn1oh7o
e_om087oY?om0;ooo@2kood0bool0?Soo@21oh7oPOn1omKoo@21ojCoo@2oood0
^oom0<_oo03hood0POn1oh7oPOoFood0POoJo`1PQOom0;_ooP3:oo`0moon087o
POn1oh7oe_om087oPOoNood0^oon0<[oo03gooh0POn1oh7oPOoFood0POn1omko
o@2kooh0b_ol0?OooP21oh7oPOn1omKoo@21om[o0625ood0_?om0<[oo03good0
POn1oh7oPOoGood0POn1omkoo@2lood0b_ol0?Ooo@21oh7oPOn1omOoo@21oh7o
g_om0;coo@3:oo`0moom087oPOn1oh7oeoom087of_l0H8Goo@2mood0bOol0?Ko
o@21oh7oPOn1omSoo@21oh7og_om0;goo@39oo`0m_om087oPOn1oh7of?om087o
POoNood0_Oom0<Woo03food0POn1oh7oPOoHood0POoJo`1PQOom0;goo@39oo`0
m_om087oPOn1oh7of?om087oPOoNood0_Oom0<Woo03food0POn1oh7oPOoHood0
POn1omkoo@2mood0bOol0?Koo@21oh7oPOn1omSoo@21om[o06S;ood0_oom0;ko
o@38oo`0mOom087oPOn1oh7ofOom087oY?om0;ooo@2nood0b?ol0?Goo@21oh7o
POn1omWoo@21ojCoo@2oood0__om0<Soo03eood0POn1oh7oPOoIood0POoJo`1X
boom0;ooo@2nood0b?ol0?Goo@21oh7oPOn1omWoo@21ojCoo@2oood0__om0<So
o03eood0POn1oh7oPOoIood0POnTood0_oom0;koo@38oo`0mOom087oPOn1oh7o
fOom087of_l0H<_oo@2oood0_oom0<Ooo03dood0POn1oh7oU?n8087ogoom0;oo
o@2oood0aool0?Coo@21oh7oPOnDohP0POoOood0_oom0;ooo@37oo`0m?om087o
POn1oiCoR02Eo`1Pboom0;ooo@2oood0aool0?Coo@21oh7oPOnDohP0POoOood0
_oom0;ooo@37oo`0m?om087oPOn1oiCoR021omooo@2oood0_oom0<Ooo03dood0
POn1oh7oU?n809Go08B5ood0m?ol0?;oo03Vood0m_ok0??on`3_oo<0n?om087o
POn1oiGoR021oiWoo@3doo`0l_ol0>Koo@3foo/0look0>ool`3hood0POn1oh7o
UOn8087oVOom0?Coo03boo`0i_om0?Kon`3coo/0kooc0?Soo@21oh7oPOnEohP0
UOl0Q8Goo@3doo`0l_ol0>Koo@3foo/0lool0>kol`3hood0POn1oh7oUOn8087o
VOom0?Coo03boo`0i_om0?Kon`3coo`0k_oc0?Soo@21oh7oPOnEohP0POnIood0
m?ol0?;oo03Vood0m_ok0??oo03^oo<0n?om087oPOn1oiGoR02Eo`24QOom0?Co
o03boo`0iool0?Gon`3eoo/0k_oc0?Soo021oh7oPOnFohP0POnIood0m?ol0?;o
o03Woo`0mOok0?Gon`3^oo<0n?ol087oPOn1oiKoR021oiWoo@3doo`0l_ol0>Oo
o03eoo/0mOok0>kol`3hoo`0POn1oh7oU_n809Go08B5ood0m?ol0?;oo03Wood0
lool0?Kon`3]oo<0n?ol087oPOn1oiKoR021oiWoo@3doo`0l_ol0>Ooo@3coo`0
m_ok0>gol`3hoo`0POn1oh7oU_n8087oVOom0?Coo03boo`0ioom0??oo03foo/0
kOoc0?Soo021oh7oPOnFohP0UOl0Q8Goo@3doo`0l_ol0>Ooo@3coo/0n?ok0>So
o03bood0POn1oh7oU_n8087oVOom0?Coo03boo`0ioom0??on`3hoo/0j?ol0?;o
o@21oh7oPOnFohP0POnIood0m?ol0?;oo03Wood0look0?Son`3Xoo`0l_om087o
POn1oiKoR02Eo`2@boom0;ooo@3doo`0l_ol0>Soo03boo/0nOok0>Soo03boo`0
POn1oh7oUon8087ogoom0;ooo@3doo`0l_ol0>Soo03boo/0nOok0>Soo03boo`0
POn1oh7oUon8087ogoom0;ooo@3doo`0l_ol0>Soo03boo/0nOok0>Soo03boo`0
POn1oh7oUon809Go093;ood0_oom0?Coo03boo`0j?ol0?7oo03joo/0iool0?;o
o021oh7oPOnGohP0POoOood0_oom0?Coo03boo`0j?ol0?7oo03joo/0iool0?;o
o021oh7oPOnGohP0POoOood0_oom0?Coo03boo`0j?ol0?7oo03joo/0iool0?;o
o021oh7oPOnGohP0UOl0T<_oo@2oood0m?ol0?;oo03Xoo`0lOok0?con`3Voo`0
l_ol087oPOn1oiOoR021omooo@2oood0m?ol0?;oo03Xoo`0lOok0?con`3Voo`0
l_ol087oPOn1oiOoR021omooo@2oood0m?ol0?;oo03Xoo`0lOok0?con`3Voo`0
l_ol087oPOn1oiOoR02Eo`2@boom0;ooo@3doo`0l_ol0>Soo@3_oo/0oOol0>Go
o03aood0POn1oh7oUon8087ogoom0;ooo@3doo`0l_ol0>Soo@3_oo/0oOol0>Go
o03aood0POn1oh7oUon8087ogoom0;ooo@3doo`0l_ol0>Soo@3_oo/0oOol0>Go
o03aood0POn1oh7oUon809Go08B5ood0m?ol0?;oo03Yoo`0k_ol0?kon`3Uoo`0
lOol087oPOn1oiSoR021oiWoo@3doo`0l_ol0>Woo03^oo`0o_ok0>Goo03aoo`0
POn1oh7oV?n8087oVOom0?Coo03boo`0jOol0>koo03noo/0iOol0?7oo021oh7o
POnHohP0UOl0Q8Goo@3doo`0l_ol0>Woo03^oo/00?ok0>Coo03aoo`0POn1oh7o
V?n8087oVOom0?Coo03boo`0jOol0>kon`00oo/0i?ol0?7oo021oh7oPOnHohP0
POnIood0m?ol0?;oo03Yoo`0k_ok003on`3Too`0lOol087oPOn1oiSoR02Eo`24
QOom0?Coo03boo`0jOol0>goo000oo`0hool0?7oo021oh7oPOn1oh7oPOngood0
m?ol0?;oo03Yoo`0kOol003oo03Soo`0lOol087oPOn1oh7oPOn1okOoo@3doo`0
l_ol0>Woo03]oo`00?ol0>?oo03aoo`0POn1oh7oPOn1ok?o07R5ood0m?ol0?;o
o03Yoo`0k?og0>?oo03aoo`0POn1oh7oPOn1oh7o]oom0?Coo03boo`0jOol0>co
m`3Soo`0lOol087oPOn1oh7oPOn1okOoo@3doo`0l_ol0>Woo03/ooL0hool0?7o
o021oh7oPOn1oh7o/ol0Q<_oo@2oood0m?ol0?;oo03Yoo`0k?oh0>;oo03aoo`0
POn1oh7oPOn1oh7ooOom0;ooo@3doo`0l_ol0>Woo03/ooP0h_ol0?7oo021oh7o
POn1oh7oPOomood0_oom0?Coo03boo`0jOol0>con03Roo`0lOol087oPOn1oh7o
POnco`24boom0;ooo@3doo`0l_ol0>Woo03[ooX0hOol0?7oo021oh7oPOn1oh7o
POomood0_oom0?Coo03boo`0jOol0>_onP3Qoo`0lOol087oPOn1oh7oPOn1oogo
o@2oood0m?ol0?;oo03Yoo`0jooj0>7oo03aoo`0POn1oh7oPOn1ok?o08C;ood0
_oom0?Coo03boo`0jOol0>_onP3Qoo`0lOol087oPOn1oh7oPOn1oogoo@2oood0
m?ol0?;oo03Yoo`0jooj0>7oo03aoo`0POn1oh7oPOn1oh7ooOom0;ooo@3doo`0
l_ol0>Woo03[ooX0hOol0?7oo021oh7oPOn1oh7o/ol0Q<_oo@2oood0m?ol0?;o
o03Yoo`0k?oh0>;oo03aoo`0POn1oh7oPOn1oh7ooOom0;ooo@3doo`0l_ol0>Wo
o03/ooP0h_ol0?7oo021oh7oPOn1oh7oPOomood0_oom0?Coo03boo`0jOol0>co
n03Roo`0lOol087oPOn1oh7oPOnco`1hQOom0?Coo03boo`0jOol0>con03Roo`0
lOol087oPOn1oh7oPOn1okOoo@3doo`0l_ol0>Woo03/ooP0h_ol0?7oo021oh7o
POn1oh7oPOngood0m?ol0?;oo03Yoo`0k?oh0>;oo03aoo`0POn1oh7oPOn1ok?o
08B5ood0m?ol0?;oo03dooh0nOol0>gomP3Soo`0lOol087oPOn1oh7oPOn1okOo
o@3doo`0l_ol0?CooP3ioo`0kOof0>?oo03aoo`0POn1oh7oPOn1oh7o]oom0?Co
o03boo`0m?on0?Woo03]ooH0hool0?7oo021oh7oPOn1oh7o/ol0T8Goo@3doo`0
l_ol0?CooP3ioo`0k_ok003on`3Too`0lOol087oPOn1oiSoR021oiWoo@3doo`0
l_ol0?CooP3ioo`0k_ok003on`3Too`0lOol087oPOn1oiSoR021oiWoo@3doo`0
l_ol0?CooP3ioo`0k_ok003on`3Too`0lOol087oPOn1oiSoR02Eo`2@QOom0?Co
o03boo`0mOom0?Woo03^oo`0o_ol0>Coo03aoo`0POn1oh7oV?n8087oVOom0?Co
o03boo`0mOom0?Woo03^oo`0o_ol0>Coo03aoo`0POn1oh7oV?n8087oVOom0?Co
o03boo`0mOom0?Woo03^oo`0o_ol0>Coo03aoo`0POn1oh7oV?n809Go09c;ood0
_oom0?Coo03coo/0m_ol0?Woo03_oo`0oOok0>Goo03aoo`0POn1oh7oV?n8087o
goom0;ooo@3doo`0look0?Koo03ioo`0kool0?gon`3Uoo`0lOol087oPOn1oiSo
R021omooo@2oood0m?ol0??on`3foo`0nOol0>ooo03moo/0iOol0?7oo021oh7o
POnHohP0UOl0W<_oo@2oood0m?ol0??on`3hooX0n?om0?3on`3loo/0i_ol0?7o
o@21oh7oPOnGohP0POoOood0_oom0?Coo03coo/0n?oj0?Soo@3`oo/0o?ok0>Ko
o03aood0POn1oh7oUon8087ogoom0;ooo@3doo`0look0?SonP3hood0l?ok0?co
n`3Voo`0lOom087oPOn1oiOoR02Eo`2Lboom0;ooo@3doo`0look0?comP3hoo`0
lOol0?[oo03Voo`0l_ol087oPOn1oiOoR021omooo@2oood0m?ol0??on`3looH0
n?ol0?7oo03joo`0i_ol0?;oo021oh7oPOnGohP0POoOood0_oom0?Coo03coo/0
o?of0?Soo03aoo`0n_ol0>Koo03boo`0POn1oh7oUon809Go09c;ood0_oom0?Co
n`3eooX0o?of0?Soo03boo/0n_ok0>Ooo03boo`0POn1oh7oUon8087ogoom0;oo
o@3doo/0mOoj0?comP3hoo`0l_ok0?[on`3Woo`0l_ol087oPOn1oiOoR021omoo
o@2oood0m?ok0?GonP3looH0n?ol0?;on`3joo/0iool0?;oo021oh7oPOnGohP0
UOl0T8Goo@3coo`0m_oi0?comP3hoo`0look0?Son`3Xoo`0l_ol087oPOn1oiOo
R021oiWoo@3coo`0m_oi0?comP3hoo`0look0?Son`3Xoo`0l_ol087oPOn1oiOo
R021oiWoo@3coo`0m_oi0?comP3hoo`0look0?Son`3Xoo`0l_ol087oPOn1oiOo
R02Eo`2LQOom0??on`3hooP0mOom0?Ooo@3coo`0m_ol0?Soo03foo/0loom087o
POn1oiKoR021oiWoo@3coo/0n?oh0?Goo@3good0lool0?Koo03hoo`0m_ok0??o
o@21oh7oPOnFohP0POnIood0look0?Son03eood0moom0??oo03foo`0n?ol0?Ko
n`3cood0POn1oh7oU_n809Go09b5ood0looj0?_omP3eood0mool0?Gon`3foo/0
nOol0?Kom`3good0POn1oh7oU_n8087oVOom0??onP3kooH0mOom0?Ooo03eoo/0
m_ok0?Woo03fooL0moom087oPOn1oiKoR021oiWoo@3cooX0noof0?Goo@3goo`0
mOok0?Kon`3ioo`0m_og0?Ooo@21oh7oPOnFohP0UOl0W8Goo@3boo000?ol0?Go
o@3goo`0m_ok0?Con`3joo`0mOoh0?Soo021oh7oPOnFohP0POnIood0l_o`003o
o03eood0mool0?Kon`3doo/0n_ol0?Gon03hoo`0POn1oh7oU_n8087oVOom0?;o
l000oo`0mOom0?Ooo03foo/0m?ok0?[oo03eooP0n?ol087oPOn1oiKoR02Eo`2O
QOom0?7olP01oool0?Goo@3food0m_ol0?;oo03joo`0m?oi0?Soo@21oh7oPOnE
ohP0POnIood0lOob007ooo`0mOom0?Koo@3foo`0l_ol0?[oo03dooT0n?om087o
POn1oiGoR021oiWoo@3aoo800Oooo03eood0m_om0?Koo03boo`0n_ol0?Con@3h
ood0POn1oh7oUOn809Go0:S;ood0_oom0?3om@3moo`0mOom0?Koo@3goo/0l_ok
0?_oo03cooX0n?om087oPOn1oiGoR021omooo@2oood0l?oe0?goo03eood0m_om
0?Oon`3boo/0nool0??onP3hood0POn1oh7oUOn8087ogoom0;ooo@3`ooD0oOol
0?Goo@3food0mook0?;on`3koo`0looj0?Soo@21oh7oPOnEohP0UOl0N<_oo@2o
ood0k_oi0>[oo@3eood0eOon0>Coo@21oh7oPOnDohP0POoOood0_oom0>kon@3Z
ood0mOom0=GooP3Tood0POn1oh7oU?n8087ogoom0;ooo@3^ooT0j_om0?Goo@3E
ooh0i?om087oPOn1oiCoR02Eo`1dboom0;ooo@3?ood0mOom0=GooP3Tood0POn1
oh7oPOoJood0POnTood0_oom0<ooo@3eood0eOon0>Coo@21oh7oPOn1om[oo@21
ojCoo@2oood0coom0?Goo@3Eooh0i?om087oPOn1oh7of_om087of_l0M<_oo@2o
ood0coom0?Coo@3Fooh0iOom087oPOn1oh7ofOom087oY?om0;ooo@3?ood0m?om
0=KooP3Uood0POn1oh7oPOoIood0POnTood0_oom0<ooo@3dood0e_on0>Goo@21
oh7oPOn1omWoo@21om[o06b5ood0coom0?Coo@3Fooh0iOom087oPOn1oh7ofOom
087oPOoNood0coom0?Coo@3Fooh0iOom087oPOn1oh7ofOom087oPOoNood0coom
0?Coo@3Fooh0iOom087oPOn1oh7ofOom087of_l0K8Goo@3?ood0loom0=SooP3U
ood0POn1oh7oPOoHood0POn1omkoo@3?ood0loom0=SooP3Uood0POn1oh7oPOoH
ood0POn1omkoo@3?ood0loom0=SooP3Uood0POn1oh7oPOoHood0POoJo`1/QOom
0<ooo@3cood0f?on0>Goo@21oh7oPOn1omSoo@21oh7og_om0<ooo@3cood0f?on
0>Goo@21oh7oPOn1omSoo@21oh7og_om0<ooo@3cood0f?on0>Goo@21oh7oPOn1
omSoo@21om[o06b5ood0coom0?;oo@3Jood0i_om087oPOn1oh7oeoom087oPOoN
ood0coom0?;oo@3Jood0i_om087oPOn1oh7oeoom087oPOoNood0coom0?;oo@3J
ood0i_om087oPOn1oh7oeoom087of_l0M<_oo@2oood0coom0?7ooP3Jooh0iOon
087oPOn1oh7oe_om087oY?om0;ooo@3?ood0lOon0=[ooP3Uooh0POn1oh7oPOoF
ood0POnTood0_oom0<ooo@3aooh0f_on0>GooP21oh7oPOn1omKoo@21om[o07C;
ood0_oom0<ooo@3aood0fol00>Coo@21oh7oPOn1omKoo@21ojCoo@2oood0coom
0?7oo@3Ko`00i?om087oPOn1oh7oe_om087oY?om0;ooo@3?ood0lOom0=_o003T
ood0POn1oh7oPOoFood0POoJo`1Xboom0;ooo@3?ood0l?on0;gooP21oh7oPOn1
omGoo@21ojCoo@2oood0coom0?3ooP2mooh0POn1oh7oPOoEood0POnTood0_oom
0<ooo@3`ooh0_Oon087oPOn1oh7oeOom087of_l0J<_oo@2oood0coom0>oooP2o
ooh0POn1oh7oPOoDood0POnTood0_oom0<ooo@3_ooh0_oon087oPOn1oh7oe?om
087oY?om0;ooo@3?ood0koon0;oooP21oh7oPOn1omCoo@21om[o04j5ood0coom
087oPOn1oh7oPOojood0POn1omkoo@3?ood0POn1oh7oPOn1oo[oo@21oh7og_om
0<ooo@21oh7oPOn1oh7on_om087of_l0CXGoo@3?ood0POn1oh7oPOn1oo[oo@21
oh7og_om0<ooo@21oh7oPOn1oh7on_om087oPOoNood0coom087oPOn1oh7oPOoj
ood0POoJo`1>QOom0<ooo@21oh7oPOn1oh7on_om087oPOoNood0coom087oPOn1
oh7oPOojood0POn1omkoo@3?ood0POn1oh7oPOn1oo[oo@21om[o04j5ood0coom
087oPOn1oh7oPOojood0POn1omkoo@3?ood0POn1oh7oPOn1oo[oo@21oh7og_om
0<ooo@21oh7oPOn1oh7on_om087of_l0H<_oo@2oood0coom087oPOn1oh7oPOoj
ood0goog087od?om0;ooo@3?ood0POn1oh7oPOn1oo[oo@3OooL0POo@ood0_oom
0<ooo@21oh7oPOn1oh7on_om0=oom`26o`1[boom0;ooo@21oh7oPOn1oh7oa?om
0>;ol@3_o`400=gon`2Aood0_oom087oPOn1oh7oPOo4ood0h_oa0>oo0@00gOok
097oo@2oood0POn1oh7oPOn1olCoo@3Roo40kol1003Moo/0aol0J<_oo@2oood0
POn1oh7oPOn1olCoo@3Tond0l_on0=kon@2Bood0_oom087oPOn1oh7oPOo4ood0
i?o]0?;ooP3NooT0T_om0;ooo@21oh7oPOn1oh7oa?om0>Cok@3booh0g_oi0<So
06S;ood0_oom087oPOn1oh7oPOo4ood0i_oZ0?Coo@3NooT0T_om0;ooo@21oh7o
POn1oh7oa?om0>KojP3dood0g_oi09;oo@2oood0POn1oh7oPOn1olCoo@3VonX0
m?om0=kon@38o`1/QOom087oPOn1oh7oPOo4ood0iooh0?Won@3eooh0gOoi087o
c?om087oPOn1oh7oPOo4ood0iooh0?Won@3eooh0gOoi087oc?om087oPOn1oh7o
POo4ood0iooh0?Won@3eooh0gOoi0<So0:j5ood0POoDonT0k_l1003Moo/0POod
oo`0i?l1003Loo/0POnTood0j?oj0?ConP3fooh0g_og087ocOom087oe?oY0>ko
0@00gOok087om?ol0>Co0@00g?ok087oY?om0>SonP3dooX0m_on0=kom`21olgo
o@21omCoj@3^o`400=gon`21ooCoo03To`400=con`21ojCoo@3XooX0m?oj0?Ko
oP3NooL0bOl0Z8Goo@21omCoiP3booh0g_oi087omOol0>GooP3MooT0POnUood0
jOok0?3on`3hooh0gOog087ocOom087oe?oV0?;ooP3NooT0POoeoo`0iOon0=go
n@21ojGoo@3Yoo/0l?ok0?SooP3MooL0POo=ood0POoDonH0l_on0=kon@21ooGo
o03Uooh0gOoi087oYOom0>Won`3`oo/0n?on0=gom`39o`2XQOom087oe?oU0?Co
o@3NooT0POoeoo`0i_om0=gon@21ojGoo@3Zoo/0k_ok0?WooP3MooL0POo=ood0
POoDonD0m?om0=kon@21ooGoo03Vood0gOoi087oYOom0>[on`3^oo/0nOon0=go
m`21olgoo@21omCoi@3dood0g_oi087omOol0>Koo@3MooT0POnUood0j_ok0>ko
n`3iooh0gOog0<Wo0;B5ood0POoDon@0mOon0=gon@21ooGoo03Vooh0g?oi087o
YOom0>_on`3/oo`0nOon0=kon`00oo`0POo>ood0POoDon@0mOon0=gon@21ooGo
o03Vooh0g?oi087oYOom0>_on`3/oo`0nOon0=kon`00oo`0POo>ood0POoDon@0
mOon0=gon@21ooGoo03Vooh0g?oi087oYOom0>_on`3/oo`0nOon0=kon`00oo`0
b_l0bl_oo@2oood0POoDoo`0kooj0?KooP3NooL0POofoo`0i_on0=gom`21ojKo
o@3[oo`0jook0?[ooP3Noo`00Oooo02Dood0_oom087oe?ol0>oonP3fooh0g_og
087om_ol0>KooP3MooL0POnVood0jool0>_on`3jooh0g_ol007ooo`0U?om0;oo
o@21omCoo03_ooX0m_on0=kom`21ooKoo03Vooh0gOog087oY_om0>_oo03[oo/0
n_on0=koo001oool0<[o0<_;ood0_oom087oe?ol0>gon`3hooh0gOog087om_ol
0>OooP3LooL0POnVood0k?ok0>[oo03joo`0h?ol007ooo/0UOom0;ooo@21omCo
o03]oo/0n?on0=gom`21ooKoo03Wooh0g?og087oY_om0>con`3Zoo`0n_ol0>3o
o001oook09Goo@2oood0POoDoo`0kOok0?SooP3MooL0POofoo`0ioon0=com`21
ojKoo@3/oo/0j_ol0?[oo03Poo`00Ooon`3;o`38boom0;ooo@21omCoo03/oo`0
n?on0=gom`21ooKoo03Wooh0g?og087oY_om0>coo03Yoo/0nool0>7on`3noo`0
UOom0;ooo@21omCoo03/oo`0n?on0=gom`21ooKoo03Wooh0g?og087oY_om0>co
o03Yoo/0nool0>7on`3noo`0UOom0;ooo@21omCoo03/oo`0n?on0=gom`21ooKo
o03Wooh0g?og087oY_om0>coo03Yoo/0nool0>7on`3noo`0bol0n<_oo@2oood0
POoDoo`0k?ok0?WooP3Noo/00?ol087omool0>OooP3Moo/00?ol087oYoom0>go
n`3Xoo`0nool0>7oo03moo`0m?ok0??on`2lood0_oom087oe?ol0>con`3iooh0
g_ok003oo021ooOoo03Wooh0gOok003oo021ojOoo@3]oo/0j?ol0?_oo03Qoo`0
oOol0?Con`3coo/0_?om0;ooo@21omCoo03/oo/0nOon0=kon`00oo`0POogoo`0
ioon0=gon`00oo`0POnWood0kOok0>Soo03koo`0hOol0?goo03doo/0look0?;o
0?J5ood0POoDoo`0jool0?WooP3Noo`00Oooo021ooOoo03Wooh0gOol007ooo`0
POnWood0kOol0>Ooo03koo`0hOol0?gon`3eoo/0lool087omOom087oe?ol0>_o
o03iooh0g_ol007ooo`0POogoo`0ioon0=goo001oool087oYoom0>goo03Woo`0
nool0>7oo03moo/0mOok0??oo021ooGoo@21omCoo03[oo`0nOon0=koo001oool
087omool0>OooP3Moo`00Oooo021ojOoo@3]oo`0iool0?_oo03Qoo`0oOok0?Go
n`3coo`0lOl0jXGoo@21omCoo03[oo`0nOol0>3oo001oook087on?ol0>Ooo03O
oo`00Ooon`21ojSoo@3]oo`0g?ol0>;oo03koo`0m?ok0?Gon`21ooGoo@21omCo
o03[oo`0nOol0>3oo001oook087on?ol0>Ooo03Ooo`00Ooon`21ojSoo@3]oo`0
g?ol0>;oo03koo`0m?ok0?Gon`21ooGoo@21omCoo03[oo`0nOol0>3oo001oook
087on?ol0>Ooo03Ooo`00Ooon`21ojSoo@3]oo`0g?ol0>;oo03koo`0m?ok0?Go
n`3ao`3HQOom087oe?ol0>_oo03ioo`0hOok0?koo021ooSoo03Woo`0h?ok0?ko
o021ojSoo@3]oo`0^?ol0?_oo03coo`0m_ok087om?om087oe?ol0>_oo03ioo`0
hOok0?koo021ooSoo03Woo`0h?ok0?koo021ojSoo@3]oo`0^?ol0?_oo03coo`0
m_ok087om?om087oe?ol0>_oo03ioo`0hOok0?koo021ooSoo03Woo`0h?ok0?ko
o021ojSoo@3]oo`0^?ol0?_oo03coo`0m_ok0?3o0@:5ood0POoDoo`0jool0?Wo
o03Qoo`0oOol0?Con`3coo/0Wool0>Ooo03Poo`0oOol0?Gon`3coo/0POo>ood0
k_ok0;Won`3koo/0m?ok0?Son`21oo?oo@21omCoo03[oo`0nOol0>7oo03moo`0
m?ok0??on`2Ooo`0iool0>3oo03moo`0mOok0??on`21olkoo@3^oo/0^Ook0?_o
n`3doo/0n?ok087oloom087oe?ol0>_oo03ioo`0hOol0?goo03doo/0look09oo
o03Woo`0h?ol0?goo03eoo/0look087oc_om0>kon`2ioo/0nook0?Con`3hoo/0
kol12/_oo@2oood0POoDoo`0jool0?Woo03Qoo`0oOok0?Gon`3coo`0W_ol0>Oo
o03Poo`0oOok0?Kon`3coo`0POo=ood0k_ol0;Soo03ioo`0look0?Won`2iood0
_oom087oe?ol0>_oo03ioo`0hOol0?gon`3eoo/0lool09koo03Woo`0h?ol0?go
n`3foo/0lool087ocOom0>koo02hoo`0nOol0??on`3ioo/0^Oom0;ooo@21omCo
o03[oo`0nOol0>7oo03moo/0mOok0??oo02Noo`0iool0>3oo03moo/0m_ok0??o
o021olgoo@3^oo`0^?ol0?Woo03coo/0nOok0>oo0@[;ood0_oom087oe?ol0>_o
o03ioo`0h_ol0?_oo03doo/0mOok09koo03Woo`0hOol0?_oo03eoo/0mOok087o
cOom0>koo02hoo`0nOol0?;oo03joo/0^?om0;ooo@21omCoo03[oo`0nOol0>;o
o03koo`0m?ok0?Gon`2Noo`0iool0>7oo03koo`0mOok0?Gon`21olgoo@3^oo`0
^?ol0?Woo03boo`0n_ok0;Soo@2oood0POoDoo`0jool0?Woo03Roo`0nool0?Co
n`3eoo/0W_ol0>Ooo03Qoo`0nool0?Gon`3eoo/0POo=ood0k_ol0;Soo03ioo`0
l_ol0?[on`3^o`3bboom0;ooo@21omCoo03[oo`0eOol0?_oo03coo`0m_ok09go
o032oo`0nool0?Coo03foo/0POo<ood0k_ol0;Won`3ioo/0look0?con`2good0
_oom087oe?ol0>_oo03Eoo`0nool0??oo03foo/0WOol0<;oo03koo`0m?ol0?Ko
n`21olcoo@3^oo`0^Ook0?Won`3coo/0o?ok0;Ooo@2oood0POoDoo`0jool0=Go
o03koo`0lool0?Kon`2Moo`0`_ol0?_oo03doo`0m_ok087oc?om0>koo02ioo/0
nOok0??on`3loo/0kOl0l/_oo@2oood0POoDoo`0k?ol0=Gon`3koo/0m?ok0?So
n`2Loo`0`ook0?_on`3eoo/0n?ok087oboom0>koo02ioo`0mool0?;on`3moo`0
]_om0;ooo@21omCoo03/oo`0eOok0?_on`3doo/0n?ok09coo033oo/0nook0?Go
n`3hoo/0POo;ood0k_ol0;Woo03goo`0l_ok0?goo02food0_oom087oe?ol0>co
o03Eoo/0nook0?Con`3hoo/0W?ol0<?on`3koo/0mOok0?Son`21ol_oo@3^oo`0
^Ool0?Ooo03boo/0oOol0>co0>Z5ood0POoDoo`0k?ol0=Goo03ioo`0look0?Wo
n`2Loo`0`ool0?Woo03doo/0nOok087oboom0>koo02ioo`0mool0?7oo03noo/0
POo`ood0POoDoo`0k?ol0=Goo03ioo`0look0?Won`2Loo`0`ool0?Woo03doo/0
nOok087oboom0>koo02ioo`0mool0?7oo03noo/0POo`ood0POoDoo`0k?ol0=Go
o03ioo`0look0?Won`2Loo`0`ool0?Woo03doo/0nOok087oboom0>koo02ioo`0
mool0?7oo03noo/0k?l0jXGoo@21omCoo03^oo/0e?ol0?Woo03boo`0n_ok09_o
o033oo`0nOol0??oo03joo/0POo:ood0k_ol0;[on`3goo/0l_ok003on`21onoo
o@21omCoo03^oo/0e?ol0?Woo03boo`0n_ok09_oo033oo`0nOol0??oo03joo/0
POo:ood0k_ol0;[on`3goo/0l_ok003on`21onooo@21omCoo03^oo/0e?ol0?Wo
o03boo`0n_ok09_oo033oo`0nOol0??oo03joo/0POo:ood0k_ol0;[on`3goo/0
l_ok003on`3[o`3ZQOom087oe?ol0?3onP3Doo/0nOok0??on`3loo/0V_ol0<Co
n`3ioo/0m?ok0?con`21olWoo@3^oo`0^_ol0?Goo03aoo`00?ol087ok_om087o
e?ol0?3onP3Doo/0nOok0??on`3loo/0V_ol0<Con`3ioo/0m?ok0?con`21olWo
o@3^oo`0^_ol0?Goo03aoo`00?ol087ok_om087oe?ol0?3onP3Doo/0nOok0??o
n`3loo/0V_ol0<Con`3ioo/0m?ok0?con`21olWoo@3^oo`0^_ol0?Goo03aoo`0
0?ol0>[o0=:5ood0POoDonD0dool0?Ooo03boo/0oOol09Woo034oo`0mool0??o
n`3moo`0POo8ood0k_ol0;[oo03eoo`0l?og087ok_om087oe?oU0=?oo03goo`0
l_ok0?goo02Ioo`0a?ol0?Ooo03coo/0oOol087ob?om0>koo02joo`0mOol0?3o
m`21onkoo@21omCoi@3Coo`0mool0?;on`3moo`0VOol0<Coo03goo`0look0?go
o021olSoo@3^oo`0^_ol0?Goo03`ooL0j_l0f/_oo@2oood0POoDonH0d_ol0?Oo
o03aoo`0o_ok09Woo034oo`0mool0?;oo03noo/0POo8ood0k_ol0;_on`3doo`0
lOoh0;?oo@2oood0POoDonH0d_ol0?Ooo03aoo`0o_ok09Woo034oo`0mool0?;o
o03noo/0POo8ood0k_ol0;_on`3doo`0lOoh0;?oo@2oood0POoDonH0d_ol0?Oo
o03aoo`0o_ok09Woo034oo`0mool0?;oo03noo/0POo8ood0k_ol0;_on`3doo`0
lOoh0>Wo0=[;ood0_oom087oe?oU0=Con`3goo/0l_ok003on`2Hoo`0aOok0?Oo
n`3coo/00?ok087oaoom0>koo02koo`0lool0?3onP2bood0_oom087oe?oU0=Co
n`3goo/0l_ok003on`2Hoo`0aOok0?Oon`3coo/00?ok087oaoom0>koo02koo`0
lool0?3onP2bood0_oom087oe?oU0=Con`3goo/0l_ok003on`2Hoo`0aOok0?Oo
n`3coo/00?ok087oaoom0>koo02koo`0lool0?3onP3Xo`3Jboom0;ooo@21omCo
i03Eoo`0mOol0?7oo000oo`0Uool0<Goo03eoo`0l_ol003oo021olKoo@3^oo`0
^ool0??on`3aooX0/_om0;ooo@21omCoi03Eoo`0mOol0?7oo000oo`0Uool0<Go
o03eoo`0l_ol003oo021olKoo@3^oo`0^ool0??on`3aooX0/_om0;ooo@21omCo
i03Eoo`0mOol0?7oo000oo`0Uool0<Goo03eoo`0l_ol003oo021olKoo@3^oo`0
^ool0??on`3aooX0j?l0f/_oo@2oood0POoDoo`0l?oi0=Koo03eoo`0l?og09Oo
o035oo`0mOol0?7om`21olKoo@3]oo`0iool0=coo03aoo`0l_oh0;?oo@2oood0
POoDoo`0l?oi0=Koo03eoo`0l?og09Ooo035oo`0mOol0?7om`21olKoo@3]oo`0
iool0=coo03aoo`0l_oh0;?oo@2oood0POoDoo`0l?oi0=Koo03eoo`0l?og09Oo
o035oo`0mOol0?7om`21olKoo@3]oo`0iool0=coo03aoo`0l_oh0>Wo0=:5ood0
POoDoo`0k_ok0=Oon`3doo`0lOoh09Koo036oo/0m?ol0?;on021olGoo@3]oo`0
iool0=coo03aoo`0l_oh087okOom087oe?ol0>kon`3Goo/0m?ol0?7on02Foo`0
a_ok0?Coo03booP0POo5ood0kOol0>Ooo03Loo`0lOol0?;on021ongoo@21omCo
o03^oo/0eook0?Coo03aooP0U_ol0<Kon`3doo`0l_oh087oaOom0>goo03Woo`0
g?ol0?7oo03booP0jOl0gXGoo@21omCoo03]oo/0f?ol0??oo03`ooX0UOol0<Ko
o03coo`0lOoj087oa?om0>goo03Xoo/0k_on0??on`3aoo/0m?of087ok_om087o
e?ol0>gon`3Hoo`0lool0?3onP2Eoo`0a_ol0??oo03aooX0POo4ood0kOol0>So
n`3^ooh0look0?7on`3dooH0POo^ood0POoDoo`0kOok0=Soo03coo`0l?oj09Go
o036oo`0lool0?7onP21olCoo@3]oo`0j?ok0>kooP3coo/0lOok0?ComP3Zo`3Z
QOom087oe?ol0>gon`3Hoo`0look0?7onP2Eoo`0a_ol0??on`3booX0POo4ood0
kOok0>Woo03]ooh0lool0>ooo03eoo/00?ok087okoom087oe?ol0>gon`3Hoo`0
look0?7onP2Eoo`0a_ol0??on`3booX0POo4ood0kOok0>Woo03]ooh0lool0>oo
o03eoo/00?ok087okoom087oe?ol0>gon`3Hoo`0look0?7onP2Eoo`0a_ol0??o
n`3booX0POo4ood0kOok0>Woo03]ooh0lool0>ooo03eoo/00?ok0>_o0>Z5ood0
POoDoo`0k?ol0=Woo03aoo`0l_oh09Koo037oo`0lOol0??on021olGoo@3/oo`0
jOol0>koo@3coo`0kool0?Goo03noo`0POo_ood0POoDoo`0k?ol0=Woo03aoo`0
l_oh09Koo037oo`0lOol0??on021olGoo@3/oo`0jOol0>koo@3coo`0kool0?Go
o03noo`0POo_ood0POoDoo`0k?ol0=Woo03aoo`0l_oh09Koo037oo`0lOol0??o
n021olGoo@3/oo`0jOol0>koo@3coo`0kool0?Goo03noo`0jol0jXGoo@21omCo
o03/oo`0fOol0?7oo03booP0U_ol0<Ooo03aoo`0looh087oaOom0>con`3[oo/0
kool0?Con`3_oo/0mool0?gon`21oo3oo@21omCoo03/oo`0fOol0?7oo03booP0
U_ol0<Ooo03aoo`0looh087oaOom0>con`3[oo/0kool0?Con`3_oo/0mool0?go
n`21oo3oo@21omCoo03/oo`0fOol0?7oo03booP0U_ol0<Ooo03aoo`0looh087o
aOom0>con`3[oo/0kool0?Con`3_oo/0mool0?gon`3/o`3bboom0;ooo@21omCo
o03/oo`0f_ok0?7on`3dooH0Uool0<Son`3aoo/0mOof087oa_om0>_oo03[oo`0
l?oj0?Coo03]oo`0n?ok0?con`2good0_oom087oe?ol0>coo03Joo/0lOok0?Co
mP2Goo`0b?ok0?7on`3eooH0POo6ood0jool0>_oo03`ooX0m?ol0>goo03hoo/0
o?ok0;Ooo@2oood0POoDoo`0k?ol0=[on`3aoo/0m?of09Ooo038oo/0lOok0?Go
mP21olKoo@3[oo`0jool0?3onP3doo`0kOol0?Son`3loo/0kOl18/_oo@2oood0
POoDoo`0k?ol0>_ooP3coo`0kool0?Gon`00oo/0V?ol0=WooP3coo`0kool0?Ko
n`00oo/0POo7ood0jook0>gon`3dooH0m?ol0>goo03hoo`0n_ol0;Ooo@2oood0
POoDoo`0k?ol0>_ooP3coo`0kool0?Gon`00oo/0V?ol0=WooP3coo`0kool0?Ko
n`00oo/0POo7ood0jook0>gon`3dooH0m?ol0>goo03hoo`0n_ol0;Ooo@2oood0
POoDoo`0k?ol0>_ooP3coo`0kool0?Gon`00oo/0V?ol0=WooP3coo`0kool0?Ko
n`00oo/0POo7ood0jook0>gon`3dooH0m?ol0>goo03hoo`0n_ol0>go0B;;ood0
_oom087oe?ol0>coo03[ooh0lool0>ooo03eoo`0o_ol09Soo03Iooh0lool0>oo
o03foo`0o_ol087oaoom0>[on`3_oo/0loof0?Gon`3]oo/0n_ok0?[on`2hood0
_oom087oe?ol0>coo03[ooh0lool0>ooo03eoo`0o_ol09Soo03Iooh0lool0>oo
o03foo`0o_ol087oaoom0>[on`3_oo/0loof0?Gon`3]oo/0n_ok0?[on`2hood0
_oom087oe?ol0>coo03[ooh0lool0>ooo03eoo`0o_ol09Soo03Iooh0lool0>oo
o03foo`0o_ol087oaoom0>[on`3_oo/0loof0?Gon`3]oo/0n_ok0?[on`3^o`4R
boom0;ooo@21omCoo03/oo`0k?om0?Con`3_oo/0mool0?gon`2Ioo`0f_om0?Co
n`3_oo/0n?ol0?gon`21olSoo@3Yoo/0lOok0?;omP3eoo`0jool0?_on`3hoo/0
^Oom0;ooo@21omCoo03/oo`0k?om0?Con`3_oo/0mool0?gon`2Ioo`0f_om0?Co
n`3_oo/0n?ol0?gon`21olSoo@3Yoo/0lOok0?;omP3eoo`0jool0?_on`3hoo/0
^Oom0;ooo@21omCoo03/oo`0k?om0?Con`3_oo/0mool0?gon`2Ioo`0f_om0?Co
n`3_oo/0n?ol0?gon`21olSoo@3Yoo/0lOok0?;omP3eoo`0jool0?_on`3hoo/0
kol16XGoo@21omCoo03/oo`0kOol0?Coo03]oo`0n?ok0?con`2Joo`0fool0?Co
o03]oo`0nOok0?con`21olWoo@3YooT0mOoj0>[oo@3eoo`0jool0?_oo03foo`0
POocood0POoDoo`0k?ol0>goo03doo`0kOol0?Son`3loo/0V_ol0=_oo03doo`0
kOol0?Won`3loo/0POo9ood0jOoi0?GonP3Zood0mOol0>_oo03koo`0m_ol087o
loom087oe?ol0>coo03]oo`0m?ol0>goo03hoo/0o?ok09[oo03Koo`0m?ol0>go
o03ioo/0o?ok087obOom0>Won@3eooX0j_om0?Goo03[oo`0nool0?Koo03_o`4>
QOom087oe?ol0>coo03_ooX0m?ol0>goo03hoo`0n_ol09[oo03MooX0m?ol0>go
o03ioo`0n_ol087obOom0>Son03iooT0jOom0?Kog`3moo/0m_ok087om?om087o
e?ol0>coo03_ooX0m?ol0>goo03hoo`0n_ol09[oo03MooX0m?ol0>goo03ioo`0
n_ol087obOom0>Son03iooT0jOom0?Kog`3moo/0m_ok087om?om087oe?ol0>co
o03_ooX0m?ol0>goo03hoo`0n_ol09[oo03MooX0m?ol0>goo03ioo`0n_ol087o
bOom0>Son03iooT0jOom0?Kog`3moo/0m_ok0?3o0@:5ood0POoDoo`0k?ol0??o
mP3eoo/0kOok0?[on`3joo/0Vool0>7omP3eoo/0kOok0?_on`3joo/0POo:ood0
i_o[0>Soo@3foml0o_ok0?Con`21ooGoo@21omCoo03/oo`0loof0?Gon`3]oo/0
n_ok0?[on`2Koo`0hOof0?Gon`3]oo/0nook0?[on`21ol[oo@3Von/0j?om0?Ko
g`3noo/0m?ok087omOom087oe?ol0>coo03cooH0mOok0>gon`3joo/0n_ok09_o
o03QooH0mOok0>gon`3koo/0n_ok087ob_om0>Koj`3Xood0m_oO0?kon`3doo/0
lOl10XGoo@21omCoo03/oo`0loof0?Goo03[oo`0nook0?Son`2Loo`0hOof0?Go
o03[oo`0o?ok0?Son`21ol_oo@3Uond0ioom0?Kog`3noo`0l_ol087omOom087o
e?ol0>coo03cooH0mOol0>_oo03koo/0n?ok09coo03QooH0mOol0>_oo03loo/0
n?ok087oboom0>Gok@3Wood0m_oO0?koo03boo`0POoeood0POoDoo`0k?ol0??o
mP3eoo`0jool0?_on`3hoo/0W?ol0>7omP3eoo`0jool0?con`3hoo/0POo;ood0
iOo]0>Ooo@3foml0o_ol0?;oo03ao`4:boom0;ooo@21omCoo03/oo`0loof0?Go
o03[oo`0nool0?Koo02Loo`0hOof0?Goo03[oo`0o?ol0?Koo021ol_oo@3Soo40
iOom0?Oog@00oo/0l_ok0;coo@2oood0POoDoo`0k?ol0??omP3eoo`0jool0?_o
o03foo`0W?ol0>7omP3eoo`0jool0?coo03foo`0POo;ood0hooa0>Goo@3gomd0
0?ok0?;on`2lood0_oom087oe?ol0>coo03cooH0mOol0>_oo03koo`0m_ol09co
o03QooH0mOol0>_oo03loo`0m_ol087oboom0>?ol@3Uood0mooM003on`3boo/0
l_l0d/_oo@2oood0POoDoo`0k?ol0>coo@3foml0oOok0?Kon`2MonH0l?om0?Ko
g`3noo/0m_ok087oc?om0>3on03Qood0POobood0_oom087oe?ol0>coo03/ood0
m_oO0?gon`3foo/0WOoV0?3oo@3foml0o_ok0?Kon`21olcoo@3PooP0hOom087o
l_om0;ooo@21omCoo03/oo`0k?om0?Kog`3moo/0m_ok09goiP3`ood0m_oO0?ko
n`3foo/0POo<ood0h?oh0>7oo@2Xo`39boom0;ooo@21omCoo03/oo/0kOom0?Ko
g`3noo/0m?ok09koiP3`ood0m_oO007ooo/0m?ok087ocOom0;Ooo@21oo;oo@2o
ood0POoDoo`0k?ok0>goo@3foml0o_ok0?Con`2NonH0l?om0?Kog`01oook0?Co
n`21olgoo@2good0POobood0_oom087oe?ol0>con`3]ood0m_oO0?kon`3doo/0
W_oV0?3oo@3foml00Ooon`3doo/0POo=ood0]oom0:So0<W;ood0_oom087oe?ol
0>_oo03]ood0m_oO0?koo03boo`0W_oV0?3oo@3foml00Oooo03boo`0POo=ood0
]oom087ol_om0;ooo@21omCoo03[oo`0kOom0?Kog`3noo`0l_ol09koiP3`ood0
m_oO007ooo`0l_ol087ocOom0;Ooo@21oo;oo@2oood0POoDoo`0jool0>goo@3f
oml0o_ol0?;oo02NonH0l?om0?Kog`01oool0?;oo021olgoo@2good0Z?l0[XGo
o@21omCoo03[oo/0k_om0?Oog@00oo/0l_ok09ooiP3`ood0mooG0?;on`21olko
o@2good0POn/ood0POoDoo`0jook0>koo@3gomd00?ok0?;on`2OonH0l?om0?Oo
e`3boo/0POo>ood0]oom087o[?om087oe?ol0>_on`3^ood0mooM003on`3boo/0
WooV0?3oo@3gomL0l_ok087oc_om0;Ooo@2Xo`1DQOom087oX?om087oZOom087o
QOom0;Ooo@21ojcoo@21oj3oo@21ojWoo@21ohGoo@2good0POn/ood0POnPood0
POnYood0POn5ood0]oom0:So05B5ood0POnPood0POnYood0POn5ood0]oom087o
[?om087oX?om087oZOom087oQOom0;Ooo@21ojcoo@21oj3oo@21ojWoo@21ohGo
o@2good0Z?l0E8Goo@21oj3oo@21ojWoo@21ohGoo@2good0POn/ood0POnPood0
POnYood0POn5ood0]oom087o[?om087oX?om087oZOom087oQOom0;Ooo@2Xo`1P
boom0;ooo@21oj3oo@21ojWoo@21ohGoo@2good0POobood0_oom087oX?om087o
ZOom087oQOom0;Ooo@21oo;oo@2oood0POnPood0POnYood0POn5ood0]oom0:So
063;ood0_oom087oX?om087oZOom087oQOom0;Ooo@21oo;oo@2oood0POnPood0
POnYood0POn5ood0]oom087ol_om0;ooo@21oj3oo@21ojWoo@21ohGoo@2good0
Z?l0H<_oo@2oood0POnPood0POnYood0POn5ood0]oom087ol_om0;ooo@21oj3o
o@21ojWoo@21ohGoo@2good0POobood0_oom087oX?om087oZOom087oQOom0;Oo
o@2Xo`1Pboom0;ooo@21oj3oo@21ojWoo@21ohGoo@2good0POobood0_oom087o
X?om087oZOom087oQOom0;Ooo@21oo;oo@2oood0POnPood0POnYood0POn5ood0
]oom0:So05B5ood0POnPood0POnYood0POn5ood0]oom087o[?om087oX?om087o
ZOom087oQOom0;Ooo@21ojcoo@21oj3oo@21ojWoo@21ohGoo@2good0Z?l0E8Go
o@21oj3oo@21ojWoo@21ohGoo@2good0POn/ood0POnPood0POnYood0POn5ood0
]oom087o[?om087oX?om087oZOom087oQOom0;Ooo@2Xo`1DQOom087oX?om087o
ZOom087oQOom0;Ooo@21ojcoo@21oj3oo@21ojWoo@21ohGoo@2good0POn/ood0
POnPood0POnYood0POn5ood0]oom0:So05B5ood0POnPood0POnYood0POn5ood0
]oom087o[?om087oX?om087oZOom087oQOom0;Ooo@21ojcoo@21oj3oo@21ojWo
o@21ohGoo@2good0Z?l0E8Goo@21oj3oo@21ojWoo@21ohGoo@2good0POn/ood0
POnPood0POnYood0POn5ood0]oom087o[?om087oX?om087oZOom087oQOom0;Oo
o@2Xo`1Fboom0;ooo@21oj3oo@21ojWoo@21ohGoo@21ojCoo@2oood0POnPood0
POnYood0POn5ood0POnTood0_oom087oX?om087oZOom087oQOom087of_l0E/_o
o@2oood0POnPood0POnYood0POn5ood0POnTood0_oom087oX?om087oZOom087o
QOom087oY?om0;ooo@21oj3oo@21ojWoo@21ohGoo@21om[o05K;ood0_oom087o
X?om087oZOom087oQOom087oY?om0;ooo@21oj3oo@21ojWoo@21ohGoo@21ojCo
o@2oood0POnPood0POnYood0POn5ood0POoJo`1Fboom0;ooo@21oj3oo@21ojWo
o@21ohGoo@21ojCoo@2oood0POnPood0POnYood0POn5ood0POnTood0_oom087o
X?om087oZOom087oQOom087of_l0CXGoo@21oj3oo@21ojWoo@21ohGoo@21oh7o
g_om087oX?om087oZOom087oQOom087oPOoNood0POnPood0POnYood0POn5ood0
POoJo`12QOom087oPOn1oh7oPOo4ood0POn1omkoo@21oh7oPOn1oh7oa?om087o
POoNood0POn1oh7oPOn1olCoo@21om[o04:5ood0POn1oh7oPOn1olCoo@21oh7o
g_om087oPOn1oh7oPOo4ood0POn1omkoo@21oh7oPOn1oh7oa?om087of_l0@XGo
o@21oh7oPOn1oh7oa?om087oPOoNood0POn1oh7oPOn1olCoo@21oh7og_om087o
POn1oh7oPOo4ood0POoJo`1:boom0;ooo@21oh7oPOn1oh7oa?om087oY?om0;oo
o@21oh7oPOn1oh7oa?om087oY?om0;ooo@21oh7oPOn1oh7oa?om087of_l0B/_o
o@2oood0POn1oh7oPOn1olCoo@21ojCoo@2oood0POn1oh7oPOn1olCoo@21ojCo
o@2oood0POn1oh7oPOn1olCoo@21om[o04[;ood0_oom087oPOn1oh7oPOo4ood0
POnTood0_oom087oPOn1oh7oPOo4ood0POnTood0_oom087oPOn1oh7oPOo4ood0
POoJo`1Fboom0;ooo@21on;oP@3V087oPOn1ookoo@21ojCoo@2oood0POoRoh40
iP21oh7oPOonood0POnTood0_oom087oh_n10>H0POn1oh7oo_om087of_l0CXGo
o@21on;oP@3V087oPOn1ookoo@21oh7og_om087oh_n10>H0POn1oh7oo_om087o
POoNood0POoRoh40iP21oh7oPOonood0POoJo`1DQOom087oh_n10>H0/_n10>L0
POoWood0POn1omkoo@21on;oP@3V0;;oP@3W087oioom087oPOoNood0POoRoh40
iP2boh40i`21onOoo@21om[o05B5ood0POoRoh40iP2boh40i`21onOoo@21oh7o
g_om087oh_n10>H0/_n10>L0POoWood0POn1omkoo@21on;oP@3V0;;oP@3W087o
ioom087of_l0H8Goo@21on;oo021oo3oo02boh40i`21onOoo@21oh7og_om087o
h_ol087ol?ol0;;oP@3W087oioom087oPOoNood0POoRoo`0POo`oo`0/_n10>L0
POoWood0POoJo`1Xboom0;ooo@21on;oo021oo3oo02boh40i`21onOoo@21ojCo
o@2oood0POoRoo`0POo`oo`0/_n10>L0POoWood0POnTood0_oom087oh_ol087o
l?ol0;;oP@3W087oioom087of_l0J<_oo@2oood0POoRoo`0POo`oo`0/_n10>L0
POoWood0POnTood0_oom087oh_ol087ol?ol0;;oP@3W087oioom087oY?om0;oo
o@21on;oo021oo3oo02boh40i`21onOoo@21om[o06S;ood0_oom087oh_ol087o
l?ol0;;oP@3W087oioom087oY?om0;ooo@21on;oo021oo3oo02boh40i`21onOo
o@21ojCoo@2oood0POoRoo`0POo`oo`0/_n10>L0POoWood0POoJo`1Xboom0;oo
o@21on;oo021oo3oo02boh40i`21onOoo@21ojCoo@2oood0POoRoo`0POo`oo`0
/_n10>L0POoWood0POnTood0_oom087oh_ol087ol?ol0;;oP@3W087oioom087o
f_l0H8Goo@21on;oo021oo3oo02boh40i`21onOoo@21oh7og_om087oh_ol087o
l?ol0;;oP@3W087oioom087oPOoNood0POoRoo`0POo`oo`0/_n10>L0POoWood0
POoJo`1VQOom0<[ooP2Loo`0POo`oo`0/_n10>L0POoWood0POn1omkoo@3:ooh0
W?ol087ol?ol0;;oP@3W087oioom087oPOoNood0b_on09coo021oo3oo02boh40
i`21onOoo@21om[o06J5ood0b_ol09koo021oo3oo02boh40i`21onOoo@21oh7o
g_om0<[oo02Noo`0POo`oo`0/_n10>L0POoWood0POn1omkoo@3:oo`0W_ol087o
l?ol0;;oP@3W087oioom087of_l0IXGoo@3:ooT0XOol087ol?ol0;;oP@3W087o
ioom087oPOoNood0b_oi0:7oo021oo3oo02boh40i`21onOoo@21oh7og_om0<[o
n@2Qoo`0POo`oo`0/_n10>L0POoWood0POoJo`1VQOom0<[omP2Too`0POo`oo`0
/_n10>L0POoWood0POn1omkoo@3:ooH0Y?ol087ol?ol0;;oP@3W087oioom087o
POoNood0b_of0:Coo021oo3oo02boh40i`21onOoo@21om[o06k;ood0_oom0<[o
l`2Woo`0POo`oo`0/_n10>L0POoWood0POnTood0_oom0<[ol`2Woo`0POo`oo`0
/_n10>L0POoWood0POnTood0_oom0<[ol`2Woo`0POo`oo`0/_n10>L0POoWood0
POoJo`1^boom0;ooo@3:oo40ZOol087ol?ol0;;oP@3W087oioom087oY?om0;oo
o@3:oo40ZOol087ol?ol0;;oP@3W087oioom087oY?om0;ooo@3:oo40ZOol087o
l?ol0;;oP@3W087oioom087of_l0K/_oo@2oood0b_o^0:coo021oo3oo02boh40
i`21onOoo@21ojCoo@2oood0b_o^0:coo021oo3oo02boh40i`21onOoo@21ojCo
o@2oood0b_o^0:coo021oo3oo02boh40i`21onOoo@21om[o06k;ood0_oom0<[o
j`2_oo`0POo`oo`0/_n10>L0POoYooT0POnVood0_oom0<[oj`2_oo`0POo`oo`0
/_n10>L0POoYooT0POnVood0_oom0<[oj`2_oo`0POo`oo`0/_n10>L0POoYooT0
POoLo`1VQOom0<[oj@2aoo`0POo`oo`0/_n10>L0POoZooH0POn1on;oo@3:onT0
/Ool087ol?ol0;;oP@3W087oj_of087oPOoRood0b_oY0;7oo021oo3oo02boh40
i`21on[omP21omko06J5ood0b_oV0;Coo021oo3oo02boh40i`21on_om021oh7o
hoom0<[oiP2doo`0POo`oo`0/_n10>L0POo[oo@0POn1on?oo@3:onH0]?ol087o
l?ol0;;oP@3W087ojood087ogol0IXGoo@3:on<0]ool087ol?ol0;;oP@3W087o
k?ob087oPOoTood0b_oS0;Ooo021oo3oo02boh40i`21oncolP21oh7oi?om0<[o
h`2goo`0POo`oo`0/_n10>L0POo/oo80POoPo`1VQOom0<[oh02joo`0POo`oo`0
/_n10>L0POo]oo00POn1onGoo@3:on00^_ol087ol?ol0;;oP@3W087okOo`087o
POoUood0b_oP0;[oo021oo3oo02boh40i`21ongol021on7o06k;ood0_oom0<[o
gP2loo`0POo`oo`0/_n10>L0POo]onl0POn/ood0_oom0<[ogP2loo`0POo`oo`0
/_n10>L0POo]onl0POn/ood0_oom0<[ogP2loo`0POo`oo`0/_n10>L0POo]onl0
POoRo`1^boom0;ooo@3:om/0_ool087ol?ol0;;oP@3W087ok_o^087o[?om0;oo
o@3:om/0_ool087ol?ol0;;oP@3W087ok_o^087o[?om0;ooo@3:om/0_ool087o
l?ol0;;oP@3W087ok_o^087oh_l0@_goP@210>40POo`oh40P@210840cP3moh40
P@3Q087ol?n10840P@210<h0oOn10840h@21oo3oP@210840P@3>0012oOn10840
h@21oo3oP@210840P@3>0?goP@210>40POo`oh40P@210840cP3moh40P@3Q087o
l?n10840P@210<h004;moh40P@3Q087ol?n10840P@210<h0oOn10840h@21oo3o
P@210840P@3>0?goP@210>40POo`oh40P@210840cP00@_goP@210>40POo`oh40
P@210840cP3moh40P@3Q087ol?n10840P@210<h0oOn10840h@21oo3oP@210840
P@3>001LPOo:omP0`_ol087ol?ol0;;oP@3W087okoo/087oPOn/omP0`_ol087o
l?ol0;;oP@3W087okoo/087oPOn/omP0`_ol087ol?ol0;;oP@3W087okoo/087o
hol0G87ob_oK0;ooo021oo3oo02boh40i`21onkok@21oh7o[?oK0;ooo021oo3o
o02boh40i`21onkok@21oh7o[?oK0;ooo021oo3oo02boh40i`21onkok@21on?o
06;;ood0Q?oN0;coo021oo3oo02boh40i`21onkokP21ojcoo@24omh0_?ol087o
l?ol0;;oP@3W087ok_o^087o[?om08CogP2loo`0POo`oo`0/_n10>L0POo^onh0
POoRo`1Rboom08Coh@2ioo`0POo`oo`0/_n10>L0POo^onh0POn/ood0Q?oQ0;Wo
o021oo3oo02boh40i`21onkokP21ojcoo@24on40^Ool087ol?ol0;;oP@3W087o
k_o^087oh_l0H/_oo@24on<0]ool087ol?ol0;;oP@3W087okOo`087oZoom08Co
h`2goo`0POo`oo`0/_n10>L0POo]oo00POn[ood0Q?oS0;Ooo021oo3oo02boh40
i`21ongol021on7o06;;ood0Q?oV0;Coo021oo3oo02boh40i`21oncol@21oj_o
o@24onH0]?ol087ol?ol0;;oP@3W087ok?oa087oZoom08CoiP2doo`0POo`oo`0
/_n10>L0POo/oo40POoQo`1LPOo:onT0/Ool087ol?ol0;;oP@3W087ok?ob087o
POnYonT0/Ool087ol?ol0;;oP@3W087ok?ob087oPOnYonT0/Ool087ol?ol0;;o
P@3W087ok?ob087oh?l0G87ob_o[0:ooo021oo3oo02boh40i`21oncol`21oh7o
Z?o[0:ooo021oo3oo02boh40i`21oncol`21oh7oZ?o[0:ooo021oo3oo02boh40
i`21oncol`21omoo05b1ol[okP2/oo`0POo`oo`0/_n10>L0POoZooL0POn1ojKo
kP2/oo`0POo`oo`0/_n10>L0POoZooL0POn1ojKokP2/oo`0POo`oo`0/_n10>L0
POoZooL0POoMo`1LPOo:oo40ZOol087ol?ol0;;oP@3W087oioom087oPOnSoo40
ZOol087ol?ol0;;oP@3W087oioom087oPOnSoo40ZOol087ol?ol0;;oP@3W087o
ioom087of_l0G87ob_oc0:Ooo021oo3oo02boh40i`21onOoo@21oh7oXooc0:Oo
o021oo3oo02boh40i`21onOoo@21oh7oXooc0:Ooo021oo3oo02boh40i`21onOo
o@21om[o06;;ood0Q?of0:Coo021oo3oo02boh40i`21onOoo@21ojCoo@24ooH0
Y?ol087ol?ol0;;oP@3W087oioom087oY?om08ComP2Too`0POo`oo`0/_n10>L0
POoWood0POoJo`1Rboom08Con@2Qoo`0POo`oo`0/_n10>L0POoWood0POnTood0
Q?oi0:7oo021oo3oo02boh40i`21onOoo@21ojCoo@24ooT0XOol087ol?ol0;;o
P@3W087oioom087of_l0H/_oo@24oo`0W_ol087ol?ol0;;oP@3W087oioom087o
Y?om08Coo02Noo`0POo`oo`0/_n10>L0POoWood0POnTood0Q?ol09koo021oo3o
o02boh40i`21onOoo@21om[o06;;ood0Q?on09coo021oo3oo02boh40i`21onOo
o@21ojCoo@24ooh0W?ol087ol?ol0;;oP@3W087oioom087oY?om08CooP2Loo`0
POo`oo`0/_n10>L0POoWood0POoJo`1FPOn1on;oo021oo3oo02boh40i`21onOo
o@21oh7oPOnkoo`0POo`oo`0/_n10>L0POoWood0POn1oh7o^ool087ol?ol0;;o
P@3W087oioom087of_l0KZkoo03Oooh0_oon0:Coo021oo3oo02boh40i`21onOo
o@21ohOoo03Oooh0_oon0:Coo021oo3oo02boh40i`21onOoo@21ohOoo03Oooh0
_oon0:Coo021oo3oo02boh40i`21onOoo@21om[o06j^oo`0h?on0;gooP2Uoo`0
POo`oo`0/_n10>L0POoWood0POn7oo`0h?on0;gooP2Uoo`0POo`oo`0/_n10>L0
POoWood0POn7oo`0h?on0;gooP2Uoo`0POo`oo`0/_n10>L0POoWood0POoJo`1^
[_ol0>7oo@3;oo`0n?om0:KoP@3V0;;oP@3W087oioom087oQool0>7oo@3;oo`0
n?om0:KoP@3V0;;oP@3W087oioom087oQool0>7oo@3;oo`0n?om0:KoP@3V0;;o
P@3W087oioom087of_l0N/_oo@3Xoo`0hOon0<[oo03gooh0Y_n10>H0/_n10>L0
POoWood0POnTood0j?ol0>7ooP3:oo`0moon0:KoP@3V0;;oP@3W087oioom087o
Y?om0>Soo03Qooh0b_ol0?OooP2Voh40iP2boh40i`21onOoo@21om[o07C;ood0
j?ol0>;oo@3:oo`0moom0:OoP@3V087oPOn1ookoo@21ojCoo@3Xoo`0h_om0<[o
o03good0Yon10>H0POn1oh7oo_om087oY?om0>Soo03Rood0b_ol0?Ooo@2Woh40
iP21oh7oPOonood0POoJo`1Xboom0<Goo@39oo`0m_om0:SoP@3V087oPOn1ooko
o@21ojCoo@35ood0bOol0?Koo@2Xoh40iP21oh7oPOonood0POnTood0aOom0<Wo
o03food0Z?n10>H0POn1oh7oo_om087of_l0G<_oo@35ood0bOol0?Koo@21oh7o
POn1oh[oo@21ojCoo@35ood0bOol0?Koo@21oh7oPOn1oh[oo@21ojCoo@35ood0
bOol0?Koo@21oh7oPOn1oh[oo@21om[o05B<ood0b?ol0?Goo@21oh7oPOn1oh_o
o@21oh7oiOom0<Soo03eood0POn1oh7oPOn;ood0POn1onGoo@38oo`0mOom087o
POn1oh7oRoom087of_l0E8coo@38oo`0mOom087oPOn1oh7oRoom087oPOoUood0
b?ol0?Goo@21oh7oPOn1oh_oo@21oh7oiOom0<Soo03eood0POn1oh7oPOn;ood0
POoJo`1DSOom0<Ooo03dood0POn1oh7oPOn<ood0POn1onKoo@37oo`0m?om087o
POn1oh7oS?om087oPOoVood0aool0?Coo@21oh7oPOn1ohcoo@21om[o05B=ood0
aool0?Coo@21oh7oPOn1ohcoo@21oh7oi_om0<Ooo03dood0POn1oh7oPOn<ood0
POn1onKoo@37oo`0m?om087oPOn1oh7oS?om087of_l0P<_oo@3Xoo`0i_om0?Ko
n`3coo/0kooc0?Soo@21oh7oPOn1ohgoo@21ojCoo@3Xoo`0i_om0?Kon`3coo/0
kooc0?Soo@21oh7oPOn1ohgoo@21ojCoo@3Xoo`0i_om0?Kon`3coo/0kooc0?So
o@21oh7oPOn1ohgoo@21om[o083;ood0j?ol0>Koo@3foo/0lool0>kol`3hood0
POn1oh7oPOn=ood0POnTood0j?ol0>Koo@3foo/0lool0>kol`3hood0POn1oh7o
POn=ood0POnTood0j?ol0>Koo@3foo/0lool0>kol`3hood0POn1oh7oPOn=ood0
POoJo`20boom0>Soo03Woo`0mOok0?Gon`3^oo<0n?ol087oPOn1oh7oS_om087o
Y?om0>Soo03Woo`0mOok0?Gon`3^oo<0n?ol087oPOn1oh7oS_om087oY?om0>So
o03Woo`0mOok0?Gon`3^oo<0n?ol087oPOn1oh7oS_om087of_l0P<_oo@3Xoo`0
ioom0??oo03foo/0kOoc0?Soo021oh7oPOn1ohkoo@21ojCoo@3Xoo`0ioom0??o
o03foo/0kOoc0?Soo021oh7oPOn1ohkoo@21ojCoo@3Xoo`0ioom0??oo03foo/0
kOoc0?Soo021oh7oPOn1ohkoo@21om[o07B^oo`0ioom0??on`3hoo/0j?ol0?;o
o@21oh7oPOn1ohkoo@21ohOoo03Wood0look0?Son`3Xoo`0l_om087oPOn1oh7o
S_om087oQool0>Ooo@3coo/0n?ok0>Soo03bood0POn1oh7oPOn>ood0POoJo`1d
[_ol0>Soo03boo/0nOok0>Soo03boo`0POn1oh7oPOn?ood0POn7oo`0j?ol0?;o
n`3ioo/0j?ol0?;oo021oh7oPOn1ohooo@21ohOoo03Xoo`0l_ok0?Won`3Xoo`0
l_ol087oPOn1oh7oSoom087of_l0M:koo03Xoo`0lOol0?[on`3Woo`0l_ol087o
POn1oh7oSoom087oQool0>Soo03aoo`0n_ok0>Ooo03boo`0POn1oh7oPOn?ood0
POn7oo`0j?ol0?7oo03joo/0iool0?;oo021oh7oPOn1ohooo@21om[o07B^oo`0
j?ol0?7on`3loo/0i_ol0?;oo021oh7oPOn1ohooo@21ohOoo03Xoo`0lOok0?co
n`3Voo`0l_ol087oPOn1oh7oSoom087oQool0>Soo03aoo/0o?ok0>Koo03boo`0
POn1oh7oPOn?ood0POoJo`20[_ol0>Soo@3_oo/0oOol0>Goo03aood0POn1olGo
0021oh7oc?om087oQool0>Soo@3_oo/0oOol0>Goo03aood0POn1olGo0021oh7o
c?om087oQool0>Soo@3_oo/0oOol0>Goo03aood0POn1olGo0021oh7oc?om087o
f_l0Sl_oo@3Xoo`0jOol0>koo03noo/0iOol0?7oo021oh7oaol10021oh7oc?om
087oY?om0>Soo03Yoo`0k_ol0?kon`3Uoo`0lOol087oPOo7o`40087oPOo<ood0
POnTood0j?ol0>Woo03^oo`0o_ok0>Goo03aoo`0POn1olOo0@00POn1olcoo@21
om[o08c;ood0j?ol0>Woo03^oo/00?ok0>Coo03aoo`0POn1olSooP21oh7oc?om
087oY?om0>Soo03Yoo`0k_ok003on`3Too`0lOol087oPOo8ooh0POn1olcoo@21
ojCoo@3Xoo`0jOol0>kon`00oo/0i?ol0?7oo021oh7ob?on087oPOo<ood0POoJ
o`2<boom0>Soo03Yoo`0kOol003oo03Soo`0lOol087oPOo9ood0POn1olcoo@21
ojCoo@3Xoo`0jOol0>goo000oo`0hool0?7oo021oh7obOom087oPOo<ood0POnT
ood0j?ol0>Woo03]oo`00?ol0>?oo03aoo`0POn1olWoo@21oh7oc?om087of_l0
P<_oo@3Xoo`0jOol0>com`3Soo`0lOol087oPOo:oo`0POn1olcoo@21ojCoo@3X
oo`0jOol0>com`3Soo`0lOol087oPOo:oo`0POn1olcoo@21ojCoo@3Xoo`0jOol
0>com`3Soo`0lOol087oPOo:oo`0POn1olcoo@21om[o07B^oo`0jOol0>con03R
oo`0lOol087oPOo;oo/0POn1olcoo@21ohOoo03Yoo`0k?oh0>;oo03aoo`0POn1
ol_on`21oh7oc?om087oQool0>Woo03/ooP0h_ol0?7oo021oh7obook087oPOo<
ood0POoJo`20[_ol0?;ooP3koo`0jooj0>7oo03aoo`0POn1olconP21oh7oc?om
087oQool0?;ooP3koo`0jooj0>7oo03aoo`0POn1olconP21oh7oc?om087oQool
0?;ooP3koo`0jooj0>7oo03aoo`0POn1olconP21oh7oc?om087of_l0P:koo03b
ooh0nool0>_onP3Qoo`0lOol087oPOo=ooT0POn1olcoo@21ohOoo03booh0nool
0>_onP3Qoo`0lOol087oPOo=ooT0POn1olcoo@21ohOoo03booh0nool0>_onP3Q
oo`0lOol087oPOo=ooT0POn1olcoo@21om[o082^oo`0loom0?_oo03/ooP0h_ol
0?7oo021oh7oc_oh087oPOo<ood0POn7oo`0loom0?_oo03/ooP0h_ol0?7oo021
oh7oc_oh087oPOo<ood0POn7oo`0loom0?_oo03/ooP0h_ol0?7oo021oh7oc_oh
087oPOo<ood0POoJo`2<boom0>Soo03doo`0nool0>con03Roo`0lOol087oPOo?
ooL0POn1olcoo@21ojCoo@3Xoo`0m?ol0?_oo03/ooP0h_ol0?7oo021oh7ocoog
087oPOo<ood0POnTood0j?ol0?Coo03koo`0k?oh0>;oo03aoo`0POn1oloom`21
oh7oc?om087of_l0S<_oo@3Xoo`0m_oj0?_oo03]ooH0hool0?7oo021oh7od?of
087oPOo<ood0POnTood0j?ol0?KonP3koo`0kOof0>?oo03aoo`0POn1om3omP21
oh7oc?om087oY?om0>Soo03fooX0nool0>gomP3Soo`0lOol087oPOo@ooH0POn1
olcoo@21om[o09S;ood0j?ol0?[omP3koo`0k_ok003on`3Too`0lOol087oPOoA
ooD0POn1olcoo@21ojCoo@3Xoo`0n_of0?_oo03^oo/00?ok0>Coo03aoo`0POn1
om7om@21oh7oc?om087oY?om0>Soo03jooH0nool0>kon`00oo/0i?ol0?7oo021
oh7odOoe087oPOo<ood0POoJo`2Hboom0>Soo03jooH0nool0>koo03noo`0i?ol
0?7oo021oh7od_od087oPOo<ood0POnTood0j?ol0?[omP3koo`0k_ol0?koo03T
oo`0lOol087oPOoBoo@0POn1olcoo@21ojCoo@3Xoo`0n_of0?_oo03^oo`0o_ol
0>Coo03aoo`0POn1om;om021oh7oc?om087of_l0S:koo03jooH0nool0>ooo03m
oo/0iOol0?7oo021oh7odooc087oPOo<ood0POn7oo`0n_of0?_oo03_oo`0oOok
0>Goo03aoo`0POn1om?ol`21oh7oc?om087oQool0?[omP3koo`0kool0?gon`3U
oo`0lOol087oPOoCoo<0POn1olcoo@21om[o08b^oo`0loom0?[oo@3`oo/0o?ok
0>Koo03aood0POn1om?olP21oh7oc?om087oQool0??oo@3jood0l?ok0?con`3V
oo`0lOom087oPOoCoo80POn1olcoo@21ohOoo03cood0n_om0?3on`3loo/0i_ol
0?7oo@21oh7odoob087oPOo<ood0POoJo`2<[_ol0??oo@3joo`0lOol0?[oo03V
oo`0l_ol087oPOoDoo40POn1olcoo@21ohOoo03cood0n_ol0?7oo03joo`0i_ol
0?;oo021oh7oe?oa087oPOo<ood0POn7oo`0loom0?[oo03aoo`0n_ol0>Koo03b
oo`0POn1omCol@21oh7oc?om087of_l0S:koo03cood0n_ol0?;on`3joo/0iool
0?;oo021oh7oeOo`087oPOo<ood0POn7oo`0loom0?[oo03boo/0n_ok0>Ooo03b
oo`0POn1omGol021oh7oc?om087oQool0??oo@3joo`0l_ok0?[on`3Woo`0l_ol
087oPOoEoo00POn1olcoo@21om[o09S;ood0j?ol0??oo@3joo`0look0?Son`3X
oo`0l_ol087oPOoFonl0POn1olcoo@21ojCoo@3Xoo`0loom0?[oo03coo/0n?ok
0>Soo03boo`0POn1omKok`21oh7oc?om087oY?om0>Soo03cood0n_ol0??on`3h
oo/0j?ol0?;oo021oh7oe_o_087oPOo<ood0POoJo`2Tboom0>Soo03cood0nOom
0??oo03foo`0n?ol0?Kon`3cood0POn1omKokP21oh7oc?om087oY?om0>Soo03c
ood0nOom0??oo03foo`0n?ol0?Kon`3cood0POn1omKokP21oh7oc?om087oY?om
0>Soo03cood0nOom0??oo03foo`0n?ol0?Kon`3cood0POn1omKokP21oh7oc?om
087of_l0Y<_oo@3Xoo`0loom0?Woo03eoo/0m_ok0?Woo03fooL0moom087oPOoG
ond0POn1olcoo@21ojCoo@3Xoo`0loom0?Woo03eoo/0m_ok0?Woo03fooL0moom
087oPOoGond0POn1olcoo@21ojCoo@3Xoo`0loom0?Woo03eoo/0m_ok0?Woo03f
ooL0moom087oPOoGond0POn1olcoo@21om[o0:C;ood0j?ol0??oo@3ioo`0m_ok
0?Con`3joo`0mOoh0?Soo021oh7of?o/087oPOo<ood0POnTood0j?ol0??oo@3i
oo`0m_ok0?Con`3joo`0mOoh0?Soo021oh7of?o/087oPOo<ood0POnTood0j?ol
0??oo@3ioo`0m_ok0?Con`3joo`0mOoh0?Soo021oh7of?o/087oPOo<ood0POoJ
o`2H[_ol0??oo@3hood0m_ol0?;oo03joo`0m?oi0?Soo@21oh7of?o[087oPOo<
ood0POn7oo`0loom0?Soo@3foo`0l_ol0?[oo03dooT0n?om087oPOoHon/0POn1
olcoo@21ohOoo03cood0n?om0?Koo03boo`0n_ol0?Con@3hood0POn1omSoj`21
oh7oc?om087of_l0V:koo03cood0n?om0?Oon`3boo/0nool0??onP3hood0POn1
omWojP21oh7oc?om087oQool0??oo@3hood0mook0?;on`3koo`0looj0?Soo@21
oh7ofOoZ087oPOo<ood0POn7oo`0loom0?Soo@3goo/0l_ok0?_oo03cooX0n?om
087oPOoIonX0POn1olcoo@21om[o06bKood0moom0=GooP3Tood0POn1omWoj@21
oh7oc?om087oPOodood0moom0=GooP3Tood0POn1omWoj@21oh7oc?om087oPOod
ood0moom0=GooP3Tood0POn1omWoj@21oh7oc?om087of_l0K9_oo@3good0eOon
0>Coo@21oh7of_oX087oPOo<ood0POn1ooCoo@3good0eOon0>Coo@21oh7of_oX
087oPOo<ood0POn1ooCoo@3good0eOon0>Coo@21oh7of_oX087oPOo<ood0POoJ
o`1/Voom0?Koo@3Fooh0iOom087oPOoJonL0POn1olcoo@21oh7om?om0?Koo@3F
ooh0iOom087oPOoJonL0POn1olcoo@21oh7om?om0?Koo@3Fooh0iOom087oPOoJ
onL0POn1olcoo@21om[o07C;ood0eOom0?Koo@3Fooh0iOom087oPOoKonH0POn1
olcoo@21ojCoo@3Eood0m_om0=KooP3Uood0POn1om_oiP21oh7oc?om087oY?om
0=Goo@3food0e_on0>Goo@21oh7ofooV087oPOo<ood0POoJo`1dboom0=Goo@3e
ood0f?on0>Goo@21oh7ofooU087oPOo<ood0POnTood0eOom0?Goo@3Hooh0iOom
087oPOoKonD0POn1olcoo@21ojCoo@3Eood0mOom0=SooP3Uood0POn1om_oi@21
oh7oc?om087of_l0M<_oo@3Eood0mOom0=SooP3Uood0POn1omcoi021oh7oc?om
087oY?om0=Goo@3eood0f?on0>Goo@21oh7og?oT087oPOo<ood0POnTood0eOom
0?Goo@3Hooh0iOom087oPOoLon@0POn1olcoo@21om[o07C;ood0eOom0?Coo@3J
ood0i_om087oPOoLon<0POn1olcoo@21ojCoo@3Eood0m?om0=[oo@3Vood0POn1
omcoh`21oh7oc?om087oY?om0=Goo@3dood0f_om0>Koo@21oh7og?oS087oPOo<
ood0POoJo`1/Voom0??ooP3Jooh0iOon087oPOoLon80POn1olcoo@21oh7om?om
0??ooP3Jooh0iOon087oPOoLon80POn1olcoo@21oh7om?om0??ooP3Jooh0iOon
087oPOoLon80POn1olcoo@21om[o06bKood0loom0=_o003Tood0POn1omgoh@21
oh7oc?om087oPOodood0loom0=_o003Tood0POn1omgoh@21oh7oc?om087oPOod
ood0loom0=_o003Tood0POn1omgoh@21oh7oc?om087of_l0H9_oo@3booh0_Oon
087oPOoMon00POn1olcoo@21oh7om?om0?;ooP2mooh0POn1omgoh021oh7oc?om
087oPOodood0l_on0;gooP21oh7ogOoP087oPOo<ood0POoJo`1PVoom0?7ooP2o
ooh0POn1omWoh`21oh7oc?om087oPOodood0lOon0;oooP21oh7ofOoS087oPOo<
ood0POn1ooCoo@3aooh0_oon087oPOoIon<0POn1olcoo@21om[o05W;ood0eOom
087oPOn1o`7oonD0POn1olcoo@21ojCoo@3Eood0POn1oh7o0Oooi@21oh7oc?om
087oY?om0=Goo@21oh7oPOl1oooU087oPOo<ood0POoJo`1:boom087oPOn1olco
j021oh7oc?om087oY?om087oPOn1olcoj021oh7oc?om087oY?om087oPOn1olco
j021oh7oc?om087of_l0B/_oo@21oh7oPOo:onX0POn1olcoo@21ojCoo@21oh7o
POo:onX0POn1olcoo@21ojCoo@21oh7oPOo:onX0POn1olcoo@21om[o04[;ood0
POn1oh7oaoo]087oPOo<ood0POnTood0POn1oh7oaoo]087oPOo<ood0POnTood0
POn1oh7oaoo]087oPOo<ood0POoJo`12POn1oh7oRoo_087oPOo<ood0POn1oh7o
POn1onCok`21oh7oc?om087oPOn1oh7oPOoTonl0POn1olcoo@21om[o04:1oh7o
POn8oo80POn1olcoo@21oh7oPOn1oh7ohOob087oPOo<ood0POn1oh7oPOn1on7o
lP21oh7oc?om087of_l0@X7oPOn1ohWol@21oh7oc?om087oPOn1oh7oPOoRoo40
POn1olcoo@21oh7oPOn1oh7oh_oa087oPOo<ood0POoJo`1APOn1oh7oROom007o
ooL0POn1olcoo@21oh7oPOn1oh7oh_om007oooL0POn1olcoo@21oh7oPOn1oh7o
h_om007oooL0POn1olcoo@21om[o05K;ood0POn1oh7o`oom0?gon@21oh7oc?om
087oY?om087oPOn1ol?oo@3mooT0POn1olcoo@21ojCoo@21oh7oPOo3ood0oOoi
087oPOo<ood0POoJo`1Fboom087oPOn1olCoo@3ioo`0POn1olcoo@21ojCoo@21
oh7oPOo4ood0nOol087oPOo<ood0POnTood0POn1oh7oa?om0?Woo021oh7oc?om
087of_l0FL_oo@21oh7oPOo4ood0m_l10021oh7oc?om087oY?om087oPOn1olCo
o@3fo`40087oPOo<ood0POnTood0POn1oh7oa?om0?Ko0@00POn1olcoo@21om[o
04[;ood0POn1oh7oa?on087oPOnnood0POnTood0POn1oh7oa?on087oPOnnood0
POnTood0POn1oh7oa?on087oPOnnood0POoJo`12POn1oh7oRoom087oPOnnood0
POn1oh7oPOn1onCoo@21oh7o__om087oPOn1oh7oPOoTood0POn1okkoo@21om[o
04:1oh7oPOn;ood0POn1okkoo@21oh7oPOn1oh7oi?om087oPOnnood0POn1oh7o
POn1onCoo@21oh7o__om087of_l0@X7oPOn1oh_ooP21oh7o_Oom087oPOn1oh7o
POoTooh0POn1okgoo@21oh7oPOn1oh7oi?on087oPOnmood0POoJo`12POn1oh7o
S?om087oPOnmood0POn1oh7oPOn1onGoo@21oh7o_Oom087oPOn1oh7oPOoUood0
POn1okgoo@21om[o04:1oh7oPOn<ood0POn1okgoo@21oh7oPOn1oh7oiOom087o
POnmood0POn1oh7oPOn1onGoo@21oh7o_Oom087of_l0B/_oo@21oh7oPOo6ooh0
POn1okcoo@21ojCoo@21oh7oPOo6ooh0POn1okcoo@21ojCoo@21oh7oPOo6ooh0
POn1okcoo@21om[o04[;ood0POn1oh7oa_on087oPOnlood0POnTood0POn1oh7o
a_on087oPOnlood0POnTood0POn1oh7oa_on087oPOnlood0POoJo`1:boom087o
POn1olOoo@21oh7o_?om087oY?om087oPOn1olOoo@21oh7o_?om087oY?om087o
POn1olOoo@21oh7o_?om087of_l0B/_oo@21oh7oPOo7ooh0POn1ok_oo@21ojCo
o@21oh7oPOo7ooh0POn1ok_oo@21ojCoo@21oh7oPOo7ooh0POn1ok_oo@21om[o
04:1oh7oPOn=ooh0POn1ok_oo@21oh7oPOn1oh7oi_on087oPOnkood0POn1oh7o
POn1onKooP21oh7o^oom087of_l0Hh7oPOn1ohkoo@3Koo`0hol1003=oo/0POo0
ood0POn1oh7oPOn1onOoo@3Koo`0hol1003=oo/0POo0ood0POn1oh7oPOn1onOo
o@3Koo`0hol1003=oo/0POo0ood0POoJo`1PPOn1oh7oS_on0=[oo03Tooh0c_oi
087o`Oom087oPOn1oh7oPOoWooh0f_ol0>CooP3>ooT0POo1ood0POn1oh7oPOn1
onOooP3Joo`0i?on0<kon@21ol7oo@21om[o0621oh7oPOn>ooh0f_ol0>Goo@3>
ooT0POo1ood0POn1oh7oPOn1onOooP3Joo`0iOom0<kon@21ol7oo@21oh7oPOn1
oh7oioon0=[oo03Uood0c_oi087o`Oom087of_l0J<_oo@21oh7oPOo9ood0f_ol
0>GooP3=ooT0POo1ood0POnTood0POn1oh7obOom0=[oo03Uooh0cOoi087o`Oom
087oY?om087oPOn1olWoo@3Joo`0iOon0<gon@21ol7oo@21om[o06S;ood0POn1
oh7ob_om0=Woo03Uooh0c_og087o`_om087oY?om087oPOn1ol[oo@3Ioo`0iOon
0<kom`21ol;oo@21ojCoo@21oh7oPOo:ood0fOol0>GooP3>ooL0POo2ood0POoJ
o`1Vboom087oPOn1ol[oo03Joo`0i_on0<gom`21oocoR021omooo@21oh7oPOo:
oo`0f_ol0>KooP3=ooL0POolohP0POoOood0POn1oh7ob_ol0=[oo03Vooh0cOog
087oo?n809Go06K;ood0POn1oh7ob_ol0=[oo03Vooh0cOog087oo?n8087ogoom
087oPOn1ol[oo03Joo`0i_on0<gom`21oocoR021omooo@21oh7oPOo:oo`0f_ol
0>KooP3=ooL0POolohP0UOl0IX7oPOn1oi3oo03Joo`0i_on0<kon`00oo`0POom
ohP0POn1oh7oPOnToo`0f_ol0>KooP3>oo/00?ol087ooOn8087oPOn1oh7oY?ol
0=[oo03Vooh0c_ok003oo021oogoR02Eo`1YPOn1oh7oT?ol0=[oo03Vooh0c_ol
007ooo`0POomohP0POn1oh7oPOnToo`0f_ol0>KooP3>oo`00Oooo021oogoR021
oh7oPOn1ojCoo03Joo`0i_on0<koo001oool087ooOn809Go06V1oh7oPOn@oo`0
f_ol0>Koo03@oo`00Ooon`21ookoR021oh7oPOn1ojCoo03Joo`0i_ol0=3oo001
oook087oo_n8087oPOn1oh7oY?ol0=[oo03Voo`0d?ol007ooo/0POonohP0UOl0
IX7oPOn1oi3oo03Joo`0i_ol0=7on`3noo`0POonohP0POn1oh7oPOnToo`0f_ol
0>Koo03Aoo/0o_ol087oo_n8087oPOn1oh7oY?ol0=[oo03Voo`0dOok0?koo021
ookoR02Eo`24boom087oPOn1ol[oo03Joo`0i_ol0=7oo03moo`0m?ok0??on`2U
ohP0POoOood0POn1oh7ob_ol0=[oo03Voo`0dOol0?goo03doo/0look0:GoR021
omooo@21oh7oPOo:oo`0f_ol0>Koo03Aoo`0oOol0?Con`3coo/0YOn809Go08C;
ood0POn1oh7ob_ol0=[oo03Voo`0dOol0?gon`3eoo/0lool0:CoR021omooo@21
oh7oPOo:oo`0f_ol0>Koo03Aoo`0oOok0?Gon`3coo`0Y?n8087ogoom087oPOn1
ol[oo03Joo`0i_ol0=7oo03moo/0mOok0??oo02TohP0UOl0Q<_oo@21oh7oPOo:
oo`0f_ol0>Koo03Boo`0nool0?Con`3eoo/0Y?n8087ogoom087oPOn1ol[oo03J
oo`0i_ol0=;oo03koo`0m?ok0?Gon`2TohP0POoOood0POn1oh7ob_ol0=[oo03V
oo`0d_ol0?_oo03doo/0mOok0:CoR02Eo`1hboom087oPOn1ol[oo03Joo`0/_ol
0?_oo03coo`0m_ok0:?oR021omooo@21oh7oPOo:oo`0f_ol0;;oo03koo`0lool
0?Kon`2SohP0POoOood0POn1oh7ob_ol0=[oo02boo`0nool0??oo03foo/0Xon8
09Go06b1oh7oPOn@oo`0f_ol0;?on`3koo/0m?ok0?Son`2RohP0POn1oh7oPOnT
oo`0f_ol0;?on`3koo/0m?ok0?Son`2RohP0POn1oh7oPOnToo`0f_ol0;?on`3k
oo/0m?ok0?Son`2RohP0UOl0K87oPOn1oi3oo03Joo`0/ool0?Woo03coo/0nOok
0:;oR021oh7oPOn1ojCoo03Joo`0/ool0?Woo03coo/0nOok0:;oR021oh7oPOn1
ojCoo03Joo`0/ool0?Woo03coo/0nOok0:;oR02Eo`1/POn1oh7oT?ol0=[oo02c
oo`0nOol0?;oo03joo/0POn1oh7oPOn1oh7obool0=[oo02coo`0nOol0?;oo03j
oo/0POn1oh7oPOn1oh7obool0=[oo02coo`0nOol0?;oo03joo/0POn1okco06b1
oh7oPOn@oo`0f_ol0;Con`3ioo/0look0?con`21oh7oPOn1oh7oPOo:oo`0f_ol
0;Con`3ioo/0look0?con`21oh7oPOn1oh7oPOo:oo`0f_ol0;Con`3ioo/0look
0?con`21oh7o^ol0K87oPOn1oi3oo03Joo`0]?ol0?Ooo03boo/0oOol087oPOn1
oh7oPOn1olWoo03Joo`0]?ol0?Ooo03boo/0oOol087oPOn1oh7oPOn1olWoo03J
oo`0]?ol0?Ooo03boo/0oOol087oPOnjo`1dboom087oPOn1ol[oo03Joo`0]?ol
0?Ooo03aoo`0o_ok087oPOn4ood0POn1oh7ob_ol0=[oo02doo`0mool0?7oo03n
oo/0POn1ohCoo@21oh7oPOo:oo`0f_ol0;Coo03goo`0lOol0?kon`21oh7o^_l0
M<_oo@21oh7oPOo:oo`0f_ol0;Gon`3goo/0l_ok003on`21oh7oPoom087oPOn1
ol[oo03Joo`0]Ook0?Oon`3boo/00?ok087oPOn3ood0POn1oh7ob_ol0=[oo02e
oo/0mook0?;on`00oo/0POn1okWo07C;ood0POn1oh7ob_ol0=[oo02eoo`0mOol
0?7oo000oo`0POn1oh;oo@21oh7oPOo:oo`0f_ol0;Goo03eoo`0lOol003oo021
oh7oP_om087oPOn1ol[oo03Joo`0]Ool0?Goo03aoo`00?ol087oPOnho`1Xboom
087oPOn1ol[oo03Joo`0]Ool0?Goo03`ooL0POn1oh;oo@21oh7oPOo:oo`0f_ol
0;Goo03eoo`0l?og087oPOn2ood0POn1oh7ob_ol0=[oo02eoo`0mOol0?3om`21
oh7o^?l0Nh7oPOn1oi3oo03Joo`0gOl1003booX0l_ok0?Coo03aooP0POn1oh7o
POn1oh7oa_ol0=[oo03Mo`400?;onP3boo/0m?ol0?7on021oh7oPOn1oh7oPOo6
oo`0f_ol0=go0@00l_oj0?;on`3doo`0lOoh087oPOngo`1hPOn1oh7oT?ol0=[o
o03Nooh0m?of0?Coo03coo`0l?oj087oPOn1oh7oPOn1olGoo03Joo`0g_on0?Co
mP3doo`0lool0?3onP21oh7oPOn1oh7oPOo5oo`0f_ol0=kooP3dooH0m?ol0??o
o03`ooX0POn1okKo07R1oh7oPOn@oo`0f_ol0=kooP3eoo@0mOol0??on`3aooX0
Von8087oPOn1oh7oY?ol0=[oo03Nooh0mOod0?Goo03coo/0lOoj09_oR021oh7o
POn1ojCoo03Joo`0g_on0?Gom03eoo`0look0?7onP2KohP0UOl0Q87oPOn1oi3o
o03Joo`0goom0?Koo03loo`0mool0?7oo03booP0W?n8087oPOn1oh7oY?ol0=[o
o03Oood0m_ol0?coo03goo`0lOol0?;on02LohP0POn1oh7oPOnToo`0f_ol0=oo
o@3foo`0o?ol0?Ooo03aoo`0l_oh09coR02Eo`2@boom087oPOn1ol[oo03Joo`0
hOok0?Koo@3iooh0mool0?7oo03booP0W?n8087ogoom087oPOn1ol[oo03Joo`0
hOok0?Koo@3iooh0mool0?7oo03booP0W?n8087ogoom087oPOn1ol[oo03Joo`0
hOok0?Koo@3iooh0mool0?7oo03booP0W?n809Go093;ood0POn1oh7ob_ol0=[o
o03TooP0moom0?Soo@3ioo/0lOok0?ComP2MohP0POoOood0POn1oh7ob_ol0=[o
o03TooP0moom0?Soo@3ioo/0lOok0?ComP2MohP0POoOood0POn1oh7ob_ol0=[o
o03TooP0moom0?Soo@3ioo/0lOok0?ComP2MohP0UOl0W<_oo@21oh7oPOo:oo`0
f_ol0>Con03gooh0m_on0?Woo03_oo`0mOok003on`2NohP0POoOood0POn1oh7o
b_ol0=[oo03TooP0moon0?KooP3ioo`0kool0?Gon`00oo/0W_n8087ogoom087o
POn1ol[oo03Joo`0i?oh0?OooP3fooh0nOol0>ooo03eoo/00?ok09koR02Eo`2L
boom087oPOn1ol[oo03Joo`0i?oh0?OooP3fooh0nOol0>ooo03eoo`0o_ol09ko
R021omooo@21oh7oPOo:oo`0f_ol0>Con03gooh0m_on0?Woo03_oo`0mOol0?ko
o02NohP0POoOood0POn1oh7ob_ol0=[oo03TooP0moon0?KooP3ioo`0kool0?Go
o03noo`0W_n809Go0921oh7oPOn@oo`0f_ol0=kooP3gooh0m_on0?[on`3_oo/0
mool0?gon`2OohP0POn1oh7oPOnToo`0f_ol0=kooP3gooh0m_on0?[on`3_oo/0
mool0?gon`2OohP0POn1oh7oPOnToo`0f_ol0=kooP3gooh0m_on0?[on`3_oo/0
mool0?gon`2OohP0UOl0Q87oPOn1oi3oo03Joo`0g_on0>WooP3joo`0kOol0?So
n`3loo/0X?n8087oPOn1oh7oY?ol0=[oo03Nooh0jOon0?[oo03]oo`0n?ok0?co
n`2PohP0POn1oh7oPOnToo`0f_ol0=kooP3Yooh0n_ol0>goo03hoo/0o?ok0:3o
R02Eo`24POn1oh7oT?ol0=[oo03Nooh0j_om0?[oo03]oo`0n?ol0?[oo02PohP0
POn1oh7oPOnToo`0f_ol0=kooP3Zood0n_ol0>goo03hoo`0n_ol0:3oR021oh7o
POn1ojCoo03Joo`0g_on0>[oo@3joo`0kOol0?Soo03joo`0X?n809Go08B1oh7o
POn@oo`0f_ol0=kooP3[ood0n_ok0>gon`3joo/0n_ok0:7oR021oh7oPOn1ojCo
o03Joo`0g_on0>_oo@3joo/0kOok0?[on`3joo/0XOn8087oPOn1oh7oY?ol0=[o
o03Nooh0joom0?[on`3]oo/0n_ok0?[on`2QohP0UOl0T<_oo@21oh7oPOo:oo`0
f_ol0=kooP3/ood0nOol0>_oo03koo/0n?ok0:;oR021omooo@21oh7oPOo:oo`0
f_ol0=kooP3/ood0nOol0>_oo03koo/0n?ok0:;oR021omooo@21oh7oPOo:oo`0
f_ol0=kooP3/ood0nOol0>_oo03koo/0n?ok0:;oR02Eo`2@boom087oPOn1ol[o
o03Joo`0g_on0>kon`3ioo`0jool0?_oo03foo`0X_n8087ogoom087oPOn1ol[o
o03Joo`0g_on0>kon`3ioo`0jool0?_oo03foo`0X_n8087ogoom087oPOn1ol[o
o03Joo`0g_on0>kon`3ioo`0jool0?_oo03foo`0X_n809Go08c;ood0POn1oh7o
b_ol0=[oiP3dooh0l?ok0?Sog`3moo/0m_ok087ojOom087oY?om087oPOn1ol[o
o03JonH0m?on0?3on`3homl0oOok0?Kon`21onWoo@21ojCoo@21oh7oPOo:oo`0
f_oV0?CooP3`oo/0n?oO0?gon`3foo/0POoYood0POoJo`2<boom087oPOn1ol[o
o03JonH0m?on0?;onP3goml0o_ok0?Con`21on[oo@21ojCoo@21oh7oPOo:oo`0
f_oV0?CooP3booX0mooO0?kon`3doo/0POoZood0POnTood0POn1oh7ob_ol0=[o
iP3dooh0l_oj0?Oog`3noo/0m?ok087oj_om087of_l0Q87oPOn1oi3oo03JonH0
m?on0??on`3eoml0o_ol0?;oo021on[oo@21oh7oPOn1oh7ojOol0=[oiP3dooh0
look0?Gog`3noo`0l_ol087oj_om087oPOn1oh7oPOoYoo`0f_oV0?CooP3coo/0
mOoO0?koo03boo`0POoZood0POoJo`24POn1oh7oT?ol0=[oiP3dooh0m?ol0?Co
g@00oo/0l_ok087ojoom087oPOn1oh7oPOoYoo`0f_oV0?CooP3doo`0m?oM003o
n`3boo/0POo[ood0POn1oh7oPOn1onWoo03JonH0m?on0?Coo03domd00?ok0?;o
n`21on_oo@21om[o05B1oh7oPOn@oo`0/_on0?Goo@21oicoo@21oh7oPOn1oh7o
jOol0;;ooP3eood0POnLood0POn1oh7oPOn1onWoo02booh0mOom087oW?om087o
f_l0E87oPOn1oi3oo02booh0m_om087oVoom087oPOn1oh7oPOoYoo`0/_on0?Ko
o@21oi_oo@21oh7oPOn1oh7ojOol0;;ooP3food0POnKood0POoJo`1DPOn1oh7o
T?ol0;;ooP3good0POnJood0POn1oh7oPOn1onWoo02booh0moom087oV_om087o
POn1oh7oPOoYoo`0/_on0?Ooo@21oi[oo@21om[o05c;ood0POn1oh7ob_ol0;;o
oP3gooh0POnIood0POnTood0POn1oh7ob_ol0;;ooP3gooh0POnIood0POnTood0
POn1oh7ob_ol0;;ooP3gooh0POnIood0POoJo`1Oboom087oPOn1ol[oo02booh0
mol10021oiSoo@21ojCoo@21oh7oPOo:oo`0/_on0?Oo0@00POnHood0POnTood0
POn1oh7ob_ol0;;ooP3go`40087oV?om087of_l0G<_oo@21oh7oPOo:oo`0/_on
0?Sok`21ojOoo@21ojCoo@21oh7oPOo:oo`0/_on0?Sok`21ojOoo@21ojCoo@21
oh7oPOo:oo`0/_on0?Sok`21ojOoo@21om[o05c;ood0POn1oh7ob_ol0;;ooP3h
onl0POnWood0POnTood0POn1oh7ob_ol0;;ooP3honl0POnWood0POnTood0POn1
oh7ob_ol0;;ooP3honl0POnWood0POoJo`1JPOn1oh7oT?ol0;;ooP3honl0POnW
ood0goog087oPOn1oh7oUOol0;;ooP3honl0POnWood0goog087oPOn1oh7oUOol
0;;ooP3honl0POnWood0goog08Ko06>1oh7oPOn@oo`0POn1ok[oo@3Roo40kol1
003=oo/0POn1oh7oPOoVoo`0POn1ok[oo@3Roo40kol1003=oo/0POn1oh7oPOoV
oo`0POn1ok[oo@3Roo40kol1003=oo/0eol0H87oPOn1oi3oo@21oh7o^Oom0>Co
k@3booh0c_oi087oPOn1oh7oioom087oPOniood0i?o]0?;ooP3>ooT0POn1oh7o
POoWood0POn1okWoo@3Tond0l_on0<kon@3Ho`1PPOn1oh7oSoom087oPOnjood0
i_oZ0?Coo@3>ooT0POn1oh7oPOoVood0POn1ok[oo@3VonX0m?om0<kon@21oh7o
POn1onKoo@21oh7o^_om0>KojP3dood0c_oi0=So07C;ood0POn1oh7obOom087o
POnjood0iooh0?Won@3eooh0cOoi0:;oo@21oh7oPOo9ood0POn1ok[oo@3WooP0
nOoi0?GooP3=ooT0X_om087oPOn1olWoo@21oh7o^_om0>Oon03iooT0mOon0<go
n@3Ho`1dboom087oPOn1olSooP21oh7o^_om0>SonP3dooX0m_on0<kom`2Sood0
POn1oh7ob?on087oPOnjood0j?oj0?ConP3fooh0c_og0:?oo@21oh7oPOo8ooh0
POn1ok[oo@3XooX0m?oj0?KooP3>ooL0fOl0M<_oo@21oh7oPOo8ood0POn1ok_o
o@3Yoo/0l?ok0?SooP3=ooL0Xoom087oPOn1olSoo@21oh7o^oom0>Won`3`oo/0
n?on0<gom`2Sood0POn1oh7ob?om087oPOnkood0jOok0?3on`3hooh0cOog0=Wo
07C;ood0POn1oh7ob?om087oPOnkood0j_ok0>kon`3iooh0cOog0:?oo@21oh7o
POo8ood0POn1ok_oo@3Zoo/0k_ok0?WooP3=ooL0Xoom087oPOn1olSoo@21oh7o
^oom0>[on`3^oo/0nOon0<gom`3Io`1hPOn1oh7oSOon087oPOnkood0jook0>co
o03iooh0c_ok003oo021oh7oPOn1onKooP21oh7o^oom0>_on`3/oo`0nOon0<ko
n`00oo`0POn1oh7oPOoVooh0POn1ok_oo@3[oo/0k?ol0?WooP3>oo/00?ol0=[o
07^1oh7oPOn=ood0POn1okcoo@3[oo`0jook0?[ooP3>oo`00Oooo021oh7oPOn1
onKoo@21oh7o_?om0>_oo03[oo/0n_on0<koo001oool087oPOn1oh7oi_om087o
POnlood0jool0>_on`3jooh0c_ol007ooo`0f_l0Nh7oPOn1ohgoo@21oh7o_?om
0>con`3Zoo`0n_ol0=3oo001oook087oPOn1oh7oioom087oPOnlood0k?ok0>[o
o03joo`0d?ol007ooo/0POn1oh7oPOoWood0POn1okcoo@3/oo/0j_ol0?[oo03@
oo`00Ooon`3Ko`1hPOn1oh7oS?on087oPOnlood0k?ol0>Won`3koo`0dOok0?ko
o021oh7oPOn1onKooP21oh7o_?om0>coo03Yoo/0nool0=7on`3noo`0POn1oh7o
POoVooh0POn1okcoo@3/oo`0jOok0?_oo03Aoo/0o_ol0=_o09K;ood0POn1oh7o
a_om087oPOnmood0kOok0>Soo03koo`0dOol0?goo03doo/0lool0<_oo@21oh7o
POo6ood0POn1okgoo@3]oo/0j?ol0?_oo03Aoo`0oOol0?Con`3coo`0boom087o
POn1olKoo@21oh7o_Oom0>gon`3Xoo`0nool0=7oo03moo`0m?ok0??oo000U/_o
o@21oh7oPOo6ood0POn1okgoo@3]oo`0iool0?_oo03Aoo`0oOok0?Gon`3coo`0
boom087oPOn1olKoo@21oh7o_Oom0>goo03Woo`0nool0=7oo03moo/0mOok0??o
o03;ood0POn1oh7oa_om087oPOnmood0kOol0>Ooo03koo`0dOol0?gon`3eoo/0
lool002:boom087oPOn1olKoo@21oh7o_Oom0>goo03Loo`0d_ol0?_oo03doo/0
mOok0<_oo@21oh7oPOo6ood0POn1okgoo@3]oo`0g?ol0=;oo03koo`0m?ok0?Go
n`3;ood0POn1oh7oa_om087oPOnmood0kOol0=coo03Boo`0nool0?Con`3eoo/0
08c;ood0POn1oh7oaOom0?OooP21oh7oboom0>goo02Xoo`0nool0??oo03foo/0
b_om087oPOn1olGoo@3gooh0POn1ol_oo@3]oo`0Z?ol0?_oo03coo`0m_ok0<[o
o@21oh7oPOo5ood0moon087oPOo;ood0kOol0:Soo03koo`0lool0?Kon`00o`21
POn1oh7oRoom0?Woo021oh7oboom0>kon`2Yoo/0nook0?Con`3hoo/0POn1oh7o
ROom0?Woo021oh7oboom0>kon`2Yoo/0nook0?Con`3hoo/0POn1oh7oROom0?Wo
o021oh7oboom0>kon`2Yoo/0nook0?Con`3hoo/00Ooo09nZoo`0goon0;kooP21
oh7od_om0?con@21oh7oboom0>koo02Xoo`0nOol0??on`3ioo/0Z?ol0=oooP2n
ooh0POn1om;oo@3looT0POn1ol_oo@3^oo`0Z?ol0?Woo03coo/0nOok0:Soo03O
ooh0__on087oPOoBood0o?oi087oPOo;ood0k_ol0:Soo03ioo`0look0?Won`01
ool0WZ[oo03Pooh0_?on087oPOoBood00?of087oPOo;ood0k_ol0:Soo03ioo`0
l_ol0?[on`2Woo`0h?on0;cooP21oh7od_om003omP21oh7oboom0>koo02Xoo`0
nOol0?;oo03joo/0Yool0>3ooP2looh0POn1om;oo@00ooH0POn1ol_oo@3^oo`0
Z?ol0?Woo03boo`0n_ok0?ko09jZoo`0hOom0<_oo03good0POn1om?ol@21oh7o
boom0>koo02Yoo/0nOok0??on`3loo/0Y_ol0>7oo@3;oo`0moom087oPOoCoo40
POn1ol_oo@3^oo`0ZOok0?Won`3coo/0o?ok0:Koo03Qood0bool0?Ooo@21oh7o
dooa087oPOo;ood0k_ol0:Won`3ioo/0look0?con`3mo`2NZ_ol0>7ooP3:oo`0
m_on087oPOoCoo40POn1ol_oo@3^oo`0ZOol0?Ooo03boo/0oOol0:Goo03Qooh0
b_ol0?KooP21oh7odooa087oPOo;ood0k_ol0:Woo03goo`0l_ok0?goo02Uoo`0
hOon0<[oo03fooh0POn1om?ol@21oh7oboom0>koo02Yoo`0mool0?;on`3moo`0
o?l0Z/_oo@3Too`0h_om0<[oo03food0POn1omOokP21oh7oboom0>koo02Yoo`0
mool0?7oo03noo/0a_om0>Coo03Rood0b_ol0?Koo@21oh7oeoo^087oPOo;ood0
k_ol0:Woo03goo`0lOol0?kon`36ood0i?ol0>;oo@3:oo`0m_om087oPOoGonh0
POn1ol_oo@3^oo`0ZOol0?Ooo03aoo`0o_ok0?co09k;ood0`Oom0<Woo03eood0
POn1om_oj`21oh7oboom0>koo02Zoo/0mook0?;on`00oo/0aOom0<7oo@39oo`0
mOom087oPOoKon/0POn1ol_oo@3^oo`0Z_ok0?Oon`3boo/00?ok0<Goo@31ood0
bOol0?Goo@21oh7ofoo[087oPOo;ood0k_ol0:[on`3goo/0l_ok003on`3ko`2N
boom0<7oo@39oo`0mOom087oPOoNonP0POn1ol_oo@3^oo`0Z_ol0?Goo03aoo`0
0?ol0<Coo@31ood0bOol0?Goo@21oh7og_oX087oPOo;ood0k_ol0:[oo03eoo`0
lOol003oo034ood0`Oom0<Woo03eood0POn1omkoj021oh7oboom0>koo02Zoo`0
mOol0?7oo000oo`0n_l0T/_oo@32ood0b?ol0?Coo@21oh7ohOoV087oPOo;ood0
k_ol0:[oo03eoo`0l?og0<Coo@32ood0b?ol0?Coo@21oh7ohOoV087oPOo;ood0
k_ol0:[oo03eoo`0l?og0<Coo@32ood0b?ol0?Coo@21oh7ohOoV087oPOo;ood0
k_ol0:[oo03eoo`0l?og0?[o08Z8ood0b?ol0?Coo@21oh7oi?oS087oPOo;ood0
k_ol0:_on`3doo`0lOoh087o0?om0<Soo03dood0POn1onCoh`21oh7oboom0>ko
o02[oo/0m?ol0?7on021o`3oo@38oo`0m?om087oPOoTon<0POn1ol_oo@3^oo`0
Zook0?Coo03aooP0nOl0RXWoo@37oo`0loom087oPOoXon00POn1ol_oo@3^oo`0
Zool0??oo03`ooX0POl0ood0aool0??oo@21oh7oj?oP087oPOo;ood0k_ol0:_o
o03coo`0l?oj087o0?om0<Ooo03cood0POn1onSoh021oh7oboom0>koo02[oo`0
lool0?3onP3ho`2:ROom0<Ooo03cood0POn1onOoh@21oh7oboom0>koo02[oo`0
look0?7onP21o`3oo@37oo`0loom087oPOoWon40POn1ol_oo@3^oo`0Zool0??o
n`3aooX0POl0ood0aool0??oo@21oh7oiooQ087oPOo;ood0k_ol0:_oo03coo/0
lOoj0?So0;JZoo`0i_om0?Kon`3coo/0kooc0?Ooo@21oh7oiooR087oPOo;ood0
kOol0>Ooo03<oo`0lOol0?;on02Roo`0i_om0?Kon`3coo/0kooc0?Ooo@21oh7o
iooR087oPOo;ood0kOol0>Ooo03<oo`0lOol0?;on02Roo`0i_om0?Kon`3coo/0
kooc0?Ooo@21oh7oiooR087oPOo;ood0kOol0>Ooo03<oo`0lOol0?;on03io`32
boom0>Coo03Vood0m_ok0??oo03^oo<0moom087oPOoVon<0POn1ol_oo@3]oo`0
iool0<coo03aoo`0l_oh0<?oo@3Too`0i_om0?Kon`3coo`0k_oc0?Ooo@21oh7o
i_oS087oPOo;ood0kOol0>Ooo03<oo`0lOol0?;on033ood0i?ol0>Koo@3foo/0
lool0>kol`3good0POn1onKoh`21oh7oboom0>goo03Woo`0c?ol0?7oo03booP0
nOl0gL_oo@3Too`0iool0?Gon`3eoo/0k_oc0?Ooo021oh7oi_oT087oPOo;ood0
kOol0>Son`3do`400??onP3aoo/0lOok0?ComP34ood0i?ol0>Ooo03eoo/0mOok
0>kol`3goo`0POn1onKoi021oh7oboom0>goo03Xoo/0m?l1003cooX0lOok0?7o
n`3dooH0a?om0>Coo03Woo`0mOok0?Gon`3^oo<0mool087oPOoVon@0POn1ol_o
o@3]oo`0j?ok0?Co0@00looj0?7on`3aoo/0m?of0?[o0>K;ood0i?ol0>Ooo@3c
oo`0m_ok0>gol`3goo`0POn1onGoi@21oh7oboom0>gon`3Yoo`0m?on0?GomP3c
oo`0kool0?Gon`00oo/0aOom0>Coo03Wood0lool0?Kon`3]oo<0mool087oPOoU
onD0POn1ol_oo@3]oo/0jOol0?CooP3eooH0lool0>ooo03eoo/00?ok0<Goo@3T
oo`0ioom0??oo03foo/0kOoc0?Ooo021oh7oiOoU087oPOo;ood0kOok0>Woo03d
ooh0mOof0??oo03_oo`0mOok003on`3ko`3Vboom0>Coo03Wood0look0?Son`3X
oo`0lOom087oPOoTonH0POn1ol_oo@3/oo`0jOol0?CooP3foo@0m?ol0>ooo03e
oo`0o_ol0<Goo@3Too`0ioom0??on`3hoo/0j?ol0?7oo@21oh7oi?oV087oPOo;
ood0k?ol0>Woo03dooh0m_od0?Coo03_oo`0mOol0?koo035ood0i?ol0>Ooo@3c
oo/0n?ok0>Soo03aood0POn1onCoiP21oh7oboom0>coo03Yoo`0m?on0?Kom03d
oo`0kool0?Goo03noo`0nol0iZ[oo03Xoo`0l_ok0?Won`3Xoo`0lOol087oPOoT
onL0POn1ol_oo@3/oo/0jook0?Goo@3goo`0o?ol0?Kon`3_oo/0mool0?gon`2U
oo`0j?ol0?;on`3ioo/0j?ol0?7oo021oh7oi?oW087oPOo;ood0k?ok0>_on`3e
ood0mool0?coo03foo/0kook0?Ooo03moo/0YOol0>Soo03boo/0nOok0>Soo03a
oo`0POn1onCoi`21oh7oboom0>con`3[oo/0mOom0?Ooo03loo`0m_ok0>oon`3g
oo`0oOok0?co0>JZoo`0j?ol0?7oo03joo/0iool0?7oo021oh7ohooX087oPOo;
ood0jool0>_oo03foo/0moom0?WooP3foo`0kOol0?Son`3loo/0Y_ol0>Soo03a
oo`0n_ok0>Ooo03aoo`0POn1on?oj021oh7oboom0>_oo03[oo`0m_ok0?Ooo@3i
ooh0m_ol0>goo03hoo/0o?ok0:Koo03Xoo`0lOol0?[on`3Woo`0lOol087oPOoS
onP0POn1ol_oo@3[oo`0jool0?Kon`3good0nOon0?Koo03]oo`0n?ok0?con`3m
o`3VZ_ol0>Soo03aoo/0o?ok0>Koo03aoo`0POn1on;oj@21oh7oboom0>_on`3]
oo/0nOoh0?Soo@3hood0mool0>goo03hoo`0n_ol0:Koo03Xoo`0lOok0?con`3V
oo`0lOol087oPOoRonT0POn1ol_oo@3[oo/0kOok0?Won03hood0n?om0?Ooo03]
oo`0n?ol0?[oo02Voo`0j?ol0?7on`3loo/0i_ol0?7oo021oh7oh_oY087oPOo;
ood0jook0>gon`3iooP0n?om0?Soo@3goo`0kOol0?Soo03joo`0oOl0iZ[oo03X
ood0kook0?goo03Uoo`0l?om087oPOoQonX0POn1ol_oo@3Zoo/0kook0?Son03h
ooh0m_on0?Son`3]oo/0n_ok0?[on`2Woo`0j?om0>oon`3moo`0iOol0?3oo@21
oh7ohOoZ087oPOo;ood0j_ok0>oon`3hooP0n?on0?KooP3hoo/0kOok0?[on`3j
oo/0Yool0>Soo@3_oo/0oOol0>Goo03`ood0POn1on7ojP21oh7oboom0>[on`3_
oo/0n?oh0?SooP3fooh0n?ok0>gon`3joo/0n_ok0?ko0??;ood0i?ol0>Woo03^
oo`0o_ok0>Goo03`oo`0POn1on7oj`21oh7oboom0>Won`3aoo/0mooh0?SooP3f
ooh0n?ol0>_oo03koo/0n?ok0<Woo@3Too`0jOol0>koo03noo/0iOol0?3oo021
oh7ohOo[087oPOo;ood0jOok0?7on`3gooP0n?on0?KooP3hoo`0jool0?_on`3h
oo/0bOom0>Coo03Yoo`0k_ol0?kon`3Uoo`0l?ol087oPOoQon/0POn1ol_oo@3Y
oo/0lOok0?Oon03hooh0m_on0?Soo03[oo`0nook0?Son`01ool0ll_oo@3Too`0
jOol0>kon`00oo/0i?ol0?3oo021oh7oh?o/087oPOo;ood0jOoi0?GonP3`ooh0
n?on0?KooP3hoo`0jool0?_oo03foo`0bOom0>Coo03Yoo`0k_ok003on`3Too`0
l?ol087oPOoPon`0POn1ol_oo@3YooT0mOoj0?3ooP3hooh0m_on0?Soo03[oo`0
nool0?Koo039ood0i?ol0>Woo03^oo/00?ok0>Coo03`oo`0POn1on3ok021oh7o
boom0>Won@3eooX0l?on0?SooP3fooh0n?ol0>_oo03koo`0m_ol007oo`3Jboom
0>Coo03Yoo`0kOol003oo03Soo`0l?ol087oPOoOond0POn1ol_oo@3XooP0nOoi
0>oooP3Zooh0nOoO0?gon`3foo/0b_om0>Coo03Yoo`0kOol003oo03Soo`0l?ol
087oPOoOond0POn1ol_oo@3XooP0nOoi0>oooP3Zooh0nOoO0?gon`3foo/0b_om
0>Coo03Yoo`0kOol003oo03Soo`0l?ol087oPOoOond0POn1ol_oo@3XooP0nOoi
0>oooP3Zooh0nOoO0?gon`3foo/00?l0`<_oo@3Too`0jOol0>com`3Soo`0l?ol
087oPOoNonh0POn1ol_oo@3Von/0k_on0>_oo@3ioml0o_ok0?Con`3;ood0i?ol
0>Woo03/ooL0hool0?3oo021oh7og_o^087oPOo;ood0i_o[0>kooP3[ood0nOoO
0?kon`3doo/0boom0>Coo03Yoo`0k?og0>?oo03`oo`0POn1omkokP21oh7oboom
0>Koj`3^ooh0joom0?Wog`3noo/0m?ok002dZ_ol0>Woo03/ooP0h_ol0?3oo021
oh7ogOo_087oPOo;ood0iOo]0>gooP3/ood0n?oO0?koo03boo`0Z_ol0>Woo03/
ooP0h_ol0?3oo021oh7ogOo_087oPOo;ood0iOo]0>gooP3/ood0n?oO0?koo03b
oo`0Z_ol0>Woo03/ooP0h_ol0?3oo021oh7ogOo_087oPOo;ood0iOo]0>gooP3/
ood0n?oO0?koo03boo`00;BZoo`0jOol0>_onP3Qoo`0l?ol087oPOoLoo00POn1
ol_oo@3Soo40joon0>goo@3homd00?ok0?;oo02Zoo`0jOol0>_onP3Qoo`0l?ol
087oPOoLoo00POn1ol_oo@3Soo40joon0>goo@3homd00?ok0?;oo02Zoo`0jOol
0>_onP3Qoo`0l?ol087oPOoLoo00POn1ol_oo@3Soo40joon0>goo@3homd00?ok
0?;oo000UZ[oo03Yoo`0jooj0>7oo03`oo`0POn1om_ol@21oh7oboom0>3on03W
ooh0kook087oh_ol0>Woo03[ooX0hOol0?3oo021oh7ofooa087oPOo;ood0h?oh
0>OooP3_oo/0POoRoo`0jOol0>_onP3Qoo`0l?ol087oPOoKoo40POn1ol_oo@3P
ooP0ioon0>oon`2io`2:Z_ol0>Woo03/ooP0h_ol0?3oo021oh7ofooa087oPOo;
ood0_Oon0?7on`21on3oo03Yoo`0k?oh0>;oo03`oo`0POn1om_ol@21oh7oboom
0;gooP3aoo/0POoPoo`0jOol0>con03Roo`0l?ol087oPOoKoo40POn1ol_oo@2m
ooh0lOok0;Oo08ZZoo`0jOol0>con03Roo`0l?ol087oPOoJoo80POn1ol_oo@2m
ooh0looj087ogool0>Woo03/ooP0h_ol0?3oo021oh7of_ob087oPOo;ood0_Oon
0??onP21omooo03Yoo`0k?oh0>;oo03`oo`0POn1om[olP21oh7oboom0;gooP3c
ooX0]_l0U/_oo@3Too`0jOol0>gomP3Soo`0l?ol087oPOoIoo<0POn1ol_oo@2m
ooh0m?ok087oo_om0>Coo03Yoo`0kOof0>?oo03`oo`0POn1omWol`21oh7oboom
0;gooP3doo/0POonood0i?ol0>Woo03]ooH0hool0?3oo021oh7ofOoc087oPOo;
ood0_Oon0?Con`2do`2Rboom0>Coo03Yoo`0k_ok003on`3Too`0l?ol087oPOoH
oo@0POn1ol_oo@2mooh0mOol087oo?om0>Coo03Yoo`0k_ok003on`3Too`0l?ol
087oPOoHoo@0POn1ol_oo@2mooh0mOol087oo?om0>Coo03Yoo`0k_ok003on`3T
oo`0l?ol087oPOoHoo@0POn1ol_oo@2mooh0mOol0;;o0:k;ood0i?ol0?OonP3j
oo`0k_ol0?koo03Too`0l?ol087oPOoGooD0POn1ol_oo@2mooh0m_om087on_om
0>Coo03gooX0n_ol0>koo03noo`0i?ol0?3oo021oh7oeooe087oPOo;ood0_Oon
0?Koo@21oo[oo@3Too`0mooj0?[oo03^oo`0o_ol0>Coo03`oo`0POn1omOom@21
oh7oboom0;gooP3food0/?l0[/_oo@3Too`0nOof0?coo03_oo`0oOok0>Goo03`
oo`0POn1omKomP21oh7oboom0;gooP3good0POoiood0i?ol0?WomP3loo`0kool
0?gon`3Uoo`0l?ol087oPOoFooH0POn1ol_oo@2mooh0moom087onOom0>Coo03i
ooH0o?ol0>ooo03moo/0iOol0?3oo021oh7oe_of087oPOo;ood0_Oon0?Ooo@2_
o`2RZ_ol0?[ol`3mood0l?ok0?con`3Voo`0l?om087oPOoDooL0POn1ol_oo@2m
ooh0n?om087oeool0?[ol`3mood0l?ok0?con`3Voo`0l?om087oPOoDooL0POn1
ol_oo@2mooh0n?om087oeool0?[ol`3mood0l?ok0?con`3Voo`0l?om087oPOoD
ooL0POn1ol_oo@2mooh0n?om0:ko0:jZoo`0nool0?coo03moo`0lOol0?[oo03V
oo`0lOol087oPOoCooP0POn1ol_oo@2mooh0n?on087oe_ol0?_oo03loo`0oOol
0?7oo03joo`0i_ol0?7oo021oh7odooh087oPOo;ood0_Oon0?SooP21omKoo03k
oo`0o?ol0?goo03aoo`0n_ol0>Koo03aoo`0POn1om?on021oh7oboom0;gooP3h
ooh0[Ol0/J[oo03loo`0nOom0?koo03boo/0n_ok0>Ooo03aoo`0POn1om;on@21
oh7oboom0;gooP3ho`40087oeOol0?coo03iood0o_ol0?;on`3joo/0iool0?7o
o021oh7od_oi087oPOo;ood0_Oon0?So0@00POoEoo`0o?ol0?Woo@3noo`0l_ok
0?[on`3Woo`0lOol087oPOoBooT0POn1ol_oo@2mooh0n?l1002/o`2^Z_ol0?co
o@3hood0o_ol0??on`3hoo/0j?ol0?7oo021oh7odOoj087oPOo;ood0_Oon0?Wo
k`21onCoo03lood0n?om0?koo03coo/0n?ok0>Soo03aoo`0POn1om7onP21oh7o
boom0;gooP3ionl0POoToo`0o?om0?Soo@3noo`0look0?Son`3Xoo`0lOol087o
POoAooX0POn1ol_oo@2mooh0nOo_0;_o0<;;ood0i?ol0?goo03good0o_om0??o
o03foo`0n?ol0?Kon`3bood0POn1oloon`21oh7oboom0;gooP3ionl0QOom0>Co
o03moo`0moom0?koo@3coo`0m_ol0?Soo03foo/0l_om087oPOo?oo/0POn1ol_o
o@2mooh0nOo_08Goo@3Too`0oOol0?Ooo@3nood0lool0?Koo03hoo`0m_ok0?;o
o@21oh7ocook087oPOo;ood0_Oon0?Wok`2ko`32boom0>Coo03mood0m_om0?ko
o03eoo/0m_ok0?Woo03fooL0m_om087oPOo>oo`0POn1ol_oo@2mooh0nOo_08Go
o@3Too`0oOom0?Koo@3noo`0mOok0?Kon`3ioo`0m_og0?Koo@21oh7oc_ol087o
POo;ood0_Oon0?Wok`25ood0i?ol0?goo@3food0o_ol0?Gon`3foo/0nOol0?Ko
m`3food0POn1olkoo021oh7oboom0;gooP3ionl0^ol0/<_oo@3Too`0oOom0?Ko
o@3noo`0m_ok0?Con`3joo`0mOoh0?Ooo021oh7ocOom087oPOo;ood0POnTood0
i?ol0?goo@3food0o_ol0?Kon`3doo/0n_ol0?Gon03goo`0POn1olgoo@21oh7o
boom087oY?om0>Coo03mood0m_om0?koo03foo/0m?ok0?[oo03eooP0mool087o
POo=ood0POn1ol_oo@21om[o0;3;ood0i?ol0?goo@3food0oOom0?Koo03boo`0
n_ol0?Con@3good0POn1ol_ooP21oh7oboom087oY?om0>Coo03mood0m_om0?go
o@3foo`0l_ol0?[oo03dooT0moom087oPOo;ooh0POn1ol_oo@21ojCoo@3Too`0
oOom0?Koo@3mood0m_ol0?;oo03joo`0m?oi0?Ooo@21oh7oboon087oPOo;ood0
POoJo`2KZ_ol0>koo@3mood0mook0?;on`3koo`0looj0?Ooo@21oh7ob_l10021
oh7oboom087oPool0>koo@3mood0mook0?;on`3koo`0looj0?Ooo@21oh7ob_l1
0021oh7oboom087oPool0>koo@3mood0mook0?;on`3koo`0looj0?Ooo@21oh7o
b_l10021oh7oboom087of_l0K9?oo@3kood0eOon0>?oo@21oh7ob?l0087oPOo;
ood0POn1oncoo@3kood0eOon0>?oo@21oh7ob?l0087oPOo;ood0POn1oncoo@3k
ood0eOon0>?oo@21oh7ob?l0087oPOo;ood0POoJo`1PU?ol0?_oo@3Eooh0hoom
087oPOn1oh7oTOom087oPOo]oo`0noom0=GooP3Sood0POn1oh7oPOnAood0POn1
ongoo03kood0eOon0>?oo@21oh7oPOn1oi7oo@21om[o062Eoo`0nOom0=KooP3T
ood0POn1oh7oPOn@ood0POn1onkoo03iood0e_on0>Coo@21oh7oPOn1oi3oo@21
oh7ok_ol0?Woo@3Fooh0i?om087oPOn1oh7oT?om087of_l0J<_oo@3@oo/0nOom
0=KooP3Tood0POn1oh7oPOn@ood0POnTood0d?ok0?Woo@3Fooh0i?om087oPOn1
oh7oT?om087oY?om0=3on`3iood0e_on0>Coo@21oh7oPOn1oi3oo@21om[o06S;
ood0d_ok0?Koo@3Hooh0i?om087oPOn1oh7oSoom087oY?om0=;on`3food0f?on
0>Coo@21oh7oPOn1ohooo@21ojCoo@3Boo/0m_om0=SooP3Tood0POn1oh7oPOn?
ood0POoJo`1Xboom0=?on`3eood0f?on0>Coo@21oh7oPOn1ohooo@21ojCoo@3C
oo/0mOom0=SooP3Tood0POn1oh7oPOn?ood0POnTood0dook0?Goo@3Hooh0i?om
087oPOn1oh7oSoom087of_l0J<_oo@3EooX0loom0=[oo@3Uood0POn1oh7oPOn>
ood0POnTood0eOoj0??oo@3Jood0iOom087oPOn1oh7oS_om087oY?om0=GonP3c
ood0f_om0>Goo@21oh7oPOn1ohkoo@21om[o062Loo/0l?on0=[ooP3Tooh0POn1
oh7oPOn=ood0POn1ooGon`3`ooh0f_on0>CooP21oh7oPOn1ohgoo@21oh7omOok
0?3ooP3Jooh0i?on087oPOn1oh7oSOom087of_l0H9kon`3^ood0fol00>?oo@21
oh7oPOn1ohgoo@21oh7omook0>koo@3Ko`00hoom087oPOn1oh7oSOom087oPOog
oo/0k_om0=_o003Sood0POn1oh7oPOn=ood0POoJo`1DWook0>cooP2looh0POn1
oh7oPOn<ood0POn1ooSon`3/ooh0_?on087oPOn1oh7oS?om087oPOohoo/0k?on
0;cooP21oh7oPOn1ohcoo@21om[o05BOood0jOon0;kooP21oh7oPOn1oh_oo@21
oh7on?om0>WooP2nooh0POn1oh7oPOn;ood0POn1ooSoo@3Yooh0__on087oPOn1
oh7oRoom087of_l0CZ3oo@21oh7oPOoMoh40i`21onOoo@21oh7onOom087oPOn1
omgoP@3W087oioom087oPOoiood0POn1oh7ogOn10>L0POoWood0POoJo`1Fboom
0=_oo@21oh7oPOoLoh40i`21onOoo@21ojCoo@3Kood0POn1oh7og?n10>L0POoW
ood0POnTood0foom087oPOn1omcoP@3W087oioom087of_l0G<_oo@3Kood0POo6
oh40iP2boh40i`21onOoo@21ojCoo@3Kood0POo6oh40iP2boh40i`21onOoo@21
ojCoo@3Kood0POo6oh40iP2boh40i`21onOoo@21om[o05c;ood0foon087oaOn1
0>H0/_n10>L0POoWood0POnTood0foon087oaOn10>H0/_n10>L0POoWood0POnT
ood0foon087oaOn10>H0/_n10>L0POoWood0POoJo`1Lboom0=cok@21omGoP@3V
0;;oP@3W087oioom087oY?om0=cok@21omGoP@3V0;;oP@3W087oioom087oY?om
0=cok@21omGoP@3V0;;oP@3W087oioom087of_l0E:;ok@21omGoP@3V0;;oP@3W
087oioom087oPOokond0POoEoh40iP2boh40i`21onOoo@21oh7onoo]087oeOn1
0>H0/_n10>L0POoWood0POoJo`1PX_o]087oeOol087ol?ol0;;oP@3W087oioom
087oPOokond0POoEoo`0POo`oo`0/_n10>L0POoWood0POn1oo_ok@21omGoo021
oo3oo02boh40i`21onOoo@21om[o05J1oh7oh_ol087ol?ol0;;oP@3W087oioom
087oPOn1ok_oo021oo3oo02boh40i`21onOoo@21oh7oPOnkoo`0POo`oo`0/_n1
0>L0POoWood0POoJo`1FPOn1on;oo021oo3oo02boh40i`21onOoo@21oh7oPOnk
oo`0POo`oo`0/_n10>L0POoWood0POn1oh7o^ool087ol?ol0;;oP@3W087oioom
087of_l0J<_oo@21o`3ooP2Poo`0POo`oo`0/_n10>L0POoWood0POnTood0POl0
ooh0X?ol087ol?ol0;;oP@3W087oioom087oY?om087o0?on0:3oo021oo3oo02b
oh40i`21onOoo@21om[o06S;ood0POl0oo/0Xool087ol?ol0;;oP@3W087oioom
087oY?om087o0?ok0:?oo021oo3oo02boh40i`21onOoo@21ojCoo@21o`3on`2S
oo`0POo`oo`0/_n10>L0POoWood0POoJo`1Xboom087o0?oh0:Koo021oo3oo02b
oh40i`21onOoo@21ojCoo@21o`3on02Voo`0POo`oo`0/_n10>L0POoWood0POnT
ood0POl0ooP0Y_ol087ol?ol0;;oP@3W087oioom087of_l0J<_oo@21o`3om@2Y
oo`0POo`oo`0/_n10>L0POoWood0POnTood0POl0ooD0ZOol087ol?ol0;;oP@3W
087oioom087oY?om087o0?oe0:Woo021oo3oo02boh40i`21onOoo@21om[o05b1
olKol`2[oo`0POo`oo`0/_n10>L0POoWood0POn1oiool`2[oo`0POo`oo`0/_n1
0>L0POoWood0POn1oiool`2[oo`0POo`oo`0/_n10>L0POoWood0POoJo`1LPOo6
oo00[_ol087ol?ol0;;oP@3W087oioom087oPOnOoo00[_ol087ol?ol0;;oP@3W
087oioom087oPOnOoo00[_ol087ol?ol0;;oP@3W087oioom087of_l0G87oa_o]
0;7oo021oo3oo02boh40i`21onOoo@21oh7oWoo]0;7oo021oo3oo02boh40i`21
onOoo@21oh7oWoo]0;7oo021oo3oo02boh40i`21onOoo@21om[o05b1olKojP2d
oo`0POo`oo`0/_n10>L0POoYooP0POn1oj;ojP2doo`0POo`oo`0/_n10>L0POoY
ooP0POn1oj;ojP2doo`0POo`oo`0/_n10>L0POoYooP0POoMo`1Xboom087o0?oW
0;Ooo021oo3oo02boh40i`21on[omP21ojSoo@21o`3oi`2goo`0POo`oo`0/_n1
0>L0POoZooH0POnXood0POl0onL0]ool087ol?ol0;;oP@3W087oj_of087og_l0
J<_oo@21o`3oi02joo`0POo`oo`0/_n10>L0POo/oo80POnZood0POl0on@0^_ol
087ol?ol0;;oP@3W087ok?ob087oZ_om087o0?oT0;[oo021oo3oo02boh40i`21
oncolP21on3o06S;ood0POl0on40_Ool087ol?ol0;;oP@3W087ok?oa087oZoom
087o0?oQ0;goo021oo3oo02boh40i`21oncol@21oj_oo@21o`3oh@2moo`0POo`
oo`0/_n10>L0POo/oo40POoQo`1Xboom087o0?oN0<3oo021oo3oo02boh40i`21
ongol021oj_oo@21o`3ogP30oo`0POo`oo`0/_n10>L0POo]oo00POn[ood0POl0
omh0`?ol087ol?ol0;;oP@3W087okOo`087ohOl0G87oa_oL0<;oo021oo3oo02b
oh40i`21onkokP21oh7oYooL0<;oo021oo3oo02boh40i`21onkokP21oh7oYooL
0<;oo021oo3oo02boh40i`21onkokP21on;o05b1olKof@35oo`0POo`oo`0/_n1
0>L0POo^onh0POn1ojOof@35oo`0POo`oo`0/_n10>L0POo^onh0POn1ojOof@35
oo`0POo`oo`0/_n10>L0POo^onh0POoRo`12oOn10840h@21oo3oP@210840P@3>
0?goP@210>40POo`oh40P@210840cP3moh40P@3Q087ol?n10840P@210<h004;m
oh40P@3Q087ol?n10840P@210<h0oOn10840h@21oo3oP@210840P@3>0?goP@21
0>40POo`oh40P@210840cP00@_goP@210>40POo`oh40P@210840cP3moh40P@3Q
087ol?n10840P@210<h0oOn10840h@21oo3oP@210840P@3>0012oOn10840h@21
oo3oP@210840P@3>0?goP@210>40POo`oh40P@210840cP3moh40P@3Q087ol?n1
0840P@210<h004;moh40P@3Q087ol?n10840P@210<h0oOn10840h@21oo3oP@21
0840P@3>0?goP@210>40POo`oh40P@210840cP00K/_oo@33ood0`_oN0<3oo021
oo3oo02boh40i`21onkok@21ojgoo@33ood0`_oN0<3oo021oo3oo02boh40i`21
onkok@21ojgoo@33ood0`_oN0<3oo021oo3oo02boh40i`21onkok@21on?o06k;
ood0`oom0<;oh@2moo`0POo`oo`0/_n10>L0POo^onh0POn/ood0`oom0<;oh@2m
oo`0POo`oo`0/_n10>L0POo^onh0POn/ood0`oom0<;oh@2moo`0POo`oo`0/_n1
0>L0POo^onh0POoRo`1VROom0<;oh`2koo`0POo`oo`0/_n10>L0POo^onh0POn1
on[oo@32on<0^ool087ol?ol0;;oP@3W087ok_o^087oPOoZood0`_oS0;_oo021
oo3oo02boh40i`21onkokP21on;o06J9ood0`_oV0;Soo021oo3oo02boh40i`21
ongol021oh7ojOom0<;oiP2hoo`0POo`oo`0/_n10>L0POo]oo00POn1onWoo@32
onH0^?ol087ol?ol0;;oP@3W087okOo`087ohOl0IXWoo@32onT0]Ool087ol?ol
0;;oP@3W087ok?oa087oPOoYood0`_oY0;Goo021oo3oo02boh40i`21oncol@21
oh7ojOom0<;oj@2eoo`0POo`oo`0/_n10>L0POo/oo40POoQo`1VROom0<;oj`2c
oo`0POo`oo`0/_n10>L0POo/oo80POn1onSoo@32on/0/ool087ol?ol0;;oP@3W
087ok?ob087oPOoXood0`_o[0;?oo021oo3oo02boh40i`21oncolP21on3o06k;
ood0`oom0<;okP2`oo`0POo`oo`0/_n10>L0POoZooH0POnXood0`oom0<;okP2`
oo`0POo`oo`0/_n10>L0POoZooH0POnXood0`oom0<;okP2`oo`0POo`oo`0/_n1
0>L0POoZooH0POoNo`1^boom0<?oo@32oo40[Ool087ol?ol0;;oP@3W087ojOoi
087oY_om0<?oo@32oo40[Ool087ol?ol0;;oP@3W087ojOoi087oY_om0<?oo@32
oo40[Ool087ol?ol0;;oP@3W087ojOoi087og?l0K/_oo@33ood0`_oc0:_oo021
oo3oo02boh40i`21onOoo@21ojCoo@33ood0`_oc0:_oo021oo3oo02boh40i`21
onOoo@21ojCoo@33ood0`_oc0:_oo021oo3oo02boh40i`21onOoo@21om[o06k;
ood0`oom0<;omP2Xoo`0POo`oo`0/_n10>L0POoWood0POnTood0`oom0<;omP2X
oo`0POo`oo`0/_n10>L0POoWood0POnTood0`oom0<;omP2Xoo`0POo`oo`0/_n1
0>L0POoWood0POoJo`1VROom0<;on@2Uoo`0POo`oo`0/_n10>L0POoWood0POn1
on;oo@32ooT0YOol087ol?ol0;;oP@3W087oioom087oPOoRood0`_oi0:Goo021
oo3oo02boh40i`21onOoo@21om[o06J9ood0`_ol0:;oo021oo3oo02boh40i`21
onOoo@21oh7oh_om0<;oo02Roo`0POo`oo`0/_n10>L0POoWood0POn1on;oo@32
oo`0X_ol087ol?ol0;;oP@3W087oioom087of_l0IXWoo@32ooh0X?ol087ol?ol
0;;oP@3W087oioom087oPOoRood0`_on0:3oo021oo3oo02boh40i`21onOoo@21
oh7oh_om0<;ooP2Poo`0POo`oo`0/_n10>L0POoWood0POoJo`1PROom087og_ol
087ol?ol0;;oP@3W087oioom087oPOoRood0POoNoo`0POo`oo`0/_n10>L0POoW
ood0POn1on;oo@21omkoo021oo3oo02boh40i`21onOoo@21om[o06S;ood0`oom
087og_ol087ol?ol0;;oP@3W087oioom087oY?om0<?oo@21omkoo021oo3oo02b
oh40i`21onOoo@21ojCoo@33ood0POoNoo`0POo`oo`0/_n10>L0POoWood0POoJ
o`1Lboom0<?oo@21omkoP@3V0;;oP@3W087oioom087oY?om0<?oo@21omkoP@3V
0;;oP@3W087oioom087oY?om0<?oo@21omkoP@3V0;;oP@3W087oioom087of_l0
G<_oo@33ood0POoNoh40iP2boh40i`21onOoo@21ojCoo@33ood0POoNoh40iP2b
oh40i`21onOoo@21ojCoo@33ood0POoNoh40iP2boh40i`21onOoo@21om[o05c;
ood0`oom087og_n10>H0/_n10>L0POoWood0POnTood0`oom087og_n10>H0/_n1
0>L0POoWood0POnTood0`oom087og_n10>H0/_n10>L0POoWood0POoJo`1DROom
087og_n10>H0/_n10>L0POoWood0POn1on;oo@21omkoP@3V0;;oP@3W087oioom
087oPOoRood0POoNoh40iP2boh40i`21onOoo@21om[o04j9ood0POn1oh7om?n1
0>L0POoWood0POn1on;oo@21oh7oPOodoh40i`21onOoo@21oh7oh_om087oPOn1
ooCoP@3W087oioom087of_l0CXWoo@21oh7oPOodoh40i`21onOoo@21oh7oh_om
087oPOn1ooCoP@3W087oioom087oPOoRood0POn1oh7om?n10>L0POoWood0POoJ
o`1>ROom087oPOn1ooCoP@3W087oioom087oPOoRood0POn1oh7om?n10>L0POoW
ood0POn1on;oo@21oh7oPOodoh40i`21onOoo@21om[o04:9ood0POn1oh7oPOn1
ol3oo@21oh7oh_om087oPOn1oh7oPOo0ood0POn1on;oo@21oh7oPOn1oh7o`?om
087of_l0B/_oo@33ood0POn1oh7oPOn1ol3oo@21ojCoo@33ood0POn1oh7oPOn1
ol3oo@21ojCoo@33ood0POn1oh7oPOn1ol3oo@21om[o04[;ood0`oom087oPOn1
oh7oPOo0ood0POnTood0`oom087oPOn1oh7oPOo0ood0POnTood0`oom087oPOn1
oh7oPOo0ood0POoJo`1:boom0<?oo@21oh7oPOn1oh7o`?om087oY?om0<?oo@21
oh7oPOn1oh7o`?om087oY?om0<?oo@21oh7oPOn1oh7o`?om087of_l0B/_oo@33
ood0POn1oh7oPOn1ol3oo@21ojCoo@33ood0POn1oh7oPOn1ol3oo@21ojCoo@33
ood0POn1oh7oPOn1ol3oo@21om[o04:9ood0POn1oh7oPOn1ol3oo@21oh7oh_om
087oPOn1oh7oPOo0ood0POn1on;oo@21oh7oPOn1oh7o`?om087of_l0Q8Woo@21
om3oj@3^o`400=gon`21ooCoo03To`400=con`21ojCoo@21oh7oh_om087od?oY
0>ko0@00gOok087om?ol0>Co0@00g?ok087oY?om087oPOoRood0POo@onT0k_l1
003Moo/0POodoo`0i?l1003Loo/0POnTood0POoJo`1nROom087od?oV0?;ooP3N
ooT0POoeoo`0iOon0=gon@21ojGoo@21oh7oh_om087od?oV0?;ooP3NooT0POoe
oo`0iOon0=gon@21ojGoo@21oh7oh_om087od?oV0?;ooP3NooT0POoeoo`0iOon
0=gon@21ojGoo@21om[o07j9ood0POo@onD0m?om0=kon@21ooGoo03Vood0gOoi
087oYOom087oPOoRood0POo@onD0m?om0=kon@21ooGoo03Vood0gOoi087oYOom
087oPOoRood0POo@onD0m?om0=kon@21ooGoo03Vood0gOoi087oYOom087of_l0
Q/_oo@33ood0POo@on@0mOon0=gon@21ooGoo03Vooh0g?oi087oYOom087oY?om
0<?oo@21om3oi03eooh0gOoi087omOol0>KooP3LooT0POnUood0POnTood0`oom
087od?oT0?GooP3MooT0POoeoo`0i_on0=con@21ojGoo@21om[o09;;ood0`oom
087od?ol0>oonP3fooh0g_og087om_ol0>KooP3MooL0POnVood0POnTood0`oom
087od?ol0>oonP3fooh0g_og087om_ol0>KooP3MooL0POnVood0POnTood0`oom
087od?ol0>oonP3fooh0g_og087om_ol0>KooP3MooL0POnVood0POoJo`2Bboom
0<?oo@21om3oo03]oo/0n?on0=gom`21ooKoo03Wooh0g?og087oY_om087oY?om
0<?oo@21om3oo03]oo/0n?on0=gom`21ooKoo03Wooh0g?og087oY_om087oY?om
0<?oo@21om3oo03]oo/0n?on0=gom`21ooKoo03Wooh0g?og087oY_om087of_l0
T/_oo@33ood0POo@oo`0k?ol0?SooP3MooL0POofoo`0ioon0=com`21ojKoo@21
ojCoo@33ood0POo@oo`0k?ol0?SooP3MooL0POofoo`0ioon0=com`21ojKoo@21
ojCoo@33ood0POo@oo`0k?ol0?SooP3MooL0POofoo`0ioon0=com`21ojKoo@21
om[o0::9ood0POo@oo`0k?ok0?WooP3Noo/00?ol087omool0>OooP3Moo/00?ol
087oYoom087oPOoRood0POo@oo`0k?ok0?WooP3Noo/00?ol087omool0>OooP3M
oo/00?ol087oYoom087oPOoRood0POo@oo`0k?ok0?WooP3Noo/00?ol087omool
0>OooP3Moo/00?ol087oYoom087of_l0Z8Woo@21om3oo03[oo`0nOon0=koo001
oool087omool0>OooP3Moo`00Oooo021ojOoo@21oh7oh_om087od?ol0>_oo03i
ooh0g_ol007ooo`0POogoo`0ioon0=goo001oool087oYoom087oPOoRood0POo@
oo`0jool0?WooP3Noo`00Oooo021ooOoo03Wooh0gOol007ooo`0POnWood0POoJ
o`2XROom087od?ol0>_oo03ioo`0h?ol007ooo/0POohoo`0iool0=ooo001oook
087oZ?om087oPOoRood0POo@oo`0jool0?Woo03Poo`00Ooon`21ooSoo03Woo`0
gool007ooo/0POnXood0POn1on;oo@21om3oo03[oo`0nOol0>3oo001oook087o
n?ol0>Ooo03Ooo`00Ooon`21ojSoo@21om[o0::9ood0POo@oo`0jool0?Woo03Q
oo/0o_ol087on?ol0>Ooo03Poo/0o_ol087oZ?om087oPOoRood0POo@oo`0jool
0?Woo03Qoo/0o_ol087on?ol0>Ooo03Poo/0o_ol087oZ?om087oPOoRood0POo@
oo`0jool0?Woo03Qoo/0o_ol087on?ol0>Ooo03Poo/0o_ol087oZ?om087of_l0
e<_oo@33ood0POo@oo`0jool0?Woo03Qoo`0oOol0?Con`3coo/0Wool0>Ooo03P
oo`0oOol0?Gon`3coo/0POo>ood0POnTood0`oom087od?ol0>_oo03ioo`0hOol
0?goo03doo/0look09ooo03Woo`0h?ol0?goo03eoo/0look087oc_om087oY?om
0<?oo@21om3oo03[oo`0nOol0>7oo03moo`0m?ok0??on`2Ooo`0iool0>3oo03m
oo`0mOok0??on`21olkoo@21om[o0=C;ood0`oom087od?ol0>_oo03ioo`0hOol
0?gon`3eoo/0lool09koo03Woo`0h?ol0?gon`3foo/0lool087ocOom087oY?om
0<?oo@21om3oo03[oo`0nOol0>7oo03moo/0mOok0??oo02Noo`0iool0>3oo03m
oo/0m_ok0??oo021olgoo@21ojCoo@33ood0POo@oo`0jool0?Woo03Qoo`0oOok
0?Gon`3coo`0W_ol0>Ooo03Poo`0oOok0?Kon`3coo`0POo=ood0POoJo`3Dboom
0<?oo@21om3oo03[oo`0nOol0>;oo03koo`0m?ok0?Gon`2Noo`0iool0>7oo03k
oo`0mOok0?Gon`21olgoo@21ojCoo@33ood0POo@oo`0jool0?Woo03Roo`0nool
0?Con`3eoo/0W_ol0>Ooo03Qoo`0nool0?Gon`3eoo/0POo=ood0POnTood0`oom
087od?ol0>_oo03ioo`0h_ol0?_oo03doo/0mOok09koo03Woo`0hOol0?_oo03e
oo/0mOok087ocOom087of_l0_<_oo@33ood0POo@oo`0jool0=Goo03koo`0lool
0?Kon`2Moo`0`_ol0?_oo03doo`0m_ok087oc?om087oY?om0<?oo@21om3oo03[
oo`0eOol0?_oo03coo`0m_ok09goo032oo`0nool0?Coo03foo/0POo<ood0POnT
ood0`oom087od?ol0>_oo03Eoo`0nool0??oo03foo/0WOol0<;oo03koo`0m?ol
0?Kon`21olcoo@21om[o0;B9ood0POo@oo`0k?ol0=Gon`3koo/0m?ok0?Son`2L
oo`0`ook0?_on`3eoo/0n?ok087oboom087oPOoRood0POo@oo`0k?ol0=Gon`3k
oo/0m?ok0?Son`2Loo`0`ook0?_on`3eoo/0n?ok087oboom087oPOoRood0POo@
oo`0k?ol0=Gon`3koo/0m?ok0?Son`2Loo`0`ook0?_on`3eoo/0n?ok087oboom
087of_l0]8Woo@21om3oo03/oo`0eOol0?Woo03coo/0nOok09coo033oo`0nOol
0?Con`3ioo/0POo;ood0POn1on;oo@21om3oo03/oo`0eOol0?Woo03coo/0nOok
09coo033oo`0nOol0?Con`3ioo/0POo;ood0POn1on;oo@21om3oo03/oo`0eOol
0?Woo03coo/0nOok09coo033oo`0nOol0?Con`3ioo/0POo;ood0POoJo`2dROom
087od?ol0>kon`3Doo`0nOol0?;oo03joo/0Vool0<?oo03ioo`0lool0?[on`21
ol[oo@21oh7oh_om087od?ol0>kon`3Doo`0nOol0?;oo03joo/0Vool0<?oo03i
oo`0lool0?[on`21ol[oo@21oh7oh_om087od?ol0>kon`3Doo`0nOol0?;oo03j
oo/0Vool0<?oo03ioo`0lool0?[on`21ol[oo@21om[o0;B9ood0POo@oo`0l?oj
0=Con`3ioo/0look0?con`2Joo`0a?ok0?Won`3doo/0o?ok087obOom087oPOoR
ood0POo@oo`0l?oj0=Con`3ioo/0look0?con`2Joo`0a?ok0?Won`3doo/0o?ok
087obOom087oPOoRood0POo@oo`0l?oj0=Con`3ioo/0look0?con`2Joo`0a?ok
0?Won`3doo/0o?ok087obOom087of_l0Z8Woo@21om3oi@3Coo`0mool0?;on`3m
oo`0VOol0<Coo03goo`0look0?goo021olSoo@21oh7oh_om087od?oU0=?oo03g
oo`0l_ok0?goo02Ioo`0a?ol0?Ooo03coo/0oOol087ob?om087oPOoRood0POo@
onD0dool0?Ooo03boo/0oOol09Woo034oo`0mool0??on`3moo`0POo8ood0POoJ
o`2`boom0<?oo@21om3oiP3Boo`0mool0?7oo03noo/0VOol0<Coo03goo`0l_ol
0?kon`21olSoo@21ojCoo@33ood0POo@onH0d_ol0?Ooo03aoo`0o_ok09Woo034
oo`0mool0?;oo03noo/0POo8ood0POnTood0`oom087od?oV0=;oo03goo`0lOol
0?kon`2Ioo`0a?ol0?Ooo03boo`0o_ok087ob?om087of_l0/<_oo@33ood0POo@
onD0e?ok0?Oon`3boo/00?ok09Soo035oo/0mook0??on`00oo/0POo7ood0POnT
ood0`oom087od?oU0=Con`3goo/0l_ok003on`2Hoo`0aOok0?Oon`3coo/00?ok
087oaoom087oY?om0<?oo@21om3oi@3Doo/0mook0?;on`00oo/0V?ol0<Gon`3g
oo/0look003on`21olOoo@21om[o0;3;ood0`oom087od?oT0=Goo03eoo`0lOol
003oo02Goo`0aOol0?Goo03boo`00?ol087oa_om087oY?om0<?oo@21om3oi03E
oo`0mOol0?7oo000oo`0Uool0<Goo03eoo`0l_ol003oo021olKoo@21ojCoo@33
ood0POo@on@0eOol0?Goo03aoo`00?ol09Ooo035oo`0mOol0?;oo000oo`0POo6
ood0POoJo`2Tboom0<?oo@21om3oo03`ooT0e_ol0?Goo03`ooL0Uool0<Goo03e
oo`0lOog087oa_om087oY?om0<?oo@21om3oo03`ooT0e_ol0?Goo03`ooL0Uool
0<Goo03eoo`0lOog087oa_om087oY?om0<?oo@21om3oo03`ooT0e_ol0?Goo03`
ooL0Uool0<Goo03eoo`0lOog087oa_om087of_l0W8Woo@21om3oo03^oo/0eook
0?Coo03aooP0U_ol0<Kon`3doo`0l_oh087oaOom087oPOoRood0POo@oo`0k_ok
0=Oon`3doo`0lOoh09Koo036oo/0m?ol0?;on021olGoo@21oh7oh_om087od?ol
0>kon`3Goo/0m?ol0?7on02Foo`0a_ok0?Coo03booP0POo5ood0POoJo`2LROom
087od?ol0>gon`3Hoo`0lool0?3onP2Eoo`0a_ol0??oo03aooX0POo4ood0POn1
on;oo@21om3oo03]oo/0f?ol0??oo03`ooX0UOol0<Koo03coo`0lOoj087oa?om
087oPOoRood0POo@oo`0kOok0=Soo03coo`0l?oj09Goo036oo`0lool0?7onP21
olCoo@21om[o09b9ood0POo@oo`0kOok0=Soo03coo/0lOoj09Goo036oo`0look
0?;onP21olCoo@21oh7oh_om087od?ol0>gon`3Hoo`0look0?7onP2Eoo`0a_ol
0??on`3booX0POo4ood0POn1on;oo@21om3oo03]oo/0f?ol0??on`3aooX0UOol
0<Koo03coo/0l_oj087oa?om087of_l0W8Woo@21om3oo03/oo`0fOol0?7oo03b
ooP0U_ol0<Ooo03aoo`0looh087oaOom087oPOoRood0POo@oo`0k?ol0=Woo03a
oo`0l_oh09Koo037oo`0lOol0??on021olGoo@21oh7oh_om087od?ol0>coo03I
oo`0lOol0?;on02Foo`0aool0?7oo03cooP0POo5ood0POoJo`2Tboom0<?oo@21
om3oo03/oo`0fOol0?7oo03booP0U_ol0<Ooo03aoo`0looh087oaOom087oY?om
0<?oo@21om3oo03/oo`0fOol0?7oo03booP0U_ol0<Ooo03aoo`0looh087oaOom
087oY?om0<?oo@21om3oo03/oo`0fOol0?7oo03booP0U_ol0<Ooo03aoo`0looh
087oaOom087of_l0_<_oo@33ood0POo@oo`0k?ol0?;onP3`oo/0lOok0?ComP2G
oo`0gooj0?7on`3aoo/0mOof087oa_om087oY?om0<?oo@21om3oo03/oo`0l_oj
0?3on`3aoo/0m?of09Ooo03OooX0lOok0?7on`3eooH0POo6ood0POnTood0`oom
087od?ol0>coo03booX0l?ok0?7on`3dooH0Uool0=oonP3aoo/0lOok0?GomP21
olKoo@21om[o0=C;ood0`oom087od?ol0>coo03dooH0l_ol0>ooo03eoo/00?ok
09Soo03QooH0lool0>ooo03foo/00?ok087oaoom087oY?om0<?oo@21om3oo03/
oo`0m?of0?;oo03_oo`0mOok003on`2Hoo`0hOof0??oo03_oo`0m_ok003on`21
olOoo@21ojCoo@33ood0POo@oo`0k?ol0?ComP3boo`0kool0?Gon`00oo/0V?ol
0>7omP3coo`0kool0?Kon`00oo/0POo7ood0POoJo`3Dboom0<?oo@21om3oo03/
oo`0mOoc0?Coo03_oo`0mOol0?koo02Hoo`0h_oc0?Goo03_oo`0m_ol0?koo021
olOoo@21ojCoo@33ood0POo@oo`0k?ol0?Gol`3doo`0kool0?Goo03noo`0V?ol
0>;ol`3eoo`0kool0?Koo03noo`0POo7ood0POnTood0`oom087od?ol0>coo03e
oo<0m?ol0>ooo03eoo`0o_ol09Soo03Roo<0mOol0>ooo03foo`0o_ol087oaoom
087of_l0i8Woo@21om3oo03/oo`0m_ol0?coo03eoo/0kook0?Ooo03moo/0VOol
0>?oo03loo`0m_ok0>oon`3hoo`0oOok087ob?om087oPOoRood0POo@oo`0k?ol
0?Koo03loo`0mOok0>oon`3goo`0oOok09Woo03Soo`0o?ol0?Kon`3_oo/0n?ol
0?gon`21olSoo@21oh7oh_om087od?ol0>coo03foo`0o?ol0?Gon`3_oo/0mool
0?gon`2Ioo`0hool0?coo03foo/0kook0?Soo03moo/0POo8ood0POoJo`3TROom
087od?ol0>coo03goo`0nOom0?Koo03]oo`0n?ok0?con`2Joo`0i?ol0?Woo@3g
oo`0kOol0?Won`3loo/0POo9ood0POn1on;oo@21om3oo03/oo`0mool0?Woo@3f
oo`0kOol0?Son`3loo/0V_ol0>Coo03iood0mool0>goo03ioo/0o?ok087obOom
087oPOoRood0POo@oo`0k?ol0?Ooo03iood0m_ol0>goo03hoo/0o?ok09[oo03T
oo`0nOom0?Ooo03]oo`0nOok0?con`21olWoo@21om[o0>B9ood0POo@oo`0k?ol
0?Ooo@3hood0m_ol0>goo03hoo`0n_ol09[oo03Tood0n?om0?Ooo03]oo`0nOol
0?[oo021olWoo@21oh7oh_om087od?ol0>coo03good0n?om0?Koo03]oo`0n?ol
0?[oo02Joo`0i?om0?Soo@3goo`0kOol0?Woo03joo`0POo9ood0POn1on;oo@21
om3oo03/oo`0moom0?Soo@3foo`0kOol0?Soo03joo`0V_ol0>Coo@3hood0mool
0>goo03ioo`0n_ol087obOom087of_l0i8Woo@21om3oo03/oo`0n?ol0?Ooo@3h
oo/0kOok0?[on`3joo/0Vool0>Goo03good0nOok0>gon`3koo/0n_ok087ob_om
087oPOoRood0POo@oo`0k?ol0?Soo03good0n?ok0>gon`3joo/0n_ok09_oo03U
oo`0moom0?Won`3]oo/0nook0?[on`21ol[oo@21oh7oh_om087od?ol0>coo03h
oo`0moom0?Son`3]oo/0n_ok0?[on`2Koo`0iOol0?Ooo@3ioo/0kOok0?_on`3j
oo/0POo:ood0POoJo`3/boom0<?oo@21om3oo03/oo`0n?om0?Koo@3hoo`0jool
0?_on`3hoo/0W?ol0>Goo@3food0nOol0>_oo03loo/0n?ok087oboom087oY?om
0<?oo@21om3oo03/oo`0n?om0?Koo@3hoo`0jool0?_on`3hoo/0W?ol0>Goo@3f
ood0nOol0>_oo03loo/0n?ok087oboom087oY?om0<?oo@21om3oo03/oo`0n?om
0?Koo@3hoo`0jool0?_on`3hoo/0W?ol0>Goo@3food0nOol0>_oo03loo/0n?ok
087oboom087of_l0k<_oo@33ood0POo@oo`0k?ol0?Soo@3food0n?ol0>_oo03k
oo`0m_ol09coo03Uood0m_om0?Woo03[oo`0o?ol0?Koo021ol_oo@21ojCoo@33
ood0POo@oo`0k?ol0?Soo@3food0n?ol0>_oo03koo`0m_ol09coo03Uood0m_om
0?Woo03[oo`0o?ol0?Koo021ol_oo@21ojCoo@33ood0POo@oo`0k?ol0?Soo@3f
ood0n?ol0>_oo03koo`0m_ol09coo03Uood0m_om0?Woo03[oo`0o?ol0?Koo021
ol_oo@21om[o0=C;ood0`oom087od?ol0>coo03hood0m_om0?Wog`3moo/0m_ok
09goiP3kood0m_om0?[og`3noo/0m_ok087oc?om087oY?om0<?oo@21om3oo03/
oo`0n?om0?Koo@3ioml0oOok0?Kon`2MonH0noom0?Koo@3joml0o_ok0?Kon`21
olcoo@21ojCoo@33ood0POo@oo`0k?ol0?Soo@3food0nOoO0?gon`3foo/0WOoV
0?_oo@3food0n_oO0?kon`3foo/0POo<ood0POoJo`2oboom0<?oo@21om3oo03/
oo/0j_om0?Wog`3noo/0m?ok09koiP3/ood0n_oO007ooo/0m?ok087ocOom087o
Y?om0<?oo@21om3oo03/oo/0j_om0?Wog`3noo/0m?ok09koiP3/ood0n_oO007o
oo/0m?ok087ocOom087oY?om0<?oo@21om3oo03/oo/0j_om0?Wog`3noo/0m?ok
09koiP3/ood0n_oO007ooo/0m?ok087ocOom087of_l0]hWoo@21om3oo03[oo`0
joom0?Sog`3noo`0l_ol09koiP3]ood0nOoO007ooo`0l_ol087ocOom087oPOoR
ood0POo@oo`0jool0>_oo@3homl0o_ol0?;oo02NonH0kOom0?Wog`01oool0?;o
o021olgoo@21oh7oh_om087od?ol0>_oo03[ood0n?oO0?koo03boo`0W_oV0>go
o@3ioml00Oooo03boo`0POo=ood0POoJo`2XROom087od?ol0>_on`3]oo`0nOoM
003on`3boo/0WooV0>koo03jomL0l_ok087oc_om087oPOoRood0POo@oo`0jook
0>goo03iomd00?ok0?;on`2OonH0k_ol0?[oe`3boo/0POo>ood0POn1on;oo@21
om3oo03[oo/0kOol0?Wog@00oo/0l_ok09ooiP3^oo`0n_oG0?;on`21olkoo@21
om[o04j9ood0POnLoo`0POnYoo`0POn7ood0POn1on;oo@21oicoo021ojWoo021
ohOoo@21oh7oh_om087oW?ol087oZOol087oQoom087of_l0CXWoo@21oigon`21
oj[on`21ohOoo@21oh7oh_om087oWOok087oZ_ok087oQoom087oPOoRood0POnM
oo/0POnZoo/0POn7ood0POoJo`1>ROom087oWook087oZ_ok087oQOom087oPOoR
ood0POnOoo/0POnZoo/0POn5ood0POn1on;oo@21oioon`21oj[on`21ohGoo@21
om[o05K;ood0`oom087oX?ok087oZ_ok087oQ?om087oY?om0<?oo@21oj3on`21
oj[on`21ohCoo@21ojCoo@33ood0POnPoo/0POnZoo/0POn4ood0POoJo`1Fboom
0<?oo@21oj;onP21oj_onP21oh?oo@21ojCoo@33ood0POnRooX0POn[ooX0POn3
ood0POnTood0`oom087oX_oj087oZooj087oPoom087of_l0E/_oo@33ood0POnS
oo/0POnZoo/0POn1ood0POnTood0`oom087oXook087oZ_ok087oPOom087oY?om
0<?oo@21oj?on`21oj[on`21oh7oo@21om[o05o;ood0`oom087oYOok087oZ_ok
087oPOl1ooom087oY?om0<?oo@21ojGon`21oj[on`21oh7o0Oooo@21ojCoo@33
ood0POnUoo/0POnZoo/0POn1o`7oood0POoJo`1DROom087oY_ok087oZ_ok087o
POonood0POn1on;oo@21ojKon`21oj[on`21oh7oo_om087oPOoRood0POnVoo/0
POnZoo/0POn1ookoo@21om[o06J9ood0^Oon0;oooP2food0POnXood0POn1ooco
o@21oh7oh_om0;WooP2oooh0]_om087oZ?om087oPOolood0POn1on;oo@2iooh0
_oon0;Koo@21ojSoo@21oh7oo?om087of_l0IXWoo@2jooh0_Oon0;Soo@21ojSo
o@21oh7onoom087oPOoRood0^_on0;gooP2hood0POnXood0POn1oo_oo@21oh7o
h_om0;[ooP2mooh0^?om087oZ?om087oPOokood0POoJo`1bROom0;_oo@3;oo`0
n?om0;[oo@21ojSoo@21oh7on_om087oPOoRood0^oom0<_oo03hood0^_om087o
Z?om087oPOojood0POn1on;oo@2kood0bool0?Soo@2jood0POnXood0POn1oo[o
o@21om[o07[;ood0`oom0;_ooP3:oo`0moon0;[oo@21ojSoo@21oh7on_om087o
Y?om0<?oo@2kooh0b_ol0?OooP2jood0POnXood0POn1oo[oo@21ojCoo@33ood0
^oon0<[oo03gooh0^_om087oZ?om087oPOojood0POoJo`1jboom0<?oo@2lood0
b_ol0?Ooo@2kooh0POnWooh0POn1ooWoo@21ojCoo@33ood0_?om0<[oo03good0
^oon087oYoon087oPOoiood0POnTood0`oom0;coo@3:oo`0moom0;_ooP21ojOo
oP21oh7onOom087of_l0M<_oo@33ood0_Oom0<Woo03food0_Oo]087o^?o]087o
ROom087oY?om0<?oo@2mood0bOol0?Koo@2mond0POnhond0POn9ood0POnTood0
`oom0;goo@39oo`0m_om0;gok@21okSok@21ohWoo@21om[o07C;ood0`oom0;go
o@39oo`0m_om0;gok@21okSok@21ohWoo@21ojCoo@33ood0_Oom0<Woo03food0
_Oo]087o^?o]087oROom087oY?om0<?oo@2mood0bOol0?Koo@2mond0POnhond0
POn9ood0POoJo`1/ROom0;koo@38oo`0mOom0;kok@21okSok@21ohWoo@21oh7o
h_om0;koo@38oo`0mOom0;kok@21okSok@21ohWoo@21oh7oh_om0;koo@38oo`0
mOom0;kok@21okSok@21ohWoo@21om[o0629ood0__om0<Soo03eood0POn1oh7o
POoEood0POn1on;oo@2nood0b?ol0?Goo@21oh7oPOn1omGoo@21oh7oh_om0;ko
o@38oo`0mOom087oPOn1oh7oeOom087of_l0H8Woo@2oood0aool0?Coo@21oh7o
POn1omKoo@21oh7oh_om0;ooo@37oo`0m?om087oPOn1oh7oe_om087oPOoRood0
_oom0<Ooo03dood0POn1oh7oPOoFood0POoJo`1PROom0;ooo@37oo`0m?om087o
POn1oh7oe_om087oPOoRood0_oom0<Ooo03dood0POn1oh7oPOoFood0POn1on;o
o@2oood0aool0?Coo@21oh7oPOn1omKoo@21om[o09S;ood0`oom0?Coo03boo`0
i_om0?Oon`3coo/0k_oc0?Soo@21oh7oPOn1omOoo@21ojCoo@33ood0m?ol0?;o
o03Vood0mook0??on`3^oo<0n?om087oPOn1oh7oeoom087oY?om0<?oo@3doo`0
l_ol0>Koo@3goo/0look0>kol`3hood0POn1oh7oPOoGood0POoJo`2Hboom0<?o
o@3doo`0l_ol0>Koo@3goo/0lool0>gol`3hood0POn1oh7oPOoGood0POnTood0
`oom0?Coo03boo`0i_om0?Oon`3coo`0kOoc0?Soo@21oh7oPOn1omOoo@21ojCo
o@33ood0m?ol0?;oo03Vood0mook0??oo03]oo<0n?om087oPOn1oh7oeoom087o
f_l0T<_oo@33ood0m?ol0?;oo03Woo`0m_ok0?Gon`3]oo<0n?ol087oPOn1oi;o
R021omooo@33ood0m?ol0?;oo03Woo`0m_ok0?Gon`3]oo<0n?ol087oPOn1oi;o
R021omooo@33ood0m?ol0?;oo03Woo`0m_ok0?Gon`3]oo<0n?ol087oPOn1oi;o
R02Eo`2@boom0<?oo@3doo`0l_ol0>Ooo@3doo`0m_ok0>col`3hoo`0POn1oh7o
T_n8087ogoom0<?oo@3doo`0l_ol0>Ooo@3doo`0m_ok0>col`3hoo`0POn1oh7o
T_n8087ogoom0<?oo@3doo`0l_ol0>Ooo@3doo`0m_ok0>col`3hoo`0POn1oh7o
T_n809Go08B9ood0m?ol0?;oo03Wood0m?ok0?Son`3Woo`0l_om087oPOn1oi;o
R021oigoo@3doo`0l_ol0>Ooo@3doo/0n?ok0>Ooo03bood0POn1oh7oT_n8087o
WOom0?Coo03boo`0ioom0?Con`3hoo/0iool0?;oo@21oh7oPOnBohP0UOl0Q8Wo
o@3doo`0l_ol0>Soo03coo/0nOok0>Ooo03boo`0POn1oh7oTon8087oWOom0?Co
o03boo`0j?ol0??on`3ioo/0iool0?;oo021oh7oPOnCohP0POnMood0m?ol0?;o
o03Xoo`0look0?Won`3Woo`0l_ol087oPOn1oi?oR02Eo`24ROom0?Coo03boo`0
j?ol0?;oo03joo/0i_ol0?;oo021oh7oPOnCohP0POnMood0m?ol0?;oo03Xoo`0
l_ol0?[on`3Voo`0l_ol087oPOn1oi?oR021oigoo@3doo`0l_ol0>Soo03boo`0
n_ok0>Koo03boo`0POn1oh7oTon809Go08B9ood0m?ol0?;oo03Xoo`0l_ok0?co
n`3Uoo`0l_ol087oPOn1oi?oR021oigoo@3doo`0l_ol0>Soo03boo/0o?ok0>Go
o03boo`0POn1oh7oTon8087oWOom0?Coo03boo`0j?ol0?;on`3loo/0iOol0?;o
o021oh7oPOnCohP0UOl0Q8Woo@3doo`0l_ol0>Soo@3`oo/0oOol0>Coo03aood0
POn1oh7oTon8087oWOom0?Coo03boo`0j?om0?3on`3moo`0i?ol0?7oo@21oh7o
POnCohP0POnMood0m?ol0?;oo03Xood0l?ok0?goo03Too`0lOom087oPOn1oi?o
R02Eo`2@boom0<?oo@3doo`0l_ol0>Woo03_oo`0o_ok0>Coo03aoo`0POn1oh7o
U?n8087ogoom0<?oo@3doo`0l_ol0>Woo03_oo`0o_ok0>Coo03aoo`0POn1oh7o
U?n8087ogoom0<?oo@3doo`0l_ol0>Woo03_oo`0o_ok0>Coo03aoo`0POn1oh7o
U?n809Go093;ood0`oom0?Coo03boo`0jOol0>oon`00oo/0hool0?7oo021oh7o
POnDohP0POoOood0`oom0?Coo03boo`0jOol0>oon`00oo/0hool0?7oo021oh7o
POnDohP0POoOood0`oom0?Coo03boo`0jOol0>oon`00oo/0hool0?7oo021oh7o
POnDohP0UOl0T<_oo@33ood0m?ol0?;oo03Yoo`0k_ol003oo03Roo`0lOol087o
POn1oiCoR021omooo@33ood0m?ol0?;oo03Yoo`0k_ol003oo03Roo`0lOol087o
POn1oiCoR021omooo@33ood0m?ol0?;oo03Yoo`0k_ol003oo03Roo`0lOol087o
POn1oiCoR02Eo`24boom0<?oo@3doo`0l_ol0>Woo03]ooL0h_ol0?7oo021oh7o
POnDohP0POoOood0`oom0?Coo03boo`0jOol0>gom`3Roo`0lOol087oPOn1oiCo
R021omooo@33ood0m?ol0?;oo03Yoo`0kOog0>;oo03aoo`0POn1oh7oU?n809Go
07R9ood0m?ol0?;oo03Yoo`0kOoh0>7oo03aoo`0POn1oh7oU?n8087oWOom0?Co
o03boo`0jOol0>gon03Qoo`0lOol087oPOn1oiCoR021oigoo@3doo`0l_ol0>Wo
o03]ooP0hOol0?7oo021oh7oPOnDohP0UOl0N8Woo@3doo`0l_ol0>Woo03/ooX0
h?ol0?7oo021oh7oPOnDohP0POnMood0m?ol0?;oo03Yoo`0k?oj0>3oo03aoo`0
POn1oh7oU?n8087oWOom0?Coo03boo`0jOol0>conP3Poo`0lOol087oPOn1oiCo
R02Eo`1hROom0?Coo03boo`0jOol0>conP3Poo`0lOol087oPOn1oh7oPOn1okOo
o@3doo`0l_ol0>Woo03/ooX0h?ol0?7oo021oh7oPOn1oh7oPOngood0m?ol0?;o
o03Yoo`0k?oj0>3oo03aoo`0POn1oh7oPOn1ojoo07R9ood0m?ol0?;oo03Yoo`0
kOoh0>7oo03aoo`0POn1oh7oPOn1oh7o]oom0?Coo03boo`0jOol0>gon03Qoo`0
lOol087oPOn1oh7oPOn1okOoo@3doo`0l_ol0>Woo03]ooP0hOol0?7oo021oh7o
POn1oh7o[ol0Q<_oo@33ood0m?ol0?;oo03Yoo`0kOoh0>7oo03aoo`0POn1oh7o
POn1oh7onOom0<?oo@3doo`0l_ol0>Woo03]ooP0hOol0?7oo021oh7oPOn1oh7o
POoiood0`oom0?Coo03boo`0jOol0>gon03Qoo`0lOol087oPOn1oh7oPOn_o`2@
boom0<?oo@3doo`0l_ol0?[onP3goo`0k_of0>;oo03aoo`0POn1oh7oPOn1oh7o
nOom0<?oo@3doo`0l_ol0?[onP3goo`0k_of0>;oo03aoo`0POn1oh7oPOn1oh7o
nOom0<?oo@3doo`0l_ol0?[onP3goo`0k_of0>;oo03aoo`0POn1oh7oPOn1ojoo
09c;ood0`oom0?Coo03boo`0o?of0?Woo03_oo/00?ok0>?oo03aoo`0POn1oh7o
POn1oh7onOom0<?oo@3doo`0l_ol0?comP3ioo`0kook003on`3Soo`0lOol087o
POn1oh7oPOn1ooWoo@33ood0m?ol0?;oo03looH0nOol0>oon`00oo/0hool0?7o
o021oh7oPOn1oh7o[ol0W<_oo@33ood0m?ol0?;oo03moo<0nool0>ooo03noo`0
hool0?7oo021oh7oPOn1oh7oPOoiood0`oom0?Coo03boo`0oOoc0?_oo03_oo`0
o_ol0>?oo03aoo`0POn1oh7oPOn1oh7onOom0<?oo@3doo`0l_ol0?gol`3koo`0
kool0?koo03Soo`0lOol087oPOn1oh7oPOn_o`2LROom0?Coo03coo/0o_ol0?co
o03koo`0l?ol0?gon`3Too`0lOol087oPOn1oh7oPOn1okOoo@3doo`0look0?ko
o03loo`0nool0?3oo03moo/0i?ol0?7oo021oh7oPOn1oh7oPOngood0m?ol0??o
n`3noo`0o?ol0?_oo03`oo`0oOok0>Coo03aoo`0POn1oh7oPOn1ojoo09n9ood0
m?ol0??on`01oool0?Woo@3kood0lOok0?con`3Uoo`0lOom087oPOn1oh7oPOn1
okKoo@3doo`0look007ooo`0nOom0?_oo@3aoo/0o?ok0>Goo03aood0POn1oh7o
POn1oh7o]_om0?Coo03coo/00Oooo03iood0noom0?7on`3loo/0iOol0?7oo@21
oh7oPOn1oh7o[_l0WhWoo@3doo`0look007oood0n?om0?_oo03boo`0n_ol0>Go
o03boo`0POn1oh7oTon8087oWOom0?Coo03coo/00Oooo@3hood0nool0?;oo03j
oo`0iOol0?;oo021oh7oPOnCohP0POnMood0m?ol0??on`01ooom0?Soo@3koo`0
l_ol0?[oo03Uoo`0l_ol087oPOn1oi?oR02Eo`2LROom0?Con`3eooX00?ol0?Oo
o@3loo`0look0?[on`3Voo`0l_ol087oPOn1oi?oR021oigoo@3doo/0mOoj003o
o03good0o?ol0??on`3joo/0i_ol0?;oo021oh7oPOnCohP0POnMood0m?ok0?Go
nP00oo`0moom0?coo03coo/0n_ok0>Koo03boo`0POn1oh7oTon809Go0:S;ood0
`oom0??oo03fooT00?om0?Koo@3loo`0m?ok0?Son`3Woo`0l_ol087oPOn1oi?o
R021omooo@33ood0lool0?Kon@00ood0m_om0?coo03doo/0n?ok0>Ooo03boo`0
POn1oh7oTon8087ogoom0<?oo@3coo`0m_oi003oo@3food0o?ol0?Con`3hoo/0
iool0?;oo021oh7oPOnCohP0UOl0]<_oo@33ood0look0?Son000ood0m_om0?_o
o@3doo`0m_ol0?Ooo03foo/0loom087oPOn1oi;oR021omooo@33ood0look0?So
n000ood0m_om0?_oo@3doo`0m_ol0?Ooo03foo/0loom087oPOn1oi;oR021omoo
o@33ood0look0?Son000ood0m_om0?_oo@3doo`0m_ol0?Ooo03foo/0loom087o
POn1oi;oR02Eo`2dboom0<?oo@3cooX0noof003oo@3food0nool0?Kon`3foo/0
n?ol0?Kom`3good0POn1oh7oT_n8087ogoom0<?oo@3cooX0noof003oo@3food0
nool0?Kon`3foo/0n?ol0?Kom`3good0POn1oh7oT_n8087ogoom0<?oo@3cooX0
noof003oo@3food0nool0?Kon`3foo/0n?ol0?Kom`3good0POn1oh7oT_n809Go
0:S;ood0`oom0?;ol000oo`0lOom0?_oo03goo/0m?ok0?Woo03eooP0n?ol087o
POn1oi;oR021omooo@33ood0l_o`003oo03aood0nool0?Oon`3doo/0nOol0?Go
n03hoo`0POn1oh7oT_n8087ogoom0<?oo@3boo000?ol0?7oo@3koo`0mook0?Co
n`3ioo`0mOoh0?Soo021oh7oPOnBohP0UOl0WhWoo@3aoo800Oooo03bood0nOom
0?Ooo03boo`0nOol0?Con@3hood0POn1oh7oTOn8087oWOom0?7olP01oool0?;o
o@3iood0mool0?;oo03ioo`0m?oi0?Soo@21oh7oPOnAohP0POnMood0lOob007o
oo`0l_om0?Woo@3goo`0l_ol0?Woo03dooT0n?om087oPOn1oi7oR02Eo`2LROom
0?3om@3moo`0lool0?Woo@3hoo/0l_ok0?[oo03cooX0n?om087oPOn1oi7oR021
oigoo@3`ooD0oOol0??oo03iood0n?ok0?;on`3joo`0looj0?Soo@21oh7oPOnA
ohP0POnMood0l?oe0?goo03coo`0nOom0?Son`3boo/0n_ol0??onP3hood0POn1
oh7oTOn809Go06b9ood0k_oi0>Woo03good0eOon0>Coo@21oh7oPOn@ohP0POnM
ood0k_oi0>Woo03good0eOon0>Coo@21oh7oPOn@ohP0POnMood0k_oi0>Woo03g
ood0eOon0>Coo@21oh7oPOn@ohP0UOl0H8Woo@3?oo/0moom0=GooP3Tood0POn1
oh7oT?n8087oWOom0<oon`3good0eOon0>Coo@21oh7oPOn@ohP0POnMood0cook
0?Ooo@3Eooh0i?om087oPOn1oi3oR02Eo`1PROom0=7on`3dood0e_on0>Goo@21
oh7oPOn?ohP0POnMood0dOok0?Coo@3Fooh0iOom087oPOn1ohooR021oigoo@3A
oo/0m?om0=KooP3Uood0POn1oh7oSon809Go06c;ood0`oom0=;on`3cood0e_on
0>Goo@21oh7oPOn?ohP0POoOood0`oom0=;on`3cood0e_on0>Goo@21oh7oPOn?
ohP0POoOood0`oom0=;on`3cood0e_on0>Goo@21oh7oPOn?ohP0UOl0K<_oo@33
ood0e?oj0?7oo@3Hooh0iOom087oPOn1ohkoR021omooo@33ood0e?oj0?7oo@3H
ooh0iOom087oPOn1ohkoR021omooo@33ood0e?oj0?7oo@3Hooh0iOom087oPOn1
ohkoR02Eo`1dboom0<?oo@3Eoo/0koom0=SooP3Uood0POn1oh7oPOoDood0POnT
ood0`oom0=Gon`3_ood0f?on0>Goo@21oh7oPOn1omCoo@21ojCoo@33ood0eOok
0>ooo@3Hooh0iOom087oPOn1oh7oe?om087of_l0M<_oo@33ood0eook0>coo@3J
ood0i_om087oPOn1oh7odoom087oY?om0<?oo@3Goo/0k?om0=[oo@3Vood0POn1
oh7oPOoCood0POnTood0`oom0=Oon`3/ood0f_om0>Koo@21oh7oPOn1om?oo@21
om[o06b9ood0f?ok0>[ooP3Jooh0iOon087oPOn1oh7od_om087oPOoRood0f?ok
0>[ooP3Jooh0iOon087oPOn1oh7od_om087oPOoRood0f?ok0>[ooP3Jooh0iOon
087oPOn1oh7od_om087of_l0K8Woo@3Hood0j?om0=_o003Tood0POn1oh7oPOoB
ood0POn1on;oo@3Hood0j?om0=_o003Tood0POn1oh7oPOoBood0POn1on;oo@3H
ood0j?om0=_o003Tood0POn1oh7oPOoBood0POoJo`1PROom0=Woo@3Vooh0_Oon
087oPOn1oh7odOom087oPOoRood0fOom0>KooP2mooh0POn1oh7oPOoAood0POn1
on;oo@3Iood0i_on0;gooP21oh7oPOn1om7oo@21om[o0629ood0f_om0>CooP2o
ooh0POn1oh7oPOo@ood0POn1on;oo@3Jood0i?on0;oooP21oh7oPOn1om3oo@21
oh7oh_om0=[oo@3Tooh0_oon087oPOn1oh7od?om087of_l0E/_oo@33ood0f_om
087oPOn1oh7oPOo[ood0POnTood0`oom0=[oo@21oh7oPOn1oh7ojoom087oY?om
0<?oo@3Jood0POn1oh7oPOn1on_oo@21om[o05K;ood0`oom0=[ooP21oh7oPOn1
oh7oj_om087oY?om0<?oo@3Jooh0POn1oh7oPOn1on[oo@21ojCoo@33ood0f_on
087oPOn1oh7oPOoZood0POoJo`1Fboom0<?oo@3Kond0POn1oh7oPOn1oo[oo@21
ojCoo@33ood0foo]087oPOn1oh7oPOojood0POnTood0`oom0=_ok@21oh7oPOn1
oh7on_om087of_l0E/_oo@33ood0foo]087oPOn1oh7oPOojood0POnTood0`oom
0=_ok@21oh7oPOn1oh7on_om087oY?om0<?oo@3Kond0POn1oh7oPOn1oo[oo@21
om[o05B9ood0foo]087oPOn1oh7oPOojood0goog087oS_om0=_ok@21oh7oPOn1
oh7on_om0=oom`21ohkoo@3Kond0POn1oh7oPOn1oo[oo@3OooL0Q_l0HhWoo@21
oh7oPOn1oh7o`?om0>;ol@3_o`400=gon`21olooo@21oh7oPOn1oh7o`?om0>;o
l@3_o`400=gon`21olooo@21oh7oPOn1oh7o`?om0>;ol@3_o`400=gon`37o`1P
ROom087oPOn1oh7oPOo0ood0i?o]0?;ooP3NooT0POo@ood0POn1oh7oPOn1ol3o
o@3Tond0l_on0=kon@21om3oo@21oh7oPOn1oh7o`?om0>Cok@3booh0g_oi0<So
0629ood0POn1oh7oPOn1ol3oo@3VonX0m?om0=kon@21om3oo@21oh7oPOn1oh7o
`?om0>KojP3dood0g_oi087od?om087oPOn1oh7oPOo0ood0i_oZ0?Coo@3NooT0
b?l0M<_oo@33ood0POn1oh7oPOn1ol3oo@3WooP0nOoi0?GooP3MooT0T_om0<?o
o@21oh7oPOn1oh7o`?om0>Oon03iooT0mOon0=gon@2Bood0`oom087oPOn1oh7o
POo0ood0iooh0?Won@3eooh0gOoi0<So07C;ood0`oom087oPOn1oh7oPOo0ood0
j?oj0?ConP3fooh0g_og09?oo@33ood0POn1oh7oPOn1ol3oo@3XooX0m?oj0?Ko
oP3NooL0Toom0<?oo@21oh7oPOn1oh7o`?om0>SonP3dooX0m_on0=kom`39o`1d
boom0<?oo@21oh7oPOn1oh7o`?om0>Won`3`oo/0n?on0=gom`2Cood0`oom087o
POn1oh7oPOo0ood0jOok0?3on`3hooh0gOog09?oo@33ood0POn1oh7oPOn1ol3o
o@3Yoo/0l?ok0?SooP3MooL0bOl0M<_oo@33ood0POn1oh7oPOn1ol3oo@3Zoo/0
k_ok0?WooP3MooL0Toom0<?oo@21oh7oPOn1oh7o`?om0>[on`3^oo/0nOon0=go
m`2Cood0`oom087oPOn1oh7oPOo0ood0j_ok0>kon`3iooh0gOog0<Wo07R9ood0
POn1oh7oPOn1ol3oo@3[oo/0k?ol0?WooP3Noo/00?ol087od_om087oPOn1oh7o
POo0ood0jook0>coo03iooh0g_ok003oo021om;oo@21oh7oPOn1oh7o`?om0>_o
n`3/oo`0nOon0=kon`00oo`0b_l0NhWoo@21oh7oPOn1oh7o`?om0>_oo03[oo/0
n_on0=koo001oool087od_om087oPOn1oh7oPOo0ood0jool0>_on`3jooh0g_ol
007ooo`0POoBood0POn1oh7oPOn1ol3oo@3[oo`0jook0?[ooP3Noo`00Oooo03:
o`1kROom087oPOn1oh7oPOo0ood0k?ok0>[oo03joo`0h?ol007ooo/0POoCood0
POn1oh7oPOn1ol3oo@3/oo/0j_ol0?[oo03Poo`00Ooon`21om?oo@21oh7oPOn1
oh7o`?om0>con`3Zoo`0n_ol0>3oo001oook0<_o07R9ood0POn1oh7oPOn1ol3o
o@3/oo`0jOok0?_oo03Qoo/0o_ol087odoom087oPOn1oh7oPOo0ood0k?ol0>Wo
n`3koo`0hOok0?koo021om?oo@21oh7oPOn1oh7o`?om0>coo03Yoo/0nool0>7o
n`3noo`0bol0T8Woo@21oh7oPOn1oh7o`?om0>gon`3Xoo`0nool0>7oo03moo`0
m?ok0??on`21oo[oo@21oh7oPOn1oh7o`?om0>gon`3Xoo`0nool0>7oo03moo`0
m?ok0??on`21oo[oo@21oh7oPOn1oh7o`?om0>gon`3Xoo`0nool0>7oo03moo`0
m?ok0??on`3bo`2Hboom0<?oo@21oh7oPOn1oh7o`?om0>goo03Woo`0nool0>7o
o03moo/0mOok0??oo02kood0`oom087oPOn1oh7oPOo0ood0kOol0>Ooo03koo`0
hOol0?gon`3eoo/0lool0;_oo@33ood0POn1oh7oPOn1ol3oo@3]oo`0iool0?_o
o03Qoo`0oOok0?Gon`3coo`0lOl0S<_oo@33ood0POn1oh7oPOn1ol3oo@3]oo`0
g?ol0>;oo03koo`0m?ok0?Gon`2kood0`oom087oPOn1oh7oPOo0ood0kOol0=co
o03Roo`0nool0?Con`3eoo/0^oom0<?oo@21oh7oPOn1oh7o`?om0>goo03Loo`0
h_ol0?_oo03doo/0mOok0?7o083;ood0`oom087oPOn1oh7oPOo0ood0kOol0;So
o03koo`0lool0?Kon`2jood0`oom087oPOn1oh7oPOo0ood0kOol0;Soo03koo`0
lool0?Kon`2jood0`oom087oPOn1oh7oPOo0ood0kOol0;Soo03koo`0lool0?Ko
n`3`o`20boom0<?oo@21oh7oPOn1oh7o`?om0>kon`2ioo/0nook0?Con`3hoo/0
^Oom0<?oo@21oh7oPOn1oh7o`?om0>kon`2ioo/0nook0?Con`3hoo/0^Oom0<?o
o@21oh7oPOn1oh7o`?om0>kon`2ioo/0nook0?Con`3hoo/0kol0N8Woo@21oh7o
POn1oh7o`?om0>koo02hoo`0nOol0??on`3ioo/0POogood0POn1oh7oPOn1ol3o
o@3^oo`0^?ol0?Woo03coo/0nOok087omoom087oPOn1oh7oPOo0ood0k_ol0;So
o03ioo`0look0?Won`3_o`1hROom087oPOn1oh7oPOo0ood0k_ol0;Soo03ioo`0
l_ol0?[on`21ooKoo@21oh7oPOn1oh7o`?om0>koo02hoo`0nOol0?;oo03joo/0
POofood0POn1oh7oPOn1ol3oo@3^oo`0^?ol0?Woo03boo`0n_ok0>ko07R9ood0
POn1oh7oPOn1ol3oo@3^oo`0^Ook0?Won`3coo/0o?ok087omOom087oPOn1oh7o
POo0ood0k_ol0;Won`3ioo/0look0?con`21ooGoo@21oh7oPOn1oh7o`?om0>ko
o02ioo/0nOok0??on`3loo/0kOl0N8Woo@21oh7oPOn1oh7o`?om0>koo02ioo`0
mool0?;on`3moo`0POodood0POn1oh7oPOn1ol3oo@3^oo`0^Ool0?Ooo03boo/0
oOol087om?om087oPOn1oh7oPOo0ood0k_ol0;Woo03goo`0l_ok0?goo03/o`20
boom0<?oo@21oh7oPOn1oh7o`?om0>koo02ioo`0mool0?7oo03noo/0]_om0<?o
o@21oh7oPOn1oh7o`?om0>koo02ioo`0mool0?7oo03noo/0]_om0<?oo@21oh7o
POn1oh7o`?om0>koo02ioo`0mool0?7oo03noo/0k?l0P<_oo@33ood0POn1oh7o
POn1ol3oo@3^oo`0^_ok0?Oon`3boo/00?ok0;Goo@33ood0POn1oh7oPOn1ol3o
o@3^oo`0^_ok0?Oon`3boo/00?ok0;Goo@33ood0POn1oh7oPOn1ol3oo@3^oo`0
^_ok0?Oon`3boo/00?ok0>_o083;ood0`oom087oPOn1oh7oPOo0ood0k_ol0;[o
o03eoo`0lOol003oo02dood0`oom087oPOn1oh7oPOo0ood0k_ol0;[oo03eoo`0
lOol003oo02dood0`oom087oPOn1oh7oPOo0ood0k_ol0;[oo03eoo`0lOol003o
o03Zo`1dboom0<?oo@21oh7oPOn1oh7o`?om0>koo02joo`0mOol0?3om`2dood0
`oom087oPOn1oh7oPOo0ood0k_ol0;[oo03eoo`0l?og0;Coo@33ood0POn1oh7o
POn1ol3oo@3^oo`0^_ol0?Goo03`ooL0j_l0K8Woo@21oh7oPOn1oh7o`?om0>ko
o02koo/0m?ol0?7on021oo7oo@21oh7oPOn1oh7o`?om0>koo02koo/0m?ol0?7o
n021oo7oo@21oh7oPOn1oh7o`?om0>koo02koo/0m?ol0?7on03Yo`1/ROom087o
POn1oh7oPOo0ood0k_ol0;_oo03coo`0l?oj087ol?om087oPOn1oh7oPOo0ood0
k_ol0;_oo03coo`0l?oj087ol?om087oPOn1oh7oPOo0ood0k_ol0;_oo03coo`0
l?oj0>So06b9ood0POn1oh7oPOn1ol3oo@3^oo`0^ool0??on`3aooX0POo`ood0
POn1oh7oPOn1ol3oo@3^oo`0^ool0??on`3aooX0POo`ood0POn1oh7oPOn1ol3o
o@3^oo`0^ool0??on`3aooX0j?l0N8Woo@21oh7oPOn1oh7o`?om0>goo03Woo`0
g?ol0?7oo03booP0POoaood0POn1oh7oPOn1ol3oo@3]oo`0iool0=coo03aoo`0
l_oh087olOom087oPOn1oh7oPOo0ood0kOol0>Ooo03Loo`0lOol0?;on03Yo`20
boom0<?oo@21oh7oPOn1oh7o`?om0>goo03Woo`0g?ol0?7oo03booP0/oom0<?o
o@21oh7oPOn1oh7o`?om0>goo03Woo`0g?ol0?7oo03booP0/oom0<?oo@21oh7o
POn1oh7o`?om0>goo03Woo`0g?ol0?7oo03booP0jOl0S<_oo@33ood0POn1oh7o
POn1ol3oo@3]oo`0j?ok0?GonP3`oo/0lOok0?ComP2dood0`oom087oPOn1oh7o
POo0ood0kOol0>Son`3eooX0l?ok0?7on`3dooH0]?om0<?oo@21oh7oPOn1oh7o
`?om0>goo03Xoo/0mOoj0?3on`3aoo/0m?of0>[o09S;ood0`oom087oPOn1oh7o
POo0ood0kOok0>Woo03fooH0l_ol0>ooo03eoo/00?ok0;Goo@33ood0POn1oh7o
POn1ol3oo@3]oo/0jOol0?KomP3boo`0kool0?Gon`00oo/0]Oom0<?oo@21oh7o
POn1oh7o`?om0>gon`3Yoo`0m_of0?;oo03_oo`0mOok003on`3[o`2Hboom0<?o
o@21oh7oPOn1oh7o`?om0>coo03Yoo`0mooc0?Coo03_oo`0mOol0?koo02eood0
`oom087oPOn1oh7oPOo0ood0k?ol0>Woo03goo<0m?ol0>ooo03eoo`0o_ol0;Go
o@33ood0POn1oh7oPOn1ol3oo@3/oo`0jOol0?Ool`3doo`0kool0?Goo03noo`0
jol0W8Woo@21oh7oPOn1oh7o`?om0>con`3[oo/0n?ol0?coo03eoo/0kook0?Oo
o03moo/0POodood0POn1oh7oPOn1ol3oo@3/oo/0jook0?Soo03loo`0mOok0>oo
n`3goo`0oOok087om?om087oPOn1oh7oPOo0ood0k?ok0>_on`3hoo`0o?ol0?Go
n`3_oo/0mool0?gon`3/o`2LROom087oPOn1oh7oPOo0ood0jool0>_oo03hoo`0
nOom0?Koo03]oo`0n?ok0?con`21ooGoo@21oh7oPOn1oh7o`?om0>_oo03[oo`0
n?ol0?Woo@3foo`0kOol0?Son`3loo/0POoeood0POn1oh7oPOn1ol3oo@3[oo`0
jool0?Soo03iood0m_ol0>goo03hoo/0o?ok0>go09b9ood0POn1oh7oPOn1ol3o
o@3[oo/0kOok0?Soo@3hood0m_ol0>goo03hoo`0n_ol087omOom087oPOn1oh7o
POo0ood0jook0>gon`3hood0n?om0?Koo03]oo`0n?ol0?[oo021ooGoo@21oh7o
POn1oh7o`?om0>_on`3]oo/0n?om0?Soo@3foo`0kOol0?Soo03joo`0kOl0W8Wo
o@21oh7oPOn1oh7o`?om0>[on`3_oo/0n?ol0?Ooo@3hoo/0kOok0?[on`3joo/0
POofood0POn1oh7oPOn1ol3oo@3Zoo/0kook0?Soo03good0n?ok0>gon`3joo/0
n_ok087om_om087oPOn1oh7oPOo0ood0j_ok0>oon`3hoo`0moom0?Son`3]oo/0
n_ok0?[on`3^o`2LROom087oPOn1oh7oPOo0ood0jOok0?7on`3good0m_om0?So
o03[oo`0nook0?Son`21ooOoo@21oh7oPOn1oh7o`?om0>Won`3aoo/0moom0?Ko
o@3hoo`0jool0?_on`3hoo/0POogood0POn1oh7oPOn1ol3oo@3Yoo/0lOok0?Oo
o@3food0n?ol0>_oo03koo/0n?ok0>oo0:C;ood0`oom087oPOn1oh7oPOo0ood0
jOoi0?GonP3food0m_om0?Soo03[oo`0nool0?Koo02iood0`oom087oPOn1oh7o
POo0ood0jOoi0?GonP3food0m_om0?Soo03[oo`0nool0?Koo02iood0`oom087o
POn1oh7oPOo0ood0jOoi0?GonP3food0m_om0?Soo03[oo`0nool0?Koo03_o`2H
boom0<?oo@21oh7oPOn1oh7o`?om0>Son03iooT0mOom0?Koo@3ioml0oOok0?Ko
n`2jood0`oom087oPOn1oh7oPOo0ood0j?oh0?Won@3eood0m_om0?Wog`3moo/0
m_ok0;[oo@33ood0POn1oh7oPOn1ol3oo@3XooP0nOoi0?Goo@3food0nOoO0?go
n`3foo/0l?l0P<_oo@33ood0POn1oh7oPOn1ol3oo@3Von/0iOom0?Wog`3noo/0
m?ok0;_oo@33ood0POn1oh7oPOn1ol3oo@3Von/0iOom0?Wog`3noo/0m?ok0;_o
o@33ood0POn1oh7oPOn1ol3oo@3Von/0iOom0?Wog`3noo/0m?ok0?7o083;ood0
`oom087oPOn1oh7oPOo0ood0iOo]0>Goo@3homl0o_ol0?;oo02kood0`oom087o
POn1oh7oPOo0ood0iOo]0>Goo@3homl0o_ol0?;oo02kood0`oom087oPOn1oh7o
POo0ood0iOo]0>Goo@3homl0o_ol0?;oo03ao`1hROom087oPOn1oh7oPOo0ood0
hooa0>Coo03iomd00?ok0?;on`21oo[oo@21oh7oPOn1oh7o`?om0>?ol@3Too`0
nOoM003on`3boo/0POojood0POn1oh7oPOn1ol3oo@3Soo40i?ol0?Wog@00oo/0
l_ok0?;o05B9ood0POn1oh7oPOn1ol3oo@3PooP0hOol087o/Oom087oPOn1oh7o
POo0ood0h?oh0>7oo021ok7oo@21oh7oPOn1oh7o`?om0>3on03Qoo`0ZOl0B8Wo
o@21oh7oPOn1oh7o`?om0;Son`21ok7oo@21oh7oPOn1oh7o`?om0;Son`21ok7o
o@21oh7oPOn1oh7o`?om0;Son`2Yo`18ROom087oPOn1oh7oPOo0ood0^_ok087o
[oom087oPOn1oh7oPOo0ood0^_ok087o[oom087oPOn1oh7oPOo0ood0^_ok0:Oo
05C;ood0`oom087oPOn1oh7oPOo0ood0^ook087ol?om0<?oo@21oh7oPOn1oh7o
`?om0;_on`21oo3oo@33ood0POn1oh7oPOn1ol3oo@2koo/0Y_l0E<_oo@33ood0
POn1oh7oPOn1ol3oo@2mooX0POo_ood0`oom087oPOn1oh7oPOo0ood0_Ooj087o
koom0<?oo@21oh7oPOn1oh7o`?om0;gonP2Uo`1Dboom0<?oo@21oh7oPOn1oh7o
`?om0;kon`21ongoo@33ood0POn1oh7oPOn1ol3oo@2noo/0POo]ood0`oom087o
POn1oh7oPOo0ood0__ok0:?o05C;ood0`oom087oPOn1oh7oPOo0ood0`?ok087o
joom0<?oo@21oh7oPOn1oh7o`?om0<3on`21on_oo@33ood0POn1oh7oPOn1ol3o
o@30oo/0XOl0B9Sog`21oh7oPOn1oh7ocoom0<7on`21okOog`21oh7oPOn1oh7o
coom0<7on`21okOog`21oh7oPOn1oh7ocoom0<7on`2Po`18V?oO087oPOn1oh7o
POo?ood0`Oom087o]OoO087oPOn1oh7oPOo?ood0`Oom087o]OoO087oPOn1oh7o
POo?ood0`Oom09ko04RGon40POn1oh7oPOn1olkoo@32ood0POncon40POn1oh7o
POn1olkoo@32ood0POncon40POn1oh7oPOn1olkoo@32ood0WOl0B9Ooh@21oh7o
POn1oh7oc_om0<?oo@21ok;oh@21oh7oPOn1oh7oc_om0<?oo@21ok;oh@21oh7o
POn1oh7oc_om0<?oo@2Lo`1Dboom0=7oh@21oh7oPOn1oh7oc_om0<?oo@21onKo
o@3Aon40POn1oh7oPOn1olkoo@33ood0POoVood0dOoQ087oPOn1oh7oPOo>ood0
`oom09co05C;ood0d?oS087oPOn1oh7oPOo=ood0`oon087oiOom0=3oh`21oh7o
POn1oh7ocOom0<?ooP21onGoo@3@on<0POn1oh7oPOn1olgoo@33ooh0Vol0E<_o
o@3@on<0POn1oh7oPOn1olgoo@34ond0POoeood0d?oS087oPOn1oh7oPOo=ood0
a?o]087omOom0=3oh`21oh7oPOn1oh7ocOom0<Cok@2[o`1Dboom0<ooi@21oh7o
POn1oh7oc?om0<Cok@21ooGoo@3?onD0POn1oh7oPOn1olcoo@34ond0POoeood0
cooU087oPOn1oh7oPOo<ood0a?o]0:_o04REonD0POn1oh7oPOn1olcoo@34ond0
POnoonD0POn1oh7oPOn1olcoo@34ond0POnoonD0POn1oh7oPOn1olcoo@34ond0
Zol0@YGoi@21oh7oPOn1oh7oc?om087oPOo^onD0POn1oh7oPOn1olcoo@21oh7o
k_oU087oPOn1oh7oPOo<ood0POoJo`12U?oW087oPOn1oh7oPOo;ood0POn1ongo
i`21oh7oPOn1oh7oboom087oPOo]onL0POn1oh7oPOn1ol_oo@21om[o04:DonL0
POn1oh7oPOn1ol_oo@21oh7okOoW087oPOn1oh7oPOo;ood0POn1ongoi`21oh7o
POn1oh7oboom087of_l0@YCoi`21oh7oPOn1oh7oboom087oPOo]onL0POn1oh7o
POn1ol_oo@21oh7okOoW087oPOn1oh7oPOo;ood0POoJo`1:boom0<goj@21oh7o
POn1oh7ob_om087oY?om0<goj@21oh7oPOn1oh7ob_om087oY?om0<goj@21oh7o
POn1oh7ob_om087of_l0B/_oo@3=onT0POn1oh7oPOn1ol[oo@21ojCoo@3=onT0
POn1oh7oPOn1ol[oo@21ojCoo@3=onT0POn1oh7oPOn1ol[oo@21om[o04[;ood0
c?o[087oPOn1oh7oPOo9ood0POnTood0c?o[087oPOn1oh7oPOo9ood0POnTood0
c?o[087oPOn1oh7oPOo9ood0POoJo`1:boom0<coj`21oh7oPOn1oh7obOom087o
Y?om0<coj`21oh7oPOn1oh7obOom087oY?om0<coj`21oh7oPOn1oh7obOom087o
f_l0@Y;oj`21oh7oPOn1oh7obOom087oPOo[on/0POn1oh7oPOn1olWoo@21oh7o
joo[087oPOn1oh7oPOo9ood0POoJo`12TOo]087oPOn1oh7oPOo8ood0POn1on[o
k@21oh7oPOn1oh7ob?om087oPOoZond0POn1oh7oPOn1olSoo@21om[o04:Aond0
POn1oh7oPOn1olSoo@21oh7oj_o]087oPOn1oh7oPOo8ood0POn1on[ok@21oh7o
POn1oh7ob?om087of_l0@Y7ok@21oh7oPOn1oh7ob?om087oPOoZond0POn1oh7o
POn1olSoo@21oh7oj_o]087oPOn1oh7oPOo8ood0POoJo`1:boom0<[ok`21oh7o
POn1oh7oaoom087oY?om0<[ok`21oh7oPOn1oh7oaoom087oY?om0<[ok`21oh7o
POn1oh7oaoom087of_l0B/_oo@3:onl0POn1oh7oPOn1olOoo@21ojCoo@3:onl0
POn1oh7oPOn1olOoo@21ojCoo@3:onl0POn1oh7oPOn1olOoo@21om[o04[;ood0
bOo`087oPOn1oh7oPOo7ood0POnTood0bOo`087oPOn1oh7oPOo7ood0POnTood0
bOo`087oPOn1oh7oPOo7ood0POoJo`1:boom0<Wol@21oh7oPOn1oh7oa_om087o
Y?om0<Wol@21oh7oPOn1oh7oa_om087oY?om0<Wol@21oh7oPOn1oh7oa_om087o
f_l0@Xool@21oh7oPOn1oh7oa_om087oPOoXoo40POn1oh7oPOn1olKoo@21oh7o
j?oa087oPOn1oh7oPOo6ood0POoJo`12S_oc087oPOn1oh7oPOo5ood0POn1onOo
l`21oh7oPOn1oh7oaOom087oPOoWoo<0POn1oh7oPOn1olGoo@21om[o04:>oo<0
POn1oh7oPOn1olGoo@21oh7oiooc087oPOn1oh7oPOo5ood0POn1onOol`21oh7o
POn1oh7oaOom087of_l0@Xkol`21oh7oPOn1oh7oaOom087oPOoWoo<0POn1oh7o
POn1olGoo@21oh7oiooc087oPOn1oh7oPOo5ood0POoJo`1:boom0<Oom@21oh7o
POn1oh7oa?om087oY?om0<Oom@21oh7oPOn1oh7oa?om087oY?om0<Oom@21oh7o
POn1oh7oa?om087of_l0B/_oo@37ooD0POn1oh7oPOn1olCoo@21ojCoo@37ooD0
POn1oh7oPOn1olCoo@21ojCoo@37ooD0POn1oh7oPOn1olCoo@21om[o04[;ood0
aooe087oPOn1oh7oPOo4ood0POnTood0aooe087oPOn1oh7oPOo4ood0POnTood0
aooe087oPOn1oh7oPOo4ood0POoJo`1:boom0<Kom`21oh7oPOn1oh7o`oom087o
Y?om0<Kom`21oh7oPOn1oh7o`oom087oY?om0<Kom`21oh7oPOn1oh7o`oom087o
f_l0@Xcom`21oh7oPOn1oh7o`oom087oPOoUooL0POn1oh7oPOn1ol?oo@21oh7o
iOog087oPOn1oh7oPOo3ood0POoJo`12Rooi087oPOn1oh7oPOo2ood0POn1onCo
n@21oh7oPOn1oh7o`_om087oPOoTooT0POn1oh7oPOn1ol;oo@21om[o04:;ooT0
POn1oh7oPOn1ol;oo@21oh7oi?oi087oPOn1oh7oPOo2ood0POn1onCon@21oh7o
POn1oh7o`_om087of_l0@X_on@21oh7oPOn1oh7oaOoh087oPOoVooT0POn1oh7o
POn1olGon021oh7oi_oi087oPOn1oh7oPOo5ooP0POoLo`12R_ok087oPOn1oh7o
POo5ooD0POn1onOon`21oh7oPOn1oh7oaOoe087oPOoWoo/0POn1oh7oPOn1olGo
m@21omko04[;ood0a?ok087oPOn1oh7oPOo7oo80POnYood0a?ok087oPOn1oh7o
POo7oo80POnYood0a?ok087oPOn1oh7oPOo7oo80POoOo`1:boom0<Con`21oh7o
POn1oh7ob?o`087oZ_om0<Con`21oh7oPOn1oh7ob?o`087oZ_om0<Con`21oh7o
POn1oh7ob?o`087oh?l0B/_oo@33ood0POn1oh7oPOn1olOok`21oj_oo@33ood0
POn1oh7oPOn1olOok`21oj_oo@33ood0POn1oh7oPOn1olOok`21on7o04[;ood0
`oom087oPOn1oh7oPOo8onh0POn[ood0`oom087oPOn1oh7oPOo8onh0POn[ood0
`oom087oPOn1oh7oPOo8onh0POoQo`15R?l10021oh7oPOn1oh7oaoo^087oPOoX
o`40087oPOn1oh7oPOo7onh0POn1onSo0@00POn1oh7oPOn1olOokP21on7o04F8
o`40087oPOn1oh7oPOo7ond0POn1onWo0@00POn1oh7oPOn1olOok@21oh7ojOl1
0021oh7oPOn1oh7oaoo]087oh_l0=_goP@210840P@210840P@2M0?goP@210840
P@210840P@2M0?goP@210840P@210840P@2M000foOn10840P@210840P@2109d0
oOn10840P@210840P@2109d0oOn10840P@210840P@2109d003Kmoh40P@210840
P@210840W@3moh40P@210840P@210840W@3moh40P@210840P@210840W@00=_go
P@210840P@210840P@2M0?goP@210840P@210840P@2M0?goP@210840P@210840
P@2M000nboom087oPOn1oh7oPOn6onh0POn[ood0POn1oh7oPOn1ohKokP21oj_o
o@21oh7oPOn1oh7oQ_o^087ohOl0?/_oo@21oh7oPOn1oh7oQ_o^087oZoom087o
POn1oh7oPOn6onh0POn[ood0POn1oh7oPOn1ohKokP21on7o03R1oh7oPOn1oh7o
POo<onh0POn1oh7oPOn1oh7oPOn/onh0POn1oh7oPOn1oh7oPOn/onh0POoQo`0h
POn1oh7oPOn1oh7oboo`087oPOn1oh7oPOn1oh7oZ_o`087oPOn1oh7oPOn1oh7o
Z_o`087oh?l0>87oPOn1oh7oPOn1ol[ol@21oh7oPOn1oh7oPOn1ojWol@21oh7o
POn1oh7oPOn1ojWol@21on3o03R1oh7oPOn1oh7oPOo:oo80POn1oh7oPOn1oh7o
POnXoo80POn1oh7oPOn1oh7oPOnXoo80POoOo`0nboom087oPOn1oh7oPOn2ooD0
POnXood0POn1oh7oPOn1oh;om@21ojSoo@21oh7oPOn1oh7oP_oe087og_l0A<_o
o@21oh7oPOn1oh7oPOl0ooT0POnVood0POn1oh7oPOn1oh7o0?oi087oY_om087o
POn1oh7oPOn1o`3on@21omco04C;ood0POn1oh7oPOn1oh7oo_om087oY?om087o
POn1oh7oPOn1ookoo@21ojCoo@21oh7oPOn1oh7oPOonood0POoJo`14boom087o
POn1oh7oPOn1ookoo@21ojCoo@21oh7oPOn1oh7oPOonood0POnTood0POn1oh7o
POn1oh7oo_om087of_l0>87oPOn1oh7oPOn1olCoo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1oigoo@21om[o03R1oh7oPOn1oh7oPOo4ood0POn1oh7o
POn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POoJo`0hPOn1oh7oPOn1oh7o
a?om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087of_l0>87o
POn1oh7oPOn1olCoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigo
o@21om[o03R1oh7oPOn1oh7oPOo4ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7o
POn1oh7oPOnMood0POoJo`14boom087oPOn1oh7oPOn1ookoo@21ojCoo@21oh7o
POn1oh7oPOonood0POnTood0POn1oh7oPOn1oh7oo_om087of_l0A<_oo@21oh7o
POn1oh7oPOonood0POnTood0POn1oh7oPOn1oh7oo_om087oY?om087oPOn1oh7o
POn1ookoo@21om[o04C;ood0POn1oh7oPOn1oh7oo_om087oY?om087oPOn1oh7o
POn1ookoo@21ojCoo@21oh7oPOn1oh7oPOonood0POoJo`14boom087oPOn1oh7o
POn1ookoo@21ojCoo@21oh7oPOn1oh7oPOonood0POnTood0POn1oh7oPOn1oh7o
o_om087of_l0>87oPOn1oh7oPOn1olCoo@21oh7oPOn1oh7oPOn1oigoo@21oh7o
POn1oh7oPOn1oigoo@21om[o03R1oh7oPOn1oh7oPOo4ood0POn1oh7oPOn1oh7o
POnMood0POn1oh7oPOn1oh7oPOnMood0POoJo`0hPOn1oh7oPOn1oh7oa?om087o
POn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087of_l0>87oPOn1oh7o
POn1olCoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21om[o
04C;ood0POn1oh7oPOn1oh7oo_om087oY?om087oPOn1oh7oPOn1ookoo@21ojCo
o@21oh7oPOn1oh7oPOonood0POoJo`14boom087oPOn1oh7oPOn1ookoo@21ojCo
o@21oh7oPOn1oh7oPOonood0POnTood0POn1oh7oPOn1oh7oo_om087of_l0A<_o
o@21oh7oPOn1oh7oPOonood0POnTood0POn1oh7oPOn1oh7oo_om087oY?om087o
POn1oh7oPOn1ookoo@21om[o04C;ood0POn1oh7oPOn1oh7oo_om087oY?om087o
POn1oh7oPOn1ookoo@21ojCoo@21oh7oPOn1oh7oPOonood0POoJo`0hPOn1oh7o
POn1oh7oa?om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087o
f_l0>87oPOn1oh7oPOn1olCoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7o
POn1oigoo@21om[o03R1oh7oPOn1oh7oPOo4ood0POn1oh7oPOn1oh7oPOnMood0
POn1oh7oPOn1oh7oPOnMood0POoJo`0hPOn1oh7oPOn1oh7oa?om087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087of_l0A<_oo@21oh7oPOn1oh7o
POonood0POnTood0POn1oh7oPOn1oh7oo_om087oY?om087oPOn1oh7oPOn1ooko
o@21om[o04C;ood0POn1oh7oPOn1oh7oo_om087oY?om087oPOn1oh7oPOn1ooko
o@21ojCoo@21oh7oPOn1oh7oPOonood0POoJo`14boom087oPOn1oh7oPOn1ooko
o@21ojCoo@21oh7oPOn1oh7oPOonood0POnTood0POn1oh7oPOn1oh7oo_om087o
f_l0A<_oo@21oh7oPOn1oh7oPOonood0POnTood0POn1oh7oPOn1oh7oo_om087o
Y?om087oPOn1oh7oPOn1ookoo@21om[o03R1oh7oPOn1oh7oPOo4ood0POn1oh7o
POn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POoJo`0hPOn1oh7oPOn1oh7o
a?om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087of_l0>87o
POn1oh7oPOn1olCoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigo
o@21om[o03R1oh7oPOn1oh7oPOo4ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7o
POn1oh7oPOnMood0POoJo`0hPOn1oh7oPOn1oh7oa?om087oPOn1oh7oPOn1oh7o
WOom087oPOn1oh7oPOn1oh7oWOom087of_l0A<_oo@21oh7oPOn1oh7oPOonood0
POnTood0POn1oh7oPOn1oh7oo_om087oY?om087oPOn1oh7oPOn1ookoo@21om[o
04C;ood0POn1oh7oPOn1oh7oo_om087oY?om087oPOn1oh7oPOn1ookoo@21ojCo
o@21oh7oPOn1oh7oPOonood0POoJo`14boom087oPOn1oh7oPOn1ookoo@21ojCo
o@21oh7oPOn1oh7oPOonood0POnTood0POn1oh7oPOn1oh7oo_om087of_l0A<_o
o@21oh7oPOn1oh7oPOonood0POnTood0POn1oh7oPOn1oh7oo_om087oY?om087o
POn1oh7oPOn1ookoo@21om[o03R1oh7oPOn1oh7oPOo4ood0POn1oh7oPOn1oh7o
POnMood0POn1oh7oPOn1oh7oPOnMood0POoJo`0hPOn1oh7oPOn1oh7oa?om087o
POn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087of_l0>87oPOn1oh7o
POn1olCoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21om[o
03R1oh7oPOn1oh7oPOo4ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7o
POnMood0POoJo`14boom087oPOn1oh7oPOn1ookoo@21ojCoo@21oh7oPOn1oh7o
POonood0POnTood0POn1oh7oPOn1oh7oo_om087of_l0A<_oo@21oh7oPOn1oh7o
POonood0POnTood0POn1oh7oPOn1oh7oo_om087oY?om087oPOn1oh7oPOn1ooko
o@21om[o04C;ood0POn1oh7oPOn1oh7oo_om087oY?om087oPOn1oh7oPOn1ooko
o@21ojCoo@21oh7oPOn1oh7oPOonood0POoJo`14boom087oPOn1oh7oPOn1ooko
o@21ojCoo@21oh7oPOn1oh7oPOonood0POnTood0POn1oh7oPOn1oh7oo_om087o
f_l0>87oPOn1oh7oPOn1olCoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7o
POn1oigoo@21om[o03R1oh7oPOn1oh7oPOo4ood0POn1oh7oPOn1oh7oPOnMood0
POn1oh7oPOn1oh7oPOnMood0POoJo`0hPOn1oh7oPOn1oh7oa?om087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087of_l0>87oPOn1oh7oPOn1olCo
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21om[o04C;ood0
POn1oh7oPOn1oh7oo_om087oY?om087oPOn1oh7oPOn1ookoo@21ojCoo@21oh7o
POn1oh7oPOonood0POoJo`14boom087oPOn1oh7oPOn1ookoo@21ojCoo@21oh7o
POn1oh7oPOonood0POnTood0POn1oh7oPOn1oh7oo_om087of_l0?/_oo@21oh7o
POn1oh7oW_o3087o__om087oPOn1oh7oPOnNol<0POnnood0POn1oh7oPOn1oiko
``21ooCo03k;ood0POn1oh7oPOn1oiko``21okkoo@21oh7oPOn1oh7oW_o3087o
__om087oPOn1oh7oPOnNol<0POodo`0hPOn1oh7oPOn1oh7oi?o3087oPOn1oh7o
POn1oh7oeoo3087oPOn1oh7oPOn1oh7oeoo3087om?l0>87oPOn1oh7oPOn1onCo
``21oh7oPOn1oh7oPOn1omOo``21oh7oPOn1oh7oPOn1omOo``21ooCo03R1oh7o
POn1oh7oPOoTol<0POn1oh7oPOn1oh7oPOoGol<0POn1oh7oPOn1oh7oPOoGol<0
POodo`0hPOn1oh7oPOn1oh7oi?o3087oPOn1oh7oPOn1oh7oeoo3087oPOn1oh7o
POn1oh7oeoo3087om?l0>87oPOn1oh7oPOn1onCo``21oh7oPOn1oh7oPOn1omOo
``21oh7oPOn1oh7oPOn1omOo``21ooCo03k;ood0POn1oh7oPOn1oiko``21okko
o@21oh7oPOn1oh7oW_o3087o__om087oPOn1oh7oPOnNol<0POodo`0nboom087o
POn1oh7oPOnNol<0POnnood0POn1oh7oPOn1oiko``21okkoo@21oh7oPOn1oh7o
W_o3087om?l0?/_oo@21oh7oPOn1oh7oW_o3087o__om087oPOn1oh7oPOnNol<0
POnnood0POn1oh7oPOn1oiko``21ooCo03k;ood0POn1oh7oPOn1oiko``21okko
o@21oh7oPOn1oh7oW_o3087o__om087oPOn1oh7oPOnNol<0POodo`0hPOn1oh7o
POn1oh7oi?o3087oPOn1oh7oPOn1oh7oeoo3087oPOn1oh7oPOn1oh7oeoo3087o
m?l0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0><_oo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1om?o03S;ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7o
POn1oh7oPOnMood0POn1oh7oPOn1oh7oPOoCo`0hboom087oPOn1oh7oPOn1oh7o
WOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7odol0><_oo@21oh7o
POn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1om?o
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0><_oo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1om?o03S;ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7o
POn1oh7oPOnMood0POn1oh7oPOn1oh7oPOoCo`0hboom087oPOn1oh7oPOn1oh7o
WOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7odol0><_oo@21oh7o
POn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1om?o
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0hboom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7o
WOom087oPOn1oh7oPOn1oh7odol0><_oo@21oh7oPOn1oh7oPOn1oigoo@21oh7o
POn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1om?o03S;ood0POn1oh7oPOn1oh7o
POnMood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOoCo`0hboom087o
POn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7o
dol0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0hboom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7o
WOom087oPOn1oh7oPOn1oh7odol0><_oo@21oh7oPOn1oh7oPOn1oigoo@21oh7o
POn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1om?o03S;ood0POn1oh7oPOn1oh7o
POnMood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOoCo`0hboom087o
POn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7o
dol0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0hboom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7o
WOom087oPOn1oh7oPOn1oh7odol0><_oo@21oh7oPOn1oh7oPOn1oigoo@21oh7o
POn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1om?o03S;ood0POn1oh7oPOn1oh7o
POnMood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOoCo`0hboom087o
POn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7o
dol0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo03S;ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7o
POnMood0POn1oh7oPOn1oh7oPOoCo`0hboom087oPOn1oh7oPOn1oh7oWOom087o
POn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7odol0><_oo@21oh7oPOn1oh7o
POn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1om?o03S;ood0
POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7o
POoCo`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo03S;ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7o
POnMood0POn1oh7oPOn1oh7oPOoCo`0hboom087oPOn1oh7oPOn1oh7oWOom087o
POn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7odol0><_oo@21oh7oPOn1oh7o
POn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1om?o03S;ood0
POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7o
POoCo`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo03S;ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7o
POnMood0POn1oh7oPOn1oh7oPOoCo`0hboom087oPOn1oh7oPOn1oh7oWOom087o
POn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7odol0><_oo@21oh7oPOn1oh7o
POn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1om?o03S;ood0
POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7o
POoCo`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0><_oo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7o
POn1oigoo@21oh7oPOn1oh7oPOn1om?o03S;ood0POn1oh7oPOn1oh7oPOnMood0
POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOoCo`0hboom087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7odol0><_o
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7o
POn1om?o0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0><_oo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7o
POn1oigoo@21oh7oPOn1oh7oPOn1om?o03S;ood0POn1oh7oPOn1oh7oPOnMood0
POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOoCo`0hboom087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7odol0><_o
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7o
POn1om?o0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0><_oo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7o
POn1oigoo@21oh7oPOn1oh7oPOn1om?o03S;ood0POn1oh7oPOn1oh7oPOnMood0
POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOoCo`0hboom087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7odol0><_o
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7o
POn1om?o0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0hboom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOn1oh7odol0><_oo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1om?o03S;ood0POn1oh7o
POn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOoCo`0h
boom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7o
POn1oh7odol0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0hboom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOn1oh7odol0><_oo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1om?o03S;ood0POn1oh7o
POn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOoCo`0h
boom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7o
POn1oh7odol0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0hboom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOn1oh7odol0><_oo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1om?o03S;ood0POn1oh7o
POn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOoCo`0h
boom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7o
POn1oh7odol0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo03S;ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7o
POn1oh7oPOnMood0POn1oh7oPOn1oh7oPOoCo`0hboom087oPOn1oh7oPOn1oh7o
WOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7odol0><_oo@21oh7o
POn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1om?o
03S;ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POn1oh7o
POn1oh7oPOoCo`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo03S;ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7o
POn1oh7oPOnMood0POn1oh7oPOn1oh7oPOoCo`0hboom087oPOn1oh7oPOn1oh7o
WOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7odol0><_oo@21oh7o
POn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1om?o
09X0003oRZ0000000nP2Z00000@0000004P000180000400P00<0200000000000
0NXQW0000003j0:Q0003j`?Y1XT0000PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo
0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0P
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
ROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo
0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0P
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
ROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo
0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0P
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
ROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo
0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0Z]?l0087oPOn1oh7o
POoJo`00POn1oh7oPOn1om[o0021oh7oPOn1ojOo02ZhooP0POn1oh7oPOn1on;o
n021oh7oPOn1oh7oh_oh087oPOn1oh7oZol0:[Wom@21oh7oPOn1oh7oiOoe087o
POn1oh7oPOoUooD0POn1oh7oPOn]o`0Z^oob087oPOn1oh7oPOoXoo80POn1oh7o
POn1onSolP21oh7oPOn1ojko02Zkoo40POn1oh7oPOn1onWol@21oh7oPOn1oh7o
jOoa087oPOn1oh7o[ol0:[col021oh7oPOn1oh7oj_o`087oPOn1oh7oPOoZoo00
POn1oh7oPOn_o`0Z_Oo^087oPOn1oh7oPOo/onh0POn1oh7oPOn1oncokP21oh7o
POn1ok3o02Zmonh0POn1oh7oPOn1oncokP21oh7oPOn1oh7ok?o^087oPOn1oh7o
/?l0:X40P@210840P@3R0?SoP@210840P@210>80n?n10840P@210840hP3ho`0Z
P@210840P@210>80n?n10840P@210840hP3hoh40P@210840P@3R0?So02Z10840
P@210840hP3hoh40P@210840P@3R0?SoP@210840P@210>80n?l0:X40P@210840
P@3R0?SoP@210840P@210>80n?n10840P@210840hP3ho`0ZP@210840P@210>80
n?n10840P@210840hP3hoh40P@210840P@3R0?So03:mond0POn1olWoo@21oh7o
ZOo]087oPOo9ood0POn1ojWok@21oh7obOom087oPOo]o`0b_Oo^087oPOo8ood0
POn1ojWokP21oh7ob?om087oPOnYonh0POn1olSoo@21oh7okOl0:[gokP21oh7o
POn1oh7ok?o^087oPOn1oh7oPOo/onh0POn1oh7oPOn`o`0Z_?o`087oPOn1oh7o
POoZoo00POn1oh7oPOn1on[ol021oh7oPOn1ojoo02Zkoo40POn1oh7oPOn1onWo
l@21oh7oPOn1oh7ojOoa087oPOn1oh7o[ol0:[_olP21oh7oPOn1oh7oj?ob087o
POn1oh7oPOoXoo80POn1oh7oPOn^o`0b^Ooe087oPOo5ood0POn1ojGom@21oh7o
aOom087oPOnUooD0POn1olGoo@21oh7okOl0<[Oon@21oh7o`oom087oPOnSooT0
POn1ol?oo@21oh7oXooi087oPOo3ood0POn1ongo03:food0POn1ol3oo@21oh7o
X_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOo]o`0b]_om087oPOo0ood0
POn1oj;oo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7okOl0:[Koo@21oh7o
POn1oh7ogOom087oPOn1oh7oPOoMood0POn1oh7oPOnXo`0Z]_om087oPOn1oh7o
POoMood0POn1oh7oPOn1omgoo@21oh7oPOn1ojSo02Zfood0POn1oh7oPOn1omgo
o@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0:[Koo@21oh7oPOn1oh7ogOom087o
POn1oh7oPOoMood0POn1oh7oPOnXo`0b]_om087oPOo0ood0POn1oj;oo@21oh7o
`?om087oPOnRood0POn1ol3oo@21oh7okOl0<[Koo@21oh7o`?om087oPOnRood0
POn1ol3oo@21oh7oX_om087oPOo0ood0POn1ongo03:food0POn1ol3oo@21oh7o
X_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOo]o`0b]_om087oPOo0ood0
POn1oj;oo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7okOl0:[Koo@21oh7o
POn1oh7ogOom087oPOn1oh7oPOoMood0POn1oh7oPOnXo`0Z]_om087oPOn1oh7o
POoMood0POn1oh7oPOn1omgoo@21oh7oPOn1ojSo02Zfood0POn1oh7oPOn1omgo
o@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0:[Koo@21oh7oPOn1oh7ogOom087o
POn1oh7oPOoMood0POn1oh7oPOnXo`0Z]_om087oPOn1oh7oPOoMood0POn1oh7o
POn1omgoo@21oh7oPOn1ojSo03:food0POn1ol3oo@21oh7oX_om087oPOo0ood0
POn1oj;oo@21oh7o`?om087oPOo]o`0b]_om087oPOo0ood0POn1oj;oo@21oh7o
`?om087oPOnRood0POn1ol3oo@21oh7okOl0<[Koo@21oh7o`?om087oPOnRood0
POn1ol3oo@21oh7oX_om087oPOo0ood0POn1ongo03:food0POn1ol3oo@21oh7o
X_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOo]o`0Z]_om087oPOn1oh7o
POoMood0POn1oh7oPOn1omgoo@21oh7oPOn1ojSo02Zfood0POn1oh7oPOn1omgo
o@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0:[Koo@21oh7oPOn1oh7ogOom087o
POn1oh7oPOoMood0POn1oh7oPOnXo`0Z]_om087oPOn1oh7oPOoMood0POn1oh7o
POn1omgoo@21oh7oPOn1ojSo03:food0POn1ol3oo@21oh7oX_om087oPOo0ood0
POn1oj;oo@21oh7o`?om087oPOo]o`0b]_om087oPOo0ood0POn1oj;oo@21oh7o
`?om087oPOnRood0POn1ol3oo@21oh7okOl0<[Koo@21oh7o`?om087oPOnRood0
POn1ol3oo@21oh7oX_om087oPOo0ood0POn1ongo03:food0POn1ol3oo@21oh7o
X_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOo]o`0Z]_om087oPOn1oh7o
POoMood0POn1oh7oPOn1omgoo@21oh7oPOn1ojSo02Zfood0POn1oh7oPOn1omgo
o@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0:[Koo@21oh7oPOn1oh7ogOom087o
POn1oh7oPOoMood0POn1oh7oPOnXo`0Z]_om087oPOn1oh7oPOoMood0POn1oh7o
POn1omgoo@21oh7oPOn1ojSo03:food0POn1ol3oo@21oh7oX_om087oPOo0ood0
POn1oj;oo@21oh7o`?om087oPOo]o`0b]_om087oPOo0ood0POn1oj;oo@21oh7o
`?om087oPOnRood0POn1ol3oo@21oh7okOl0</koc@21oh7of?om087oPOnjold0
POn1omSoo@21oh7o^_o=087oPOoHood0POn1ongo03;>old0POn1omSoo@21oh7o
^_o=087oPOoHood0POn1ok[oc@21oh7of?om087oPOo]o`0Vc_o=087oPOn1oh7o
SOo=087oPOn1oh7oSOo=087oPOn1oh7o`?l09/koc@21oh7oPOn1ohgoc@21oh7o
POn1ohgoc@21oh7oPOn1ol3o03;>ood0eOom087oPOn1oh7oSOom0=Goo@21oh7o
POn1ohgoo@3Eood0POn1oh7oPOo0o`0bc_om0=Goo@21oh7oPOn1ohgoo@3Eood0
POn1oh7oPOn=ood0eOom087oPOn1oh7o`?l0</koo@3Eood0POn1oh7oPOn=ood0
eOom087oPOn1oh7oSOom0=Goo@21oh7oPOn1ol3o03k>ood0eOom087oPOoHood0
POn1ok[oo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7of?om087oPOo]o`0n
c_om0=Goo@21oh7of?om087oPOnjood0eOom087oPOoHood0POn1ok[oo@3Eood0
POn1omSoo@21oh7okOl0?/koo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7o
f?om087oPOnjood0eOom087oPOoHood0POn1ongo03k>ood0eOom087oPOoHood0
POn1ok[oo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7of?om087oPOo]o`0b
c_om0=Goo@21oh7oPOn1ohgoo@3Eood0POn1oh7oPOn=ood0eOom087oPOn1oh7o
`?l0</koo@3Eood0POn1oh7oPOn=ood0eOom087oPOn1oh7oSOom0=Goo@21oh7o
POn1ol3o03;>ood0eOom087oPOn1oh7oSOom0=Goo@21oh7oPOn1ohgoo@3Eood0
POn1oh7oPOo0o`0bc_om0=Goo@21oh7oPOn1ohgoo@3Eood0POn1oh7oPOn=ood0
eOom087oPOn1oh7o`?l0?/koo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7o
f?om087oPOnjood0eOom087oPOoHood0POn1ongo03k>ood0eOom087oPOoHood0
POn1ok[oo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7of?om087oPOo]o`0n
c_om0=Goo@21oh7of?om087oPOnjood0eOom087oPOoHood0POn1ok[oo@3Eood0
POn1omSoo@21oh7okOl0?/koo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7o
f?om087oPOnjood0eOom087oPOoHood0POn1ongo03;>ood0eOom087oPOn1oh7o
SOom0=Goo@21oh7oPOn1ohgoo@3Eood0POn1oh7oPOo0o`0bc_om0=Goo@21oh7o
POn1ohgoo@3Eood0POn1oh7oPOn=ood0eOom087oPOn1oh7o`?l0</koo@3Eood0
POn1oh7oPOn=ood0eOom087oPOn1oh7oSOom0=Goo@21oh7oPOn1ol3o03;>ood0
eOom087oPOn1oh7oSOom0=Goo@21oh7oPOn1ohgoo@3Eood0POn1oh7oPOo0o`0n
c_om0=Goo@21oh7of?om087oPOnjood0eOom087oPOoHood0POn1ok[oo@3Eood0
POn1omSoo@21oh7okOl0?/koo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7o
f?om087oPOnjood0eOom087oPOoHood0POn1ongo03k>ood0eOom087oPOoHood0
POn1ok[oo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7of?om087oPOo]o`0n
c_om0=Goo@21oh7of?om087oPOnjood0eOom087oPOoHood0POn1ok[oo@3Eood0
POn1omSoo@21oh7okOl0</koo@3Eood0POn1oh7oPOn=ood0eOom087oPOn1oh7o
SOom0=Goo@21oh7oPOn1ol3o03;>ood0eOom087oPOn1oh7oSOom0=Goo@21oh7o
POn1ohgoo@3Eood0POn1oh7oPOo0o`0bc_om0=Goo@21oh7oPOn1ohgoo@3Eood0
POn1oh7oPOn=ood0eOom087oPOn1oh7o`?l0</koo@3Eood0POn1oh7oPOn=ood0
eOom087oPOn1oh7oSOom0=Goo@21oh7oPOn1ol3o03;>ood0eOom087oPOn1oh7o
SOom0=Goo@21oh7oPOn1ohgoo@3Eood0POn1oh7oPOo0o`0nc_om0=Goo@21oh7o
f?om087oPOnjood0eOom087oPOoHood0POn1ok[oo@3Eood0POn1omSoo@21oh7o
kOl0?/koo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7of?om087oPOnjood0
eOom087oPOoHood0POn1ongo03k>ood0eOom087oPOoHood0POn1ok[oo@3Eood0
POn1omSoo@21oh7o^_om0=Goo@21oh7of?om087oPOo]o`0nc_om0=Goo@21oh7o
f?om087oPOnjood0eOom087oPOoHood0POn1ok[oo@3Eood0POn1omSoo@21oh7o
kOl0</koo@3Eood0POn1oh7oPOn=ood0eOom087oPOn1oh7oSOom0=Goo@21oh7o
POn1ol3o03;>ood0eOom087oPOn1oh7oSOom0=Goo@21oh7oPOn1ohgoo@3Eood0
POn1oh7oPOo0o`0bc_om0=Goo@21oh7oPOn1ohgoo@3Eood0POn1oh7oPOn=ood0
eOom087oPOn1oh7o`?l0</koo@3Eood0POn1oh7oPOn=ood0eOom087oPOn1oh7o
SOom0=Goo@21oh7oPOn1ol3o03k>ood0eOom087oPOoHood0POn1ok[oo@3Eood0
POn1omSoo@21oh7o^_om0=Goo@21oh7of?om087oPOo]o`0nc_om0=Goo@21oh7o
f?om087oPOnjood0eOom087oPOoHood0POn1ok[oo@3Eood0POn1omSoo@21oh7o
kOl0?/koo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7of?om087oPOnjood0
eOom087oPOoHood0POn1ongo03k>ood0eOom087oPOoHood0POn1ok[oo@3Eood0
POn1omSoo@21oh7o^_om0=Goo@21oh7of?om087oPOo]o`0nc_om0=Goo@3WooL0
POn1oh7oPOnaood0eOom0>Oom`21oh7oPOn1ok7oo@3Eood0ioog087oPOn1oh7o
i?l0Elkoo@3Eood0j_oa0>_o0@00gOok087oPOn1oh7om_om0=Goo@3Zoo40jol1
003Moo/0POn1oh7oPOofood0eOom0>[ol@3[o`400=gon`21oh7oPOnYo`1Dc_om
0=Goo@3/on`0koon0=kon@21oh7oPOn1ooOoo@3Eood0k?o/0>oooP3NooT0POn1
oh7oPOogood0eOom0>cok03_ooh0g_oi087oPOn1oj[o05C>ood0eOom0>koj@3a
ood0g_oi087oPOn1oh7omoom0=Goo@3^onT0lOom0=kon@21oh7oPOn1ooOoo@3E
ood0k_oY0?7oo@3NooT0POn1oh7oZ_l0J<koo@3Eood0kooh0?Won03booh0gOoi
087o`_om087oPOnjood0eOom0>oon03iooP0l_on0=gon@21ol;oo@21oh7o^_om
0=Goo@3_ooP0nOoh0?;ooP3MooT0POo2ood0POn1ongo06S>ood0eOom0?3onP3c
ooX0loon0=kom`21ol?oo@21oh7o^_om0=Goo@3`ooX0looj0??ooP3NooL0POo3
ood0POn1ok[oo@3Eood0l?oj0??onP3cooh0g_og087o`oom087oPOo]o`1Xc_om
0=Goo@3aooX0l?ok0?GooP3MooL0POo3ood0POn1ok[oo@3Eood0lOoj0?3on`3e
ooh0gOog087o`oom087oPOnjood0eOom0?7onP3`oo/0mOon0=gom`21ol?oo@21
oh7okOl0J<koo@3Eood0l_ok0>gon`3fooh0gOog087o`oom087oPOnjood0eOom
0?;on`3]oo/0m_on0=gom`21ol?oo@21oh7o^_om0=Goo@3boo/0kOok0?KooP3M
ooL0POo3ood0POn1ongo06c>ood0eOom0?;oo03[oo`0m_on0=kon`00oo`0POn1
oh7oPOoiood0eOom0?;oo03[oo`0m_on0=kon`00oo`0POn1oh7oPOoiood0eOom
0?;oo03[oo`0m_on0=kon`00oo`0POn1oh7o[?l0Klkoo@3Eood0look0>_on`3g
ooh0g_ol007ooo`0POn1oh7oPOoiood0eOom0??on`3[oo/0moon0=koo001oool
087oPOn1oh7onOom0=Goo@3coo/0jook0?OooP3Noo`00Oooo021oh7oPOn/o`1_
c_om0=Goo@3coo`0jOol0?Ooo03Poo`00Ooon`21oh7oPOn1oo[oo@3Eood0lool
0>Woo03goo`0h?ol007ooo/0POn1oh7oPOojood0eOom0??oo03Yoo`0mool0>3o
o001oook087oPOn1ojgo06c>ood0eOom0?Coo03Xoo`0mool0>7on`3noo`0POn1
oh7oPOojood0eOom0?Coo03Xoo`0mool0>7on`3noo`0POn1oh7oPOojood0eOom
0?Coo03Xoo`0mool0>7on`3noo`0POn1oh7o[Ol0P<koo@3Eood0m?ol0>Ooo03h
oo`0hOol0?goo03doo/0look087oPOn1oj7oo@3Eood0m?ol0>Ooo03hoo`0hOol
0?goo03doo/0look087oPOn1oj7oo@3Eood0m?ol0>Ooo03hoo`0hOol0?goo03d
oo/0look087oPOn1omCo08c>ood0eOom0?Goo03Voo`0n?ol0>7oo03moo/0mOok
0??oo021on_oo@21oh7o^_om0=Goo@3eoo`0i_ol0?Soo03Qoo`0oOok0?Gon`3c
oo`0POo[ood0POn1ok[oo@3Eood0mOol0>Koo03hoo`0hOol0?gon`3eoo/0lool
087ojoom087oPOo]o`20c_om0=Goo@3eoo`0f?ol0>;oo03koo`0m?ok0?Gon`21
on_oo@21oh7o^_om0=Goo@3eoo`0f?ol0>;oo03koo`0m?ok0?Gon`21on_oo@21
oh7o^_om0=Goo@3eoo`0f?ol0>;oo03koo`0m?ok0?Gon`21on_oo@21oh7okOl0
M<koo@3Eood0mOol0;Coo03koo`0lool0?Kon`21on[oo@21oh7o^_om0=Goo@3e
oo`0]?ol0?_oo03coo`0m_ok087oj_om087oPOnjood0eOom0?Goo02doo`0nool
0??oo03foo/0POoZood0POn1ongo07C>ood0eOom0?Goo02eoo/0nook0?Con`3h
oo/0POoYood0POn1ok[oo@3Eood0mOol0;Gon`3koo/0m?ok0?Son`21onWoo@21
oh7o^_om0=Goo@3eoo`0]Ook0?_on`3doo/0n?ok087ojOom087oPOo]o`1Xc_om
0=Goo@3foo`0]?ol0?Woo03coo/0nOok087oPOn1oikoo@3Eood0m_ol0;Coo03i
oo`0look0?Won`21oh7oPOnNood0eOom0?Koo02doo`0nOol0??on`3ioo/0POn1
oh7odOl0J<koo@3Eood0m_ol0;Coo03ioo`0l_ol0?[on`21oh7oPOnMood0eOom
0?Koo02doo`0nOol0?;oo03joo/0POn1oh7oWOom0=Goo@3foo`0]?ol0?Woo03b
oo`0n_ok087oPOn1om3o06S>ood0eOom0?Koo02eoo/0nOok0??on`3loo/0POn1
oh7oW?om0=Goo@3foo`0]Ook0?Won`3coo/0o?ok087oPOn1oicoo@3Eood0m_ol
0;Gon`3ioo/0look0?con`21oh7oPOo?o`1Xc_om0=Goo@3foo`0]Ool0?Ooo03b
oo/0oOol087oPOn1oi_oo@3Eood0m_ol0;Goo03goo`0l_ok0?goo021oh7oPOnK
ood0eOom0?Koo02eoo`0mool0?;on`3moo`0POn1oh7oc_l0P<koo@3Eood0m_ol
0?;ok`3Foo`0mool0?7oo03noo/0POoVood0POn1ok[oo@3Eood0m_ol0?;ok`3F
oo`0mool0?7oo03noo/0POoVood0POn1ok[oo@3Eood0m_ol0?;ok`3Foo`0mool
0?7oo03noo/0POoVood0POn1ongo083>ood0eOom0?Koo03bonl0eook0?Oon`3b
oo/00?ok087oiOom087oPOnjood0eOom0?Koo03bonl0eook0?Oon`3boo/00?ok
087oiOom087oPOnjood0eOom0?Koo03bonl0eook0?Oon`3boo/00?ok087oiOom
087oPOo]o`20c_om0=Goo@3foo`0l_o_0=Ooo03eoo`0lOol003oo021onCoo@21
oh7o^_om0=Goo@3foo`0l_o_0=Ooo03eoo`0lOol003oo021onCoo@21oh7o^_om
0=Goo@3foo`0l_o_0=Ooo03eoo`0lOol003oo021onCoo@21oh7okOl0M<koo@3E
ood0m_ol0?;ok`3Goo`0mOol0?3om`21onCoo@21oh7o^_om0=Goo@3foo`0l_o_
0=Ooo03eoo`0l?og087oi?om087oPOnjood0eOom0?Koo03bonl0eool0?Goo03`
ooL0POoTood0POn1ongo06S>ood0eOom0?Koo03Uoo`0f?ok0?Coo03aooP0POn1
oh7oV?om0=Goo@3foo`0iOol0=Son`3doo`0lOoh087oPOn1oiSoo@3Eood0m_ol
0>Goo03Hoo/0m?ol0?7on021oh7oPOo;o`1Xc_om0=Goo@3foo`0iOol0=Soo03c
oo`0l?oj087oPOn1oiOoo@3Eood0m_ol0>Goo03Hoo`0lool0?3onP21oh7oPOnG
ood0eOom0?Koo03Uoo`0f?ol0??oo03`ooX0POn1oh7ob_l0J<koo@3Eood0m_ol
0>Goo03Hoo`0look0?7onP21oh7oPOnGood0eOom0?Koo03Uoo`0f?ol0??on`3a
ooX0POn1oh7oUoom0=Goo@3foo`0iOol0=Soo03coo/0lOoj087oPOn1ol[o06S>
ood0eOom0?Goo03Voo`0fOol0?7oo03booP0POn1oh7oV?om0=Goo@3eoo`0i_ol
0=Woo03aoo`0l_oh087oPOn1oiSoo@3Eood0mOol0>Koo03Ioo`0lOol0?;on021
oh7oPOo;o`1dc_om0=Goo@3eoo`0i_ol0=Woo03aoo`0l_oh087ohoom087oPOnj
ood0eOom0?Goo03Voo`0fOol0?7oo03booP0POoSood0POn1ok[oo@3Eood0mOol
0>Koo03Ioo`0lOol0?;on021on?oo@21oh7okOl0P<koo@3Eood0mOol0>Oon`3_
ooh0kook0?7on`3dooH0POoTood0POn1ok[oo@3Eood0mOol0>Oon`3_ooh0kook
0?7on`3dooH0POoTood0POn1ok[oo@3Eood0mOol0>Oon`3_ooh0kook0?7on`3d
ooH0POoTood0POn1ongo08c>ood0eOom0?Gon`3Xoo/0koon0>ooo03_oo`0mOok
003on`21onGoo@21oh7o^_om0=Goo@3eoo/0j?ok0>oooP3_oo`0kool0?Gon`00
oo/0POoUood0POn1ok[oo@3Eood0mOok0>Son`3_ooh0kool0>ooo03eoo/00?ok
087oiOom087oPOo]o`2<c_om0=Goo@3doo`0j?ok0?3oo@3_oo`0kool0?Goo03n
oo`0POoUood0POn1ok[oo@3Eood0m?ol0>Son`3`ood0kool0>ooo03eoo`0o_ol
087oiOom087oPOnjood0eOom0?Coo03Xoo/0l?om0>ooo03_oo`0mOol0?koo021
onGoo@21oh7okOl0P<koo@3Eood0m?ol0>WonP3aoo`0l?ok0>oon`3goo`0oOok
087oPOn1oi_oo@3Eood0m?ol0>WonP3aoo`0l?ok0>oon`3goo`0oOok087oPOn1
oi_oo@3Eood0m?ol0>WonP3aoo`0l?ok0>oon`3goo`0oOok087oPOn1olko083>
ood0eOom0??oo03ZooX0looj0?3oo03]oo`0n?ok0?con`21oh7oPOnLood0eOom
0??oo03ZooX0looj0?3oo03]oo`0n?ok0?con`21oh7oPOnLood0eOom0??oo03Z
ooX0looj0?3oo03]oo`0n?ok0?con`21oh7oPOo?o`20c_om0=Goo@3coo/0k?oi
0?OomP3`oo`0kOol0?Soo03joo`0POn1oh7oW?om0=Goo@3coo/0k?oi0?OomP3`
oo`0kOol0?Soo03joo`0POn1oh7oW?om0=Goo@3coo/0k?oi0?OomP3`oo`0kOol
0?Soo03joo`0POn1oh7ocol0P<koo@3Eood0l_ok0>kon03gooH0lOok0>gon`3j
oo/0n_ok087oPOn1oigoo@3Eood0l_ok0>kon03gooH0lOok0>gon`3joo/0n_ok
087oPOn1oigoo@3Eood0l_ok0>kon03gooH0lOok0>gon`3joo/0n_ok087oPOn1
om3o083>ood0eOom0?;onP3`ooL0moof0?7oo03[oo`0nook0?Son`21oh7oPOnN
ood0eOom0?;onP3`ooL0moof0?7oo03[oo`0nook0?Son`21oh7oPOnNood0eOom
0?;onP3`ooL0moof0?7oo03[oo`0nook0?Son`21oh7oPOoAo`2<c_om0=Goo@3a
ooX0looe0?3oo@3aoo`0jool0?_oo03foo`0POoYood0POn1ok[oo@3Eood0lOoj
0??om@3`ood0lOol0>_oo03koo`0m_ol087ojOom087oPOnjood0eOom0?7onP3c
ooD0l?om0?7oo03[oo`0nool0?Koo021onWoo@21oh7okOl0Slkoo@3Eood0l?oh
0?Son@01ooom0?3oo@3boml0oOok0?Kon`21on[oo@21oh7o^_om0=Goo@3`ooP0
n?oi007oood0l?om0?;og`3moo/0m_ok087oj_om087oPOnjood0eOom0?3on03h
ooT00Oooo@3`ood0l_oO0?gon`3foo/0POoZood0POn1ongo083>ood0eOom0>oo
j@3nood0l?om0?;og`3noo/0m?ok087ojoom087oPOnjood0eOom0>ooj@3nood0
l?om0?;og`3noo/0m?ok087ojoom087oPOnjood0eOom0>ooj@3nood0l?om0?;o
g`3noo/0m?ok087ojoom087oPOo]o`20c_om0=Goo@3]ond0o?om0?3oo@3boml0
o_ol0?;oo021on_oo@21oh7o^_om0=Goo@3]ond0o?om0?3oo@3boml0o_ol0?;o
o021on_oo@21oh7o^_om0=Goo@3]ond0o?om0?3oo@3boml0o_ol0?;oo021on_o
o@21oh7okOl0M<koo@3Eood0jooa0?WooP3`ood0looM003on`3boo/0POn1oh7o
XOom0=Goo@3[oo40nOon0?3oo@3comd00?ok0?;on`21oh7oPOnQood0eOom0>_o
l@3iooh0l?om0??og@00oo/0l_ok087oPOn1omCo04S>ood0eOom0>Som`3Rood0
POn1oh7oPOoCood0eOom0>Som`3Rood0POn1oh7oPOoCood0eOom0>Som`3Rood0
POn1oh7oQ_l0?<koo@3Eood0_oom087oPOn1oh7odoom0=Goo@2oood0POn1oh7o
POoCood0eOom0;ooo@21oh7oPOn6o`0lc_om0=Goo@2oood0POn1oh7oPOoCood0
eOom0;ooo@21oh7oPOn1om?oo@3Eood0_oom087oPOn1ohKo04C>ood0eOom0;oo
o@21oikoo@21oh7o^_om0=Goo@2oood0POnNood0POn1ok[oo@3Eood0_oom087o
W_om087oPOo]o`14c_om0=Goo@2oood0POnNood0POn1ok[oo@3Eood0_oom087o
W_om087oPOnjood0eOom0;ooo@21oikoo@21oh7okOl0A<koo@3Eood0_oom087o
W_om087oPOnjood0eOom0;ooo@21oikoo@21oh7o^_om0=Goo@2oood0POnNood0
POn1ongo04C>ood0eOom0;ooo@21oikoo@21oh7o^_om0=Goo@2oood0POnNood0
POn1ok[oo@3Eood0_oom087oW_om087oPOo]o`0lc_om0=Goo@2oood0POn1oh7o
POoCood0eOom0;ooo@21oh7oPOn1om?oo@3Eood0_oom087oPOn1ohKo03c>ood0
eOom0;ooo@21oh7oPOn1om?oo@3Eood0_oom087oPOn1oh7odoom0=Goo@2oood0
POn1oh7oQ_l0?<koo@3Eood0_oom087oPOn1oh7odoom0=Goo@2oood0POn1oh7o
POoCood0eOom0;ooo@21oh7oPOn6o`0lc_om0=Goo@2oood0POn1oh7oPOoCood0
eOom0;ooo@21oh7oPOn1om?oo@3Eood0_oom087oPOn1ohKo04C>ood0eOom0;oo
o@21oikoo@21oh7o^_om0=Goo@2oood0POnNood0POn1ok[oo@3Eood0_oom087o
W_om087oPOo]o`14c_om0=Goo@2oood0POnNood0POn1ok[oo@3Eood0_oom087o
W_om087oPOnjood0eOom0;ooo@21oikoo@21oh7okOl0A<koo@3Eood0_oom087o
W_om087oPOnjood0eOom0;ooo@21oikoo@21oh7o^_om0=Goo@2oood0POnNood0
POn1ongo04C>ood0eOom0;ooo@21oikoo@21oh7o^_om0=Goo@2oood0POnNood0
POn1ok[oo@3Eood0_oom087oW_om087oPOo]o`0lc_om0=Goo@2oood0POn1oh7o
POoCood0eOom0;ooo@21oh7oPOn1om?oo@3Eood0_oom087oPOn1ohKo03;>ood0
eOom087oPOn1oh7oSOom0=Goo@21oh7oPOn1ohgoo@3Eood0POn1oh7oPOo0o`0b
c_om0=Goo@21oh7oPOn1ohgoo@3Eood0POn1oh7oPOn=ood0eOom087oPOn1oh7o
`?l0</koo@3Eood0POn1oh7oPOn=ood0eOom087oPOn1oh7oSOom0=Goo@21oh7o
POn1ol3o03;>ood0eOom087oPOn1oh7oSOom0=Goo@21oh7oPOn1ohgoo@3Eood0
POn1oh7oPOo0o`0nc_om0=Goo@21oh7of?om087oPOnjood0eOom087oPOoHood0
POn1ok[oo@3Eood0POn1omSoo@21oh7okOl0?/koo@3Eood0POn1omSoo@21oh7o
^_om0=Goo@21oh7of?om087oPOnjood0eOom087oPOoHood0POn1ongo03k>ood0
eOom087oPOoHood0POn1ok[oo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7o
f?om087oPOo]o`0nc_om0=Goo@21oh7of?om087oPOnjood0eOom087oPOoHood0
POn1ok[oo@3Eood0POn1omSoo@21oh7okOl0</koo@3Eood0POn1oh7oPOn=ood0
eOom087oPOn1oh7oSOom0=Goo@21oh7oPOn1ol3o03;>ood0eOom087oPOn1oh7o
SOom0=Goo@21oh7oPOn1ohgoo@3Eood0POn1oh7oPOo0o`0bc_om0=Goo@21oh7o
POn1ohgoo@3Eood0POn1oh7oPOn=ood0eOom087oPOn1oh7o`?l0</koo@3Eood0
POn1oh7oPOn=ood0eOom087oPOn1oh7oSOom0=Goo@21oh7oPOn1ol3o03k>ood0
eOom087oPOoHood0POn1ok[oo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7o
f?om087oPOo]o`0nc_om0=Goo@21oh7of?om087oPOnjood0eOom087oPOoHood0
POn1ok[oo@3Eood0POn1omSoo@21oh7okOl0?/koo@3Eood0POn1omSoo@21oh7o
^_om0=Goo@21oh7of?om087oPOnjood0eOom087oPOoHood0POn1ongo03k>ood0
eOom087oPOoHood0POn1ok[oo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7o
f?om087oPOo]o`0bc_om0=Goo@21oh7oPOn1ohgoo@3Eood0POn1oh7oPOn=ood0
eOom087oPOn1oh7o`?l0</koo@3Eood0POn1oh7oPOn=ood0eOom087oPOn1oh7o
SOom0=Goo@21oh7oPOn1ol3o03;>ood0eOom087oPOn1oh7oSOom0=Goo@21oh7o
POn1ohgoo@3Eood0POn1oh7oPOo0o`0bc_om0=Goo@21oh7oPOn1ohgoo@3Eood0
POn1oh7oPOn=ood0eOom087oPOn1oh7o`?l0?/koo@3Eood0POn1omSoo@21oh7o
^_om0=Goo@21oh7of?om087oPOnjood0eOom087oPOoHood0POn1ongo03k>ood0
eOom087oPOoHood0POn1ok[oo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7o
f?om087oPOo]o`0nc_om0=Goo@21oh7of?om087oPOnjood0eOom087oPOoHood0
POn1ok[oo@3Eood0POn1omSoo@21oh7okOl0?/koo@3Eood0POn1omSoo@21oh7o
^_om0=Goo@21oh7of?om087oPOnjood0eOom087oPOoHood0POn1ongo03;>ood0
eOom087oPOn1oh7oSOom0=Goo@21oh7oPOn1ohgoo@3Eood0POn1oh7oPOo0o`0b
c_om0=Goo@21oh7oPOn1ohgoo@3Eood0POn1oh7oPOn=ood0eOom087oPOn1oh7o
`?l0</koo@3Eood0POn1oh7oPOn=ood0eOom087oPOn1oh7oSOom0=Goo@21oh7o
POn1ol3o03;>ood0eOom087oPOn1oh7oSOom0=Goo@21oh7oPOn1ohgoo@3Eood0
POn1oh7oPOo0o`0bc_om0=Goo@21oh7oPOn1ohgoo@3Eood0POn1oh7oPOn=ood0
eOom087oPOn1oh7o`?l0?/koo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7o
f?om087oPOnjood0eOom087oPOoHood0POn1ongo03k>ood0eOom087oPOoHood0
POn1ok[oo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7of?om087oPOo]o`0n
c_om0=Goo@21oh7of?om087oPOnjood0eOom087oPOoHood0POn1ok[oo@3Eood0
POn1omSoo@21oh7okOl0?/koo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7o
f?om087oPOnjood0eOom087oPOoHood0POn1ongo03;>ood0eOom087oPOn1oh7o
SOom0=Goo@21oh7oPOn1ohgoo@3Eood0POn1oh7oPOo0o`0bc_om0=Goo@21oh7o
POn1ohgoo@3Eood0POn1oh7oPOn=ood0eOom087oPOn1oh7o`?l0</koo@3Eood0
POn1oh7oPOn=ood0eOom087oPOn1oh7oSOom0=Goo@21oh7oPOn1ol3o03;>ood0
eOom087oPOn1oh7oSOom0=Goo@21oh7oPOn1ohgoo@3Eood0POn1oh7oPOo0o`0n
c_om0=Goo@21oh7of?om087oPOnjood0eOom087oPOoHood0POn1ok[oo@3Eood0
POn1omSoo@21oh7okOl0?/koo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7o
f?om087oPOnjood0eOom087oPOoHood0POn1ongo03k>ood0eOom087oPOoHood0
POn1ok[oo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7of?om087oPOo]o`0n
c_om0=Goo@21oh7of?om087oPOnjood0eOom087oPOoHood0POn1ok[oo@3Eood0
POn1omSoo@21oh7okOl0</koo@3Eood0POn1oh7oPOn=ood0eOom087oPOn1oh7o
SOom0=Goo@21oh7oPOn1ol3o03;>ood0eOom087oPOn1oh7oSOom0=Goo@21oh7o
POn1ohgoo@3Eood0POn1oh7oPOo0o`0bc_om0=Goo@21oh7oPOn1ohgoo@3Eood0
POn1oh7oPOn=ood0eOom087oPOn1oh7o`?l0</koo@3Eood0POn1oh7oPOn=ood0
eOom087oPOn1oh7oSOom0=Goo@21oh7oPOn1ol3o03k>ood0eOom087oPOoHood0
POn1ok[oo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7of?om087oPOo]o`0n
c_om0=Goo@21oh7of?om087oPOnjood0eOom087oPOoHood0POn1ok[oo@3Eood0
POn1omSoo@21oh7okOl0?/koo@3Eood0POn1omSoo@21oh7o^_om0=Goo@21oh7o
f?om087oPOnjood0eOom087oPOoHood0POn1ongo03;>old0POn1omSoo@21oh7o
^_o=087oPOoHood0POn1ok[oc@21oh7of?om087oPOo]o`0Vc_o=087oPOn1oh7o
SOo=087oPOn1oh7oSOo=087oPOn1oh7o`?l09/koc@21oh7oPOn1ohgoc@21oh7o
POn1ohgoc@21oh7oPOn1ol3o02K=oll0POn1oh7oPOn;oll0POn1oh7oPOn;oll0
POn1oh7oPOnoo`0Z]_om087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7o
POn1ojSo02Zfood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOn1oh7o
Z?l0<[Koo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7oX_om087oPOo0ood0
POn1ongo03:food0POn1ol3oo@21oh7oX_om087oPOo0ood0POn1oj;oo@21oh7o
`?om087oPOo]o`0b]_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOnRood0
POn1ol3oo@21oh7okOl0<[Koo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7o
X_om087oPOo0ood0POn1ongo02Zfood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7o
gOom087oPOn1oh7oZ?l0:[Koo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0
POn1oh7oPOnXo`0Z]_om087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7o
POn1ojSo02Zfood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOn1oh7o
Z?l0<[Koo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7oX_om087oPOo0ood0
POn1ongo03:food0POn1ol3oo@21oh7oX_om087oPOo0ood0POn1oj;oo@21oh7o
`?om087oPOo]o`0b]_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOnRood0
POn1ol3oo@21oh7okOl0<[Koo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7o
X_om087oPOo0ood0POn1ongo02Zfood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7o
gOom087oPOn1oh7oZ?l0:[Koo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0
POn1oh7oPOnXo`0Z]_om087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7o
POn1ojSo02Zfood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOn1oh7o
Z?l0<[Koo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7oX_om087oPOo0ood0
POn1ongo03:food0POn1ol3oo@21oh7oX_om087oPOo0ood0POn1oj;oo@21oh7o
`?om087oPOo]o`0b]_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOnRood0
POn1ol3oo@21oh7okOl0<[Koo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7o
X_om087oPOo0ood0POn1ongo02Zfood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7o
gOom087oPOn1oh7oZ?l0:[Koo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0
POn1oh7oPOnXo`0Z]_om087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7o
POn1ojSo02Zfood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOn1oh7o
Z?l0:[Koo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0POn1oh7oPOnXo`0b
]_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7o
kOl0<[Koo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7oX_om087oPOo0ood0
POn1ongo03:hooT0POn1ol;oo@21oh7oY?oi087oPOo2ood0POn1ojCon@21oh7o
`_om087oPOo]o`0b^Oog087oPOo3ood0POn1ojGom`21oh7o`oom087oPOnUooL0
POn1ol?oo@21oh7okOl0:[_ol`21oh7oPOn1oh7oiooc087oPOn1oh7oPOoWoo<0
POn1oh7oPOn]o`0Z^oob087oPOn1oh7oPOoXoo80POn1oh7oPOn1onSolP21oh7o
POn1ojko02Zloo00POn1oh7oPOn1on[ol021oh7oPOn1oh7oj_o`087oPOn1oh7o
[ol0:[gok`21oh7oPOn1oh7ojoo_087oPOn1oh7oPOo[onl0POn1oh7oPOn_o`0b
__o]087oPOo8ood0POn1oj[ok@21oh7ob?om087oPOnZond0POn1olSoo@21oh7o
kOl0<[kok@21oh7ob?om087oPOnZond0POn1olSoo@21oh7oZ_o]087oPOo8ood0
POn1ongo02Z10840P@210840hP3hoh40P@210840P@3R0?SoP@210840P@210>80
n?l0:X40P@210840P@3R0?SoP@210840P@210>80n?n10840P@210840hP3ho`0Z
P@210840P@210>80n?n10840P@210840hP3hoh40P@210840P@3R0?So02Z10840
P@210840hP3hoh40P@210840P@3R0?SoP@210840P@210>80n?l0:[kok@21oh7o
POn1oh7okOo]087oPOn1oh7oPOo]ond0POn1oh7oPOn`o`0Z__o]087oPOn1oh7o
POo]ond0POn1oh7oPOn1ongok@21oh7oPOn1ok3o03:nond0POn1olSoo@21oh7o
Z_o]087oPOo8ood0POn1oj[ok@21oh7ob?om087oPOo]o`0b_Oo_087oPOo7ood0
POn1ojWok`21oh7oaoom087oPOnYonl0POn1olOoo@21oh7okOl0<[col@21oh7o
a_om087oPOnXoo40POn1olKoo@21oh7oZ?oa087oPOo6ood0POn1ongo03:koo<0
POn1olGoo@21oh7oYooc087oPOo5ood0POn1ojOol`21oh7oaOom087oPOo]o`0Z
^ooc087oPOn1oh7oPOoWoo<0POn1oh7oPOn1onOol`21oh7oPOn1ojgo02ZiooL0
POn1oh7oPOn1on?om`21oh7oPOn1oh7ohoog087oPOn1oh7oZol0:[Koo@21oh7o
POn1oh7ogOom087oPOn1oh7oPOoMood0POn1oh7oPOnXo`0Z]_om087oPOn1oh7o
POoMood0POn1oh7oPOn1omgoo@21oh7oPOn1ojSo02Zfood0POn1oh7oPOn1omgo
o@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0<[Koo@21oh7o`?om087oPOnRood0
POn1ol3oo@21oh7oX_om087oPOo0ood0POn1ongo03:food0POn1ol3oo@21oh7o
X_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOo]o`0b]_om087oPOo0ood0
POn1oj;oo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7okOl0<[Koo@21oh7o
`?om087oPOnRood0POn1ol3oo@21oh7oX_om087oPOo0ood0POn1ongo02Zfood0
POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0:[Koo@21oh7o
POn1oh7ogOom087oPOn1oh7oPOoMood0POn1oh7oPOnXo`0Z]_om087oPOn1oh7o
POoMood0POn1oh7oPOn1omgoo@21oh7oPOn1ojSo02Zfood0POn1oh7oPOn1omgo
o@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0<[Koo@21oh7o`?om087oPOnRood0
POn1ol3oo@21oh7oX_om087oPOo0ood0POn1ongo03:food0POn1ol3oo@21oh7o
X_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOo]o`0b]_om087oPOo0ood0
POn1oj;oo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7okOl0<[Koo@21oh7o
`?om087oPOnRood0POn1ol3oo@21oh7oX_om087oPOo0ood0POn1ongo02Zfood0
POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0:[Koo@21oh7o
POn1oh7ogOom087oPOn1oh7oPOoMood0POn1oh7oPOnXo`0Z]_om087oPOn1oh7o
POoMood0POn1oh7oPOn1omgoo@21oh7oPOn1ojSo02Zfood0POn1oh7oPOn1omgo
o@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0<[Koo@21oh7o`?om087oPOnRood0
POn1ol3oo@21oh7oX_om087oPOo0ood0POn1ongo03:food0POn1ol3oo@21oh7o
X_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOo]o`0b]_om087oPOo0ood0
POn1oj;oo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7okOl0<[Koo@21oh7o
`?om087oPOnRood0POn1ol3oo@21oh7oX_om087oPOo0ood0POn1ongo02Zfood0
POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0:[Koo@21oh7o
POn1oh7ogOom087oPOn1oh7oPOoMood0POn1oh7oPOnXo`0Z]_om087oPOn1oh7o
POoMood0POn1oh7oPOn1omgoo@21oh7oPOn1ojSo02Zfood0POn1oh7oPOn1omgo
o@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0:[Koo@21oh7oPOn1oh7ogOom087o
POn1oh7oPOoMood0POn1oh7oPOnXo`0b]_om087oPOo0ood0POn1oj;oo@21oh7o
`?om087oPOnRood0POn1ol3oo@21oh7okOl0<[Koo@21oh7o`?om087oPOnRood0
POn1ol3oo@21oh7oX_om087oPOo0ood0POn1ongo03:food0POn1ol3oo@21oh7o
X_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOo]o`0b]_om087oPOo0ood0
POn1oj;oo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7okOl0:[Koo@21oh7o
POn1oh7ogOom087oPOn1oh7oPOoMood0POn1oh7oPOnXo`0Z]_om087oPOn1oh7o
POoMood0POn1oh7oPOn1omgoo@21oh7oPOn1ojSo02Zfood0POn1oh7oPOn1omgo
o@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0:[Koo@21oh7oPOn1oh7ogOom087o
POn1oh7oPOoMood0POn1oh7oPOnXo`0b]_om087oPOo0ood0POn1oj;oo@21oh7o
`?om087oPOnRood0POn1ol3oo@21oh7okOl0<[Koo@21oh7o`?om087oPOnRood0
POn1ol3oo@21oh7oX_om087oPOo0ood0POn1ongo03;@old0POn1omKoo@21oh7o
_?o=087oPOoFood0POn1okcoc@21oh7oe_om087oPOo]o`0bd?o=087oPOoFood0
POn1okcoc@21oh7oe_om087oPOnlold0POn1omKoo@21oh7okOl09]3oc@21oh7o
POn1ohgoc@21oh7oPOn1ohgoc@21oh7oPOn1okko02K@old0POn1oh7oPOn=old0
POn1oh7oPOn=old0POn1oh7oPOnno`0bd?ol0=Ooo021oh7oPOn1ohgoo03Goo`0
POn1oh7oPOn=oo`0eool087oPOn1oh7o__l0<]3oo03Goo`0POn1oh7oPOn=oo`0
eool087oPOn1oh7oSOol0=Ooo021oh7oPOn1okko03k@oo`0eool087oPOoFood0
POn1okcoo03Goo`0POn1omKoo@21oh7o_?ol0=Ooo021oh7oe_om087oPOo]o`0n
d?ol0=Ooo021oh7oe_om087oPOnloo`0eool087oPOoFood0POn1okcoo03Goo`0
POn1omKoo@21oh7okOl0?]3oo03Goo`0POn1omKoo@21oh7o_?ol0=Ooo021oh7o
e_om087oPOnloo`0eool087oPOoFood0POn1ongo03k@oo`0eool087oPOoFood0
POn1okcoo03Goo`0POn1omKoo@21oh7o_?ol0=Ooo021oh7oe_om087oPOo]o`0b
d?ol0=Ooo021oh7oPOn1ohgoo03Goo`0POn1oh7oPOn=oo`0eool087oPOn1oh7o
__l0<]3oo03Goo`0POn1oh7oPOn=oo`0eool087oPOn1oh7oSOol0=Ooo021oh7o
POn1okko03;@oo`0eool087oPOn1oh7oSOol0=Ooo021oh7oPOn1ohgoo03Goo`0
POn1oh7oPOnno`0bd?ol0=Ooo021oh7oPOn1ohgoo03Goo`0POn1oh7oPOn=oo`0
eool087oPOn1oh7o__l0<]3oo03Goo`0POn1oh7oPOn=oo`0eool087oPOn1oh7o
SOol0=Ooo021oh7oPOn1okko03k@oo`0eool087oPOoFood0POn1okcoo03Goo`0
POn1omKoo@21oh7o_?ol0=Ooo021oh7oe_om087oPOo]o`0nd?ol0=Ooo021oh7o
e_om087oPOnloo`0eool087oPOoFood0POn1okcoo03Goo`0POn1omKoo@21oh7o
kOl0?]3oo03Goo`0POn1omKoo@21oh7o_?ol0=Ooo021oh7oe_om087oPOnloo`0
eool087oPOoFood0POn1ongo03k@oo`0eool087oPOoFood0POn1okcoo03Goo`0
POn1omKoo@21oh7o_?ol0=Ooo021oh7oe_om087oPOo]o`0bd?ol0=Ooo021oh7o
POn1ohgoo03Goo`0POn1oh7oPOn=oo`0eool087oPOn1oh7o__l0<]3oo03Goo`0
POn1oh7oPOn=oo`0eool087oPOn1oh7oSOol0=Ooo021oh7oPOn1okko03;@oo`0
eool087oPOn1oh7oSOol0=Ooo021oh7oPOn1ohgoo03Goo`0POn1oh7oPOnno`0b
d?ol0=Ooo021oh7oPOn1ohgoo03Goo`0POn1oh7oPOn=oo`0eool087oPOn1oh7o
__l0?]3oo03Goo`0POn1omKoo@21oh7o_?ol0=Ooo021oh7oe_om087oPOnloo`0
eool087oPOoFood0POn1ongo03k@oo`0eool087oPOoFood0POn1okcoo03Goo`0
POn1omKoo@21oh7o_?ol0=Ooo021oh7oe_om087oPOo]o`0nd?ol0=Ooo021oh7o
e_om087oPOnloo`0eool087oPOoFood0POn1okcoo03Goo`0POn1omKoo@21oh7o
kOl0?]3oo03Goo`0POn1omKoo@21oh7o_?ol0=Ooo021oh7oe_om087oPOnloo`0
eool087oPOoFood0POn1ongo03;@oo`0eool087oPOn1oh7oSOol0=Ooo021oh7o
POn1ohgoo03Goo`0POn1oh7oPOnno`0bd?ol0=Ooo021oh7oPOn1ohgoo03Goo`0
POn1oh7oPOn=oo`0eool087oPOn1oh7o__l0<]3oo03Goo`0POn1oh7oPOn=oo`0
eool087oPOn1oh7oSOol0=Ooo021oh7oPOn1okko03;@oo`0eool087oPOn1oh7o
SOol0=Ooo021oh7oPOn1ohgoo03Goo`0POn1oh7oPOnno`0nd?ol0=Ooo021oh7o
e_om087oPOnloo`0eool087oPOoFood0POn1okcoo03Goo`0POn1omKoo@21oh7o
kOl0?]3oo03Goo`0POn1omKoo@21oh7o_?ol0=Ooo021oh7oe_om087oPOnloo`0
eool087oPOoFood0POn1ongo03k@oo`0eool087oPOoFood0POn1okcoo03Goo`0
POn1omKoo@21oh7o_?ol0=Ooo021oh7oe_om087oPOo]o`0nd?ol0=Ooo021oh7o
e_om087oPOnloo`0eool087oPOoFood0POn1okcoo03Goo`0POn1omKoo@21oh7o
kOl0<]3oo03Goo`0POn1oh7oPOn=oo`0eool087oPOn1oh7oSOol0=Ooo021oh7o
POn1okko03;@oo`0eool087oPOn1oh7oSOol0=Ooo021oh7oPOn1ohgoo03Goo`0
POn1oh7oPOnno`0bd?ol0=Ooo021oh7oPOn1ohgoo03Goo`0POn1oh7oPOn=oo`0
eool087oPOn1oh7o__l0<]3oo03Goo`0POn1oh7oPOn=oo`0eool087oPOn1oh7o
SOol0=Ooo021oh7oPOn1okko03k@oo`0eool0>Gom`21oh7oPOn1ok?oo03Goo`0
iOog087oPOn1oh7o/ool0=Ooo03UooL0POn1oh7oPOoTo`1Od?ol0=Ooo03Xoo40
jol1003=oo/0POoAood0POn1okcoo03Goo`0j?oa0>_o0@00cOok087odOom087o
POnloo`0eool0>Sol@3[o`400<gon`21om7oo@21oh7okOl0G=3oo03Goo`0j_o/
0>oooP3>ooT0POoBood0POn1okcoo03Goo`0j_o/0>oooP3>ooT0POoBood0POn1
okcoo03Goo`0j_o/0>oooP3>ooT0POoBood0POn1ongo05c@oo`0eool0>coj@3a
ood0c_oi087od_om087oPOnloo`0eool0>coj@3aood0c_oi087od_om087oPOnl
oo`0eool0>coj@3aood0c_oi087od_om087oPOo]o`1Xd?ol0=Ooo03]ooP0nOoh
0?;ooP3=ooT0POoBood0POn1okcoo03Goo`0kOoh0?Won03booh0cOoi087od_om
087oPOnloo`0eool0>gon03iooP0l_on0<gon@21om;oo@21oh7okOl0G=3oo03G
oo`0k_oj0??onP3cooh0c_og087oPOn1oh[oo03Goo`0k_oj0??onP3cooh0c_og
087oPOn1oh[oo03Goo`0k_oj0??onP3cooh0c_og087oPOn1ok_o05c@oo`0eool
0>oonP3`oo/0mOon0<gom`21oh7oPOn:oo`0eool0>oonP3`oo/0mOon0<gom`21
oh7oPOn:oo`0eool0>oonP3`oo/0mOon0<gom`21oh7oPOnko`1Ld?ol0=Ooo03`
oo/0kOok0?KooP3=ooL0POn1oh7oR_ol0=Ooo03`oo/0kOok0?KooP3=ooL0POn1
oh7oR_ol0=Ooo03`oo/0kOok0?KooP3=ooL0POn1oh7o^ol0J=3oo03Goo`0l?ol
0>_oo03fooh0c_ok003oo021oh7oPOn;oo`0eool0?3oo03[oo`0m_on0<kon`00
oo`0POn1oh7oRool0=Ooo03`oo`0jool0?KooP3>oo/00?ol087oPOn1okco07O@
oo`0eool0?7on`3[oo/0moon0<koo001oool087oe?om087oPOnloo`0eool0?7o
n`3[oo/0moon0<koo001oool087oe?om087oPOnloo`0eool0?7on`3[oo/0moon
0<koo001oool087oe?om087oPOo]o`1gd?ol0=Ooo03aoo`0jOol0?Ooo03@oo`0
0Ooon`21omGoo@21oh7o_?ol0=Ooo03aoo`0jOol0?Ooo03@oo`00Ooon`21omGo
o@21oh7o_?ol0=Ooo03aoo`0jOol0?Ooo03@oo`00Ooon`21omGoo@21oh7okOl0
M=3oo03Goo`0l_ol0>Soo03goo`0dOok0?koo021omGoo@21oh7o_?ol0=Ooo03b
oo`0j?ol0?Ooo03Aoo/0o_ol087oeOom087oPOnloo`0eool0?;oo03Xoo`0mool
0=7on`3noo`0POoEood0POn1ongo08c@oo`0eool0?;oo03Woo`0n?ol0=7oo03m
oo`0m?ok0??on`21oocoo@21oh7o_?ol0=Ooo03boo`0iool0?Soo03Aoo`0oOol
0?Con`3coo/0POolood0POn1okcoo03Goo`0l_ol0>Ooo03hoo`0dOol0?goo03d
oo/0look087oo?om087oPOo]o`20d?ol0=Ooo03coo`0i_ol0?Soo03Aoo`0oOok
0?Gon`3coo`0POn1oh7o/_ol0=Ooo03coo`0i_ol0?Soo03Aoo`0oOok0?Gon`3c
oo`0POn1oh7o/_ol0=Ooo03coo`0i_ol0?Soo03Aoo`0oOok0?Gon`3coo`0POn1
oh7ohol0M=3oo03Goo`0lool0=Soo03Boo`0nool0?Con`3eoo/0POn1oh7o/_ol
0=Ooo03coo`0f?ol0=;oo03koo`0m?ok0?Gon`21oh7oPOnboo`0eool0??oo03H
oo`0d_ol0?_oo03doo/0mOok087oPOn1on?o06S@oo`0eool0??oo02Too`0nool
0??oo03foo/0POn1oh7o/Ool0=Ooo03coo`0Y?ol0?_oo03coo`0m_ok087oPOn1
ok7oo03Goo`0lool0:Coo03koo`0lool0?Kon`21oh7oPOoRo`1Xd?ol0=Ooo03c
oo`0YOok0?_on`3doo/0n?ok087oPOn1ok3oo03Goo`0lool0:Gon`3koo/0m?ok
0?Son`21oh7oPOn`oo`0eool0??oo02Uoo/0nook0?Con`3hoo/0POn1oh7ohOl0
M=3oo03Goo`0m?ol0:Coo03ioo`0look0?Won`21ooWoo@21oh7o_?ol0=Ooo03d
oo`0Y?ol0?Woo03coo/0nOok087onOom087oPOnloo`0eool0?Coo02Too`0nOol
0??on`3ioo/0POoiood0POn1ongo07C@oo`0eool0?Coo02Too`0nOol0?;oo03j
oo/0POohood0POn1okcoo03Goo`0m?ol0:Coo03ioo`0l_ol0?[on`21ooSoo@21
oh7o_?ol0=Ooo03doo`0Y?ol0?Woo03boo`0n_ok087on?om087oPOo]o`1dd?ol
0=Ooo03doo`0YOok0?Won`3coo/0o?ok087omoom087oPOnloo`0eool0?Coo02U
oo/0nOok0??on`3loo/0POogood0POn1okcoo03Goo`0m?ol0:Gon`3ioo/0look
0?con`21ooOoo@21oh7okOl0M=3oo03Goo`0m?ol0:Goo03goo`0l_ok0?goo021
ooKoo@21oh7o_?ol0=Ooo03doo`0YOol0?Ooo03boo/0oOol087om_om087oPOnl
oo`0eool0?Coo02Uoo`0mool0?;on`3moo`0POofood0POn1ongo07C@oo`0eool
0?Coo03bonl0a_ol0?Ooo03aoo`0o_ok087oPOn1ojgoo03Goo`0m?ol0?;ok`36
oo`0mool0?7oo03noo/0POn1oh7o[Ool0=Ooo03doo`0l_o_0<Koo03goo`0lOol
0?kon`21oh7oPOoNo`1dd?ol0=Ooo03doo`0l_o_0<Oon`3goo/0l_ok003on`21
oh7oPOn/oo`0eool0?Coo03bonl0aook0?Oon`3boo/00?ok087oPOn1ojcoo03G
oo`0m?ol0?;ok`37oo/0mook0?;on`00oo/0POn1oh7ogOl0M=3oo03Goo`0m?ol
0?;ok`37oo`0mOol0?7oo000oo`0POn1oh7oZool0=Ooo03doo`0l_o_0<Ooo03e
oo`0lOol003oo021oh7oPOn[oo`0eool0?Coo03bonl0aool0?Goo03aoo`00?ol
087oPOn1omco06S@oo`0eool0?Coo03bonl0aool0?Goo03`ooL0POn1oh7oZool
0=Ooo03doo`0l_o_0<Ooo03eoo`0l?og087oPOn1oj_oo03Goo`0m?ol0?;ok`37
oo`0mOol0?3om`21oh7oPOoLo`1Xd?ol0=Ooo03doo`0iOol0<Son`3doo`0lOoh
087oPOn1oj[oo03Goo`0m?ol0>Goo038oo/0m?ol0?7on021oh7oPOnZoo`0eool
0?Coo03Uoo`0b?ok0?Coo03aooP0POn1oh7ofol0M=3oo03Goo`0m?ol0>Goo038
oo`0lool0?3onP21oo;oo@21oh7o_?ol0=Ooo03doo`0iOol0<Soo03coo`0l?oj
087ol_om087oPOnloo`0eool0?Coo03Uoo`0b?ol0??oo03`ooX0POobood0POn1
ongo07C@oo`0eool0?Coo03Uoo`0b?ol0??on`3aooX0POobood0POn1okcoo03G
oo`0m?ol0>Goo038oo`0look0?7onP21oo;oo@21oh7o_?ol0=Ooo03doo`0iOol
0<Soo03coo/0lOoj087ol_om087oPOo]o`1dd?ol0=Ooo03coo`0i_ol0<Woo03a
oo`0l_oh087oloom087oPOnloo`0eool0??oo03Voo`0bOol0?7oo03booP0POoc
ood0POn1okcoo03Goo`0lool0>Koo039oo`0lOol0?;on021oo?oo@21oh7okOl0
M=3oo03Goo`0lool0>Koo039oo`0lOol0?;on021oo?oo@21oh7o_?ol0=Ooo03c
oo`0i_ol0<Woo03aoo`0l_oh087oloom087oPOnloo`0eool0??oo03Voo`0bOol
0?7oo03booP0POocood0POn1ongo06S@oo`0eool0??oo03Woo/0b_ok0?7on`3d
ooH0POn1oh7oZool0=Ooo03coo`0iook0<[on`3aoo/0m?of087oPOn1oj_oo03G
oo`0lool0>Oon`3:oo/0lOok0?ComP21oh7oPOoLo`1dd?ol0=Ooo03coo/0j?ok
0<[oo03_oo`0mOok003on`21oh7oPOn/oo`0eool0??on`3Xoo/0b_ol0>ooo03e
oo/00?ok087oPOn1ojcoo03Goo`0look0>Son`3:oo`0kool0?Gon`00oo/0POn1
oh7ogOl0Sm3oo03Goo`0l_ol0>Son`3`o`400?;onP3coo`0kool0?Goo03noo`0
POn1oh7o[?ol0=Ooo03boo`0j?ok0?3o0@00l_oj0??oo03_oo`0mOol0?koo021
oh7oPOn/oo`0eool0?;oo03Xoo/0l?l1003booX0lool0>ooo03eoo`0o_ol087o
POn1omgo08c@oo`0eool0?;oo03YooX0lOon0?ComP3foo/0kook0?Ooo03moo/0
POn1oh7o[Ool0=Ooo03boo`0jOoj0?7ooP3dooH0m_ok0>oon`3goo`0oOok087o
POn1ojgoo03Goo`0l_ol0>WonP3aooh0m?of0?Kon`3_oo/0mool0?gon`21oh7o
POoNo`2Hd?ol0=Ooo03aoo`0j_oj0?7ooP3eoo@0mool0>goo03hoo/0o?ok087o
moom087oPOnloo`0eool0?7oo03ZooX0lOon0?Gom03goo`0kOol0?Son`3loo/0
POogood0POn1okcoo03Goo`0lOol0>[onP3aooh0mOod0?Ooo03]oo`0n?ok0?co
n`21ooOoo@21oh7okOl0Y=3oo03Goo`0lOok0>con@3bood0m_ol0?coo03hoo`0
kOol0?Soo03joo`0POogood0POn1okcoo03Goo`0lOok0>con@3bood0m_ol0?co
o03hoo`0kOol0?Soo03joo`0POogood0POn1okcoo03Goo`0lOok0>con@3bood0
m_ol0?coo03hoo`0kOol0?Soo03joo`0POogood0POn1ongo0:C@oo`0eool0?3o
n`3^ooP0m?ok0?Koo@3iooh0nOok0>gon`3joo/0n_ok087on?om087oPOnloo`0
eool0?3on`3^ooP0m?ok0?Koo@3iooh0nOok0>gon`3joo/0n_ok087on?om087o
POnloo`0eool0?3on`3^ooP0m?ok0?Koo@3iooh0nOok0>gon`3joo/0n_ok087o
n?om087oPOo]o`2Td?ol0=Ooo03`ooX0l?og0?Oon03good0n?om0?[oo03[oo`0
nook0?Son`21ooWoo@21oh7o_?ol0=Ooo03`ooX0l?og0?Oon03good0n?om0?[o
o03[oo`0nook0?Son`21ooWoo@21oh7o_?ol0=Ooo03`ooX0l?og0?Oon03good0
n?om0?[oo03[oo`0nook0?Son`21ooWoo@21oh7okOl0V=3oo03Goo`0kooj0??o
m@3gooP0moon0?KooP3joo`0jool0?_oo03foo`0POn1oh7o/?ol0=Ooo03_ooX0
looe0?Oon03gooh0m_on0?[oo03[oo`0nool0?Koo021oh7oPOn`oo`0eool0>oo
nP3cooD0mooh0?OooP3fooh0n_ol0>_oo03koo`0m_ol087oPOn1on7o09_@oo`0
eool0>kon03hooT00Oooo@3gooP0moon0?KooP3koml0oOok0?Kon`21oh7oPOna
oo`0eool0>kon03hooT00Oooo@3gooP0moon0?KooP3koml0oOok0?Kon`21oh7o
POnaoo`0eool0>kon03hooT00Oooo@3gooP0moon0?KooP3koml0oOok0?Kon`21
oh7oPOoRo`2<d?ol0=Ooo03]onT0o_om0?7ooP3gooh0m_on0?_og`3noo/0m?ok
087oPOn1ok;oo03Goo`0kOoY0?koo@3aooh0moon0?KooP3koml0o_ok0?Con`21
oh7oPOnboo`0eool0>goj@3nood0lOon0?OooP3fooh0nooO0?kon`3doo/0POn1
oh7ohol0P=3oo03Goo`0joo]0?coo@3aooh0jOon0?_og`3noo`0l_ol087oPOn1
ok;oo03Goo`0joo]0?coo@3aooh0jOon0?_og`3noo`0l_ol087oPOn1ok;oo03G
oo`0joo]0?coo@3aooh0jOon0?_og`3noo`0l_ol087oPOn1on?o08c@oo`0eool
0>Wol@3iooh0lOon0>[oo@3lomd00?ok0?;on`21oocoo@21oh7o_?ol0=Ooo03Y
oo40nOon0?7ooP3Zood0o?oM003on`3boo/0POolood0POn1okcoo03Goo`0jOoa
0?WooP3aooh0j_om0?cog@00oo/0l_ok087oo?om087oPOo]o`1Ld?ol0=Ooo03V
ooL0hoon0>_oo@21okKoo@21oh7o_?ol0=Ooo03VooL0hoon0>_oo@21okKoo@21
oh7o_?ol0=Ooo03VooL0hoon0>_oo@21okKoo@21oh7okOl0D=3oo03Goo`0__on
0>coo@21okGoo@21oh7o_?ol0=Ooo02nooh0k?om087o]Oom087oPOnloo`0eool
0;kooP3/ood0POneood0POn1ongo053@oo`0eool0;kooP3^oo/0POneood0POn1
okcoo03Goo`0__on0>kon`21okGoo@21oh7o_?ol0=Ooo02nooh0k_ok087o]Oom
087oPOo]o`18d?ol0=Ooo02nooh0l?ok087oPOn1oh7oj_ol0=Ooo02nooh0l?ok
087oPOn1oh7oj_ol0=Ooo02nooh0l?ok087oPOn1oi_o04S@oo`0eool0;kooP3b
ooX0POn1oh7oPOoYoo`0eool0;kooP3booX0POn1oh7oPOoYoo`0eool0;kooP3b
ooX0POn1oh7oV_l0B=3oo03Goo`0__on0??on`21oh7oPOn1onOoo03Goo`0__on
0??on`21oh7oPOn1onOoo03Goo`0__on0??on`21oh7oPOnHo`18d?ol0=Ooo02n
ooh0m?ol087oPOn1oh7oiOol0=Ooo02nooh0m?ol087oPOn1oh7oiOol0=Ooo02n
ooh0m?ol087oPOn1oiKo04S@oo`0eool0;kooP3eood0POn1oh7oPOoSoo`0eool
0;kooP3eood0POn1oh7oPOoSoo`0eool0;kooP3eood0POn1oh7oU?l0D=3oo03G
oo`0__on0?Koo@21oj_oo@21oh7o_?ol0=Ooo02nooh0m_om087oZoom087oPOnl
oo`0eool0;kooP3food0POn[ood0POn1ongo053@oo`0eool0;kooP3good0POnZ
ood0POn1okcoo03Goo`0__on0?Ooo@21oj[oo@21oh7o_?ol0=Ooo02nooh0moom
087oZ_om087oPOo]o`1@d?ol0=Ooo02nooh0moon087oZOom087oPOnloo`0eool
0;kooP3gooh0POnYood0POn1okcoo03Goo`0__on0?OooP21ojWoo@21oh7okOl0
Dm3oo03Goo`0__on0?Oo0@00POnXood0POn1okcoo03Goo`0__on0?Oo0@00POnX
ood0POn1okcoo03Goo`0__on0?Oo0@00POnXood0POn1ongo04S@oo`0eool0;ko
oP3honl0POn1oh7oPOo^oo`0eool0;kooP3honl0POn1oh7oPOo^oo`0eool0;ko
oP3honl0POn1oh7oWol0B=3oo03Goo`0__on0?Sok`21oh7oPOn1onkoo03Goo`0
__on0?Sok`21oh7oPOn1onkoo03Goo`0__on0?Sok`21oh7oPOnOo`18d?ol0=Oo
o02nooh0n?o_087oPOn1oh7ok_ol0=Ooo02nooh0n?o_087oPOn1oh7ok_ol0=Oo
o02nooh0n?o_087oPOn1oioo03;@oo`0eool087oPOn1oh7oSOol0=Ooo021oh7o
POn1ohgoo03Goo`0POn1oh7oPOnno`0nd?ol0=Ooo021oh7oe_om087oPOnloo`0
eool087oPOoFood0POn1okcoo03Goo`0POn1omKoo@21oh7okOl0?]3oo03Goo`0
POn1omKoo@21oh7o_?ol0=Ooo021oh7oe_om087oPOnloo`0eool087oPOoFood0
POn1ongo03k@oo`0eool087oPOoFood0POn1okcoo03Goo`0POn1omKoo@21oh7o
_?ol0=Ooo021oh7oe_om087oPOo]o`0nd?ol0=Ooo021oh7oe_om087oPOnloo`0
eool087oPOoFood0POn1okcoo03Goo`0POn1omKoo@21oh7okOl0<]3oo03Goo`0
POn1oh7oPOn=oo`0eool087oPOn1oh7oSOol0=Ooo021oh7oPOn1okko03;@oo`0
eool087oPOn1oh7oSOol0=Ooo021oh7oPOn1ohgoo03Goo`0POn1oh7oPOnno`0b
d?ol0=Ooo021oh7oPOn1ohgoo03Goo`0POn1oh7oPOn=oo`0eool087oPOn1oh7o
__l0<]3oo03Goo`0POn1oh7oPOn=oo`0eool087oPOn1oh7oSOol0=Ooo021oh7o
POn1okko04P00=7oo03Goo`0POn1omKoo@21oh7okOl00=7oo03Goo`0POn1omKo
o@21oh7okOl00=7oo03Goo`0POn1omKoo@21oh7okOl0?]3oo03Goo`0POn1omKo
o@21oh7o_?ol0=Ooo021oh7oe_om087oPOnloo`0eool087oPOoFood0POn1ongo
03k@oo`0eool087oPOoFood0POn1okcoo03Goo`0POn1omKoo@21oh7o_?ol0=Oo
o021oh7oe_om087oPOo]o`0nd?ol0=Ooo021oh7oe_om087oPOnloo`0eool087o
POoFood0POn1okcoo03Goo`0POn1omKoo@21oh7okOl0<]3oo03Goo`0POn1oh7o
POn=oo`0eool087oPOn1oh7oSOol0=Ooo021oh7oPOn1okko03;@oo`0eool087o
POn1oh7oSOol0=Ooo021oh7oPOn1ohgoo03Goo`0POn1oh7oPOnno`0bd?ol0=Oo
o021oh7oPOn1ohgoo03Goo`0POn1oh7oPOn=oo`0eool087oPOn1oh7o__l0<]3o
o03Goo`0POn1oh7oPOn=oo`0eool087oPOn1oh7oSOol0=Ooo021oh7oPOn1okko
03;@oo`0eool087oPOn1oh7oSOol0=Ooo021oh7oPOn1ohgoo03Goo`0POn1oh7o
POnno`0nd?ol0=Ooo021oh7oe_om087oPOnloo`0eool087oPOoFood0POn1okco
o03Goo`0POn1omKoo@21oh7okOl0?]3oo03Goo`0POn1omKoo@21oh7o_?ol0=Oo
o021oh7oe_om087oPOnloo`0eool087oPOoFood0POn1ongo03k@oo`0eool087o
POoFood0POn1okcoo03Goo`0POn1omKoo@21oh7o_?ol0=Ooo021oh7oe_om087o
POo]o`0nd?ol0=Ooo021oh7oe_om087oPOnloo`0eool087oPOoFood0POn1okco
o03Goo`0POn1omKoo@21oh7okOl0<]3oo03Goo`0POn1oh7oPOn=oo`0eool087o
POn1oh7oSOol0=Ooo021oh7oPOn1okko03;@oo`0eool087oPOn1oh7oSOol0=Oo
o021oh7oPOn1ohgoo03Goo`0POn1oh7oPOnno`0bd?ol0=Ooo021oh7oPOn1ohgo
o03Goo`0POn1oh7oPOn=oo`0eool087oPOn1oh7o__l0<]3oo03Goo`0POn1oh7o
POn=oo`0eool087oPOn1oh7oSOol0=Ooo021oh7oPOn1okko03k@oo`0eool087o
POoFood0POn1okcoo03Goo`0POn1omKoo@21oh7o_?ol0=Ooo021oh7oe_om087o
POo]o`0nd?ol0=Ooo021oh7oe_om087oPOnloo`0eool087oPOoFood0POn1okco
o03Goo`0POn1omKoo@21oh7okOl0?]3oo03Goo`0POn1omKoo@21oh7o_?ol0=Oo
o021oh7oe_om087oPOnloo`0eool087oPOoFood0POn1ongo03k@oo`0eool087o
POoFood0POn1okcoo03Goo`0POn1omKoo@21oh7o_?ol0=Ooo021oh7oe_om087o
POo]o`0bd?ol0=Ooo021oh7oPOn1ohgoo03Goo`0POn1oh7oPOn=oo`0eool087o
POn1oh7o__l0<]3oo03Goo`0POn1oh7oPOn=oo`0eool087oPOn1oh7oSOol0=Oo
o021oh7oPOn1okko03;@oo`0eool087oPOn1oh7oSOol0=Ooo021oh7oPOn1ohgo
o03Goo`0POn1oh7oPOnno`0bd?ol0=Ooo021oh7oPOn1ohgoo03Goo`0POn1oh7o
POn=oo`0eool087oPOn1oh7o__l0?]3oo03Goo`0POn1omKoo@21oh7o_?ol0=Oo
o021oh7oe_om087oPOnloo`0eool087oPOoFood0POn1ongo03k@oo`0eool087o
POoFood0POn1okcoo03Goo`0POn1omKoo@21oh7o_?ol0=Ooo021oh7oe_om087o
POo]o`0nd?ol0=Ooo021oh7oe_om087oPOnloo`0eool087oPOoFood0POn1okco
o03Goo`0POn1omKoo@21oh7okOl0?]3oo03Goo`0POn1omKoo@21oh7o_?ol0=Oo
o021oh7oe_om087oPOnloo`0eool087oPOoFood0POn1ongo03;@oo`0eool087o
POn1oh7oSOol0=Ooo021oh7oPOn1ohgoo03Goo`0POn1oh7oPOnno`0l003Aoo`0
eool087oPOn1oh7o__l00=7oo03Goo`0POn1oh7oPOnno`00dOol0=Ooo021oh7o
POn1okko03;@oo`0eool087oPOn1oh7oSOol0=Ooo021oh7oPOn1ohgoo03Goo`0
POn1oh7oPOnno`0bd?ol0=Ooo021oh7oPOn1ohgoo03Goo`0POn1oh7oPOn=oo`0
eool087oPOn1oh7o__l0<]3oo03Goo`0POn1oh7oPOn=oo`0eool087oPOn1oh7o
SOol0=Ooo021oh7oPOn1okko03k@oo`0eool087oPOoFood0POn1okcoo03Goo`0
POn1omKoo@21oh7o_?ol0=Ooo021oh7oe_om087oPOo]o`0nd?ol0=Ooo021oh7o
e_om087oPOnloo`0eool087oPOoFood0POn1okcoo03Goo`0POn1omKoo@21oh7o
kOl0?]3oo03Goo`0POn1omKoo@21oh7o_?ol0=Ooo021oh7oe_om087oPOnloo`0
eool087oPOoFood0POn1ongo03k@oo`0eool087oPOoFood0POn1okcoo03Goo`0
POn1omKoo@21oh7o_?ol0=Ooo021oh7oe_om087oPOo]o`0bd?ol0=Ooo021oh7o
POn1ohgoo03Goo`0POn1oh7oPOn=oo`0eool087oPOn1oh7o__l0<]3oo03Goo`0
POn1oh7oPOn=oo`0eool087oPOn1oh7oSOol0=Ooo021oh7oPOn1okko02K@old0
POn1oh7oPOn=old0POn1oh7oPOn=old0POn1oh7oPOnno`0Vd?o=087oPOn1oh7o
SOo=087oPOn1oh7oSOo=087oPOn1oh7o__l0<]3oc@21oh7oe_om087oPOnlold0
POn1omKoo@21oh7o_?o=087oPOoFood0POn1ongo03;@old0POn1omKoo@21oh7o
_?o=087oPOoFood0POn1okcoc@21oh7oe_om087oPOo]o`0b]_om087oPOo0ood0
POn1oj;oo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7okOl0<[Koo@21oh7o
`?om087oPOnRood0POn1ol3oo@21oh7oX_om087oPOo0ood0POn1ongo02Zfood0
POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0:[Koo@21oh7o
POn1oh7ogOom087oPOn1oh7oPOoMood0POn1oh7oPOnXo`0Z]_om087oPOn1oh7o
POoMood0POn1oh7oPOn1omgoo@21oh7oPOn1ojSo02Zfood0POn1oh7oPOn1omgo
o@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0<[Koo@21oh7o`?om087oPOnRood0
POn1ol3oo@21oh7oX_om087oPOo0ood0POn1ongo03:food0POn1ol3oo@21oh7o
X_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOo]o`0b]_om087oPOo0ood0
POn1oj;oo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7okOl0<[Koo@21oh7o
`?om087oPOnRood0POn1ol3oo@21oh7oX_om087oPOo0ood0POn1ongo02Zfood0
POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0:[Koo@21oh7o
POn1oh7ogOom087oPOn1oh7oPOoMood0POn1oh7oPOnXo`0Z]_om087oPOn1oh7o
POoMood0POn1oh7oPOn1omgoo@21oh7oPOn1ojSo02Zfood0POn1oh7oPOn1omgo
o@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0:[Koo@21oh7oPOn1oh7ogOom087o
POn1oh7oPOoMood0POn1oh7oPOnXo`0b]_om087oPOo0ood0POn1oj;oo@21oh7o
`?om087oPOnRood0POn1ol3oo@21oh7okOl0<[Koo@21oh7o`?om087oPOnRood0
POn1ol3oo@21oh7oX_om087oPOo0ood0POn1ongo03:food0POn1ol3oo@21oh7o
X_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOo]o`0b]_om087oPOo0ood0
POn1oj;oo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7okOl0:[Koo@21oh7o
POn1oh7ogOom087oPOn1oh7oPOoMood0POn1oh7oPOnXo`0Z]_om087oPOn1oh7o
POoMood0POn1oh7oPOn1omgoo@21oh7oPOn1ojSo02Zfood0POn1oh7oPOn1omgo
o@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0:[Koo@21oh7oPOn1oh7ogOom087o
POn1oh7oPOoMood0POn1oh7oPOnXo`0b]_om087oPOo0ood0POn1oj;oo@21oh7o
`?om087oPOnRood0POn1ol3oo@21oh7okOl0<[Koo@21oh7o`?om087oPOnRood0
POn1ol3oo@21oh7oX_om087oPOo0ood0POn1ongo03:food0POn1ol3oo@21oh7o
X_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOo]o`0b]_om087oPOo0ood0
POn1oj;oo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7okOl0:[Koo@21oh7o
POn1oh7ogOom087oPOn1oh7oPOoMood0POn1oh7oPOnXo`0Z]_om087oPOn1oh7o
POoMood0POn1oh7oPOn1omgoo@21oh7oPOn1ojSo02Zfood0POn1oh7oPOn1omgo
o@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0:[Son021oh7oPOn1oh7oh_oh087o
POn1oh7oPOoRooP0POn1oh7oPOn[o`0b^Ooe087oPOo5ood0POn1ojGom@21oh7o
aOom087oPOnUooD0POn1olGoo@21oh7okOl0<[_olP21oh7oa_om087oPOnWoo80
POn1olKoo@21oh7oYoob087oPOo6ood0POn1ongo03:koo40POn1olOoo@21oh7o
Yooa087oPOo7ood0POn1ojOol@21oh7oaoom087oPOo]o`0b_?o`087oPOo7ood0
POn1ojSol021oh7oaoom087oPOnXoo00POn1olOoo@21oh7okOl0:[gokP21oh7o
POn1oh7ok?o^087oPOn1oh7oPOo/onh0POn1oh7oPOn`o`0Z_Oo^087oPOn1oh7o
POo/onh0POn1oh7oPOn1oncokP21oh7oPOn1ok3o02Z10840P@210840hP3hoh40
P@210840P@3R0?SoP@210840P@210>80n?l0:X40P@210840P@3R0?SoP@210840
P@210>80n?n10840P@210840hP3ho`0ZP@210840P@210>80n?n10840P@210840
hP3hoh40P@210840P@3R0?So02Z10840P@210840hP3hoh40P@210840P@3R0?So
P@210840P@210>80n?l0:X40P@210840P@3R0?SoP@210840P@210>80n?n10840
P@210840hP3ho`0b_Oo]087oPOo9ood0POn1ojWok@21oh7obOom087oPOnYond0
POn1olWoo@21oh7okOl0<[gokP21oh7ob?om087oPOnYonh0POn1olSoo@21oh7o
ZOo^087oPOo8ood0POn1ongo02Zmonh0POn1oh7oPOn1oncokP21oh7oPOn1oh7o
k?o^087oPOn1oh7o/?l0:[col021oh7oPOn1oh7oj_o`087oPOn1oh7oPOoZoo00
POn1oh7oPOn_o`0Z^ooa087oPOn1oh7oPOoYoo40POn1oh7oPOn1onWol@21oh7o
POn1ojoo02Zkoo80POn1oh7oPOn1onSolP21oh7oPOn1oh7oj?ob087oPOn1oh7o
[_l0<[Wom@21oh7oaOom087oPOnUooD0POn1olGoo@21oh7oYOoe087oPOo5ood0
POn1ongo03:gooT0POn1ol?oo@21oh7oXooi087oPOo3ood0POn1oj?on@21oh7o
`oom087oPOo]o`0b]_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOnRood0
POn1ol3oo@21oh7okOl0<[Koo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7o
X_om087oPOo0ood0POn1ongo02Zfood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7o
gOom087oPOn1oh7oZ?l0:[Koo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0
POn1oh7oPOnXo`0Z]_om087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7o
POn1ojSo02Zfood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOn1oh7o
Z?l0<[Koo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7oX_om087oPOo0ood0
POn1ongo03:food0POn1ol3oo@21oh7oX_om087oPOo0ood0POn1oj;oo@21oh7o
`?om087oPOo]o`0b]_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOnRood0
POn1ol3oo@21oh7okOl0<[Koo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7o
X_om087oPOo0ood0POn1ongo02Zfood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7o
gOom087oPOn1oh7oZ?l0:[Koo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0
POn1oh7oPOnXo`0Z]_om087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7o
POn1ojSo02Zfood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOn1oh7o
Z?l0:[Koo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0POn1oh7oPOnXo`0b
]_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7o
kOl0<[Koo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7oX_om087oPOo0ood0
POn1ongo03:food0POn1ol3oo@21oh7oX_om087oPOo0ood0POn1oj;oo@21oh7o
`?om087oPOo]o`0b]_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOnRood0
POn1ol3oo@21oh7okOl0:[Koo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0
POn1oh7oPOnXo`0Z]_om087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7o
POn1ojSo02Zfood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOn1oh7o
Z?l0:[Koo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0POn1oh7oPOnXo`0b
]_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7o
kOl0<[Koo@21oh7o`?om087oPOnRood0POn1ol3oo@21oh7oX_om087oPOo0ood0
POn1ongo03;?om<0POn1om7oo@21oh7o^ooC087oPOoAood0POn1ok_od`21oh7o
dOom087oPOo]o`0bcooC087oPOoAood0POn1ok_od`21oh7odOom087oPOnkom<0
POn1om7oo@21oh7okOl09/ood`21oh7oPOn1ohOod`21oh7oPOn1ohOod`21oh7o
POn1okWo02K?om<0POn1oh7oPOn7om<0POn1oh7oPOn7om<0POn1oh7oPOnio`0b
coom0=_oo@21oh7oPOn1ohOoo@3Kood0POn1oh7oPOn7ood0foom087oPOn1oh7o
^Ol0</ooo@3Kood0POn1oh7oPOn7ood0foom087oPOn1oh7oQoom0=_oo@21oh7o
POn1okWo03k?ood0foom087oPOoAood0POn1ok_oo@3Kood0POn1om7oo@21oh7o
^oom0=_oo@21oh7odOom087oPOo]o`0ncoom0=_oo@21oh7odOom087oPOnkood0
foom087oPOoAood0POn1ok_oo@3Kood0POn1om7oo@21oh7okOl0?/ooo@3Kood0
POn1om7oo@21oh7o^oom0=_oo@21oh7odOom087oPOnkood0foom087oPOoAood0
POn1ongo03k?ood0foom087oPOoAood0POn1ok_oo@3Kood0POn1om7oo@21oh7o
^oom0=_oo@21oh7odOom087oPOo]o`0bcoom0=_oo@21oh7oPOn1ohOoo@3Kood0
POn1oh7oPOn7ood0foom087oPOn1oh7o^Ol0</ooo@3Kood0POn1oh7oPOn7ood0
foom087oPOn1oh7oQoom0=_oo@21oh7oPOn1okWo03;?ood0foom087oPOn1oh7o
Qoom0=_oo@21oh7oPOn1ohOoo@3Kood0POn1oh7oPOnio`0bcoom0=_oo@21oh7o
POn1ohOoo@3Kood0POn1oh7oPOn7ood0foom087oPOn1oh7o^Ol0</ooo@3Kood0
POn1oh7oPOn7ood0foom087oPOn1oh7oQoom0=_oo@21oh7oPOn1okWo03k?ood0
foom087oPOoAood0POn1ok_oo@3Kood0POn1om7oo@21oh7o^oom0=_oo@21oh7o
dOom087oPOo]o`0ncoom0=_oo@21oh7odOom087oPOnkood0foom087oPOoAood0
POn1ok_oo@3Kood0POn1om7oo@21oh7okOl0?/ooo@3Kood0POn1om7oo@21oh7o
^oom0=_oo@21oh7odOom087oPOnkood0foom087oPOoAood0POn1ongo03k?ood0
foom087oPOoAood0POn1ok_oo@3Kood0POn1om7oo@21oh7o^oom0=_oo@21oh7o
dOom087oPOo]o`0bcoom0=_oo@21oh7oPOn1ohOoo@3Kood0POn1oh7oPOn7ood0
foom087oPOn1oh7o^Ol0</ooo@3Kood0POn1oh7oPOn7ood0foom087oPOn1oh7o
Qoom0=_oo@21oh7oPOn1okWo03;?ood0foom087oPOn1oh7oQoom0=_oo@21oh7o
POn1ohOoo@3Kood0POn1oh7oPOnio`0bcoom0=_oo@21oh7oPOn1ohOoo@3Kood0
POn1oh7oPOn7ood0foom087oPOn1oh7o^Ol0?/ooo@3Kood0POn1om7oo@21oh7o
^oom0=_oo@21oh7odOom087oPOnkood0foom087oPOoAood0POn1ongo03k?ood0
foom087oPOoAood0POn1ok_oo@3Kood0POn1om7oo@21oh7o^oom0=_oo@21oh7o
dOom087oPOo]o`0ncoom0=_oo@21oh7odOom087oPOnkood0foom087oPOoAood0
POn1ok_oo@3Kood0POn1om7oo@21oh7okOl0?/ooo@3Kood0POn1om7oo@21oh7o
^oom0=_oo@21oh7odOom087oPOnkood0foom087oPOoAood0POn1ongo03;?ood0
foom087oPOn1oh7oQoom0=_oo@21oh7oPOn1ohOoo@3Kood0POn1oh7oPOnio`0b
coom0=_oo@21oh7oPOn1ohOoo@3Kood0POn1oh7oPOn7ood0foom087oPOn1oh7o
^Ol0</ooo@3Kood0POn1oh7oPOn7ood0foom087oPOn1oh7oQoom0=_oo@21oh7o
POn1okWo03;?ood0foom087oPOn1oh7oQoom0=_oo@21oh7oPOn1ohOoo@3Kood0
POn1oh7oPOnio`0ncoom0=_oo@21oh7odOom087oPOnkood0foom087oPOoAood0
POn1ok_oo@3Kood0POn1om7oo@21oh7okOl0?/ooo@3Kood0POn1om7oo@21oh7o
^oom0=_oo@21oh7odOom087oPOnkood0foom087oPOoAood0POn1ongo03k?ood0
foom087oPOoAood0POn1ok_oo@3Kood0POn1om7oo@21oh7o^oom0=_oo@21oh7o
dOom087oPOo]o`0ncoom0=_oo@21oh7odOom087oPOnkood0foom087oPOoAood0
POn1ok_oo@3Kood0POn1om7oo@21oh7okOl0</ooo@3Kood0POn1oh7oPOn7ood0
foom087oPOn1oh7oQoom0=_oo@21oh7oPOn1okWo03;?ood0foom087oPOn1oh7o
Qoom0=_oo@21oh7oPOn1ohOoo@3Kood0POn1oh7oPOnio`0bcoom0=_oo@21oh7o
POn1ohOoo@3Kood0POn1oh7oPOn7ood0foom087oPOn1oh7o^Ol0</ooo@3Kood0
POn1oh7oPOn7ood0foom087oPOn1oh7oQoom0=_oo@21oh7oPOn1okWo03;?ood0
foom087oPOn1oh7oQoom0=_oo@21oh7oPOn1ohOoo@3Kood0POn1oh7oPOnio`0n
coom0=_oo@21oh7odOom087oPOnkood0foom087oPOoAood0POn1ok_oo@3Kood0
POn1om7oo@21oh7okOl0?/ooo@3Kood0POn1om7oo@21oh7o^oom0=_oo@21oh7o
dOom087oPOnkood0foom087oPOoAood0POn1ongo03k?ood0foom087oPOoAood0
POn1ok_oo@3Kood0POn1om7oo@21oh7o^oom0=_oo@21oh7odOom087oPOo]o`0n
coom0=_oo@21oh7odOom087oPOnkood0foom087oPOoAood0POn1ok_oo@3Kood0
POn1om7oo@21oh7okOl0</ooo@3Kood0POn1oh7oPOn7ood0foom087oPOn1oh7o
Qoom0=_oo@21oh7oPOn1okWo03;?ood0foom087oPOn1oh7oQoom0=_oo@21oh7o
POn1ohOoo@3Kood0POn1oh7oPOnio`0bcoom0=_oo@21oh7oPOn1ohOoo@3Kood0
POn1oh7oPOn7ood0foom087oPOn1oh7o^Ol0</ooo@3Kood0POn1oh7oPOn7ood0
foom087oPOn1oh7oQoom0=_oo@21oh7oPOn1okWo03k?ood0foom087oPOoAood0
POn1ok_oo@3Kood0POn1om7oo@21oh7o^oom0=_oo@21oh7odOom087oPOo]o`0n
coom0=_oo@21oh7odOom087oPOnkood0foom087oPOoAood0POn1ok_oo@3Kood0
POn1om7oo@21oh7okOl0?/ooo@3Kood0POn1om7oo@21oh7o^oom0=_oo@21oh7o
dOom087oPOnkood0foom087oPOoAood0POn1ongo03k?ood0foom087oPOoAood0
POn1ok_oo@3Kood0POn1om7oo@21oh7o^oom0=_oo@21oh7odOom087oPOo]o`0n
coom0=_oo@3PooL0POn1oh7oPOnbood0foom0>3om`21oh7oPOn1ok;oo@3Kood0
h?og087oPOn1oh7oi?l0Elooo@3Kood0hooa0>_o0@00gOok087oPOn1oh7omoom
0=_oo@3Soo40jol1003Moo/0POn1oh7oPOogood0foom0>?ol@3[o`400=gon`21
oh7oPOnYo`1Dcoom0=_oo@3Uon`0koon0=kon@21oh7oPOn1ooSoo@3Kood0iOo/
0>oooP3NooT0POn1oh7oPOohood0foom0>Gok03_ooh0g_oi087oPOn1oj[o05C?
ood0foom0>Ooj@3aood0g_oi087oPOn1oh7on?om0=_oo@3WonT0lOom0=kon@21
oh7oPOn1ooSoo@3Kood0iooY0?7oo@3NooT0POn1oh7oZ_l0J<ooo@3Kood0j?oh
0?Won03booh0gOoi087o`_om087oPOnkood0foom0>Son03iooP0l_on0=gon@21
ol;oo@21oh7o^oom0=_oo@3XooP0nOoh0?;ooP3MooT0POo2ood0POn1ongo06S?
ood0foom0>WonP3cooX0loon0=kom`21ol?oo@21oh7o^oom0=_oo@3YooX0looj
0??ooP3NooL0POo3ood0POn1ok_oo@3Kood0jOoj0??onP3cooh0g_og087o`oom
087oPOo]o`1Xcoom0=_oo@3ZooX0l?ok0?GooP3MooL0POo3ood0POn1ok_oo@3K
ood0j_oj0?3on`3eooh0gOog087o`oom087oPOnkood0foom0>[onP3`oo/0mOon
0=gom`21ol?oo@21oh7okOl0J<ooo@3Kood0jook0>gon`3fooh0gOog087o`oom
087oPOnkood0foom0>_on`3]oo/0m_on0=gom`21ol?oo@21oh7o^oom0=_oo@3[
oo/0kOok0?KooP3MooL0POo3ood0POn1ongo06c?ood0foom0>_oo03[oo`0m_on
0=kon`00oo`0POn1oh7oPOojood0foom0>_oo03[oo`0m_on0=kon`00oo`0POn1
oh7oPOojood0foom0>_oo03[oo`0m_on0=kon`00oo`0POn1oh7o[?l0Klooo@3K
ood0k?ok0>_on`3gooh0g_ol007ooo`0POn1oh7oPOojood0foom0>con`3[oo/0
moon0=koo001oool087oPOn1oh7on_om0=_oo@3/oo/0jook0?OooP3Noo`00Ooo
o021oh7oPOn/o`1_coom0=_oo@3/oo`0jOol0?Ooo03Poo`00Ooon`21oh7oPOn1
oo_oo@3Kood0k?ol0>Woo03goo`0h?ol007ooo/0POn1oh7oPOokood0foom0>co
o03Yoo`0mool0>3oo001oook087oPOn1ojgo06c?ood0foom0>goo03Xoo`0mool
0>7on`3noo`0POn1oh7oPOokood0foom0>goo03Xoo`0mool0>7on`3noo`0POn1
oh7oPOokood0foom0>goo03Xoo`0mool0>7on`3noo`0POn1oh7o[Ol0P<ooo@3K
ood0kOol0>Ooo03hoo`0hOol0?goo03doo/0look087oPOn1oj;oo@3Kood0kOol
0>Ooo03hoo`0hOol0?goo03doo/0look087oPOn1oj;oo@3Kood0kOol0>Ooo03h
oo`0hOol0?goo03doo/0look087oPOn1omCo08c?ood0foom0>koo03Voo`0n?ol
0>7oo03moo/0mOok0??oo021on_oo@21oh7o^oom0=_oo@3^oo`0i_ol0?Soo03Q
oo`0oOok0?Gon`3coo`0POo[ood0POn1ok_oo@3Kood0k_ol0>Koo03hoo`0hOol
0?gon`3eoo/0lool087ojoom087oPOo]o`20coom0=_oo@3^oo`0f?ol0>;oo03k
oo`0m?ok0?Gon`21on_oo@21oh7o^oom0=_oo@3^oo`0f?ol0>;oo03koo`0m?ok
0?Gon`21on_oo@21oh7o^oom0=_oo@3^oo`0f?ol0>;oo03koo`0m?ok0?Gon`21
on_oo@21oh7okOl0M<ooo@3Kood0k_ol0;Coo03koo`0lool0?Kon`21on[oo@21
oh7o^oom0=_oo@3^oo`0]?ol0?_oo03coo`0m_ok087oj_om087oPOnkood0foom
0>koo02doo`0nool0??oo03foo/0POoZood0POn1ongo07C?ood0foom0>koo02e
oo/0nook0?Con`3hoo/0POoYood0POn1ok_oo@3Kood0k_ol0;Gon`3koo/0m?ok
0?Son`21onWoo@21oh7o^oom0=_oo@3^oo`0]Ook0?_on`3doo/0n?ok087ojOom
087oPOo]o`1Xcoom0=_oo@3_oo`0]?ol0?Woo03coo/0nOok087oPOn1oiooo@3K
ood0kool0;Coo03ioo`0look0?Won`21oh7oPOnOood0foom0>ooo02doo`0nOol
0??on`3ioo/0POn1oh7odOl0J<ooo@3Kood0kool0;Coo03ioo`0l_ol0?[on`21
oh7oPOnNood0foom0>ooo02doo`0nOol0?;oo03joo/0POn1oh7oW_om0=_oo@3_
oo`0]?ol0?Woo03boo`0n_ok087oPOn1om3o06S?ood0foom0>ooo02eoo/0nOok
0??on`3loo/0POn1oh7oWOom0=_oo@3_oo`0]Ook0?Won`3coo/0o?ok087oPOn1
oigoo@3Kood0kool0;Gon`3ioo/0look0?con`21oh7oPOo?o`1Xcoom0=_oo@3_
oo`0]Ool0?Ooo03boo/0oOol087oPOn1oicoo@3Kood0kool0;Goo03goo`0l_ok
0?goo021oh7oPOnLood0foom0>ooo02eoo`0mool0?;on`3moo`0POn1oh7oc_l0
P<ooo@3Kood0kool0?;ok`3Foo`0mool0?7oo03noo/0POoVood0POn1ok_oo@3K
ood0kool0?;ok`3Foo`0mool0?7oo03noo/0POoVood0POn1ok_oo@3Kood0kool
0?;ok`3Foo`0mool0?7oo03noo/0POoVood0POn1ongo083?ood0foom0>ooo03b
onl0eook0?Oon`3boo/00?ok087oiOom087oPOnkood0foom0>ooo03bonl0eook
0?Oon`3boo/00?ok087oiOom087oPOnkood0foom0>ooo03bonl0eook0?Oon`3b
oo/00?ok087oiOom087oPOo]o`20coom0=_oo@3_oo`0l_o_0=Ooo03eoo`0lOol
003oo021onCoo@21oh7o^oom0=_oo@3_oo`0l_o_0=Ooo03eoo`0lOol003oo021
onCoo@21oh7o^oom0=_oo@3_oo`0l_o_0=Ooo03eoo`0lOol003oo021onCoo@21
oh7okOl0M<ooo@3Kood0kool0?;ok`3Goo`0mOol0?3om`21onCoo@21oh7o^oom
0=_oo@3_oo`0l_o_0=Ooo03eoo`0l?og087oi?om087oPOnkood0foom0>ooo03b
onl0eool0?Goo03`ooL0POoTood0POn1ongo06S?ood0foom0>ooo03Uoo`0f?ok
0?Coo03aooP0POn1oh7oVOom0=_oo@3_oo`0iOol0=Son`3doo`0lOoh087oPOn1
oiWoo@3Kood0kool0>Goo03Hoo/0m?ol0?7on021oh7oPOo;o`1Xcoom0=_oo@3_
oo`0iOol0=Soo03coo`0l?oj087oPOn1oiSoo@3Kood0kool0>Goo03Hoo`0lool
0?3onP21oh7oPOnHood0foom0>ooo03Uoo`0f?ol0??oo03`ooX0POn1oh7ob_l0
J<ooo@3Kood0kool0>Goo03Hoo`0look0?7onP21oh7oPOnHood0foom0>ooo03U
oo`0f?ol0??on`3aooX0POn1oh7oV?om0=_oo@3_oo`0iOol0=Soo03coo/0lOoj
087oPOn1ol[o06S?ood0foom0>koo03Voo`0fOol0?7oo03booP0POn1oh7oVOom
0=_oo@3^oo`0i_ol0=Woo03aoo`0l_oh087oPOn1oiWoo@3Kood0k_ol0>Koo03I
oo`0lOol0?;on021oh7oPOo;o`1dcoom0=_oo@3^oo`0i_ol0=Woo03aoo`0l_oh
087ohoom087oPOnkood0foom0>koo03Voo`0fOol0?7oo03booP0POoSood0POn1
ok_oo@3Kood0k_ol0>Koo03Ioo`0lOol0?;on021on?oo@21oh7okOl0P<ooo@3K
ood0k_ol0>Oon`3cooX0kook0?7on`3dooH0POoTood0POn1ok_oo@3Kood0k_ol
0>Oon`3cooX0kook0?7on`3dooH0POoTood0POn1ok_oo@3Kood0k_ol0>Oon`3c
ooX0kook0?7on`3dooH0POoTood0POn1ongo08c?ood0foom0>kon`3Xoo/0mOof
0?7oo03_oo`0mOok003on`21onGoo@21oh7o^oom0=_oo@3^oo/0j?ok0?GomP3a
oo`0kool0?Gon`00oo/0POoUood0POn1ok_oo@3Kood0k_ok0>Son`3eooH0lOol
0>ooo03eoo/00?ok087oiOom087oPOo]o`2<coom0=_oo@3]oo`0j?ok0?Kol`3c
oo`0kool0?Goo03noo`0POoUood0POn1ok_oo@3Kood0kOol0>Son`3foo<0lool
0>ooo03eoo`0o_ol087oiOom087oPOnkood0foom0>goo03Xoo/0m_oc0??oo03_
oo`0mOol0?koo021onGoo@21oh7okOl0S<ooo@3Kood0kOol0>WonP3goo`0o?ol
0?Con`3_oo/0mool0?gon`21oh7oPOnLood0foom0>goo03YooX0mool0?coo03d
oo/0kook0?Ooo03moo/0POn1oh7oW?om0=_oo@3]oo`0jOoj0?Ooo03loo`0m?ok
0>oon`3goo`0oOok087oPOn1olko08c?ood0foom0>coo03ZooX0n?ol0?Woo@3e
oo`0kOol0?Son`3loo/0POn1oh7oWOom0=_oo@3/oo`0j_oj0?Soo03iood0mOol
0>goo03hoo/0o?ok087oPOn1oigoo@3Kood0k?ol0>[onP3hoo`0nOom0?Goo03]
oo`0n?ok0?con`21oh7oPOo?o`2<coom0=_oo@3/oo/0k?oi0?Soo@3hood0mOol
0>goo03hoo`0n_ol087oPOn1oigoo@3Kood0k?ok0>con@3hood0n?om0?Goo03]
oo`0n?ol0?[oo021oh7oPOnMood0foom0>con`3/ooT0n?om0?Soo@3eoo`0kOol
0?Soo03joo`0POn1oh7ocol0S<ooo@3Kood0jook0>kon03ioo`0moom0?Oon`3]
oo/0n_ok0?[on`21oh7oPOnNood0foom0>_on`3^ooP0nOol0?Ooo@3goo/0kOok
0?[on`3joo/0POn1oh7oW_om0=_oo@3[oo/0k_oh0?Woo03good0mook0>gon`3j
oo/0n_ok087oPOn1om3o08c?ood0foom0>_onP3`ooL0nOom0?Koo@3goo`0jool
0?_on`3hoo/0POn1oh7oWoom0=_oo@3[ooX0l?og0?Woo@3food0mool0>_oo03k
oo/0n?ok087oPOn1oiooo@3Kood0jooj0?3om`3iood0m_om0?Ooo03[oo`0nook
0?Son`21oh7oPOoAo`2Hcoom0=_oo@3ZooX0looe0?Woo@3food0mool0>_oo03k
oo`0m_ol087ojOom087oPOnkood0foom0>[onP3cooD0nOom0?Koo@3goo`0jool
0?_oo03foo`0POoYood0POn1ok_oo@3Kood0j_oj0??om@3iood0m_om0?Ooo03[
oo`0nool0?Koo021onWoo@21oh7okOl0Vlooo@3Kood0jOoh0?Son@01ooom0?Wo
o@3food0n?oO0?gon`3foo/0POoZood0POn1ok_oo@3Kood0jOoh0?Son@01ooom
0?Woo@3food0n?oO0?gon`3foo/0POoZood0POn1ok_oo@3Kood0jOoh0?Son@01
ooom0?Woo@3food0n?oO0?gon`3foo/0POoZood0POn1ongo083?ood0foom0>So
j@3nood0j_om0?Sog`3noo/0m?ok087ojoom087oPOnkood0foom0>Soj@3nood0
j_om0?Sog`3noo/0m?ok087ojoom087oPOnkood0foom0>Soj@3nood0j_om0?So
g`3noo/0m?ok087ojoom087oPOo]o`20coom0=_oo@3Vond0o?om0>_oo@3goml0
o_ol0?;oo021on_oo@21oh7o^oom0=_oo@3Vond0o?om0>_oo@3goml0o_ol0?;o
o021on_oo@21oh7o^oom0=_oo@3Vond0o?om0>_oo@3goml0o_ol0?;oo021on_o
o@21oh7okOl0M<ooo@3Kood0i?oa0?WooP3/oo`0n?oM003on`3boo/0POn1oh7o
X_om0=_oo@3Too40nOon0>coo03homd00?ok0?;on`21oh7oPOnRood0foom0>Co
l@3iooh0k?ol0?Sog@00oo/0l_ok087oPOn1omCo04S?ood0foom0>7om`3Ooo`0
POn1oh7oPOoHood0foom0>7om`3Ooo`0POn1oh7oPOoHood0foom0>7om`3Ooo`0
POn1oh7oR_l0?<ooo@3Kood0]_ok087oPOn1oh7of?om0=_oo@2foo/0POn1oh7o
POoHood0foom0;Kon`21oh7oPOn:o`0lcoom0=_oo@2hoo/0POn1oh7oPOoFood0
foom0;Son`21oh7oPOn1omKoo@3Kood0^?ok087oPOn1ohSo04C?ood0foom0;Wo
n`21oiooo@21oh7o^oom0=_oo@2ioo/0POnOood0POn1ok_oo@3Kood0^Ook087o
Woom087oPOo]o`14coom0=_oo@2kooX0POnNood0POn1ok_oo@3Kood0^ooj087o
W_om087oPOnkood0foom0;_onP21oikoo@21oh7okOl0A<ooo@3Kood0_?ok087o
W?om087oPOnkood0foom0;con`21oicoo@21oh7o^oom0=_oo@2loo/0POnLood0
POn1ongo04C?ood0foom0;kon`21oi[oo@21oh7o^oom0=_oo@2noo/0POnJood0
POn1ok_oo@3Kood0__ok087oV_om087oPOo]o`0lcoom0=_oo@2ooo/0POn1oh7o
POo?ood0foom0;oon`21oh7oPOn1olooo@3Kood0_ook087oPOn1oh7o03o?ood0
foom0;ooo@21oh7oPOn1olgoo@3Kood0_oom087oPOn1oh7ocOom0=_oo@2oood0
POn1oh7oPOl1ool0?/ooo@3Kood0`?om087oPOn1oh7oc?om0=_oo@30ood0POn1
oh7oPOo<ood0foom0<3oo@21oh7oPOn1ooko03k?ood0foom0<7oo@21oh7oPOn1
ol_oo@3Kood0`Oom087oPOn1oh7oboom0=_oo@31ood0POn1oh7oPOomo`14coom
0=_oo@31ood0POnEood0POn1ok_oo@3Kood0`Oom087oUOom087oPOnkood0foom
0<7oo@21oiGoo@21oh7okOl0A<ooo@3Kood0`Oon087oU?om087oPOnkood0foom
0<7ooP21oiCoo@21oh7o^oom0=_oo@31ooh0POnDood0POn1ongo04C?ood0foom
0<;ok@21ojCoo@21oh7o^oom0=_oo@32ond0POnTood0POn1ok_oo@3Kood0`_o]
087oY?om087oPOo]o`14coom0=_oo@32ond0POnTood0POn1ok_oo@3Kood0`_o]
087oY?om087oPOnkood0foom0<;ok@21ojCoo@21oh7okOl0?<ooo@3Kood0`_o]
087oPOn1oh7of_om0=_oo@32ond0POn1oh7oPOoJood0foom0<;ok@21oh7oPOn<
o`0bcoom0=_oo@21oh7oPOn1ohOoo@3Kood0POn1oh7oPOn7ood0foom087oPOn1
oh7o^Ol0</ooo@3Kood0POn1oh7oPOn7ood0foom087oPOn1oh7oQoom0=_oo@21
oh7oPOn1okWo03;?ood0foom087oPOn1oh7oQoom0=_oo@21oh7oPOn1ohOoo@3K
ood0POn1oh7oPOnio`0bcoom0=_oo@21oh7oPOn1ohOoo@3Kood0POn1oh7oPOn7
ood0foom087oPOn1oh7o^Ol0?/ooo@3Kood0POn1om7oo@21oh7o^oom0=_oo@21
oh7odOom087oPOnkood0foom087oPOoAood0POn1ongo03k?ood0foom087oPOoA
ood0POn1ok_oo@3Kood0POn1om7oo@21oh7o^oom0=_oo@21oh7odOom087oPOo]
o`0ncoom0=_oo@21oh7odOom087oPOnkood0foom087oPOoAood0POn1ok_oo@3K
ood0POn1om7oo@21oh7okOl0?/ooo@3Kood0POn1om7oo@21oh7o^oom0=_oo@21
oh7odOom087oPOnkood0foom087oPOoAood0POn1ongo03;?ood0foom087oPOn1
oh7oQoom0=_oo@21oh7oPOn1ohOoo@3Kood0POn1oh7oPOnio`0bcoom0=_oo@21
oh7oPOn1ohOoo@3Kood0POn1oh7oPOn7ood0foom087oPOn1oh7o^Ol0</ooo@3K
ood0POn1oh7oPOn7ood0foom087oPOn1oh7oQoom0=_oo@21oh7oPOn1okWo03;?
ood0foom087oPOn1oh7oQoom0=_oo@21oh7oPOn1ohOoo@3Kood0POn1oh7oPOni
o`0ncoom0=_oo@21oh7odOom087oPOnkood0foom087oPOoAood0POn1ok_oo@3K
ood0POn1om7oo@21oh7okOl0?/ooo@3Kood0POn1om7oo@21oh7o^oom0=_oo@21
oh7odOom087oPOnkood0foom087oPOoAood0POn1ongo03k?ood0foom087oPOoA
ood0POn1ok_oo@3Kood0POn1om7oo@21oh7o^oom0=_oo@21oh7odOom087oPOo]
o`0ncoom0=_oo@21oh7odOom087oPOnkood0foom087oPOoAood0POn1ok_oo@3K
ood0POn1om7oo@21oh7okOl0</ooo@3Kood0POn1oh7oPOn7ood0foom087oPOn1
oh7oQoom0=_oo@21oh7oPOn1okWo03;?ood0foom087oPOn1oh7oQoom0=_oo@21
oh7oPOn1ohOoo@3Kood0POn1oh7oPOnio`0bcoom0=_oo@21oh7oPOn1ohOoo@3K
ood0POn1oh7oPOn7ood0foom087oPOn1oh7o^Ol0</ooo@3Kood0POn1oh7oPOn7
ood0foom087oPOn1oh7oQoom0=_oo@21oh7oPOn1okWo03k?ood0foom087oPOoA
ood0POn1ok_oo@3Kood0POn1om7oo@21oh7o^oom0=_oo@21oh7odOom087oPOo]
o`0ncoom0=_oo@21oh7odOom087oPOnkood0foom087oPOoAood0POn1ok_oo@3K
ood0POn1om7oo@21oh7okOl0?/ooo@3Kood0POn1om7oo@21oh7o^oom0=_oo@21
oh7odOom087oPOnkood0foom087oPOoAood0POn1ongo03k?ood0foom087oPOoA
ood0POn1ok_oo@3Kood0POn1om7oo@21oh7o^oom0=_oo@21oh7odOom087oPOo]
o`0bcoom0=_oo@21oh7oPOn1ohOoo@3Kood0POn1oh7oPOn7ood0foom087oPOn1
oh7o^Ol0</ooo@3Kood0POn1oh7oPOn7ood0foom087oPOn1oh7oQoom0=_oo@21
oh7oPOn1okWo03;?ood0foom087oPOn1oh7oQoom0=_oo@21oh7oPOn1ohOoo@3K
ood0POn1oh7oPOnio`0bcoom0=_oo@21oh7oPOn1ohOoo@3Kood0POn1oh7oPOn7
ood0foom087oPOn1oh7o^Ol0</ooo@3Kood0POn1oh7oPOn7ood0foom087oPOn1
oh7oQoom0=_oo@21oh7oPOn1okWo03k?ood0foom087oPOoAood0POn1ok_oo@3K
ood0POn1om7oo@21oh7o^oom0=_oo@21oh7odOom087oPOo]o`0ncoom0=_oo@21
oh7odOom087oPOnkood0foom087oPOoAood0POn1ok_oo@3Kood0POn1om7oo@21
oh7okOl0?/ooo@3Kood0POn1om7oo@21oh7o^oom0=_oo@21oh7odOom087oPOnk
ood0foom087oPOoAood0POn1ongo03k?ood0foom087oPOoAood0POn1ok_oo@3K
ood0POn1om7oo@21oh7o^oom0=_oo@21oh7odOom087oPOo]o`0bcoom0=_oo@21
oh7oPOn1ohOoo@3Kood0POn1oh7oPOn7ood0foom087oPOn1oh7o^Ol0</ooo@3K
ood0POn1oh7oPOn7ood0foom087oPOn1oh7oQoom0=_oo@21oh7oPOn1okWo03;?
ood0foom087oPOn1oh7oQoom0=_oo@21oh7oPOn1ohOoo@3Kood0POn1oh7oPOni
o`0bcoom0=_oo@21oh7oPOn1ohOoo@3Kood0POn1oh7oPOn7ood0foom087oPOn1
oh7o^Ol0?/ooo@3Kood0POn1om7oo@21oh7o^oom0=_oo@21oh7odOom087oPOnk
ood0foom087oPOoAood0POn1ongo03k?ood0foom087oPOoAood0POn1ok_oo@3K
ood0POn1om7oo@21oh7o^oom0=_oo@21oh7odOom087oPOo]o`0bcooC087oPOoA
ood0POn1ok_od`21oh7odOom087oPOnkom<0POn1om7oo@21oh7okOl0</ood`21
oh7odOom087oPOnkom<0POn1om7oo@21oh7o^ooC087oPOoAood0POn1ongo02K?
om<0POn1oh7oPOn7om<0POn1oh7oPOn7om<0POn1oh7oPOnio`0VcooC087oPOn1
oh7oQooC087oPOn1oh7oQooC087oPOn1oh7o^Ol0:[Koo@21oh7oPOn1oh7ogOom
087oPOn1oh7oPOoMood0POn1oh7oPOnXo`0Z]_om087oPOn1oh7oPOoMood0POn1
oh7oPOn1omgoo@21oh7oPOn1ojSo03:food0POn1ol3oo@21oh7oX_om087oPOo0
ood0POn1oj;oo@21oh7o`?om087oPOo]o`0b]_om087oPOo0ood0POn1oj;oo@21
oh7o`?om087oPOnRood0POn1ol3oo@21oh7okOl0<[Koo@21oh7o`?om087oPOnR
ood0POn1ol3oo@21oh7oX_om087oPOo0ood0POn1ongo03:food0POn1ol3oo@21
oh7oX_om087oPOo0ood0POn1oj;oo@21oh7o`?om087oPOo]o`0Z]_om087oPOn1
oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7oPOn1ojSo02Zfood0POn1oh7oPOn1
omgoo@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0:[Koo@21oh7oPOn1oh7ogOom
087oPOn1oh7oPOoMood0POn1oh7oPOnXo`0Z]_om087oPOn1oh7oPOoMood0POn1
oh7oPOn1omgoo@21oh7oPOn1ojSo02Zfood0POn1oh7oPOn1omgoo@21oh7oPOn1
oh7ogOom087oPOn1oh7oZ?l0<[Koo@21oh7o`?om087oPOnRood0POn1ol3oo@21
oh7oX_om087oPOo0ood0POn1ongo03:food0POn1ol3oo@21oh7oX_om087oPOo0
ood0POn1oj;oo@21oh7o`?om087oPOo]o`0b]_om087oPOo0ood0POn1oj;oo@21
oh7o`?om087oPOnRood0POn1ol3oo@21oh7okOl0<[Koo@21oh7o`?om087oPOnR
ood0POn1ol3oo@21oh7oX_om087oPOo0ood0POn1ongo02Zfood0POn1oh7oPOn1
omgoo@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0:[Koo@21oh7oPOn1oh7ogOom
087oPOn1oh7oPOoMood0POn1oh7oPOnXo`0Z]_om087oPOn1oh7oPOoMood0POn1
oh7oPOn1omgoo@21oh7oPOn1ojSo02Zfood0POn1oh7oPOn1omgoo@21oh7oPOn1
oh7ogOom087oPOn1oh7oZ?l0<[Koo@21oh7o`?om087oPOnRood0POn1ol3oo@21
oh7oX_om087oPOo0ood0POn1ongo03:food0POn1ol3oo@21oh7oX_om087oPOo0
ood0POn1oj;oo@21oh7o`?om087oPOo]o`0b]_om087oPOo0ood0POn1oj;oo@21
oh7o`?om087oPOnRood0POn1ol3oo@21oh7okOl0<[Koo@21oh7o`?om087oPOnR
ood0POn1ol3oo@21oh7oX_om087oPOo0ood0POn1ongo02Zfood0POn1oh7oPOn1
omgoo@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0:[Koo@21oh7oPOn1oh7ogOom
087oPOn1oh7oPOoMood0POn1oh7oPOnXo`0Z]_om087oPOn1oh7oPOoMood0POn1
oh7oPOn1omgoo@21oh7oPOn1ojSo02Zfood0POn1oh7oPOn1omgoo@21oh7oPOn1
oh7ogOom087oPOn1oh7oZ?l0<[Koo@21oh7o`?om087oPOnRood0POn1ol3oo@21
oh7oX_om087oPOo0ood0POn1ongo03:food0POn1ol3oo@21oh7oX_om087oPOo0
ood0POn1oj;oo@21oh7o`?om087oPOo]o`0b]_om087oPOo0ood0POn1oj;oo@21
oh7o`?om087oPOnRood0POn1ol3oo@21oh7okOl0<[Koo@21oh7o`?om087oPOnR
ood0POn1ol3oo@21oh7oX_om087oPOo0ood0POn1ongo02Zfood0POn1oh7oPOn1
omgoo@21oh7oPOn1oh7ogOom087oPOn1oh7oZ?l0:[Koo@21oh7oPOn1oh7ogOom
087oPOn1oh7oPOoMood0POn1oh7oPOnXo`0Z]_om087oPOn1oh7oPOoMood0POn1
oh7oPOn1omgoo@21oh7oPOn1ojSo02ZhooT0POn1oh7oPOn1on7on@21oh7oPOn1
oh7ohOoi087oPOn1oh7oZ_l0:[Wom`21oh7oPOn1oh7ohoog087oPOn1oh7oPOoS
ooL0POn1oh7oPOn[o`0b^ooc087oPOo5ood0POn1ojOol`21oh7oaOom087oPOnW
oo<0POn1olGoo@21oh7okOl0<[_olP21oh7oa_om087oPOnWoo80POn1olKoo@21
oh7oYoob087oPOo6ood0POn1ongo03:loo00POn1olOoo@21oh7oZ?o`087oPOo7
ood0POn1ojSol021oh7oaoom087oPOo]o`0b_Oo_087oPOo7ood0POn1ojWok`21
oh7oaoom087oPOnYonl0POn1olOoo@21oh7okOl0:[kok@21oh7oPOn1oh7okOo]
087oPOn1oh7oPOo]ond0POn1oh7oPOn`o`0Z__o]087oPOn1oh7oPOo]ond0POn1
oh7oPOn1ongok@21oh7oPOn1ok3o02Z10840P@210840hP3hoh40P@210840P@3R
0?SoP@210840P@210>80n?l0:X40P@210840P@3R0?SoP@210840P@210>80n?n1
0840P@210840hP3ho`0ZP@210840P@210>80n?n10840P@210840hP3hoh40P@21
0840P@3R0?So02Z10840P@210840hP3hoh40P@210840P@3R0?SoP@210840P@21
0>80n?l0<[kok@21oh7ob?om087oPOnZond0POn1olSoo@21oh7oZ_o]087oPOo8
ood0POn1ongo03:nond0POn1olSoo@21oh7oZ_o]087oPOo8ood0POn1oj[ok@21
oh7ob?om087oPOo]o`0Z__o]087oPOn1oh7oPOo]ond0POn1oh7oPOn1ongok@21
oh7oPOn1ok3o02Zmonl0POn1oh7oPOn1on_ok`21oh7oPOn1oh7ojoo_087oPOn1
oh7o[ol0:[col@21oh7oPOn1oh7ojOoa087oPOn1oh7oPOoYoo40POn1oh7oPOn^
o`0Z^ooc087oPOn1oh7oPOoWoo<0POn1oh7oPOn1onOol`21oh7oPOn1ojgo03:i
ooH0POn1olCoo@21oh7oYOof087oPOo4ood0POn1ojGomP21oh7oa?om087oPOo]
o`0b^?oi087oPOo2ood0POn1ojCon@21oh7o`_om087oPOnTooT0POn1ol;oo@21
oh7okOl0;87oPOn1oo7oo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0POn1
ongo02b1oh7oPOoaood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOo]
o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo02b1oh7oPOoaood0POn1oh7oPOn1
omgoo@21oh7oPOn1oh7ogOom087oPOo]o`0/POn1oh7olOom087oPOn1oh7oPOoM
ood0POn1oh7oPOn1omgoo@21oh7okOl0;87oPOn1oo7oo@21oh7oPOn1oh7ogOom
087oPOn1oh7oPOoMood0POn1ongo02b1oh7oPOoaood0POn1oh7oPOn1omgoo@21
oh7oPOn1oh7ogOom087oPOo]o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oROl0;87oPOn1oo7oo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoM
ood0POn1ongo02b1oh7oPOoaood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom
087oPOo]o`0/POn1oh7olOom087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21
oh7okOl0;87oPOn1oo7oo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0POn1
ongo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0/POn1
oh7olOom087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7okOl0;87oPOn1
oo7oo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0POn1ongo02b1oh7oPOoa
ood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOo]o`0/POn1oh7olOom
087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7okOl0887oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn9o`0/POn1oh7olOom087oPOn1oh7oPOoMood0POn1oh7oPOn1
omgoo@21oh7okOl0;87oPOn1oo7oo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoM
ood0POn1ongo02b1oh7oPOoaood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom
087oPOo]o`0/POn1oh7olOom087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21
oh7okOl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo02b1
oh7oPOoaood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOo]o`0/POn1
oh7olOom087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7okOl0;87oPOn1
oo7oo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0POn1ongo02b1oh7oPOoa
ood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOo]o`0PPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0;87oPOn1oo7oo@21oh7oPOn1
oh7ogOom087oPOn1oh7oPOoMood0POn1ongo02b1oh7oPOoaood0POn1oh7oPOn1
omgoo@21oh7oPOn1oh7ogOom087oPOo]o`0/POn1oh7olOom087oPOn1oh7oPOoM
ood0POn1oh7oPOn1omgoo@21oh7okOl0;87oPOn1oo7oo@21oh7oPOn1oh7ogOom
087oPOn1oh7oPOoMood0POn1ongo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0
;87oPOn1oo7oo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0POn1ongo02b1
oh7oPOoaood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOo]o`0/POn1
oh7olOom087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7okOl0;87oPOn1
oo7oo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0POn1ongo0221oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0/POn1oh7olOom087oPOn1
oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7okOl0;87oPOn1oo7oo@21oh7oPOn1
oh7ogOom087oPOn1oh7oPOoMood0POn1ongo02b1oh7oPOoaood0POn1oh7oPOn1
omgoo@21oh7oPOn1oh7ogOom087oPOo]o`0/POn1oh7olOom087oPOn1oh7oPOoM
ood0POn1oh7oPOn1omgoo@21oh7okOl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1ohWo02b1oh7oPOoaood0POn1oh7oPOn1omgoo@21oh7oPOn1
oh7ogOom087oPOo]o`0/POn1oh7olOom087oPOn1oh7oPOoMood0POn1oh7oPOn1
omgoo@21oh7okOl0;87oPOn1oo7oo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoM
ood0POn1ongo02b1oh7oPOoaood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom
087oPOo]o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0
887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo02b1oh7oPOoaood0POn1
oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOo]o`0/POn1oh7olOom087oPOn1
oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7okOl0;87oPOn1oo7oo@21oh7oPOn1
oh7ogOom087oPOn1oh7oPOoMood0POn1ongo02b1oh7oPOoaood0POn1oh7oPOn1
omgoo@21oh7oPOn1oh7ogOom087oPOo]o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oROl0;87oPOn1oo7oo@21oh7oPOn1oh7ogOom087oPOn1
oh7oPOoMood0POn1ongo02b1oh7oPOoaood0POn1oh7oPOn1omgoo@21oh7oPOn1
oh7ogOom087oPOo]o`0/POn1oh7olOom087oPOn1oh7oPOoMood0POn1oh7oPOn1
omgoo@21oh7okOl0;87oPOn1oo7oo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoM
ood0POn1ongo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9
o`0/POn1oh7olOom087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7okOl0
;87oPOn1oo7oo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0POn1ongo02b1
oh7oPOoaood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOo]o`0/POn1
oh7olOom087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7okOl0887oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0
887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn9o`0/POn1oh7olOom087oPOn1oh7oPOoMood0POn1
oh7oPOn1omgoo@21oh7okOl0;87oPOn1oo7oo@21oh7oPOn1oh7ogOom087oPOn1
oh7oPOoMood0POn1ongo02b1oh7oPOoaood0POn1oh7oPOn1omgoo@21oh7oPOn1
oh7ogOom087oPOo]o`0/POn1oh7olOom087oPOn1oh7oPOoMood0POn1oh7oPOn1
omgoo@21oh7okOl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
ohWo02b1oh7oPOoaood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOo]
o`0/POn1oh7olOom087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7okOl0
;87oPOn1oo7oo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0POn1ongo02b1
oh7oPOoaood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOo]o`0PPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9
o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0;87oPOn1oo7oo@21
oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0POn1ongo02b1oh7oPOoaood0POn1
oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOo]o`0/POn1oh7olOom087oPOn1
oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7okOl0;87oPOn1oo7oo@21oh7oPOn1
oh7ogOom087oPOn1oh7oPOoMood0POn1ongo0221oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0
887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oROl0;87oPOn1oo7oo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0POn1
ongo02b1oh7oPOoaood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOo]
o`0/POn1oh7olOom087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7okOl0
;87oPOn1oo7oo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0POn1ongo0221
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0/POn1oh7olOom
087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7okOl0;87oPOn1oo7oo@21
oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0POn1ongo02b1oh7oPOoaood0POn1
oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOo]o`0/POn1oh7olOom087oPOn1
oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7okOl0887oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9
o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1ohWo02b1oh7oPOoaood0POn1oh7oPOn1omgoo@21
oh7oPOn1oh7ogOom087oPOo]o`0/POn1oh7olOom087oPOn1oh7oPOoMood0POn1
oh7oPOn1omgoo@21oh7okOl0;87oPOn1oo7oo@21oh7oPOn1oh7ogOom087oPOn1
oh7oPOoMood0POn1ongo02b1oh7oPOoaood0POn1oh7oPOn1omgoo@21oh7oPOn1
oh7ogOom087oPOo]o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0
887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo02b1oh7oPOoa
ood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOo]o`0/POn1oh7olOom
087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7okOl0;87oPOn1oo7oo@21
oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0POn1ongo02b1oh7oPOoaood0POn1
oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOo]o`0PPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0;87oPOn1oo7oo@21oh7oPOn1oh7ogOom
087oPOn1oh7oPOoMood0POn1ongo02b1oh7oPOoaood0POn1oh7oPOn1omgoo@21
oh7oPOn1oh7ogOom087oPOo]o`0/POn1oh7olOom087oPOn1oh7oPOoMood0POn1
oh7oPOn1omgoo@21oh7okOl0;87oPOn1oo7oo@21oh7oPOn1oh7ogOom087oPOn1
oh7oPOoMood0POn1ongo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9
o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn9o`0/POn1oh7olOom087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21
oh7okOl0;87oPOn1oo7oo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0POn1
ongo02b1oh7oPOoaood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOo]
o`0/POn1oh7olOom087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21oh7okOl0
887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0/POn1oh7olOom087oPOn1oh7oPOoM
ood0POn1oh7oPOn1omgoo@21oh7okOl0;87oPOn1oo7oo@21oh7oPOn1oh7ogOom
087oPOn1oh7oPOoMood0POn1ongo02b1oh7oPOoaood0POn1oh7oPOn1omgoo@21
oh7oPOn1oh7ogOom087oPOo]o`0/POn1oh7olOom087oPOn1oh7oPOoMood0POn1
oh7oPOn1omgoo@21oh7okOl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1ohWo02b1oh7oPOoaood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom
087oPOo]o`0/POn1oh7olOom087oPOn1oh7oPOoMood0POn1oh7oPOn1omgoo@21
oh7okOl0;87oPOn1oo7oo@21oh7oPOn1oh7ogOom087oPOn1oh7oPOoMood0POn1
ongo002J0000ohnP0000001]0nP00004000000180000B0000100800300P00000
0000007Z8I`0000006d3j0?Y0004E@?[0000><_oo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1om?o0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0><_o
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7o
POn1om?o03S;ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0
POn1oh7oPOn1oh7oPOoCo`0hboom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOn1oh7odol0><_oo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1om?o0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0h
boom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7o
POn1oh7odol0><_oo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1om?o0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`14eook0??on`21oh7oPOn1oh7oPOn1ok?on`3coo/0
POn1oh7oPOn1oh7oPOncoo/0look087oPOn1oh7oPOn1oh7ogOl0A=Oon`3coo`0
POn1oh7oPOn1oh7oPOnboo/0lool087oPOn1oh7oPOn1oh7o/_ok0??oo021oh7o
POn1oh7oPOn1omco04CFoo/0mOok087oPOn1oh7oPOn1oh7o/Ook0?Gon`21oh7o
POn1oh7oPOn1ok7on`3eoo/0POn1oh7oPOn1oh7oPOoLo`14eOol0?Kon`21oh7o
POn1oh7oPOn1ojooo03foo/0POn1oh7oPOn1oh7oPOn_oo`0m_ok087oPOn1oh7o
POn1oh7ofol0A=Gon`3hoo/0POn1oh7oPOn1oh7oPOn^oo/0n?ok087oPOn1oh7o
POn1oh7o[_ok0?Son`21oh7oPOn1oh7oPOn1om[o04CDoo/0nOok087oPOn1oh7o
POn1oh7o[Ook0?Won`21oh7oPOn1oh7oPOn1ojgon`3ioo/0POn1oh7oPOn1oh7o
POoJo`14dool0?[on`21oh7oPOn1oh7oPOn1oj_oo03joo/0POn1oh7oPOn1oh7o
POn[oo`0n_ok087oPOn1oh7oPOn1oh7ofOl0A=?on`3loo/0POn1oh7oPOn1oh7o
POnZoo/0o?ok087oPOn1oh7oPOn1oh7oZ_ok0?con`21oh7oPOn1oh7oPOn1omSo
04CBoo/0oOol087oPOn1oh7oPOn1oh7oZ?ok0?goo021oh7oPOn1oh7oPOn1ojSo
n`3moo`0POn1oh7oPOn1oh7oPOoGo`14dOol0?kon`21oh7oPOn1oh7oPOn1ojOo
o03noo/0POn1oh7oPOn1oh7oPOnWoo`0o_ok087oPOn1oh7oPOn1oh7oeol0A=7o
n`00oo/0POn1oh7oPOn1oh7oPOnVoo/00?ok087oPOn1oh7oPOn1oh7oY_ok003o
n`21oh7oPOn1oh7oPOn1omKo04C@oo`00?ol087oPOn1oh7oPOn1oh7oY?ol003o
o021oh7oPOn1oh7oPOn1ojCoo000oo`0POn1oh7oPOn1oh7oPOoEo`0hcoog087o
POn1oh7oPOn1oh7oXoog087oPOn1oh7oPOn1oh7oXoog087oPOn1oh7oPOn1oh7o
eOl0><oon021oh7oPOn1oh7oPOn1oj;on021oh7oPOn1oh7oPOn1oj;on021oh7o
POn1oh7oPOn1omCo03S>ooX0POn1oh7oPOn1oh7oPOnPooX0POn1oh7oPOn1oh7o
POnPooX0POn1oh7oPOn1oh7oPOoCo`0hc_oj087oPOn1oh7oPOn1oh7oX?oj087o
POn1oh7oPOn1oh7oX?oj087oPOn1oh7oPOn1oh7odol0><oon021oh7oPOn1oh7o
POn1oj;on021oh7oPOn1oh7oPOn1oj;on021oh7oPOn1oh7oPOn1omCo03S?ooP0
POn1oh7oPOn1oh7oPOnRooP0POn1oh7oPOn1oh7oPOnRooP0POn1oh7oPOn1oh7o
POoDo`0hd?of087oPOn1oh7oPOn1oh7oY?of087oPOn1oh7oPOn1oh7oY?of087o
POn1oh7oPOn1oh7oeOl0A=7on`00oo/0POn1oh7oPOn1oh7oPOnVoo/00?ok087o
POn1oh7oPOn1oh7oY_ok003on`21oh7oPOn1oh7oPOn1omKo04CAoo`0o_ol087o
POn1oh7oPOn1oh7oY_ol0?koo021oh7oPOn1oh7oPOn1ojKoo03noo`0POn1oh7o
POn1oh7oPOoFo`14d_ol0?gon`21oh7oPOn1oh7oPOn1ojSoo03moo/0POn1oh7o
POn1oh7oPOnXoo`0oOok087oPOn1oh7oPOn1oh7oeol0A=?on`3loo/0POn1oh7o
POn1oh7oPOnZoo/0o?ok087oPOn1oh7oPOn1oh7oZ_ok0?con`21oh7oPOn1oh7o
POn1omSo04CCoo`0n_ol087oPOn1oh7oPOn1oh7oZ_ol0?[oo021oh7oPOn1oh7o
POn1oj[oo03joo`0POn1oh7oPOn1oh7oPOoHo`14e?ok0?[on`21oh7oPOn1oh7o
POn1ojcon`3joo/0POn1oh7oPOn1oh7oPOn/oo/0n_ok087oPOn1oh7oPOn1oh7o
fOl0A=Gon`3hoo/0POn1oh7oPOn1oh7oPOn^oo/0n?ok087oPOn1oh7oPOn1oh7o
[_ok0?Son`21oh7oPOn1oh7oPOn1om[o04CEoo`0m_ol087oPOn1oh7oPOn1oh7o
[_ol0?Koo021oh7oPOn1oh7oPOn1ojkoo03foo`0POn1oh7oPOn1oh7oPOoJo`14
e_ok0?Kon`21oh7oPOn1oh7oPOn1ok3on`3foo/0POn1oh7oPOn1oh7oPOn`oo/0
m_ok087oPOn1oh7oPOn1oh7ofol0A=Oon`3doo/0POn1oh7oPOn1oh7oPOnboo/0
m?ok087oPOn1oh7oPOn1oh7o/_ok0?Con`21oh7oPOn1oh7oPOn1omco04CGoo`0
l_ol087oPOn1oh7oPOn1oh7o/_ol0?;oo021oh7oPOn1oh7oPOn1ok;oo03boo`0
POn1oh7oPOn1oh7oPOoLo`14f?ok0?;on`21oh7oPOn1oh7oPOn1okCon`3boo/0
POn1oh7oPOn1oh7oPOndoo/0l_ok087oPOn1oh7oPOn1oh7ogOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0VP000?n:X0000000K@:X000010000000B000
04P0000@02000`08000000000001jR6L0000001]0Z43j@?[15D6R@0002b1oh7o
POoaood0POn1oh7oPOn1omgoo@21oh7oPOn1oh7ogOom087oPOo]o`0PPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0P
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0;87oPOn1oo7oo@21oh7o
POn1oh7ogOom087oPOn1oh7oPOoMood0POn1ongo02b1oh7oPOoaood0POn1oh7o
POn1omgoo@21oh7oPOn1oh7ogOom087oPOo]o`0/POn1oh7olOom087oPOn1oh7o
POoMood0POn1oh7oPOn1omgoo@21oh7okOl0;87oPOn1oo7oo@21oh7oPOn1oh7o
gOom087oPOn1oh7oPOoMood0POn1ongo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
ROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo
0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0P
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
ROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo
0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`0Z
POn1oh7ogook087oPOn1oh7oPOoOoo/0POn1oh7oPOn1omoon`21oh7o02Z1oh7o
POoPooT0POn1oh7oPOn1on7on@21oh7oPOn1oh7ohOoi087oP_l0:X7oPOn1on3o
n@21oh7oPOn1oh7ohOoi087oPOn1oh7oPOoQooT0POn2o`0ZPOn1oh7oh?oi087o
POn1oh7oPOoQooT0POn1oh7oPOn1on7on@21oh;o02Z1oh7oPOoQooL0POn1oh7o
POn1on?om`21oh7oPOn1oh7ohoog087oPol0:X7oPOn1on7om`21oh7oPOn1oh7o
hoog087oPOn1oh7oPOoSooL0POn3o`0ZPOn1oh7ohOog087oPOn1oh7oPOoSooL0
POn1oh7oPOn1on?om`21oh?o03J1oh7oPOoRoo/00?ol087oPOn1oh7oPOoUoo/0
0?ol087oPOn1oh7oPOoUoo/00?ol087oQ?l0>H7oPOn1on;oo001oool087oPOn1
oh7oPOoUoo`00Oooo021oh7oPOn1oh7oiOol007ooo`0POn4o`0iPOn1oh7oh_ol
007ooo/0POn1oh7oPOn1onKoo001oook087oPOn1oh7oPOoVoo`00Ooon`21ohGo
03J1oh7oPOoSoo/0o_ol087oPOn1oh7oPOoWoo/0o_ol087oPOn1oh7oPOoWoo/0
o_ol087oQOl0H87oPOn[oo/0look0=?oo03moo`0m?ok0??on`21oh7oPOn1omKo
n`3coo/0dool0?goo03doo/0look087oPOn1oh7oe_ok0??on`3Coo`0oOol0?Co
n`3coo/0POn/o`1PPOn1oj_on`3coo`0d_ol0?gon`3eoo/0lool087oPOn1oh7o
eOok0??oo03Boo`0oOok0?Gon`3coo`0POn1oh7oPOoEoo/0lool0=;oo03moo/0
mOok0??oo021oj_o0621oh7oZ_ok0?Gon`3Coo`0nool0?Con`3eoo/0POn1oh7o
POoDoo/0mOok0=?oo03koo`0m?ok0?Gon`21oh7oPOn1omCon`3eoo/0dool0?_o
o03doo/0mOok087oZol0K87oPOnYoo`0m_ok0?3oo@3Woo`0nool0??oo03foo/0
POn1oh7oPOoBoo`0m_ok0?3oo@3Woo`0nool0??oo03foo/0POn1oh7oPOoBoo`0
m_ok0?3oo@3Woo`0nool0??oo03foo/0POnZo`1/POn1ojWon`3hoo/0koom0>So
n`3koo/0m?ok0?Son`21oh7oPOn1om7on`3hoo/0koom0>Son`3koo/0m?ok0?So
n`21oh7oPOn1om7on`3hoo/0koom0>Son`3koo/0m?ok0?Son`21ojWo06b1oh7o
Z?ok0?Won`3_ood0j?ol0?Woo03coo/0nOok087oPOn1oh7od?ok0?Won`3_ood0
j?ol0?Woo03coo/0nOok087oPOn1oh7od?ok0?Won`3_ood0j?ol0?Woo03coo/0
nOok087oZOl0K87oPOnWoo`0n_ok0>koo@3Xoo`0nOol0?;oo03joo/0POn1oh7o
POo>oo`0n_ok0>koo@3Xoo`0nOol0?;oo03joo/0POn1oh7oPOo>oo`0n_ok0>ko
o@3Xoo`0nOol0?;oo03joo/0POnXo`1/POn1ojOon`3loo/0kOom0>Won`3ioo/0
look0?con`21oh7oPOn1olgon`3loo/0kOom0>Won`3ioo/0look0?con`21oh7o
POn1olgon`3loo/0kOom0>Won`3ioo/0look0?con`21ojOo06b1oh7oY_ok0?go
o03/ood0jOol0?Ooo03boo/0oOol087oPOn1oh7obook0?goo03/ood0jOol0?Oo
o03boo/0oOol087oPOn1oh7obook0?goo03/ood0jOol0?Ooo03boo/0oOol087o
Y_l0K87oPOnUoo`0o_ok0>coo@3Yoo`0mool0?7oo03noo/0POn1oh7oPOo:oo`0
o_ok0>coo@3Yoo`0mool0?7oo03noo/0POn1oh7oPOo:oo`0o_ok0>coo@3Yoo`0
mool0?7oo03noo/0POnVo`1/POn1ojGon`00oo/0joom0>[on`3goo/0l_ok003o
n`21oh7oPOn1olWon`00oo/0joom0>[on`3goo/0l_ok003on`21oh7oPOn1olWo
n`00oo/0joom0>[on`3goo/0l_ok003on`21ojGo06b1oh7oY?ol003oo03Zood0
j_ol0?Goo03aoo`00?ol087oPOn1oh7oaool003oo03Zood0j_ol0?Goo03aoo`0
0?ol087oPOn1oh7oaool003oo03Zood0j_ol0?Goo03aoo`00?ol087oY?l0E87o
POnSooL0j_om0>[oo03eoo`0l?og087oPOn1oh7oa_og0>[oo@3Zoo`0mOol0?3o
m`21oh7oPOn1olKom`3Zood0j_ol0?Goo03`ooL0POnTo`1DPOn1oj?on03Yood0
jook0?Coo03aooP0POn1oh7oPOo5ooP0jOom0>_on`3doo`0lOoh087oPOn1oh7o
aOoh0>Woo@3[oo/0m?ol0?7on021oj?o05B1oh7oX_oj0>Soo@3[oo`0lool0?3o
nP21oh7oPOn1ol?onP3Xood0jool0??oo03`ooX0POn1oh7oPOo3ooX0j?om0>_o
o03coo`0l?oj087oX_l0E87oPOnRooX0m?oU0?Ooo03coo/0lOoj087oPOn1oh7o
`ooj0?Coi@3goo`0look0?7onP21oh7oPOn1ol?onP3donD0mool0??on`3aooX0
POnRo`1DPOn1oj?on03eonD0n?ol0?7oo03booP0POn1oh7oPOo5ooP0mOoU0?So
o03aoo`0l_oh087oPOn1oh7oaOoh0?Goi@3hoo`0lOol0?;on021oj?o05B1oh7o
Xooh0?Goi@3hoo`0lOol0?;on021oh7oPOn1olGon03eonD0n?ol0?7oo03booP0
POn1oh7oPOo5ooP0mOoU0?Soo03aoo`0l_oh087oXol0E87oPOnTooH0m_oU0?Wo
n`3aoo/0m?of087oPOn1oh7oaoof0?Koi@3ioo/0lOok0?ComP21oh7oPOn1olOo
mP3fonD0nOok0?7on`3dooH0POnTo`1/POn1ojGon`00oo/0joom0>goo03_oo`0
mOok003on`21oh7oPOn1olWon`00oo/0joom0>goo03_oo`0mOok003on`21oh7o
POn1olWon`00oo/0joom0>goo03_oo`0mOok003on`21ojGo06b1oh7oYOol0?ko
o03[ood0kOol0>ooo03eoo`0o_ol087oPOn1oh7obOol0?koo03[ood0kOol0>oo
o03eoo`0o_ol087oPOn1oh7obOol0?koo03[ood0kOol0>ooo03eoo`0o_ol087o
YOl0K87oPOnVoo`0oOok0>coo@3^oo/0kook0?Ooo03moo/0POn1oh7oPOo;oo`0
oOok0>coo@3^oo/0kook0?Ooo03moo/0POn1oh7oPOo;oo`0oOok0>coo@3^oo/0
kook0?Ooo03moo/0POnVo`1/POn1ojOon`3loo/0kOom0>koo03]oo`0n?ok0?co
n`21oh7oPOn1olgon`3loo/0kOom0>koo03]oo`0n?ok0?con`21oh7oPOn1olgo
n`3loo/0kOom0>koo03]oo`0n?ok0?con`21ojOo06b1oh7oYool0?[oo03]ood0
k_ol0>goo03hoo`0n_ol087oPOn1oh7ocOol0?[oo03]ood0k_ol0>goo03hoo`0
n_ol087oPOn1oh7ocOol0?[oo03]ood0k_ol0>goo03hoo`0n_ol087oYol0K87o
POnXoo/0n_ok0>koo@3_oo/0kOok0?[on`3joo/0POn1oh7oPOo?oo/0n_ok0>ko
o@3_oo/0kOok0?[on`3joo/0POn1oh7oPOo?oo/0n_ok0>koo@3_oo/0kOok0?[o
n`3joo/0POnXo`1/POn1ojWon`3hoo/0koom0>ooo03[oo`0nook0?Son`21oh7o
POn1om7on`3hoo/0koom0>ooo03[oo`0nook0?Son`21oh7oPOn1om7on`3hoo/0
koom0>ooo03[oo`0nook0?Son`21ojWo06b1oh7oZOol0?Koo03_ood0kool0>_o
o03koo`0m_ol087oPOn1oh7odOol0?Koo03_ood0kool0>_oo03koo`0m_ol087o
POn1oh7odOol0?Koo03_ood0kool0>_oo03koo`0m_ol087oZOl0H87oPOnZoo/0
m_ok0?3oo@3`oml0oOok0?Kon`21oh7oPOn1om?on`3foo/0l?om0?3og`3moo/0
m_ok087oPOn1oh7odook0?Kon`3`ood0l?oO0?gon`3foo/0POnZo`1PPOn1oj_o
n`3doo/0lOom0?3og`3noo/0m?ok087oPOn1oh7oeOok0?Con`3aood0l?oO0?ko
n`3doo/0POn1oh7oPOoEoo/0m?ok0?7oo@3`oml0o_ok0?Con`21oj_o0621oh7o
Zool0?;oo03aood0l?oO0?koo03boo`0POn1oh7oPOoEoo`0l_ol0?7oo@3`oml0
o_ol0?;oo021oh7oPOn1omGoo03boo`0lOom0?3og`3noo`0l_ol087oZol0H87o
POn/oo/0l_ok0?;oo@3aomd00?ok0?;on`21oh7oPOn1omOon`3boo/0l_om0?7o
g@00oo/0l_ok087oPOn1oh7oeook0?;on`3bood0lOoM003on`3boo/0POn/o`0P
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oROl0887o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
ROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn9o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oROl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohWo0221oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn9o`2P0;l0o`\>"], "NumberedFigure",
  ImageSize->{401, 266},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Figure 1. Two coupled pairs of conductors with parameters per unit \
length ('),  voltages and currents on a section of wires ranging from x to x+\
\[CapitalDelta]x\
\>", "Caption"],

Cell[TextData[{
  "The parameters R' (Resistance/m along the conductor), L' (Inductance/m of \
a circuit), C' (effective Capacity/m between two conductors) and G' \
(Conductivity/m from one conductor to the next) are normalized to the length \
of the wire and their index denotes the conductor they refer to. Their \
numerical values can be found by measurement or calculation (see below).\n\t\
At frequencies not too high the pulses are electromagnetic waves guided by \
the conductors. The state of the pulses may be calculated by numerically \
integrating their evolution in space and time from a given",
  StyleBox[" initial state",
    FontSlant->"Italic"],
  " of voltages and currents, subjected to the ",
  StyleBox["boundary conditions",
    FontSlant->"Italic"],
  " at either end of the conductor. The voltages ",
  Cell[BoxData[
      \(TraditionalForm\`u\_j\)]],
  " and currents ",
  Cell[BoxData[
      \(TraditionalForm\`i\_k\)]],
  " change according to the following set of one dimensional partial \
differential equations called ",
  StyleBox["telegraph equations",
    FontSlant->"Italic"],
  " that can be read off Fig. 1:"
}], "Text"],

Cell[BoxData[{
    \(\[PartialD]\_x\ u\_1 = \(-R\_1'\) i\_1 - L\_1' \[PartialD]\_t\ i\_1 - 
        L\_12' \[PartialD]\_t\ i\_2\), "\n", 
    \(\[PartialD]\_x\ u\_2 = \(-R\_2'\) i\_2 - L\_2' \[PartialD]\_t\ i\_2 - 
        L\_12' \[PartialD]\_t\ i\_1\), "\n", 
    \(\[PartialD]\_x\ i\_1 = \(-C\_1'\) \[PartialD]\_t\ u\_1 + 
        C\_12' \[PartialD]\_t\ u\_21 - G\_1' u\_1 + G\_12' u\_21\), "\n", 
    \(\[PartialD]\_x\ i\_2 = \(-C\_2'\) \[PartialD]\_t\ u\_2 - 
        C\_12' \[PartialD]\_t\ u\_21 - G\_2' u\_2 - 
        G\_12' u\_21\)}], "NumberedEquation"],

Cell[TextData[{
  "with ",
  Cell[BoxData[
      \(TraditionalForm\`u\_21\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`u\_2\)]],
  "- ",
  Cell[BoxData[
      \(TraditionalForm\`u\_1\)]],
  ". For numerical integration these equations and their boundary conditions \
will be cast into another form that allows the calculation of discrete \
increments in time (\[CapitalDelta]t) and space (\[CapitalDelta]x). \n\tThe \
end of the next section contains a flip page animation of a model pulse \
travelling back and forth including its behavior at the wire ends. In a \
second section a method is presented to calculate the capacities and \
inductances of a given set of linear conductors (including ground planes and \
dielectrics) by numerically solving the Laplace equation. Code is given that \
allows precision tests against known geometries. The last section shows then \
the application of all this to the \"pigtail\", a part of the ATLAS vertex \
detector for high energy particles being assembled at CERN. This is a \
connection made of microstrip lines on kapton foil carrying signals from the \
inner part to an optoconverter further outside.\n\tThis document is an \
interactive notebook that may be used to carry out the calculation or to view \
the animations on a computer. All programming is done in ",
  StyleBox["Mathematica",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox["(",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["Ref. 8",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[")",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["  ",
    FontSlant->"Italic"],
  "\[Dash]\[NonBreakingSpace]code is shown in grey boxes\[NonBreakingSpace]\
\[Dash], so the input may be easily adapted to get results on other \
geometries. "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Integration of the Telegraph Equations", "Section"],

Cell[CellGroupData[{

Cell["coupled Telegraph Equations", "Subsection"],

Cell[CellGroupData[{

Cell["Rearrangement of the Equations", "Subsubsection"],

Cell[TextData[{
  "\tThe scheme in Fig. 1 shows a generic situation of coupling, where \
everything is reduced to the essentials. It is represented by the set of \
equations (1). To describe any 'real' setup, it is best to leave Fig. 1 and \
equations (1) as they are and to project the properties of the situation at \
hand on to Fig. 1. \n\tLater on the coupling of two differential circuits \
will be considered, so all the capacitive coupling will have to be expressed \
through the capacity ",
  Cell[BoxData[
      \(TraditionalForm\`C\_12'\)]],
  "  (45) in Fig. 1. In addition, to simplify matters, we may, as the \
conductivity of capton is extremely low, put the G matrix safely to zero.\n\t \
To integrate the telegraph equations the set of equations (1) is rewritten \
with the time derivative term on the left hand side and currents, voltages \
and parameters are given in vector and matrix notation (",
  StyleBox["Ref\[NonBreakingSpace]2",
    FontWeight->"Bold"],
  ",\[NonBreakingSpace]p.182f):"
}], "Text"],

Cell[BoxData[{
    \(\[PartialD]\_t\ 
        u\&\[RightVector] = \(-\([C'\^\(-1\)]\)\) \[PartialD]\_x\ 
          i\&\[RightVector]\), "\[IndentingNewLine]", 
    \(\[PartialD]\_t\ 
        i\&\[RightVector] = \(-\([\(L'\^\(-1\)\) 
                R']\)\)\ i\&\[RightVector]\  - \ \([L'\^\(-1\)]\) \[PartialD]\
\_x\ u\&\[RightVector]\)}], "NumberedEquation"],

Cell["with  R', L', C'  as matrices [  ]: ", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\([R']\), "=", 
        RowBox[{"(", GridBox[{
              {\(R\_1\), "0"},
              {"0", \(R\_2\)}
              }], ")"}]}], ",", " ", 
      RowBox[{\([L']\), "=", 
        RowBox[{"(", GridBox[{
              {\(L\_1\), \(L\_\(1, 2\)\)},
              {\(L\_\(1, 2\)\), \(L\_2\)}
              }], ")"}]}], ",", "\[IndentingNewLine]", " ", 
      RowBox[{\([C']\), "=", 
        RowBox[{"(", GridBox[{
              {\(C\_1' + C\_\(1, 2\)'\), \(-\ C\_\(1, 2\)'\)},
              {\(-\ C\_\(1, 2\)'\), \(C\_2' + C\_\(1, 2\)'\)}
              }], ")"}]}], ",", "  "}]], "NumberedEquation"],

Cell[TextData[{
  "where the indices point to the pairs of conductors as is evident from Fig. \
1. For the following calculations it will be useful to collect ",
  Cell[BoxData[
      \(u\&\[RightVector]\)]],
  " and ",
  Cell[BoxData[
      \(i\&\[RightVector]\)]],
  " into another state vector ",
  Cell[BoxData[
      \(v\&\[RightVector]\)]],
  ". Both equations (2)  then form (4) a single equation containing the time \
derivative of ",
  Cell[BoxData[
      \(v\&\[RightVector]\)]],
  " on one side and the sum of two matrix operators ",
  Cell[BoxData[
      \(\[ScriptCapitalL]\_1\)]],
  " and ",
  Cell[BoxData[
      \(\[ScriptCapitalL]\_2\)]],
  " acting on ",
  Cell[BoxData[
      \(v\&\[RightVector]\)]],
  " at the other side :"
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(v\&\[RightVector]\), "=", 
        RowBox[{
          RowBox[{
            RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                  {\(\(\ \)\(u\&\[RightVector]\)\)},
                  {\(\(\ \)\(i\&\[RightVector]\)\)}
                  }], "\[NegativeThinSpace]", ")"}], "\[Rule]", 
            "\[IndentingNewLine]", \(\[PartialD]\_t\ v\&\[RightVector]\)}], 
          "=", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"(", GridBox[{
                      {"0", "0"},
                      {"0", \([\(L'\^\(-1\)\) R']\)}
                      }], ")"}]}], \(v\&\[RightVector]\)}], " ", "-", " ", 
            RowBox[{
              RowBox[{\(\[PartialD]\_x\), " ", 
                RowBox[{"(", GridBox[{
                      {"0", \([C'\^\(-1\)]\)},
                      {\([L'\^\(-1\)]\), "0"}
                      }], ")"}]}], \(v\&\[RightVector]\)}]}]}]}], " ", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      "\t\t", \(\(=\)\(\ \ \ \ \ \ \ \ \ \ \ \ \)\(\(\[ScriptCapitalL]\_1\) \
\((v\&\[RightVector])\)\ \ \ \ \ \ \ \ \ \  + \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \(\[ScriptCapitalL]\_2\) \((v\&\[RightVector])\)\)\)}]}], \
"NumberedEquation"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Code  (verify Manipulation of Equations)"
}], "Subsection",
  CellFrame->False,
  PageBreakAbove->True],

Cell[TextData[{
  "If you want to repeat or modify the calculations in the electronic version \
of this notebook:  ",
  StyleBox["\nselect the cell bracket enclosing all grey cells of the \
corresponding Mathematica Code section and press the ",
    FontSlant->"Italic"],
  StyleBox["evaluate",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" key",
    FontSlant->"Italic"],
  " \n\nThis cell solves the system of equations (1) for the terms containing \
the time derivatives:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(eq1 = r1i1 + l1\ \ di1t + l12\ \ di2t + du1x;\)\), "\n", 
    \(\(eq2 = r2i2 + l2\ di2t + l12\ di1t + du2x;\)\), "\n", 
    \(\(eq3 = c1\ \ du1t - c12\ \((du2t - du1t)\) + di1x;\)\), "\n", 
    \(\(eq4 = c2\ \ du2t + c12 \((du2t - du1t)\) + di2x;\)\), "\n", 
    \(Solve[{eq1 \[Equal] 0, eq2 \[Equal] 0, eq3 \[Equal] 0, 
          eq4 \[Equal] 0}, {du1t, du2t, di1t, di2t}] // Simplify\)}], "Input",\

  CellLabel->"In[1]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \({{di1t \[Rule] \(\(-du2x\)\ l12 + du1x\ l2 + l2\ r1i1 - l12\ \
r2i2\)\/\(l12\^2 - l1\ l2\), 
        di2t \[Rule] \(du2x\ l1 - du1x\ l12 - l12\ r1i1 + l1\ \
r2i2\)\/\(l12\^2 - l1\ l2\), 
        du1t \[Rule] \(-\(\(c2\ di1x + c12\ \((di1x + di2x)\)\)\/\(c12\ c2 + 
                  c1\ \((c12 + c2)\)\)\)\), 
        du2t \[Rule] \(-\(\(c1\ di2x + c12\ \((di1x + di2x)\)\)\/\(c12\ c2 + 
                  c1\ \((c12 + c2)\)\)\)\)}}\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell["\<\
The next code example verifies the equality of the first equation \
of (2) with equations (1):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"-", 
        RowBox[{
          RowBox[{"Inverse", "[", 
            RowBox[{"(", GridBox[{
                  {\(c1 + c12\), \(-c12\)},
                  {\(-c12\), \(c2 + c12\)}
                  }], ")"}], "]"}], ".", \({di1x, di2x}\)}]}], "//", 
      "Simplify"}]], "Input",
  CellLabel->"In[6]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \({\(-\(\(c2\ di1x + c12\ \((di1x + di2x)\)\)\/\(c12\ c2 + 
              c1\ \((c12 + c2)\)\)\)\), \(-\(\(c1\ di2x + 
              c12\ \((di1x + di2x)\)\)\/\(c12\ c2 + 
              c1\ \((c12 + c2)\)\)\)\)}\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell["\<\
It is an easy exercise to check the second equation of (2) in the \
same way.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Discretization of the Telegraph Equations", "Subsection",
  PageBreakAbove->True],

Cell[TextData[{
  "The state vector ",
  Cell[BoxData[
      \(v\&\[RightVector]\)]],
  "(x,t) is represented on a discrete time and space grid as "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(v\&\[RightVector]\)]],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`t\_n\)]],
  ") = ",
  Cell[BoxData[
      \(v\&\[RightVector]\)]],
  "( j\[CapitalDelta]x, n\[CapitalDelta]t ) = ",
  Cell[BoxData[
      \(TraditionalForm\`v\&\[RightVector]\_j\%n\)]],
  ",             j = 0,..., M,    n = 0,..., N,"
}], "NumberedEquation"],

Cell[TextData[{
  "where  n (time) and j (space) label the coordinates of the grid and \
\[CapitalDelta]x, \[CapitalDelta]t  stand for the grid spacing. The \
differential operators will be replaced by finite differences, then the state \
at the time n+1 and at the place j may be expressed by a linear combination \
of some points at the previous time n. In this way the calculation proceeds \
in time one \[CapitalDelta]t after the other. For stability \[CapitalDelta]t \
has to be \[LessEqual] \[CapitalDelta]x/(speed of light). \n\tIn case the \
differencing scheme valid for each ",
  Cell[BoxData[
      \(\[ScriptCapitalL]\_i\)]],
  " ",
  StyleBox["alone",
    FontSlant->"Italic"],
  " in (4) is known and results in a prescription ",
  Cell[BoxData[
      \(\[Upsilon]\_i\)]],
  " to update ",
  Cell[BoxData[
      \(v\&\[RightVector]\_j\%n\)]],
  " (in the next two subsections this condition is shown to be fulfilled) :"
}], "Text"],

Cell[BoxData[{
    \(\(\[ScriptCapitalL]\_1\) : 
        v\&\[RightVector]\_j\%\(n + 1\) = \(\[Upsilon]\_1\) \((v\&\
\[RightVector]\_k\%n, \[CapitalDelta]t)\)\ \ \ \ \ \ \((Damping\ Term)\)\), "\
\[IndentingNewLine]", 
    \(\(\(\(\[ScriptCapitalL]\_2\) : 
        v\&\[RightVector]\_j\%\(n + 1\) = \(\[Upsilon]\_2\) \((v\&\
\[RightVector]\_k\%n, \[CapitalDelta]t)\)\ \ \ \ \ \ \((Wave\ \
Equation)\)\)\(,\)\)\)}], "NumberedEquation"],

Cell[TextData[{
  "then the discrete telegraph equations follow with the method of operator \
splitting (",
  StyleBox["Ref. 3",
    FontWeight->"Bold"],
  ", p.847",
  ") from (6) by applying the updates one after the other:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(v\&\[RightVector]\_j\%\(n + 1\)\)]],
  "=",
  Cell[BoxData[
      \(\(\(\ \)\(\[Upsilon]\_1\)\)\)]],
  Cell[BoxData[
      \(\((\(\[Upsilon]\_2\) \((v\&\[RightVector]\_k\%n, \[CapitalDelta]t)\), \
\[CapitalDelta]t)\)\)]]
}], "NumberedEquation"],

Cell[CellGroupData[{

Cell[TextData[{
  "differencing ",
  Cell[BoxData[
      \(\[ScriptCapitalL]\_2\)]]
}], "Subsubsection"],

Cell[TextData[{
  "The differencing scheme of ",
  Cell[BoxData[
      \(\[ScriptCapitalL]\_2\)]],
  " is presented in some detail. The time derivative is written as "
}], "Text"],

Cell[BoxData[
    \(\(\(\[PartialD]\_t\ 
        v\&\[RightVector] = \((v\&\[RightVector]\_j\%\(n + 1\) - v\&\
\[RightVector]\_j\%n)\)\/\[CapitalDelta]t\)\(,\)\)\)], "NumberedEquation"],

Cell["so that with (4)", "Text"],

Cell[BoxData[
    RowBox[{"  ", 
      RowBox[{
        RowBox[{\(v\&\[RightVector]\_j\%\(n + 1\)\), "=", 
          RowBox[{
            RowBox[{
              RowBox[{"[", 
                RowBox[{"\[DoubleStruckL]", "-", 
                  RowBox[{"\[CapitalDelta]t", " ", 
                    RowBox[{\(\[PartialD]\_x\), " ", 
                      RowBox[{"(", GridBox[{
                            {"0", \([C'\^\(-1\)]\)},
                            {\([L'\^\(-1\)]\), "0"}
                            }], ")"}]}]}]}], 
                "]"}], \(v\&\[RightVector]\_j\%n\)}], 
            "=", \(\([\[DoubleStruckL] - \[CapitalDelta]t\ \[PartialD]\_x\ \
\([B]\)]\) v\&\[RightVector]\_j\%n\)}]}], "  ", ","}]}]], "NumberedEquation"],

Cell["\<\
where \[DoubleStruckL] denotes the identity matrix and [B] is a \
shorthand for the LC matrix. Next the Lax-Wendroff two-step scheme, which is \
second order in time, quite accurate and has little distortion if the step \
size chosen is small enough,  will be applied. First the space derivative is \
written as\
\>", "Text"],

Cell[BoxData[
    \(\(\(\[PartialD]\_x\ 
        v\&\[RightVector] = \((v\&\[RightVector]\_\(j + 1\)\%n - v\&\
\[RightVector]\_j\%n)\)\/\[CapitalDelta]x\)\(,\)\)\)], "NumberedEquation"],

Cell["\<\
where [B] is considered independent of x, and temporary \"half step \
grid points\" are constructed, which  (Fig.\[NonBreakingSpace]2) we put into \
(9)\
\>", "Text"],

Cell[BoxData[{
    \(\(v\&\[RightVector]\_\(j + 1\/2\)\%\(n + 1\/2\) - \
v\&\[RightVector]\_\(j + 1\/2\)\%n\)\/\(\[CapitalDelta]t\/2\) = \(-\([B]\)\) \
\((v\&\[RightVector]\_\(j + 1\)\%n - v\&\[RightVector]\_j\%n)\)\/\
\[CapitalDelta]x\ \), "\[IndentingNewLine]", 
    \(\(\(\[Rule]\)\(\ \)\(v\&\[RightVector]\_\(j + 1\/2\)\%\(n + 
              1\/2\)\)\) = 
      v\&\[RightVector]\_\(j + 1\/2\)\%n - \(\[CapitalDelta]t\/\(2  \
\[CapitalDelta]x\)\)[
            B] \((v\&\[RightVector]\_\(j + 1\)\%n - 
              v\&\[RightVector]\_j\%n)\)\)}], "NumberedEquation"],

Cell["and in the same way ", "Text"],

Cell[BoxData[
    \(\(\(\ \)\(v\&\[RightVector]\_\(j - 1\/2\)\%\(n + 1\/2\) = 
      v\&\[RightVector]\_\(j - 1\/2\)\%n - \(\[CapitalDelta]t\/\(2  \
\[CapitalDelta]x\)\)[
            B] \(\((v\&\[RightVector]\_j\%n - 
                v\&\[RightVector]\_\(j - 1\)\%n)\)\(.\)\)\)\)\)], \
"NumberedEquation"],

Cell[GraphicsData["PICT", "\<\
];8000000<T1BP0A0_l<0?on0001;0000B`000000003A`ER0000002Q09H02P40
000000000000X02H0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G
0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40000000000000X02H
0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G0:40UP0:0@000000
0000002P09P0X02I0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F
00X10000000000000:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I
0:00U`2Q09H02P40000000000000X02H0:00V@2P09L07P0100X000000dL5HP0/
00T00`I7IFiUMV4000<00`0=00`0;P04003o000[0@41800Y004P00070000000S
0000X02n0:40`00=HgEbLVE^M71_JFid3@00X02o0280b@590000X02n0:40`03=
HgEbLVE^M71_JFid838PJFiTIGPPLgER86EhHfPP<b1YKVAUN21cMF8=83<b>B0P
I6Uf86EhHfPP3B0b<34P86AYMR0c86U^I6Eh80dP<20PLgER83<PJFiTIGPP3B0`
821cMF8P=20b879_K6`P=B1YKVAUN20e86U^I6Eh87AbHFicK65dI@e^IFLPLf=Q
K6D==20b879_K6`PKVEW86EhHfPPKVEW86EhHfPPM79QKW=/HGAU80dP<S0a821c
MF8PM79QKW=/HGAU3@00X@300DDU8E1C;D5TKf9U;C<^<215D5=6;C<^<0dU9D9_
MFiTJFiW@Vmh>R0P<20`83<b>B0b<34P3BDUE6UdK6Dj82Q<HGP^@diF:B0=9BE3
LVEQM6mb>R13HFifHG<P:3L^<2hb:B0=9BE3LVEQM6U_KTAQM6Dj82P`<Rlb=2l`
<B10834a>S@a851=:B0=9BE4Kf=eKFE^M51bKf=CIGAc>R14IFiUHV5O@f5^MV5c
@gEcM6m]@fm/Kg9c3BDU:b13ETAYHg@=9BE4Kf=eKFE^M4I_KWAc>R0=9BE4Kf=e
KFE^M4iUIFAUI4I_KWAc>R17IFiUMV4=3BDUA6mSMFeUKWA@LVmSIG=c@fm/Kg9c
>R13NF5^84eQIfE^M64PFFE/K6mg849/HF=[3BDUAFiT@fm]KFE^M7<=9BE2IFMY
KU1bKfa_Ib0=002Q0<1002DU@VEWJFiBIG=_MG9SICXPL79_Hg=UM213ETAYHg@=
9BEDJGA/ICXPA6E^IF9Q87=dHFiTHG9T86MbHG1XJF=c3BDUEVEbLfU_KSXP<Bh`
<PdU9D=bIF5dJFm^A65dICXP<C0_<C@_>CT=9BE3Kg1iLVUWJ7@j82Q3:B0a>CTd
;20a>CTi84AUKVERHB1CNG=dIFec;R11K6`PDVUWJ7Ac859ULfEbMVET3GEcIG9T
JF=d82m3ETAYHg@P<S0`86AYHg@PL7Ed3D=FA6USM21RIFMYKPd_JFifHFaYI6=_
K6mbM65RK6Do87AbMFDPI6EV820P3Bm/IGIUK38P;faQKVMeHFMUK6EfIF`PMfQU
LVDPNg1_L21/HFiWMF5WIFaUMVE/838PIfEmNfIQK7=UOB1YIVE/LfDPI6EV3FaU
MVE/<R1^Kg@PNb0_N7=XKgLPN`d`86=eLW9UKWA`KfU^M20e82da879_K6`PNg1_
L21`Kg0PKFmfIGA_86AeL20a865TI20c834PLVm/K21UN6=X86AeL20d834PLVm/
K21UN6=X86MUM20`879]KgIUM6lPHgEbLVE^M71_JFidOB1UN6=X86]cJ6mg3G1_
L21`Kg0PL6m`871_L7dPI6EV87dPJFH=;fU^JGAYHFaYNVD=Nd=FA6USM0ekI7E`
87QSJ6ESJg]RJFiTOFUV871_L21`Kg1mIVmbHFa/3F=eLW9UKWAcHg9UIFhP;emc
L21UN6=X86AUIR0_Gg=Q86EhHfPPI6EV82mOLfHPIGQSJ21TIFH=;dAUIV5eK7AC
Hg9UIFikGg=V85mcHB0_Gg=`86a_HFAmI6EV3Bm4IFIQMFadDf=bIFE^D79_Hg/P
;emcL21/Kf5TOFAUIPd_LfEdLgAbKf]UHFAZMG=d87MXIG9UNg1_L21dLWEUOG]V
HFacIGeYIVE/LfD=NbmcHB0_LfEdLgAbKf]UHFAZMG=d86a_HF@PI6EV3Bm/JB0_
K6U^IGA_86a_HF@PI6EV3Bm]M20_KFmfIGA_86a_HF@PI6EV3BmSM20_HgEbMVEd
Kb1/Kf5T86AUIPd_K6PPNb1SMG9bIFidL6mYKW@PIGQSJ21`Kg0PK6U^IGA_OF9Y
KV@PI6EV3Bm/MR1k86=eLW9UKWA`KfU^M21`Kg0PIGQSJ21/JFiUM6mmHVU^I21T
IFIm3G/_Lf5kNf=eLW9UKWATJF=d85=dLVm[ID5TJWEcM4AYHg@PKVEkDgAbKf]U
@FAZMG=dA6USM21RIFMYKWeYIWek86=eLW9UKWATJF=d85=dLVm[ID5TJWEcM4AY
Hg@PIG5kIFiTOFUVOFUVIFacIGdPHVU^I21TIFH=MG=ULVAYHg@P;e=dLVm[ID5T
JWEcM4AYHg@P<C0`86AYHg@PL7Ed3E=dLVm[ID5TJWEcM4AYHg@PHVEWJFh=;emh
K0ekM79QKW=VKg9]3Bhb=B1cMF8PLVmeKV@P;S8e865TI21UN6=X3Bhb=B1cMF8P
LVmeKV@P;S8e865TI21UN6=X3FUdLV5^LfI_LVd=OF9YKV@PI6EV3Bm/JG/PGgQ/
86aYKVEdKgeRJFiT86AUIPd_KGAk85mhK21]KgIUM6mmHVU^I21TIFH=;f=dNb1O
N6`PHgEbMVEdKgeRJFiT86AUIPd_K6PPNb1TMG0PGgQ/871_L21SMG9bIFidL6mY
KW@PIGQSJ21`Kg0PK6U^IGA_OF9YKV@PI6EV3Bm/MR1k86AeL21ON6`PL6m`86=e
LW9UKWA`KfU^M21`Kg0PIGQSJ21/JFiUM6mmHVU^I21TIFH=;g9`NemhK2mSMUmR
87QTIRmSMUmb87QTIPeON6`_HgIOM21hI6H_HgIOK21hI6H=HgIOK21SMUmd86e_
MVEdK`eSMUmb86=fGg@PK6U^IGA_3F=fGg8PHgIOHR1/JFiUM6l=HgIOK21SMUmR
86aYKVEdK`eSK6mcIG1QM6P=OF9YKV@PI6EV3FE^I7eYIVE/LfEmI6EV3BmdIG9]
JFiQM6D=NgEcIG9TJF=d82mCM79_JfE1I6YeLgA4JF=d86]^KgM^87]SMG9bIFid
I6USM21CM79_JfE1I6YeLgA4JF=d86EaNfE^I7eYIWeYIPeSMG9bIFidI6USM213
ETAYHg@PIG5kIFiTOFUVOFAUIPd_KGQ=HGPP=S@PI6EV3Bm]N5=dJb1KKGQ=HGPP
NfeQM79YN7dPLVE`IF5dGFAUIPd_KGQ9I7PP<21TIFH=;g=dKG]]N5=dJb1]N4UT
N20`86ad87/_KGQ9I7PP<21cM6mbIGeYIR1]N4UTN21WIG@PHgEbLVE^M6eQM79Y
N21`Kg0P;fehBFAh86ehBFAh834PHFAT87=dKg9UOFAUIPd_LWA]NfehBFAh834P
IfDPNbm]N4UTN21]N4UTN20a87=eHR1cM6mbIB1]N5=dJb1]N4UTN21WIG@PLfEd
KF5dLVUhOFUV87eTIFH=;g=SK21k83Lb86AYMR1UN6=X83Lb86AYMR1UN6=X87=S
HFaU87dPI6EV3BmcHfaY87/P=c8PIGQSJ21TJGHPIGQSJ20g<R1UN6=X86AYMR1U
N6=X87=SHFaU87dPI6EV3BmOHgI]M7PPKF5dLVUh86AUIPd_GgAhM6edN21]HGAb
JGPPI6EV3BmOJFiYM6edN21]HGAbJGPPI6EV3BmhI6IkIGQSJ21TIFImI6EV3Bm]
JFik<R1SKg1i86MdNfEhHfQmJFHPL6m`OFAUIPd_KF5hNc8PHfm`NB1/M7]UN6=X
OFUV871_L7eTIFH=;d=FMVES838e=R1QLW9QNB1TIFH=;e@PM79eIB1TIFH=;dHP
IV5/LfDPI6EV3BmOJF@P<21TIFH=;emUKV=_I6U^I6Eh830PI6EV3BmOIFiSKfA1
LW8P<b1QLW9QNB1TIFH=;emVI20`86AUIPd_GgAUN7ACHGIU86ieK6`PI6EV3BmO
K6EdM6EbDg1QHfDP<21TIFH=;emcL65SIEQdLV4P<21TIFH=;em@HFMUDf5fIB1^
MFa/86AUIPd_Gg1UKVPP<Bh`86AUIPd_Gg1UKWHP<Bh`86AUIPd_Lf5fIC0PKWE/
K21TIFH=;emg830PI6EV3BmOJ20`86AUIPd_GfAc830PI6EV3BmXHg@PIV5/LfDP
I6EV3Bm`Mb0`86AUIPd_MfAYIR0`86AUIPd_M6E]L20`86AUIPd_HgEbLVmd830P
I6EV3BmcHGIUJ65^I6aULR1^MFa/86AUIPd_JF4P<21TIFH=;fUh830PI6EV3BmY
N6hP<B1TIFH=;deeK7AYL6aUA65dHE=_MG9SIG<PIV5/LfDPI6EV80d_I6ERMFL=
NfAeL20_96E`Lb1UN6=X86i_M21TIFIk;g=QMVEXHFiTK6Eb86EbLVmbI6USM20_
J65^I6aUIG9bKg8PIfEd86AUIPeULW9_LVAYHg@=;fQQKVA/IFEbLVmbNbAULW9_
LR1RIFMYKPe^IGMULW9_LW/_KVEgIG9bKg8PIV5/LfDPI6EV3G=XKgM`HFMU3CLb
83Lb87=SHFaU3Bm8IFafIGAYHf4PIVU^I6I_KW@P;S8PLf=QK6EVKfid87=UM6I_
KW@=;S8e83T^=R1]KgIUM6l=:4EbLVmb>R0YLfQ_M`eULW9_LViQKFD=NfAeL21d
NG1U;g=dLVU^IgAiL6DPKVD=NbQSKfifIG9dIF@PIG9bKg8PKV5]IB1gJFa/86E^
I21eL21YKR1dJ6Uc87=dLVU^IbUSMW=mJFH=LfQ_MgeUN6ES3Bhb=B0i;S@PKFmf
IGA_3BQ?IVIUKVAYKVLP@fm]KF5^I3XP:G=XKgL=;f=_KFeQKV@PK6mQI0ekI7E`
87AiL6D_LgAbJFiWM7U`IB1^I@ek:6=_KWIULWAUI21SKfe]HFiT86iQKFDPMfU/
K21UKV@PMG0PJFhPM6QYLb1cM79YKVLYHgIcOFUV3G=XKgMmIGQUH`d^<SDP>Bhb
86e_MVEdK`dXDgAQHf/j82UcJ6mg3FmcM65SJ`ek;S8e86=eLW9UKWA`KfU^M20^
<R1cMF8PIGQSJ21`Kg0PKFmfIGA_3FAeL21dNG1U;g=dLVU^IgAiL6DPKVEkI7E`
87AiL6D_JFidIFMULWAiL6DPIG4=<B1YKVAUN21dNG1U;g9UHFadNG1U86Ea86mb
3C4PJFiTIGPPM7U`IBm^HFeUM7U`IB1ULB1_LPe^Kg@PNgAiL6EmJFH=:6=_KWIU
LWAUI21cM65SJb1gJFa/86E^I21eL21YKR1dJ6Uc87=dLVU^IbUSMW=mJFH=LfQ_
MgeVKg9QK6`=LfQ_Mg1QIfD=@eI4JF=d82mcHGIUJ65^I6aULR1WIG@PIGQUHgeY
IPeUKVAmL7EdOFUVOFAUIPd_K6=kLfEdK6U^IF=QL7eTIFH=;faZNg=UM6aYKVEZ
KfU^OFAUIPd_K6ekLfEdKFUdIG9/JFeYM7eTIFH=;faVNg=UM6I/HGAmI6EV3BmS
L7]SK6mcIG1QM6QmI6EV3Bm^L7]^IGM`HGAXOFAUIPd_971cNR0c<21QLW9QNB1T
IFH=;bA`JGPP<21TIFH=;fMcNfMcHGIU82A`LgXPI7E`82A`JGPPGg1UKVPPL7Ed
82A`JGPP<B1QI6@PGg1UKWHPL7Ed82lTL6Uh82A`JGPP<R1QI6@PI6EVOFAUIPd_
Ig9kIg9ULgA_LVD_971YN20TL6Uh838PLgER86AUIR0TL7=j86AeL20TL6Uh86MU
M20_Gg1UKVPPIGQSJ21TIFHP971YN20a865TI21WIG@P;em`IFif86EhHfPPI6EV
OFAUIPd_K6UkK6U^IGA_OB1TIFH=;faXNf=eLW9UKWA`KfU^M21UN6=X871_L21/
JFiUM6mmI6EV3Bm/MW]SMG9bIFidL6mYKW@PL6m`86EhHfPPK6U^IGA_OFAUIPd_
KGAkKFmfIGA_OB1TIFH=;emSMUm]J7]SMG9bIFidL6mYKW@PIGQSJ21`Kg0PKFmf
IGA_OFAUIPd_Gf=fGfefNf=eLW9UKWA`KfU^M21`Kg0PIGQSJ21]KgIUM6mmI6EV
3BmSM7]SMG9fIGA_OB1TIFH=;g9dNc@P;C8PLVm/K21]KgIUM6l=I7E`830PIGQS
J21bK6U^IGA_3FEhHfPP<21bK6U^IGA_3FiUIb0`86EhHfPPLVaYKVEdK`eSK6mc
IG1QM6QmI6EV3BmOJ78=N`ek;d1ULW8PIV5/LfDPI6EV86=eLW9UKWAVK65d86Ae
L7]WLf5fIG]UKf=/JG1mLgA_L71UI7]WLVEcM6mbIB0b86eeK21TMG0PLfEdIVaQ
M21TMG0P<S0`86MUNbPU9B13HFifHG<j@faYL21VHFU/IFALLRU`LVU^M20_@6Eb
LR1dLWEU86AUIR1`Kg0PIGQYM7eYIWekIg9ULgA_LVDPLfEdIVaQM21UN6UdOFUV
IFacIGe/Kfm`841ULW8PKVmd87]UKf=/JG1mJFHPLfEdIVaQM7d=Nbm0IG9b86IQ
K7=U86AUIR1SMG9bIFidIVaQM21TMG1kIg=QMVEkHfaYL7ecM6m`L6ETNfMbIG=d
Kg9U838PKGE/86AeL21cIGAVK65d86AeL20b<30PIfEk:2DU84=QKWIQLcY3K6U`
86IQJFaUI5ab:G1bJFid82m0IG9b87AbMFDPI6EV871_L21UN6UdOFUVOG]WLVEc
M6mbIB1cIGAVK65d86EhJGAmJFIUK7=UOFa_Kg0P@6EbLR1^Kg@PNf=/JG1mJFHP
LfEdIVaQM7d=OFAUIPd_Gf=c86ieK6`PI6EV3BmVIg]cIGAWLV5iOFAUIPd_LfEd
HfeiJf=_K6mb87MXIG9U87]`Kg0PM79eIGekIV5/LfEmJFIUK7=U3G/_ISAk87=U
M6=]NF]SKfa_LWeTIFImNbmV=7/a87=eHR0d834PLVm/K20cNc<PJFiTIGPPHFAT
86iUIb1TMG0P<21/M7]`Kg0P<7eYIR0c834PLVm/K7ebIG1UHG@PLfEdLVMRHfm/
Kg8PL6m`OFAUIWeYIVE/LfD=;g=UM6=_K6mbLg1QHfDPMfQULVDPNg1_L21dLWEU
OG]VHFacIGeYIVE/LfD=NbmcHg=k86AeL21cIGASKfa_LW=`HF=U82mOHg<PIGQS
J21TIFImI6EV;fHcNb1OHg<PLfEdHfm/Kg9cL65SIB1cIGASKfa_LWeTIFH=OG/_
IS=k87=UM79WHV=_K6mbOFAUIRmcHg=k871_L7eTIFImJFIUK7=U3BlTHf<P=B1Q
LW9QNB1TIFH=;fIYKVASKGU[HgEcM6m]Hfm/Kg8PMfQULVDPNg1_L21dLWEUOG]V
HFacIGeYIVE/LfD=KVmd87/_IVU^I6=]NF]SMG=dKfeSKfa_LW/THf<PHG=dKg9U
OFAUIWeYIPd_LfEdHgEcM6m]Hfm/Kg8PMfQULVDPNg1_L21dLWEUOG]VHFacIGeY
IVE/LfD=KVmdNbmcIGASMG=dKfeSKfa_LW]UN6=X865/Kf5T871_L21`Kg0P=7/d
86U^I6Eh86eeK20d834PLVm/K7ebIG1UHG@PLfEdHfeiJf=_K6mb871_L7eTIFIm
JFH=;fISNcHP<B1bKfa/86IYKVASKGU[HgEcM6m]Hfm/Kg8PIGQSJ21cIGASMG=d
KfeSKfa_LWeTIFH=;g=UM7=UL65bHGAYKfiWLV5i87MXIG9U87]`Kg0PM79eIGek
IV5/LfEmJFIUK7=U3Fi_M7/_LfEdLfE`HG9QM6U_KVMbHGTPNg=iLgAUKFAYHg@P
;g=UM6MbHGTPIfEd86EhIF=m86AUIWeYIPd_LfMk87=UM7=UL65bHGAYKfiWLV5i
OFAUIPd_Lg1k;em`IFif87QTIRmOL6E^J21hI6ImI6EV3BmbL0ek;f=fGf8PN6AV
;f=fGg8PN6AV3BmSMUmd87QTIRmSMUm/87QTIPeSMUm/86=fGg@PKFmfIGA_3F=f
Gg8PHgIOM21/JFiUM6l=HgIOLR1SMUmR86aYKVEdK`eSMUm/86=fGf8PK6U^IGA_
3F=/Kg=UL65dJ7eTIFH=;g9bNbmiLV5TJGEc87QTIPd_N79QI6UeLb1hI6H=;f=f
Gf8PN6AV3BmSMUmb87QTIPd_HgIOM21hI6H=;f=fGf`PN6AV3F=fGf`PN79QI6Ue
Lb1QI6@PHgIOM21]KgIUM6l=HgIOLR1hLV5TJGEc87=eHR1SMUmd86aYKVEdK`eO
HgI]M7PPHgEbLVE^M6eQM79YN21`Kg0=HgEbLVE^M71_JFid87AbHFicK65dI@eh
LV5TJGEc87UbHFAYMG<PLf=QK6D=<B0`834P<B0a865bHgA_83AkL6m`OG9UL6EQ
M0eOHgI]M7PPLfEdKF5dLVUh3F=fGg8PHgIOHR1iLV5TJGEc87=eHR1/JFiUM6l=
Gf=fKGAh86=eLW9UKWA]HGAbJGPPL6m`3F=eLW9UKWA`KfU^M21dLV5^LfaQM6D=
N79QI6UeLb1iLV5TJGEc87=SHFaU3C0P<B0]<B0a834PHG9SM6lP=7]`Kg1mLVE`
IF5d3EmSMVedN21cIGA]HGAbJGP=HgIOK21hLV5TJGEc865TI21SMUmR86aYKVEd
K`eOHgI]M7PPHgEbLVE^M6eQM79YN21`Kg0=HgEbLVE^M71_JFid87AbHFicK65d
I@ehLV5TJGEc87UbHFAYMG<PLf=QK6D=;C4P<20]<B0]<B0a865bHgA_83AkL6m`
OG9UL6EQM0eOHgI]M7PPLfEdKF5dLVUh3F=fGf`PHgIOM21iLV5TJGEc865TI21/
JFiUM6l=Gf=fKGAh86=eLW9UKWA]HGAbJGPPL6m`3F=eLW9UKWA`KfU^M21dLV5^
LfaQM6D=N79QI6UeLb1iLV5TJGEc87=SHFaU3C0P;C4P<B0]<B0a865bHgA_83Ak
L6m`OG9UL6EQM0eOHgI]M7PPLfEdKF5dLVUh3F=/Kg=UL65dJ7eTIFH=;fE`NemS
MVedN21SMG9bIFidKF5dLVUh871_L0edLV5^LfaQM6D=Lf=QK6D=<B0`86e_MVEd
K`d`830P<B0`83<f<21QLV<=Hfa_LfE`HGAX3EmSMVedN21cIGA]HGAbJGQmI6EV
3BmgI7]OHgI]M7PPHgEbLVE^M6eQM79YN21`Kg0=M79QKW=/HGAU3G=SHFaU3C0P
<21]KgIUM6l=<20`834P=B0]<R1bKfa/865bHfh=Hfa_LfE`HGAX3EmSMVedN21c
IGA]HGAbJGQmI6EV3BmQLg]OHgI]M7PPHgEbLVE^M6eQM79YN21`Kg0=M79QKW=/
HGAU3G=SHFaU3C0P<20a83DP;C8PLVm/K21QLV=^3EmSMVedN21cIGA]HGAbJGQm
I6EV3BmTL`ekGg1UKWHPGg1UKVPPKVDPI7E`Ng=dKB1OL6E^J21TMG0P<21/IG]`
Kg0P<GeYIR1OL6E^MR1TMG0P<21/IG]`Kg0P<GeYIR1cHf5/IGekGg1UKVPPLfEd
K6U^IGMYI7AXOFUVIFacIB1cM79_JfDPNg9dKGeYIWeTIFH=;fAVNfIYK6amI6EV
3BmTIG]UKfIYK6amI6EV3BmOIg=dJb0e865bLV5i86AUIPd_GfMcM6]S830PI6EV
3BmOIg=dNb0i86AYHg@PHVEWJFhPK6EfIF`bNbmOHf=c86=eLW9UKWASKfa_LW=`
HF=U86AUIR0_Gf=S85]SMG9bIFidHfm/Kg9M86AUIWek;emSHb1KHgEbLVE^M79W
HV=_K6mbGFAUIWeYIVE/LfDPNf=eLW9UKWA`KfU^M7ecM6m`L6ET87/_Gf=`86ie
K6`PI6EVOG/P<R1QLW9QNB1QLgA_LVDP;emSL21UN6=X86AUIWeYIVE/LfDP;emS
IR1SMG9bIFidIVm^M21TIFH=;emSK7LPHgEbLVE^M6aYKVEgJFAdJ21TIFHP;emS
K6<PHgEbLVE^M6aYKVESHG0PI6EV82mOHfaZ86=eLW9UKWA/JFiUJVmYKR1TIFHP
;emSKF`PHgEbLVE^M6eYM6EbK6U]JG@PI6EV86=eLW9UKWATJF=d86E^I7eTIFH=
;fQcNfiUMg1QM6PPIg=QMVDPLgA]OFAUIPd_J6=k;emXLR1/Kf5T86EhHfPPIfEd
86EhIF<PKVEgL65dJ7eTIFH=;fQUNemWLgA[85mWLgA[Hb1OIg=d871eM20_GfMc
M6]S85mWLgA[Hb0a865TI21cM6mbIB0=Ig9ULgA_LVDPLWA]82mOIg=dJf<PGfMc
M6]S834PLgER87=dKg9U85mWLgA[85mWLgA[Hb1WIG@PK6EfIF`bNfAeL20_Gf=S
Lb1WIG@PLfEdHfm/Kg9cL65SIB1TMG0P;emSHb1WIG@PHFa_HF@PL6m`87=UM6=_
K6mbOG]TMG0P;emSHb1WIG@PHFa_HF@PL6m`87=UM79WHV=_K6mbOFUVIFacIB1T
MG0P;emSL21WIG@PI7E`86ieK6`PIG4P3Fi_M7]QK6mQI21`Kg0PKFmfIGA_OG]`
Kg1mJFIUK7=U86AeL20_Gf=V86MUM21cIGAVKfid3FAeL2mOHfag86MUM21cIGA/
JFiUMfUTM6PPI7E`;emSK6<PIfEd87=UM6aYKVESHG0PI7E`;emSK6XPIfEd87=U
M6aYKVEZKfU^86AeL2mOHfe/86MUM21cIGA]JGAULVaYKFUd871_L7eTIFH=;fUT
Nb0_GfUT87QTIWeTIFH=;emYKF5dLVUhNemg830P<21OJ21OJF@P<21^IG]^IFLP
<21OJ7ek<20`OFUVIFacIB1OHgI]M7PPHG=dKg9UOFAUIPdU84=_L7UbJFMXM20X
@bTP<CTi<2`P<CTi<B1RNB11I6mRIB1CNG=dIFec84U^HfmbL6mbHGAUI2h=9B11
K6`PLVUWJ7Ac879ULfEbMVET;Pe/IGIUK38PNb1cHGIU82mTKfidK6mQI6aUMVE/
<B1hI6HPOFUV3BmcM65bM6i_K6mQI7]k;fi_K6mQI21cHGIU86AUIWdPJFImI6EV
3BmUKVA^Kfa_HFAkNfi_K6mQI21bIG=dKg9UOFUV87eTIFH=;gAULgAcNG=dIFeT
JF=dNgMXIG9UNg=iLgAUKFAYHg@PIG5kM79eIGekIV5/LfEmJFIUK7=UOG]VHFac
IGeYIVE/LfEmI6EV3Bm^Hfm/Kg9c834PI6EV3BmSKfa_LVU]HFMU87MXIG9UNg1_
L21dLWEUOG]VHFacIGeYIVE/LfEk;fiSKfa_LW<P<0ecM65dMG=TJF=d869UIfU^
80d_L79_HfEcLf=_K6mbLb1gJ6EbIG]`Kg0PL6m`871bKf=ULg=SKfa_LW=mNbmT
IGIYHfEYKVI_87MXIG9UNg1_L21TIGIYHfEYKVI_82m3Kfa_LW<PJfi_Mfh=Ng1_
L21kI6EfJF=UJFiVKb0_@fm/Kg9c86MUM7emJFImJFImJFIUK7=U86E^I21TIFH=
KV=_K6mbLb0`86iUNbmSKfa_LVU]HFMU87AULgAcNG=dIFeTJF=d3BmcIGASKfa_
LWAbHFicIVEb87AULgAcNG=dIFeTJF=d3BmSMG9bIFidHfm/Kg9dLV5^LfIULR1d
IG=dLgUcM6E]I6USM0d_HgEbLVE^M6=]NF]SKfa_LR1dIG=dLgUcM6E]I6USM0eQ
KV@PHFiT865^I21^KgAk;fiSKfa_LW<P<21TIFImJFImJFImJFH=KV=_K6mbLb1T
MG0P<B1^IB1UN6=X86AeL20c86iU86EhHfPP=21^IB1QKV@PHFiT87/_KV=_K6mb
Lb0`86AUIWeYIPe^Hfm/Kg9c834PIG4PI7E`86AeL21^Kg@PLgAQLWA^Kfa_HF@=
NbmTKf=/MGAYKF5WIG]KNc8e=B1]MF`PLVmeKV@PHgIY869gHfaeM21UN6=X86MU
M20b=CDPI6UfOB0_IGQUHb1/Kf5T86AeL21SMG9bIFidM79QKW=VIG8PIGQSJ5dP
3F=fN21RJFiT87=UM7AbHFicIVEb85mg85mX83PPGfU]HGAbJGPPGfAc86U]HFMU
OFAUIWeYIPe^Kg@PIFiTKVm/Kf5T3FiSKfa_LW<PI7E`83<PIG4PIGQSJ20d86Ea
86mb3FAeL21TMG0PKVmd87=dHG9dKVm/Kf5T3G/_KWE/K71bKf=kNgemI6EV;f=_
KV=QM7EdJFak;fEhIF<PK6mQI0dg82da879_K6`P;fEhIF<PK6mQI7eTIFH=;fAU
IW=eHV=/MG@=Nc4PHFAT86MUM6U^M6EbMV5/86AUIWeTIFH=;g=`Hfm^Hf5dM79Q
KW=VIG8P820=Nbm4HfaeM21UN6=X86AUIRm3HfaeM21UN6=X86AUIRm2HfaeM21U
N6=X86AUIRm1HfaeM21UN6=X86AUIRm^Hfm]L7EdIB1UN6=X86aT3F=eLW9UKWAS
Kfa_LWAbHFicIVEb3E]k@F=/MG@PKV=_KG1eM6EmHfm^Hf5dMGAYK5dPHgIh3E]k
@V=/MG@PKV=_KG1eM6EmHfm^Hf5dMGAYK5dPHgIh3E]k@f=/MG@PKV=_KG1eM6Em
Hfm^Hf5dMGAYK5dPHgIh3E]kA6=/MG@PKV=_KG1eM6EmHfm^Hf5dMGAYK5dPHgIh
3G=UM6=_K6mbM79QKW=VIG9mI6EV3BmcIGAeL79WHV=/MGAc3G/_HVUd<gPPLVMR
HfaeM21/IFiWM6PP<b1cMF8PI6EV3BmRJG@aN21RJG@cN20c86UTJGHPI6EV;g9S
K7Ed879WHV=/MG@PI6EV3BmWHfaeM21bHfaeM20a869YM3=h86AUIW=eHV=/MG@_
HV=/MG@PLV=/MG@P<R1RJG@cN21TIFIcMF9SK7EdOFAUIWeYIR1^Kg@P80eUKVA^
Kfa_HF@PKV=_K6mbLb0c86Ea86AeL21TMG0PKVmd87=dHG9dKVm/Kf5T3G/_<f=_
KG1eM6EkIGQSJ21RJG@cN21]MF`=LVmeKV@PHgIY86MUM20b=CDPI6UfOFAUIPd_
I6mSK7EdJFeQIfEk9BmbIf9SK7Ed87QTIR1`Kg0P3G=UM7E`LVMRHfaeM7<_<f=_
KG1eM6DPLV=/MG@PIf=/MG@PHV=/MG@PI7E`3G=`Hfm^Hf5dM79QKW=VIG8PGgLP
GfPP>21OJFeQM79YN0eK;emTLb1/Kf5T82mUN6ES86a_HF@P;fAeL21/Kf5T86Ae
L5eSMWP=KWE/K71bKf<PKWE/K71bKf<PM79eIB0c86=_K6mbJFeQIfEmI6EVOFUV
86i_M21UKVA^Kfa_HF@PKV=_K6mbLb0d86Ea86AeL21TMG0PKVmd87=dHG9dKVm/
Kf5T3G/_LgAeIVISK7EdNf=]NF]YKVAUN20c82da879_K6`PL7EdOFAUIPd_IWA_
JFidNc4PIGQSJ21cMF8P<SDe86eeK21bKgE^I21SMVUmI6EV3BldHfm]L7EdIB1k
86EhHfPPHVUd=7PPKGE/879_MFiT86=fJB1WIG@P<SDe86AYMR1m86AUIPd_Hfm]
L7EdIF=]NF]SK7EdNg=UM7E`LVMRHfaeM7<_HVUd=7PPLVMRHfaeM21/IFiWM6PP
<b1YI6Uf83@PKGE/83@PLgER86AUIPd_HfeiJf=/MG@PHVUd=7PP=21QI6@PLgAb
JFiW86AUIPd_Hf=/MG@PHfeiJf=/MG@PI6EV3Bm]HfaeM21SHfaeM20a869YM3Ah
86AUIW=eHV=/MG@=;gUSK7Ed86=SK7Ed838PHVUd=7PPI6EVLgERHfaeM0d_Jf=/
MG@PHf=/MG@P<b1RJG@dN21TIFIcMF9SK7Ed3BmSKGU[JFiTIGPP<21TIFH=<20a
869YM35h3G]TMG0P;f=]NF]YKVAUN21UN6=X869YM35h86EhHfPPLgER83@PKGE/
86AUIPdc86eeK21TMG0PLV=/MG@PIGQSJ21WIG@P<SDe86AYMR1UN6=X86AeL21W
HfaeM21UN6=X86MUM20b=CDPI6Uf3FEhHfPPHV=/MG@PIGQSJ21WIG@P<SDe86AY
MPecIGAbIf9SKfa_LR1SMG9bIFidHfeiJf=_K6mb3FIdKfU^M21[HfaeM21cM7EV
IV=/MG@=IWA_JFid87USK7Ed87=dMFIVHfaeM0eVM6mYKW@PKF=/MG@PLgAeIVIS
K7Ed3FIdKfU^M21SHfaeM21cM7EVIV=/MG@=OFI_LWeTIFH=;fA_HfaeM6U]HFMU
NfU^MV5/JFASKfa_LWAQHVaU?g]SKfe`MGAUHfeiJf=/MGAmJFH=;cASKfe`MGAU
86=SK7Ed86eSK7Ed87USK7Ed86]SK7Ed87=`Hfm^Hf5dM79QKW=VIG8=GgLPGfPP
>21OJFeQM79YN5/_GfAc86a_HF@P;fEhIF<PK6mQI2mTMG0PK6mQI21TMG0PI7E`
GB1SMWPP3FieK6a`LVmS86ieK6a`LVmS86ieK6a`LVmS87AbMFDP=21SKfa_LVU]
HFMUOFAUIWeYIPe^Kg@PIFiTKVm/Kf5T3FiSKfa_LW<P<21UL@eTMG0PI7E`86i_
M21cM65bM6i_K6mQI0ek;f=_K6mbIGQ`HFiTNfeiLgAbJFiWIGQ`830PLVMRHfae
M0dc86=_L7T==b0]<B1bKfa/3G/c86eeK20c86MUM6U^M6EbMV5/871eM6U^M6Eb
MV5/86EhHfPP<b1QI6@PIGQSJ20c86=_L7UmIVmbHFa/3G1_L21`Kg0PL6m`871_
L21`Kg1mI6EV3BmSLVEQM6EUN71QKVAcM79k;feiLgAbJFiWIGQ`86EhHfPPLg@`
86aUKVMdJ21]MF`PLgAbJFiW86AUIWeTIFH=;fA_HfaeM6U]HFMUNbmbIf9SK7Ed
87QTIR1`Kg0P<b1SLVEQM6EUN71QKVAcM78PGgLPGfPP>21OJFeQM79YN0eK;emT
Lb1/Kf5T82mUN6ES86a_HF@P;f=_K6mbIGQ`HFiT86a_HF@P;fEhIF<PK6mQI5dP
HgIh3FIQK7=U83<PHfm/Kg9YKF5WIGeTIFImJFHPKVmd86E^I6i_K6mQI0e/IGIU
K38PNb1TKfidK6mQI6aUMVE/<B1bIG=dKg9U87eYIPe/IGIUK38PKVmdNb1cHGIU
82mTKfidK6mQI6aUMVE/<R1hI6HPOFUV3BmbIf9SK7Ed830PI6EV3BmTKf=/MGAY
KF5WIG/_J6UfHF`P<SDe86AUIR0=Fbm9KVAUN6ET82m4IGIYHfEBAd8PJ6UfHF`P
LVMRHfaeM5dPLfEdHfm/Kg9cL65SI@eOJFeQIfETJF=d86AeL21RIFMYKR0=;eMY
I7AX85mg86AUIR0=;dQUJFMXM21OJ21TIFHP80d_A6ESKfAU85/`86QYMV5/GB1T
IFHP80d_BFeQIfE=HGAbJGPPGfU]HGAbJGPPI6EV3Bm2JGAcD6Eb@fm]L6m^IFid
83PPI6EV80d_BFidIG9`KfaQM6DPIV5/LfDPI6EV3FE^I21YKF5WIGeTIFH=K6Ef
IF`b86i_M7/PI6m^M6a_HFA/IGIUK38PLVEcM6mbIB1mJFH=9BE5KVA@LVmSDfEd
3BmOJFeQIfETJF=d834e86AYHg@PHVEWJFhP;dU]HFMUE7U`IB0a86AUIRm2JGAc
D6Eb@fm]L6m^IFid83PPI6EV;dU^M6EbL6m/HGAU86IQK7=U86AUIR1SMG9bIFid
I6USM21UKV@PI6EV3BmXHG=SKfa_LR1dLWEU86AUIPd_K6EfIF`b87=iLgAUKFAY
Hg@P;faQKVMeHFMUK6EfIF`PJfi_Mfh=NfaQKVMeHFMUK6EfIF`P<R1WIGekIV5/
LfEmJFIUK7=U86AUIPd_IVmeLVEa87/d86U^I6Eh86Ea83PP<B1bKfa/3C@PJFiT
IGPPIG4P>20a879_K6`==21YKVAUN21ULB0h834PLVm/K0dd86U^I6Eh86Ea83PP
<B1bKfa/3G1_L21`Kg0PL6m`871_L21QKV@PHFiT865^I7dPI6EV3BmcIGAeL69Q
KVAcNfMcHGIU3BmOLfEdM79QKW=VIG8PLgUcM6E]I6USM20_LfEdM79QKW=VIG8P
IfEd86AUIPd_Gf=eLW9UKWAdLV5^LfIULR1cNG=dIFeTJF=d82mSMG9bIFidM79Q
KW=VIG8PIfEd86AUIPd_GfU]HFMU87=iLgAUKFAYHg@P;fU]HFMU86MUM21TIFH=
;f9/HFi[830PGf=eLW9UKWAdLV5^LfIULR1UN6ES3C4PGf=eLW9UKWAdLV5^LfIU
LR1UN6ES86Ea86AUIPd_KVEWHGAYMVDPHVaQKV]k<21OHgEbLVE^M7AbHFicIVEb
86EhIF<P<2he86adO@ek<21OHgEbLVE^M7AbHFicIVEb86EhIF<P<B1OHgEbLVE^
M7AbHFicIVEb86EhIF<PIgAmJFIUK7=U86AUIPd_JFifIG9dIF@o86iUIf5dJGIU
86AUIPd_Gf=eLW9UKWAWLV5i87=iLgAUKFAYHg@P;f=eLW9UKWAWLV5i86MUM21T
IFH=J65cHfm/Kg9k;bAR830PI6EVOB1k;bAR83DPI6EVOB1YIVE/LfD=;g=UM6=]
NF]SKfa_LR1gJ6EbIG]`Kg0P<B0`830P<21cIGASKGU[Hfm/Kg8PGf=eLW9UKWAW
LV5i834PIGQSJ21cMF8=<20a830P<21cIGASKGU[Hfm/Kg8PGf=eLW9UKWAWLV5i
834PIGQSJ21cMF8=<20`834P<21cIGASKGU[Hfm/Kg8PGf=eLW9UKWAWLV5i834P
IGQSJ21cMF8=<20`830P<B1cIGASKGU[Hfm/Kg8PGf=eLW9UKWAWLV5i834PIGQS
J21cMF8==21k=21SKg1iOB1bIG1UHG@=<B0`830P<21VKgEbIG5k;bAR834PLgA_
LVEmJFH=<20a830P<21VKgEbIG5k;bAR838PLgA_LVEmJFH=<20`834P<21VKgEb
IG5k;bAR83<PLgA_LVEmJFH=<20`830P<B1VKgEbIG5k;bAR83@PLgA_LVEmJFH=
<20`830P<21VKgEbIG5k;bAR83HPLgA_LVEmJFImJFH=HVaQKV]k;bAR83HPLgA_
LVEmJFH=968P<21ULB0THR0e86Ea86mbNblTI7@P<21TIFImJFH_96Ad82da86AU
IR1WLVEcM6mbIGeTIFH=;fA_JFeQIfEk3FaUMVE/<W]YKF5WIGekHVEWJFh=EfUT
M6PPB6EYIfQd849YM7=@IG93Kfe`KfiUKW@PBFeQIfE=HGAbJGP=A6ESKfAU86aU
KVMdJ20b86Ea3G/_A65dHE=_MG9SIB1/Kf5T86E^I21YKF5WIGek3DAUHfmTIB1/
IFiWM6PP=R1UL@ekCGE/M6U`K6E4HGAQDfmeLV=ULg]4HGAQDfmeLV=U830PIfEd
84AQM65CKgEbHfDP<B1WIG@PA65dHE=_MG9SIB0b86MUM7ek;dAQM65CKgEbHfDP
K6mQI7eYIVE/LfD=CGE/M6U`K6E4HGAQDfmeLV=ULb0c86E^I214DdU3Kfa_LTU]
HFMUOG/=A6ESKfAU86aUKVMdJ20h86EaNdeeK7AYL6aUA65dHE=_MG9SIG=kA65d
HE=_MG9SIB0`86MUM214HGAQDfmeLV=U834PIfEd3DAQM65CKgEbHfDP<R1WIG@P
A65dHE=_MG9SIB0c86MUM7ek;dAQM65CKgEbHfDPK6mQI7eYIVE/LfD=CGE/M6U`
K6E4HGAQDfmeLV=ULb0d86E^I214DdU3Kfa_LTU]HFMUOFUVOFUVIFacI@emJFIU
K7=U3GeYIVE/LfEmI6EV3BmTM7/_LVMRHfaeM21hI6HP;f9gHfaeM21hI6ImI6EV
3BmSK7/TJB1cIGA]HGAbJGPPM79QKW=/HGAU87=SHFaU3BmOMb1OJFeQIfETJF=d
82mGJFAdJ21WIG@PI6EV3BmOJ21OJFeQIfETJF=d82m8IFUWJ7@PIfEd86AUIPd_
GfAc85mYKF5WIFAYHg@P;dAQM65CKgEbHfDPIfEd86AUIPeTKf=/MGAYKF5WIGdP
I6EV3BmSI7/TJB1cIGA]HGAbJGPPM79QKW=/HGAU87=SHFaU3FaUMVE/<W]OJFeQ
IfETJF=d82m3Kfa_LU=`HF=U86MUM21cIGASKfa_LW=`HF=UOFUV3BmOMb1OJFeQ
IfETJF=d82mGJFAdJ21WIG@PI6EV3BmOJ21OJFeQIfETJF=d82m8IFUWJ7@PIfEd
86AUIPd_GfAc85mYKF5WIFAYHg@P;dAQM65CKgEbHfDPIfEd86AUIPeOJFeQIfET
JF=d869UIfU^3Bm9KF5WIDeQM79YN21OJFeQM79YN21TIFH=HgEbLVE^M6AYHg@P
IFiT3FA_JFeQIfEm86AUIPd_JFek96TPLfEdKF5dLVUh87AbHFicK65dIB1cHf5/
IB0=K6EfIF`bNbm4IGIYHfE7LV5i87=UM6=_K6mbLg1QHfDP<21cIGAWLV5iOFUV
3BmOMb1OJFeQIfETJF=d82mGJFAdJ21WIG@PI6EV3BmOJ21OJFeQIfETJF=d82m8
IFUWJ7@PIfEd86AUIPd_GfAc85mYKF5WIFAYHg@P;dAQM65CKgEbHfDPIfEd86AU
IPeOJFeQIfETJF=d869UIfU^3BD_A6ESKfAU85/`835M86AUIR0P3BD_EfUTM6PP
GgLPI6EV3BD_B6EYIfQd85mX86AUIPd_BFeQIfE=HGAbJGPPGfU]HGAbJGPPI6EV
3F=eLW9UKWATJF=d86E^I20=I6mYKF5WIB1mI6EV3BmSKfa_LVU]HFMU87MXIG9U
Ng1_L2m4DdU3Kfa_LTU]HFMU87]SKfa_LVU]HFMUOB1TIFImNbm4DdU3Kfa_LTU]
HFMUN`d_96iS87QTIR1`Kg0P;g1bKf<`87QTIR0c86U^I6Eh838PJFiTIGPPKGE/
83LPHFAT83PPI6Uf86=fJB1cM79YKVLP;g=d<B1hI6H=96iS83<PIG5kNg1bKf<`
86AeL2mcM30PN6AV830PIGQSJ20c86EhHfPPK6E^IgAX83<PLgER3G]TMG0PLg@`
86EhHfPPIfEd82hc86eeK20a86U^I6Eh834PHFAT87=d<21UN6=X86MUM20^=CTP
KGE/865TI20a86U^I6Eh838PHFAT87=d<21UN6=X86MUM20^<C4PKGE/865TI0eS
MVTPIGQSJ20c86AYMR1SMVTPIGQSJ21cM34P<b0a879_K6`PL7EdOFI_LR1cM35m
OG]kL79_Hc0PI7E`;g=d<21hI6HP<21UN6=X83@PIGQSJ21/IFiWM6PP=21cMF9k
I7E`3G=d<21UN6=X86MUM20^<b1]MF`=<B1YKVAUN20a865TI21cM30PIGQSJ21W
IG@P;SDi86eeK21QI6@=<B1YKVAUN20b865TI21cM30PIGQSJ21WIG@P;S4a86ee
K21QI6@=<B1YKVAUN20c865TI21cM30PIGQSJ21WIG@PHFAT86AeL20b=CD^<21W
M7]`Kg0P<SDe;S1mJFH=<SDe;S0PIGQSJ21cMF8PHgIY3FEhHfPP=21TJGHPHgIY
86EhHfP=Lg@a83<P<B1bKfa/871eM7eVKg8PLg@aOGeYIVE/LfD=JFeQIfEmI6EV
OFUVIFacI@d_Ce19JFeQIfEkJFeQIfEmI6EV3BlTJB1]HGAbJGPPI6EV3BmRJG]c
Hf5/IB1dLV5^LfaQM6DP96TPHgEbLVE^M6eQM79YN21`Kg0PM79QKW=/HGAU87=S
HFaU87=UM7E`HV5^I7=mI6EV3BmUJG/TJB1cIGA]HGAbJGQmI6EV3BmYJg/TJB1c
IGA]HGAbJGPPM79QKW=/HGAU87=SHFaU80d_GgLPGfU]HFMUI6USM20_EfUTM6PP
IfEd86AUIPd_GfPPGfU]HFMUI6USM20_B6EYIfQd86MUM21TIFH=;emTLb1OJFeQ
IfETJF=d82m4HGAQDfmeLV=U86MUM21TIFH=GgLPGfPPIV5/LfDPGfU]HGAbJGPP
=B0]<B1bKfa/85mTLb1YKF5WIFeQLf]mI6EV3BmbLg/b86=_L7TPM79QKW=/HGAU
3C<P;C4PLVm/K21^IFLPLVmdHGAU3FiUIb1UN6=X86iUIb1UN6=X87AbHFicK65d
I@emI6EV3BmSLg]OHgI]M7PPHG=dKg9U86=_KV=QM7dPI6EV3BmVI7/_GfIT87QT
IWeTIFH=;emVKfidCF5dLVUhNc4P<20`85mVI20`86iUNbda830P<7ek<B0`831m
JFIUK7=U85mSMVedN21QLgA_LVEmI6EV3BmbIW/_GfE^HfmTJFiTIGPPN6AV3DI_
KWA4JG9UHgA_LWTPIGQSJ21[KVmgKR1k3FIYKVAVKfid86AeL21/IFiWM6PP<B1Q
I6@PI6USM21RIFMYKW/a86U^I6Eh;dI9A21^IG]TIFImNg1_L21`Kg1mJFIUK7=U
OFI_LV5/K0eTMG0P;dI_KWA>HFeU86EhHfPPI6EV84I_KWADNG1U830PKVEk;dE^
HfmTJFiW84E^HfmTJFiW838e=R1QLW9QNB1SKg1i86AUIPeOIFiSKfAYKVAUN20`
86MUNc0PGfE^HfmT@G9b85mUKV=_I6U^I6Eh86MUM7]TMG0PM7U`IBm^HFeUM7U`
IB1ULG]5KV=_I6U^Ib0b86U^I6Eh838PJFiTIGPPL7Ed871_L20a865TI7d=NfEh
HfPPL6m`OFUVIFacIGeVKg9QK6`PL6m`OFUVOFUV3F=eLW9UKWATJF=d86E^I0eT
IFIYKVEVKfid871_L21mNg1_L21`Kg1mJFIUK7=UOB1TIFH=;f=fLfIk86IYKVAV
Kfid86IdDfUjIB0`830PIWACJGYU85mVI20`86iUNbda86eeK7eYIR0`830PGf=f
KGAh865cM6mbIB0=KF5[IFI_KW@PLfEdIVm^M7eTIFH=;feVNc<P;C4PLVm/K21V
JFiTIVm^M20c834PLVm/K21UN6=X86IdDfUjIB1]MF`PIGQSJ21VM5=YNVDPKGE/
830PIGQSJ20`86EhHfPP3EmVI20`86iUNbda86eeK7eYIR0`830PGf=fKGAh865c
M6mbIB1]HF]UIVm^M21cIGAVKfidOFAUIPd_Mg9[<B0X82TPI6EV3BmgI6USM20a
=R1TJF=d86AUIPd_EfmbJcLe83Le87=dLVU^Ib1TIFH=;di]Jg]GKg9[=cDPHgIc
86AeL7eTIFH=;di`M7]`MG@PHgI^OFAUIPd_I6Q?I6QkCVe[838P=cTPCW1dOFAU
IPd_I6Q2I6QkCVe[838P<C4a84i`M7eTIFH=;fAXDfAXNdi]Jb0b83Pc84i`M7eT
IFH=;g=VEfUTM6QkIg=QMVDP<20`86e_MVEdKb0`830PK6U^IGA_830P<21/JFiU
M6lP<20`86aYKVEdKb1SK6mcIG1QM6PPHfaYL21cM79YKVMgJFAdJ21WLVEcM6mb
IGeTIFH=;fIdLg/_IWACJGYU86EhHfPPI6EVOFAUIPd_KF]6E7]TMG0_AVm^M5Ai
L6DPIfEd830PIG5kI7E`86eQN6aUKVMdJ21TJF=d869UIfU^3G/a86U^I6Eh;dI9
A21^IB0b86U^I6Eh82mEKVUaMFE9A21^IB1QKVAkI6EVOG]`Kg0PL6m`OFUVIFac
IGeVKg9QK6`=HgEbLVE^M6AYHg@PIFiT3FAeL2m6A6E`EVESM6mb838PHfm`NB1W
IG@=FfEhHfPP=R1YKVAUN21UN6=X83HPJFiTIGPPIGQSJ7]]JdID83<P<B1bKfa/
OFI_LV5/K21`Kg0PL6m`GB1`MG@PI7E`OG/_M6E]L4ID834b86AYHg@PI6EV3GAU
KG16E21RIFMYKPd_AVm^M4eQM79YN21K<B0`830P<B0`831M86AUIPd_AVm^M5Ai
L6DP<b1TIFH=I7E`;dE^HfmTJFiW86MUM2m5KV=_I6U^Ib1UN6=X86AUIPd_L79_
Hc8P<R1YKVAUN21TIFH=I7E`;fId<B1UN6=X86AUIPd_IW@b834PHG9bHGTPI6EV
3Bm6Kfid@T9_N21K<20`834P<EdPI6EV3Bm2MFU/I4=XHG9k@eI4JF=d869UIfU^
3FEhHfPPI7E`;fIdI7@PN6AV869UIfU^3GMTJF=d869UIfU^3BmSJ78PN6AV;f=X
LW=d87MbJc4PI7E`830PHfQb871eM21TIFH=IW@b830PIfEd86ieK6`PIG5kIW@a
86AeL21/IFiWM6PP<R1QI6@PI6USM21RIFMYKPek<B1YKVAUN2m6BD@PKVDP<R1Y
KVAUN20_EFiYLGEUBD@PKVDPHFiTNfAUIWekL6m`871_L7eYIVE/LfEmIVmbHFa/
3Bm@HFU^M5AiL6DP<R1TIFH_DgAbKf]UEfUTM6PP;S0b=20`84I_KWA=HGAbJGPP
JFAdLV5^LfI_LVdPL6m`86AUIPeSMG9bIFidI6USM21UKV@=;g4PIGQSJ21TIFIY
KVEVKfid3FId<R1UN6=X830PIGQSJ21`MGAmJFH=IWATM2m`LVmS<R1WIG@PIGQU
Hb1UKV@PIFiT86E^I7eTIFHPIFiT87AUKG16E7eYIVE/LfD=<b1YKVAUN21UN6=X
3FAUIVU^IFI_KW@PIGQSJ21`Kg1mI6EV3Bm]HW]TMG0PI6Q2I6PPAVm^M4AYLVES
M6mbNB0a86U^I6Eh86]^KgM^3G]UN6=X871_L7ekI7D08`000:40`3ooL20b86U^
I6Eh3FIYKVAVKfidNf9_K6A`LVmSOB1UN6=X3Fe[AU@PL6m`871_L21`Kg0PIGQS
J21`Kg0=OFUVIFacIB1mI6EV3Bm]Kg]TMG0PI6Q?I6PPAVm^M4AYLVESM6mbNB0a
86U^I6Eh86]^KgM^3G]UN6=X871_L7ekI7E`838PJFiTIGP=IVU^I6I_KWAkKgEd
L79_HgdPIGQSJ0e]JdID871_L21`Kg0PL6m`86EhHfPPL6m`3GeYIVE/LfDPOFAU
IPd_KG=kI7E`86AXDfAX84I_KWA4JG9UHgA_LWTP<B1YKVAUN21[KVmgKPekIGQS
J21`Kg1mNfAeL20b86U^I6Eh3FIYKVAVKfidNe=XHFA3J65bOB1UN6=X3Fe[AU@P
871_L21`Kg0PL6m`86EhHfPPL6m`3GeYIVE/LfDPOFAUIPd_KgEdL79_Hg]VM34P
LfEdIVm^M0eWLf5fIB1SJ79cM21cIUMYI7AX86MbIG=dKg9U3G=UM6=XHG9gJFAd
J21THVacJ7eTIFH=;f9_K6A`LVmSNfId<B1cIGAVKfid3FMcHGIU3F=XLW=d87=V
EfUTM6PP<B1YKVAUN20`86iUNfEhHfPP;S0e865TI21UN6=XOFUV3FMbIG=dKg9U
3G=UM6=XHG9gJFAdJ0eVM34P;e1QJFidE7U`IB1WIG@P<R1^I@ek<20`86e_MVEd
Kb1WLf5fIB1VM38P<21WIG@PLfEdIVm^M21SJ79cM21cJ6mg86MbIG=dKg9U86=X
LW=d87=XKgMm3G/`830PKFmfIGA_86McHGIU86=XLW=d87=XKgLPIg9ULgA_LVDP
;S0e830PKFmfIGA_86=XLW=d87=XKgMmJFIUK7=UOFAUIPd_I69/LfQkHgEbLVE^
M6=_K6mb86=eLW9UKWASKfa_LW=`HF=U834^<21cIGAWLV5i3F=XLW=d830P<21]
KgIUM6lPLfQ_Mb1cIGASKfa_LW=`HF=U87=UM6=_K6mb3FId<R0`86MUM21cIGAV
Kfid86=XLW=d830P<21]KgIUM6lPLfQ_MgeTIFH=;e=XHFA3J65bN`eVM34PLfEd
IVm^M0eWLf5fI@eSJ79cM21cIUMYI7AX834PJFiTIGPP<21^IG]UN6=X82h`=B1Q
I6@PIGQSJ7eYIPeWLVEcM6mbI@ecIGASJ65bMfUTM6P=HfQbLg@P;S0f830PKFmf
IGA_87=XKgL=<20^<3DPM79QKW=/HGAU86ARK7=XOFAUIPd_M7=kLfQ_MgeTIFH=
;gAQNbmOK6EdM6EbDg1QHfDPN6AV;emcL65SIEQdLV4PN6AVOFAUIPd_M6Ik;emd
IGQdEfUTM6PPN6AV3BmOKWE]Dg1QHfEc87QTIPd_Gg=dLVU^IdaUKVMdJ21hI6H=
I7E`2G=dLVU^IgMYI7AX871_L0eOK6EdM6EbDg1QHfDPGg=dLVU^IdaUKVMdJ20a
87=eHR1]MF`PHFAT3EmcL65SIEQdLV4PGfieKE=`HF=ULb1]MF`PHFAT3EmdIGQd
EfUTM6PPIGQSJ21cMF8P;gMTJFHPN6AV3EmcL65SIEQdLV4P<20c<PegI6UV85mc
M79YKVM<IFiWM6PPI6Uf3Em/IGAdIG9CL65SIB1QI6@=<20f82da879_K6`PHGMY
I7AXLfQ_MgeTIFH=;g1RNbmOD65WIE=QMVDPLf5fIB1TIFH_LfQ_Mg1QIfEkOFAU
IWeTIFH=;g1UNem@HFMUDf5fIB1bIG=dKg9UOFAUIPd_L6ekGg1]86=eLW9UKWA]
HGAbJGPPL6m`OFAUIPd_Gg1]86eQM79YN21TIFH=;g1cNg=XKgM`HFMU85m`KB1c
IGA]HGAbJGQmI6EV3FaUMVE/<W/_IFHPNfMcHGIU83HPHG9bHGTPHG=dKg9U86=_
KV=QM21TMG0PIGQUHfI_LVdPIg9ULgA_LVEmI6EVO@ek;fEVNfMcHGIU83HPHG9b
HGTPHG=dKg9U86=_KV=QM21^IGM`HGAX86AeL21RIFMYKR1=HGAbJGPPHfm^Hf5d
3D92KgPPI7E`86AeL20`86MUM21UN6=X834PIfEd86e_MVEdK`eTMG0PI7E`830P
IfEd86EhHfPP<b1WIG@PK6U^IGA_3FAeL21TMG0P<R1WIG@PIGQSJ20c86MUM21/
JFiUM6l=I7E`838PIfEd86EhHfPP<B1WIG@PK6U^IGA_86=/Kg=UL65dJ0eSK6U`
86iUMg1QM6PPD65YKWA@LVmS86E^I21WLVEcM6mbIGeTIFImJFIUK7=U3BmRHg]c
HGIU834a834PLVm/K20a<21TJF=d869UIfU^82m2@Vmh83DP<B1bKfa/83@PHG9b
HGTPHG=dKg9U86AUIPd_CF5dLVUh83LP<B1bKfa/83HPHG9bHGTPHG=dKg9U86AU
IR0_AVmbKEAiL6DP<B1TIFH_D65YKWA@LVmSNbm`L21WIG@PIGQUHgeTIFImI6EV
3BmUHg]`Kg0PLVEcM6mbIGeTIFH=;g1bJFidMVek<B1fKG9UHfaQJFdPMVecM65d
MG<PL6m`86EhHfPPL6m`82PP820P820P820P820P820P820P820P820P:F=fLb1`
LVU^M20XG6hYL79YKW@PIVaeLfQmI6EV3BmcIGA_MVEbL79YKW@PMfQULVDPNg1_
L7ek;g=UM6mfIG9`LVU^M7]`Kg1mI6EVOFUVIFacI@d_Lg=dLR1k82lTLg=dLW<P
IGQSJ21TIFHP;bAcLgAb86EhHfPPI6EV82lTLg=dLWTPIGQSJ21TIFHP;bAcLgAb
N21UN6=X86AUIR0_@fmeLVUULR1VJFiTIVm^M20TLg=dLW<P3G=SHFaUIVm^M21c
IGAVKfid82AcLgAbN20TLg=dLWTPKG@PLgA]834P;C4PLf=QK6DP97=cM78PLfQ_
Mb1bM6dPOB1TIFH=;dACBD9UIfU^D65YKWA@LVmSNbm`L21]HG9[Nf=eLW9UKWAV
JFaU87A_JfE^86i_M7]mJFHPI7E`;dACBDE^I51QJFidD79_H`d9IG5kL6m`86=_
MFidM6m]HG9[865bLV5i865cM6mbIB1SMWPPHVU^I20_IGQUHb1/Kf5TGF=fN21T
IFHPA5=9AFiTD65YKWA@LVmS86EhJGAm3@UkHfmeKWAdKfeQLV/P<c0`86MdNf=_
MFidM6m]HG9[865bLV5i865cM6mbIB1SMWPPHVU^I20_IGQUHb1/Kf5TOFUVOFUV
IFacIGe/Kfm`OFAUIPd_A5=9AFiTD65YKWA@LVmSNf=eLW9UKWATJF=d86E^I7eT
IFH=;dACBD9UIfU^D65YKWACMF9@LVmS87]cHGIU834a834PLVm/K20a<21TJF=d
86AeL20_L4@PIGQSJ21TIFHPHVEWJFhP3@T_@T9_N20e834PLVm/K20d865bLV5i
865cM6mbIB1TIFHP;deQM79YN20g834PLVm/K20f865bLV5i865cM6mbIB1TIFHP
3@T_AVmbKEAiL6DP<B1TIFHP;e1QJFidD79_Hb1k82m`L21WIG@PIGQUHb1m86AU
IR0_L71m86AUIPd_A5=9AFiTD65YKWACMF9@LVmS87]RJFiT86AUIR1UKV@PL4Am
86AUIPd_JF5Q87/_JGPPJGPPJGQ^865TI21TIFIm86AUIPd_JF5c<R1k;fUWHG0P
IGQSJ21TIFHP;emcM30PJF4PJGPPJFMQL21QI6@PIfEd86AUIR1OLg@`OB1TIFH=
;fUQLb1k;g=d<21YHB1YN21WIG@PI6EV86UQHB1cM31m86AUIPd_JCPeLb1k<21Y
HG<b82m1Dd=9BCPeA6ESKfAU86IYK7AULR1cM30PLVEQI7=dLVU^Ib1`Kg0PJF5Q
OB1TIFH=;fUbK6Ec87/`86UQLc8P;d5C@dU9>3E4IF=_I6DPIVU/M6Eb82mBMFi<
IFiWM6Q4IF=_I6DPIVU/M6Eb87=d<21bIF5TLgAbJFiW871_L21YHF5m86AUIPeY
KVUdJF5/JGYU3FE^I0dU9DE^I59ULfmeLV=U3D=FA6USM21RIFMYKR0`86UT834P
IV@=GfE^HfmT@G9b830=F`dc>BmaMFmdIG=YKVM/IB0i=RmWLV5fI@da<SP_HWE/
K6Ed;f9eK6aUM2maMFmdIG=YKVM/HV5cIBmVK6mbJFh_LGE_M6ETHVaRHG=U;fE/
K6U`LfUc;fAQIfMULRmTHFMWIG9THV`_HfUbHgE]IVaUN2m`IG9dJ6meLf5^I2mC
Hf5bKfh_IgEYK7=YKVM/K6EVM2m?ABmRMFa/IG@_HWE/K6Ed;f9eK6aUM0d_HWE/
K6Ed;g5eKgAUK6EVM2maMFmdIG9YIfQd;g5eKgAUI69/K6EVM2maMFmdIFARK79Y
IfQd;f9eK6aUM2mUKVAQLfP_IFeTHG=X;gAYK6AU;gAbHFAUKF5bJ`d_Lf=QLVm^
3BmWMFU/LfU^IfabJFMXM2m_IBmRMFa/IG@_HWE/K6Ed;eUTJFEbIG=YL`d_HWE/
K6Ed;fEhHfaQKFA_Mfh_HfE^M2mcM6EbK6U^IbmSMG9bIFiSNBmiIFh_HW9_JfE^
HV5b;g=UHgAYKfh_I6UULVEcJG<_Hfm`NG9YIfQd;fmbI6IUKFU^JFiU;fMeJFa/
IFe_M6aUIW@_K6mWJF=QK6i_M2mXNG1XIFh_LVEWJG=dIG9UI2m]HF=bKfh=;fAU
Ig9UIBm`K7EcKFU^MG<_M7M_LgE`IG9YKg8_M6QbIFEcMG1ULVU_LRmQHgEdIBm]
MBm`HG9QIg9QL6P_L6EbJFmTHfE^M6EbIF@_HfETJFa/HBm_KVEcMG1ULVU_LRm_
LVA]HG=SMFaYKVD_IgEYK6aUKFmdLVUWJ7@_KfiULGEQLWAULRm_KVEXHFaV;gAX
LVEULGEQLWAULW<_LGEULgAYKfiTKgM^3Bm1Ig9QMVD_@F5SMGAU;d5SJG9SMFeV
K6Eh;d5dJFaTIBm1I6UULVEcJG<=;d5bJFiW3Bm1ABm3HfETJFa/HBm5Ig9QMVD_
AF5SMGAU;dEWLV5fIBm5I6UULVEcJG<_BFMbHGIU;dUQHgEdIBm9HfUbHgE]IVaU
N2m9I6UULVEcJG<=;dEdJ2m>M6U/I6D_CfMbHGIU;dmQHgEdIBm?HfUbHgE]IVaU
N2m?M6U/I6D_CfAYIG9ULfUc;feeK7AYL6ai;dmcK65cJ2mEIg9QMVD_EF5SMGAU
;eESJG9SMFeVK6Eh;eETJFEbIG=YLbmIHF=eM6D_E6Q_LVh_IfEbKF5^I69/L`d_
HFMbHGIU;f5QHgEdIBmQHfUbHgE]IVaUN2mQM6U/I6D_HFAYIG9ULfUc3BmQLVU^
I`d_HFD_Hf=UI6U/K64_IFMbHGIU;fEQHgEdIBmUHfUbHgE]IVaUN2mUI6UULVEc
JG<=;fUWLV5fI@d_JF5SMGAU3BmYHfUbHgE]IVaUN0d_JFAYIG9ULfUc3BmUM6P_
KWAYK6AU;fmWLV5fIBm_HF=eM6D_Kf=YLV=eKFI/IGP_KgAYK6AU;fmTJFEbIG=Y
LbmTJGIYI6D_Kg=/HG=X;gEWLV5fIBmeHF=eM6D_MF=YLV=eKFI/IGP_MFAYIG9U
LfUc;gUQHgEdIBmdJ6mbKRmiI6UULVEcJG<=GB1`MG@=GfE^HfmT@G9b834=F`dc
>BmaMFmdIG=YKVM/IB0i=RmWLV5fI@da<SP_@FAYIG9ULfUc;d5bJFiW;d=SIFAY
K6aQ;dEQHgEdIBm>M6U/I6D_CfAYIG9ULfUc;eETJFEbIG=YLbmQHF=eM6D=;f5W
LV5fIBmQHfUbHgE]IVaUN2mQI6UULVEcJG<_HGAYK6AU;f5bJFiW;f=SIFAYK6aQ
;fEQHgEdIBmUIg9QMVD=;fESJG9SMFeVK6Eh;fETJFEbIG=YLbmYHF=eM6D_JFMb
HGIU;fUSJG9SMFeVK6Eh;fUTJFEbIG=YLbm^M6U/I6D_Kf5SMGAU3Bm_Ig9QMVD_
Kf=YLV=eKFI/IGP_KfAYIG9ULfUc;fmdJFaTIBmeHF=eM6D_MFMbHGIU;gESJG9S
MFeVK6Eh;gETJFEbIG=YL`d_I65WIfEb;fAUIg9UIBmSIFid;g=dIG9/JFiW;g=U
HgAYKfh_HWE/K6Ed;g1QLV5WLV5`J2mWIG9]HFiTHVac3BmbIFMYLgAULVET;f=_
L7UbJFMXM2mdLV5TIFeQLV/_HF=eM6D_I6UULVEcJG<_KVmdIG5eHF`_@DD_Cg=/
HG=X3BmYKVIYKVUdNBm`K7EcKFU^MG<_K6EcLfEaMF5/;fMbIF5dIG9ULGEQK2mi
IFh_KGD_L65bM6UQK6AYIVH_LgE]KF5dJFm^3Bm`LVmTMF=d;g1Y;fU^M6EWLV5/
;fmbI6IUKFU^JFiU;fmbI6eQLf=eK6U^IBm?KFEWHBmQIBm_LfaQLfP=;g5eIG=d
JFm^I6mgKRmUN6=/HFeTKgM^;fa_IfUSHFa^Kg@_LV5TJF=QK2mVK6mbJFh_HG1`
LVmhIG5eHF`_A6E/M64_IgEYK6aUKFmdK6EVM0d_IgEYK6aUKFmdLVUWJ7@_IFa/
JG1cJG<_HVaQKV/_@FMbHGIU;d5dJFaTIBm?M6U/I6D_CdD_KfD=;fE^I65cJ2mU
KFAQLfP_LGE_M6ETHVa/IFId;g5eKgAUI69/LVUWJ7@_LGE_M6E/IFId;g5eKgAU
LVUWJ7@_I6UfJFAU;fa_NVE^IfD=;gUTJFEbIG=YLbmII6UULVEcJG<_IW9QHgAY
Kfh_HgEbLVE^HgT_IgEYK7=YKVM/K6EVM2mWMFU/LfU^IfabJFMXM2mVJBmVK0d_
I65WIfEbI69/;g1ULVU_I6=UKWAULVET;g5eKgAULfU^IfaRHG=U;g5eKgAUI69/
HV5cIBm`IG9dJ6meLf5^I2m1HfUbHgE]IVaUN2m5HfUbHgE]IVaUN2m1HF=eM6D=
;dETJFEbIG=YLbm5Ig9QMVD_BF5SMGAU;dUSJG9SMFeVK6Eh;dUTJFEbIG=YLbm9
Ig9QMVD_Cf5SMGAU;dmSJG9SMFeVK6Eh3BmQL71/IBm?Ig9QMVD_EF5SMGAU;eES
JG9SMFeVK6Eh;eEWLV5fIBmTKgA/IG=cJBmSJG9SMFeVK6Eh;gAYK6AU3Bm]HF=b
Kfh_HW9UMVD_I6mdHF=SIFid;g9YKVL_HfETJFa/HBmXMFiWHG9eKFaQMG@_KfM_
KVE[;f=QLVm^3EdPL7Ed3FE^I0dU9DE^I51bKfa_Ib0=9BE2IFMYKU=UM7E`80e3
ETAYHg@PHVEWJFh=3BDU@VEWJFiBIG=_MG9SICXPIVm^M217IFiUMV4=<C@PI6US
M21RIFMYKPd_AVm^M4iQKFDP;dMUKVEfHB1TIFH=;dI_KWA=HGAbJGPPFc0^<30a
830P<20`;S0`<B0`831M86AUIPd_AVm^M4U^IVlP<C0PI6USM21TMG0PHVEWJFh=
;dIeK6a>HFeU82Q7IFiUMV4Y86AUIPd_AV5]JFaiCV5]IB0XAfE^IGIQ:B1TIFH=
;eE^I6EbK6U^IE1_LfUdJFm^82da<30PI6EV3BmEKVAULVaYKVEDJ6USJfiULg<P
=C0PI6EV3BmCM79YJfE_MGA@Kg=YM6U_KR0c<30PI6EV3BmCM79YJfE_MGADJ6US
JfiULg<P<SDPI6EV3BmGIFUWJ7@P:4eUI6UeKBTPI6EV3Bm9M65/JF=1KVM/IB0`
86AUIPd_JG=6JGQUI51YM6=X86IQK7=U86AUIPeUKV@PI6EV3BmOIfaiL6PP:5PP
82TPI6EV3BmWN0ek3@Ta86EhHfQk3@T9I7E`834f82PP82TPHgIbLb1OIfaiL6PP
IGQSJ20a86EhHfPPL7EdJFidIG9fHF`P<B1YKVAUN21UN6=X3@T9GfM/NG1X86=f
KR1`MG@=2@UmIVmb3GeTIFH=;e1QJFidE7U`IB0`86AUIPd_AVm^M5AiL6DP<B1T
IFH=;dE^HfmTJFiW838e=R1QLW9QN@d`834P<SDe87/P<B1YKVAUN21UN6=X82l^
KVmdI6EV871eM21m86I_LPdc<20b=CDPIgP=I6EV3Bm6Kfid@T9_N21K830P<20`
830PGB1TIFH=HgEbLVE^M6AYHg@PIFiT3FAeL20_D79YMV5dIB0h86AYHg@PI7E`
869UIfU^3BmBA7]cM79YKVLPHgEbLVE^M6IYK6DPIGQSJ21bIF5TJ6EhLgAbJFiW
871_L7eTIFH=;di4NfAUIWeTIFH=;di@Ng1eM7eTIFH=;d9/MFEFHFaeIG=K82db
=C0P<20b<S0`838b<31M86AUIPd_CFU^AVEQM7EbIB1k834f834fOB1TIFH=;g1Q
Lg=gKg9T83Dh<cTPI6EV3BmCMF9bLb0d<b1QLW9QN@e>A0db86U^I6Eh82m3J65b
DgAbJFiWLb0b=CHPI6USM21TMG0PHVEWJFh=;bi^KgATIFHP834`8594838dAD=2
A30e<dE3@D@c=C96=CPa84i43BmH<34P834b8594838dAD=2A30e<dE2>D4`=cE4
@C@h@d=5AB1>A0d_F30b820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDP
CT@=;eP`<b0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<3@P
834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F30e820a<R1BA20b
=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;eP`=R0P<C8PDT@P<SA5@d94<3Dc
AD8i@C0g=DA1=3Q3@dE584i43BmH<3LP834b8594838dAD=2A30e<dE2>D4`=cE4
@C@h@d=5AB1>A0d_F30h820a<B1BA20b=4E3@T@`=C=5@d54<cDbASDh=SDb84i4
3BmH<3TP834b8594838dAD=2A30e<dE2=SE3A3U2<C4d@S11AB1>A0d_F311820a
<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;eP`@R0P<C8PDT@P<SA5
@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<4<P834b8594838dAD=2A30e<dE2
>D4`=cE4@C@h@d=5AB1>A0d_F314820a<R1BA20b=4E3@T@`=C=5@SHe@d@i@S4a
=48`@DDPCT@=;eP`AB0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i4
3BmH<4HP834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F34`820a
<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePa<B0P<C8PDT@P<SA5
@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<C8P834b8594838dAD=2A30e<dE2
>D4`=cE4@C@h@d=5AB1>A0d_F34c820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d
>4=3ADDPCT@=;ePa=20P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i4
3BmH<CDP834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F34f820a
<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePa=b0P<C8PDT@P<SA5
@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<CPP834b8594838dAD=2A30e<dE2
>D4`=cE4@C@h@d=5AB1>A0d_F34i820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d
>4=3ADDPCT@=;ePa@B0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i4
3BmH<D8P834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F353820a
<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePaA20P<C4PDT@P<SA5
@d94<3DcAD=1A3<e<THe>3He<R1>A0d_F355820a<R1BA20b=4E3@T@`=C=5@SU1
<3LeA44d>4=3ADDPCT@=;ePaAR0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3
@dE584i43BmH<S0P834b8594838dAD=2A30e<dE2=SE3A3U2<C4d@S11AB1>A0d_
F38a820d<B1BA20b=4E3@T@`=C=5@SHgAC<c=T51=3La=C4d=4A1=CPcA48b@S54
AS=5@D55=T=4<T@g=d4e>CLh@CLg<CH=@c16=d52>3=3>C0g<d<h<34b<3Th<R1>
A0d_F38b820d=B1BA20b=4E3@T@`=C=5@SU1<3LeA44d>3<bASLd<dHg=ST`@TE4
A3<h<CDc@SPc>C<dAS55=cQ4>D4eA38hAT8=@dDf@CPd<S4e@T=2ACM6>D4d>CM5
=c0a>455>35484i43BmH<S<P834a>21BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THh
@dHh<DHd@STb=SLb<C8h@T<iACE3@DE2<C=1AC94<3=3A4E6ATD=>38cAD@b=S51
=S@i=c96A3DgASHg=C8c@c13@S4h@S4eAS93=SLh@S8g@c4i<DDf=CDe@CHd@cLe
AT<b3DHb@CHf=3U1=4<fASLg<30hAT4d=c4`>DDcA48c@SE1<D4c<3E4<SI5<4<f
<c8e=4DgAD@`=STi@cLh<@e6@D8`<3Ph@cTf@S12>D8fATE6<D8e<44b=D@a>D93
<395AD8b=38a<T95@THeA3La<STfAS53@B1>A0d_F38d820b=c0PDT@P<SA5@d94
<3DcAD8h=cDc@d4dA3I6=c14@S4cACA5<S0fAD<i@SLa<dDf=D<d<3=3<cU2>C91
=c15>CHi3CDa>3Q1@d<h<c<`@cE5@C95<SU3@S=3<SA2ACPe>DI4>CE5=30aAS0b
=CPg<cLf=c4d<cU3<c0c@d55=0d`<C@f=3E4>3I5=C0b=c<h>D4f<3E6=dHb<d91
<S@d>3E2@TI6=44a=SDh<T<`=C0gAC4d=3A4@D8e<T@==3DcA3I3>3E2<cHg=DA3
A4I5<T4`ACDb<4I4=3Tb<SA5<38gA3De=c0a@DE3@S4`ADE2=D<b@DA1=C<d3C0`
<cPf@CDc>CDa@TA2>C8gAD@b=cPg<T<i<c4d@SHc=cTb=4=5>C@g=DE2=CU1=dDe
@cLi=d<e@TDg=0dhA4<c@C<f=CTf<3Pf<4Hg<dE1<C53@SM5@SHc=dA4>C8f@d<i
@T4`>D8g=34aASD`<c12=cHdATE1A4D==C16=STfA4I1>4@i@SHhACTi@S8g@DDf
>4=4AC55@C0i>D8iATI6>C=6ASQ6<C<e@S8h@C56>DHa<S553CM4=3<b@c0`@cDh
<c56@d<hACPc@c8e<T<i<S16>3Hg=cPf<48iAT93AD@a<cE3<4Hd=cDh<T=1AT@a
APdiASQ1A4Hh<3Ha=396ADA1=3Pe=CM3@cA1@SLe=THb<DDf=3@c=4H`<CA6>D54
@cE3>C<dA3<`@SDb<cPPCT@=;ePb=B0P<SLa8594838dAD=2A30e<dE2@T@hA3Q5
A491=CA6@D@e>C<c<311>C=4@DHa=44b<CE6@D4f=dE6=CD`<DHf>316=`e2<c0e
<TE1@SLbAS4d<cDb@cI6>C<a<D96>C12<cQ2>44gAS92A3LfAD@d@C@b<TA4>3Dd
>4<f<d<eA3@==D8c<DHe<D8a<T8b=3A6=3@gA34c@SDi<c<d@cQ6<c<`@c8i=354
=CPe@d8hAS<`@SE2<3<c=c4`A3La3DH`<3Lc=4I5>DE4=4<g=313<4=5<SM4=CM2
<T95<SA1A3Lb>DHcAD=3<38f<3M2A30a=C4h@DI4AT8i=Pe1<CHd>48g=SM3@d=6
<4@`=CQ6<T8`<CHdAD@f<S@e=CDg=d<hAC@f<4=5=3U5@dDd=3Lg=c8eAT@f<DH=
<CD`=353ADI4=SDc<3Q5<THf@d8b@cLg<3Tg@SLgA3Hg=c=4@S8b<DHb@SM3=C91
=c52<4I1=T@dAT8g3CU6=D8c@CLhASHf@d<`ADDdAC8f<cQ3AD8g=T@f=S12ASA2
=cI4<T4`=CPa=CLa>3@c<3Pd@d8i>3HeA@db=d@`<d8dA3E4=DDf@CLhAD8g=4E4
=C92<T4d=S56AD=1@c52=CDb<cM2=SM1A3Q4@CHb=CQ6<30g>48=AT8aA4=6>C@h
=S@d@CI6ATDf=CPb@c4f<S=1@dE5AD52A34i=C92>DHh@CLh>DDiA316=CDe=CPe
>CPf3C8d84i43BmH<SHP83<d>21BA20b=4E3@T@`=C=5@SPc<CDa>C55AS0d=d@a
<cM4>DDiAT<`@cPf@cLeASH`AC91=C0cAS@h<DE2AS0hATD=<SLd=CDc@d4a<D8g
AT8f<TDg<DE3>D=6=4<e=dI5@CA1=48c<D4`<dA3=SDg=CTe=S4b@STiAD<a@C<`
3C=5<SDe<451AS0c=T93@CU4=c=3=S94=30g=D=3@S0a<cHaAS<g>38h=C<e<cT`
<C4bACH`>C4h=SM4A@dgA4=3>4I3@D<`<3A3ATHh>CTc=3M3@S96>3He@CU5=SDd
=SHiACM4<CE1>315ATHbA4A5>CLf>3U5>3H=<C<dAS0e@SPa>4Hc=T4b=4I3=C<h
<C0a>3P`@DHe=T8iA3M3=C0bAC96=S95A3I3<391>DI1>4@c@CLe3D4g@C54<C8e
=491AC52<T@eAT8a@S4dA356=34h<DE2<T@i=TA4<48f=TDgAC4d=S@hAD8g=CHd
=CPf<0dc>DE1@S<g<CHf>CTh@TH`<4<g>D8h=CHh=S91=S0i@dHe=c<i<3<b=C=5
A4@d@SE6=D4g=TE3<THa<34=ADI2<CDeACE2=DA5@C<h=dA3AS0b=CTf<SA4=D=4
>CI2<c0e@cM6>C@b<CDa<30f@c16=D<c<313=4I63C<b@T@eA44c=44c<d<i<DE6
<T@b=SE4ACLbAD56@DHi<TI6<3I2<3D`<SM5=cHf=D55AD=3@T<a>4I3=@diATHd
=D8f=d4i<S56A34f=D95<dI4<cI2@D8`ASM4A3M3A3PfACU6>3Dc<d8b@d8hACLi
@C8b@CM3@S0=>C8dA3M1=492@C8c>CHc=D4e<c4h>4I1@SPf=D4e=CE6<c8d<S0i
<DHf@S0i=c95=CLe@D@c>CE2@CE63CTc>3<i<dI3>3Tc=C14A3@c=d8h@C8c=TH`
=3<a>C12>D52>21>A0d_F38g820c<21BA20b=4E3@T@`=C=5@SHgAC<c=T51=3La
=3Hh@TI5>3Q5@dHd=cU1=SI4=c<`=c4f=3@h@C<a<CA6=cTbACDPCT@=;ePb>20P
<C0e8594838dAD=2A30e<dE2>CM2@DHdAD4f=d96@CE2<T8g=STf=495<c0c>C4i
<cA1<dHh>44iATHi<c@g=3@e<Pdb<S4f>C0g>D4g=D<eASDhAC96@cE6AT91@C14
<T4d=3@dASLf<DI4A4A5<cE6@TI5>C94@cHf=d@f<D8==CA6A3Df=3=2@SLd@DHg
<d92=cQ4@S56@S<cASI2<CI1@cP`AS@a@C4f>3Hb<34a<4@aAD@c@T4eACQ43CDh
>3@a@C@f=38a<3PgAD<d@dHi<d4e<c53<4<g=R1>A0d_F38i820a<3@PDT@P<SA5
@d94<3DcAD8i=d91ASA5@CHd>3<c<S<d<4=5@SA6>C<g@S0`<4I6=c<e<CI6<C4d
AS0h<4<h@d@g3DA4<CP`ACQ1<4=2<SDa<3Da<34e>C@d@CE6>C94<3HbASTe@SLg
=3PbASA4@DD`@T8i@D55=455<48h>@da>C<i<d8f@S8b=d92>4<i=48`AS11A314
=3Q4=D=3A3U3<4<`<cP`>C54<D@bACHh@c56>4@eAC4h@c8=>3Lh>DA4@C0gACM3
<3<`<T52=4A1<S<e>3Hb@R1>A0d_F391820g<B1BA20b=4E3@T@`=C=5@SU2>4A6
@dHc=SE3AD@i=SQ5A4De<dA2=3<aAS91>C=3<S4f<CU5=S4e<S12<cPe<D<=A48c
@S<d@cTf@SPh<c4c<TDd@cU4ATE4<C@d<T8g=C8gAC4d>44a@DHc=4@c>C4a@CDc
ACL`AC0d>3<e3DI3@S16<C@f@cM4=dH`=CHi>D91=d8PCT@=;ePb@R0P=3TPDT@P
<SA5@d94<3DcAD8h=cDc@d4dA3I6=dE4A44iA4H`@c=6<T@f@cDc>34`@c4a@cHb
=SLe<S4b@T<dA30c3CI3=S8`AC<c<C0f>CA2>D8d<S56>48cASQ4<C4h=d91@S11
=T@d84i43BmH<T<P83L`8594838dAD=2A30e<dE2=SM5<c<f@D4d=S@f@S<h@c<h
@C<f<cD`A4=3ATHgADHeA3LiA3I6<C4c@D96<3A3>0daA3M3@TA6=d<g<4=2@dI4
>38bATI3=CHi@c@a>4I3=3Pb@SHg<4DfA3Lf=c<g<dE3<C96A496<3Ti@c8==D4i
@c<bACM6@cLa=CHa<SQ2=D<PCT@=;ePbA20P<SHPDT@P<SA5@d94<3DcAD8i<SM5
@THg<TA4@SQ1A451>CQ3<c<b<c<a=3A5=DA4=T@c<cQ6A3I6=R1>A0d_F395820b
=b1BA20b=4E3@T@`=C=5@SHgAC<c=T51=3La=SLa>CLi=d4g@D8cA4A3=D@eACDi
<d51=cLb@DA5AT8PCT@=;ePbAR0P<c0PDT@P<SA5@d94<3DcAD8i>3Hh@d4d>DE5
AS=3AC<i<C13=30g<cPb@DA2@CPb=S56=C8h@CM6ASA1=TA3@SPg84i43BmH<c0P
834c=B1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THh<4I2<CPh<T@g>3Lb<STh>3Lc
@SE5AT<h<C96AT=2=cDe=c8g@cH=@C8a>4<`=S12<C<i=DE5<3Pg@dE1=34`=DHc
A3Ld<CQ1<3Pi=d@b@S4a=T<f@cPc=3A6=DHf=D55=cL`3DDb@d8`A3=4<SPiATHe
@TE3<C8a=STc<SHh@CTc<DHeACQ6A3PiA4@i=DA1=dA1=DA4<38f@CE3AT8b@@e2
A30f@d@g<dDe=dDf>4Hf<THh=S4i<S0d<CT`@SPh<D<b<S@fAD=6A44i@cA3=C0d
@CI2<S53AS@c>34=>D4f@S4b=cHg@c92<4Dc<C53=C93<THi@CU2<c<h84i43BmH
<c4P83<e8594838dAD=2A30e<dE2>3Le<d=1=4@fASPbASPe>CHd=d<h<C@h<cQ2
>4Dd>C8g=C0f<DA4ATHc=c8f@S@g>@daADDc=cI1A38d84i43BmH<c8P834e>21B
A20b=4E3@T@`=C=5@SPg=C=3@CA4=TE4<CU5>C<f<T@i=CTe<355@CLg=T95<4E1
@S4d>34h<TDc<D53AC0=@D4b<T8f@C96AD8g<44h=4Da@DI2<CA4=T@hAT94>48e
>3Da@T@f<D=4AC<h<3E3=3=4<SE4A30g@S0h3C@`@CPb=D4h>D=1=TDiAD8c<3T`
<38`>3A6>454@STd>3A5ATA2ACLd@TA6A3<a>3Dc@CM6@S<b@S4dAPdb>DDf>C<e
@C<b<d@a>C=1=TH`=DHg=SD`@SDbAT@i>492A3Dc=T8a=T8eAC<g<c@g=3U3<3@f
=DDbA3L=AC0c>D=3>3=5@SPg=TDh>C<g=4<g@SHe=TDg<S0aA48`AS4f<c8f<c0g
=CA5@TI1=DI5=SA6@cPa>3Hd3C52>3M2<c94>3U4=D<i<TDPCT@=;ePc<b0P<S<a
8594838dAD=2A30e<dE2>3Le<d=1=4@fASQ2@SQ5<T@g=48d<38`@C@h=DE2@S93
ACI3=c8h<D=5A34bADHe<`e4@c8f=dDh=44g>CTi>34b>C14<T4a@C=6AS<`@c4d
@cA1>3Tb=C4dA3TfA3Pd=c<i=SHc<SL`AD96=d8==c=6<3PdASU2<3A3<c0c=cI1
=dI2ASI6=DA5<3I4AD<i<c@h=DDe>4A2<4@g>3I5A3Q2=3<a<3U3@c163C15=C13
<4@f<c54<48aA34`AD8d=dDf@C@e@CI5A4I5=4HfA495=4Df=S@a>D=4A316@D4`
<TA5=c13<0dh>CM4A3@b=T<g<c8eA44c@cD`@T8i@c@g@CQ3>DDiATE6<4He=C<c
AD56>CT`=cTc>CQ6>3E1=CDeACD==D<g=SE4<cHi@cLg=SQ1=38dAT<f<d8bASE3
@T<g<CPg=d55<d<`<CQ5@ST`A4A3=311>C52<S0i<CDg3CHi>3M3ADI5=SDe=d91
A4A1<30d<cLb<d4aAD4i=48a<S<aACA2=DI5<3Lf<S8f>C=6<3M1<dI3AS<g<0e4
@T4i<dDe<cHa>C54@cHbA3I1@DDg@D<f=cHf<c=2A4Dd<4A6=3Db=c<PCT@=;ePc
=20P=S0PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=cQ6=cM5<4E3ATA6<T94@c4a
=STg=T8f<48hASM3<S=2=SA1AC=13D@h=cHb@d@eA4Hg<D4g<d=3=S<e@CDd<S4`
@D@`@C=3>DA3@c8b<cA3@CHa@DI2<4H`AT4bA44`@T<e=R1>A0d_F3<e820a<c8P
DT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6>4<f@DA4ACM3>C13@d<f@DE4=TI6<S4c
A34hASLc=3E4ACU2>C8e3CHh>3Hf>C96AC8d=495=38f>3@iATE1@cPf@SM4<T<d
AS91<cA1<S8b<SM1>4H`>C8d<SI4<C4iAS53@@e3<SD`AS<a@CP`@dA1<4H`<DE2
@dDg@cQ6@DE5@cTe=DDeA3Hd>D<i=34g=CTd=3Q6=C4h@d8e@DDf<C4==S<aA3Lg
@cLh@D4c>3<d@CHh>D8`A3Hd>3<cA3A5=c0h=T8f>3I2=T<g@C<a<T=6@c@cA3Dg
=SA6@dE53CLc>CQ5@dI6@T=3>3Th=S4b@D8h@T54<b1>A0d_F3<f820b<cHPDT@P
<SA5@d94<3DcAD8h=cDc@d4dA3I6>44f=c12<D52=c16<D<cA313A3@a>C4hA3Pg
@D<g=D91@SP`ASPd3CH`<30a=DI4>3U3<3<h@CQ2@S<d<34f=dHh<C53<c@e@SI1
A44`>CI5@C<i<dDi<d@d@TDb@c=2>3@f@@e5@THa=316@THdACTd<3<`=d93=S@a
@c55@SI1>3PeAS@a>CI6<C4i@D@c>30e@D@g@T8`>C0a>C@a=DD=@CLi>4A2=T<g
A34h<T91=4=6>3A6=38bASHb@c@e<CPa=C=4ACE6AS52>4Hc=c8f>C52<3Ld@D8b
<c@i3C<g=S0g=T=5ASDb<3Q6@DA2A491<S@h=4<g@TA3=C14=3Hg=SPa@SPd<DHb
@CL`ADD`AD@i<cTiASA5>@dg<4<b>DHe@DDd>CE4=cDf>3U1<4A5<CM6<cA6=D=2
=38e<c8d=cTf=S0cA4E5@THiA44d=SA3A3I4<T<=>DH`ACLgASHe=dHgA44dAC52
@TDi@dHa@dHc<CI6=CTh<S53AC4gAD=4=C=5A3Pg<T4i=4H`<D<eA3A13CE6<44c
A311=T95ASLf<38d<d@bAC0fA3@`>D@a<3Dg@T94@CU6A4@i=T51@c8hA3=3@cPP
CT@=;ePc=b0P>3HPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6>3A1=4Dg=TA5<4=1
<D4b=38d<THi=D@e<C4d=4Hg<3E6<34g<C923D8i@SQ5=4<d<3@eA3E6>CLiACPb
>4A6@T4a<cTgAD8f@CU4ATDc<D4h>CI2=dHh<SHa<C=3@CPcA34a@`e4=3Ti>CTf
@dDb=4Ha=cQ2@cDi<CPi@c<a=3=5=D8`=CQ4@dA3=DA2>D=5ASTf<4<g=C4e84i4
3BmH<cPP83<`=B1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THg=4D`ASPi>494<C0`
>30dACTd@DDf<cLb<SU4<3Hc@T95>CTi=DD=<SHe>4Di<SDd@cI4>D8`>34h=48d
@T<`=3Lc@cU4=C13<3Q3<C=6AC0g<DA2@T@cAT<a<CTf>44d<TD`3C0`<dH`AT96
@c54@cLh@dDc<3U6=DDi<dHi>44iACDeAS8c=D52<SA4@dHd=S<bACHb>D53>3E3
ADDc<0de@S<c=T@i@T<i<c14=c8c<dA2=CA6<453=S<a@SLi<4Dc@DI1AT8cAT<d
<4=5AS0a=38d<d@iAD4aA4D=<DDd<C0c<SPg<CI6>D53=D<g<SPe>392>CTd=cPi
@d4b=S4g=C55>DDaASP`AS=3<351ACQ2=T8g=cHf3D93=c<c=d<fAT<h@S4`<T<i
@S@e<cDeA493=dH`<cLhASI1=c8a>C<g@c96<D=4@T4g=S8e=3Df=SDiAPdb>4<c
<T<g<S51@CPe@dHe=DHi@DDh@T=3=34f<DI1=3Pf<34a@cHcAC0d=CThAC8h@dHc
>3@b<C0a=dD==d<`=cU1A44a=S12ADHc@cPf<TDcA353<4HaA3<h>3A4@cHf<CI5
@S0`>3Q3@S8d=TDa=T<a=CQ5=48i3DE5<CE1A3DeAC@h<cTe=SPc<4Hb>C@gADA3
ATI2>CM6<3Th>4He<3DcA4Dh@TE4@C<`=c12@T4h<T<fA@da<4A4AT=5<DA5<SPc
=3E1>D@a=d@d>C4h=C91AD8cA4HfA3<e<4I5=TE4>44gA3@d=c55ACDdAS0g<CT=
=3Hg=3U3@D8e=21>A0d_F3<i820b<cHPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6
=cHd=4@b@D8d@T8h>CLg@TDbA3I3>4HhAC0e=44i@d<i<d<f>C543CTg@S0f<CHg
=D4f>354=D@`A34eACLa=cU3@SPh=CM3ADI2=3M3=S95ADDe>CHc>D8d>CLc<dA3
>453<0df=d8g>3Tg<cDi@dHi=3Hc<cU4>DE6@CDhASLd<3M1=4Hd@SLb=SA1<cHf
AT=3@cLi@d@d>DA2=CPh<d<==D<e<T@c>C0d=3<`AS0eAC<g<4=3=C@a=dI3@DDc
@D8h<4<a=c4b<CPg=3Pa@D4d=S4c=SPb>C15A3Hd3C4b@dA1A30h<3Hc>44iA3<d
@cE1<DHbA3H`=cPi<C0c=T=5=SPeAC=6=4I2=S96ADA5=48`ATI6A3DhAPda=T8d
ASLhA312=C8c@S92<C8e<3@b@CTiACHgA3Hg=TDiA3LhA30a=c<b<CTgA44i@dE4
=C4bASHa>4H=A3Lc<393<4=4AT4c>DDc@SM3>393<311>38c=SHi=T@i=dA4A48`
<3PcA30b>34b<4@e<c8c=S@g<THh3CQ3<DE6@SU2<c<cATE2<D<g=SLi<S94=4Hg
=S8c=CLf<SDb<DI6<SQ1<CDe<D51@d=4@c@PCT@=;ePc@B0P=3<PDT@P<SA5@d94
<3DcAD8f=dDc<cI1@C@g<CHg<CTg>CM1=d52<dA4@cE4=DDe>C=1@CLg<T54AC14
<CDd<d<`3DHa@c91<4@hACDd=d8e>4Hc<C0`<4=5A3Lg84i43BmH<d8P83Ph8594
838dAD=2A30e<dE2=SM5<c<f@D4d=S@f@S<h@c<h@C<f<cD`A4=3ATHgADHeA3Li
A3I6<C4c@D96<3A3>0daA3M3@TA6=d<g<4=2@dI4>38bATI3=CHi@c@a>4I3=3Pb
@SHg<4DfA3Lf=c<g<dE3<C96A496<3Ti@c8==D4i@c<bACM6@cLa=CHa<SQ2@CDe
@THg=3U4AC4b=C4i=S@d@S4h=DHg=C4iAT94=TA5=3Hc=44PCT@=;ePc@b0P=34P
DT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=dE4A3E6@T8i<C4a=c4a<CTf<3D`<d8h
>C56=CI1A4@g=DHa<ST`3C<`<D91=STfA3DgADHa<38bACU3=DHPCT@=;ePcA20P
=34PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=dE4A3De<4A6>CTaASLg<cI4>CHb
>3<eAD4i=C8b<3H`=S0`<4@f3C0h<cM2@CU1@S<h>391>CI3@SDa<D4PCT@=;ePc
AB0P<cPPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I3=cM4<3Pa=S0e<TDdASP`<SU3
=C@g<3U6@d=1=d8i<3A4@dDc=D@e3D<aASLbAS8i@CTb<T@a<CHPCT@=;ePcAR0P
<CLc8594838dAD=2A30e<dE2>DDd=30a<SDg>DA3ACU6=TDfADA5=cQ1=CI5<DHc
<c93=3I1<TA6@S0dA4A6=cI1@@daA396@dA2@c4d=c0b>CE6>C8h<3La<D56A30g
@D55<44d@TE5=TDa>C<i=S8i@CTd=DE1@S55AC<g=CT=<D51=c4a<c@g>3Le@dHe
<TE4<4He@C0gAD95@SE5A4<g<D8e=D96=CPaA4Ha=4A6=DHd<d8`>391<S8g3DHd
@d4f@c4f=d=3>CDgA4DbAS0f<C0fASTb<T<d@T8c>44g@SE3=CM5=S0`=cDdACQ4
<44d=c@a@d96>@da=314ATHeAC92<SHfAD94=T@hA3<c@D53AD<b@SLiACM1AC=1
=DA4<356ASTfA48i=38c>D4c@d94=ST=@c<d<C8`A44`=3Q5>DA5AC8i@SLhA44`
<dA4<T@i<dHi=T@d@d8h=3A6=TD`<21>A0d_F3@`820c=3TPDT@P<SA5@d94<3Dc
AD8h@C51<D4a@STeAS52<3D`>CPf@dA1<34`AD<g=3@e<cU1>4I2=3=6<cU1>354
@D913C8dATI4@c@`AT4fA3Pf<cPf=3A6<TE4<c8f>4HgAD4c<SE5A3<`=S=2>D8f
AC@`<3Di@S=5<493>4<d>@df=T4i>3=4>DA4ACQ1<C8h<C<e<cU1<48i@S0e@TDh
=c95<cA5ASHhA3Q5<c8bATHc=DDb@SPa@C0g@TH=AS<d<CA4=T52=T<g=dDh@C8a
>3Td@CM4=d@d<CE2@cHe@S@`<4Df<SU5=3TgAS95=38fA4DeASM4>3A53CQ6ACDc
>4I1<4<a=C@eAT4e<C0b=3LbAT54@TI5>3Lf@SPg=SDf>4I6<30h=3=2=C0i=C<b
@STgASU4A0e4AC8c<cI5=TI3>CM3<T@e@CL`@c<f<c8a>D@d<3<g=D4a>DA5@CTd
=CLeAD8b=S@c@DA2<3=2=DA1=S0=<T8hAT@c<S=6<4E2@c0i@T51<c@g=DA3@c<h
<3Pf>3<g@CM5ACE3=48h@SA6<d91>D8cAS<i>4@b@D8i3CU1=T8f<CU1ADE5@C8g
<SM3=d51=dE2@d93AS53ACM3>D<b<3M5A4=6=c0h=cU4=D=6>D54=C0`>3E6=0e6
@c<gAT52=3M3<SPh@THh@DDaADDi<cM4=44g<4<f<30f=dA5@d8gAD8f@C4`A4Hd
>3Di<T=1<T<d<3L=AS8f<dA1<CU2=C0f=S0f@C11=d4b>4Hd<TA4<TE6@CE3<4E2
A3<cA3<`>C11@cA5=493>48f=dE2A44h3D93<S0c@SQ6@CLf@CLe<SI6<cE5<3Q6
=C@b=48i=cU1<cLa<dE6>C55AD8i<SM2<CTb=4Di@D54=4E5@Pe2A3@e<44bACPf
=4Dc>3A3>3@d<cDgASDcAT@e=SM5=3Lh<D4`@b1>A0d_F3@a820f<21BA20b=4E3
@T@`=C=5@SPc<CDa>C55AS0i<C<e=DDf<c4iA3=6>C4a<3Df<D=5=44b@THh=THg
=d@g<D8a@C<=002Q0<0oocTcASE5<CA5A3I3=d<c@cM3<S8i@C<gATA5<c@g>48c
@d8b@c4`=dI6<cLb@CE3=3<f<cPb<C8`<cHf=B1>A0d_F3@b820a>C4PDT@P<SA5
@d94<3DcAD8h=44h>30c>3@g@DHf@C4a=SHf<4Hg@C@h=SDgAD8h<T8b<3Da@DDe
<CHgA44bAT4b3C=3ATA1>4A5=SDa>D8f@c51>CPi=C4a@cDgAD=1<SI6=cTd=dI2
=d<b=dE2ASDg=cQ6>C8b@cD`ACDh<Pe3>4@h<CLh>3Hh@C4b<44c>DHa>3=2=S8a
@cPf=3A6@SI5>D4a@C0h=STaAD4i<C93=C<iAS<eA3Th@ST=<3E2=SH`@CI2@C<d
<c@g=44i>CM2@STg@d=2ACLg<dHc>CPh>38f=D54ACPaAD@i=3Lg=S0f=T4e<C8`
3C54<4Hb<SI6=S<hA44e=d@h@cQ6A3Da=CTf@cI5ACM2<c=4=44g<D@a@D<dAD<b
=S4cADD`>CQ6ASA4>@di<4E1>D=3@D=3<S8gACE3<S0i=30i>DDc@S54>CLg@c4`
@S@d@D<g<c96@DHgAS8e<cM6<T96A4<c@d@=<S<b=CTf>CTd=CPd@CQ6@dI1<C<c
=B1>A0d_F3@c820a=S@PDT@P<SA5@d94<3DcAD8h=3Dg<44b<3U6=TE2=dDh=C0g
>CA4@TA2>3=2@S<b<DE4AT@h>4<d=DHa<3=5@DE43C94@C8`@S<e=CPb<3Hf>CQ1
=CM3=D8c<4E4>48c@cI1=cU2<491<c<f=4<f<dHa<cPc=DDf<CQ5<S4h<Pdg<4He
A3U2<c15ASLdADI4=c<e@T@b@dI2=SPc=C91=DA4=SPbA30`@DI1>CA6ADDd@C4h
=DHdACU2@c8=@CE6<DA6<CTa@c0a@c54=CI3A4HgAT@h@CLb=3M5@C0c<c=6>4E1
=3@e<d4h=4Hc<4Df=CDg>44b>3I63CI4<cDi>3E6>3Pc=44i@SQ6@T95<SU5>CPd
<c4e>48i@c96<d55<D8`<cPfAD8g>3M4@SQ4>3U4@SM4<Pe5A3Lc>D@`@THh@c0i
<CPb>4DcA4I6@C<a<THf84i43BmH=3@P834b<21BA20b=4E3@T@`=C=5@SP`@T8e
=D56@SPd=CTd=DA4=CLi@T8a<cA3<C96<34bAC0aASLf<DI1@CLi=S8dAT4==D56
=3Q1>355AD<b>4Db<356<c51ADHg@S@g=dE2AD<i=c=3<c@bA3Hf=SPbAS0hACDc
<THi=D=4@SU23D8e=dDg<D=4>3Li>D8h=D@c@S4f<CTgACE4ATI1<38bAS<d<D52
<C<i>3Pa@cU3<S=3<THhAT4gA4A6<Pda@TDhACH`=DDc>DDf@SHb=SLa=c0d=d8h
=d8e=3<f=cLg<D@eA4I5<DE5<DA1<CHf>4@c>3Pb@DA5AT8PCT@=;ePd=B0P=3LP
DT@P<SA5@d94<3DcAD8iAT=1@C0g<CDdASU2@S0`A3U5<D8d@c13A394=S0a=4A6
=3=4>C=3<4Hc<D=6=38b3DA2@S0h<S4b<d4g<30h>3M5ATE5<DHf=4E6=C92@CU4
<48PCT@=;ePd=R0P=34PDT@P<SA5@d94<3DcAD8i>CDi=38e>C@a=T<d@CL`ATHd
=4Dd@C8b@CE5AS<`A44g@SI1A4A2=S8i<d8c=C143C<f<4He<3Q3ADA5<cLf<STa
A3@`@SDPCT@=;ePd=b0P<CHb8594838dAD=2A30e<dE2>3I3AC8a=c51@CTc@CDg
=C54<CHi<SLf>48e=d92<S16<c0b@S0f>4E4>CLa>C0i=@dcA34a=C96>4HbA3T`
>CHa=cPdAD91<SHf=T4f<S95=C@cA3Da=dE1=cLa=TA2<d<f<STf<CHc@c<d=D4=
>D@f>48b=TA1A3Q2=c13>3A4=3H`>4A2=DI2ACE2=3E5@d<`>34h=3Tf<34c=c0h
=D4d=S96<4Hh=3U33C=1@d54=S8g@D4a<48dAD8d>3<e=3Td>DHiAD4cA3Hb<3Lb
>496<d<a=cU4=c@b>3<e<cLh<48g<c@`<0di@cLhA3Pf>D8e@cQ6<c=5=d4i<dHh
<CTdAT@`>C@g<S<a<38h>CPb=SLfAS@f@D@h>4@d=DA6ASHc>D8=>CPgA30b@STf
>CThAT94>C0`>D93=SI484i43BmH=3PP83@g8594838dAD=2A30e<dE2>356A3@f
@S0e=cE4>3@g=d@c=d@c=D@c>4@`=C@a@SDiATD`=c4bAS8bAD@f<CU2@@d`<S91
<c4g=c@c=34d<D8i<C11=3Ld@dHg@SDfA3Lf<dDd84i43BmH=3TP838e8594838d
AD=2A30e<dE2=S=2<cDiADDd=30c<48i>44g<C16<C0g@T<f>44c=TDb<4E1=CTb
84i43BmH=44P834`=b1BA20b=4E3@T@`=C=5@SU1>4Df@cQ6ADHa=SLc@S93<3E5
=C<c>D8c=4A3<T8a=c<d=C=4AD4g<3LbACQ1ACT=<dE3=314@DE6<THd<d4d=d<i
<S12>3Lh>4Hf<cL`<494<cU4=S<g=cM2>CHc>30`=cHe=3Lc=C@b@cA23CQ1=38d
@cM5<d53<3A4<cLhAS52<T=6AC@c>3M2A4Di<3M5>DI5AS8e=D96=3LgACE5<S91
@cU2>C<c<0dd@D93<453<3U4=34bA3I5=c8cA4Hg@cM5<CQ3<3Q4<S5484i43BmH
=48P83Dd8594838dAD=2A30e<dE2>3LaASDg>D4a@S8c@D8e@D4b=C56>44h=cU2
>395=TDb=c4b=D8`>CDd=4I6@D@c>@ddASM3@D54<C14@S0h=S8i@d8c=3Td@CQ2
ATDg<34a>30d@THa<d8dA452A48b@S<PCT@=;ePd@b0P<c0PDT@P<SA5@d94<3Dc
AD8iAS<f>3I4=3Lh=SHe=CHf=cA4>DDa=3M6@c4aA3He>313=SU4=DH`=T4gAC11
>34d84i43BmH=4@P83Lg8594838dAD=2A30e<dE2>4HbAS4`@c4f=c56@CLb@DDb
@SA4>D8g@c<i<DDc>3LcA3Q1<S0f@D@h=c@a=d4fAPd`<D93=TI4AT4d=c=3<CI1
@DHc>3Li=4@g=48f=C=5@dE3<dHd@DA5<S0f=SE5@cM1=cM5<C8h<d8g=D<=<DE6
<d<f=CE2ACLc<SPf<3Ha<d91=cU2<30`>C4c>C4i<21>A0d_F3A5820e=b1BA20b
=4E3@T@`=C=5@SP`<SM2<CDc@C8h@S51@d91<DDdAT8d<dI1=c54>CDg<4<h@d93
AC=5<TDf>38`>4D=<SHe<C52AD@c=D<dAT@`A3Lh@S8`ACQ1<d8d<dHe=T8c=dDf
<3Pa=cHd<S<d<3E4=4@g>48e84i43BmH=4HP834c=B1BA20b=4E3@T@`=C=5@SPb
>DDd=3A2<3DiASTe@C54=356AD<`=DE1<S91@C4iA3<d@SE1<48c@cM5<S0`<C8=
A38a@cLa@CPi@T96<STb=cPh@c<h<SLgASLb@CA6<DE6>4He<30a=DHg=C4`<DE6
<THi@CPhA4@`<D@i3DE1@CTaAD4b@TE2=c16<SQ1=S94=4Dh<C4a<cPa@d4g>CM3
=S0f>4@g>48`=c=1>CI1=3E5@C@e=c4c@Pe4=48d<3A2@T=3AD52<SHd=3Td=CI5
<c<b>D<f<CPb@TE5=3I5<d8g<dHd<dD`>D8`=C<a@DE5=3=1A3L==DDg<c0d>4I1
<S52<THb=c8`@C4b>3Td=SPf<cHc84i43BmH=C0P834`<b1BA20b=4E3@T@`=C=5
@SU6<cHh=T@d=d4b<cT`AD@`ASPe@d@f=cHhAS0d<S93ADE4A3Q2<D=1>DHe@d@e
<C<=<34f@S@h@CU5=CI3>DDh=d=1AC16A44c=TE1A48i>4HgAC<`>CPe>CM2=c@c
>34b<SLaA3@e>4<a=THh3C4i@CA4ACDf=S@e<SDdAC0`=C0e=SE5=SLa<c12=SHd
<SD`=d4i@C0e@STd<c8h@cTh>CLc>CI6A3@aAPdd@dI5=3E2<D<i=cLe@c8g@c<g
<CDh<C11@R1>A0d_F3Da820a>C4PDT@P<SA5@d94<3DcAD8h<SU5=3@d@S0e>DI5
=3@e@SI4<48`=cLcAD4h=S=3=SA4>3Dg>3=5A396=c8f<S0e3CTc=C51=dE1<cDg
<CTcAS0e@S92<DDcA3Q1@SLb@T@e<4@c@cTeA3Hc=c92>38b=SE1>CA1<c<dA3<b
A0e3>CPi@SE3@c0g<T4g>3M3<CTiA48i>3Hg<S@d<cTb>3@i=C@b=cU3=CH`A393
@C4eAD=5@CE6A3Tg=c<=>4@h>4A2<SHc<c<g<3Q1>3@`AS8d<4A4=TA5ATE3@c0b
ACU1=CTh<D53=3@b<D52AT@d@DA4<SQ6=3=23D8d<4=5>D=5<dI1=C=5>C94<48g
<C<e@C<`@d<d>C92AS8c=4A6@DE1AT8`=c8a=S0fA4A1<cU5>3<bAPdc=CQ4ADE5
ASHfA3D`<d=2=c93=D@h<TI3<CPcA4<c=CQ4>3Ti=T@`<C@c<cPi>CQ6A3M6=DI1
=S91AT@=@c91@d4f@D51@cHiAS8c=S8c@SLg=R1>A0d_F3Db820a=S<PDT@P<SA5
@d94<3DcAD8iA44c<38a=38c<SI4<dA3A44i@DDc=CDdAS4`=S54<3I2>38`<DI1
<c0f=3E3AS<h3C0eAT94A3LgAD4aA396@cI4>D56AD8e@DHd@TDc@d@h=S0`AT4g
<D96@cA6<496<S55@c8cASDa>D<a<@e4A4I3@cTc>4=5=S4b=c<f<C4g=T=1@CU3
>D8e<SU1A48f@CA2@cLa=STd<D<a>3Lc<30c<d51>493=S0=>44b>C8fA48h>CTi
=CU5<TI1ACU4@DHh<C0g@SQ1<S4cA3Hb@D@h=T96<D51@C92=D95@S0d=48f>30c
3C<b=d=6<CDb<c12<S<f=T4h@S51ASM1<34c<4I1<CPg<c4i@TE3A30g<SHb@C93
<SDf<S4c=dE1AT4iA@e3AS0c<T@e>34`=cU2A44`=C96=DE3<S=4AB1>A0d_F3Dc
820b<cLPDT@P<SA5@d94<3DcAD8iA44c<38a=38`=DI4<D53ADA6=c14@CA3ACHe
>3@h@S<i=T<c=SU3AC0e>C@a@d8d3D=3@C4eAT@c=316=SQ6>4I6>4E6<ST`<C0g
AC0b>CE2@cQ1@D4c=T53@THh=T<i=SHg@SPi=S<`<CDd@@db<DHb=THi<T<`>4Da
ACPi<cLf<S96=C<d@C12<TE4=cE1<3M5>C12<3Lg>48aA3He=DA2=S0g@cHa@c8=
ACA2>CE2<d93<cHa@C13<c8cAD<b<S4a@CA4=S<d=S95@dE6@d@b<c@cASM2<34c
@SP`@CU2A3@g<3Pd3C8b<c@h@c4a@c4f>C@eA3L`=d<`@S14A3Te<DDd<SLb<DDe
=D4i=S4h<3@h<4Di=3Le@SU1>3Hc>D=4>0e3A4@g<DI3<cHg<TDh<394>CE3>4=6
ACD`@T@`>391<c92@DDg<C=2ACU5@S56=D8h@dHb=3Q1>C<f@T8=>4<h>48h=DE1
=SA1@C<g=3I1<c<hA3Hh@DI6<C@a=dI1<SPc@c0a=4E6@TI4<493<SQ5ASLd>494
<4H`3D52<SDc<C8i<SU4AD56A3U2@T8e@cPb<48g@cT`>CH`@CDd=cHe=SM5@CLf
A44h@TE5=d8eAR1>A0d_F3Dd820c=R1BA20b=4E3@T@`=C=5@SPdAD8b=3@e<T4`
<38c<CPe>3D`<C<i<d8e<3L`<TI4<c<c=cLb>3Lf@CM5>C4i=3H=ASTh=351@c@b
@CDe84i43BmH=CDP834a=R1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=T<g>C8e<c8c
=DE6=3<g<T@b<C11<DDcAC0h=SI4>4=2A3Tb<3D`ASP=<TH`@S55=TA1<3Le=TE3
>4H`<T4`>38i=3Ph@D@a=4I2=d4fAT4i=c@d=d<e@S4a@d56=352<3Ld=S4d3D92
=4I5<D91ATHh=SDc@D@d>30e@TD`@C8f@c55@C12AT<`A34h=44iA4I5@cPeA4@g
>D@gAD@b<30e=Pdi@S8e@d4bA3E4<SM3@DA6=S4g=S15<cU4<DDd<D=3A44i=cTa
>44e@SE1AC@g>CDe@THc84i43BmH=CHP83@c8594838dAD=2A30e<dE2>3<a=C4i
<DE6<3E3@T4c=3A3<T@i=c0d<T4`<cTc@c8b>CLd<CP`@CT`>3Le@CLa>0dh<CDh
<C4iA3E2A30h<T8eA4@gAT4h=d4fAB1>A0d_F3Dg820h>B1BA20b=4E3@T@`=C=5
@T8h<SLaAS8c>C4g<3@`=4Dg@STf>491AT=3A3M6ACTd@C16<C8g<DDh=30`<3Le
@d8=A3@i@S0d>CA2=S95=SE3=CA5<3<bAC51=456<4=2@S14@DI5AS0a=T93AC<h
<CM4<STh@SDc>30i<d<a3D56>C8e@c<a>C96<3Pg@C0b@TH`ACHe<cLf>D8g@SLb
<SU6@d<cA4D`@C8f@SPb@d91<d8d>3<i@c8PCT@=;ePe>20P=S@PDT@P<SA5@d94
<3DcAD8iA4Dg@S0f@CPg=T4e<d=2=CTe<CE2A4HdAC8h@d@i=T8iAC52=dDh=SHd
<T53@dDg3D@f@S14@c8i@STa<STd=cDg<D<b@cI2=d52=D8i=3A4ACHa=38h@c=6
=d8d<cU1<c55=THg<CTe@d51A@d`@TDa<CPi<b1>A0d_F3Di820d>21BA20b=4E3
@T@`=C=5@SU4ACM2<3I1>3Lf=CE2AC13@T8d<CLi<CA4<C0iA4E4ACPi=T91<4I5
@T=3@c=2=C@=>3Tc@THa<d8`>4Hf>3H`@SPh=3Ta@T8h=d53=44fA3E6A3Db84i4
3BmH=D4P83@f8594838dAD=2A30e<dE2>DI3@D4`=c4e=SA4@C8f<THa=34`AT=6
ACPd<T51AD<c=d@i<4Hb=4<c>34f@S92=`e1=dA2<352>C@i=CLh>3Q4<CPc>C14
=3<d<4E5ADA3@B1>A0d_F3E2820c>21BA20b=4E3@T@`=C=5@STg@T56=4E1=SLd
@TI6=c=4@SPa<d53@cTh<cQ3<3Da=cDa@DHg@DDaACLc@T=1<c8=<D=6=DA3>453
ACPg<D<c>B1>A0d_F3E3820c<B1BA20b=4E3@T@`=C=5@STh=SQ3@C@iADE6<d<f
ACQ4=cU6@C4f@cPc>CLg>C<c=4A4@TE1=DHb<STe=d92AC<==S4PCT@=;ePeA20P
<cPPDT@P<SA5@d94<3DcAD8i=d91ASA5@CHf<C0h@T4`<3I5=c<d<dDc<D@i>4Df
<D@c=D@h>3<`=D4f>3A6<CE43C0c=S=1<30d=D=6=CLd>DHPCT@=;ePeAB0P=34P
DT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=dE4A44cACE6AT=5>316<SU2<4E5@d8g
@d4a=TI2ASU5<CE1<38h3D<f=44g@C<h<4Hf<44b=S8b=d4f@CHPCT@=;ePeAR0P
<SDPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I1=TH`@CPd>48c<cI6<cHiA351<c0h
=3U4=STb<cPPCT@=;ePf<20P<c4PDT@P<SA5@d94<3DcAD8i@d8b>CLb@d8`=SHi
>4E6@C8e<4I1=S0c<3<g=TI5ADHh<cTeA4E1AS@c@cHi<cTb3CLg84i43BmH=S4P
838c<B1BA20b=4E3@T@`=C=5@STi=CTd<SDi=3=4=STi<SLb=4@i>D8d=D=3>D@a
@S<g>CL`>3<d<3<a=30cAD8eACH==c<h<S55AS16>4E2ASE1<dHe>CU2<STeAC4h
@cTh<S0i>DA2<S8g>4=2<4=6>48h<T4f<3DeACI3>4D`3C8`=d4b<S52@CPdA3Th
@dHeA395<3@hASPi<4E1A44h<T8c=C52=c4`=cLg@C=1@S@f@S<`ASLg<d<c@@de
@C96=S8e<CI1=cHa<d<h>44g@cU2=T<`A44b<TA3<CM6@dDb<30dA3Q2>C8a>48e
<STh>496<SDaACP==3@f=4Di@SM3=C4aA3@`AS15<4<d<C4d<SPc<SLe<T96@cPi
>3PiA394<cHhAS8e<3=4<c4b=TI6>3U63CTi<491>CA6=352=4<c>3M2<CPaACDh
>CHe<38i=d=1@d@b=3@`ADHh>C@iA3I6=495>CA5AS0b<TI6=@dd@CHbA3I5<c@g
@d@c@SD`ATHd<c92AC@i@TDd>3=3AS4e>454=DI3ASHc<T4g<dI4<cQ2AT=1<4=3
AT@=@S<aA48e<CLb<D94@CPiACLfAD<g=D53@c8d@dHb=CM3@STgASI1AD8f84i4
3BmH=S8P838`<B1BA20b=4E3@T@`=C=5@SU4ACM2<3I1>3Lf>4A3=SI6@D55=3Lc
@CE1=c=2@SE4A3Dh>CPh<c56@C93<C8h<cD=@S4gAT55<cPa<496<30b=3@b=SDe
@C@dATDd@S56<D8`<S<fACPcA3Pb<3@b@D<dASM2<D8f=DA1<T@c3CTf<3M1<C@d
@CI6<SDa@dH`=DDe<454<d=5<c@gA316>C0`@cM2<S8h@c54=S8`ATHf=SQ3@T54
=D4`A0db<C@b<34`>C<`>3U5=311A34`=TA6>D53=3Tg>4Hg<cPb<S=3ASM4<SHi
=C<e>D92@THb@C@`<D@cACD=@CDb@dHg>CDb=SM3=30gAD95<SE2AC8e=T4i<T<a
<4<i<D<c=SLfACQ6<3La@cTd<cD`>38c>DHf@cI33DA6@ST`@SDb>C<hA3DcASE6
>DE1=C=1@SE3@CQ4<cE2@CI2=4@fAS4e<44dA3T`ASA4<D8f@C8i@c@c=Pdg<3E2
@CThATHiA30bA3D`<d@f@C<b@c51@c8fAT@`=cM5@CHa=SHc<4HPCT@=;ePf<b0P
<CDe8594838dAD=2A30e<dE2>CU4<311<C<f=D=6=3M4=SI5<cU4@S4g>C4i@dE3
=CT`AD4h=CDi<44c=C8g=D8i>0dd>3De<SE1@d8c@S@d=S0a=S96<3Df<c0i@D=2
@d95A3DhA3DgATA5<SH`>3L`ADE5@cHcAT=3<DE2=DD==SLb@TE4<cH`A44dA3E4
=3L`=C8g=D@`<44a>DI6@cThACM6@c93=cDi<CQ6=dA2AD93=3=6AS@cACPa3CLg
<3Df=3@e<4@g=DA5AD8e>D4h@D53>CTh>D<aACU5<d54=44h<CPd=T51>D4b<DDi
=4A2AT4c=SHdAPdh<dDa<D8`AT=5<cLe@T<h=d@f<c0hADDg>3LcASU2=c@i<D=6
=DA3>CTb>492<44c@cTa<c<d<dI5AC@=<CLhAD4f>3<f=b1>A0d_F3Hd820a=c<P
DT@P<SA5@d94<3DcAD8i@cHa<C4aAD52=c@g=dI4ATI1=3Pc=c4aA3E3@CM2<CPf
=3He<D@d<SPc@CPe<d4a3DE3<c8c=S95>DDa=DHi<c15@SPf@CPh=S4i<DDg>D<`
<DI4=48b>DHb>C=4ASQ6AS0d@C4fA48dATE1>0dd@S12>DA1>44e@T=4@C4b<C@b
@SDg<CHf@C<i>C=5>C=5=T54=353>CHe<30e<44g<SDa<d@`>CM1A4D==dDc<D8b
@THh@SPiAD53=CTi>D4d<D@c<SE4>DA3=C@b@cDb=SDdASI5<cTaA3D`@TA5=D8b
>DHb<44h3CDdAT@`@C=5>DHb<4D`ACTd=3TgA3Th<d8b<393=CU4=SPa@c<f=D52
>3I3<C<iA3@e<SI4>4I4@DDh<Pda=cI6=TDh@C0`<451<SHi@T4c@S51>DE5@c0e
<DHe=c@cA3L`<34`=3<iA3Pf84i43BmH=SDP834g<R1BA20b=4E3@T@`=C=5@SU6
@d51<3La=CHd<d=1AD8h<cTh=3@e=3HdA3Pd=48a@C95AC@e=DA6=T@cAC8d=c<=
<cDb=STc@S8e<38f>D@f=cDb>DDd<d<`<34b=D@iAC@c@SHd@dE6A3<e<dE5>392
<TDa>3Pf=CLhASM33D@g<d<cACDe=TI1=4=5<SHe<355<T<`=CTd=3E1AS14<DA5
ACM1>CD`<CQ6AD<hA4Hg@c=2AC0e=dHg<0dd@dI4=4<`=30c=CPe@STe>38`@dDc
ADHi<3<i<T4`>CU6AT8fADA1>CQ6=d@fAC4`A392=3Dd<314>34=>3I2<DDh>3Te
=cHa<THa>3Ld<CLc@C14>4Di<c4h=48c@SI3A3Da>DE1ADI3=cLd<cA5ACDi=D@f
<dI33CLi<D55>44i@c<d<TA5@S<i<cT`<353>CU6@SLd@DA3=SHg=dHd>D51A3U3
84i43BmH=SHP83Pe8594838dAD=2A30e<dE2>C<b@cPfA3HbACDfACM6<4Hf=3M1
A4<`@CPe<SA5A3M3AC=6<D4g<S=5=30i=48e<Pe3ASLb=DI2<cU1@T8`=DDiAS4c
AD=5=c<a@SHb<D<hA4=5=3De@cTf@c52@S12AT51>3<`=3I5=D<f>48=A44g=CPb
@d<g=D8e>3Q2A3Q4>CHc<TDa=cHc=DHe=S4g@S@c@D51=SU2@CI1=dI5=34PCT@=
;ePf=b0P<S@`8594838dAD=2A30e<dE2>DA5=d8`=T4h=cTeACA5ATE5=c4a=CLd
@S8c<SPi=d<b=4@g=D94>48i@C@a@c0g@`di<SU5<c11A352<cPa<TDb=cPh=48i
<c=5AD4`<TDg=d95>CE2@STfASTeATHf@CLc=SHe=3Ti>DHh>D4=<d<g>3<a<C4d
@D<e<C0c<3Tb>CU4@d53=C8i@D4b>3LaAC=3<SP`>4Hc<DI1@SLf<SE1<c8d=44e
=C0`3CHbA4@i@C=4AS13=S@h@dE6<c4a@S4g@cTf<C4aAS@b<D8f>4@e<C=3=34b
<c51=4=3A3Lf@D8d=4<dA@e1<d@e>4E3=THa@C<e=3D`=SU6<3U3=3Q1<T93=SLb
>DDiAT55A4<b<3Hf>CPg=D@`<d4`>356>3=4=4H==c54<4=2A3<h<DHh=d8c@SU3
<4E6<C92@cDc<S4aA30i=CTa<SDa@c51@T<g<SM3@SI6=SI4A4Hb=d553C95>CPf
<CA1<dHf<cT`<THf<D8c@C4g@dE4>CE6<S@d<cTg=3Th@S=5<34`<c<`=SH`AD4d
@T8i<3U6<`e1<CTb=3U6A38h>D<cAD91=DE6<c4c@c=2ACU1>C91<CHf@D8f>CTc
>356A3Tb<3I6=DDg@CLhAS8h<C@PCT@=;ePf>20P<C8`8594838dAD=2A30e<dE2
>DHc=SPfA3@g@C8c<4<`<S95A3HhA4=1>D@i@D8c=TD`@CLb@S4g=S@f<4Dh>DH`
=@de=STf<44`=S<d<T8i=dHe=c0d>3Df=T4`A3M2A3=4>44c>C15<CQ1<4=4<34h
>4A4ACQ2>CL`@cP`@TD==CPi<DE6<SLb>D=1<DE3<3M4@C4d=dHi<495<SM6<3Da
=cT`>C92<C0d@d95=C94>352ASDeACTcAT<f3DA1@c0`AS4eACDe@DHdACLe=S<g
<3A2>34h=c8i@T@`<T@c@D51A3Pa@d8g>CHc=DE5=DA3AT93@T<fA21>A0d_F3Hi
820c>21BA20b=4E3@T@`=C=5@SI3<S55=d@f@c@i@S4`=c4i=T56AD8h=4<c@S4i
<d<i=cL`<4<a=DE1<d4d=494A4<=A4<e@CTe@c<h>CLd>C93@R1>A0d_F3I1820i
<B1BA20b=4E3@T@`=C=5@SHa=CTi=3L`AT4`=3Lf<T@f<d52<CDd=SM4=S8iA4E5
<3M2<C<i@T8h=c=2>CE4=S0=>CM6@CT`=S4f=C@b>D53<SA1A493=CT`@DDa>3Hf
<T4hATA4AC=2<d@a<TA6=3A5=THb<S=5AD8d=c0g3DE6<S51=C@e@D51=4=5>4@d
@c4d<CA1A4E1AC@e@S96@S8i=3@cA4@a=4E6A4@d<d=2=44d>DA4<3M4<`e5=21>
A0d_F3I2820e<b1BA20b=4E3@T@`=C=5@STh=SQ3@C@iADE6<3Db@T@fA3<i=4I1
@d4`<dA2=cHb<3U2>CM6ASDcA4@e<S<eAD8=ADE4@CLe<CM3<34c@dDf>3LfAC8c
A48d=S4i>C8d>CTe=dHf<cQ1A3M4<3TfAB1>A0d_F3I3820b=B1BA20b=4E3@T@`
=C=5@SI3<S55=d@f@cI4=SM1>4He=SI6=CPc<d94@cLi=S4i<C96@CDeA21>A0d_
F3I4820b<C4PDT@P<SA5@d94<3DcAD92A3L`@THe<T8i<CLi>4E3<4E1AS<g<4E4
>D=6=TDhA312=D@c<CTa@T=5AS<b=DD`3CDb<d=4A3E3<4E2AS94@TA1ASDbA3A2
<CTh=C<b@cTc>4I1>D94<T8`<c<f>3E6=cLh=cDi<495AC15<@df=4Dd>48`ASTe
@D8aASTf>C0f>CM4=C95ASTe<4E3ACPh=C52=D=1=CDh=3M4@DDf=C92AD4`@DDg
>D4==C92>DDdASHi@cE3>3A4<C=6=3Q5<D@i=c<b<D8b<3TbADDf@c@h@c4e=38`
=CM4@SDh=T51@SM5=D@g3C8g=dI1=DE4=c4a<cHgAS=3=3Da=DDfA351<d4i<D91
=S8`>34h=SLf=C=3<T@`<d91@T=5=d52<3Q4=`dc=353<3I1<3@aAD=6<S<b@dE6
=S8a@T<cAD@b<CLiAC<hACL`=30eA4A4AT8e<d=6@T<f=CTi=3E6AS4=@d8f=cDd
<34f<316@c@a@CI1<4@e@c8b@S=1<3Hh@S@i<30i<S91<c0g=4I2>34b>D8c@S<`
>30d<cE43D8f84i43BmH=TDP834a>B1BA20b=4E3@T@`=C=5@SU6<cHh=T@d=d4b
<c13<38bAD@f>DHg<3Tb=cQ3>38g=T4`<3Ld<c8hACDeA34aA48=<D4g@c0i<3E2
=3M2@cDe=T=5<T96=3Dh@c0dAD8e@S<bAS8e>DA1>CU3=cTf=C8iA3PhASHh<TDe
<S<d3CM4@DA5@CPf@DHd@d4g@CA6=3<b<T<g=c@e<C=4<SDa@S8a<d4e@C8e@S@h
=4Ha<c8d=cQ6<d@e>3=5@Pdb=4<e>353@DDg=494=3@d@T96AT4gA4A5<CU2>DA4
<TA6<cTd=SHg@S=2@SLbA3U4>44e>3A5=TDe84i43BmH=THP834c<B1BA20b=4E3
@T@`=C=5@SU4@C<`<S4d<S<b>C0a>3<i<CLg@DDd@S0`AC<bA3PhAT4`=C16=355
AD<b<30h=4@=<C51=3I1<S93=395<CLi<D<c=CU5=c96AS8e<SPi>3Pe@D=6=D@g
<c8i=S<f@cTi>4<`@c8e=d53=34`3C@g<cE2<D8g=3U6@d51>3Li<S@c@cQ3ASLh
=DI1<S@b=44e<SD`>CHa@S4f<D<i@S96@S<g<DHa<cI2A0diACPhAD<cA3@b<455
>3Db<C<b<S=1@D<d<S96@C4`>313=C=1@SPd>DI3ADDd<3Hc=4<a>3T`<dI2>4H=
>CQ2A3<d<THg=cPd@dI5A3Pc=4Hf=b1>A0d_F3L`820a=c<PDT@P<SA5@d94<3Dc
AD8i@cHa<C4aAD52>4=4A3Dh>4Hh=cLaASU5<cQ1@SDg<C8a=CD`=CU2@C52=cM3
<3E33CA3=3U1=cE6=CLf<d8cACA5=4HaA4A5<SH`@SDf@cHh=c=6<d96=3Td=DI3
=C4cASHh=DI6>4H`<T8dAPdh<4HiAC@e=DDfAT@g@C14<44g<c@f=C=6=S0g@D96
AD93>3E4AS55=d4d=c<fASHb>4=5>D@`@TDg@SL=<4<c>3U4<D=2@CDi=T8h<C=3
=S@b=CE2A3Pg=CPaA3Q3ASI2ASPg<SM1@T<d=THhA3Tc@T=1A4I5>3Db3D<fAC0e
<cQ2=C4c=C4`>3U3<cDb>D8d<TDe<S@d<C8d=4Hf@D4e@DI1=3U2AS@bASA6@STg
<S=6=30fAPdfASI2<3I5@T4a>3I1>44g<3Lh@cHf=TDc@c0eAD8f>3Pd>CPf<TE1
=4<f@d@g84i43BmH=c4P834g<b1BA20b=4E3@T@`=C=5@SU3=S4a<C55@D8g=3Lg
AC53<4@eAC<iASE3>30a@CM2=cPe=SDc=30h=dDd>CPfASH=@D<dA4D`>38`@S8i
>CPi@SDa=C93@C15=D4g<DHb<48e<d=5@C@c>C=2<S55@d96=dDi=316A4<f@S=1
3CLb=S@gASM4@S4c=3@f<SM2<T96=3Q1=C=2<THa=SE5ASI4@T@h<44eAC<b<c<a
@c=1<3Lb=SM3=4=6A@df>3Q6>DHb@THb<S@e=CTb=3A1<c0i>4Hb>C=5@CTi>D<d
<30fACLi>4Da>DA4=34gASLg@D4f>DI5<44=>44i=C4c=30f@T<i=S56<T=1@CHa
<4<aAC14@CQ6=SM3AT<f<S8h=d<f<d<f<34`=S<aAC<hADI1<DE63D4i=30e=CM4
=C@`<34c@T<`<S8hASLh<4=3@CE3>34a=CE1<4<h<SPhAS=2<30PCT@=;ePg<R0P
=cPPDT@P<SA5@d94<3DcAD8i<dDgAT=4@T8i=3Lh=c0c@T@i@c@bATDdASTgAS8i
<C4e=THaACE2A4<`@SHg>3923CHcA495>D@eA4E2A394@C=6@D<a<3L`>C11=D52
AS4c<d4`<3Dh<SQ2A48h@cHa@c54=C@`ATI6A3@g=@e1ACA4=48cAT8c=T=4<D<f
@DDi>C0`=491=S8h=d4b@SQ3@C4PCT@=;ePg<b0P<S4h8594838dAD=2A30e<dE2
>D8i@D<c=3Ph<395<S4i<3La<D8dAS54<d=3ACPbAS53<DDe@S<d=cA2<d@h@dH`
<Pda=c@g<C=4=44b=SE6=dHc=SPi<CU6@SLc<T=6@c93=3E2=T4d@SA1<C=1>3Tb
=C4c<S@`A3Hf>C0e<3L=<d4`@cQ5=c95<3I1=c13=391@DA5<cTb<S=2<C16=SU6
<c51=CDa=TH`>3D`<3I5A3<c@dH`=S4a=TDi3C8b>3<d=c4cA48b>3Hb=TDfADDc
<c4f>3U2=D4g=D56=c8a<C4cA351ATA6@C15@D4`@CU4A3Pg=d<i>0di@d8fASTg
ASA4>C8d>311>D<h@cM6<dE4=dDg=C0aAD<hADE3>3Q4AC0i<cTg=dE3AC@bAT@h
ACLeAS4==S=6@c<`@C11>CLb>3Lf@STc<d<h<T8b<T@b@T53>352>C92=D4`=c0a
@c<e<S0d<4I6=D4h>C<h<SQ63D<`@C8h=DE4>4I2<dHi<3Lb@c0b<DA6=D92=S16
=CU1=CA6>3<e<CHg>CE6@TDaAS11<4<d@C=6@THb<`ddASTi=3HcA3=5=D@eA4=4
84i43BmH=c@P834`<R1BA20b=4E3@T@`=C=5@STf=cQ6=T=3<cPb>3Pa=48f=d4h
<cPdA48h=T8a@CE4=C@e@cH`<C94<3@a=CE6=4<=@C=1AC4d<30d@dA1<TDb<T4i
@SDaAD8f<CU5>3Lh@SPe>C8g<CI2<c14>C4a<4A5=cM3AC51@DD`=3M63D@i>CM1
=3I2AD4g<S4g=3<h>34h=SA6=496@T@h<48g=cA3=4DgAD93<S0iAC52<cLb>34`
AD<`AT91A@df<CHdA455<c8a<CTa=C@c<3DhAD95A3LPCT@=;ePg=B0P<C0g8594
838dAD=2A30e<dE2>DHc=SPfA3@g@DA4A30`>30g<DA5AC0e=c0c<TI5=CDf<TI5
A30b@DE2=c4g>C@`<@e4<TE2<STi>D@dASE6<4@i>C@bA4=1<dA2ACDc=C4e=CA4
>DHd>492=THdA3Pf=S0d>D@a@CHe@c55<T4=A4Hg<C=2<4H`A48f@dI2A4E2AS<h
ASI2<d4g=D@g@SDeATDb@dDa@d<h<c0c<SU4<D@g>3<c@cI4=dI13D4h=S<`=DA4
@d56A3<g<D8c@cM2<S<`ACLa=c4fACLe=4DPCT@=;ePg=R0P=34PDT@P<SA5@d94
<3DcAD8iAC0aACA5<cPg>3DfA4<bATH`=DHc<cHd=c4fAT=2>3I6@CLfASPc<C@i
=cTi=C@f3DE5>3M4@CQ1AC4b=d8`=S<g=4<`<3<PCT@=;ePg=b0P>3DPDT@P<SA5
@d94<3DcAD8hAT4gA3E1@cE4<THh>C8c<CDf@cLg=d8b<392<C8f>3D`=DI5@CE4
=4I1=cL`@SLg3CM6@CE1>3I1AD<eA4<iATA3ATI4<cM1>3Th=C4c<dE2ADDe@cE6
=3A2>394>DI5<4<hA3Dc>D=1>CU5<Pde=dHc@C0e>CLh@S8a=TA1@SDg<D<g@CI1
=S=4@C15>CLf@DI5=CI5<T<i@d=5=dHe>B1>A0d_F3Lh820f<b1BA20b=4E3@T@`
=C=5@SThADHi=TA3=D@h>3Lc<3Lf=312=c8cACQ5AD@e@D4e>C0c=dH`<dDg=cM4
@SQ3AT<=ADH`<C94<CTbAS=2=c4a=cHfAC<f@TA3@D<e<c56AT4b@c8d<C=2>C4d
<CP`=CI1@cU5@T4c@cTd=T<b3DI5A3TgA21>A0d_F3Li820i<B1BA20b=4E3@T@`
=C=5@SU6>3H`AT=5@CI3<SPd@CLi=S8`=3Ha@cPa=c4f=S91ASPh>3Pf=S<i@CL`
@T=3ACL=ACA1<3<f=3Td=SE3ATHi<D8`>44d@STc@dE2=C54<CU2=CPi=CHi<D=3
<D54<3Lc=cL`=SA5<S@cA48`3CU1>4=3@dHe=cTe<S4`=STg<c8d@cPiAS92>3<d
>4E3>3E1<SHa>3I4@d@a<S93@dA6<CQ5<c16=CPhA0e6@B1>A0d_F3M1820d=R1B
A20b=4E3@T@`=C=5@STi=CTd<SDi=3=4@dA6<D=2>C@cAS<g<d@i@CDaAC16>3Lh
>3@`=S0eATDd<cQ2=S8=@STf<TDg>312>3<`<3@g<T8g<dE3>4=1@T53=C@f<cTP
CT@=;ePg@R0P<S8`8594838dAD=2A30e<dE2>CM6A34a<T@e@S@`>DHe=3L`<dI6
@d<i@C<e@CPc=cE4=30c@CE6@T52<C0fASLi<`d`=SPb=D55=T4g@CU5=T8h=SI5
=c91=cPg<3Ld@DE3=CTe>C0h=SPe@D8eA4Dh>C<g=D94=44b@CHa>44=<T<i<SHg
<4@d<dDb<cI3<d@i<c<c=DHe@d<`@c8f@TH`=3I5=C4dAC=6=c92=cPf<TI6>3Hg
@CPhA3Hc3D@`@dE4@dI5AD8c@STh<451AC=5<D53A4I2>3De<cTfA4<h<S=5<CHa
=SHe=cLcA3Q5<C8bAS<dA4@g>@di>D@d<4<b<c@a<c8hACQ3>CLeASE5A34d>CQ4
<SHiAC56=TI4A3U4=SPaA3Tb=d91AD4e=T8eATDh<3@=AC@g<4Di@C=4=S@a<SLf
AD8`@S0a<4Dh=D@b>D8iA4<a=T=1<S94>DE5=312<3=2A3P`ASPg=CHa<SM33D8d
<d8b>3@b<3@b=DH`=c4`=c=5AS@h<SI2<dD`=c8eATHb=S<a@c53>C4d=3He>D55
<SPc<cP`=d8f<0e5@DHf=cHa>C0b@SU1@SPhA395<R1>A0d_F3M3820b=B1BA20b
=4E3@T@`=C=5@SHc=dHc=T8fASL`<c8g@T92=4H`>C94AT@h=dE2ASTgA4I2>3Df
AB1>A0d_F3M4820b<S4PDT@P<SA5@d94<3DcAD8i=dI4<C4bA3E2<STcAC4e<3Pf
=3Pe=cHi@cHc=c0g@D@e=4I2=SDf>CDb=D4i=cQ33C95<34aA4<h>CThAS53=c55
>4@b<3Li=TA6>4@a>D8`<c=3=44hATDe<cPg=C<gA3@eASI3=CPh=4Db@@e4AD8b
A3@eAD8`@CHc<38eA392=4I3=c=3A3Df@C8a=SPc=C8c=4@c>353=c=5@SI3A34c
>4Di=SI4@T<=@c0`=353@CTfACLg@cHg@DE5>CM3=C4e=T4e>3I5=SE2=DHh@CLg
A4Hd=c0i<454<c<f=S4e@DA1>D543CLdAC8aA4E5@c0b@C0iACTb@SP`A3=5=dDc
AD8f>CE2=S0gA4<cAS11A34`AD4`>CT`>C56>3@i<SLe@@dfADA5@CPh@dI3ACHf
AD8b<CP`=THc=3L`=CLfA4Dc=4@`=c@f@dE4<c=6=D8h>CDc<TE6ATI2=4Dc<3<=
ASPd<3LgACM3A3A4AD@b>38eA3<fAS8f@T54<3M3ACLe>4=3>495=S=4=SE1=D8h
=dI5<3<c@T4h<c933C55ASTg<D@g<3PgAS8i<S=3@D@e=C4PCT@=;ePgAB0P<C<i
8594838dAD=2A30e<dE2>3Le<d=1=4@f@cLi@d8`<TDi<SP`@T<b<dI4<3I6<496
=4Dh=C0`AC12<TE3>CE2A0dc=S@d<CPcA34f@DHaA30g@S=1<S4hAC51>DE1=393
<DHb@dHc@CTg@S@gADHc=cQ6>394A38g@STb=34=>4Hc<C56@d54>CU3=D<d<3I5
@d56A3A2@S@i@d<b=d4b=S8a@T@bAD@i=30f@T=6>CI4@cD`<3<b<CTc3C0`@c0d
AS=4<DDa=THa@dH`>493<c15<c13=D8d<dDh<dA5<T8b<cLc=cI2AC=4ASM5<CLa
@T8e<S@b<Pdd=dHcAC91ASDa>354=C56<4@g>3M3@dDeACA3=44f=S<d=D=4<21>
A0d_F3M6820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePh<20P
>3DPDT@P<SA5@d94<3DcAD8h<c4e<CTaADH`>C4c=CE5=S<a>D@cASTa<C0e=S53
ACA1<T96>3I6=cM4=c52<D4c3CTcASE5<CA5A3I3=d<c@cM3<S8i@C<gATA5<c@g
>48c@d8b@c4`=dI6<cLb@CE3=3<f<cPb<C8`<cI6@@dcAT8c<3Le<D<`=SU6<S8c
@STc@cHi>C8c<30d>D4b>CHhASHb<SM2>C93=cA3=3LdAB1>A0d_F3Pa820a=cLP
DT@P<SA5@d94<3DcAD8h<c4e<CTaADH`@SM3@T<f>38d=d@dAC54<c4h>3Te>CU3
@c0dAS=5>C<c@TDd=3Ld3C<b@cE3ACI3ACI6A34b=4Hf=CA6AT8`=D=1AC0c<CU6
=CA6A30`ASHf@C=2A3@d=CDi@DH`AS0h>CI2A0dg>DA2<d92=T56@SU2AS0b@C12
=4Dh<d=4<SA2=CTg@C92=c@bAD=6@C8f=4@g<DDcACHf>3U6<C0d<CD=<3U1AS53
<TI1<d4d=451<3Lg=c0gA453>4I6>4<iAC8h@SQ1ACLf=C0e<34g@cHbASPc=392
@C4f>3123DI1<3La=3A4<cE6ADE3<3Pb<CQ4<cQ6AT55<C<h<S@aACM3<4<e@S92
AS11=C0iAC@d@TDd@cP`>48f<Pde=4@f@D4`=d8i<C8b<c4h>44g@T95<SM6<4Df
<dE4=S=6ASLb=SHc=4Da@C4d>44i@CI6<48PCT@=;ePh<R0P<S@f8594838dAD=2
A30e<dE2>3@e=c11<S0iAST`@THc@S54<3M3@SDd<SLc<c16<SPd<T91ASL`<4I5
>DI4@SL`APd`=dA1ACE1<4Di>3D`@C92>C8b>356=3Te<c4i=T8i@CLb@D<g@cHf
ACA2<d4f<cM5@D@e=dI5=TI5<CD=<C@f>4A2>3<`>3DeA3L`>DHc=S0f=cLh=d=3
@S4d=44g@C53<CPfA4@b=48e@cHf<351AS8b@cE1AS=53D<i<3A6=CDa=S55ADHe
<3Li@C<b<DDg@D55A3PiAD94=S56<DI1<c<b<3<`ASDg<D53>C12=C8f=T8h>@di
A4A4=d=6=3=5AC4`ACTi=STi<C=1@T@g<CTh<C94ASPc=TI3=d91@d8e<315<392
<3De@d56<S54=48=ACDh=c0c@T8d>495<C52A3H`<SHb=495A495@c4d@T8h=C0f
ASDe=CA6=T4a<c4c=CTdA353=S<b@cLa3CA6>C0cA4A2<d8`=D54A3HiACTdAC=2
<c8`=SI3A44h<c8h=3HbAS8c<CPg=44g=S0i=4<h<S4b<3Dd=Pe4=SDd=T8hAD8h
ACQ6<cHd>CU5A3He@cM2@T@`ADE5=456@dDa@S8i>4@g@D8`=3I6=3Dd<3<e<3De
@S8=AD4dA3@c=S56<4E484i43BmH>3<P83Hg8594838dAD=2A30e<dE2>DI3@D4`
=c4e=4Hi@T8`<4@iAC52=4<`@d@bA3H`<CA4AS@cA3Tc@c16<c53AS@b<Pe4@T8`
>38a<S=1=c0`>3PgADI5AC56=SA5ASDb@T4iA4Hb=D8dASPh<d4`@d<h<CDeAT56
=C0`=D51=d4=@S11=SHg=d=4AD4`=30PCT@=;ePh=20P<CHg8594838dAD=2A30e
<dE2>30b=d8a=C=1<SQ2<D53@T4aACA6@S@cAT4g<D@i=CL`@cQ3@T=5<dDbACHh
<S0hA@db=SDa<D95A3<e@cA6A314=cQ2<S15>44c@S@cASDf@S<gACH`>34g=S@b
<c@`=D@dA3Lh=4<d<D4`>CP=>4Dc=d<iACHe<cA3@CTh>48h@T8hAC93>C96<T8d
<C<i<cLg=C91@S@a@cTb@C@e=C91<D<e=S@g@T8i3CDa>CM2@D=6@CA6<DE1<T<d
<TA3>356<dD`<C92=4<i<3=6=d<d=cQ2>3TcA3Te@CI5ATE6>D4h=T4a=Pdc>4A4
>DI4ADHi<C55<cM5ATDh<4D`ATA3AD55=c=4<DI1>354=3Hi>D@cASA3<4Hd=d4c
AT8e<C=4AD@=@D<b@C0h@DA6=C<h>34i@c53=SPh>3Tg=D54=3M4@TA3=R1>A0d_
F3Pe820a=S4PDT@P<SA5@d94<3DcAD8h<SU5=3@d@S0e>DHi=D4aA3@aATE3<3E5
@C8b@D4a>D@c=48e@C12<d<gAC8`<34b3D@b<D<g<D4h>D92AS8i<SLh>4<c>38g
=dHg<T4dAS55ASQ6=C0`<CE6=cDa<355AS96>D4h>4A4<354>@e5@D4i<DE1<T95
@SL`AS8h@CHbA3A5>34a<C<h<D=1=cTg@cH`=SQ4=cQ2<3Lc@CTf@C@eAD4d=CLa
<d8=A3A2=30d@T93@dE1@S8f=3@i=3DfAC<c<SU3=S4h<T95AC@fAC=2=c=6=3=5
<3U2<3Dc<D55AC@c@D@g3CE5=c<`=3Q6@C8a@S96<SLb<44a<SPi=3Hh=S<i=S0g
>4I1>C4d>3I5<c0f<3L`<48h=c<dA3=4=dE6@`e3>3Di<SQ1<3@a<c<f=3D`<T91
ACLh84i43BmH>3HP834d<B1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=T<g>C8e<c8c
=DE6=3<g<T@b<C11<DDcAC0h=SI4>4=2A3Tb<3D`ASP=<TH`@S55=TA1<3Le=TE3
>4H`<T4`>38i=3Ph@D@a=4I2=d4fAT4i=c@d=d<e@S4a@d56=352<3Ld=S4d3D92
=4I5<D91ATHh=SDc@D@d>30e@TD`@C8f@c55@C12AT<`A34h=44iA4I5@cPeA4@g
>D@gAD@b<30e=Pdi@S8e@d4bA3E4<SM3@DA6=S4g=S15<cU4<DDd<D=3A44i=cTa
>44e@SE1AC@g>CDe@S11AS4f<TI5<ST=A3Pa>4I2=392=313A4@`@dI4AST`<3M6
=S55@CA6<CTiAT<b=cLgACI584i43BmH>3LP838e<@00X@30?olPDT@P<SA5@d94
<3DcAD8i>CDi=38e>C@cA3Hi>C8g<SA4>CU2=3E3@cU4<D8c=cTg<3Pc=30c<C@`
<dE2=DDf3CLc>38aADH`ASQ5@THe@C=6=CTi@S8i=DDa>4<i>38`>CU4@S8b=cQ3
@S13ASQ2>391=S0e=DDf@cQ5<0db<3M1<S8a@T4h=4@i>4=6=D@bAC0d>4Hh>C15
@DA1>392<cDa@SLa<3Lg=d4c@D8d=T8c<4Hg=c=3<d4==D4bASHb=C4f@CLf<C=3
>3Q1=d<i@SI3<4A1<S94@c4gAT=5<S0`=4@h@STb<CQ2=C8i>3Q2AS8e<DDh3C@d
=SA5>D8g@cDa<D@d<4H`AC13=34a=38h<c8g=C92AT<h>CPh>D@bA3<f>4Hb=C0c
A3<a<SI6ASPiAPdi>C12@CTdAS@a@SA3<cPg@S4h<DDe>3Tf=C0b>CM3@D=4<S@d
<4E6>3Td>D@fASA2ACTdADH`<S96ASD==44f<T@fAC<d=d=4<d8e<4I6=3<b@TDd
>D95=3Pc@dHa=CQ1A3E6@dHf<c91=c=6A3<h@TI3@C13@dI43D8c<DA2=C4g<S52
A44h>DDg=TE3=cE1@d<b=4=6<SDg@d8i=dHf@DDd<cLb<34h<S95=d<f=CA1=S92
<PdiAT@h=T8`AS8`@c8d=cM5ADHe@d=184i43BmH>3PP838e<21BA20b=4E3@T@`
=C=5@STi=CTd<SDi=3=4=STi<SLb=4@i>D8d=D=3>D@a@S<g>CL`>3<d<3<a=30c
AD8eACH==c<h<S55AS16>4E2ASE1<dHe>CU2<STeAC4h@cTh<S0i>DA2<S8g>4=2
<4=6>48h<T4f<3DeACI3>4D`3C8`=d4b<S52@CPdA3Th@dHeA395<3@hASPi<4E1
A44h<T8c=C52=c4`=cLg@C=1@S@f@S<`ASLg<d<c@@de@C96=S8e<CI1=cHa<d<h
>44g@cU2=T<`A44b<TA3<CM6@dDb<30dA3Q2>C8a>48e<STh>496<SDaACP==3@f
=4Di@SM3=C4aA3@`AS15<4<d<C4d<SPc<SLe<T96@cPi>3PiA394<cHhAS8e<3=4
<c4b=TI6>3U63CTi<491>CA6=352=4<c>3M2<CPaACDh>CHe<38i=d=1@d@b=3@`
ADHh>C@iA3I6=495>CA5AS0b<TI6=@dd@CHbA3I5<c@g@d@c@SD`ATHd<c92AC@i
@TDd>3=3AS4e>454=DI3ASHc<T4g<dI4<cQ2AT=1<4=3AT@=@S<aA48e<CLb<D94
@CPiACLfAD<g=D53@c8d@dHb=CM3@STgASI1AC<i<D<f<4<e<493=TA5=C=4>DA3
3CHa<D=5AT<f>4He<S=1>C4g>CDh84i43BmH>3TP838e>B1BA20b=4E3@T@`=C=5
@STi=CTd<SDi=3=4=STi<SLb=4@i>D8d=D=3>D@a@S<g>CL`>3<d<3<a=30cAD8e
ACH==c<h<S55AS16>4E2ASE1<dHe>CU2<STeAC4h@cTh<S0i>DA2<S8g>4=2<4=6
>48h<T4f<3DeACI3>4D`3C8`=d4b<S52@CPdA3Th@dHeA395<3@hASPi<4E1A44h
<T8c=C52=c4`=cLg@C=1@S@f@S<`ASLg<d<c@@de@C96=S8e<CI1=cHa<d<h>44g
@cU2=T<`A44b<TA3<CM6@dDb<30dA3Q2>C8a>48e<STh>496<SDaACP==3@f=4Di
@SM3=C4aA3@`AS15<4<d<C4d<SPc<SLe<T96@cPi>3PiA394<cHhAS8e<3=4<c4b
=TI6>3U63CTi<491>CA6=352=4<c>3M2<CPaACDh>CHe<38i=d=1@d@b=3@`ADHh
>C@iA3I6=495>CA5AS0b<TI6=@dd@CHbA3I5<c@g@d@c@SD`ATHd<c92AC@i@TDd
>3=3AS4e>454=DI3ASHc<T4g<dI4<cQ2AT=1<4=3AT@=@S<aA48e<CLb<D94@CPi
ACLfAD<g=D53@c8d@dHb=CM3@STgASI1AC@cAT8i=c@b>3<d@CU1<CPh>3Li3CQ6
@SThAD<d<S<f=4E4=3Q4<38e<d4e<CL`=4I1=C93ASU4=dHh84i43BmH>44P838e
=b1BA20b=4E3@T@`=C=5@STi=CTd<SDi=3=4=STi<SLb=4@i>D8d=D=3>D@a@S<g
>CL`>3<d<3<a=30cAD8eACH==c<h<S55AS16>4E2ASE1<dHe>CU2<STeAC4h@cTh
<S0i>DA2<S8g>4=2<4=6>48h<T4f<3DeACI3>4D`3C8`=d4b<S52@CPdA3Th@dHe
A395<3@hASPi<4E1A44h<T8c=C52=c4`=cLg@C=1@S@f@S<`ASLg<d<c@@de@C96
=S8e<CI1=cHa<d<h>44g@cU2=T<`A44b<TA3<CM6@dDb<30dA3Q2>C8a>48e<STh
>496<SDaACP==3@f=4Di@SM3=C4aA3@`AS15<4<d<C4d<SPc<SLe<T96@cPi>3Pi
A394<cHhAS8e<3=4<c4b=TI6>3U63CTi<491>CA6=352=4<c>3M2<CPaACDh>CHe
<38i=d=1@d@b=3@`ADHh>C@iA3I6=495>CA5AS0b<TI6=@dd@CHbA3I5<c@g@d@c
@SD`ATHd<c92AC@i@TDd>3=3AS4e>454=DI3ASHc<T4g<dI4<cQ2AT=1<4=3AT@=
@S<aA48e<CLb<D94@CPiACLfAD<g=D53@c8d@dHb=CM3@STgASI1AC@c=S@e@SHb
=c4dASPe<D91AS913C0f=D<c>392AS4g<S8cAT54ACHd=cA5@SE2<c8i>CHg>CPP
CT@=;ePh@R0P<c8`8594838dAD=2A30e<dE2>CTe>C@b=CTd<d@f>CTb=c8dA3Ti
@S@e@d<iA352<cLi=c0h<c@`<c4d<3=5@SE5=Pdg<cPb<DE6<4HhAD96=D4cASDi
>D8b>CE5<CQ3>CPb<3TiA48b<SLh@d8`@dHh@SPb@CH`=CE5=T<hAC0=<S0g@C8b
<D91>3A4>CQ3ASE4<TD`=3Q6>3T`AD54@CPb@S<e<D8g<C0g=cM1<d52=3I2<c16
=cLc@c=13CE1<THf<SDa=T4g=S4c@cPh@CM3>D8f@c14@C8bA4<a=dI3AC8`<3A4
>48i<S4h@SDb>CPh@THb=C55>0dd=3HdACU2=d<e<C54=316<4D`@c@a<C@b>3<b
=cDb@TI3>3Th>3U4<T@c=SQ6<SD`<d@c<C8fATHh>DH=>CT`@T4i=4Hd<D8d@c<h
=d8a>355=CPi=SD`<STg@d53A38d=315ASPi=3U4=THd@TDi=4E6<38bATHe3CA1
=S94=TDc=3M3A3=2=C16AS@c<T95=3U2AC@h<d=6<CDh@D@eAT=6=S<b@CLcAT@c
>496@d4`@d=6A0e2<c54@SDa=c8a@TA1>3U5=cI5@cLe@D=3<SA3AS8e=d=2>CM6
=T55=3<i<C0aA34e@dDb<dI5ASLi<DH=@CA2AS0g@T52=S0e<493<d<aAT8aAT56
=TDe@T=6<c=2A4DfASP`A3I6A38d<c13<T8a>34d@T<hAT4f3D8g=3E4ADA2@cI1
@SM5=48`@CHa<DI2AT<e@CP`AS14=CHi<THg=CI3>C=4A3Q6<SI5>4D`>38e<3Pe
=Pe3@c15<44f@SQ3@S54<c=1<d8b>C4f>DDf@S91=TD`A48e>3Tb@cL`84i43BmH
>4<P83<e<R1BA20b=4E3@T@`=C=5@STi=CTd<SDi=3=4=STi<SLb=4@i>D8d=D=3
>D@a@S<g>CL`>3<d<3<a=30cAD8eACH==c<h<S55AS16>4E2ASE1<dHe>CU2<STe
AC4h@cTh<S0i>DA2<S8g>4=2<4=6>48h<T4f<3DeACI3>4D`3C8`=d4b<S52@CPd
A3Th@dHeA395<3@hASPi<4E1A44h<T8c=C52=c4`=cLg@C=1@S@f@S<`ASLg<d<c
@@de@C96=S8e<CI1=cHa<d<h>44g@cU2=T<`A44b<TA3<CM6@dDb<30dA3Q2>C8a
>48e<STh>496<SDaACP==3@f=4Di@SM3=C4aA3@`AS15<4<d<C4d<SPc<SLe<T96
@cPi>3PiA394<cHhAS8e<3=4<c4b=TI6>3U63CTi<491>CA6=352=4<c>3M2<CPa
ACDh>CHe<38i=d=1@d@b=3@`ADHh>C@iA3I6=495>CA5AS0b<TI6=@dd@CHbA3I5
<c@g@d@c@SD`ATHd<c92AC@i@TDd>3=3AS4e>454=DI3ASHc<T4g<dI4<cQ2AT=1
<4=3AT@=@S<aA48e<CLb<D94@CPiACLfAD<g=D53@c8d@dHb=CM3@STgASI1AC@c
AS<`<d<c=S@e<cU1<S<d=d@h3C95<d8h@DDg=4<h@c@i=d51<D4c<S<`<dDe>C8a
=C<i@D52>DDg=T55>CI4=SU2>395<3A2=d4g<4=3=@da@d<e=TE4<CLd<d4e<cTi
<CHgA3=4ACE5>314@dD`=4Ha@S4i=CA1<C0b=C<g>C8c>4I1AST`AT4b=dD==3@f
=CTf=D8b=SM4=CDc@SDaA316<c14=CM6<392ASPi@CDh<3Lb=SPg<SHh<d4i<cHg
@c52@S<cAS563CQ1<CTiA314=CE3=DHd>4E5=48h=c8g<D<i<3Da@c4b<TA6<d@d
<4I5AS1684i43BmH>4@P838b=B1BA20b=4E3@T@`=C=5@STiA30`@C4c=SDc<c0e
@D4f<T<f<SQ1@DE2=44iAT92=DI4<4A2=C51@C8i=3@fAD8=<TI4=3=2A3<e<3=4
@cHf@cM5<CE1>4@c=3T`@c54AS=1=3=6<3Pe>D4h@D8b>3H`=cU1=T8b=DE5<3Ti
3DI1@T92=c52=T@h=C<e@C@b@C8b=TA3<3M3=34h<354=T8f<c0e@d8`>4Db>34i
<STd@CTeATE2=3Q6A0dd=314=CU6=S4g@SA5ASA1<c<c@S@c>DHb@c14A3Tb=T8b
>D<hAD4d=SE1@DI1A3E1<DE3<dI4@d51>D4==C56@CLd@S91=DDi@SQ2@T<dAS=1
>CT`<CHfA4Dg@CA3<3<cAC8`@C4eA3Lf=TDa=3Lb@D<`AT@a>3Dc3CA1AS@e<D<d
<T8c@SPh>CI4ASTe@S51@C@hAS=4>48f<38b<3I2<C@`@TE4>CLb=4E3=d=3=d55
=34e=`e1<d<i<TDa@d<eACM3A3I3@C@`<DA5<DHa>4E4A4<`>CM3=CDa=DHi<d@f
<TE5=D<d=3A5=DA1<3He<cT==SHf@d95=S4a@DHhA3H`<c<b=c11=3U2=3I2@S=1
84i43BmH>4DP834i<B1BA20b=4E3@T@`=C=5@SU6@d51<3La=CHd<c@a<C12<34d
>4Dc@c92=d@d<C@`=cTcACQ3<cLiA315=CA3<TH=@S4c@CDc=cTi=TDe=CI5@c93
@dA6AT@h=THi=c@c<S@`=CTf<38d=SHd<SD`<d4hACE3AD55ACPi<48b3D<a=SLc
AS56>3Q2@dDfACLa@C=6=D@f>4I6>3M6<d91@cQ1=4<f@SHi>30hASHeA3@h=34i
<CU1<cPa<Pe5=CHf=T=3=48f@SDc=4E5>3Tb>3Th=CI6@cU6<C@e=c@g=TDb=48i
@D8h>34a=DI2=cI1AC54=CHc=T@=AC52@T54=4I5=313AS0b<SU4<dDb>3Pc=4=6
@D<gADDg<cU1<S56>3P`ATE1=SDfA3@hAC8e<SHf=3U63C@d@CU4=S<dAT@g@CI6
A30`<cE4A496<30`@THe=dI1<CPa=CM4<d<eAS16ASHg<3=6@CU2A4<fA30b@@e2
A4@h<S0d<SA4ASM2<3E2<34i<cLf84i43BmH>4HP834i<R1BA20b=4E3@T@`=C=5
@SU6@d51<3La=CHd<c@a<C12<34d>4Dc@c92=d@d<C@`=cTcACQ3<cLiA315=CA3
<TH=@S4c@CDc=cTi=TDe=CI5@c93@dA6AT@h=THi=c@c<S@`=CTf<38d=SHd<SD`
<d4hACE3AD55ACPi<48b3D<a=SLcAS56>3Q2@dDfACLa@C=6=D@f>4I6>3M6<d91
@cQ1=4<f@SHi>30hASHeA3@h=34i<CU1<cPa<Pe5=CHf=T=3=48f@SDc=4E5>3Tb
>3Th=CI6@cU6<C@e=c@g=TDb=48i@D8h>34a=DI2=cI1AC54=CHc=T@=AC52@T54
=4I5=313AS0b<SU4<dDb>3Pc=4=6@D<gADDg<cU1<S56>3P`ATE1=SDfA3@hAC8e
<SHf=3U63C@d@CU4=S<dAT@g@CI6A30`<cE4A496<30`@THe=dI1<CPa=CM4<d<e
ASHb=S0a@c53<4Dc=3Hi@SHa<`e4=493=C4b<T<d=3Hd@d4`ADI4@cLa=34PCT@=
;ePi<20P<S0`8594838dAD=2A30e<dE2>DI3@D4`=c4e=S@c=34a<48`<C@hAC=3
<T8gA3@a=30g>C=5>4<c=cU4<4De=4<bAPe2<C=1=C<g>CTfACDe=TE3<T=3A4I6
A3PfASTg=3<b=30e>CH`<S@f=S@b=C0c@CQ5=D=5@DE5>3T`@S8=@c4f=c=6<DHh
>493ACI5=c51<dHeA3HhATHh=dHc@T53>44d@cI2=STh<3Q6=SE4=3Pd<CTa>D4c
>34b3DDe=SHf@d<d@SI2=C<dADDh>C8h>CPe=TI3>DHa=3Dg=3LfAC8d@SU1@SPh
<C4eAT8g=T55<D@e=S<fA0e5<D92@D@dATDd<4=6<38b>D@cAC8h>3<d@dI1@cM5
ACLc>D4b<DHh>316AD4f=CI4=3Q5<SDb=SHd>DH==3A1>D@f<cA6A3M1=TI4<30c
=DA4@TH`<312ASDgAT4a>34e=d@c@cE6=S93@CU3A3PaAC4g>3<f@TDh3CLd@CDd
=S0h@SE6A315<S13=dE5A3@f>453AD<c=DA2=DI1@SQ6<c4PCT@=;ePi<B0P<CTg
8594838dAD=2A30e<dE2>DI3@D4`=c4e=S@c=34a<48`<C@hAC=3<T8gA3@a=30g
>C=5>4<c=cU4<4De=4<bAPe2<C=1=C<g>CTfACDe=TE3<T=3A4I6A3PfASTg=3<b
=30e>CH`<S@f=S@b=C0c@CQ5=D=5@DE5>3T`@S8=@c4f=c=6<DHh>493ACI5=c51
<dHeA3HhATHh=dHc@T53>44d@cI2=STh<3Q6=SE4=3Pd<CTa>D4c>34b3DDe=SHf
@d<d@SI2=C<dADDh>C8h>CPe=TI3>DHa=3Dg=3LfAC8d@SU1@SPh<C4eAT8g=T55
<D@e=S<fA0e5<D92@D@dATDd<4=6<38b>D@cAC8h>3<d@dI1@cM5ACLc>D4b<DHh
>316AD4f=CI4=3Q5<SDb=SHd>DH==3A1>D@f<cA6A3M1=TI4<30c=DA4@TH`<312
ASDgAT4a>34e=d@c@cE6<CHe<C@c<C4iA34c<D<g<CE23CU1=38d=C4e<T<h@D91
<dI3>DA2<DE4@c8bA3@eACTa<3TPCT@=;ePi<R0P=3@PDT@P<SA5@d94<3DcAD8f
@c8aACM4=T<d>D8a<3La>CI1ATE2>3A3<d8a>C=3>CLg<313<CDc=CU1=SU4@SI6
3D8`@S4`A3I4<dD`@TE4@CTgASM5=3@a<CA4=S@PCT@=;ePi<b0P=3DPDT@P<SA5
@d94<3DcAD8f@c8aACM4=T<d>D8a<3La>CI1ATE2>3A3<d8a>C=3>CLg<313<CE5
@C53A355<3=23C0i<C@b<DA5=T=2<3Hd<T4f@T4a<cDa<T<a=4I4=21>A0d_F3Td
820e<b1BA20b=4E3@T@`=C=5@SI3<S55=d@f@c@i@S4`=c4i=T56AD8h=4<c@S4i
<d<i=cL`<4<a=D4e=S<h@TE6<dD=<44b@CH`<3<f>3U1<C4a@dI2<CQ4=c<f<cE2
>396A3Hi@C@`<DHc<dDc=38cAB1>A0d_F3Te820e<21BA20b=4E3@T@`=C=5@SI3
<S55=d@f@c@i@S4`=c4i=T56AD8h=4<c@S4i<d<i=cL`<4<a=C=3<cM6=4@bA3P=
<cLaAS11@c@bAD<c<cPc<d92=dA3@SDa=d56>CM5>3Hc@SU5=SE2AB1>A0d_F3Tf
820b<3LPDT@P<SA5@d94<3DcAD8iAS<f>3I4=3M1<S<`@c0b<TE4=SU6=c0i<SLh
@cPb=cI1<30g=3<b>4De=D@a<DA23C51=d<`>C0e@S@g@T<e=CI3AC92AS@e>4<`
=4E2=D8c<THb=CU4@CTi@cLi=SDb>D@h>4Hf>395=C8c=0dgA454AD4h=T56=4=1
=d4dAS@c<S93=cLd=C4cA38e<D8b<C=1=D4b=D8d>3A6<C<b=3LhAS=4=CPcAD8=
<SA3=CPa@d55=cA2A3@d=492ATI1=dA4AC4i@SU4A394AS<i=3Hf=d8c@T8g<T@i
A3Q1=CPdACHd=CA23CHf=d95@SLa=cQ5@TDe=S8c>4@g@TDdA4E3@C4d>C96<c<`
=cLc=3Dd=SE5=SU3>316<3Ti<cLiASL`@Pda@S95>3Ti=dHc>3=2<dDc=SA4@cT`
>3@i<cTa>DHd@C@`<cHc@c<h@CU1<3Q3@cA5=356ASTfAT@e>C<=@CLg=dHg@C56
=TA1AT@d<C@gASLf>3H`@DDi<C<a=CH`@c0d>CLa<CM3=d<a<CPe<S0i>4D`84i4
3BmH>CLP834e<B1BA20b=4E3@T@`=C=5@SU4@C<`<S4d<S<b>C0a>3<i<CLg@DDd
@S0`AC<bA3PhAT4`=C16=355AD<b<30h=4@=<C51=3I1<S93=395<CLi<D<c=CU5
=c96AS8e<SPi>3Pe@D=6=D@g<c8i=S<f@cTi>4<`@c8e=d53=34`3C@g<cE2<D8g
=3U6@d51>3Li<S@c@cQ3ASLh=DI1<S@b=44e<SD`>CHa@S4f<D<i@S96@S<g<DHa
<cI2A0diACPhAD<cA3@b<455>3Db<C<b<S=1@D<d<S96@C4`>313=C=1@SPd>DI3
ADDd<3Hc=4<a>3T`<dI2>4H=>CQ2A3<d<THg=cPd@dI5A3Pc=4Hi<TE2=DHf<cHb
=c15>393ATI4@CHi<D8hAS8`>3E3@T=4AT<a<3Pf3CHb84i43BmH>CPP834e<21B
A20b=4E3@T@`=C=5@SU4@C<`<S4d<S<b>C0a>3<i<CLg@DDd@S0`AC<bA3PhAT4`
=C16=355AD<b<30h=4@=<C51=3I1<S93=395<CLi<D<c=CU5=c96AS8e<SPi>3Pe
@D=6=D@g<c8i=S<f@cTi>4<`@c8e=d53=34`3C@g<cE2<D8g=3U6@d51>3Li<S@c
@cQ3ASLh=DI1<S@b=44e<SD`>CHa@S4f<D<i@S96@S<g<DHa<cI2A0diACPhAD<c
A3@b<455>3Db<C<b<S=1@D<d<S96@C4`>313=C=1@SPd>DI3ADDd<3Hc=4<a>3T`
<dI2>4H=>CQ2A3<d<THg=cPd@dI5A3Pc=4HiA38e=T@cA4I6A4<i=CDa=SA3ASQ2
A3@b@C8f=DDgAC55>C@e<d@b84i43BmH>CTP834e=b1BA20b=4E3@T@`=C=5@SU4
@C<`<S4d<S<b>C0a>3<i<CLg@DDd@S0`AC<bA3PhAT4`=C16=355AD<b<30h=4@=
<C51=3I1<S93=395<CLi<D<c=CU5=c96AS8e<SPi>3Pe@D=6=D@g<c8i=S<f@cTi
>4<`@c8e=d53=34`3C@g<cE2<D8g=3U6@d51>3Li<S@c@cQ3ASLh=DI1<S@b=44e
<SD`>CHa@S4f<D<i@S96@S<g<DHa<cI2A0diACPhAD<cA3@b<455>3Db<C<b<S=1
@D<d<S96@C4`>313=C=1@SPd>DI3ADDd<3Hc=4<a>3T`<dI2>4H=>CQ2A3<d<THg
=cPd@dI5A3Pc=4Hi<3M6=CPb@CTg<48a<c=6@cU6>C92=SPc=44e@dE6@CTh=48h
ADHd3DDd>CM2>4DdADHd@dA184i43BmH>D4P834e=b1BA20b=4E3@T@`=C=5@SU4
@C<`<S4d<S<b>C0a>3<i<CLg@DDd@S0`AC<bA3PhAT4`=C16=355AD<b<30h=4@=
<C51=3I1<S93=395<CLi<D<c=CU5=c96AS8e<SPi>3Pe@D=6=D@g<c8i=S<f@cTi
>4<`@c8e=d53=34`3C@g<cE2<D8g=3U6@d51>3Li<S@c@cQ3ASLh=DI1<S@b=44e
<SD`>CHa@S4f<D<i@S96@S<g<DHa<cI2A0diACPhAD<cA3@b<455>3Db<C<b<S=1
@D<d<S96@C4`>313=C=1@SPd>DI3ADDd<3Hc=4<a>3T`<dI2>4H=>CQ2A3<d<THg
=cPd@dI5A3Pc=4Hi<T@e<C8i>3U5=C@h>DI1>D@a@dHi<3E5<THd<c95=d=1ASA5
>4E33D@g=4I1=SU3>4<eASDg84i43BmH>D8P838a>B1BA20b=4E3@T@`=C=5@SU4
@C<`<S4d<S<b>C0a>3<i<CLg@DDd@S0`AC<bA3PhAT4`=C16=355AD<b<30h=4@=
<C51=3I1<S93=395<CLi<D<c=CU5=c96AS8e<SPi>3Pe@D=6=D@g<c8i=S<f@cTi
>4<`@c8e=d53=34`3C@g<cE2<D8g=3U6@d51>3Li<S@c@cQ3ASLh=DI1<S@b=44e
<SD`>CHa@S4f<D<i@S96@S<g<DHa<cI2A0diACPhAD<cA3@b<455>3Db<C<b<S=1
@D<d<S96@C4`>313=C=1@SPd>DI3ADDd<3Hc=4<a>3T`<dI2>4H=>CQ2A3<d<THg
=cPd@dI5A3Pc=4Hd<38gAD4`AS92<48dA3@h<cU5@CU3@SDiA4Ha=d<d<TA5=CPi
<SE53C8`ADDd>3@e<4Db=D<b=4D`@CH`>D94=48b=dA1ADE2@dHg@T8gAD8b=C<h
A4<i<cQ3@S95<d<`@T8e<0dg<DDg=C95=CI3<D8i<c<f@ST`@D4eA4Hd=C4iA48e
A395A4=3=cLf<cDcAS11=c4g>D@i=CH`>3Pc<c0=A311<SHd=D4g@DE4@CLi<44g
84i43BmH>D<P834b=R1BA20b=4E3@T@`=C=5@SU6<cHh=T@d=d54A4@`<3P`=c54
ADD`=CL`<c96ACDe=S96AD@`<T55@SLa=cTd<34=A395@S8i>CU4=4HeAS14>CTd
<TA3@C=4@TDe<cDa=CDdA3U6=3Q2@SI6=4@h=SH`=3U4<D4f=D<aAC913DA6=c4c
@S16<4A2=T=6@TA5@THc>4Hf@S=1=cE4=d8e=DI5<T=5<D=3>3<`<c8iA354=cPc
<d<fA3M6@@e1>3Hc<3E4A4=1AT@c=c52<d<g@S8c<4Dg<CLa=TDg=D92<S15<3Lf
=CLh<48gA30hAS=2AS8g@S8f=S4=<3<eA4A1=C12@cU584i43BmH>D@P834b=B1B
A20b=4E3@T@`=C=5@SU6<cHh=T@d=d54A4@`<3P`=c54ADD`=CL`<c96ACDe=S96
AD@`<T55@SLa=cTd<34=A395@S8i>CU4=4HeAS14>CTd<TA3@C=4@TDe<cDa=CDd
A3U6=3Q2@SI6=4@h=SH`=3U4<D4f=D<aAC913DA6=c4c@S16<4A2=T=6@TA5@THc
>4Hf@S=1=cE4=d8e=DI5<T=5<D=3>3<`<c8iA354=cPc<d<fA3M6@@e1>3Hc<3E4
A4=1AT@c=c52<d<g@S8c<4Dg<CLa=TDg=C8a=C92>D53<CHa<3He@C4a@d=3@CA6
>CLd=d@=>4Di=c4i<dDg=21>A0d_F3U5820a<cDPDT@P<SA5@d94<3DcAD8iAS<f
>3I4=3M1A4A4<30h<3LaA4E5<3Dg<3<bATDe=CHbATE4<391AD8g<CLi=30a3D@b
AD8b>CTiA3A6=DH`A3Ti=394@d4cA495=C<e<CDe=4@iAS@h@T8fASA4>3Hf<3@i
A351=SE3<DDb@@e4ASLa<d8`AS14@SI3AT94AD96<cQ6=T8c@CLeA3M2=CE6AC93
AC53@cPc<3<b>D@aA3Lh<c=3=T@gAT4=@CPf<c0eA4A3@DI4<cLa@S=3=d8b<c15
=c4g<CI5=cE2@T4c<CLf>DE3<3Q3<d@h=3I1=S@g>3@b@CPb3C51=C0i=3<d@cDc
@SLgA3A5A4=4A3@f=T<g=T4g<R1>A0d_F3U6820a<c8PDT@P<SA5@d94<3DcAD8i
AS<f>3I4=3M1A4A4<30h<3LaA4E5<3Dg<3<bATDe=CHbATE4<391AD8g<CLi=30a
3D@bAD8b>CTiA3A6=DH`A3Ti=394@d4cA495=C<e<CDe=4@iAS@h@T8fASA4>3Hf
<3@iA351=SE3<DDb@@e4ASLa<d8`AS14@SI3AT94AD96<cQ6=T8c@CLeA3M2=CE6
AC93AC53@cPc<3<b>D@aA3Lh<c=3=T@gAT4=@CPf<c0eA4A3@DI4<cLa@S=3=d8b
<c15=c4g<CI5=cE2@S11=DH`@d<f@S<a=C@b<CA3=38eAC8dAD523C=2@D4b<4E1
<C15=3Le<c56=c4fAS<b@B1>A0d_F44`820e>B1BA20b=4E3@T@`=C=5@SPg=C=3
@CA4=THg<3Ha<THf<T4a=S94=SA2@T4`@C@i@T95AD95>312A30d>CQ6@ST=@S53
A4=2=C=5A3LbAD8bACE3>3A3=T@b@D4d=352AS92@D<hAS8b>48c>4Dc>D@i@S13
<d4`A4I6AB1>A0d_F44a820a<c8PDT@P<SA5@d94<3DcAD8f=C@fA4A1<DDa>4=2
<d8aA3<i=S0e<CLh<CI1<3Dh@D4b@D@a=c0h=SLhAD8f<S4c3D=2@cHf>454@DHe
=4@e=S<g=SQ6AC54=D=5@SPhAC<`A44g<d52=4I4@C@`=CHi=494>3LfACHd<3M1
@@dd<c4bA314>C=4=T<i<D=5ACE5@D4c<TE2=CHhAD@h@CLaAT51>34i=D91=dI2
>3Hf>DA3>D@h<4<iAD4=@S0f=cLg>C8g<C8d@TDc<S16<TDa<C4c<D94<CHe=48h
<SM5=T55<CHd<D<b@S4i@D8i>311<4@a=S8e3CQ1=DI3A3Lc>C14@SDe<S8c=C4`
=c93AB1>A0d_F44b820a>C0PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=c4b>30i
<cU1=cLg<C52@S8fAT<c=CDb<T8`=DDb@D51<d=3<TDa3DHi@TDg@c<bAT<cASI6
A3M1=3@e@DA6A4Hg>3Pb>3U2<dE3@S0f<3P`AS0a<cLfADDb=S<d@S4`<392<`d`
<C8fA4I3<313@cI4<3A6=DHh@DI3=cDc=4He@c8iAC4c=T8cAC@f@TA2<T<b<cI4
@C@iATI5>CI4<T8=<cQ5A4I6<3M6<CHe=c<i=TDcA455=D4e<cHf=D53<CHb<SE3
@CU1=3E1>DDc<3<e=CDa@CE2<C<b=cP`3C0fATE2ATHh<3A6=C<gA493=SI3AD94
=dHd=D4`<d4bADA1@S0c@T55>DD`ASPi<3Da<4E3@T@f<3Q4=0df<T<b=3@bASHg
=D95<3H`<CLi@C@b@dA6<CU3@D8gAD<`<c0d<DE6@TA5@SQ2<SDe<cI3<C<f<3E4
<S0==38fACLf=3Ti<S4f<3Q1@c14<S8PCT@=;eQ1<b0P<CDb8594838dAD=2A30e
<dE2>3Le<d=1=4@fA3A6<44b@SHb=CTd@SPa<SPiADDc=cI2=3<f=496=SPe=C@c
=c<g=`db@C15=4A1ACA5>38i<DHb<D<i>DDeA3Ph@D@`=cLeAS<b=C<c@CE2<cLd
<cTf@d<h<D8d@S<`=CM3<CD=AD4d=CTc>D<h<d@b=3A5=c4aA3T`=C<`=D<`=D4i
<313>D=1<C4`@S0iAS94@CM6@T95@cHd=TDg=34a3CHc@C0`=DHh=34bA3La>D=1
>4=3<d53>3<b<S94=4Hc=T=4<C0e<SLc@CDh>CL`A3Da@SM5=CI6=3Ha>0dh=d4a
=D<b<S4h=d=5ACE3A3Lf=D<h@cU2<D@c<cQ6<3Dc=cLa=4I6@DE5A3A4=313@D=2
@cE3@T=4=c0=ADA6=B1>A0d_F44d820c<cDPDT@P<SA5@d94<3DcAD8h=cDc@d4d
A3I6=cU6@THi>30a>4A4@SE2@SA1=C91>CTe=4A4=C93=C16=T=1@d=33DDb<4@c
@SLh@SPh@D<eAD@e=cDc<D4e>CLaA4H`=3Q4@SA4=d51ACDi@DHhA3<`@d4d=T51
<CI6=c@fAPdd@c0hACLhA4I4=CU4<3He>C8i<48b=4A6@DDf<c96=TDgA3A5>4@f
A391<S4b<cA1AC0i<D8`A3D`=3D=<D4h=CE6@c@c@S0bAC<a@S<i=38d<S0a<T55
@SLi@SPh=4<a@TA6AD@bAC13A3Pc<c8i<D@f@cU4>CLb3C@a<SI6AS0h<34e@S@c
=dE2>CA6>DHh<SE6=dI6<4I3A34`AT8`@S8dAD@d>38g=4A5=TE1=4I1AD@g@`e1
@CI6@S=3<4Db@S<c=DDh<4Dc=C0d<T@iAD95@T8f<c95=cE2=T91AT55@d4iAD8h
<c4d=d4iA3@`@dH=<cHh<T@f>3A6<dHaA392<SPe<d8d@cQ3AS0a<S<b=cDg=C12
=C54>C0f=CU6<c93AT4f>3M2=3E5@CPg3D@e<CQ5=CE4=DHg<S0fAT=4@d<d<CLe
=C8d<3@b=3U2AT53<cDf=SI4=D54<C<a=3@`>4I6<3@g>356>@da<D8f@CPc=38i
@T@g@T4i=dE4=c0hAD8d<T=5@SI4<dA5=4I2>CHf<dA5AC93<30g=cU6A3Le=38i
=CP=>3Te<4Hf<SPi=C<a@cI6=cHa>3Da>3=4@D=6@D=6@S95=CPc@T4f<SU4<3@d
=SHi<d4g=3Pb=C8d=SM13CLf@C0f@T8g=cDb@C4f@S=6<CU1@d8g=cLi=TDi=d4f
<d93=CU6@cU5@C8dACE1A3Pc@S11>DHg@S8d=Pdi>D56AC8a<SI384i43BmH@CDP
834`<B1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THhATI2<dHg@C12<3M1@T@`<d@a
@CDc<3@iAD=3A3<d@d<a=4<a=3P=>DHa<c55=4Di@D=4<SLd@C=2=SHhAC54@SE5
=d4a@c0`@SM3<T55=CPfA3T`>D<iA48i<3<b@c@bA3Tc3CPc@S=3ASE4=C0f@S@h
<CU3<C4c=CU3=3Tc@S@i=4A3=456=CPeAT54=cI6=C=4<3Df<cA4<CE6>DDe@`df
@S4c@SA2=3A5ADI4<d4e=3Dd<C@b84i43BmH@CHP83Lg8594838dAD=2A30e<dE2
>3Le<d=1=4@fASM4=cQ2<C@i@S4f=4E5A3@`=3La@dDfACQ4=48`=C@f<c0d=CPi
>0e1A34a=SM4@S4h=c@a@dI5AC55@S8g@T91A3Hd=D95=S0hADHg<c8f<SM3@S8i
<d=6@CHcAS8eAC<`=SL==cPi=3=1=dE5<c=6=D4b=SU5@dI4<34cADHe=CE1@cPb
@R1>A0d_F44g820b=3DPDT@P<SA5@d94<3DcAD8i@d8b>CLb@d8bA4Hh@SA4A4Hi
@C52<dHd@d@g<S<b@CU2@THf@cU2=T8hATE4@C0c3C=1=CI2=dA4ATDd=cDa>4De
ASA3=CE2A4@i<30b=S15AS4d<c0fAC8d=D52<DI6@SM5<T8d=T8dAC8b>@e4A3<c
A38i=c91>4<d<CLeAD95>D8eAS=2=SU2=4I1<T8f@cHd=c8d=d@c=3=3=DDe<SLf
@SU1>D8e=CP=<S94=D8hA3Ld@D<h=TD`A313AC<h=3Ld@T@c@CHg<SLhACLc=D4d
=CTh=cQ2@SE6@D<b@S94=30i<C=33CQ1A4=6>CHc>4@cAC<i>C<d@DDhACE1=dDa
AT93@TA3ATE3<cE2=SI4<THg@C=1=C<i=SPf@dDcACPe>0db=DDh<TDc<d91=48f
@dA2<S51@SQ1=DHd=d@iADHg@C=6<DA4<SHb<TDiADA6AT93<D<gA3Hb>DA3@cD=
=TA4<cDbA4DgA30e>C<d<C8f<CDa<c94>DDfAT8g=D96AC<dAT=6AT55=SM1>3<b
>DA2@SPc@d=2<c163CTfAD@h<TA5<cE2ACHeASU2=cDa>4I6<d4g@SE5<38iASTe
ASI4<DA3@CM3=CPb=3Db@D4g=DDh<44f<0dhATDi<STa=CQ484i43BmH@CPP83<a
=21BA20b=4E3@T@`=C=5@T93=SE3<3Di@cM5<S<`ACU4>D<`<DDa<d=3A455AC4b
<SLf@CHe@d8b<d4`<38d@d<==S<`>D51A4<aA30e=D<f@T94>DDg<SLhAC0c@C4e
@D<a=4=5@D4a@D56>3A4<4<b@cM1@c15=D8`>3Ta3DI1=3Hg=TA6<cTc@C@f>4De
AT@a=SHe=S<c=dHb=3DcAS@a<C95<38g<CTb<T8c<C4i<3M5A30`=d@fA@diAS<b
A356<d@`=C8f=D<i<C11A3E3@S@`<S0h>4Db<SQ2@SHa=cLd<38b>3A6=CDe=TA5
=S@iAS0h=c<==3I1=SM2@c0fA491>4I4@SDdAS<dA3Ph=3HbASLf=c12>3E4>C4b
=353>D8`=c@e=454=394AS56@STf3D<g<C0cA48i=THe>3<i@D8h=SA5ACPi<S=3
>4@a=CM3<T8g>4E6<SM3<SPaACLiA4E2<cDg<cA6<3A4APe1<3Hb<4=3@D4f@C4c
@C@d>DA6@S53<D<d=cLbAD8f=S@c@cI4<4HiAT54@CQ5>30dADE2<CI3=4=3<30=
>30h@TE3<494<CTh=SDb@S16=3Hd>3PgA4A1<CE5<C<g>3<d<S96=dI6@c0fAC14
AD53=d<a@c8hADHc3DHd<CQ3AST`@c13<T=2AD=4<C<hA3PfA3A2<DHhA4<a=3Db
@S52<T4i>CA5>352AS13=4He>4Hh>3Dc<@dg<cP`=4<b<D4`<C94ASQ4<CM3=cLi
=STb<SLc=TA3@D<`@dHb<c<g@dI2<C4dATE3A4@f>3M3AC<h@CH=@dHf>38eAD<g
<SPb@c8gAT4f<CHd=SE2=D<iA21>A0d_F44i820b>3TPDT@P<SA5@d94<3DcAD92
@cHe@c0e>D<gAD=4ASU6@CP`>C@c<34c=c@d=SA4AT8e>C0eACDg@SU3@T8i=d55
3C16=cPh>34h<c<i<THh<S15>3Q3>DDc=cTc@SM3A3Hc>3E1>455=S=4>4<h<cHh
=3<d>CE6>3M5=DE2=@dfAS8hAT8i=c8d@D=6<cHa=4A2>D8b=cP`=d8d@SI5AT96
=3Pb=S56=CHg=cTc<d53@dHc<354=S13<SP=>CP`ASPe<C4fAC0e=SLc=CE5=cM4
@T<eACU3=C16A34d=44f@D@b<S4e<SPi<SM4>4E1<SE4@T4d=DI63DHd<cU5AT=6
@SQ3=S<f@TDbASQ1<C<d=T8iA34`>394@C<h<DHc@cU4=STd>DHi>CHi@C<c=SLb
<SQ5<`e1>38f=3E1@D@f@S91<CT`<44c<SI5=C=4=dDh<SQ2<48e>CE2<T<e@S@c
>DI2>48b@c8f=CPe@cQ4=CT=ACPh<T<i>CPhAT54=CPbA3Pf>3Df@dA1=cHd<SHf
@SI1=SU4A3Dd=3A6=SLd=T=2<DA2A315@T@e=3E43C93<315<S0f<c4f@cM4@d@g
A34b=d<f=TDc<4Dh<CE2AD8gAD@i<3@a>D@i=451>D<f=3I2=D95<cPa<`dh=DHc
<SA3=S51AD4f<S@g@cT`=T55<CA2<S@d@SLh>DE3A3P`=C=4@C4d<3H`>C8e>C<i
A393@T8c=S4=<SE6=CHg=3Tb<CA3=S=1=cPg=c@h@CA4A3U5@SPd<CM4>CTd=S<P
CT@=;eQ1@B0P>30PDT@P<SA5@d94<3DcAD8hA30iASI4@CA3<CQ2A44i<C0c>CDg
@CM5@C96@cDi<CLa=SHf=391<S0d@dA5=3Q33D<i<d=6<dDiA496@C<a=S8i>4I3
=3@gASE6A3Da=3DiACHg<CLhACDeAS<fA496@c8cAC=6<494<CA3=Pdd@cE2=48`
@d=5<S4iA4D`A38dAC=5ASP`<T51=CE1@CM2<cE2@d@c84i43BmH@D8P83<a8594
838dAD=2A30e<dE2>D=2<STg<T=2<3U6ACTe<SA2>CPf<3=1<C@c=CTf<cDe>454
=cHi@T=4=SDg<4@bA@dcAR1>A0d_F453820c=b1BA20b=4E3@T@`=C=5@SU3@S8i
=c93@S0i@c96<d<`AT4i<cPh@d92@S8f=CI6@dDh=D@`<SLe=T51@c@g@cH=<DHc
<S<bADDd=cTf=dDPCT@=;eQ1A20P=c4PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6
=dE4A44b=TDe<C13<cDh<D<gA4=3=cM6@dHb@CLcA3A3<c96>4H`3C@i>CDe@cE3
=dI2=CTb<3D`ADDg@THh>DHh=SQ3=d@a<S0cACQ4AC8aAT8g@CI6=453=C@i<cU1
>D<`@`e4A3D`<TE5@C0e<T93<312ASU6<35584i43BmH@DDP83Lh8594838dAD=2
A30e<dE2@T8a=TI2AC8d>CHh<CDe=dHa=D4e<cA3>493@C@`@cU3<38f=4<a=D4b
=d8d<CTa<`dh@CPe=SHhAD93<d=3@THb@SQ2ADA3<48h@S<h<S8d@D<g@CA2>CHb
=3Le=cHc<CI1=3Pi@d8e=4Di<ST=>CDg<dDi>CPe=34i=30dACM2>38cADHi<cHg
@SLaADA4=S4d84i43BmH@DHP838`<b1BA20b=4E3@T@`=C=5@SPb>DDd=3A2<3Df
>CE3>CTg@TDb@TA5ASTh<CU6>CHb>CU6=C13@DE1@TA4A4Dd=CH==44f=3E3>CLi
<34e@d<iA3D`>30iAD<g@D@d=D4g=cLg@T8`<D8g@c8h=d94AS0i>C4fA3Ti<cTd
=3Hf3CH`A44c<3E4=c14AS=6=c8gASU1<3=2<3D`@D=5>C<a<38`A391@SE5=3@`
<SDe>4@h=cTb@d4fA3E4<0de@d56@S=2<C0gATDi@SDe=S0h<D4d>D4b<T51<SHg
ATHi<S0g=D@`=SHi>C=5<C=1@CTb=c94>4A5<4<=@T8aA4E6>44a@c0hADI6<c@a
@dHg@T8dA4Ha>CLa<T53<CP`A496=dA6=CQ4>DA2>C0d>48f<SHb<d<c3CLe@C=3
<38h<4@b=S=2<3Tg@dDh<D8`<d<h=CA5=SU2<DE3@C=5ADA4A38`@cTi=DI6>CE1
@SHe=S4i@Pe1AC4b>C=3=T@d@C8a<CT`<3<eA3A5@T@iA4A2AT52=CU4=4E5=CA1
@dHdAD5184i43BmH@S0P838d=R1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THh<4Hc
<SDhA3=3=CI2AS8e<c4`=C8f@S53@S51AT=5ASHg=dE4<c4==d54@d4cASM3=d@d
<3DbADI4AS16ACDi=C8`>C@`<352<C56<4@g=48iA38gA4Db=3<dAD8g@C0a=CH`
3CHd>CU3ACHfAC11>3U2@dDe@DHc@c@d<CLd@c8c>492<c@i@TE1=c<fAS16>C8h
<C=2<CA1<SE4>DH`>0e2@SQ6ASM1@d8f@C@f<c56ASTf=496=dDfADDf=d8`=c4i
=c0gATDb@D92<cTg@c8h@C91>CE3>C55A3L=@c@a=STe>3<i=c8g<SU3=cDb=D55
A3LiA4I4<DI5>3Q2AT8aACI3=TI2>3HbAT4c@TD`<S@g=T@f<dE43D@dAD4f@CM1
@c8iASP`=cE6@SU1<dHa>C=3=4I3>3Ta@CLd>CL`<S=4=d95<3@`@T4i=d4`=SA1
=DE5A0da>3Tg=C8d@c0h@T@b<3=1<D8e@d4`=cI3<cA1>C<a@TE2@S8g=c54<3M5
=351=CI4<T56=DE1<d8e<4<=<D=2>48h<3D`AC4a@DE5<3=5@CPg@dDh@T91=D95
=SI2<c@h=T91<c8dATDgAD4d>4<d=c<`<4DfADDf3CDc>C95<c8e>C0b@R1>A0d_
F48a820f<b1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THgADA4=C93A3Ld<cHd=c0h
>4@g>3Pb<C0`<S<fASTd>CU3@DD`@T8==c@i<CU5>34iA4@h=44e<3Q5@CU3@CA2
@DHg@C@dACPe<cHg>34b<C=5=CI6=D=5@D@i=SPf@D=6=SA33C8h@TDf@B1>A0d_
F48b820e=B1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THgADA4=4=4ADHh<SE6@CTe
=CTd=38`=D56=D4`AS0e<CDc<dHf=TH=<D52=C95ASE2<c4h=C@bAC@a<c<a@CU3
ADHh@c8a=CTa=TA1A392=SPh@cI5@THg<SDPCT@=;eQ2<b0P=C@PDT@P<SA5@d94
<3DcAD8h=cDc@d4dA3I3=cTb>C@h@C11=c@f<D54>3Ph@D=3<SHf>3Pd=3Q6=4Dh
@T@h<dE63CTd<T51>30cAC4e>3E6@C16>4HfAC56>C8h<4A4=C=2@C15@DDg<3<b
<d4c@DA5<R1>A0d_F48d820h<b1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THg<3Td
<SL`A44a<c@`@SDd<DHe=C@gA3Te@T8a@S@d=d93=C=1>CD==D@bAT=3A4Hh<CLb
@T8i@c@h<cTiA3DhA3DeATI6>C4i@dI5>CM3=44`@c4iA352AC92@D@eAC@f>C<`
3D56ASU6=S=3=C@f<THa=C0c<CQ6=SPhASU3<CI2A3Pd<D4b=3T`>3A2=c96<c0P
CT@=;eQ2=B0P<C4b8594838dAD=2A30e<dE2>D=2<STg<T=2<c<cATHd>D<g@CU6
<391<44d<3<fACLb>C@h@S8i@CPh@cLb>DHi<0e1=48d=3A4@c@g@THi=cDcAD=5
@c16=T4`<d92ATA5>48eAC8fASQ1=TI1@d=4ACLg<44h>DDb=351>38=<TE4@SDe
>DA6A48`@CM2AS16<3<i>3Pe@C14ACDd<DHg>3E3@S0hAT8d@c11@cLa<SLi=3Pb
<c0`<cPc3C8g<CM4@CM1@T8d<cM3@DA6<S<i<4Hc=T4c@SA6<SHeASLb@SE1A494
=D8d84i43BmH@SHP838`=21BA20b=4E3@T@`=C=5@SPd=CL`@C8`>DHf<D<f=TDf
@D=5ADDhADDe<38dAD4`=3@`A3M2<TDgACDg=SLi@T@==CL`<C8`@S=4A38dAS<`
>CU4<3PbAS15<3@e=c8`@SQ6<SLg>DDcASU3=THiAS4d=3<iATDa>3A2=3I33C@d
A4A5=CQ4@c@b=C94<C=6<3LdA452<SM6<44`=S94>30`<DHb<C=5@c<e<CA3<c0a
=cHe@DA3A392@Pdf<TI3@c4`=34`@cU5=S4a=4E5ACDd=TDbAS4e@D<h=34f=cTa
=cM6=4<bACQ2<TA5<cDe<C@b@CM2<TH=AS@c@C8h<CA4<CTd=SDi@CU4ACE3@D@d
=c53A3He=SPh=3He@C=5@D=1=dDc@SA5A4@a<dHh<d<dACLe3C12A3A1ASQ1@CI3
<T4h<dI3=T92=3M1=455>C<dAC16=38a<c@f>3Ti>354<DA4ACM4>CE2@SL`<355
=@e6>CDb<ST`ASQ5>3<b<T@g<SE3<cM2@D8h>34g<dE6=cU6=4@b@S8a<dE2A3Q1
@TDPCT@=;eQ2=b0P=CLPDT@P<SA5@d94<3DcAD8iA44c<38a=38cA4Df@CA3<3I5
ATHd=3000:40`3ooA3Tb@S@gADHi@TE4@cPd@D4h>C8e@TE2@`e2@dHd=CLa@CDb
>D@e<C<f=3<`=d55<D93>D@b@cHd<4A5@S0e@CPh>3ThAS8h>451<312ASHPCT@=
;eQ2>20P=3LPDT@P<SA5@d94<3DcAD8hADA6>CM3ACDiAS55<4DfACTh>D52=d@e
@cHi<30g=4<f@cPgASDd=44b@D=3AT953C<f<c4g@T8i<C14ATH`>CE3<C0g@CPi
A3Ha<30`=c<e<4<PCT@=;eQ2>B0P>3TPDT@P<SA5@d94<3DcAD8h<DI4=3I2<3Dg
=CU4=3Hi=T@d@D@d>4I4A4<b=T8g@DDhASU6<d<cAT4b<3A3=d4g3D95<SQ4<CHa
=c92>3Ti@D8e<c54=30`A44i<c@`>3Q3AC0`AD93>4Ha>3U6=d52<CDb@S96@T4d
>DI6=`e3<44i=4E6@d@f>C<f@d8`AS=5<SHd<44h<48e@S=1>C8`AS=4=S8b@SQ5
A3E3<d@g@CPg@c8`=3U684i43BmH@T4P838a=R1BA20b=4E3@T@`=C=5@SU2=c0i
>C0a=4He=d<g<T54@C15=SPdASA6A3Q4=c0b=3<a>394=dE3=S0g@S52<3@=@S0g
@cLf<4Hc>4I2>34bASA2@SDaA456=CD`=d@c>C0h=S<eASE2@SA3=4I1=3Pi<3<c
<3Td=C0c@c@d3CTh=4<d=4<cA3I1<C0hAC0`>CPi<SM1A3M2@D<hAS@g=S55>3Q3
=CD`@D95>DDf=cDb<C4g@c56ASHi@`dd<D<eA4E4@C0`<3@cA34f=SDh=d=4@c<`
=T4c@T92A3L`<T=5=dHh@D@d@c55=dA1AD91@cTc>C4c>3D==DHgADHd=D8f@D@a
@T4gA4=3AC<e@c@i>3@g<S<c<dDa@DE6=T93<4Dh@S0f@TE5AD92A4=6<T95ACI4
3CI2@D@a=CA3@CU4@dD`<c0b@C12>CLb=c96ASHg=d92<cL`<D4a=C<b@cH`=30h
AD<e=48i=cHg=4E6@Pe2@d<c=S4gA4@c@CTb=492<STg<c8h=4=2<D=1>30eATHb
=C8f@SHi=C4`<T8a<316@D8e=T4g<c<b@S@=<CTg<S0c<S53<C8f84i43BmH@T8P
838a<B1BA20b=4E3@T@`=C=5@SHe@d@i@S4a=3A5<C<h<4Dc@C4g=C<fA3Hb<DI4
=cI2<3<e@D<b<cPi<d8a=STb=CD==cHc@S4a@CLc=S0e@c4g=SHhAS=6=CM1>4@f
<d8d@SU6<SI4=DHcA4@e<CDgAD@h=44eA34h=4=2>3Ta3D<c<4I4<4<aA4<a>C=1
=STe<SQ2=C4a=dI3ASM4<CHi@T4e@S<h>CQ4@TD`>C<i<dDc@C@g=SPiAS<g>@dd
=4<hADA2A48d>DH`<48i=C=5<cH`<3M4=c=4<d<c=c92<3HaAC8d>3<g<DA1=3E2
AT=5=3Q5>C8g>3L==T4g@CHdA34`<S<i<S<b<TH`A495<DI1=SDd=3TgACLf@SPf
@S@b<4I3<CPfA3Hh@c12>3Q2@cLdAC123C=6=STiAS4`<C@hASTdA4Ha=3Q2=SQ5
<48d>CLfATHh<cT`>CA2=C16ASTc>C@e@c@c@CDh@CE4=3Hh=0di=3Lf>3DfAS=6
=cPg@C4a=CPcA4<b<T<e@c8b<dA4>4@f=C=5<S8`@C4eAS53=S4i>452=3@g=cPe
=SP=A3LPCT@=;eQ2@b0P<C<b8594838dAD=2A30e<dE2>C96=CLg<cM1<cE4@d=3
=d56A4<c=4@d>DA4AT8h@cTf=cHg@TE4<DI1=CM6@c=6<@d`<C0a<CI5<SA3<D@h
A4@`<3=1>313=3Tg=3Pb@SI4<TI5A3Q1=4=5<c=4=DA2ADI1<38g>48i>CU3=S@=
AS=5ASHh<CPfAD96<C16AD53ASLc@d<b=SQ1>D92@THc@c16<395<c@c@SPe@c<b
AC<a<S8`<4<bADHb3CTb@cHh<3M2=4Da>DHa<c4g=T55>4E4AC91=4I2=C8d<313
@SHi<DDb@D8h@CTe<C=6<c<`=dDd=4<fA0e3@STb<DHc=D8g=cDa=3A2>D52=T52
=S4PCT@=;eQ2A20P<CLe8594838dAD=2A30e<dE2>4E4ASTg@dDe>DI1A3Db@c56
AC51>CM5=TI1>CDdAS0e=SQ4<T<e<cQ4>D93ATHa=`e2A4<c>3A6>D4iA3<e=3La
<CI2AC93=S@`<SM6<d4c>D4i>C52<CTc=cI4>3<a<D<f@S4`AT@iA4=3=48=ASHg
<4Da=3Pf<DDc=393ASHc=T93<SM1@c=6<D8i<TI2<D8d=TE3@T@aAS@c<38d<D92
<3=6@S4b>CPe3D=5@S8e<dDgA4@g@C@e@cLg<c=4@c@aA4I5<315A48e=T92<SH`
<T8d@cQ2=THc@CLe>3Hc@CHa=d52<`e2>CE1<392=c8e<C0f<38i=452=T8b@CPh
=C=6ACU3@c54A4I5>3=1@SLc<CLd=SA5<C8e@c4e@SM5<48=<D@h<DDg>34i<44`
ATDd<CTi>3Ld=C4eASTd<C4i<SU4@c@bAC4aAT@`=CTc<3@d<S4PCT@=;eQ2AB0P
<cHb8594838dAD=2A30e<dE2@THaAS0eASPe=4<`>3<e=dHa@D<fATI1@CM4<d8c
@CU4<3Dg>3@iASU4=D56<S53<`e2>CU2=CLf=DH`>DI1=c4g>44g=3T`>4I1>4=6
>CLg@d8fAD=1<SLb@dA4<T@fA3Pf@d4fAT91>312ADD=@cHe<C54>C0g@CPd<d8e
=3P`@D<g<3@h>C<iACA4@SE1<cTi>CPgAD55<DA3=SE1AC<b<CQ2@D51<C113C8d
@DA4@cDd=T@h@c0i<c0c=CL`@c@d@DHb=c=6<cI6<TI5=4E1A452@CTa<CLiAS8g
<d=5<cLa<D<c<`di<SHa>48e<cA3@SHb<d<h@SM2A3I6=3Tc@cM2=SPa@S53<TDe
=DA5=3De=D4d@dA2<cE3=4<gA3A6=T4==DE6=CLe>C<a>3<g<3Ta<3E4>3PgA30`
A3Pi>CHf>D92<dDa<dE5<48b<44d<cM3<SD`<dE1=D55<3953CHaAD8i>4E5ACP`
<C0e<S8i@SHa>3M3@d@e@T4c=D=6<391ASM2A3TaASTi=CA6=48a>3<e@c91@TI3
<0e2<cLb>CHbASDdA4E3<T8c<cI6ACPb<D@gAS0g<SLg=STi<4DfA4<c>DDg<30f
=3U3=c55@dHd<4<iA48=<3T`=4I5ATDhA3=4@SM5@DA5<30h=4<g<cHa@c@f=CLd
AC@b>CQ2=cHa@TDh>DE2@DDc=4@e=DI4=c=63CDe=d94>30g=S<h=C51>C8b@S0d
>3Hg<4A2@T<fASLgA30f@SM2<DE1AC8c=4@i<dDcAT<d=3Q3=3ThA0da@d94A30e
<cLg=30e=SHh<T@f<cPc<d<b<30a<cI1A44d=4E1>3U1AS4eA3Tb<DDd>C4c=S14
=SM1<T<=<SDcASHbADA5=CA6<S4a@C8bACDc@SQ2@DDf@S4g=SHg<30iAD8h@c94
AS8f<CDaAS@a=c0bAS91ASHb3D@h@S0PCT@=;eQ2AR0P<CLi8594838dAD=2A30e
<dE2>DA1<c0b<C@b<c8d@T93A4E4@CE5>4De<c96=S8h<CE2=SQ2=d=5=3Hd@S4h
<3E4APe1>3I6<C53=c8e<cM6<cM3<3De>D<f@T4d<cLb=CE1=C15<3Dc<3D`=48d
>CTh>44f=d<`A3<c@TDe=48=<T93<DDc@C0e>CTiAC4a>C4e@DI1=d@e=cLe>DE4
>3I3=cI4=DDc=D51@cDi=T<b<T52ASI2AC<b@C543CE6<4I2A38c@S94>D91=3Tb
>3@g@S11<dE3ACPg=c@f<dHaASPh<SI3@CHcA3Pf=d4a<C4cASM1A392>@e5=C0d
>C0e<c8f@CTa=c4h@SHd<34eAC=3=311A314=38d>455ACE5A3M5<cQ2<SDf@C0c
ACI2=S0i>D<=@CDhACE2=c@a=C0hAT93<d<c@CQ2=48b@cE2<cDc@THiA3Pi@c0f
@C53=d53>3=5<cDg=3@i>492>21>A0d_F4<`820a=c<PDT@P<SA5@d94<3DcAD8i
AC@d<34b=CLiA4@g=D@h=3U5=DE2@dA3<cHc=c0`<38b>CM1A391AD@a@c13<S<i
3CQ1=3Dc<SI6<44g@SQ6=D4a=C<g<3Hc@c4b<3Hi>48g>DHg<S12@d4cAD52<TA5
=48g>4=6AS@gA38dAPd`@SLb=3=2=4I2>D@f=S4g<CP`ATE1<c@g<T94<SPe<S8d
<cE5=D<b<c=4@CTe@CE4=T8d<c@b=4<g<3@=<C0f>CTg@T@i=cHhA3I4AD92AS8g
<3U2<3PeACTi>3Tc@THhA30iADE6=S@d=4D`=34cAS@b@CQ6<d8i3C<h=S54@CD`
@C@e>C0`A3Hb<3<a=3Lh<30f<4=2>C0d@cE1<C@f<3U4=3Ph@cD`A3M1AT@h=S0g
A4<i@@e4ADA3=DA1ASLd>4Dd>391<cDe<S54AS11A3E3@T91>D<h<c4`=S96@C8`
=cA284i43BmH@c4P83@b8594838dAD=2A30e<dE2=SM5<c<f@D4d=c8b<T8b>CDh
>3M4<SI5<C8b=30cACTcASE1<CP`=3=4<dA4=T8c@`e3<cQ2<3DiASA6<c=3=SDb
ASDbA4=2<C<PCT@=;eQ3<R0P<c<PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=dE4
A44iA4H`<3Lb<S0h@D8f=CTf<44i=c91@dI2<S92<354=d=23D<d<c8h<b1>A0d_
F4<c820e<21BA20b=4E3@T@`=C=5@T94<d<a=D@i=T=5@cE6@cM4AD<f>4Hf@DH`
<C8h=cLd@SI4=TDeA4Hf=d@i<3<i<34=<S=4>D@cAC93@T@hA4<g>3@i>3T`@CA3
@TD`<S=2<DA1@dHi>391=b1>A0d_F4<d820i<B1BA20b=4E3@T@`=C=5@SPg=C=3
@CA4=THh>D8e<S<i=C8c=THe=30aA4Dh>CDi=D54=cA1ADA3@C@d>3LcA3L=@cLe
=S4a@cDcADA2A3=6>D@eASE4<d<`<S=1AS16A34e@cHe<CE4=T93=3<g=SE6A3I4
<dDi>3@`>4A13CLdAC@b@S8e<C95=d51@C=5ASQ1AT8h=cHg<SU1AD<i=3Pd<CI4
@D55=DHb>38c=CHa>3M1=TDe>CQ2=PdgA21>A0d_F4<e820b=SDPDT@P<SA5@d94
<3DcAD8h=cDc@d4dA3I3=cU1=CTd@SLb<C<i<4I1<3Tb@c15=394<c95=CHi@cU4
<4HiACI23D93>3Dg<34g>CQ6=d8iAC<`<S4gASPh<dA3>CD`@c15AS<`=CU6A3I5
=T55ASI1<SM4@DI6<S=1<C54<0e2<3=3<C@f=SLa>C=5@D8c=44f<34b=c0e>CDi
@C4d=dA4=CDa=4He<CU5ATHf=4Ha@CLf=3=4>3E4=3T=@C<d>4@e=TDg<c0g@DI2
=C0b@D53=C@b@CPb>34a=d<a>3Ta=SH`AS@i=SQ5@S8`AS8d=3I1=C=3ADHc3CPa
<SM2<c92AT4f=3De@C56=DI3>352=dD`@C92AS8h<38b@SDf=48cAC4g=3Q2@CTa
<3Ta<cDa<3Hi>0di>CI5=C4e>314A30bA494@S=2A4@d>D53<S4c@c54=c13=c@d
<dDb<3<f>4<e@T8d<T4a@dDc=cA2=T4=A48eA48c=T<h<THeATI3@CU2=CDiAD54
=493<CI2=SA2ACHf<3E2=C@iA44d@CTe=dHcATDd=DI4>3Tg3C0f=C4b<454@D=4
@D=5AT@c=D94@T<b@T@`=4<`>3@g<CH`@dD`@DHe@C4h>C0cAT@a@THdASU3=4=1
@Pdh>3Q1ASDf@CA4A3=3<3Hb<S16<312@D8b=C8g>391=c@d@d8i=cHh>4Dd=DHc
<4@i@b1>A0d_F4<f820e<21BA20b=4E3@T@`=C=5@SQ4<3U6=TA1=3U6=DE2<CE4
<CHa=D4i=S55<cU5=C51<DHf>DHd=c<hACM4>3Df=cD=@CDe=3<b@d8c@CI6<C@f
=c<h<4Da=454@S13=C95@d=4<48dA3M4<21>A0d_F4<g820g<b1BA20b=4E3@T@`
=C=5@STh<SA1<3Hd>CHi=dDi<3M3@CA3@c@h=CQ3@cDc<T=2@THf<c96@cA4<SI5
AD4i=cD=ATE3=CP`=48b>C@`A451@D8`@CPi<SDaATA2A352A4A1>3=1<dDa<STd
=38d=cM1AST`<C8c<C=1<4523CA5AS4fADE5@T@d>D=2@D=4=c51ADHe@T=584i4
3BmH@cPP83Lc8594838dAD=2A30e<dE2>CPb=44`=S@i=SU3<CTi<T<i=D95A3Q5
@d8a>D4`=4@hACM2>4<d=3PeAC13<C<a@Pdc=STh<4A4=3@bA4E1<4Ha@S<e<CH`
=cHf=3=2A4I1AC0eATDa<CDh@d<h<CTe=DHc=cQ3=SI4<DI5AT8=>C8dADDaAC8h
A3E1<SDb<SLbA4E3=C8f@CLPCT@=;eQ3>B0P=CTPDT@P<SA5@d94<3DcAD92=DHd
AD56A3Hi=38h<3I1=cA3A4A6A3<h@D=1@d8b<3Th<3@hA4=5=CE3>3Lf<S533DDb
A30f@CTi<CHg@d<h<CDi<D55=STc<3Hf<3Di@TE2ACPgASI4=3De=3M6=T4d@T<`
ASDg@c4h@c<PCT@=;eQ3@B0P<C8PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3H`=T<e
84i43BmH@d8P83P`8594838dAD=2A30e<dE2>3<a=C4i<DE6<3Ta<cDeACHc<CU4
<dHi<C4`=CHa@dDd@C92ASPfASLgA3La@S51<`di<dHeAC4dAD@f@cM3<d<g@c8b
>D4c=dI4AC<d=cQ2<d=2<T<a<3M6AS<g<T4e@c@c=S<h<S4b<3<f>C<=@STd@CDa
@cU2ASTa@CU2@SU3<D8`>392>493A3M2=T92@T<e=c<g<21>A0d_F4=3820a=STP
DT@P<SA5@d94<3DcAD8h<c4e<CTaADH`>C4c=CE5=S<a>D@cASTa<C0e=S53ACA1
<T96>3I6=cM4=c52<D4c3CTcASE5<CA5A3I3=d<c@cM3<S8i@C<gATA5<c@g>48c
@d8b@c4`=dI6<cLb@CE3=3<f<cPb<C8`<cHh<@e3A3<f<TDbA3M5A4I3=d4c<3Lf
<3Lf<cPd@c8a<C0e>4<`<3Hg>356=D<`@SPe<38h<3@i<3<h@S@h@c@==DI4@D8a
=D4hACPaACU5<S<c@S96@D<g=494=CLh@c=5ASHcAS@b=cU6A3<d=cI4AC8b<4Da
=34a<CLd3D4dASLg@D4h<C93AC0d>3Th@THf=cTe>48h<DE1<c=4<3@d=4=1>C8`
=d4g<c14AC<d<DDh=d<e=C<`=`dg<4@g<38b=cU3>4He@SA5ACHc=38bAD53@TDf
@T52>4@c<C4`AR1>A0d_F4=4820b=3@PDT@P<SA5@d94<3DcAD8h<SU5=3@d@S0e
>DHi=D4aA3@aATE3<3E5@C8b@D4a>D@c=48e@C12<d<gAC8`<34b3D@b<D<g<D4h
>D92AS8i<SLh>4<c>38g=dHg<T4dAS55ASQ6=C0`<CE6=cDa<355AS96>D4h>4A4
<354>@e5@D4i<DE1<T95@SL`AS8h@CHbA3A5>34a<C<h<D=1=cTg@cH`=SQ4=cQ2
<3Lc@CTf@C@eAD4d=CLa<d8=A3A2=30d@T93@dE1@S8f=3@i=3DfAC<c<SU3=S4h
<T95AC@fAC=2=c=6=3=5<3U2<3Dc<D55AC@c@D@g3CE5=c<`=3Q6@C8a@S96<SLb
<44a<SPi=3Hh=S<c<34h<4Da>4Db<C4bAS@f=d4a<CE1>C15=D<`=SA5=Pdc<S<f
<3@c@C0d@SM4@D4dA3M6>CDb>CHb=S8b=DE3@D<d@CPc=C96=SPf<3Di=CU6=C4c
ASDaADDe<D4=ASLc=D@d<cA1<3I5<S0g>CI1>3I5>4E2>CPa<d<d=3<a@c51A34a
<3Q1<dHg=SHi=3<eASTf<TA1>C963C4b>4A3ASLa>D=6<cP`@dHh<3Tc<4De=3@h
>CI6>3I3@d@bA48b<d52=313=CLa=T8h=cQ2AD=6>4Dg<`dd<c@g<d8`@b1>A0d_
F4=5820a=SPPDT@P<SA5@d94<3DcAD92<C8b<DDb=TI3@d@hAD8i=dA2<cH`<CM3
AD4d@S@f<CI6AS56@cM3=cHc=3Hf@c@f3CTg=D8`=S@f>C0b=4D`@d8e@T4h<44i
=CHd=DD`>3A5=SLa<TE6<3<h@CDe=SA4ACPb@D4`ACHe@d8a@@di=CM1@CLg>CQ3
@S=5<C94A353<d53ADHbA3@a<T52A355<d4d<cPi@CHfA44b>C96<cDd@cT`A44f
<S8=<C4b>353ACA4=CPe<TI6=T8h>C@f=393<S51<cTdAD<h=4<gAC0b>3DiACLa
@CLa>34h<3M6=dHdATA43CI5=SLd=DDi<C54<CTi=4De>CTf@cHiAD4d@CPe@C8`
ADDf>D51=DDcATI4@d@f<CT`@S<e>3=4AS95<`e1AS<f@S@b=44e>C96<3I6ASPe
@C8d<34c=SLe<SHf@C93=S4PCT@=;eQ3AR0P<SPc8594838dAD=2A30e<dE2@T94
<38`=C0iA3La<30e@cI3=SA3=CE3<DI4<SH`=T@i<c54<3<g=CTd@d4e<cU4=`df
@S8i@dI3@S4g=DA3=4@b<DDg@C@i@D4d>3E1=CQ5>3Hb<cLd<CDe@SHi<SPd<S4h
@d4b<T8d<3PeASP=<TE4=CM5@SPdAC4f=cU5>3Ha>313@d4d=3HgA30aAT8bAS4e
AC<d<44bA3Te<CA2=CM1=D@f@CA3A3Pe3DD`@ST`<d=2=SPe<C16=C53=c4h@C12
<3Hb<315@c<a<4<f@T4d=C51>4De<c<d=dHi=S92>4A3ATI1<0d`<c@fAS@iA4E1
AC<g>3De<C0iADHf>3I6=d@i@DA5<dHe=CHd=STgA3Dc@C16@c52@c4hASLe@dHd
>4<=>3Lc>353>3<c=C=5@D@dADHe=TDg=T=3@S12=cPg=34c=CPh<44bAC<`>34c
A314<3A2>CQ1>C<f=C=13D=3<cLd<34b>C8eA4I2<S4g=T55=d4h@DHg@SHf@D4c
=DI4A38g@cM5AC4e@TDa>CU4@dE6@T8g<3Ph@`dh>4Da=CLi=T52<TI1=SE5>D4f
ASI1A44d@c8`A3Q6=cT`AS@gA353=d8f<CLi<393<cHc@d=4ASPfAS@=@dE2=T@e
=cLc=SHa<c0h=3E6@SI1=CQ5<3=4<c4fAD8c@D4d<d@aA4<e<SA6@c91@cHd>48h
<dHg@T8b3C12@SHa>D4h@d93@C11=3@b<D94@DHb<cHh84i43BmHA30P838f8594
838dAD=2A30e<dE2>D96=d4h=d@i>D55=d@i@c93<CDb<dHc<SHh>D91ATHg@dE5
A493@dHPCT@=;eQ4<B0P<SHPDT@P<SA5@d94<3DcAD92=DHdAD56A3I3@D<c<3Pe
<38a=D=3=cTdA3Lb@cA2<TA5<34d=38d@R1>A0d_F4@b820a<STPDT@P<SA5@d94
<3DcAD8i@CQ5=T<hATDi=d@g@d=6<d56@c=1@c0b>453>3@a>3Pf<TE5@TE3<D51
=SLcA3@g3C4dA3Pa<c<c>48fAC95>DHg<3U1<C@h@SLiA3U4=34b=4I5=4I2>396
<TE3AC@g<DDi=STa=STe=cA5=`df=D@aA4@f@T4h<44h=4D`>DDe>48iAS=2=c@e
=4A1ASHb@D54=SU2@TDe=C@cACM6@S=2<CTg@T96=3T==cQ1<3Lb=STe@SA6<TE3
@C<e<TE6>44f=SQ2=CI4=3Q1<C<g@dE1A3Db<3=3>D=5=T55<SDe@cPb=3Tb3CA3
>CU6AS95<S=3<d<c<30hA21>A0d_F4@c820a<SPPDT@P<SA5@d94<3DcAD8i@CQ5
=T<hATDhA34e@dDh<4I1<48hATE3=cTi>312=cTc=cE3AC12=491<CD`A3Ha3D=3
A34b>CU3>3TiAT=1@CLf>C4aA48a>D<c>CHh<TI3ACI2ACDa<4A3@C51ASPf@DHb
@CDa=3Tb@DHh<Pdb<c0e@CHeAT96@d=3=d8d@C4cA38h=c92=cPhACHh=30c=d@h
A3I3A30a<cHi>CM5ATE4>D<d<D96@S<=<c4d@CQ6<TI5@SPcA48g=48a=cM5<c4b
<dI5<SLcAC4`=CTb<d8g=SLe=DHdA351<3T`<4Dh>C91>CA63CLcASTh=c0a=C<i
@D<bASDPCT@=;eQ4=20P=c4PDT@P<SA5@d94<3DcAD8f=dDc<cI1@C@g<CHgASH`
<3=6<3Hb<T=6<3Lh>C8d@STa@T@d=38d<D53<3TcACA43C0`>4D`AS0eA4Dc>3<g
=dI2<S<d=3A1A3M1=C15=S4iADI6@DDh>D<f<34bASI3<4Hg=SI2=cQ5>D@h<Pdf
<S53@cPb>C54<S11>CPe<3E4A3Pg84i43BmHA3DP83L`8594838dAD=2A30e<dE2
=SM5<c<f@D4d=S@f>3Pg@DDh@STd=T=1@cD`>4De<DHi<cU5<TDa>44cAT<b<4He
@Pda>C<g<cHhA38e<cM4=3TcA3I1=cLc=c4a@T93<d4gA3I3@cTa>C4f<D4eA4=5
=D4a<cM1@C@a<D@b<3L=<3E5<T53A3E1AT=4<cHc@T4h<d<PCT@=;eQ4=R0P=C<P
DT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=dE4A44iA4H`@c=6<T@a<3L`<d8bA3Ti
@T8`<D4b<D4f>CA2<3E63C52=cM3>312@c=4<C<h>3Lf@S54=CHc=4Hg@C0g>C@f
=4E3>C51@dE4@D@b<4@PCT@=;eQ4=b0P=S0PDT@P<SA5@d94<3DcAD8h=cDc@d4d
A3I6=dE4A3Dd<D4dAT<f@c4d>CTa<34iACU4<DI2<c0a<d8f<CA5@cE63DHe=d4e
@T=6>C<h=38a>CM6A3L`<cHhAD@c>DE5<cPh<SM4=cE6@C0c>4Hh=CM6@TE4<3E5
@SHf@cI1@R1>A0d_F4@h820a<CHPDT@P<SA5@d94<3DcAD8iASPf<4I3AD4f@c8h
=44g>CHb<3@f<D<h<CLa=SHb@DHh>3Ph=SHc>D4g<493@dDg3DDd@C0c=S@i=3He
@dI6>C52<3Q1=48i<d=5@SDaA34i@SDh>CDf>C53@c51A30g<cLg<3HdAC8d<dA2
<0di@CQ3@d=6=CLi=C8a<3Hi=c<b=4<h>DHb@SPc=3Q5@cPe@C8f<CPfA4=4<C8b
@d=4AS4hAC<`ASDh>4@=A3Hb@SE4>CDa@cTfA38a<C4i>314@SQ5@dI2ASLh@dHe
>C<e<C4fAD4d<c@b<cM6@DA4>B1>A0d_F4@i820g=21BA20b=4E3@T@`=C=5@SU4
ACM2<3I1>3Lf=CE2AC13@T8d<CLi<CA4<C0iA4E4ACPi=T91<4I5@T=3@c=2=C@=
>3Tc@THa<d8`>4Hf>3H`@SPh=3Ta@T8h=d53=44fA3E6A44g<4<bATDc@c55<d95
=dA6=d4a=S4fAD<d3C=5AS4a>C4b>C55<SD`AT4`@c@f=c8`<DE4=c8PCT@=;eQ4
@B0P<STPDT@P<SA5@d94<3DcAD8`AD8`AS=1A4Di@T4c<D8c@S@g<cQ1<CLh=S51
@DDc=SA4>C15@S4a<SM1<dDi<b1>A0d_F4A2820a<cTPDT@P<SA5@d94<3DcAD8h
<SHg<cHi>3Pi<4=5A38eATA5=SU3AS8i>3U2@SDi@T96>38a@T@f>451>C94@c14
3C=5@S<gACH`@C54@S91@DD`@CM3<SPi=C0c<3Ld<3Pa<S14<SH`<451>CQ1=355
<C4i=TE1>C4`@c92=0e2=4@cAC11<312=c@b@S0b=c53<d@d@CTiASPg<CE2@c0e
=DDaAS@g<cHgAT=2=4I4<SHdA4A4=S0cACH==D8bA4Hg=SDg@S8f@TDa>34e<C51
<D@b<d<g<T<e=38cACHe>4I6A3=3=4E5<3<g<d8b=S8f<3Pi<C953CDc=T=2<492
>DI4<TI1=d91ASTi=TH`=DA6=SPa>4A5=c4aA3Dd84i43BmHA4<P83@c8594838d
AD=2A30e<dE2=SI2AC4c<C<h<C<`<cTb@cTdACA2AS0fA3Tg=d=2@d@i=4I4=SP`
<d54<CM4@SDh@PdbASPb=d=1<D8g=d<`<3Hf<dDfACI5=d56@R1>A0d_F4A4820d
<b1BA20b=4E3@T@`=C=5@SHf@TDa<c4c>34c=3Q6AD8h<c8c>30f=d8`=cA2=D4g
ADH`=THgAT8e=STc<CHbAS8=@TI6@DDi=c=3A3A2=4I3ACI2=c0a<THi<3@PCT@=
;eQ4AB0P>C4PDT@P<SA5@d94<3DcAD8i@c=2@c8e>DA1AS4dAC52@TDi@CTfA3Da
A34a@dHc<cDa<SDe<SDh=3Tc@T93=c943DHg>C8e<TE1<4@c>4Di=C0f=CA2>3@h
=3Pa@T4`>4I3=3Pd<D=4<T8h<T8eA3@b@S93<4A1=dE5AS0eA@e3AD56<D4`@c@e
<C16AS51=38a=SDa<C<a=S@b=DDbA3<d@cA2=S16@d4eASPb@S0`>3De=34`<S11
AT<=>CHPCT@=;eQ4AR0P<C0`8594838dAD=2A30e<dE2>D<c@T<b=CU4@DHg<cHi
@C0d=DA5<cM3@D8b=cTa@D@d@T<a@cPb@SPc=THf>3E1<Pdg=44g@CTe=dA1<cTg
=d8a@T91<c=5=456ASU3=4@`>30`@CU3=48d<dE6=4@b@T@a=4I2>C0h<TI1=S0=
@CDa@cE4=CDc<TH`@DI3AT4i=313@dDd@d<g<dA5=491A3<f@cA6@c54=cI1>3Q6
ACHhADE1>DA2@T<d3CQ6<4=5>CU2@cI4=c=2@S@f=dDa84i43BmHAC0P83Pg8594
838dAD=2A30e<dE2>3Le<d=1=4@fASL`=S4bASHb@C4f<TDc=S<b@CU5<cA1>4Hf
AC4b@D@d=dDb>44e>0d`=S8d=30eAT@c<4I2=3@e=SQ6=C8b>3<e@SDh=T=4=CPi
@d@a=CTa<T@d<c0eACDg@CM4<CA5@cTi=D<==CHg<T<h<D<b>3<f<S0b=S0f>3Ta
@cLa>DDb=4I4<C@iA355=C=5<3E1=T4g=c<d<3Da<dDb84i43BmHAC4P838i8594
838dAD=2A30e<dE2>3Le<d=1=4@fASPdASTg<SA5=3=2@cTd>DDg<D<h=cQ2>C@f
>48c@SDfA3=5=4@PCT@=;eQ5<R0P=c0PDT@P<SA5@d94<3DcAD8f=dDc<cI1@C@f
=3I2<cQ3<cQ1<cHc=C14@d=6ASM5ASE4=cU4=THa<C=1@TH`=4<h3C54=d=2A4Hg
@cL`@d93AT@h<S96AT<e=SU3=34hAT<d>392=SL`ACI4=cHg<cLcAD<a<TI4@TH`
>CU3<Pde@CU3<c95=dI3=c4e=S4b>48e@b1>A0d_F4Dc820a<SPPDT@P<SA5@d94
<3DcAD8i@CQ5=T<hATDhA34f@cLiAD8gAS=2<C8d=CPiATI1AS@i=c<c@c8b>4Hb
=3@f=C913DH`@C8dA3I6<3Th=3U4=D@a=4Dg>4I5A4E6=cE5@d8g=DHg>CP`<SM4
AS@h@c4b=C4d>34b@SA6=D4i>0diAST`=3=6ATI1A3Pd=cQ4A3<c=T<b>D@e>3=1
@DI6<cHd=cLh<CPa=C@hA4E1=cDaADHc<3Ph=3A2=cL=<3@e<38d>4<fA452<3A6
>D=5A4E5<C<d=4I2>CM3<T8f>DI4@T8b<c15<cHf<SPc<4<d=38g@SLf=dD`3D8c
<3H`<D4e<SE4>C<h<THPCT@=;eQ5=20P<cTc8594838dAD=2A30e<dE2AC<`<T<a
<d@d@DDe@DHe<dA2=cD`ASQ4@CE1@SLeACE3=4<b<THc<SDe@D@g@C=3@Pdb=SPi
AD=6A3M6>3@d=3Da=d4`=CM4=S96AS<g=3I1>3=3>394A3A5>C=3@DDd@T53>3E4
>34d<SA2AD<=@S8aA496=3DgATA3=SQ5<SE4<S0g=CM3<SLa=d@f<SPi<3U4=C=3
=c95@SH`<cM6@D4d=CTiAT@d=D553D4`A3U3<4He=T@a<CM2<CDhASHa<4@h<D<c
<C93<d4iA4Hh=3E6=496<D4a=38i>CHi<34h>3Tf<CHe=`dh<T4f<dH`ACM2=TA1
@THe@D52ATA6<D=5<4A1<C=3ACE1<D@h=44`<4A6<CLfA394<c8g>CHe=dHd@T@=
AT<c=cLaAC53=d8b@c14<T<b>4Ha>C0b<3<g@cDd>C=6@CQ3>C8f<CI5<S0d<d8i
<d51=dI4@SE1=CPd3DHa>CLfA3Pg<S52AC<a<T<b>3Lf@S=4@C4c=314<CA2AS93
@CPhAD4f=CTi=3<f@c12@CHh=S@iAD95<`e1<DHh@STd@T=3A3PdA4=4@C53@SI1
=C@g>3Q6<SH`AS<e@CPbADDfASHhA3Le=S@`<D8i=DI2=C8gA3<=A4E5A3Hb<c0i
@C=1<S8eA4E1ADHa=4<f=4Da=c<b@C@d@SQ4A4Db>3M1<D93@DA5>4Da=SU4A356
<d4b3CM1<cPi<CDd@D93<48dAD@e=T<hA3Lc@c8b<cQ4=SP`A3A2ACD`>DA5=352
=TDd=c<d<d8iAC<g=d54@Pdc<c@f@c14=SLgAS@`AD8f<dH`=454@CHfATDe=dHf
AS<f>4A5@SQ3<D8i=CE2@DA4=SQ1=cH`<cPg@S<==C=5>C=5=S=4@D@i<3U3@D55
=d=2=C56A3E4@cQ6A3HdASP`=C4f@C@b=3Hf=CQ2@T92<cU1AT8eACHc3D4i<d4d
<D@b<cI4=T@bASM2=THd=4Df@S8hADI6@C53<T@hACDa<C<c@D8c>3Ta=SE1ASHb
<STc@D8f=Pe5=CHa@SLPCT@=;eQ5=B0P>3HPDT@P<SA5@d94<3DcAD8h<c4e<CTa
ADH`>C4c=CE5=S<a>D@cASTa<C0e=S53ACA1<T96>3I6=cM4=c52<D4c3CTcASE5
<CA5A3I3=d<c@cM3<S8i@C<gATA5<c@g>48c@d8b@c4`=dI6<cLb@CE3=3<f<cPb
<C8`<cHi@`di<C8g>3HfA44hAC95@cLaACDb<c16=3PcA48f>3Hc>4Hh@TI1A3<a
<4I6AS53@D8d<CH`84i43BmHACHP83Lc8594838dAD=2A30e<dE2>DI3@D4`=c4e
=4Hi@T8`<4@iAC52=4<`@d@bA3H`<CA4AS@cA3Tc@c16<c53AS@b<Pe4@T8`>38a
<S=1=c0`>3PgADI5AC56=SA5ASDb@T4iA4HbA455=cM2>CE4AD4b@DE1=cU4<48e
>CTg@d8=@C55@d=6>3Hc>D<h@c0c>DI5=D@e=D4g<c8PCT@=;eQ5=b0P>30PDT@P
<SA5@d94<3DcAD8h<c4e<CTaADH`>C4c=CE5=S<a>D@cASTa<C0e=S53ACA1<T96
>3I6=cM4=c52<D4c3CTcASE5<CA5A3I3=d<c@cM3<S8i@C<gATA5<c@g>48c@d8b
@c4`=dI6<cLb@CE3=3<f<cPb<C8`<cHi@`e6A314=3Lh@d4h@dHiA3E6=c<g>3U6
@T4f>316=3@f<3Hi=4=3=STc84i43BmHACPP83Lb8594838dAD=2A30e<dE2>DI3
@D4`=c4e=4Hi@T8`<4@iAC52=4<`@d@bA3H`<CA4AS@cA3Tc@c16<c53AS@b<Pe4
@T8`>38a<S=1=c0`>3PgADI5AC56=SA5ASDb@T4iA4@i@cE3=SDi<T<i>3Le@SU2
<4=3@dHh=453AS@=<D=2<30f>CA3A3Hi=S4a>4DhAS0gAC<h84i43BmHACTP83Hg
8594838dAD=2A30e<dE2>DI3@D4`=c4e=4Hi@T8`<4@iAC52=4<`@d@bA3H`<CA4
AS@cA3Tc@c16<c53AS@b<Pe4@T8`>38a<S=1=c0`>3PgADI5AC56=SA5ASDb@T4i
A4I4<C8h<T@d=cA6=SU1=SLiATDd=38`<493=c@=<CT`A38a=CLb=3=2ATDPCT@=
;eQ5@B0P=3@PDT@P<SA5@d94<3DcAD8f<d8c=CU5AC@d<3<`@STh@CLa<4Ha<3M2
@cHh@C<fAC8`AD4e@T<`<SM4=T<b<CLe3DHh>3<d=c55=3Hf<S<cA4@`@SI6<3Ph
=T56@S8PCT@=;eQ5@R0P=C0PDT@P<SA5@d94<3DcAD8f<d8c=CU5AC@d<3<`@STh
@CLa<4Ha<3M2@cHh@C<fAC8`AD4e<d@f@C4i=SH`>3@i3C8i<S56=c@fAD<d=S4a
@SPdASH`@D54=cPbASHa=c<f=T=4=CL`<THPCT@=;eQ5@b0P=C4PDT@P<SA5@d94
<3DcAD8f<d8c=CU5AC@d<3<`@STh@CLa<4Ha<3M2@cHh@C<fAC8`AD4e=SLb>C<g
@SQ5<3U63D94<3A5ACDf=3@i<SI3<C<d@S@h@THhACU6=452>396AC<d=3<f@d=3
<b1>A0d_F4E4820d=B1BA20b=4E3@T@`=C=5@SHc@S<e>DE5=3@`<c12>CQ1=c4`
AS4`=d93=SQ1<cI5<S15@CDf@TDh@c8gAS0h<T4==C0i=TH`@S8b<cLd=C51=SQ4
>DDcAD8a@TA2>4Hh84i43BmHADDP834e=21BA20b=4E3@T@`=C=5@SPb>DDd=3A2
<3DiASTe@C54=356AD<`=DE1<S91@C4iA3<d@SE1<48c@cM5<S0`<C8=A38a@cLa
@CPi@T96<STb=cPh@c<h<SLgASLb@CA6<DE6>4He<30a=DHg=C4`<DE6<THi@CPh
A4@`<D@i3DE1@CTaAD4b@TE2=c16<SQ1=S94=4Dh<C4a<cPa@d4g>CM3=S0f>4@g
>48`=c=1>CI1=3E5@C@e=c4c@Pe4=48d<3A2@T=3AD52<SHd=3Td=CI5<c<b>D<f
<CPb@TE5=3I5<d8g<dHd<dD`>D8`=C<a@DE5=3=1A3L==DDg<c0d>4I1<S52<THb
=c8`@C4b>3Td=SPf<c=6<316<3A2<SPf=C=1>4<i>DE5@S@h@T<d=C52<48a3CE5
ADE5@C0b84i43BmHADHP834f<21BA20b=4E3@T@`=C=5@SPb>DDd=3A2<3DiASTe
@C54=356AD<`=DE1<S91@C4iA3<d@SE1<48c@cM5<S0`<C8=A38a@cLa@CPi@T96
<STb=cPh@c<h<SLgASLb@CA6<DE6>4He<30a=DHg=C4`<DE6<THi@CPhA4@`<D@i
3DE1@CTaAD4b@TE2=c16<SQ1=S94=4Dh<C4a<cPa@d4g>CM3=S0f>4@g>48`=c=1
>CI1=3E5@C@e=c4c@Pe4=48d<3A2@T=3AD52<SHd=3Td=CI5<c<b>D<f<CPb@TE5
=3I5<d8g<dHd<dD`>D8`=C<a@DE5=3=1A3L==DDg<c0d>4I1<S52<THb=c8`@C4b
>3Td=SPf<d95>CPd=3I3>CHhAS0b@DDe=c<b=c4a<C8e<C8d>3Hf3DA3ATE2<C53
=D@c<c15A4Hb@CI184i43BmHAS0P838a>B1BA20b=4E3@T@`=C=5@SQ6<3I4=SU6
<4E3=DDdACI3<THf<3@b>C=6=D93=cHb@CHa=3Te<S56A4<g<C0f@CH=ASM1<c54
>CTb>DHh=T4c<CM5<4I4<cLeA3E2>3E4=30`@C@e=S14<D<d<3I5<3Ti<d<g<CD`
=cDc=SA63DE3=4De>D<i=3<a>4I3@DE3=CHf<cTh@S0f>355AS16@CDb@D<iACI2
<T<i=CU3<C@i<S@a>4E6AD4d<@e6<48h@C<e<48`A4A3<c=4<cM3<352>452<SA1
=CQ5<44i=3Tg=SLf<3M6=S@h>3Q6@SQ3<D91@CPgA48=A3=4=CTh>3U5<d@g>D<d
<c=4=C16AC55<T4f<TDe>3=4@C@gAT96>3U6=dI4A30g>30e<S8c=495=D513C@h
=4H`=34gAS94<d=3A3U6=c94<cTb=dE4=30i=T4e<3<e>DE5A4I1<TDd@cLa>C8g
ADE4=3Q6<D4f>0e1AS0g<DE5AT<b@CM5A3=5@C4i<44b>30g<SM3ADI4=C12=d4h
@S4e@dI5<CU1@SL`=SM4A3Lf@c0f@dD==3Hf<cLg>CP`@S4gA44`=d4h84i43BmH
AS4P834e=B1BA20b=4E3@T@`=C=5@SPb>DDd=3A2<3DiASTe@C54=356AD<`=DE1
<S91@C4iA3<d@SE1<48c@cM5<S0`<C8=A38a@cLa@CPi@T96<STb=cPh@c<h<SLg
ASLb@CA6<DE6>4He<30a=DHg=C4`<DE6<THi@CPhA4@`<D@i3DE1@CTaAD4b@TE2
=c16<SQ1=S94=4Dh<C4a<cPa@d4g>CM3=S0f>4@g>48`=c=1>CI1=3E5@C@e=c4c
@Pe4=48d<3A2@T=3AD52<SHd=3Td=CI5<c<b>D<f<CPb@TE5=3I5<d8g<dHd<dD`
>D8`=C<a@DE5=3=1A3L==DDg<c0d>4I1<S52<THb=c8`@C4b>3Td=SPf<cU1<SU2
<d@e<T96@CU2<dD`AT<g@SPg>CTi<34d=48a3CM4AT4a>356<C<PCT@=;eQ6<R0P
<C<e8594838dAD=2A30e<dE2>3Le<d=1=4@f@cLi<SDc<S<eADHd<cLbA38a<44a
AC=5<3Pf=T@h@d94>C8`=C16>0dbAS12<DDfA44`=cDfAD<hAS0b@C0h<STd>3Q1
A34dAT8g@CI6@CTg=3@g@cE2<C53@DHd<D8`=c@f<C@=@T8dATDa@T56ASPf=C=1
A3@h<3E2AC11<SI3<DE1<496@c14<CPd@CU4ATE3>3E4A3LiA3M5A38`<3Df3CU2
<SE3@C94=D@b=d=1A4Hf<CLf<4Dc>D@aAC@a@d=4@CTg>C4h@CE2=D55=3Li=CE2
<452<S<a=d<h@@e5=CH`=SHg=S53A3PbAC16<4=1<STb<T52=4@b@DDPCT@=;eQ6
<b0P<C@b8594838dAD=2A30e<dE2>3Le<d=1=4@f@cLi<SDc<S<eADHd<cLbA38a
<44aAC=5<3Pf=T@h@d94>C8`=C16>0dbAS12<DDfA44`=cDfAD<hAS0b@C0h<STd
>3Q1A34dAT8g@CI6@CTg=3@g@cE2<C53@DHd<D8`=c@f<C@=@T8dATDa@T56ASPf
=C=1A3@h<3E2AC11<SI3<DE1<496@c14<CPd@CU4ATE3>3E4A3LiA3M5A38`<3Df
3CU2<SE3@C94=D@b=d=1A4Hf<CLf<4Dc>D@aAC@a@d=4@CTg>C4h@CE2=D55=3Li
=CE2<44`AC@f=SU5=`e1<S8i=C@f<cA3ADDf@S=6=DA2>D<i>D94ATE2<SH`<CPa
ASP`@SI6>4I4@R1>A0d_F4Hd820a<cDPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I3
=cTb=C<b<cE5AS@c=c94<S4`@C55<dD`>3HfA3Q3@T@i<S0e<4Hh3C96<48aACI4
@C0g=CI5@cQ6<391<3Pb>C@h>454<CA6@SM1=TI1>CLd=3M3=D8a<D=1AS@a@S0g
=3Ha=0e2@SA6AC52@DI6>3He<d54=3P`=D95<44b=T<aAD4`@TI3<4@a>3A1>DA6
AD<h=DA4=cU4=dE4<S0`=CH=>D8b=D=1<T@eA38g@d54ASHa=cH`AC<iA355=353
@dA1>CLi<CQ1=D8e@DDd=cTe=D8`=CE6<S0f<D8f3DA5ATHh@c92<cI4@D96<T93
<3Tb=dDg<3U6ACDc<B1>A0d_F4He820b=R1BA20b=4E3@T@`=C=5@SI3<S55=d@f
@c@i@S4`=c4i=T56AD8h=4<c@S4i<d<i=cL`<4<a=C4c84i43BmHASHP83<i8594
838dAD=2A30e<dE2>D=2<STg<T=2<3TeA3H`<4E4@d55<cHc=DDh<38e>48hAD4b
<48cAST`AD4e<SDbA@e6<4<b@SI5>3L`@SHd<CPhASDPCT@=;eQ6=b0P<C0`8594
838dAD=2A30e<dE2>D=2<STg<T=2<3U2ASHf=4De=DHg=3Pe<351ACI2>4Hc<4Hc
<CPi>DA4ASE1<c0d<`de=D96AS51=4De=4E4>3Ta@T@a@T@c=c0`=3@i<C@eAS0b
@c0e=C53<S56<c92>C4h=d8a@cQ3AD8a=DH=<d=3@THf=SHb<SM2=4Hh@S14>CL`
AT8e=TE1<3U2=4@gA44g>C@g@TA6<c0hA38a<c8e@THd>D@iAD@f3D@e>DHb<SI3
ASU3@dHd>3PcAS9284i43BmHASPP838g8594838dAD=2A30e<dE2>D=2<STg<T=2
<3U4=D4e=C0`<3Ph=d8d=3=4@STf<C=2@d<a=3Td@cE2A21>A0d_F4Hi820i<B1B
A20b=4E3@T@`=C=5@SU3@S8i=c93@S0i>4<h=TI1<c8`@TA6=4=4@D52@C93ADA2
A3Pf@T55@S<gAS=6<3P=<3I2@S95>34a@c4e<4@f@dHc=c@a<D<g<D94A4He<dI5
@T8e>3<a>C0c<c8e=DDh>CHd=S8h>C=6=S913CA1<SU4ACE2=c<`<T92>4I3<STg
=dE4>44hASP`>C54=48`=4=4A4DaACU5>34c<S4g@C15AS<a>CTg@@e2>B1>A0d_
F4I1820b=B1BA20b=4E3@T@`=C=5@SU3@S8i=c93@S0i=SPh<CU1<SE6<T8e@D@f
AS@eA396>316>C@g=21>A0d_F4I2820a<c8PDT@P<SA5@d94<3DcAD8i@d8b>CLb
@d8`>CE4=S0f<c@a@D4`@S56=48f=3Q2<T8`>3Tg=3Dc>34c=c8a=34`3DE3=dHa
=4@h=C@e>3PiASTe<C53=c8a<TA4<SA5@TI4@T4c=455=d4f@cHf<DHaADI2@D8e
<3LhA3Ti>0d`<c=4>3H`=38d>D4hA3=3<T<c@SPg<CE6>3M5<SL`<SPi=SLe=cLc
=S@b<D4`A48h=S8i<CU2<c0gASP=<C8`A356AS=3>C0f<c@f@S@i@T<f>3@b=30c
AS14=S16<cU4<C0gA3M3>DA1@dHiAT@hAC<b@DE1A3A13C8i<c@i=THi<cTi=CLe
<c<eAT8i=cM4<B1>A0d_F4I3820h>21BA20b=4E3@T@`=C=5@SU3@S8i=c93@S0i
<cQ4<STg=cDb@cTc=4Hf>CQ6<c96<CDh=TA1A4@f<D<`A4@i<D@=<c0b=cM4<34b
@d95<4=3>3Df>CI5@T@a<3L`=C8d<d@`=D8g@TDg<cU2@cPbA3Q4@c@f=3He=3Dc
>CTi3D55<CU2<DI4@T8b=C13>D@d>CHd@d96<TDh<352=T4`=T=3ASU2<SHe=TE5
>CA2<c=6=D<i=3A684i43BmHAT@P83@e8594838dAD=2A30e<dE2>D=2<STg<T=2
<3Tg=cHi=4<g=C4i=4A6ATA6A3Q1>C4f@TA5=d56@d4c=3@b@TDgAPdcACPh>4E2
AT<bASTi<3@h<S4fASE5<cTf=c8e<d4PCT@=;eQ6AB0P>38PDT@P<SA5@d94<3Dc
AD8i@d8b>CLb@d8`=SLe<c8f@cLg@CM3@D8g=cE6@CHaATHi=cHgAD4e=3@g=DI4
@D543C4c=S8eAD<f<CLgAT@f=CTh=4=1@C8i002Q0<00ndDf<c95<DDb<4<b<391
>4@h<C4h@DDc<48`>DHc@SPh<dHc=DH=<4E1=4Da>3<b=CE6A30h=c8iASU6<CPh
>CLe@C<g>C4b<d@b@C<f>C0a>D<PCT@=;eQ6AR0P<cTPDT@P<SA5@d94<3DcAD8i
@d8b>CLb@d8`>CE4=S0`<dI5=dDi@c4c<34fA495>D=4@c<b=3Hb<c0g=3Q1AS@c
3C4h<cM2=CLcAS4i=SM6A3Pa=b1>A0eUKV@=IFiT3G1eM0e`MG@=I7E`82m6Kfid
CV5]IB1WIG@PIGQSJ21TIFIYKVEVKfid871_L0dU9DE^I59ULfmeLV=U80d=002Q
0<01UBmOGem6CS4P;dMUKVEfHB0_AfE^IGIQ86AeL21VJFiTIVm^M21TMG0P;d=X
HG9CM79YKVMc86]^KgM^87]RIFMYKR13J65bDgAbJFiWLb0_@FAYIG9ULfUc86]^
KgM^87/]<B1mNbdaOB1YIVE/LfDPIFiTOB1kL6m`82daOB1YIVE/LfDPLVH=<21Y
I0da86IT3C0P<S0a87AbHFicK65dI@dc<30P;C<`<21cHfaY3BDUAFiTDfEdMG0P
3BDU@VEWJFi@HFMUDfEdMG0P3G1]3BDUAFiTD65WIE=UM7E`3Bm4IGIYHfEBAd8P
Lf=c3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=830PK6<=838PK6X=E21cH@dU
L65WIB1bIF=d>R0a<S@P>CTP=3Db83<`<20=LgA]3C0P<20`86Hc3C4g;S<f<C0P
<CL^<cHa<21cL0da<Bhe86a]3B0`86aZ3Fi`3CTi>Bhc=CDh83<`;ST`=C8PKG@=
>CTi;S<e=CPP<c0b=Bhf>34g86aY3FAc3@00X@3000=WL`d00:40`02W<20`830P
IS<=KW0=<C0f=bha=SPc834i=2ha=c@d86ed3C4`=SL^<CHh<b0a>C@^<CLd=20i
>CT^=c8`<B0b<SD^<c0a=b0i<c4^=C@b=R0a>C<^=3<c=21SM0di=3@^<C@g=B0a
=C<^=34b=R0a<30`;S@g<b0]<2hP<C0`<2hd=c<P;C0^86=d3C4`=SL^<CHh<b0a
>C@^<CLd=21/J@eSL0eTI@d00:40`003Ig8=002Q0<00179dK@d0X@3003mcM6d=
<20`830PIS<=KW0=>CPf;S<c=B0c<38e;SHh<CLPKG@==CHf<2hg>C0e83<`<SD^
=SPa=b1/J@eTL`d00:40`003Ig<=002Q0<00^c0P<20`86Hc3Fi`3CDd>CL^=C8a
=R0b>CDg;SPg<3<PKG@==C@i=bhe<S4f838i=CL^>3L`<b0e=3Hf;S<i=3<P<c0b
=Bhc<CPe83Dd>CP^<SHb=R0c<3Tc;S@i=R1SM0de=C<h;S8h<c@P<c0h<2hh>C4a
83Df>C4^=STf83<`<S@^=CHe=R0e=STa;SHi=R0c<38d;SDf=CHPHg@==C@i=bhe
<S4f838i=CL^>3L`<b1/J@eSL0eTI@d00:40`003Ig8=002Q0<00179dK@d0X@30
02McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`02`
LgA]3C4^=C0`<20`;S0`<30P<2h`<30`834^=C0`<20]=C4i;S8`>C4P;CDf<Rhc
<SD`86=c3C8`>2hc<c8c86IdL`d_GemOATha86=fLfH=<20`830PIS<=AR1cH@dc
=3<^>CLa>B0g<SD^<c@`=R1]M0dXM21_LR1^:B1K>C8^<cLP=ST^=3PP<C8f;S8d
83P`;S@f83Hi;S@h830PGB1hLfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=0:40`027
LgA]3C0P<20`86Hc3Fi`3CDh;SDi<cDP=CP^=CTc=B0a=c<i;S4h=cTP<CTa=bhe
>C0a86E`3FAU3C0P<20`86Hc3C4g;S<f<C0P<CL^<cHa<21cL0e^L0de>2he>C<e
83Dh;SDi<cDP<CLc>Bha>3Li834i<CL^=CT`<B1UL0eTL`ebM6d=002Q0<00M7=d
K@d`830P<21V<`e^L0de>2he>C<e83Dh;SDi<cDP<S@g=2hh=S4c834i<CL^=CT`
<B1UL0eTI@d`830P<21V<`e^L0de>2he>C<e83Dh;SDi<cDP<S@g=2hh=S4c834i
<CL^=CT`<B1UL0eTL`ebM6d=0:40`01dLgA]3C0P<20`86Hc3Fi`3CDh;SDi<cDP
=CP^=CTc=B0c<S4`;SDc=3HP<CTa=bhe>C0a86E`3FAU3C0P<20`86Hc3Fi`3CDh
;SDi<cDP=CP^=CTc=B0c<S4`;SDc=3HP<CTa=bhe>C0a86E`3FAc3G9dK@d0X@30
04ecM6d=<2he=c0c830^=CL`<b0`;SDg<3<PIS<=KW0==CP^=CTc=B0e>2he>C<e
838h<cT^=3@b>20a=C@f;S@i>38PIG0=I7<=LWA]3@00X@3004acM6d=<2he=c0c
830^=CL`<b0`;SDg<3<PIS<=KW0==CP^=CTc=B0e>2he>C<e838`>CL^<SDi834e
=3H^=3Th<R1UL0eTL`ebM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b
=C0PLg0=<20`830PIS<=002Q0<00R7=dK@da;SD`<30P<2h`<30`830^<30`<20a
;SD`<30P;CDa>Bhb<3Ta82de=S8^<c8e<21SL`da=CH^<S@i<R1VM7<=;emOGdI>
<B1SMW=V3C0P<20`86Hc3DHPLf4=>38d;SDg<34P<CHi<Bh`=3Le86ed3BQ^:B0P
LfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e
<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00TG=dK@da;SD`<30P<2h`<30`830^
<30`<20a;SD`<30P;CDa>Bhb<3Ta82de=S8^<c8e<21SL`d`830P<21V<`e687=Q
3C@d<Bhf<SLf834d=CH^=SLc=b1]M0dXKR/a;c8Y85/i<Bha=b0a<3@^<C@P<C0d
;S4d83Pd;S0h830PGB1hLfQ_M`eD87=Q3G9dK@d00:40`004LWA]3@2Q0<009g=d
K@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@30089cM6d=
<Bhe<30`830^<30`<20`;S0`<30P<Bhe<30`82de<CT^<S0i<B0]=CHb;S<b=C0P
Hg<=<20`830PIS<=AR1cH@df<SP^<SDh=R0a<S0`;SDi>3HPKG@=:6h[<BTPFcTa
;S4g834`=2ha=20`85dPN7=XKgL=E21cH@ebM6d=0:40`004LWA]3@2Q0<009g=d
K@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@3006mcM6d=
<Bhe<30`830^<30`<20`;S0`<30P<Bhe<30`82de<CT^<S0i<B0]=CHb;S<b=C0P
Hg<=<20`830PIS<=AR1cH@da>CPc;S@a>3@P<SHc=bhb<S<c86ed3BQZ:B0PLfQ_
M`eD87=Q3G9dK@d00:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P
<2ha<SD`87=`3C0P<20`86Hc3@00X@3008=cM6d=<Bhe<30`830^<30`<20`;S0`
<30P<Bhe<30`82de<CT^<S0i<B0]=CHb;S<b=C0PHg<=<20`830PIS<=AR1cH@db
<cPf;S0f<S8P<SHc=bhb<S<c86ed3BQZ:c4Y85/d<bha>20a<3@^<C@P<21M87Qc
J6mg3E@PLf4=LWA]3@00X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e
<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00PW=dK@da;SD`<30P<2h`<30`830^
<30`<20a;SD`<30P;CDa>Bhb<3Ta82de=S8^<c8e<21SL`d`830P<21V<`e687=Q
3C4d<c4^<S0e>B0b=S<g;S8b<c<PKG@=:6X]<BTPFc@c;S4h83Di;S8`830PGB1h
LfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e
<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00]W=dK@da;SD`<30P<2h`<30`830^
<30`<20a;SD`<30P;CDa>Bhb<3Ta82de=S8^<c8e<21SL`d`830P<21V<`e687=Q
3C<b<3H^<cL`=B0a<cDf;SPd=cPPKG@=:6QQK6HPLgAUL5``<CDY85/i<Bha=b0h
=Rhd=20c=Rhg<20f<2hi=R0e<Rha<B0g>Bhe=b0f>Bhb=b0h>Bhi=B0i=2h`=b0`
85dPN7=XKgL=E21cH@ebM6d=0:40`02>LgA]3C4^=C0`<20`;S0`<30P<2h`<30`
834^=C0`<20]=C4i;S8`>C4P;CDf<Rhc<SD`86=c3DHPLf4=<c8`=Rhc=c0e834e
=S@^=SDg<R1]M0dXL6mYKWAc:B1K>C@^<3LP>C@^=SPP<cH^=c0P>C4^<CLP=ST^
<SLP<21M87QcJ6mg3E@PLf4=LWA]3@2Q0<00179dK@d0X@3005AcM6d=<20`830P
IS<=<CL^<cHa<20a=bhc=S4`87=`3Fi`3C<d<3@^>C@b=B0a<STg;S4g=3TPKG@=
<S8c<bh`=c<e834e<CP^=C8g>B1/J@eTL`d0X@3000=WL`d00:40`02n<20`830P
IS<=KW0=<S@`=Rh`=cPc834e=C@^>3Tb<b1]M0db=30f;S0g>3<P<CDe=2hh>C8c
838d<S@^<C@e=B0a=3Pb;SPc>3LP<S<h<2ha=cHe834d<S4^=cHa<R1SM0db<c@c
;S4i<3PP<C@d<Bhe=cDc838b<38^>3Th>B0a=C8e;S<i=c8P<S8`<Rhh>CPi834e
<SD^<cTg<R1SM0db=30f;S0g>3<P<CDe=2hh>C8c86aY3F=`3FAU3@2Q0<000fMb
3@00X@3000AbM6d=0:40`010LgA]3C0P<20`86Hc3Fi`3C@a=cT^=SLh<R0a=STd
;S<`>3<PKG@=<c0`<Bhb>CPh834e=c0^=S4a86aY3FAc3@2Q0<000fMc3@00X@30
0;/`830P<21V<`e^L0dc<CDf;SDh=SPP<CHe=Bha=C@PKG@=<c4e=Rhe>3Hh834f
=CD^<CDd83<a>C@^=CPe<R0a=CTa;S<b<cPP<c4g<2h`<3Pd834e<S0^<CTa>B1S
M0dc<C8h;SPi<3<P<CDb>2he=3Ti838i=c0^=3<e=R0a=CHh;SDe<S@P<STg<2hd
<cDf834e=SP^=CDb=21SM0dc<CDf;SDh=SPP<CHe=Bha=C@PK6T=Hg0=I6D=002Q
0<000fMb3@00X@3000AbM6d=0:40`015LgA]3C0P<20`86Hc3Fi`3C<c>3D^=34a
=20a<STg;S4g=3TPKG@==38a<Rhb<c0a834d<S0^>3Lb<B1/J@eTL`ebM6d=002Q
0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@30
0;=cM6d=<Bhe<30`830^<30`<20`;S0`<30P<Bhe<30`82de<CT^<S0i<B0]=CHb
;S<b=C0PHg<=<S0h;S<c<S<PIWAc3BmOGem6CS4PHgIcIPd`830P<21V<`e687=Q
3C<c=CH^<C0i=20b=S4g;SHi<S4PKG@=:7PPKg8PJRTPFc4a<2hd=b0f>Bhd>20a
<SH^<S@P>30^=3HP=ST^=3PP<21M87QcJ6mg3E@PLf4=LWA]3@00X@3000AbM6d=
0:40`01GLgA]3C0P<20`86Hc3C4g;S<f<C0P<CL^<cHa<21cL0e^L0di<34^<SHc
=b0a>3Tb;S@c>C8PKG@=<C0i=Rhe=cDc834h>C8^=3<i<R1/J@eTL`ebM6d=002Q
0<00A7=dK@d`830P<21V<`e^L0di<34^<SHc=b0a<CHc;S8g=S8PKG@=<C0i=Rhe
=cDc834a=S<^<SLf<R1/J@eTL`ebM6d=0:40`015LgA]3C0P<20`86Hc3Fi`3C4g
=34^<3Te<b0b>C4d;SDf<3PPKG@=<CLd<Bh`>CDc83<a<3T^>3Lb<b1/J@eTL`eb
M6d=002Q0<00AG=dK@d`830P<21V<`e^L0db=3Lf;SLf>3HP<STb<Bh`=c4b86ed
3C8d=cH^=cHh=R0c<C4f;S<h<SLPK6T=I7<=LWA]3@00X@3004=cM6d=<20`830P
IS<=KW0=<c8a<Rhd=38P<STb=bhe>34f86ed3C<b<C8^=3@b83<a<S8^>3Tc<B1/
J@eTL`ebM6d=002Q0<002WAULVeYKV5dI@d0X02o0:00_P2J0000ohnP000000=7
0nP00004000000180000B0000100800300P00000000000FR]NP000000dL3j000
0003A`?[0000<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0>H7oR?l10021oh7oPOn1oh7oPOn1oi_o0@00
POn1oh7oPOn1oh7oPOnKo`40087oPOn1oh7oPOnDo`0iPOn8o`40087oPOn1oh7o
POn1oh7oVol10021oh7oPOn1oh7oPOn1oi_o0@00POn1oh7oPOn1oiCo03V1ohSo
0@00POn1oh7oPOn1oh7oPOnKo`40087oPOn1oh7oPOn1oh7oVol10021oh7oPOn1
oh7oU?l0=X7oROom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom
087oPOn1oh7oPOnEo`0fPOn9ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1
oh7oPOnMood0POn1oh7oPOn1oiGo03J1ohWoo@21oh7oPOn1oh7oPOn1oigoo@21
oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oUOl0=X7oR_ok087oPOn1oh7oPOn1
oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOnFo`0fPOn:oo/0POn1
oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oiKo03J1
oh_onP21oh7oPOn1oh7oPOn1oj3onP21oh7oPOn1oh7oPOn1oj3onP21oh7oPOn1
oh7oU_l0=X7oRooi087oPOn1oh7oPOn1oh7oXOoi087oPOn1oh7oPOn1oh7oXOoi
087oPOn1oh7oPOnGo`0fPOn<ooP0POn1oh7oPOn1oh7oPOnRooP0POn1oh7oPOn1
oh7oPOnRooP0POn1oh7oPOn1oiOo03J1ohcon021oh7oPOn1oh7oPOn1oj;on021
oh7oPOn1oh7oPOn1oj;on021oh7oPOn1oh7oUol0=X7oS?og087oPOn1oh7oPOn1
oh7oXoog087oPOn1oh7oPOn1oh7oXoog087oPOn1oh7oPOnHo`0fPOn=ooH0POn1
oh7oPOn1oh7oPOnTooH0POn1oh7oPOn1oh7oPOnTooH0POn1oh7oPOn1oiSo03J1
ohgomP21oh7oPOn1oh7oPOn1ojComP21oh7oPOn1oh7oPOn1ojComP21oh7oPOn1
oh7oV?l0=X7oSOoe087oPOn1oh7oPOn1oh7oYOoe087oPOn1oh7oPOn1oh7oYOoe
087oPOn1oh7oPOnIo`0fPOn=ooD0POn1oh7oPOn1oh7oPOnUooD0POn1oh7oPOn1
oh7oPOnUooD0POn1oh7oPOn1oiWo03J1ohkom021oh7oPOn1oh7oPOn1ojKom021
oh7oPOn1oh7oPOn1ojKom021oh7oPOn1oh7oVOl0=X7oS_oc087oPOn1oh7oPOn1
oh7oYooc087oPOn1oh7oPOn1oh7oYooc087oPOn1oh7oPOnJo`0fPOn>oo<0POn1
oh7oPOn1oh7oPOnWoo<0POn1oh7oPOn1oh7oPOnWoo<0POn1oh7oPOn1oi[o03J1
ohool@21oh7oPOn1oh7oPOn1ojWol@21oh7oPOn1oh7oPOn1ojWol@21oh7oPOn1
oh7oVol0=X7oSooa087oPOn1oh7oPOn1oh7oZOoa087oPOn1oh7oPOn1oh7oZOoa
087oPOn1oh7oPOnKo`0fPOn?oo40POn1oh7oPOn1oh7oPOnYoo40POn1oh7oPOn1
oh7oPOnYoo40POn1oh7oPOn1oi_o03J1oi3ok`21oh7oPOn1oh7oPOn1oj_ok`21
oh7oPOn1oh7oPOn1oj_ok`21oh7oPOn1oh7oW?l0=X7oT?o_087oPOn1oh7oPOn1
oh7oZoo_087oPOn1oh7oPOn1oh7oZoo_087oPOn1oh7oPOnLo`0fPOnAonh0POn1
oh7oPOn1oh7oPOn/onh0POn1oh7oPOn1oh7oPOn/onh0POn1oh7oPOn1oico03J1
oi7ok@21oh7oPOn1oh7oPOn1ojgok@21oh7oPOn1oh7oPOn1ojgok@21oh7oPOn1
oh7oWOl0=X7oTOo]087oPOn1oh7oPOn1oh7o[Oo]087oPOn1oh7oPOn1oh7o[Oo]
087oPOn1oh7oPOnMo`0fPOnBon`0POn1oh7oPOn1oh7oPOn^on`0POn1oh7oPOn1
oh7oPOn^on`0POn1oh7oPOn1oigo03J1oi;oj`21oh7oPOn1oh7oPOn1ojooj`21
oh7oPOn1oh7oPOn1ojooj`21oh7oPOn1oh7oW_l0=X7oTooZ087oPOn1oh7oPOn1
oh7o/?oZ087oPOn1oh7oPOn1oh7o/?oZ087oPOn1oh7oPOnNo`0fPOnConX0POn1
oh7oPOn1oh7oPOn`onX0POn1oh7oPOn1oh7oPOn`onX0POn1oh7oPOn1oiko03J1
oiCoj021oh7oPOn1oh7oPOn1ok;oj021oh7oPOn1oh7oPOn1ok;oj021oh7oPOn1
oh7oWol0=X7oU?oX087oPOn1oh7oPOn1oh7o/_oX087oPOn1oh7oPOn1oh7o/_oX
087oPOn1oh7oPOnOo`0fPOnDonP0POn1oh7oPOn1oh7oPOnbonP0POn1oh7oPOn1
oh7oPOnbonP0POn1oh7oPOn1oioo03J1oiGoiP21oh7oPOn1oh7oPOn1okCoiP21
oh7oPOn1oh7oPOn1okCoiP21oh7oPOn1oh7oX?l0=X7oUOoV087oPOn1oh7oPOn1
oh7o]?oV087oPOn1oh7oPOn1oh7o]?oV087oPOn1oh7oPOnPo`0fPOnEonH0POn1
oh7oPOn1oh7oPOndonH0POn1oh7oPOn1oh7oPOndonH0POn1oh7oPOn1oj3o03J1
oiGoi@21oh7oPOn1oh7oPOn1okGoi@21oh7oPOn1oh7oPOn1okGoi@21oh7oPOn1
oh7oXOl0=X7oU_oT087oPOn1oh7oPOn1oh7o]_oT087oPOn1oh7oPOn1oh7o]_oT
087oPOn1oh7oPOnQo`0fPOnFon@0POn1oh7oPOn1oh7oPOnfon@0POn1oh7oPOn1
oh7oPOnfon@0POn1oh7oPOn1oj7o03J1oiKoh`21oh7oPOn1oh7oPOn1okOoh`21
oh7oPOn1oh7oPOn1okOoh`21oh7oPOn1oh7oX_l0=X7oUooR087oPOn1oh7oPOn1
oh7o^?oR087oPOn1oh7oPOn1oh7o^?oR087oPOn1oh7oPOnRo`0fPOnGon80POn1
oh7oPOn1oh7oPOnhon80POn1oh7oPOn1oh7oPOnhon80POn1oh7oPOn1oj;o03J1
oiSoh021oh7oPOn1oh7oPOn1ok[oh021oh7oPOn1oh7oPOn1ok[oh021oh7oPOn1
oh7oXol0=X7oV?oQ087oPOn1oh7oPOn1oh7o^OoQ087oPOn1oh7oPOn1oh7o^OoQ
087oPOn1oh7oPOnRo`0fPOnEonH0POn1oh7oPOn1oh7oPOndonH0POn1oh7oPOn1
oh7oPOndonH0POn1oh7oPOn1oj3o03J1oi;ok021oh7oPOn1oh7oPOn1ojkok021
oh7oPOn1oh7oPOn1ojkok021oh7oPOn1oh7oWOl0=X7oR_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1
oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1
oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol
087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1
oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1
oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol
087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1
oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1
oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol
087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1
oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1
oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol
087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0nkOoj087oYOol
087oPOn1oh7oPOn1ooX0POnUoo`0POn1oh7oPOn1oh7onP21ojGoo021oh7oPOn1
oh7oUOl0?^gonP21ojGoo021oh7oPOn1oh7oPOoj087oYOol087oPOn1oh7oPOn1
ooX0POnUoo`0POn1oh7oPOn1oiGo03k]ooX0POnUoo`0POn1oh7oPOn1oh7onP21
ojGoo021oh7oPOn1oh7oPOoj087oYOol087oPOn1oh7oPOnEo`0nkOoj087oYOol
087oPOn1oh7oPOn1ooX0POnUoo`0POn1oh7oPOn1oh7onP21ojGoo021oh7oPOn1
oh7oUOl0?^gonP21ojGoo021oh7oPOn1oh7oPOoj087oYOol087oPOn1oh7oPOn1
ooX0POnUoo`0POn1oh7oPOn1oiGo03k]ooX0POnUoo`0POn1oh7oPOn1oh7onP21
ojGoo021oh7oPOn1oh7oPOoj087oYOol087oPOn1oh7oPOnEo`0nkOoj087oYOol
087oPOn1oh7oPOn1ooX0POnUoo`0POn1oh7oPOn1oh7onP21ojGoo021oh7oPOn1
oh7oUOl0?^gonP21ojGoo021oh7oPOn1oh7oPOoj087oYOol087oPOn1oh7oPOn1
ooX0POnUoo`0POn1oh7oPOn1oiGo05c]ooX0b?oe0=_onP3BooL0d?ol087oPOn1
oh7oPOn1ooX0b?oe0=_onP3BooL0d?ol087oPOn1oh7oPOn1ooX0b?oe0=_onP3B
ooL0d?ol087oPOn1oh7oPOnEo`1dmOoV0=Ook`3]ooX0o?og0>7onP3koo80dool
087oPOn1oh7oPOn9onH0eoo_0>gonP3looL0hOoj0?_olP3Coo`0POn1oh7oPOn1
ohWoiP3Gonl0kOoj0?com`3QooX0noob0=?oo021oh7oPOn1oh7oUOl0M?GoiP3G
onl0kOoj0?com`3QooX0noob0=?oo021oh7oPOn1oh7oROoV0=Ook`3]ooX0o?og
0>7onP3koo80dool087oPOn1oh7oPOn9onH0eoo_0>gonP3looL0hOoj0?_olP3C
oo`0POn1oh7oPOn1oiGo07CeonH0f_oY0?3onP3nooD0hOoj0?kok@3Eoo`0POn1
oh7oPOn1ohWoiP3JonT0l?oj0?kom@3QooX0o_o]0=Goo021oh7oPOn1oh7oROoV
0=[oj@3`ooX0o_oe0>7onP3nond0eOol087oPOn1oh7oPOnEo`1jmOoV0=_oiP3b
ooX00Ooom03QooX00Oook03Eoo`0POn1oh7oPOn1ohWoiP3KonH0l_oj007ooo@0
hOoj007oon`0eOol087oPOn1oh7oPOn9onH0fooV0?;onP01oood0>7onP01ooo/
0=Goo021oh7oPOn1oh7oUOl0N_GoiP3KonH0l_oj007ooo@0hOoj007oon`0eOol
087oPOn1oh7oPOn9onH0fooV0?;onP01oood0>7onP01ooo/0=Goo021oh7oPOn1
oh7oROoV0=_oiP3booX00Ooom03QooX00Oook03Eoo`0POn1oh7oPOn1oiGo08oe
onH0gOof0?Som`3coo80nol00>7onP01oook0?_om`3Foo`0POn1oh7oPOn1ohWo
iP3MooH0n?og0??olP3ko`00hOoj007ooo/0noog0=Koo021oh7oPOn1oh7oROoV
0=gomP3hooL0loob0?_o003QooX00Ooon`3kooL0e_ol087oPOn1oh7oPOnEo`1d
kOoj0=;om`3eooH0mOoe0=Oom@3eooX0e_ol087oPOn1oh7oPOn1ooX0d_og0?Go
mP3eooD0eooe0?GonP3Foo`0POn1oh7oPOn1oh7onP3BooL0mOof0?Gom@3GooD0
mOoj0=Koo021oh7oPOn1oh7oUOl0M>gonP3BooL0mOof0?Gom@3GooD0mOoj0=Ko
o021oh7oPOn1oh7oPOoj0=;om`3eooH0mOoe0=Oom@3eooX0e_ol087oPOn1oh7o
POn1ooX0d_og0?GomP3eooD0eooe0?GonP3Foo`0POn1oh7oPOn1oiGo07C]ooX0
d_oh0?;on03eooL0eOog0??on03Hoo`0POn1oh7oPOn1oh7onP3BooP0l_oh0?Go
m`3EooL0looh0=Soo021oh7oPOn1oh7oPOoj0=;on03booP0mOog0=Gom`3cooP0
f?ol087oPOn1oh7oPOnEo`1dkOoj0=Con03_ooP0m_oh0=Com`3booT0f?ol087o
POn1oh7oPOn1ooX0e?oh0>oon03fooP0e?og0?;on@3Hoo`0POn1oh7oPOn1oh7o
nP3DooP0kooh0?Kon03DooL0l_oi0=Soo021oh7oPOn1oh7oUOl0M>gonP3DooP0
kooh0?Kon03DooL0l_oi0=Soo021oh7oPOn1oh7oPOoj0=Con03_ooP0m_oh0=Co
m`3booT0f?ol087oPOn1oh7oPOn1ooX0e?oh0>oon03fooP0e?og0?;on@3Hoo`0
POn1oh7oPOn1oiGo07C]ooX0e?oi0>conP3fooP0e?oh0?7on@3Hoo`0POn1oh7o
POn1oh7onP3DooT0k?oj0?Kon03DooP0lOoi0=Soo021oh7oPOn1oh7oPOoj0=Co
n@3/ooX0m_oh0=Con03aooT0f?ol087oPOn1oh7oPOnEo`1dkOoj0=Con@3/ooX0
m_oh0=Con03aooT0f?ol087oPOn1oh7oPOn1ooX0e?oi0>conP3fooP0e?oh0?7o
n@3Hoo`0POn1oh7oPOn1oh7onP3DooT0k?oj0?Kon03DooP0lOoi0=Soo021oh7o
POn1oh7oUOl0M>gonP3DooT0k?oj0?Kon03DooP0lOoi0=Soo021oh7oPOn1oh7o
POoj0=Con@3/ooX0m_oh0=Con03aooT0f?ol087oPOn1oh7oPOn1ooX0e?oi0>co
nP3fooP0e?oh0?7on@3Hoo`0POn1oh7oPOn1oiGo07C]ooX0eOoh0>con03hooX0
d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7onP3EooP0k?oh0?SonP3BooX0kooi0=So
o021oh7oPOn1oh7oPOoj0=Gon03/ooP0n?oj0=;onP3_ooT0f?ol087oPOn1oh7o
POnEo`1dkOoj0=GonP3YooT0n?oj0=;onP3_ooT0f?ol087oPOn1oh7oPOn1ooX0
eOoj0>Won@3hooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7onP3EooX0jOoi0?So
nP3BooX0kooi0=Soo021oh7oPOn1oh7oUOl0M>gonP3EooX0jOoi0?SonP3BooX0
kooi0=Soo021oh7oPOn1oh7oPOoj0=GonP3YooT0n?oj0=;onP3_ooT0f?ol087o
POn1oh7oPOn1ooX0eOoj0>Won@3hooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oiGo
07C]ooX0eOoj0>Won@3hooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7onP3EooX0
jOoi0?SonP3BooX0kooi0=Soo021oh7oPOn1oh7oPOoj0=GonP3YooT0n?oj0=;o
nP3_ooT0f?ol087oPOn1oh7oPOnEo`1dkOoj0=GonP3YooT0n?oj0=;onP3_ooT0
f?ol087oPOn1oh7oPOn1ooX0eOoj0>Won@3hooX0d_oj0>oon@3Hoo`0POn1oh7o
POn1oh7onP3EooX0jOoi0?SonP3BooX0kooi0=Soo021oh7oPOn1oh7oUOl0M>go
nP3EooX0jOoi0?SonP3BooX0kooi0=Soo021oh7oPOn1oh7oPOoj0=GonP3YooT0
n?oj0=;onP3_ooT0f?ol087oPOn1oh7oPOn1ooX0eOoj0>Won@3hooX0d_oj0>oo
n@3Hoo`0POn1oh7oPOn1oiGo07C]ooX0eOoj0>Won@3hooX0d_oj0>oon@3Hoo`0
POn1oh7oPOn1oh7onP3EooX0jOoi0?SonP3BooX0kooi0=Soo021oh7oPOn1oh7o
POoj0=GonP3YooT0n?oj0=;onP3_ooT0f?ol087oPOn1oh7oPOnEo`1dkOoj0=Go
nP3YooT0n?oj0=;onP3_ooT0f?ol087oPOn1oh7oPOn1ooX0eOoj0>Won@3hooX0
d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7onP3EooX0jOoi0?SonP3BooX0kooi0=So
o021oh7oPOn1oh7oUOl0M>gonP3EooX0jOoi0?SonP3BooX0kooi0=Soo021oh7o
POn1oh7oPOoj0=GonP3YooT0n?oj0=;onP3_ooT0f?ol087oPOn1oh7oPOn1ooX0
eOoj0>Won@3hooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oiGo07C]ooX0eOoj0>Wo
n@3hooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7onP3EooX0jOoi0?SonP3BooX0
kooi0=Soo021oh7oPOn1oh7oPOoj0=GonP3YooT0n?oj0=;onP3_ooT0f?ol087o
POn1oh7oPOnEo`1dkOoj0=GonP3YooT0n?oj0=;onP3_ooT0f?ol087oPOn1oh7o
POn1ooX0eOoj0>Won@3hooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7onP3EooX0
jOoi0?SonP3BooX0kooi0=Soo021oh7oPOn1oh7oUOl0M>gonP3EooX0jOoi0?So
nP3BooX0kooi0=Soo021oh7oPOn1oh7oPOoj0=GonP3YooT0n?oj0=;onP3_ooT0
f?ol087oPOn1oh7oPOn1ooX0eOoj0>Won@3hooX0d_oj0>oon@3Hoo`0POn1oh7o
POn1oiGo07C]ooX0eOoj0>Won@3hooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7o
nP3EooX0jOoi0?SonP3BooX0kooi0=Soo021oh7oPOn1oh7oPOoj0=GonP3YooT0
n?oj0=;onP3_ooT0f?ol087oPOn1oh7oPOnEo`1dkOoj0=Gon03/ooP0n?oj0=;o
nP3_ooT0f?ol087oPOn1oh7oPOn1ooX0eOoh0>con03hooX0d_oj0>oon@3Hoo`0
POn1oh7oPOn1oh7onP3EooP0k?oh0?SonP3BooX0kooi0=Soo021oh7oPOn1oh7o
UOl0M>gonP3EooP0k?oh0?SonP3BooX0kooi0=Soo021oh7oPOn1oh7oPOoj0=Go
n03/ooP0n?oj0=;onP3_ooT0f?ol087oPOn1oh7oPOn1ooX0eOoh0>con03hooX0
d_oj0>oon@3Hoo`0POn1oh7oPOn1oiGo07C]ooX0e?oi0>conP3fooX0d_oj0>oo
n@3Hoo`0POn1oh7oPOn1oh7onP3DooT0k?oj0?KonP3BooX0kooi0=Soo021oh7o
POn1oh7oPOoj0=Con@3/ooX0m_oj0=;onP3_ooT0f?ol087oPOn1oh7oPOnEo`1d
kOoj0=Con@3/ooX0m_oj0=;onP3_ooT0f?ol087oPOn1oh7oPOn1ooX0e?oi0>co
nP3fooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7onP3DooT0k?oj0?KonP3BooX0
kooi0=Soo021oh7oPOn1oh7oUOl0M>gonP3DooT0k?oj0?KonP3BooX0kooi0=So
o021oh7oPOn1oh7oPOoj0=Con@3/ooX0m_oj0=;onP3_ooT0f?ol087oPOn1oh7o
POn1ooX0e?oi0>conP3fooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oiGo07C]ooX0
e?oh0>oon03fooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7onP3DooP0kooh0?Ko
nP3BooX0kooi0=Soo021oh7oPOn1oh7oPOoj0=Con03_ooP0m_oj0=;onP3_ooT0
f?ol087oPOn1oh7oPOnEo`1dkOoh0=Con03booP0mOoj0=;onP3_ooT0f?ol087o
POn1oh7oPOn1ooP0e?oh0?;on03eooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7o
n03DooP0l_oh0?GonP3BooX0kooi0=Soo021oh7oPOn1oh7oUOl0M>gon03DooP0
l_oh0?GonP3BooX0kooi0=Soo021oh7oPOn1oh7oPOoh0=Con03booP0mOoj0=;o
nP3_ooT0f?ol087oPOn1oh7oPOn1ooP0e?oh0?;on03eooX0d_oj0>oon@3Hoo`0
POn1oh7oPOn1oiGo07S/ooT0e?og0?GomP3eooX0d_oj0>oon@3Hoo`0POn1oh7o
POn1oh7o0?oi0=Com`3eooH0mOoj0=;onP3_ooT0f?ol087oPOn1oh7oPOn1o`3o
n@3DooL0mOof0?GonP3BooX0kooi0=Soo021oh7oPOn1oh7oUOl0QncomP3jo`40
0=oomP3hooL0looj0=;onP3_ooT0f?ol087oPOn1oh7oPOn1o`3omP3jo`400=oo
mP3hooL0looj0=;onP3_ooT0f?ol087oPOn1oh7oPOn1o`3omP3jo`400=oomP3h
ooL0looj0=;onP3_ooT0f?ol087oPOn1oh7oPOnEo`27k?of0?[o0@00goof0?So
m`3cooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7o0?of0?[o0@00goof0?Som`3c
ooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7o0?of0?[o0@00goof0?Som`3cooX0
d_oj0>oon@3Hoo`0POn1oh7oPOn1oiGo06c/ond0gOoV0?;onP3BooX0kooi0=So
o021oh7oPOn1oh7oPOl0ond0gOoV0?;onP3BooX0kooi0=Soo021oh7oPOn1oh7o
POl0ond0gOoV0?;onP3BooX0kooi0=Soo021oh7oPOn1oh7oUOl0K>[ok`3LonT0
l?oj0=;onP3_ooT0f?ol087oPOn1oh7oPOn1ookok`3LonT0l?oj0=;onP3_ooT0
f?ol087oPOn1oh7oPOn1ookok`3LonT0l?oj0=;onP3_ooT0f?ol087oPOn1oh7o
POnEo`1/j_o_0=coj@3`ooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7oo_o_0=co
j@3`ooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7oo_o_0=coj@3`ooX0d_oj0>oo
n@3Hoo`0POn1oh7oPOn1oiGo06cYoo00fOo_0>gonP3BooX0kooi0=Soo021oh7o
POn1oh7oPOomoo00fOo_0>gonP3BooX0kooi0=Soo021oh7oPOn1oh7oPOomoo00
fOo_0>gonP3BooX0kooi0=Soo021oh7oPOn1oh7oUOl0C^Con03CooD0POoZoo`0
POn1oh7oPOn1oh7on?oh0=?om@21on[oo021oh7oPOn1oh7oPOohooP0dooe087o
j_ol087oPOn1oh7oPOnEo`1>i?oh0=?om@21on[oo021oh7oPOn1oh7oPOohooP0
dooe087oj_ol087oPOn1oh7oPOn1ooSon03CooD0POoZoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo
03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oUOl0@X7o^ook0=Koo021oh7oPOn1oh7oPOn1oloon`3Foo`0POn1oh7o
POn1oh7oPOo?oo/0e_ol087oPOn1oh7oPOnEo`12POnkoo/0e_ol087oPOn1oh7o
POn1oh7ocook0=Koo021oh7oPOn1oh7oPOn1oloon`3Foo`0POn1oh7oPOn1oiGo
04:1okkon03Foo`0POn1oh7oPOn1oh7oPOoBooP0e_ol087oPOn1oh7oPOn1oh7o
d_oh0=Koo021oh7oPOn1oh7oUOl0@X7o`Ooe0=Koo021oh7oPOn1oh7oPOn1omGo
m@3Foo`0POn1oh7oPOn1oh7oPOoEooD0e_ol087oPOn1oh7oPOnEo`12POo1ooD0
e_ol087oPOn1oh7oPOn1oh7oeOoe0=Koo021oh7oPOn1oh7oPOn1omGom@3Foo`0
POn1oh7oPOn1oiGo04:1ol?ol`3Foo`0POn1oh7oPOn1oh7oPOoGoo<0e_ol087o
POn1oh7oPOn1oh7oeooc0=Koo021oh7oPOn1oh7oUOl0CX7o`ook0?koo03Foo`0
POn1oh7oPOn1oh7oPOoGoo/0o_ol0=Koo021oh7oPOn1oh7oPOn1omOon`3noo`0
e_ol087oPOn1oh7oPOnEo`1>POo3oo/0o_ol0=Koo021oh7oPOn1oh7oPOn1omOo
n`3noo`0e_ol087oPOn1oh7oPOn1oh7oeook0?koo03Foo`0POn1oh7oPOn1oiGo
04j1ol?ooP3koo`0e_ol087oPOn1oh7oPOn1oh7oeoon0?_oo03Foo`0POn1oh7o
POn1oh7oPOoGooh0nool0=Koo021oh7oPOn1oh7oUOl0@X7o^_ol0=Koo021oh7o
POn1oh7oPOn1olkoo03Foo`0POn1oh7oPOn1oh7oPOo>oo`0e_ol087oPOn1oh7o
POnEo`12POnjoo`0e_ol087oPOn1oh7oPOn1oh7oc_ol0=Koo021oh7oPOn1oh7o
POn1olkoo03Foo`0POn1oh7oPOn1oiGo04j1omkoo@3Qoo`0e_ol087oPOn1oh7o
POn1oh7ol_om0>7oo03Foo`0POn1oh7oPOn1oh7oPOobood0hOol0=Koo021oh7o
POn1oh7oUOl0H8koo@3kooP0i?om0>7oo03Foo`0POn1oh7oPOn1oh7oX_om0?_o
n03Tood0hOol0=Koo021oh7oPOn1oh7oPOnRood0nooh0>Coo@3Qoo`0e_ol087o
POn1oh7oPOnEo`1PS_om0?_on03Tood0hOol0=Koo021oh7oPOn1oh7oPOnRood0
nooh0>Coo@3Qoo`0e_ol087oPOn1oh7oPOn1oj;oo@3kooP0i?om0>7oo03Foo`0
POn1oh7oPOn1oiGo062>ood0o_ob0>Ooo@3Qoo`0e_ol087oPOn1oh7oPOn1oj;o
o@3noo80ioom0>7oo03Foo`0POn1oh7oPOn1oh7oX_om0?kolP3Wood0hOol0=Ko
o021oh7oPOn1oh7oUOl0Hhkoo@01ooo_0>Woo@3Qoo`0e_ol087oPOn1oh7oPOn1
oj;oo@01ooo_0>Woo@3Qoo`0e_ol087oPOn1oh7oPOn1oj;oo@01ooo_0>Woo@3Q
oo`0e_ol087oPOn1oh7oPOnEo`1SS_om007oonl0jOom0>7oo03Foo`0POn1oh7o
POn1oh7oX_om007oonl0jOom0>7oo03Foo`0POn1oh7oPOn1oh7oX_om007oonl0
jOom0>7oo03Foo`0POn1oh7oPOn1oiGo062>ooL0nOok0>Woo@3Qoo`0e_ol087o
POn1oh7oPOn1oj;om`3ioo/0jOom0>7oo03Foo`0POn1oh7oPOn1oh7oX_og0?Wo
n`3Yood0hOol0=Koo021oh7oPOn1oh7oUOl0H8konP3eoo/0j_om0>7oo03Foo`0
POn1oh7oPOn1oh7oX_oj0?Gon`3Zood0hOol0=Koo021oh7oPOn1oh7oPOnRooX0
mOok0>[oo@3Qoo`0e_ol087oPOn1oh7oPOnEo`1PS_oj0?Gon`3Zood0hOol0=Ko
o021oh7oPOn1oh7oPOnRooX0mOok0>[oo@3Qoo`0e_ol087oPOn1oh7oPOn1oj;o
nP3eoo/0j_om0>7oo03Foo`0POn1oh7oPOn1oiGo062>oo/0l_om0>[oo@3Qoo`0
e_ol087oPOn1oh7oPOn1oj;on`3bood0j_om0>7oo03Foo`0POn1oh7oPOn1oh7o
X_ok0?;oo@3Zood0hOol0=Koo021oh7oPOn1oh7oUOl0H8kon`3bood0j_om0>7o
o03Foo`0POn1oh7oPOn1oh7oX_ok0?;oo@3Zood0hOol0=Koo021oh7oPOn1oh7o
POnRoo/0l_om0>[oo@3Qoo`0e_ol087oPOn1oh7oPOnEo`1PS_ok0?;oo@3Zood0
hOol0>_odP21oh7oPOn1oh7oPOngoo/0l_om0>[oo@3Qoo`0jooB087oPOn1oh7o
POn1okOon`3bood0j_om0>7oo03[om80POn1oh7oPOn1oj[o062>ood0l?om0>[o
o@3Qoo`0jooB087oPOn1oh7oPOn1okOoo@3`ood0j_om0>7oo03[om80POn1oh7o
POn1oh7o]oom0?3oo@3Zood0hOol0>_odP21oh7oPOn1oh7oZ_l0H8koo@3`ood0
n?oQ0>ooo03[om80POn1oh7oPOn1oh7o]oom0?3oo@3hon40kool0>_odP21oh7o
POn1oh7oPOngood0l?om0?Soh@3_oo`0jooB087oPOn1oh7oPOnZo`1PS_om0?3o
o@3hon40kool0>_odP21oh7oPOn1oh7oPOngood0l?om0?Soh@3_oo`0jooB087o
POn1oh7oPOn1okOoo@3`ood0n?oQ0>ooo03[om80POn1oh7oPOn1oj[o062>ood0
l?om0?Soh@3_oo`0e_ol087oPOn1oh7oPOn1oj;oo@3`ood0n?oQ0>ooo03Foo`0
POn1oh7oPOn1oh7oX_om0?3oo@3hon40kool0=Koo021oh7oPOn1oh7oUOl0H8ko
o@3`ood0n?oQ0>ooo03Foo`0POn1oh7oPOn1oh7oX_om0?3oo@3hon40kool0=Ko
o021oh7oPOn1oh7oPOnRood0l?om0?Soh@3_oo`0e_ol087oPOn1oh7oPOnEo`1P
S_om0?3oo@3hon40kool0=Koo021oh7oPOn1oh7oPOnRood0l?om0?Soh@3_oo`0
e_ol087oPOn1oh7oPOn1oj;oo@3`ood0n?oQ0>ooo03Foo`0POn1oh7oPOn1oiGo
062>ood0l?om0>[oo@3Qoo`0e_ol087oPOn1oh7oPOn1oj;oo@3`ood0j_om0>7o
o03Foo`0POn1oh7oPOn1oh7oX_om0?3oo@3Zood0hOol0=Koo021oh7oPOn1oh7o
UOl0H8koo@3`ood0j_om0>7oo03Foo`0POn1oh7oPOn1oh7oX_om0?3oo@3Zood0
hOol0=Koo021oh7oPOn1oh7oPOnRood0l?om0>[oo@3Qoo`0e_ol087oPOn1oh7o
POnEo`1PS_om0?3oo@3Zood0hOol0=Koo021oh7oPOn1oh7oPOnRood0l?om0>[o
o@3Qoo`0e_ol087oPOn1oh7oPOn1oj;oo@3`ood0j_om0>7oo03Foo`0POn1oh7o
POn1oiGo062>ood0l?om0>[oo@3Qoo`0e_ol087oPOn1oh7oPOn1oj;oo@3`ood0
j_om0>7oo03Foo`0POn1oh7oPOn1oh7oX_om0?3oo@3Zood0hOol0=Koo021oh7o
POn1oh7oUOl0H8koo@3`ood0j_om0>7oo03Foo`0POn1oh7oPOn1oh7oX_om0?3o
o@3Zood0hOol0=Koo021oh7oPOn1oh7oPOnRood0l?om0>[oo@3Qoo`0e_ol087o
POn1oh7oPOnEo`1PS_om0?3oo@3Zood0hOol0=Koo021oh7oPOn1oh7oPOnRood0
l?om0>[oo@3Qoo`0e_ol087oPOn1oh7oPOn1oj;oo@3`ood0j_om0>7oo03Foo`0
POn1oh7oPOn1oiGo062>ood0l?om0>[oo@3Qoo`0e_ol087oPOn1oh7oPOn1oj;o
o@3`ood0j_om0>7oo03Foo`0POn1oh7oPOn1oh7oX_om0?3oo@3Zood0hOol0=Ko
o021oh7oPOn1oh7oUOl0H8koo@3`ood0j_om0>7oo03Foo`0POn1oh7oPOn1oh7o
X_om0?3oo@3Zood0hOol0=Koo021oh7oPOn1oh7oPOnRood0l?om0>[oo@3Qoo`0
e_ol087oPOn1oh7oPOnEo`1PS_om0?3oo@3Zood0hOol0=Koo021oh7oPOn1oh7o
POnRood0l?om0>[oo@3Qoo`0e_ol087oPOn1oh7oPOn1oj;oo@3`ood0j_om0>7o
o03Foo`0POn1oh7oPOn1oiGo062>ood0l?om0>[oo@3Qoo`0e_ol087oPOn1oh7o
POn1oj;oo@3`ood0j_om0>7oo03Foo`0POn1oh7oPOn1oh7oX_om0?3oo@3Zood0
hOol0=Koo021oh7oPOn1oh7oUOl0H8koo@3`ood0j_om0>7oo03Foo`0POn1oh7o
POn1oh7oX_om0?3oo@3Zood0hOol0=Koo021oh7oPOn1oh7oPOnRood0l?om0>[o
o@3Qoo`0e_ol087oPOn1oh7oPOnEo`1PS_om0?3oo@3Zood0hOol0=Koo021oh7o
POn1oh7oPOnRood0l?om0>[oo@3Qoo`0e_ol087oPOn1oh7oPOn1oj;oo@3`ood0
j_om0>7oo03Foo`0POn1oh7oPOn1oiGo062>ood0l?om0>[oo@3Qoo`0e_ol087o
POn1oh7oPOn1oj;oo@3`ood0j_om0>7oo03Foo`0POn1oh7oPOn1oh7oX_om0?3o
o@3Zood0hOol0=Koo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[o
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
UOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[o
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
UOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`12POn:oo`0POn1oh7o
POo8ooT0POn1oh7ogool087oPOn1oh7ob?oi087oPOn1omooo021oh7oPOn1olSo
n@21omKo04:1oh[oo021oh7oPOn1olgokP21oh7oPOoUoo`0POn1oh7oPOo=onh0
POn1oh7oiOol087oPOn1oh7ocOo^087og?l0@X7oR_ol087oPOn1oh7odooQ087o
POn1oncoo021oh7oPOn1om?oh@21oh7oPOo/oo`0POn1oh7oPOoCon40POoSo`12
POn:oo`0POn1oh7oPOoHomD0POn1oh7olool087oPOn1oh7of?oE087oPOn1oo?o
o021oh7oPOn1omSoe@21on[o04:1oh[oo021oh7oPOn1omgobP21oh7oPOoioo`0
POn1oh7oPOoMolX0POn1oh7onOol087oPOn1oh7ogOo:087ol?l0CX7oR_ol087o
POn1oh7oh_oV0?[oh021oh7oPOl0oo`0POn1oh7oPOoRonH0n_oP087oPOn1o`3o
o021oh7oPOn1on;oiP3jon00POogo`1:POn:oo`0POn1oh7oPOoWonL0kOoQ087o
POn6oo`0POn1oh7oPOoWonL0kOoQ087oPOn6oo`0POn1oh7oPOoWonL0kOoQ087o
oOl0B87oR_ol087oPOn1oh7okOoV0>7oh@21oh7oSOol087oPOn1oh7okOoV0>7o
h@21oh7oSOol087oPOn1oh7okOoV0>7oh@24o`18POn:oo`0POn1oh7oPOobonH0
e_oP087oPOnDoo`0POn1oh7oPOobonH0e_oP087oPOnDoo`0POn1oh7oPOobonH0
e_oP08_o04R1oh[oo021oh7oPOn1ooOoi`39on40POn1oi[oo021oh7oPOn1ooOo
i`39on40POn1oi[oo021oh7oPOn1ooOoi`39on40TOl0B87oR_ol087oPOn1oh7o
o?oW0;goh@21oh7oXOol087oPOn1oh7oo?oW0;goh@21oh7oXOol087oPOn1oh7o
o?oW0;goh@2Ho`12POn:oo`0POn1oh7oPOoW0;7oh@21oh7oZ?ol087oPOn1oh7o
i`2aon40POn1ojSoo021oh7oPOn1onL0/OoQ09oo04:1oh[oo021oh7oPOn7onH0
YOoR087oPOn^oo`0POn1oh7oQooV0:GohP21oh7o[_ol087oPOn1ohOoiP2Uon80
YOl0@X7oR_ol087oPOn1ohcoi`2Ion40POn1okGoo021oh7oPOn<onL0VOoQ087o
POneoo`0POn1oh7oS?oW09Woh@2/o`12POn:oo`0POn1oh7oTOoW08goh@21oh7o
_?ol087oPOn1oi7oi`2=on40POn1okcoo021oh7oPOnAonL0SOoQ0;?o04:1oh[o
o021oh7oPOnFonL0POoR087oPOo2oo`0POn1oh7oU_oW087ohP21oh7o`_ol087o
POn1oiKoi`21on80^Ol0B87oR_ol087oPOn1oi_oj021ooCohP21oh7obOol087o
POn1oi_oj021ooCohP21oh7obOol087oPOn1oi_oj021ooCohP30o`18POn:oo`0
POn1oh7oXOoW087oj?oS087oPOo?oo`0POn1oh7oXOoW087oj?oS087oPOo?oo`0
POn1oh7oXOoW087oj?oS0<Ko04R1oh[oo021oh7oPOnVonL0POoLon<0POn1omKo
o021oh7oPOnVonL0POoLon<0POn1omKoo021oh7oPOnVonL0POoLon<0cOl0B87o
R_ol087oPOn1oj_oj021om3ohP21oh7ogOol087oPOn1oj_oj021om3ohP21oh7o
gOol087oPOn1oj_oj021om3ohP3Do`18POn:oo`0POn1oh7o/?oX087oa?oS087o
POoSoo`0POn1oh7o/?oX087oa?oS087oPOoSoo`0POn1oh7o/?oX087oa?oS0=[o
04R1oh[oo021oh7oPOneonP0POnhon<0POn1on[oo021oh7oPOneonP0POnhon<0
POn1on[oo021oh7oPOneonP0POnhon<0hOl0B87oR_ol087oPOn1ok_oi`21ojco
h`21oh7olOol087oPOn1ok_oi`21ojcoh`21oh7olOol087oPOn1ok_oi`21ojco
h`3Xo`18POn:oo`0POn1oh7o`?oX087oWooT087oPOogoo`0POn1oh7o`?oX087o
WooT087oPOogoo`0POn1oh7o`?oX087oWooT0>ko04R1oh[oo021oh7oPOo5onP0
POnCon@0POn1ookoo021oh7oPOo5onP0POnCon@0POn1ookoo021oh7oPOo5onP0
POnCon@0mOl0A87oR_ol087oPOn1ol[oj021ohSoi021ohCoo021oh7oPOo:onP0
POn8on@0POn4oo`0POn1oh7ob_oX087oR?oT0?_o04R1oh[oo021oh7oPOo?onT0
POn1oo_oi@21oh[oo021oh7oPOo?onT0POn1oo_oi@21oh[oo021oh7oPOo?onT0
POn1oo_oi@00B87oR_ol087oPOn1omGoj021oh7okoo/087oR_ol087oPOn1omGo
j021oh7okoo/087oR_ol087oPOn1omGoj021oh7okoo/0018POn:oo`0POn1oh7o
f_oX087oPOoSoo<0POn:oo`0POn1oh7of_oX087oPOoSoo<0POn:oo`0POn1oh7o
f_oX087oPOoSoo<004R1oh[oo021oh7oPOoOonT0POn1omKonP21oh[oo021oh7o
POoOonT0POn1omKonP21oh[oo021oh7oPOoOonT0POn1omKonP00@X7oR_ol087o
POn1onCoj@21oh7oPOn1om?oo021oh7oPOoTonT0POn1oh7oPOoCoo`0POn1oh7o
i?oY087oPOo:o`12POn:oo`0POn1oh7oj_oX087oPOn1oh7oc_ol087oPOn1on[o
j021oh7oPOn1olkoo021oh7oPOoZonP0POn1olGo04^1oh[oo021oh7o^Ol1002i
onP0POn1oh7oPOo9oo`0POn1okWo0@00^OoX087oPOn1oh7obOol087oPOnio`40
0;Woj021oh7o`?l0B87oR_ol087oPOnkood0__oY087oPOn1oh7o`ool087oPOnk
ood0__oY087oPOn1oh7o`ool087oPOnkood0__oY087oPOnjo`18POn:oo`0POn1
okcon`34onT0POn1oh7oPOnnoo`0POn1okcon`34onT0POn1oh7oPOnnoo`0POn1
okcon`34onT0POn1okGo04R1oh[oo021oh7o__oi0<Woj@21oh7oPOn1okWoo021
oh7o__oi0<Woj@21oh7oPOn1okWoo021oh7o__oi0<Woj@21oh7o/?l0B87oR_ol
087oPOo1ooD0d?oY087oPOn1oh7o/ool087oPOo1ooD0d?oY087oPOn1oh7o/ool
087oPOo1ooD0d?oY087oPOnZo`1PPOoAood0l_oe0=Woo021oh7o`ooc0=Goj@21
oh7oPOn1ooGoo@3booD0fOol087oPOo3oo<0eOoY087oPOn1oh7omOom0?;om@3I
oo`0POn1ol?ol`3EonT0POn1ojGo06R1ookon`3Loo`0m?o_0=coo021oh7oa?ob
0=[oj@21oh7oPOnMoo/0g?ol0?Cok`3Loo`0POn1olColP3JonT0POn1oh7oWOok
0=coo03donl0g?ol087oPOo4oo80f_oY087oPOnPo`1XPOonoo/0g?ol0?Cok`3L
oo`0POn1olKok`3PonX0POn1oh7oUook0=coo03donl0g?ol087oPOo6onl0h?oZ
087oPOn1oiOon`3Loo`0m?o_0=coo021oh7oa_o_0>3ojP21oh7oV_l0IX7on03L
oo`0mOo/0=koo021oh7oaoo^0>GojP21oh7oPOnEooP0g?ol0?Gok03Noo`0POn1
olOokP3UonX0POn1oh7oUOoh0=coo03eon`0g_ol087oPOo7onh0iOoZ087oPOnE
o`1bQ?oe0=goo@3eoo/0m_oj0=ooo021oh7obOo/0>_oj@21oh7oPOnCooD0gOom
0?Gon`3fooX0gool087oPOo9on`0jooY087oPOn1oi?om@3Mood0mOok0?KonP3O
oo`0POn1olWok03[onT0POn1oi3o07:4ooD0gOom0?Gon`3fooX0gool087oPOo;
onT0lOoY087oPOn1ohkom@3Mood0mOok0?KonP3Ooo`0POn1ol_oj@3aonT0POn1
oh7oS_oe0=goo@3eoo/0m_oj0=ooo021oh7obooY0?7oj@21oh7oRol0LXKol`3M
ood0m_ok0?;on`3Qoo`0POn1olcoj03fonX0POn1oh7oR_oc0=goo@3foo/0l_ok
0>7oo021oh7oc?oX0?KojP21oh7oPOn:oo<0gOom0?Kon`3boo/0hOol087oPOo<
onP0m_oZ087oPOn5o`20Q_ok0?koo03Ooo`0mOom0>ooo03Qoo`0POn1olkoiP3k
onX0POn1oh7oQOok0?koo03Ooo`0mOom0>ooo03Qoo`0POn1olkoiP3konX0POn1
oh7oQOok0?koo03Ooo`0mOom0>ooo03Qoo`0POn1olkoiP3konX0POn1oh7o0?l0
OXKon`3noo`0gool0?Goo@3_oo`0hOol087oPOo?old0/?l0TH7oPOn1om;on`3n
oo`0gool0?Goo@3_oo`0hOol087oPOo?old0/?l0TH7oPOn1om;on`3noo`0gool
0?Goo@3_oo`0hOol087oPOo?old0/?l0TH7oPOo=o`1hQ_on0?_oo03Ooo`0gool
0>7oo021oh;omI7Lom40/?oeTH7oPOn1omOooP3koo`0gool0=ooo03Qoo`0POn2
ooFAg?oA0;3omI61oh7oPOoGooh0nool0=ooo03Ooo`0hOol087oP_oeTMcod@2`
ooFAPOn1om;o06j1oogoo03Pood0gOol0>7oo021oh?oli7Oom@0[?ocTH7oPOn1
olooo03Pood0gOol0>7oo021oh?oli7Oom@0[?ocTH7oPOn1olooo03Pood0gOol
0>7oo021oh?oli7Oom@0[?ocTH7oPOoCo`1^POomoo`0h?om0=goo03Qoo`0POn4
oo2Ah_oH0:Sol961oh7oPOoAoo`0h?om0=goo03Qoo`0POn4oo2Ah_oH0:Sol961
oh7oPOoAoo`0h?om0=goo03Qoo`0POn4oo2Ah_oH0:Sol961oh7oeOl0N:;oo@3P
oo`0h?om0=goo03Qoo`0POn6onfAiOoL0:CokI61oh7oPOogood0h?ol0>3oo@3M
oo`0hOol087oQ_o]TNGog02TonfAPOn1oh7omoom0>3oo03Pood0gOol0>7oo021
ohKokI7Uom`0Y?o]TH7oPOoFo`2TdOom0?_on03Uood0h?ol0>;oo03Mood0gool
087oR?oiTOWonI7YomX0Y_oiTOWonI61oh7oZ?om0?_on03Uood0h?ol0>;oo03M
ood0gool087oR?oiTOWonI7YomX0Y_oiTOWonI61oh7oZ?om0?_on03Uood0h?ol
0>;oo03Mood0gool087oR?oiTOWonI7YomX0Y_oiTOWonI61oh7of?l0Y=7oo@3k
ooP0iOom0>3oo03Roo`0gOom0=ooo021ohWonY7eooZAk?oH0:OonY7eooZAPOn1
ojWoo@3kooP0iOom0>3oo03Roo`0gOom0=ooo021ohWonY7eooZAk?oH0:OonY7e
ooZAPOn1ojWoo@3kooP0iOom0>3oo03Roo`0gOom0=ooo021ohWonY7eooZAk?oH
0:OonY7eooZAPOn1omWo0:CAood0o_ob0>Soo@3Poo`0h_ol0=goo@3Ooo`0POn9
oo^Al_olTNgoe`2Woo^Al_olTH7oPOnYood0o_ob0>Soo@3Poo`0h_ol0=goo@3O
oo`0POn9oo^Al_olTNgoe`2Woo^Al_olTH7oPOnYood0o_ob0>Soo@3Poo`0h_ol
0=goo@3Ooo`0POn9oo^Al_olTNgoe`2Woo^Al_olTH7oPOoIo`2WdOom007oonl0
j_om0>3oo03Sood0gOol0=koo021oh[oni7aoo^Al?oE0:Soni7aoo^APOn1oj[o
o@01ooo_0>[oo@3Poo`0hoom0=goo03Noo`0POn:oo^AlOokTO3oe@2Xoo^AlOok
TH7oPOnZood00Oook`3Zood0h?ol0>?oo@3Moo`0g_ol087oR_okTO7oni7`omD0
Z?okTO7oni61oh7of_l0Ym7oo@01ooo_0>[oo@3Poo`0hoom0=goo03Noo`0POn:
oobAkookTO?od`2XoobAkookTH7oPOn[ood00Oook`3Zood0h?ol0>?oo@3Moo`0
g_ol087oR_olTNooni7com<0Z?olTNooni61oh7oZoom007oonl0j_om0>3oo03S
ood0gOol0=koo021oh[oo97_oo^AlooC0:Soo97_oo^APOn1om_o0:CAooL0nOok
0>[oo@3Poo`0hoom0>3on`3Loo`0POn;oo^Ak_olTOGod@2Yoo^Ak_olTH7oPOn[
ooL0nOok0>[oo@3Poo`0hoom0>3on`3Loo`0POn;oo^Ak_olTOGod@2Yoo^Ak_ol
TH7oPOn[ooL0nOok0>[oo@3Poo`0hoom0>3on`3Loo`0POn;oo^Ak_olTOGod@2Y
oo^Ak_olTH7oPOoKo`2^dOoj0?Gon`3[ood0h?ol0>Goo03Poo/0fool087oRool
TNgoo97goll0ZOolTNgoo975ood0POn1on_onP3eoo/0joom0>3oo03Uoo`0h?ok
0=_oo021oh_oo97]oobAmoo?0:Woo97]oobAaOom087oPOo[ooX0mOok0>_oo@3P
oo`0iOol0>3on`3Koo`0POn;oobAkOolTOOoc`2YoobAkOolTLGoo@21oi_o0:kA
ooX0mOok0>_oo@3Poo`0iOol0>3on`3Koo`0POn;oofAjoomTO3oeP2YoofAjoom
TLSon@21oh7ok?oj0?Gon`3[ood0h?ol0>Goo03Poo/0fool087oRoomTN_ooI7`
omH0ZOomTN_ooI78ooT0POn1onconP3eoo/0joom0>3oo03Uoo`0h?ok0=_oo021
oh_ooI7[oofAl?oF0:WooI7[oofAb?oi087oW?l0[]7on`3bood0joom0>3oo03V
oo/0h_ok0=Woo021oh_ooI7[oobAj_oM0:WooI7[oobAcOoe087oPOo/oo/0l_om
0>_oo@3Poo`0i_ok0>;on`3Ioo`0POn;oofAjoolTN[og@2YoofAjoolTLgom@21
oh7ok?ok0?;oo@3[ood0h?ol0>Kon`3Roo/0fOol087oRoomTN_oo97Zomd0ZOom
TN_oo97=ooD0POnLo`2^dOok0?;oo@3[ood0h?ol0>Koo@3SooT0f?ol087oS?ol
TN[ooI7Son@0Z_olTN[ooI7Aoo40POn1oncon`3bood0joom0>3oo03Vood0hooi
0=Soo021ohcoo97ZoofAhooT0:[oo97ZoofAdOoa087oPOo/oo/0l_om0>_oo@3P
oo`0i_om0>?on@3Hoo`0POn<oobAj_omTN?oi02ZoobAj_omTM7ol@21oico0:kA
oo/0l_om0>_oo@3Poo`0i_om0>?on@3Hoo`0POn<oofAjOomTMcoj`2ZoofAjOom
TMGok021oh7okOok0?;oo@3[ood0h?ol0>Koo@3SooT0f?ol087oS?omTNWooI7L
on/0Z_omTNWooI7Eon`0POn1ongon`3bood0joom0>3oo03Vood0hooi0=Soo021
ohcooI7YoofAg?o[0:[ooI7YoofAeOo/087oWOl0[]7oo@3`ood0joom0>3oo03X
oo`0hook0=Goo021ohcooI7YoofAeOob0:[ooI7YoofAfOoX087oPOo]ood0l?om
0>_oo@3Poo`0j?ol0>?on`3Eoo`0POn<oofAjOomTMGolP2ZoofAjOomTMWoj021
oh7okOom0?3oo@3[ood0h?ol0>Soo03Soo/0eOol087oS?omTNWooI7Eoo80Z_om
TNWooI7IonP0POnMo`2^dOom0?3oo@3ion40k_ol0>Soo03Uoo/0dool087oS?om
TNWooI7>ooX0ZOomTNWooI7Mon@0POn1ongoo@3`ood0nOoQ0>koo03Xoo`0iOok
0=?oo021ohcooI7YoofAc_oj0:WooI7YoofAgOoT087oPOo]ood0l?om0?Woh@3^
oo`0j?ol0>Gon`3Coo`0POn<oofAjOomTLkonP2YoofAjOomTMgoi021oigo0:SA
ood0l?om0?Woh@3^oo`0j?ol0>Gon`3Coo`0POn<oobAj_omTH7okoolTN[ooI7U
om`0POn1ongoo@3`ood0nOoQ0>koo03Xoo`0iOok0=?oo021ohcoo97ZoofAPOo_
oobAj_omTNGog021oh7okOom0?3oo@3ion40k_ol0>Soo03Uoo/0dool087oS?ol
TN[ooI61onooo97ZoofAiOoL087oWOl0Z=7oo@3`ood0nOoQ0>koo03Yood0i?om
0=3oo021oh_ooI7[oobAPOo^oofAjoolTNSof@21oh7okOom0?3oo@3ion40k_ol
0>Woo@3Tood0d?ol087oRoomTN_oo961onkooI7[oobAj?oI087oPOo]ood0l?om
0?Woh@3^oo`0jOom0>Coo@3@oo`0POn;oofAjoolTH7ok_omTN_oo97XomT0POnM
o`2XdOom0?3oo@3ion40k_ol0>Woo@3Voo`0cool087oRoomTN_ooI61ongooI7[
oofAj_oF087oPOo]ood0l?om0?Woh@3^oo`0jOom0>Koo03?oo`0POn;oofAjoom
TH7okOomTN_ooI7ZomH0POn1ongoo@3`ood0nOoQ0>koo03Yood0i_ol0<ooo021
oh_ooI7[oofAPOo]oofAjoomTN[oeP21oigo0:SAood0l?om0?Woh@3^oo`0jOom
0>Koo03?oo`0POn;oofAjoomTH7okOomTN_ooI7_om40POn1ongoo@3`ood0nOoQ
0>koo03Yood0i_ol0<ooo021oh_ooI7[oofAPOo]oofAjoomTNood@21oh7okOom
0?3oo@3ion40k_ol0>Woo@3Voo`0cool087oRoomTN_ooI61ongooI7[oofAkooA
087oWOl0Z=7oo@3`ood0joom0>3oo03[oo`0i_om0<goo021oh_oo97]oobAPOo]
oobAkOolTO3od021oh7okOom0?3oo@3[ood0h?ol0>_oo03Vood0cOol087oRool
TNgoo961ongoo97]oobAl?o@087oPOo]ood0l?om0>_oo@3Poo`0jool0>Koo@3=
oo`0POn;oobAkOolTH7okOolTNgoo97`om00POnMo`2XdOom0?3oo@3[ood0h?ol
0>_oo03Xoo`0c?ol087oRookTNkoo961ongoni7^oobAk_oB087oPOo]ood0l?om
0>_oo@3Poo`0jool0>Soo03<oo`0POn;oo^Ak_olTH7okOokTNkoo97^om80POn1
ongoo@3`ood0joom0>3oo03[oo`0j?ol0<coo021oh_oni7^oobAPOo]oo^Ak_ol
TNkodP21oigo0:SAood0l?om0>_oo@3Poo`0jool0>Soo03<oo`0POn:oobAkool
TH7ojoolTNooo97[om@0POn1ongoo@3`ood0joom0>3oo03[oo`0j?ol0<coo021
oh[oo97_oobAPOo[oobAkoolTN_oe021oh7okOom0?3oo@3[ood0h?ol0>_oo03X
oo`0c?ol087oR_olTNooo961on_oo97_oobAjooD087oWOl0Z=7oo@3`ood0joom
0>3oo03/ood0i_ol0<coo021ohWoo97aoo^APOoZoobAlOokTNSodP21oh7ol_om
0?3oo@3[ood0h?ol0>coo@3Voo`0c?ol087oROolTO7oni61on[oo97aoo^Aj?oB
087oPOobood0l?om0>_oo@3Poo`0k?om0>Koo03<oo`0POn9oobAlOokTH7oj_ol
TO7oni7Xom80POnRo`2XdOom0?3oo@3[ood0h?ol0>coo@3Wood0b_ol087oROok
TO?oni61onWoni7coo^AiOo:087oPOolood0l?om0>_oo@3Poo`0k?om0>Ooo@3:
oo`0POn9oo^AlookTH7ojOokTO?oni7UolX0POn1oocoo@3`ood0joom0>3oo03/
ood0ioom0<[oo021ohWoni7coo^APOoYoo^AlookTNGobP21ojco0:CAood0l?om
0>_oo@3Poo`0k?om0>Ooo@3:oo`0POn8ooZAm_okTH7oioojTOKoni7Rol<0POn5
ood0l?om0>_oo@3Poo`0k?om0>Ooo@3:oo`0POn8ooZAm_okTH7oioojTOKoni7R
ol<0POn5ood0l?om0>_oo@3Poo`0k?om0>Ooo@3:oo`0POn8ooZAm_okTH7oiooj
TOKoni7Rol<0POneo`2<dOom0?3oo@3[ood0h?ol0>koo03Vood0b_ol087oQoo[
TH7oiOo[TMoo_021ohkoo@3`ood0joom0>3oo03^oo`0i_om0<[oo021ohOoji61
onGoji7Ook`0POn>ood0l?om0>_oo@3Poo`0k_ol0>Koo@3:oo`0POn7on^APOoU
on^Agonl087o__l0V=7oo@3`ood0joom0>3oo03^oo`0i_om0<[oo021ohGokY61
on;okY7Loml0o?oK087oV?om0?3oo@3[ood0h?ol0>koo03Vood0b_ol087oQOo^
TH7oh_o^TMcog`3lom/0POnHood0l?om0>_oo@3Poo`0k_ol0>Koo@3:oo`0POn5
onjAPOoRonjAg?oO0?cof`21olSo09SAood0l?om0>_oo@3Poo`0k_ol0>Koo@3:
oo`0POn4oo6APOoOoo6AeooR0?;og021oj7oo@3`ood0joom0>3oo03^oo`0i_om
0<[oo021ohColI61omoolI7Gon80l_oL087oXOom0?3oo@3[ood0h?ol0>koo03V
ood0b_ol087oQ?oaTH7ogooaTMOohP3bom`0POoAo`2HdOom0?3oo@3[ood0h?ol
0>ooo@3TonD0h_ol087oP_oeTH7ofooeTM?oi@3Xom/0POn[ood0l?om0>_oo@3P
oo`0koom0>Coi@3Roo`0POn2ooFAPOoKooFAdooU0>Sof`21oj_oo@3`ood0joom
0>3oo03_ood0i?oU0>;oo021oh;omI61om_omI7ConD0j?oK087ofol0T]7oo@3`
ood0joom0>3oo03_ood0i?oU0>;oo021oh7oPOo:o`2Ac?oW0=oof`21okCoo@3`
ood0joom0>3oo03_ood0i?oU0>;oo021oh7oPOo:o`2Ac?oW0=oof`21okCoo@3`
ood0joom0>3oo03_ood0i?oU0>;oo021oh7oPOo:o`2Ac?oW0=oof`21onCo08KA
ood0l?om0>_oo@3Poo`0koom0>Coi@3Roo`0POn1oh7oT_oY0=Gof`21okkoo@3`
ood0joom0>3oo03_ood0i?oU0>;oo021oh7oPOnBonT0eOoK087o__om0?3oo@3[
ood0h?ol0>ooo@3TonD0h_ol087oPOn1oi;oj@3Eom/0POo^o`26dOom0?3oo@3[
ood0h?ol0?7oo03SonD0h_ol087oPOn1oi3oj`3<om/0POo7ood0l?om0>_oo@3P
oo`0lOol0>?oi@3Roo`0POn1oh7oT?o[0<cof`21olOoo@3`ood0joom0>3oo03a
oo`0hooU0>;oo021oh7oPOn@on/0c?oK087omol0@X7oR_ol087oPOn1ohgokP32
om/0POn1oh[oo021oh7oPOn=onh0`_oK087oPOn:oo`0POn1oh7oSOo^0<;of`21
o`12POn:oo`0POn1oh7oRooa0;Sof`21oh7oTool087oPOn1oh_ol@2hom/0POn1
oi?oo021oh7oPOn;oo40^?oK08[o04:1oh[oo021oh7oPOn9oo<0[_oL087oPOnL
oo`0POn1oh7oROoc0:kog021oh7oW?ol087oPOn1ohWol`2^om`0Tol0@X7oR_ol
087oPOn1ohOom@2Uom/0POn1ojKoo021oh7oPOn7ooD0YOoK087oPOnVoo`0POn1
oh7oQooe0:Gof`2Mo`12POn:oo`0POn1oh7oQOoh09[og021oh7o[ool087oPOn1
ohGon02Jom`0POn1ojooo021oh7oPOn5ooP0V_oL0:Ko04:1oh[oo021oh7oPOn2
oo/0TOoK087oPOnioo`0POn1oh7oP_ok097of`21oh7o^Ool087oPOn1oh;on`2A
om/0/?l0B87oR_ol087oPOn1oh7o0?om08Sof`21oh7o`_ol087oPOn1oh7o0?om
08Sof`21oh7o`_ol087oPOn1oh7o0?om08Sof`2io`12POn:oo`0POn1oh7oPOn1
ooWof`21oh7oc?ol087oPOn1oh7oPOoiom/0POn1olcoo021oh7oPOn1oh7onOoK
0<?o04:1oh[oo021oh7oPOn1oh7ol?oK087oPOoEoo`0POn1oh7oPOn1oo3of`21
oh7oeOol087oPOn1oh7oPOo`om/0c?l0@X7oR_ol087oPOn1oh7oPOoVom`0POn1
omkoo021oh7oPOn1oh7oi_oL087oPOoNoo`0POn1oh7oPOn1onKog03Eo`12POn:
oo`0POn1oh7oPOn1omgof`21oh7oj?ol087oPOn1oh7oPOoMom/0POn1onSoo021
oh7oPOn1oh7ogOoK0=oo04:1oh[oo021oh7oPOn1oh7odooL087oPOoaoo`0POn1
oh7oPOn1om?og021oh7olOol087oPOn1oh7oPOoCom`0j?l0@X7oR_ol087oPOn1
oh7oPOo:om/0POn1oo_oo021oh7oPOn1oh7ob_oK087oPOokoo`0POn1oh7oPOn1
ol[of`3bo`0nPOn:oo`0POn1oh7oPOn1ol7of`21ohCoo021oh7oPOn1oh7o`OoK
087oQ?ol087oPOn1oh7oPOo1om/0nol0?87oR_ol087oPOn1oh7oPOngoml0POn:
oo`0POn1oh7oPOn1okOog`21oh[oo021oh7oPOn1oh7o]ooO000lPOn:oo`0POn1
oh7oPOn1ojkoj021oh[oo021oh7oPOn1oh7o[_oX087oR_ol087oPOn1oh7oPOn^
onP003b1oh[oo021oh7oPOn1oh7oY?ob087oR_ol087oPOn1oh7oPOnToo80POn:
oo`0POn1oh7oPOn1ojColP00?87oR_ol087oPOn1oh7oPOnKoo/0POn:oo`0POn1
oh7oPOn1oi_on`21oh[oo021oh7oPOn1oh7oVook000fPOn:oo`0POn1oh7oPOn1
oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021
oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0
=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1
oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnN
oo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1
oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol
087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1
oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021
oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0
=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1
oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnN
oo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1
oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol
087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1
oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021
oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0
=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1
oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnN
oo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1
oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol
087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1
oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021
oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0
=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1
oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnN
oo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1
oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol
087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1
oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021
oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0
=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1
oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnN
oo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1
oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol
087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1
oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021
oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0
=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1
oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnN
oo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1
oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol
087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`1PPOo8ood0nooh0=Koo021
oh7oX_l0087odOl0087oPOn1ongoo@3kooP0e_ol087oPOnRo`00POoAo`00POn1
oh7okOom0?_on03Foo`0POn1oj;o0021om7o0021ojKo06b1olSoo@3kooP0e_ol
087of?oe087ogOod087ogOoe087oPOn1oo;oo@3kooP0e_ol087of?oe087ogOod
087ogOoe087oPOn1oo;oo@3kooP0e_ol087of?oe087ogOod087ogOoe087oZol0
K87ob?om0?kolP3Ioo`0POoIoo<0POoNoo@0POoMoo@0POn1oh7oloom0?kolP3I
oo`0POoIoo<0POoNoo@0POoMoo@0POn1oh7oloom0?kolP3Ioo`0POoIoo<0POoN
oo@0POoMoo@0POn/o`1_POo8ood00Oook`3Koo`0POoJoo00POoQoo40POoQoo00
POn1oh7omOom007oonl0fool087of_o`087ohOoa087ohOo`087oPOn1ooGoo@01
ooo_0=_oo021om[ol021on7ol@21on7ol021ojko06n1olSoo@01ooo_0=_oo021
omcok@21onCok@21onCokP21oh7oPOofood00Oook`3Koo`0POoLond0POoTond0
POoTonh0POn1oh7om_om007oonl0fool087og?o]087oi?o]087oi?o^087o[ol0
K87ob?og0?Won`3Koo`0POoNonT0POoXonX0POoWonX0POn1oh7on?og0?Won`3K
oo`0POoNonT0POoXonX0POoWonX0POn1oh7on?og0?Won`3Koo`0POoNonT0POoX
onX0POoWonX0POnao`1/POo8ooX0mOok0=coo021omooi`21on[oj021onWoj021
oh7oPOoiooX0mOok0=coo021omooi`21on[oj021onWoj021oh7oPOoiooX0mOok
0=coo021omooi`21on[oj021onWoj021ok;o06b1olSonP3eoo/0g?ol087ogooW
087oj_oX087oj_oW087oPOn1ooWonP3eoo/0g?ol087ogooW087oj_oX087oj_oW
087oPOn1ooWonP3eoo/0g?ol087ogooW087oj_oX087oj_oW087o/_l0K87ob?ok
0?;oo@3aom80POoeonD0POo/onH0POo[onH0POn1oh7on_ok0?;oo@3aom80POoe
onD0POo/onH0POo[onH0POn1oh7on_ok0?;oo@3aom80POoeonD0POo/onH0POo[
onH0POnco`1/POo8oo/0l_om0?7odP21ooGoi021ongoi@21ongoi021oh7oPOok
oo/0l_om0?7odP21ooGoi021ongoi@21ongoi021oh7oPOokoo/0l_om0?7odP21
ooGoi021ongoi@21ongoi021okCo06b1olSon`3bood0lOoB087om_oS087ok_oS
087okooS087oPOn1oo_on`3bood0lOoB087om_oS087ok_oS087okooS087oPOn1
oo_on`3bood0lOoB087om_oS087ok_oS087okooS087o]?l0K87ob?om0?3oo@3a
om80POofon<0POo^on<0POo_on<0POn1oh7onoom0?3oo@3aom80POofon<0POo^
on<0POo_on<0POn1oh7onoom0?3oo@3aom80POofon<0POo^on<0POo_on<0POnd
o`1/POo8ood0l?om0=coo021on7oh`21onkoh`21onooh`21oh7oPOokood0l?om
0=coo021on7oh`21onkoh`21onooh`21oh7oPOokood0l?om0=coo021on7oh`21
onkoh`21onooh`21okCo06b1olSoo@3`ood0g?ol087ohOoR087ol?oQ087ol?oR
087oPOn1oocoo@3`ood0g?ol087ohOoR087ol?oQ087ol?oR087oPOn1oocoo@3`
ood0g?ol087ohOoR087ol?oQ087ol?oR087o]Ol0K87ob?om0?3oo@3Loo`0POoR
on40POo`on40POoaon40POn1oh7oo?om0?3oo@3Loo`0POoRon40POo`on40POoa
on40POn1oh7oo?om0?3oo@3Loo`0POoRon40POo`on40POoaon40POneo`1/POo8
ood0l?om0=coo021on;oh@21oo7oh021oo7oh@21oh7oPOolood0l?om0=coo021
on;oh@21oo7oh021oo7oh@21oh7oPOolood0l?om0=coo021on;oh@21oo7oh021
oo7oh@21okGo06b1olSoo@3`ood0g?ol087oh_oQ087olOoP087olOoQ087oPOn1
oocoo@3`ood0g?ol087oh_oQ087olOoP087olOoQ087oPOn1oocoo@3`ood0g?ol
087oh_oQ087olOoP087olOoQ087o]Ol0K87ob?om0?3oo@3Loo`0POoRon40POoa
on00POoaon40POn1oh7oo?om0?3oo@3Loo`0POoRon40POoaon00POoaon40POn1
oh7oo?om0?3oo@3Loo`0POoRon40POoaon00POoaon40POneo`1/POo8ood0l?om
0=coo021on;oh@21oo3oh@21oo7oh@21oh7oPOolood0l?om0=coo021on;oh@21
oo3oh@21oo7oh@21oh7oPOolood0l?om0=coo021on;oh@21oo3oh@21oo7oh@21
okGo06b1olSoo@3`ood0g?ol087ohOoR087ol?oQ087ol?oR087oPOn1oocoo@3`
ood0g?ol087ohOoR087ol?oQ087ol?oR087oPOn1oocoo@3`ood0g?ol087ohOoR
087ol?oQ087ol?oR087o]Ol0K87ob?om0?3oo@3Loo`0POoQon<0POo_on80POo_
on<0POn1oh7onoom0?3oo@3Loo`0POoQon<0POo_on80POo_on<0POn1oh7onoom
0?3oo@3Loo`0POoQon<0POo_on80POo_on<0POndo`1/POo8ood0l?om0=coo021
on7oh`21onkoh`21onooh`21oh7oPOokood0l?om0=coo021on7oh`21onkoh`21
onooh`21oh7oPOokood0l?om0=coo021on7oh`21onkoh`21onooh`21okCo06b1
olSoo@3`ood0g?ol087ohOoS087ok_oS087okooS087oPOn1oo_oo@3`ood0g?ol
087ohOoS087ok_oS087okooS087oPOn1oo_oo@3`ood0g?ol087ohOoS087ok_oS
087okooS087o]?l0K87ob?om0?3oo@3Loo`0POoQon<0POo^on@0POo^on<0POn1
oh7onoom0?3oo@3Loo`0POoQon<0POo^on@0POo^on<0POn1oh7onoom0?3oo@3L
oo`0POoQon<0POo^on@0POo^on<0POndo`1/POo8ood0l?om0=coo021on3oi@21
oncoiP21oncoi@21oh7oPOojood0l?om0=coo021on3oi@21oncoiP21oncoi@21
oh7oPOojood0l?om0=coo021on3oi@21oncoiP21oncoi@21ok?o06b1olSoo@3`
ood0g?ol087ogooV087ojooW087ojooV087oPOn1oo[oo@3`ood0g?ol087ogooV
087ojooW087ojooV087oPOn1oo[oo@3`ood0g?ol087ogooV087ojooW087ojooV
087o/ol0K87ob?om0?3oo@3Loo`0POoOonL0POoZonP0POoYonP0POn1oh7onOom
0?3oo@3Loo`0POoOonL0POoZonP0POoYonP0POn1oh7onOom0?3oo@3Loo`0POoO
onL0POoZonP0POoYonP0POnbo`1/POo8ood0l?om0=coo021omkoj@21onSojP21
onOojP21oh7oPOohood0l?om0=coo021omkoj@21onSojP21onOojP21oh7oPOoh
ood0l?om0=coo021omkoj@21onSojP21onOojP21ok7o06b1olSoo@3`ood0g?ol
087ogOo[087oi_o[087oioo[087oPOn1ooOoo@3`ood0g?ol087ogOo[087oi_o[
087oioo[087oPOn1ooOoo@3`ood0g?ol087ogOo[087oi_o[087oioo[087o/?l0
K87ob?om0?3oo@3Loo`0POoKonh0POoSonl0POoSonh0POn1oh7om_om0?3oo@3L
oo`0POoKonh0POoSonl0POoSonh0POn1oh7om_om0?3oo@3Loo`0POoKonh0POoS
onl0POoSonh0POn_o`1DPOn:oo`0POoJoo40POoPoo40POoPoo80POn1oh7o]_ol
087of_oa087oh?oa087oh?ob087oPOn1okKoo021om[ol@21on3ol@21on3olP21
ojgo05B1oh[oo021omSom@21omcomP21omcom@21oh7oPOndoo`0POoHooD0POoL
ooH0POoLooD0POn1oh7o]?ol087of?oe087og?of087og?oe087oZol0B87oR_ol
087oPOnRo`00POoAo`00POn1oh7o[ool087oPOnRo`00POoAo`00POn1oh7o[ool
087oPOnRo`00POoAo`00POnVo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo04:1oh[oo021omCoo021oh7oPOn1
oh7oPOo@oo`0POoDoo`0POn1oh7oPOn1oh7od?ol087oe?ol087oPOn1oh7oaol0
CX7oR_ol087oe?ol087oeOom087oPOn1oh7oPOl0oo`0POoDoo`0POoEood0POn1
oh7oPOn1o`3oo021omCoo021omGoo@21oh7oPOogo`1>POn:oo`0POoDoo`0POoE
ood0POn1oh7oPOn1o`3oo021omCoo021omGoo@21oh7oPOn1oh7o0?ol087oe?ol
087oeOom087oPOn1ooOo05B1oh[oo021omCoo021omGoo@21omCoo@21oh7oPOna
oo`0POoDoo`0POoEood0POoDood0POn1oh7o/Ool087oe?ol087oeOom087oe?om
087oZ?l0E87oR_ol087oe?ol087oeOom087oe?om087oPOn1ok7oo021omCoo021
omGoo@21omCoo@21oh7oPOnaoo`0POoDoo`0POoEood0POoDood0POnXo`1DPOn:
oo`0POoDoo`0POoEood0POoDood0POn1oh7o/Ool087oe?ol087oeOom087oe?om
087oPOn1ok7oo021omCoo021omGoo@21omCoo@21ojSo05B1oh[oo021omCoo021
omGoo@21omCoo@21oh7oPOnaoo`0POoDoo`0POoEood0POoDood0POn1oh7o/Ool
087oe?ol087oeOom087oe?om087oZ?l0E87oR_ol087oe?ol087oeOom087oe?om
087oPOn1ok7oo021omCoo021omGoo@21omCoo@21oh7oPOnaoo`0POoDoo`0POoE
ood0POoDood0POnXo`1DPOn:oo`0POoDoo`0POoEood0POoDood0POn1oh7o/Ool
087oe?ol087oeOom087oe?om087oPOn1ok7oo021omCoo021omGoo@21omCoo@21
ojSo05B1oh[oo021omCoo021omGoo@21omCoo@21oh7oPOnaoo`0POoDoo`0POoE
ood0POoDood0POn1oh7o/Ool087oe?ol087oeOom087oe?om087oZ?l0E87oR_ol
087oe?ol087oeOom087oe?om087oPOn1ok7oo021omCoo021omGoo@21omCoo@21
oh7oPOnaoo`0POoDoo`0POoEood0POoDood0POnXo`1DPOn:oo`0POoDoo`0POoE
ood0POoDood0POn1oh7o/Ool087oe?ol087oeOom087oe?om087oPOn1ok7oo021
omCoo021omGoo@21omCoo@21ojSo05B1oh[oo021omCoo021omGoo@21omCoo@21
oh7oPOnaoo`0POoDoo`0POoEood0POoDood0POn1oh7o/Ool087oe?ol087oeOom
087oe?om087oZ?l0E87oR_ol087oe?ol087oeOom087oe?om087oPOn1ok7oo021
omCoo021omGoo@21omCoo@21oh7oPOnaoo`0POoDoo`0POoEood0POoDood0POnX
o`1DPOn:oo`0POoDoo`0POoEood0POoDood0POn1oh7o/Ool087oe?ol087oeOom
087oe?om087oPOn1ok7oo021omCoo021omGoo@21omCoo@21ojSo05B1oh[oo021
omCoo021omGoo@21omCoo@21oh7oPOnaoo`0POoDoo`0POoEood0POoDood0POn1
oh7o/Ool087oe?ol087oeOom087oe?om087oZ?l0E87oR_ol087oe?ol087oeOom
087oe?om087oPOn1ok7oo021omCoo021omGoo@21omCoo@21oh7oPOnaoo`0POoD
oo`0POoEood0POoDood0POnXo`1DPOn:oo`0POoDoo`0POoEood0POoDood0POn1
oh7o/Ool087oe?ol087oeOom087oe?om087oPOn1ok7oo021omCoo021omGoo@21
omCoo@21ojSo05B1oh[oo021omCoo021omGoo@21omCoo@21oh7oPOnaoo`0POoD
oo`0POoEood0POoDood0POn1oh7o/Ool087oe?ol087oeOom087oe?om087oZ?l0
E87oR_ol087oe?ol087oeOom087oe?om087oPOn1ok7oo021omCoo021omGoo@21
omCoo@21oh7oPOnaoo`0POoDoo`0POoEood0POoDood0POnXo`1DPOn:oo`0POoD
oo`0POoEood0POoDood0POn1oh7o/Ool087oe?ol087oeOom087oe?om087oPOn1
ok7oo021omCoo021omGoo@21omCoo@21ojSo05B1oh[oo021omCoo021omGoo@21
omCoo@21oh7oPOnaoo`0POoDoo`0POoEood0POoDood0POn1oh7o/Ool087oe?ol
087oeOom087oe?om087oZ?l0E87oR_ol087oe?ol087oeOom087oe?om087oPOn1
ok7oo021omCoo021omGoo@21omCoo@21oh7oPOnaoo`0POoDoo`0POoEood0POoD
ood0POnXo`1DPOn:oo`0POoDoo`0POoEood0POoDood0POn1oh7o/Ool087oe?ol
087oeOom087oe?om087oPOn1ok7oo021omCoo021omGoo@21omCoo@21ojSo0321
oh_oP@210840P@2108l0POn;oh40P@210840P@2?087oRon10840P@210840S`00
<87oRon10840P@210840S`21oh_oP@210840P@2108l0POn;oh40P@210840P@2?
000`POn;oh40P@210840P@2?087oRon10840P@210840S`21oh_oP@210840P@21
08l00321oh_oP@210840P@2108l0POn;oh40P@210840P@2?087oRon10840P@21
0840S`00D87oPOn1omSoo021omGoo@21omCoo@21oh7oPOn1oh7o0Oooo021omGo
o@21omCoo@21oh7oPOn1oh7o0Oooo021omGoo@21omCoo@21ojSo0521oh7oPOoH
oo`0POoEood0POoDood0POn1oh7oPOn1o`7ooo`0POoEood0POoDood0POn1oh7o
POn1o`7ooo`0POoEood0POoDood0POnXo`1@POn1oh7of?ol087oeOom087oe?om
087oPOn1oh7oPOl1oool087oeOom087oe?om087oPOn1oh7oPOl1oool087oeOom
087oe?om087oZ?l0D87oPOn1omSoo021omGoo@21omCoo@21oh7oPOn1oh7o0Ooo
o021omGoo@21omCoo@21oh7oPOn1oh7o0Oooo021omGoo@21omCoo@21ojSo0521
oh7oPOoHoo`0POoEood0POoDood0POn1oh7oPOn1o`7ooo`0POoEood0POoDood0
POn1oh7oPOn1o`7ooo`0POoEood0POoDood0POnXo`1@POn1oh7of?ol087oeOom
087oe?om087oPOn1oh7oPOl1oool087oeOom087oe?om087oPOn1oh7oPOl1oool
087oeOom087oe?om087oZ?l0D87oPOn1omSoo021omGoo@21omCoo@21oh7oPOn1
oh7o0Oooo021omGoo@21omCoo@21oh7oPOn1oh7o0Oooo021omGoo@21omCoo@21
ojSo0521oh7oPOoHoo`0POoEood0POoDood0POn1oh7oPOn1o`7ooo`0POoEood0
POoDood0POn1oh7oPOn1o`7ooo`0POoEood0POoDood0POnXo`1@POn1oh7of?ol
087oeOom087oe?om087oPOn1oh7oPOl1oool087oeOom087oe?om087oPOn1oh7o
POl1oool087oeOom087oe?om087oZ?l0D87oPOn1omSoo021omGoo@21omCoo@21
oh7oPOn1oh7o0Oooo021omGoo@21omCoo@21oh7oPOn1oh7o0Oooo021omGoo@21
omCoo@21ojSo0521oh7oPOoHoo`0POoEood0POoDood0POn1oh7oPOn1o`7ooo`0
POoEood0POoDood0POn1oh7oPOn1o`7ooo`0POoEood0POoDood0POnXo`1@POn1
oh7of?ol087oeOom087oe?om087oPOn1oh7oPOl1oool087oeOom087oe?om087o
POn1oh7oPOl1oool087oeOom087oe?om087oZ?l0D87oPOn1omSoo021omGoo@21
omCoo@21oh7oPOn1oh7o0Oooo021omGoo@21omCoo@21oh7oPOn1oh7o0Oooo021
omGoo@21omCoo@21ojSo0521oh7oPOoHoo`0POoEood0POoDood0POn1oh7oPOn1
o`7ooo`0POoEood0POoDood0POn1oh7oPOn1o`7ooo`0POoEood0POoDood0POnX
o`1@POn1oh7of?ol087oeOom087oe?om087oPOn1oh7oPOl1oool087oeOom087o
e?om087oPOn1oh7oPOl1oool087oeOom087oe?om087oZ?l0D87oPOn1omSoo021
omGoo@21omCoo@21oh7oPOn1oh7o0Oooo021omGoo@21omCoo@21oh7oPOn1oh7o
0Oooo021omGoo@21omCoo@21ojSo0521oh7oPOoHoo`0POoEood0POoDood0POn1
oh7oPOn1o`7ooo`0POoEood0POoDood0POn1oh7oPOn1o`7ooo`0POoEood0POoD
ood0POnXo`1@POn1oh7of?ol087oeOom087oe?om087oPOn1oh7oPOl1oool087o
eOom087oe?om087oPOn1oh7oPOl1oool087oeOom087oe?om087oZ?l0D87oPOn1
omSoo021omGoo@21omCoo@21oh7oPOn1oh7o0Oooo021omGoo@21omCoo@21oh7o
POn1oh7o0Oooo021omGoo@21omCoo@21ojSo04:1oh7oPOn1ojOoo@21omCoo@21
oh7oPOn1oh7oPOo>ood0POoDood0POn1oh7oPOn1oh7oc_om087oe?om087oZ?l0
>87oPOn1oh7oPOn1ooKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1
oigoo@21ojSo03R1oh7oPOn1oh7oPOofood0POn1oh7oPOn1oh7oPOnMood0POn1
oh7oPOn1oh7oPOnMood0POnXo`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0
<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9
o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7obOl0?X7oPOn1okcon`21oh7oWook087oPOn1oh7oQook
087oPOnOoo/0POn1oh7oPOn7oo/0POn1oioon`21olco06:1oh7oPOoZood0f_oh
087okoom087oloom0<[on021oh7oPOn1okGoo@3JooP0POo_ood0POocood0b_oh
087oPOn1oh7o]Oom0=[on021onooo@21oo?oo@3:ooP0POo<o`1RPOn1oh7oj_om
0=[on021onooo@21oo?oo@3:ooP0POn1oh7oPOneood0f_oh087okoom087oloom
0<[on021oh7oPOn1okGoo@3JooP0POo_ood0POocood0b_oh087oc?l0HX7oPOn1
on[oo@3MooD0POo_ood0POocood0cOoe087oPOn1oh7o]Oom0=gom@21onooo@21
oo?oo@3=ooD0POn1oh7oPOneood0gOoe087okoom087oloom0<gom@21olco06:1
oh7oPOoZood0g_od087okoom087oloom0<kom021oh7oPOn1okGoo@3Noo@0POo_
ood0POocood0c_od087oPOn1oh7o]Oom0=kom021onooo@21oo?oo@3>oo@0POo<
o`1RPOn1oh7oj_om0=kom021onooo@21oo?oo@3>oo@0POn1oh7oPOneood0g_od
087okoom087oloom0<kom021oh7oPOn1okGoo@3Noo@0POo_ood0POocood0c_od
087oc?l0EX7oPOn1ol?on`3nood0POn1ojKon`3nood0POn1oh7oPOn>oo/0o_om
087oPOnVoo/0o_om087oPOn1oh7oS_ok0?koo@21oh7oY_ok0?koo@21olco05J1
oh7oPOo3ooh0noom087oPOnVooh0noom087oPOn1oh7oS_on0?_oo@21oh7oY_on
0?_oo@21oh7oPOn1ohkooP3kood0POn1ojKooP3kood0POo<o`1FPOn1oh7o`oon
0?_oo@21oh7oY_on0?_oo@21oh7oPOn1ohkooP3kood0POn1ojKooP3kood0POn1
oh7oPOn>ooh0noom087oPOnVooh0noom087oc?l0?X7oPOn1ok[oo@21oh7oWOom
087oPOn1oh7oQOom087oPOnMood0POn1oh7oPOn5ood0POn1oigoo@21olco04Z1
oh7oPOnjood0POn1ol?oo03Pood0POn1oh7oPOn5ood0POn1ol?oo03Pood0POn1
oh7oPOn5ood0POn1ol?oo03Pood0POo<o`1:POn1oh7o^_om087oPOo3oo`0h?om
087oPOn1oh7oQOom087oPOo3oo`0h?om087oPOn1oh7oQOom087oPOo3oo`0h?om
087oc?l0KX7oPOn1on[oo@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1
okGoo@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1okGoo@3Eood0POo_
ood0POocood0jool0>3oo@21olco06j1oh7oPOoZood0eOom087okoom087oloom
0>_oo03Pood0POn1oh7oPOneood0eOom087okoom087oloom0>_oo03Pood0POn1
oh7oPOneood0eOom087okoom087oloom0>_oo03Pood0POo<o`1^POn1oh7oj_om
0=Goo@21onooo@21oo?oo@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21
oo?oo@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21oo?oo@3[oo`0h?om
087oc?l0KX7oPOn1on[oo@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1
okGoo@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1okGoo@3Eood0POo_
ood0POocood0jool0>3oo@21olco06j1oh7oPOoZood0eOom087okoom087oloom
0>_oo03Pood0POn1oh7oPOneood0eOom087okoom087oloom0>_oo03Pood0POn1
oh7oPOneood0eOom087okoom087oloom0>_oo03Pood0POo<o`1^POn1oh7oj_om
0=Goo@21onooo@21oo?oo@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21
oo?oo@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21oo?oo@3[oo`0h?om
087oc?l0KX7oPOn1on[oo@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1
okGoo@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1okGoo@3Eood0POo_
ood0POocood0jool0>3oo@21olco06j1oh7oPOoZood0eOom087okoom087oloom
0>_oo03Pood0POn1oh7oPOneood0eOom087okoom087oloom0>_oo03Pood0POn1
oh7oPOneood0eOom087okoom087oloom0>_oo03Pood0POo<o`1^POn1oh7oj_om
0=Goo@21onooo@21oo?oo@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21
oo?oo@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21oo?oo@3[oo`0h?om
087oc?l0KX7oPOn1on[oo@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1
okGoo@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1okGoo@3Eood0POo_
ood0POocood0jool0>3oo@21olco07Z1oh7oPOoZood0noo`0>coo@21onooo@21
oo?oo@3[oo`0h?om087oPOn1oh7o]Oom0?_ol03/ood0POo_ood0POocood0jool
0>3oo@21oh7oPOn1okGoo@3koo00k?om087okoom087oloom0>_oo03Pood0POo<
o`1jPOn1oh7oj_om0?_ol03/ood0POo_ood0POocood0jool0>3oo@21oh7oPOn1
okGoo@3koo00k?om087okoom087oloom0>_oo03Pood0POn1oh7oPOneood0noo`
0>coo@21onooo@21oo?oo@3[oo`0h?om087oc?l0NX7oPOn1on[oo@3koo00k?om
087okoom087oloom0?SohP3]ood0POn1oh7oPOneood0noo`0>coo@21onooo@21
oo?oo@3hon80kOom087oPOn1oh7o]Oom0?_ol03/ood0POo_ood0POocood0n?oR
0>goo@21olco07Z1oh7oPOoZood0noo`0>coo@21onooo@21oo?oo@3hon80kOom
087oPOn1oh7o]Oom0?_ol03/ood0POo_ood0POocood0n?oR0>goo@21oh7oPOn1
okGoo@3koo00k?om087okoom087oloom0?SohP3]ood0POo<o`1jPOn1oh7oj_om
0?_ol03/ood0POo_ood0POocood0n?oR0>goo@21oh7oPOn1okGoo@3koo00k?om
087okoom087oloom0?SohP3]ood0POn1oh7oPOneood0noo`0>coo@21onooo@21
oo?oo@3hon80kOom087oc?l0KX7oPOn1on[oo@3Eood0POo_ood0POocood0n?oR
0>goo@21oh7oPOn1okGoo@3Eood0POo_ood0POocood0n?oR0>goo@21oh7oPOn1
okGoo@3Eood0POo_ood0POocood0n?oR0>goo@21olco06j1oh7oPOoZood0eOom
087okoom087oloom0>_oo03Pood0POn1oh7oPOneood0eOom087okoom087oloom
0>_oo03Pood0POn1oh7oPOneood0eOom087okoom087oloom0>_oo03Pood0POo<
o`1^POn1oh7oj_om0=Goo@21onooo@21oo?oo@3[oo`0h?om087oPOn1oh7o]Oom
0=Goo@21onooo@21oo?oo@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21
oo?oo@3[oo`0h?om087oc?l0KX7oPOn1on[oo@3Eood0POo_ood0POocood0jool
0>3oo@21oh7oPOn1okGoo@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1
okGoo@3Eood0POo_ood0POocood0jool0>3oo@21olco06j1oh7oPOoZood0eOom
087okoom087oloom0>_oo03Pood0POn1oh7oPOneood0eOom087okoom087oloom
0>_oo03Pood0POn1oh7oPOneood0eOom087okoom087oloom0>_oo03Pood0POo<
o`1^POn1oh7oj_om0=Goo@21onooo@21oo?oo@3[oo`0h?om087oPOn1oh7o]Oom
0=Goo@21onooo@21oo?oo@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21
oo?oo@3[oo`0h?om087oc?l0KX7oPOn1on[oo@3Eood0POo_ood0POocood0jool
0>3oo@21oh7oPOn1okGoo@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1
okGoo@3Eood0POo_ood0POocood0jool0>3oo@21olco06j1oh7oPOoZood0eOom
087okoom087oloom0>_oo03Pood0POn1oh7oPOneood0eOom087okoom087oloom
0>_oo03Pood0POn1oh7oPOneood0eOom087okoom087oloom0>_oo03Pood0POo<
o`1^POn1oh7oj_om0=Goo@21onooo@21oo?oo@3[oo`0h?om087oPOn1oh7o]Oom
0=Goo@21onooo@21oo?oo@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21
oo?oo@3[oo`0h?om087oc?l0KX7oPOn1on[oo@3Eood0POo_ood0POocood0jool
0>3oo@21oh7oPOn1okGoo@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1
okGoo@3Eood0POo_ood0POocood0jool0>3oo@21olco06j1oh7oPOoZood0eOom
087okoom087oloom0>_oo03Pood0POn1oh7oPOneood0eOom087okoom087oloom
0>_oo03Pood0POn1oh7oPOneood0eOom087okoom087oloom0>_oo03Pood0POo<
o`1^POn1oh7oj_om0=Goo@21onooo@21oo?oo@3[oo`0h?om087oPOn1oh7o]Oom
0=Goo@21onooo@21oo?oo@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21
oo?oo@3[oo`0h?om087oc?l0KX7oPOn1on[oo@3Eood0POo_ood0POocood0jool
0>3oo@21oh7oPOn1okGoo@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1
okGoo@3Eood0POo_ood0POocood0jool0>3oo@21olco06j1oh7oPOoZood0eOom
087okoom087oloom0>_oo03Pood0POn1oh7oPOneood0eOom087okoom087oloom
0>_oo03Pood0POn1oh7oPOneood0eOom087okoom087oloom0>_oo03Pood0POo<
o`1^POn1oh7oj_om0=Goo@21onooo@21oo?oo@3[oo`0h?om087oPOn1oh7o]Oom
0=Goo@21onooo@21oo?oo@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21
oo?oo@3[oo`0h?om087oc?l0CX7oPOn1on[oo@21okooo@21oo?oo@21oh7oPOn1
oh7omOom087o_oom087oloom087oPOn1oh7oPOoeood0POnoood0POocood0POn<
o`1>POn1oh7oj_om087o_oom087oloom087oPOn1oh7oPOoeood0POnoood0POoc
ood0POn1oh7oPOn1ooGoo@21okooo@21oo?oo@21ohco04j1oh7oPOoZood0POno
ood0POocood0POn1oh7oPOn1ooGoo@21okooo@21oo?oo@21oh7oPOn1oh7omOom
087o_oom087oloom087oS?l0CX7oPOn1on[oo@21okooo@21oo?oo@21oh7oPOn1
oh7omOom087o_oom087oloom087oPOn1oh7oPOoeood0POnoood0POocood0POn<
o`1>POn1oh7ok?ok087o`Ook087omOok087oPOn1oh7oPOogoo/0POo1oo/0POoe
oo/0POn1oh7oPOn1ooOon`21ol7on`21ooGon`21ohco04j1oh7oPOo/oo/0POo1
oo/0POoeoo/0POn1oh7oPOn1ooOon`21ol7on`21ooGon`21oh7oPOn1oh7omook
087o`Ook087omOok087oS?l0CX7oPOn1ongon`21ol7on`21ooGon`21oh7oPOn1
oh7omook087o`Ook087omOok087oPOn1oh7oPOogoo/0POo1oo/0POoeoo/0POn;
o`1>POn1oh7ol_of087oa_of087on_of087oPOn1oh7oPOolooH0POo6ooH0POoj
ooH0POn1oh7oPOn1oocomP21olKomP21oo[omP21oh_o04j1oh7oPOobooH0POo6
ooH0POojooH0POn1oh7oPOn1oocomP21olKomP21oo[omP21oh7oPOn1oh7oo?of
087oa_of087on_of087oRol0CX7oPOn1oo;on021olCon021ooSon021oh7oPOn1
oh7on_oh087oa?oh087on?oh087oPOn1oh7oPOojooP0POo4ooP0POohooP0POn9
o`1>POn1oh7ol_ok087o`Ook087omOok087oPOn1oh7oPOogoo/0POo1oo/0POoe
oo/0POn1oh7oPOn1ooOon`21ol7on`21ooGon`21ohKo04j1oh7oPOoboo/0POo1
oo/0POoeoo/0POn1oh7oPOn1ooOon`21ol7on`21ooGon`21oh7oPOn1oh7omook
087o`Ook087omOok087oQ_l0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo002J0000ohH4000000=7
0H400004000000180000B0000100800300P00000000000FR]NP000000dL1NP00
0n/3A`ER0000587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0<=Koo@35oo`0k_oi087oPOoPood0
aOol0>kon@21oh7oh?om0<Goo03^ooT0POn;o`0`e_om0<Goo03aooH0POn1on3o
o@35oo`0lOof087oPOoPood0aOol0?7omP21oh_o033Food0aOol0?7omP21oh7o
h?om0<Goo03aooH0POn1on3oo@35oo`0lOof087oRol0<=Koo@35oo`0l_oe087o
POoPood0aOol0?;om@21oh7oh?om0<Goo03booD0POn;o`0`e_om0<Goo03boo/0
POn1om[oo@35oo`0l_ok087oPOoJood0aOol0?;on`21ohGo033Food0aOol0?;o
n`21oh7of_om0<Goo03boo/0POn1om[oo@35oo`0l_ok087oQOl0>=Koo@35oo`0
m?ok0<?oo@21oi[oo@35oo`0m?ok0<?oo@21oi[oo@35oo`0m?ok0<?oo@21olGo
03SFood0aOol0?Coo032ood0POnJood0aOol0?Coo032ood0POnJood0aOol0?Co
o032ood0POo5o`0he_om0<Goo03doo`0`_om087oV_om0<Goo03doo`0`_om087o
V_om0<Goo03doo`0`_om087oaOl0>=Koo@35oo`0m?ol0<;oo@21oi[oo@35oo`0
m?ol0<;oo@21oi[oo@35oo`0m?ol0<;oo@21olGo03SFood0aOol0?Coo032ood0
POnJood0aOol0?Coo032ood0POnJood0aOol0?Coo032ood0POo5o`0he_om0<Go
o03doo`0`_om087oV_om0<Goo03doo`0`_om087oV_om0<Goo03doo`0`_om087o
aOl0>=Koo@35oo`0m?ol0<;oo@21oi[oo@35oo`0m?ol0<;oo@21oi[oo@35oo`0
m?ol0<;oo@21olGo07kFood0nooh0>comP3doo`0n?o_0>GomP3gonl0kooh0??o
o@3kooT0POoNood0nooh0>comP3doo`0n?o_0>GomP3gonl0kooh0??oo@3kooT0
POoNood0nooh0>comP3doo`0n?o_0>GomP3gonl0kooh0??oo@3kooT0ROl0O]Ko
o@3kooP0k?of0?Coo03honl0iOof0?Ook`3_ooP0loom0?_on@21omkoo@3kooP0
k?of0?Coo03honl0iOof0?Ook`3_ooP0loom0?_on@21omkoo@3kooP0k?of0?Co
o03honl0iOof0?Ook`3_ooP0loom0?_on@29o`1ne_om0?kolP3boo00mool0?So
k`3Yonl0n_o_0??ol@3food0o_oc087ohOom0?kolP3boo00mool0?Sok`3Yonl0
n_o_0??ol@3food0o_oc087ohOom0?kolP3boo00mool0?Sok`3Yonl0n_o_0??o
l@3food0o_oc08co08CFood00Oook`3eonh0n?ol0?Sok`3[on`0noo_0?Gok@3h
ood00Oook`21onCoo@01ooo_0?GokP3hoo`0n?o_0>_ok03konl0mOo]0?Soo@01
ooo_087oi?om007oonl0mOo^0?Soo03honl0joo/0?_ok`3eond0n?om007oonl0
Sol0Q=Koo@01ooo_0?GokP3hoo`0n?o_0>_ok03konl0mOo]0?Soo@01ooo_087o
i?om007oonl0mOo^0?Soo03honl0joo/0?_ok`3eond0n?om007oonl0POoTood0
0Oook`3eonh0n?ol0?Sok`3[on`0noo_0?Gok@3hood00Oook`2?o`2Re_og0?Wo
n`3goo/0n?oi0?[oo03doo`0h_ok0?Kon`3hood0kOoj0?WonP3iooL0nooi087o
i?og0?Won`3goo/0n?oi0?[oo03doo`0h_ok0?Kon`3hood0kOoj0?WonP3iooL0
nooi087oi?og0?Won`3goo/0n?oi0?[oo03doo`0h_ok0?Kon`3hood0kOoj0?Wo
nP3iooL0nooi08oo0:;FooX0mOok0?Won`3doo`0n_ol0?Coo03Sood0l_ol0?So
o@3_oo/0loom0?WonP3eoo/0POoUooX0mOok0?Won`3doo`0n_ol0?Coo03Sood0
l_ol0?Soo@3_oo/0loom0?WonP3eoo/0POoUooX0mOok0?Won`3doo`0n_ol0?Co
o03Sood0l_ol0?Soo@3_oo/0loom0?WonP3eoo/0T?l0X]KonP3eoo/0nOok0?Co
o03joo`0m?ol0>?oo@3boo`0n?om0>oon`3cood0nOoj0?Gon`21onGonP3eoo/0
nOok0?Coo03joo`0m?ol0>?oo@3boo`0n?om0>oon`3cood0nOoj0?Gon`21onGo
nP3eoo/0nOok0?Coo03joo`0m?ol0>?oo@3boo`0n?om0>oon`3cood0nOoj0?Go
n`2@o`2Fe_ok0?;oo@3iood0l_ol0?[oo03doo`0hoom0>Coo@3_oo`0lOol0?_o
n`3bood0POoUoo/0l_om0?Woo@3boo`0n_ol0?Coo03Sood0i?om0>ooo03aoo`0
nook0?;oo@21onGon`3bood0nOom0?;oo03joo`0m?ol0>?oo@3Tood0kool0?7o
o03koo/0l_om093o08[Foo/0l_om0>Koo03joo`0m?ol0>?oo@3Tood0koon0>oo
o03koo/0l_ok087oiook0?;oo@3Voo`0n_ol0?Coo03Sood0i?om0>oooP3_oo`0
nook0?;on`21onOon`3bood0i_ol0?[oo03doo`0hoom0>Coo@3_ooh0kool0?_o
n`3boo/0T_l0R]Kon`3bood0i_ol0?[oo03doo`0hoom0>Coo@3_ooh0kool0?_o
n`3boo/0POoWoo/0l_om0>Koo03joo`0m?ol0>?oo@3Tood0koon0>ooo03koo/0
l_ok087oiook0?;oo@3Voo`0n_ol0?Coo03Sood0i?om0>oooP3_oo`0nook0?;o
n`2Bo`1ne_om0?3oo@3Voo`0n_ol0?Coo03Roo/0ioom0?3oiP3kood0kool087o
ioom0?3oo@3Voo`0n_ol0?Coo03Roo/0ioom0?3oiP3kood0kool087oioom0?3o
o@3Voo`0n_ol0?Coo03Roo/0ioom0?3oiP3kood0kool09;o08@00=Ooo@3`ood0
j_oh0?[oo03doo`0h_oe0>goo@3`onH0noom0>ooo02Bo`00eoom0?3oo@3ZooP0
n_ol0?Coo03RooD0kOom0?3oiP3kood0kool09;o003Good0l?om0>[on03joo`0
m?ol0>;om@3]ood0l?oV0?_oo@3_oo`0T_l0Q?T0g_om0?3oo@3ZooP0n_ol0?Co
o03RooD0kOom0?3oiP3kood0kool09;on@3Nood0l?om0>[on03joo`0m?ol0>;o
m@3]ood0l?oV0?_oo@3_oo`0T_oi0=koo@3`ood0j_oh0?[oo03doo`0h_oe0>go
o@3`onH0noom0>ooo02Bo`24l`3Tood0l?om0?3olP3joo`0m?ol0=oolP3cood0
l?oV0?_oo@3_oo`0T_oc0>Coo@3`ood0l?ob0?[oo03doo`0goob0??oo@3`onH0
noom0>ooo02Boo<0i?om0?3oo@3`oo80n_ol0?Coo03Ooo80loom0?3oiP3kood0
kool09;o08C/0>_oo@3`ood0mOo]0?[oo03doo`0f_oe0?Goo@3`ood0i?om0>oo
o02Bon`0joom0?3oo@3eond0n_ol0?Coo03JooD0mOom0?3oo@3Tood0kool09;o
k03[ood0l?om0?Gok@3joo`0m?ol0=[om@3eood0l?om0>Coo@3_oo`0T_l0Q>`0
joom0?3oo@3eond0n_ol0?Coo03JooD0mOom0?3oo@3Tood0kool09;ok03[ood0
l?om0?Gok@3joo`0m?ol0=[om@3eood0l?om0>Coo@3_oo`0T_o/0>_oo@3`ood0
mOo]0?[oo03doo`0f_oe0?Goo@3`ood0i?om0>ooo02Bo`2Bnoob0>_oo@3`ood0
m_oe0?goo03joo`0m?ol0=ConP3food0l?om0>Coo@3_oo`0S?ob0>_oo@3`ood0
m_oe0?goo03joo`0m?ol0=ConP3food0l?om0>Coo@3_oo`0S?ob0>_oo@3`ood0
m_oe0?goo03joo`0m?ol0=ConP3food0l?om0>Coo@3_oo`0T_l0T_ConP3Zood0
l?om0?Son@3goo`0n_ol0?Coo03Aoo/0n?om0?3oo@3Tood0kool08GonP3Zood0
l?om0?Son@3goo`0n_ol0?Coo03Aoo/0n?om0?3oo@3Tood0kool08GonP3Zood0
l?om0?Son@3goo`0n_ol0?Coo03Aoo/0n?om0?3oo@3Tood0kool09;o08[Food0
l?om0?Son@3goo`0n_ol0?Coo03Aoo/0n?om0?3oo@3Tood0kool087oioom0?3o
o@3hooT0mool0?[oo03doo`0dOok0?Soo@3`ood0i?om0>ooo021onOoo@3`ood0
n?oi0?Ooo03joo`0m?ol0=7on`3hood0l?om0>Coo@3_oo`0T_l0R]Koo@3`ood0
nOok0?Coo03joo`0m?ol0=3oo03hood0kool0>Kon`3boo/0POoWood0l?om0?Wo
n`3doo`0n_ol0?Coo03@oo`0n?om0>ooo03Voo/0l_ok087oioom0?3oo@3ioo/0
m?ol0?[oo03doo`0d?ol0?Soo@3_oo`0i_ok0?;on`2Bo`2Fe_om0?3oo@3iood0
look0?[oo03doo`0d?ol0?Soo@3_oo/0l_ol0?_on`3bood0POoUood0l?om0?Wo
o@3coo/0n_ol0?Coo03@oo`0n?om0>oon`3boo`0nook0?;oo@21onGoo@3`ood0
nOom0??on`3joo`0m?ol0=3oo03hood0kook0?;oo03koo/0l_om093o09KFood0
l?om0?Woo@3coo/0n_ol0?Coo03@oo`0n?om0>oon`3boo`0nook0?;oo@21onGo
o@3`ood0nOom0??on`3joo`0m?ol0=3oo03hood0kook0?;oo03koo/0l_om087o
iOom0?3oo@3iood0look0?[oo03doo`0d?ol0?Soo@3_oo/0l_ol0?_on`3bood0
T?l0X]Koo@3`ood0nOom0?Gon@3joo`0m?ol0>?oo@3coo/0n?ok0?7on@3doo`0
nooj0?Gon`21onGoo@3`ood0nOom0?Gon@3joo`0m?ol0>?oo@3coo/0n?ok0?7o
n@3doo`0nooj0?Gon`21onGoo@3`ood0nOom0?Gon@3joo`0m?ol0>?oo@3coo/0
n?ok0?7on@3doo`0nooj0?Gon`2@o`2Re_om0?3oo@3ioo/0n_of0?[oo03doo`0
hook0?Oon`3fooX0l?oj0?Son`3iooP0n_oi087oi?om0?3oo@3ioo/0n_of0?[o
o03doo`0hook0?Oon`3fooX0l?oj0?Son`3iooP0n_oi087oi?om0?3oo@3ioo/0
n_of0?[oo03doo`0hook0?Oon`3fooX0l?oj0?Son`3iooP0n_oi08oo0:;Food0
l?om0?Won`3jooH0n_ol0?Coo03Soo/0mook0?KonP3`ooX0n?ok0?Won03jooT0
POoTood0l?om0?Won`3jooH0n_ol0?Coo03Soo/0mook0?KonP3`ooX0n?ok0?Wo
n03jooT0POoTood0l?om0?Won`3jooH0n_ol0?Coo03Soo/0mook0?KonP3`ooX0
n?ok0?Won03jooT0Sol0PMKoo@3`ood0n?oZ0?[oo03doo`0h_o/0?Gol`3gon`0
nOom007ooo40POoRood0l?om0?SojP3joo`0m?ol0>;ok03eoo<0moo/0?Woo@01
oooa087oh_om0?3oo@3honX0n_ol0?Coo03Ron`0mOoc0?Ook03iood00Oool@2=
o`2:e_om0?3oo@3foo@0o_ol0?[oo03doo`0h?oa0?3om@3eoo40m_om0?kol`21
on7oo@3`ood0m_od0?koo03joo`0m?ol0>3ol@3`ooD0mOoa0?Koo@3noo<0POoQ
ood0l?om0?Kom03noo`0n_ol0?Coo03Poo40l?oe0?Gol@3food0o_oc08co08[F
ood0l?om0?Kom03noo`0n_ol0?Coo03Poo40l?oe0?Gol@3food0o_oc087ohOom
0?3oo@3foo@0o_ol0?[oo03doo`0h?oa0?3om@3eoo40m_om0?kol`21on7oo@3`
ood0m_od0?koo03joo`0m?ol0>3ol@3`ooD0mOoa0?Koo@3noo<0S?l0R]Koo@3`
ood0mOof0?_oo@3koo`0m?ol0=gom`3ZooX0l?og0??oo@3kooT0POoNood0l?om
0?GomP3kood0nool0?Coo03MooL0j_oj0?3om`3cood0nooi087og_om0?3oo@3e
ooH0noom0?_oo03doo`0gOog0>[onP3`ooL0loom0?_on@29o`0JPOn:ood0POn1
ohCoo@21oh7oQ?om087onol06X7oR_om087oPOn4ood0POn1ohCoo@21oo_o01Z1
oh[oo@21oh7oQ?om087oPOn4ood0POoko`0JPOn:ood0POn1ohCoo@21oh7oQ?om
087onol06X7oR_om087oPOn4ood0POn1ohCoo@21oo_o01Z1oh[oo@21oh7oQ?om
087oPOn4ood0POoko`0JPOn:ood0POn1ohCoo@21oh7oQ?om087onol06X7oR_om
087oPOn4ood0POn1ohCoo@21oo_o01Z1oh[oo@21oh7oQ?om087oPOn4ood0POok
o`0JPOn:ood0POn1ohCoo@21oh7oQ?om087onol06X7oR_om087oPOn4ood0POn1
ohCoo@21oo_o01Z1oh[oo@21oh7oQ?om087oPOn4ood0POoko`0DPOn1oh7oPOn1
oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1
oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1
ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0
587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1
oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1
oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1
oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1
oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOon
o`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1
oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1
oh7oPOn1oh7oPOn1ooko01ZCoo`0POn1ohGoo021oh7oQOol087oPOoco`0JTool
087oPOn5oo`0POn1ohGoo021oh7olol099?oo03Cood0POn1okOoo03Cood0POn1
okOoo03Cood0POnUo`0TTool0=?oo@21oh7o]ool0=?oo@21oh7o]ool0=?oo@21
ojGo01Z1on3oo@21oh7oQ?om087oPOn4ood0POnUo`0JPOoPood0POn1ohCoo@21
oh7oQ?om087oYOl06X7oh?om087oPOn4ood0POn1ohCoo@21ojGo01Z1on3oo@21
oh7oQ?om087oPOn4ood0POnUo`0JPOoPood0POn1ohCoo@21oh7oQ?om087oYOl0
D=Koo@3kooT0`_om0?_on03donl0loof087oW?om0?_on@32ood0nooh0?Cok`3c
ooH0POnLood0nooi0<;oo@3kooP0m?o_0??omP21olOo06SFood0nooi0>SomP3d
oo`0n?om0?_on03donl0loof087oW?om0?_on@3XooH0m?ol0?Soo@3kooP0m?o_
0??omP21oicoo@3kooT0j?of0?Coo03hood0nooh0?Cok`3cooH0POo7o`1Xe_om
0?kol`3[ooH0m?ol0?Soo@3noo80moo_0?Ook`21oiooo@3noo<0joof0?Coo03h
ood0o_ob0?Ook`3gonl0POnOood0o_oc0>_omP3doo`0n?om0?kolP3gonl0moo_
087ob_l0K]Koo@01ooo_0?7ol03goo`0n?om007oonl0nOo_0?Wok021oj3oo@01
ooo_0?7ol03goo`0n?om007oonl0nOo_0?Wok021oj3oo@01ooo_0?7ol03goo`0
n?om007oonl0nOo_0?Wok021ol_o06kFood00Oook`3bonh0n?ol0?Soo@01ooo_
0?Wok`3ion`0POnPood00Oook`3bonh0n?ol0?Soo@01ooo_0?Wok`3ion`0POnP
ood00Oook`3bonh0n?ol0?Soo@01ooo_0?Wok`3ion`0POo;o`1de_og0?_on@3b
onh0n?ol0?Som`3ioo/0m?om0?3on`3foo/0POnRooL0nooi0?;okP3hoo`0n?og
0?Won`3dood0l?ok0?Kon`21oj;om`3kooT0l_o^0?Soo03hooL0nOok0?Coo@3`
oo/0m_ok087ocOl0R_d0f_oj0?Gon`3eooT0n_oi0?[oo03hooX0mOok0?Goo@3a
ood0l_ol087ocOom0=[onP3eoo/0mOoi0?[on@3joo`0n?oj0?Gon`3eood0lOom
0?;oo021olgoo@3JooX0mOok0?Gon@3jooT0n_ol0?SonP3eoo/0mOom0?7oo@3b
oo`0POo=o`2:m03SooX0mOok0?Kon`3doo/0nool0?SonP3eoo/0mOom0?7oo@3b
oo`0POo=oo@0hooj0?Gon`3foo/0m?ok0?_oo03hooX0mOok0?Goo@3aood0l_ol
087ocOod0>?onP3eoo/0m_ok0?Con`3koo`0n?oj0?Gon`3eood0lOom0?;oo021
olgo07kd0>?on`3bood0m_ok0?Con`3koo`0n?ok0?;oo@3eood0lOom087o^Ood
0>?on`3bood0m_ok0?Con`3koo`0n?ok0?;oo@3eood0lOom087o^Ood0>?on`3b
ood0m_ok0?Con`3koo`0n?ok0?;oo@3eood0lOom087o^Ol0O_@0hook0?;on`3h
ood0l?om0?_oo03hoo/0l_om0?Goo@3aood0POnioo@0hook0?;on`3hood0l?om
0?_oo03hoo/0l_om0?Goo@3aood0POnioo@0hook0?;on`3hood0l?om0?_oo03h
oo/0l_om0?Goo@3aood0POnio`20oOoh0>?on`3boo/0n_ok0?3on`3moo`0n?ok
0?;oo@3eood0lOom087o]Ooh0>?on`3boo/0n_ok0?3on`3moo`0n?ok0?;oo@3e
ood0lOom087o]Ooh0>?on`3boo/0n_ok0?3on`3moo`0n?ok0?;oo@3eood0lOom
087o^Ol0M=Koo@3_oo`0n_ok0?3on`3moo`0n?om0?3oo@3eood0l?ok087oTOom
0>ooo03joo/0l?ok0?goo03hood0l?om0?Goo@3`oo/0POnAood0kool0?[on`3`
oo/0oOol0?Soo@3`ood0mOom0?3on`21okco07CFood0kool0?[oo03^oo`0oOol
0?Soo@3`ood0mOom0?3om@21oiOoo@3_oo`0n_ol0>koo03moo`0n?om0?3oo@3e
ood0l?oe087oUoom0>ooo03joo`0k_ol0?goo03hood0l?om0?Goo@3`ooD0POo2
o`1de_om0>ooo03joo`0k_ol0?goo03hood0l?om0?Goo@3`ooD0POnGood0kool
0?[oo03^oo`0oOol0?Soo@3`ood0mOom0?3om@21oiOoo@3_oo`0n_ol0>koo03m
oo`0n?om0?3oo@3eood0l?oe087o`_l0M=Koo@3_oo`0n_ol0>koo03moo`0n?om
0?3oo@3eood0kOob087oWOom0>ooo03joo`0k_ol0?goo03hood0l?om0?Goo@3]
oo80POnMood0kool0?[oo03^oo`0oOol0?Soo@3`ood0mOom0>golP21olSo07CF
ood0kool0?[oo03^oo`0oOol0?Soo@3`ood0mOom0>Som@21oiooo@3_oo`0n_ol
0>koo03moo`0n?om0?3oo@3eood0j?oe087oWoom0>ooo03joo`0k_ol0?goo03h
ood0l?om0?Goo@3XooD0POo:o`1de_om0>ooo03joo`0k_ol0?goo03hood0l?om
0?Goo@3XooD0POnOood0kool0?[oo03^oo`0oOol0?Soo@3`ood0mOom0>Som@21
oiooo@3_oo`0n_ol0>koo03moo`0n?om0?3oo@3eood0j?oe087ob_l0M=Koo@3_
oo`0n_ol0>koo03moo`0n?om0?3oo@3eood0h_oj087oX?om0>ooo03joo`0k_ol
0?goo03hood0l?om0?Goo@3RooX0POnPood0kool0?[oo03^oo`0oOol0?Soo@3`
ood0mOom0>;onP21ol_o07CFood0kool0?[oo03^oo`0oOol0?Soo@3`ood0mOom
0=oon`21oj;oo@3_oo`0n_ol0>koo03moo`0n?om0?3oo@3eood0gook087oX_om
0>ooo03joo`0k_ol0?goo03hood0l?om0?Goo@3Ooo/0POo=o`1de_om0>ooo03j
oo`0k_ol0?goo03hood0l?om0?Goo@3Ooo/0POnRood0kool0?[oo03^oo`0oOol
0?Soo@3`ood0mOom0=oon`21oj;oo@3_oo`0n_ol0>koo03moo`0n?om0?3oo@3e
ood0gook087ocOl0M=Kon`3boo/0n_ol0>koo03moo`0n?om0?3oo@3eood0g_ol
087oX_ok0?;on`3joo`0k_ol0?goo03hood0l?om0?Goo@3Noo`0POnRoo/0l_ok
0?[oo03^oo`0oOol0?Soo@3`ood0mOom0=koo021olgo07CFoo/0l_om0?Son`3`
oo/0oOol0?Soo@3`ood0mOom0=koo021oj;on`3bood0n?ok0?3on`3moo`0n?om
0?3oo@3eood0g_ol087oX_ok0?;oo@3hoo/0l?ok0?goo03hood0l?om0?Goo@3N
oo`0POo=o`1de_ok0?;oo@3food0l?om0?_oo03hood0l?om0?Goo@3Noo`0POnR
oo/0l_om0?Koo@3`ood0nool0?Soo@3`ood0mOom0=koo021oj;on`3bood0m_om
0?3oo@3koo`0n?om0?3oo@3eood0g_ol087ocOl0P=KonP3eoo/0m_om0?3oo@3k
oo`0n?om0?3oo@3eoo/0loom0??on`21oj;onP3eoo/0m_om0?3oo@3koo`0n?om
0?3oo@3eoo/0loom0??on`21oj;onP3eoo/0m_om0?3oo@3koo`0n?om0?3oo@3e
oo/0loom0??on`21olgo083FooP0n_oi0?Gon`3doo/0nool0?Soo@3`ood0mOoj
0?Con`3goo/0POnPooP0n_oi0?Gon`3doo/0nool0?Soo@3`ood0mOoj0?Con`3g
oo/0POnPooP0n_oi0?Gon`3doo/0nool0?Soo@3`ood0mOoj0?Con`3goo/0POo;
o`20e_oh0?[on@3dooT0n_oi0?[oo03hood0l?om0?GonP3doo/0mook087oX?oh
0?[on@3dooT0n_oi0?[oo03hood0l?om0?GonP3doo/0mook087oX?oh0?[on@3d
ooT0n_oi0?[oo03hood0l?om0?GonP3doo/0mook087obol0MmKoo@01oooa0?;o
n@3jooT0n_ol0?Soo@3`ood0m?oc0?_ok021oj3oo@01oooa0?;on@3jooT0n_ol
0?Soo@3`ood0m?oc0?_ok021oj3oo@01oooa0?;on@3jooT0n_ol0?Soo@3`ood0
m?oc0?_ok021ol_o06SFood0o_oc0>ookP3hoo`0n?om0?3oo@3booD0nOoa087o
WOom0?kol`3_onh0n?ol0?Soo@3`ood0l_oe0?Wol@21oigoo@3noo<0koo^0?So
o03hood0l?om0?;om@3ioo40POo8o`1Xe_om0?kol`3^oo00mool0?Soo@3`ood0
l_oe0?Wol@21oigoo@3noo<0k_o`0?Ooo03hood0l?om0?;om@3ioo40POnMood0
o_oc0>kol03goo`0n?om0?3oo@3booD0nOoa087ob?l0J=Koo@3kooT0joo`0?Oo
o03hood0l?om0>oonP3dooL0POnJood0nooi0>_ol03goo`0n?om0?3oo@3_ooX0
m?og087oV_om0?_on@3[oo00mool0?Soo@3`ood0kooj0?Com`21olGo03;Food0
f_of0?Coo021oh7ob?om0=[omP3doo`0POn1olSoo@3JooH0m?ol087oPOoco`0J
e_om087oPOn4ood0POn1ohCoo@21oh7o[ol06]Koo@21oh7oQ?om087oPOn4ood0
POn1ojoo01[Food0POn1ohCoo@21oh7oQ?om087oPOn_o`0Je_om087oPOn4ood0
POn1ohCoo@21oh7o[ol06]Koo@21oh7oQ?om087oPOn4ood0POn1ojoo01[Food0
POn1ohCoo@21oh7oQ?om087oPOn_o`0Je_om087oPOn4ood0POn1ohCoo@21oh7o
[ol06]Koo@21oh7oQ?om087oPOn4ood0POn1ojoo01[Food0POn1ohCoo@21oh7o
Q?om087oPOn_o`0Je_om087oPOn4ood0POn1ohCoo@21oh7o[ol06]Koo@21oh7o
Q?om087oPOn4ood0POn1ojoo01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0JPOn1okSooP21oh7oPoon087o
POn3ooh0c?l06X7oPOnhoo/0POn1ohKon`21oh7oQ_ok0<oo01Z1oh7o^Oog087o
POn:ooL0POn1oh[om`3Bo`0JPOn1okWom021oh7oSOod087oPOn=oo@0eOl06X7o
POnjoo00POn1oi7ol021oh7oTOo`0=So01Z1oh7o^_o]087oPOnDond0POn1oiCo
k@3Ko`0JPOn1ok[ojP21oh7oUooZ087oPOnGonX0g_l06X7oPOnjonL0POn1oi[o
i`21oh7oV_oW0>7o01Z1oh7o^ooT087oPOnMon@0POn1oigoi03So`0JPOn1ok_o
h@21oh7oX?oQ087oPOnPon40i_l06X7oPOnkomh0POn1oj?ogP21oh7oXooN0>Wo
01Z1oh7o^ooK087oPOnVom/0POn1ojKof`3/o`0JPOn1ok_of021oh7oZOoH087o
POnYomP0kol06840P@2?0?;oP@2108l0l_n10840S`3bo`0HP@2108`0mOn10840
S03eoh40P@2<0?Go01R10840R@3hoh40P@290?SoP@2108T0n?l06840P@2;0?Ko
P@2108/0m_n10840R`3fo`0JPOn1ok_oe@21oh7o[?oE087oPOn/omD0l_l06X7o
POnkomL0POn1oj[oe`21oh7oZ_oG0?3o01Z1oh7o^ooJ087oPOnWomX0POn1ojOo
fP3]o`0JPOn1ok_og021oh7oYOoL087oPOnUom`0jol06X7oPOnkoml0POn1oj;o
g`21oh7oX_oO0>So01Z1oh7o^ooS087oPOnNon<0POn1oikoh`3To`0JPOn1ok[o
i`21oh7oV_oW087oPOnJonL0hOl06X7oPOnjonT0POn1oiSoj@21oh7oV?oY0=oo
01Z1oh7o^_o/087oPOnEon`0POn1oiGok03Lo`0JPOn1ok[okP21oh7oToo^087o
POnConh0f_l06X7oPOnjoo40POn1oi3ol@21oh7oT?oa0=Oo01Z1oh7o^Ood087o
POn=oo@0POn1ohgom03Eo`0JPOn1okWom`21oh7oR_og087oPOn:ooL0d_l06X7o
POnioo/0POn1ohKon`21oh7oQ_ok0<ko01Z1oh7o^?on087oPOn3ooh0POn1oh?o
oP3<o`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0JPOn1ooOo
n@21oh7oR?oi087oPOn8ooT0T_l06X7oPOogooT0POn1ohSon@21oh7oR?oi09;o
01Z1oh7omooi087oPOn8ooT0POn1ohSon@2Bo`0JPOn1ooOon@21oh7oR?oi087o
POn8ooT0T_l06X7oPOogooT0POn1ohSon@21oh7oR?oi09;o01Z1oh7omooi087o
POn8ooT0POn1ohSon@2Bo`0JPOn1ooOon@21oh7oR?oi087oPOn8ooT0T_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0VPOoBooD0fooj087oPOniooD0
fooj087oPOniooD0fooj087oj?l0CZ;on03]ooX0f?o_0>gonP3looL0gooi087o
/ooh0>gonP3Honl0kOoj0?com`3OooT0POncooP0kOoj0=Sok`3]ooX0o?og0=oo
n@2Bo`1>X_oh0>gonP3Honl0kOoj0?com`3OooT0POncooP0kOoj0=Sok`3]ooX0
o?og0=oon@21ok?on03]ooX0f?o_0>gonP3looL0gooi09;o04jPooP0lOoi0=[o
j@3`ooX0o_oe0=oon@21ok7on03aooT0f_oY0?3onP3nooD0gooi087o/Ooh0?7o
n@3JonT0l?oj0?kom@3OooT0T_l0DIoon@3aoo/0fOoV0?;onP01oood0=oon@21
ok3on@3aoo/0fOoV0?;onP01oood0=oon@21ok3on@3aoo/0fOoV0?;onP01oood
0=oon@2Bo`1AWooi0?7on`3IonH0l_oj007ooo@0gooi087o/?oi0?7on`3IonH0
l_oj007ooo@0gooi087o/?oi0?7on`3IonH0l_oj007ooo@0gooi09;o05ZOooP0
looj0=_omP3hooL0loob0?_o003OooT0POn`ooP0looj0=_omP3hooL0loob0?_o
003OooT0POn`ooP0looj0=_omP3hooL0loob0?_o003OooT0T_l0CYgon03gooT0
foog0?GomP3eooD0eOoi087o[_oh0?Oon@3KooL0mOof0?Gom@3EooT0POn^ooP0
mooi0=_om`3eooH0mOoe0=Gon@2Bo`1>WOoh0?Oon@3KooL0mOof0?Gom@3EooT0
POn^ooP0mooi0=_om`3eooH0mOoe0=Gon@21ojkon03gooT0foog0?GomP3eooD0
eOoi09;o04jLooT0mook0=Won03booP0mOog0=?on@21ojgon@3goo/0fOoh0?;o
n03eooL0dooi087o[Ooi0?Oon`3IooP0l_oh0?Gom`3CooT0T_l0CYcon03ioo/0
f_oh0>oon03fooP0d_oi087o[Ooh0?Won`3JooP0kooh0?Kon03BooT0POn]ooP0
nOok0=[on03_ooP0m_oh0=;on@2Bo`1>W?oh0?Won`3JooP0kooh0?Kon03BooT0
POn]ooP0nOok0=[on03_ooP0m_oh0=;on@21ojgon03ioo/0f_oh0>oon03fooP0
d_oi09;o04jJooP0oOoi0=[on@3/ooX0m_oh0=;on@21oj_on03mooT0f_oi0>co
nP3fooP0d_oi087oZooh0?gon@3JooT0k?oj0?Kon03BooT0T_l0CYWon@3nooX0
f?oi0>conP3fooP0d_oi087oZ_oi0?konP3HooT0k?oj0?Kon03BooT0POnZooT0
o_oj0=Son@3/ooX0m_oh0=;on@2Bo`1>VOoi0?konP3HooT0k?oj0?Kon03BooT0
POnZooT0o_oj0=Son@3/ooX0m_oh0=;on@21oj[on@3nooX0f?oi0>conP3fooP0
d_oi09;o056IooP00Ooon`3HooP0k?oh0?SonP3@ooT0POnZooP00Ooon`3HooP0
k?oh0?SonP3@ooT0POnZooP00Ooon`3HooP0k?oh0?SonP3@ooT0T_l0@YOolP3H
ooX0jOoi0?SonP3@ooT0POnXoo80f?oj0>Won@3hooX0d?oi087oZ?ob0=SonP3Y
ooT0n?oj0=3on@2Bo`12Uoob0=SonP3YooT0n?oj0=3on@21ojSolP3HooX0jOoi
0?SonP3@ooT0POnXoo80f?oj0>Won@3hooX0d?oi09;o04:Goo@0e_oj0>Won@3h
ooX0d?oi087oZ?od0=KonP3YooT0n?oj0=3on@21ojSom03FooX0jOoi0?SonP3@
ooT0T_l0@YKomP3EooX0jOoi0?SonP3@ooT0POnWooH0eOoj0>Won@3hooX0d?oi
087oYoof0=GonP3YooT0n?oj0=3on@2Bo`12U_of0=GonP3YooT0n?oj0=3on@21
ojOomP3EooX0jOoi0?SonP3@ooT0POnWooH0eOoj0>Won@3hooX0d?oi09;o04:D
ooP0eOoj0>Won@3hooX0d?oi087oYOoh0=GonP3YooT0n?oj0=3on@21ojGon03E
ooX0jOoi0?SonP3@ooT0T_l0@YCon03EooX0jOoi0?SonP3@ooT0POnUooP0eOoj
0>Won@3hooX0d?oi087oYOoh0=GonP3YooT0n?oj0=3on@2Bo`12U?oh0=GonP3Y
ooT0n?oj0=3on@21ojGon03EooX0jOoi0?SonP3@ooT0POnUooP0eOoj0>Won@3h
ooX0d?oi09;o04:DooL0e_oj0>Won@3hooX0d?oi087oYOog0=KonP3YooT0n?oj
0=3on@21ojGom`3FooX0jOoi0?SonP3@ooT0T_l0@YKol`3HooX0jOoi0?SonP3@
ooT0POnWoo<0f?oj0>Won@3hooX0d?oi087oYooc0=SonP3YooT0n?oj0=3on@2B
o`12U_oc0=SonP3YooT0n?oj0=3on@21ojOol`3HooX0jOoi0?SonP3@ooT0POnW
oo<0f?oj0>Won@3hooX0d?oi09;o04:Goo80f?oj0>Won@3hooX0d?oi087oZ?ob
0=SonP3YooT0n?oj0=3on@21ojSolP3HooX0jOoi0?SonP3@ooT0T_l0CYOon`00
ooP0fOoh0>con03hooX0d?oi087oZ?ok003on03IooP0k?oh0?SonP3@ooT0POnX
oo/00?oh0=Won03/ooP0n?oj0=3on@2Bo`1>Uook003on03IooP0k?oh0?SonP3@
ooT0POnXoo/00?oh0=Won03/ooP0n?oj0=3on@21ojSon`00ooP0fOoh0>con03h
ooX0d?oi09;o04jIoo/0o?oj0=Son@3/ooX0m_oj0=3on@21oj[on`3looX0f?oi
0>conP3fooX0d?oi087oZ_ok0?conP3HooT0k?oj0?KonP3@ooT0T_l0CY[onP3l
ooP0f_oi0>conP3fooX0d?oi087oZooj0?con03JooT0k?oj0?KonP3@ooT0POn[
ooX0o?oh0=[on@3/ooX0m_oj0=3on@2Bo`1>V_oj0?con03JooT0k?oj0?KonP3@
ooT0POn[ooX0o?oh0=[on@3/ooX0m_oj0=3on@21oj_onP3looP0f_oi0>conP3f
ooX0d?oi09;o04jJoo/0n_oh0=_on03_ooP0m_oj0=3on@21oj_on`3jooP0fooh
0>oon03fooX0d?oi087oZook0?[on03KooP0kooh0?KonP3@ooT0T_l0CYcon`3f
ooX0fOoh0?;on03eooX0d?oi087o[Ook0?KonP3IooP0l_oh0?GonP3@ooT0POn]
oo/0m_oj0=Won03booP0mOoj0=3on@2Bo`1>W?ok0?KonP3IooP0l_oh0?GonP3@
ooT0POn]oo/0m_oj0=Won03booP0mOoj0=3on@21ojgon`3fooX0fOoh0?;on03e
ooX0d?oi09;o04jMooX0m_oh0=_om`3eooH0mOoj0=3on@21ojkonP3fooP0foog
0?GomP3eooX0d?oi087o[_oj0?Kon03KooL0mOof0?GonP3@ooT0T_l0CYoon@3d
ooP0foof0?Som`3cooX0d?oi087o/?oi0?Con03KooH0n?og0??onP3@ooT0POn`
ooT0m?oh0=_omP3hooL0looj0=3on@2Bo`1>Wooi0?Con03KooH0n?og0??onP3@
ooT0POn`ooT0m?oh0=_omP3hooL0looj0=3on@21ok3on@3dooP0foof0?Som`3c
ooX0d?oi09;o04:Ooo/0l?oj0=WoiP3booX0d?oi087o/?ok0?3onP3IonH0l_oj
0=3on@21ok3on`3`ooX0fOoV0?;onP3@ooT0T_l0@Z3onP3`ooP0f_oY0?3onP3@
ooT0POnaooX0l?oh0=[oj@3`ooX0d?oi087o/Ooj0?3on03JonT0l?oj0=3on@2B
o`12X?oj0?3on03JonT0l?oj0=3on@21ok7onP3`ooP0f_oY0?3onP3@ooT0POna
ooX0l?oh0=[oj@3`ooX0d?oi09;o04:RooT0k_oh0=Sok`3]ooX0d?oi087o/ooi
0>kon03Honl0kOoj0=3on@21ok?on@3^ooP0f?o_0>gonP3@ooT0T_l0987od_oe
0;;on@21oh7ohooe0;;on@21oh7ohooe0;;on@2Bo`0TPOoBooD0/_oi087oPOoS
ooD0/_oi087oPOoSooD0/_oi09;o01Z1oh7omooi087oPOn8ooT0POn1ohSon@2B
o`0JPOn1ooOon@21oh7oR?oi087oPOn8ooT0T_l06X7oPOogooT0POn1ohSon@21
oh7oR?oi09;o01Z1oh7omooi087oPOn8ooT0POn1ohSon@2Bo`0JPOn1ooSon021
oh7oROoh087oPOn9ooP0T_l06X7oPOohooP0POn1ohWon021oh7oROoh09;o01Z1
oh7on?oj087oPOn7ooX0POn1ohOonP2@o`0JPOn1oo_om`21oh7oR_og087oPOn:
ooL0T?l06X7oPOokooL0POn1oh[om`21oh7oR_og093o01Z1oh7o0?oc087oPOn>
oo<0POn1ohkol`2?o`0JPOn1o`3om@21oh7oS?oe087oPOn<ooD0SOl06X7oPOl0
ooD0POn1ohcom@21oh7oS?oe08go01Z1oh7o0?of087oPOn;ooH0POn1oh_omP2<
o`0JPOn1o`3on@21oh7oR?oi087oPOn8ooT0ROl06X7oPOl0ooT0POn1ohSon@21
oh7oR?oi08Wo01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1
oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOon
o`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1
oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1
oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1
oh7oPOn1oh7oo_l00:00_`3o\>"], "NumberedFigure",
  ImageSize->{330, 201},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Figure 2.  Location of temporary  half step points in the \
Lax-Wendroff Scheme\
\>", "Caption"],

Cell[TextData[{
  "The j\[PlusMinus]",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  " points on the right of (11) and (12) are now replaced by the averages of \
their left and right neighbors (Lax replacement)"
}], "Text"],

Cell[BoxData[
    \(\(\(\ \)\(v\&\[RightVector]\_\(j + 1\/2\)\%n \[Rule] \(\(1\/2\) \((v\&\
\[RightVector]\_\(j + 1\)\%n + \ 
              v\&\[RightVector]\_j\%n)\)\ and\ \ v\&\[RightVector]\_\(j - \
1\/2\)\%n \[Rule] \(1\/2\) \(\((v\&\[RightVector]\_j\%n + \ 
                v\&\[RightVector]\_\(j - 1\)\%n)\)\(.\)\)\)\)\)\)], \
"NumberedEquation"],

Cell[TextData[{
  "In a second step we use the four points connected by the cross in Fig. 3 \
to calculate ",
  Cell[BoxData[
      \(v\&\[RightVector]\_j\%\(n + 1\)\)]],
  " (",
  StyleBox["Ref. 3",
    FontWeight->"Bold"],
  ", p.835):"
}], "Text"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\(v\&\[RightVector]\_j\%\(n + 1\) - v\&\
\[RightVector]\_j\%n\)\/\[CapitalDelta]t = \(-\([B]\)\) \((\ \
v\&\[RightVector]\_\(j + 1\/2\)\%\(n + 1\/2\) - \ v\&\[RightVector]\_\(j - \
1\/2\)\%\(n + 1\/2\))\)\/\[CapitalDelta]x\)\)\)], "Text"],

Cell[GraphicsData["PICT", "\<\
WY0000000<T1BP0A0_l<0?on0001;0000B`000000003A`ER0000002Q09H02P40
000000000000X02H0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G
0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40000000000000X02H
0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G0:40UP0:0@000000
0000002P09P0X02I0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F
00X10000000000000:00V02P09T0X02G01h00@0:000000=71F80;00900<6AfE^
IGIQ000300<03@0<02h01000o`00:`410B00:@0180001`0000008`000:00_P2Q
0<003F=eLW9UKWA`KfU^M0d00:00_`0R0<T1B@000:00_P2Q0<00cF=eLW9UKWA`
KfU^M20b86U^I6Eh87=eHR1UN6=X83<PJFiTIGPPLgER3B0c<STP86AYMR1UN6=X
80dP<S0a821TJGHP<b1YKVAUN20=830P87=eHR0c86U^I6Eh80dP<20PLgER83@P
<R1bKfa/83DPJFiTIGPP=B1YKVAUN21dLV5^LfaQM6D=KVEW87=SHFaU3C@P<R1b
Kfa/86iUIb1UN6=X86iUIb1UN6=X87AbHFicK65dIB0=838`<B0PLgER87AbHFic
K65dI@d00:40`0559B5@Dbe1I6mRIBdc;S0PAE1CARdc;S0=9BE2KgE^I6U^Id9_
N3XP830P<20c<STP<S0a80dU9EAYM6aU>R0XC65h;T=>ERTP3BDU@g9UHGA_LSXP
@f5^MV5c82Pg;S0^<RTP3BDU@g9UHGAYKfi4HGAU>R0X<38_<S@_<34P@20a<CXd
<R1@CBTP3BDUA6mSMFeUKWA@LVmSDfEdLcXPA6E^IF9QGd=QKWIQLd=eLgA_KD=_
K6mbL`dU9B/P@eI4JF=d3BDUA6mSMFeUKWA6KfidLcXP3BDUA6mSMFeUKWA>IFET
IFA6KfidLcXPAfE^IGIQ3@dU9DA_HgE]IFidD79_HfEcLd=_K6mbLcXP@gUQKR1=
HFMUKWAQ85UUK6a_Mb12K65SJ`dU9DE^I4=_KFeUKWAc3BDU@VEWJFi@LVm/KfLP
3@00X@30@00U9D9UIfU^DVEcKgEbHfDj871bKf=cIG@P@eI4JF=d3BDUE6UdK6Dj
84AUKVERHB1cM65^I65bI21WLV5`J6USL`dU9EIULW=YKfhj834^<38=9BE3LVEQ
M6U_KTAQM6Dj834`;c4d;cTi3BDU@fm`NG9YIfQd>R0X@bTP<CTi=2`P<CTi>B14
IFiUHV4PDgUcM6E]LbhP@Fa/859YIfQdLb1BIG=ULWIUI0eeLfEbI6USM20_@eI4
JF=d838`<21TJF=d871eM0e3ETAYHg@PHVEWJFh=;fU^MV5/JFASKfa_LWAQHVaU
?b1dLWEU86AUIR0P80d_K6EfIF`b82m/HFiWMF5WIFaUMVE/87MXIG9U87]`Kg0P
K65^IgEQIfE/IGIUK20b86MUOG]VHFacIGdPJFIUK7=U86AUIPe/IGIUK38PKVmd
87/P;gQcJ6mg87/=<21SMG9bIFidL6mYKW@P=B0]<B1bKfa/87]`Kg0PL6m`86e_
MVEdKb1TMG0P<B1QI6@P<b0a879_K6`PIGQSJ21TMG0P=20a879_K6`PIGQSJ21W
IG@P<21bKFmfIGA_86=eLW9UKWA`KfU^M7dPIGQSJ21[LfQ_M`e`Kg0PL6m`871_
L21`Kg1m86AUIR1m86UV3BmYKVUdJF5/JGYU3G]3ETAYHg@=NfAeL21hHfQUHf]k
HVU^I7eYIR1`Kg0PL6m`OFI_LV5/K0eSMG9bIFidLf=bIFE^82mOLg0PIGQSJ21T
IFHP;emcHB1UN6=X86AUIR0_Gg=V86EhHfPPI6EV3Bm4IFIQMFadDf=bIFE^Nemc
IR1OLf4P;emcL21/Kf5TOFAUIPd_A6EVHGE/M5=SLVEUKU1bKf=k82mOLg0PK6mQ
I7eTIFH=;g=UM7=dLVm[IF5TJWEcM21gJ6EbIG]`Kg0PM79eIGekIV5/LfEmJFIU
K7=U3G/_Lf4P;g=UM7=dLVm[IF5TJWEcM21/Kf5T86AUIPd_K6TP;faYKVEdKb1/
Kf5T86AUIPd_KG@P;fe_MVEdKb1/Kf5T86AUIPd_Hg@P;f=eLWIUM6lPK6mQI21T
IFH=;faX87/PHgEbLVE^M71_JFid86EhHfPPL6m`86aYKVEdKgeRJFiT86AUIPd_
K7HPNb1SMG9bIFidL6mYKW@PL6m`86EhHfPPK6U^IGA_OF9YKV@PI6EVO@ek;g=Q
Ng]SMG9bIFidI6USM21CM79_JfE1I6YeLgA4JF=d86iUNe=dLVm[ID5TJWEcM4AY
Hg@PHVEWJFimJFImNb1SMG9bIFidI6USM21CM79_JfE1I6YeLgA4JF=d86EaNfE^
I7eYIWeYIVE/LfEm869YKV@PI6EV3GEcIG9TJF=d82mCM79_JfE1I6YeLgA4JF=d
834`<21TJF=d871eM0eCM79_JfE1I6YeLgA4JF=d869UIfU^3BmON6`=NgAbHFic
IVmbK@d^<SDPLgER879_MFiT82hb=B1QI6@PIGQSJ0d^<SDPLgER879_MFiT82hb
=B1QI6@PIGQSJ0eYM79QKW=VKg9]3GeRJFiT86AUIPd_K6Uk85mhK21/JFiUM6mm
HVU^I21TIFH=;fedNb1ON6`PKFmfIGA_OF9YKV@PI6EV3BmSM7/PGgQ/86=eLWIU
M6mmHVU^I21TIFH=;faX87/PI7E`85mhK21`Kg0PHgEbLVE^M71_JFid86EhHfPP
L6m`86aYKVEdKgeRJFiT86AUIPd_K7HPNb1TMG0PGgQ/871_L21SMG9bIFidL6mY
KW@PL6m`86EhHfPPK6U^IGA_OF9YKV@PI6EV3BmbL7]ON6`_HgIOHR1hI6H_HgIO
LR1hI6H=GgQ/;f=fGg@PN6AV;f=fGf`PN6AV3F=fGf`PHgIOM21]KgIUM6l=HgIO
LR1SMUmd86aYKVEdK`eSMUmb86=fGf8PK6U^IGA_3F=fGf`PHgIOHR1/JFiUM6l=
Hfa_LfE`HGAX3GeRJFiT86AUIPeUKVAmJFIUK7=UOFAUIPd_M6EbKFU^HGAU3G]e
LfEbI6USM20_DgAbKf]U@FAZMG=dA6USM21[KVmgKR1kHgEbLVE^M6AYHg@PDgAb
Kf]U@FAZMG=dA6USM21ULG]UKVAmJFImJFH=HgEbLVE^M6AYHg@P@eI4JF=d86Ea
NfE^I7eYIWeTIFH=;fehCF5h83Hd86AUIPd_KGQCM6/PFfehCF5h87]]HGAbJGQm
879UL6EQM5eTIFH=;fehBFAh830PI6EV3BmcM6ekKGQCM6/PKGQ9I7PP<21/M21k
;fehBFAh830PLgA_LVEmJFHPKGQ9I7PPIfEd86=eLW9UKWA]HGAbJGPPL6m`82m]
N4UTN21]N4UTN20a865TI21cM6mbIGeTIFH=;g9dKG]]N4UTN20a86MU87/_KGQ9
I7PPKGQ9I7PP<B1cMF8PLgA_LVDPKGQCM6/PKGQ9I7PPIfEd87=UM6eQM79YN7eY
IR1mI6EV3BmcHf`PNb0g<R1TJGHPIGQSJ20g<R1TJGHPIGQSJ21cHf5/IB1m86AU
IPd_Lf=/JB1k83Lb86EhHfPPI6Uf86EhHfPP=c8PIGQSJ21TJGHPIGQSJ21cHf5/
IB1m86AUIPd_Gf=fKGAh86eQM79YN21TIFH=;emdN7A]M7PPKF5dLVUh86AUIPd_
GfU^JGA]M7PPKF5dLVUh86AUIPd_N6AVNfEhHfPPI6EVOFAUIPd_KFU^Nc8PHfm`
NB1WM7]UN6=XOFUV871_L7eTIFH=;feQN7/b86=_L7TPK7AkIGQSJ7eYIR1`Kg1m
I6EV3Bm3EWIUHb0b=CHPHG9bHGTPI6EV3BmD87AbMFDPI6EV3Bm686IQK7=U86AU
IPd_GfUT830PI6EV3BmOIFiSKfAYKVAUN20`86AUIPd_GfE^HfmT@G9b83<PHG9b
HGTPI6EV3BmOIV@P<21TIFH=;emdIGQdDf5fIB1^MFa/86AUIPd_GfaUM7AULU=`
HF=U830PI6EV3BmOLg1QHfEHM79Q830PI6EV3BmOD65WIE=QMVDPKWE/K21TIFH=
;em`IFiX834^<21TIFH=;em`IFif834^<21TIFH=;g=QMVD`86ieK6`PI6EV3BmO
Mb0`86AUIPd_GfPP<21TIFH=;emTLb0`86AUIPd_J6=d86IQK7=U86AUIPd_L7LP
<21TIFH=;gMTJFHP<21TIFH=;gAUKG0P<21TIFH=;f=eLW9_M20`86AUIPd_Lf5f
IFQQKVA/IG8PKWE/K21TIFH=;fUQ830PI6EV3BmYN20`86AUIPd_JGQ^834PI6EV
3Bm=MFadJG1/IDAQM65CKgEbHfEc86IQK7=U86AUIR0=;fAUHWEW3G]TMG0P;bAU
L7<PIGQSJ21^Kg@PI6EVNbmcHGIUJ65^I6aULR1ULW9_LVAYHg@P;fQQKVA/IFEb
LVmb86MUM21TIFH=IG9bKg9TJF=d3BmXHFiTK6EULW9_LW/TIG9bKg8PHVEWJFh=
KVEgIG9bKg9k;fiUMfEbLVmb86IQK7=U86AUIPecJ6mgL65WI@dg<R0g<R1cHf5/
I@d_B6E/MVEdJF=Q86IYKVAVKfid82hb87=SHFaUIVm^M21cIGAVKfid3Bhb=B0i
;SHPKFmfIGA_3BQ5LW9_LSXP:G=XKgL=IG9bKg9^HFeU3G]TMG0PM7U`IBmcM79Y
KVMdNG1U86iU3G/XHfm^MVEbM6ET86EbLVmb86iQKFDPMfU/K21UKV@PMG0PJFhP
M6QYLb1cM79YKVLYHgIcOFUV3G=XKgMmIGQUH`d^<SDP>Bhd86e_MVEdK`dXCfIV
IFiTJFiW84=_KFeQKV@j82UcJ6mg3BmSKfe]HFiT86a_HF@=NfAeL21dNG1U;g=d
LVU^IgAiL6DPKVD=NbQSKfifIG9dIF@PHfm]KF5^I21^HFeU87MYK6`PIFiT87E`
86U^87AXJG<PLgAbJFiW:F=fLgeYIPecJ6mgOFEhIF<=;S8e83T^<R1]KgIUM6l=
:5=dHF=[>R0YLfQ_M`e_LgAQHf/=Nbhb=B1SMG9bIFidL6mYKW@P;S8PLgER86Eh
HfPPL6m`86e_MVEdK`eTMG0PM7U`IBmcM79YKVMdNG1U86iUNfAeL21dNG1U;fU^
M6EWIG9dNG1U86Ea3C4PJFiTIGPPM7U`IBmbIF5/M7U`IB1ULB1_LPda86U^I6Eh
87AiL6D_KV5]IGAiL6DPIG4PKg8=KVmd87]dNG1UOFUV3BQSKfifIG9dIF@PLgAQ
Hf/PMfU/K21UKV@PMG0PJFhPM6QYLb1cM79YKVLYHgIcOFUV3G=XKgMmIVmbHFa/
3G=XKgM`HFMU3D=FA6USM20_Lf5fIFQQKVA/IG8PIfEd86EhIF=mJFH=IFiTOG1e
M7eYIWeTIFH=;faSNg=UM6aYKVESHG1mI6EV3Bm/JW]cIGA/JFiUJVmYKWeTIFH=
;fa]Ng=UM6eYM6EbK6U]JGAmI6EV3Bm/IW]cIGAVK65dOFAUIPd_Hg1kHfa_LfE`
HGAXOFAUIPd_KW1kKVEgL65dJ7eTIFH=;bA`LgXP<c0PHG9bHGTPI6EV3BlTL6Uh
830PI6EV3BmWLg]WLf5fIB0TL7=j86AeL20TL6Uh85m`IFiX871eM20TL6Uh834P
HFAT85m`IFif871eM20_971YN20TL6Uh838PHFAT86AUIWeTIFH=;fMbNfMbIG=d
Kg9U;bA`JGPP971YN20b87=eHR1TIFHP971cNR1TMG0P971YN21WIG@P;em`IFiX
86EhHfPPI6EV82A`JGPP<B1QI6@PIfEd82mOL6E^MR1UN6=X86AUIWeTIFH=;faY
NfaYKVEdKgdPI6EV3Bm/J7]SMG9bIFidL6mYKW@PIGQSJ21`Kg0PK6U^IGA_OFAU
IPd_K7IkHgEbLVE^M71_JFid871_L21UN6=X86aYKVEdKgeTIFH=;fedNfe_MVEd
KgdPI6EV3BmOHgIOKFQkHgEbLVE^M71_JFid86EhHfPPL6m`86e_MVEdKgeTIFH=
;emSMUm]MW]SMG9bIFidL6mYKW@PL6m`86EhHfPPKFmfIGA_OFAUIPd_HgAkHgEb
MVEdKgdPI6EV3BmbM7/d82db879_K6`PKFmfIGA_3FAeL20`86EhHfPPLVaYKVEd
K`eUN6=X830PLVaYKVEdK`e^IFLP<21UN6=X879/JFiUM6l=Hfa_LfE`HGAXOFAU
IPd_GfQb3G/=Nbm0IG9b86IQK7=U86AUIR1SMG9bIFidIVaQM21TMG1kIg=QMVEk
IFmSK6U`OG=dKg1`IFAkIg9ULgA_LVDP<R1]MF`PI7E`87=UM6I/HG@PI7E`838`
<21WIG/X9BDP@f5^MV5c>T=/JG0PIV5YK6ETG78YL79YKW@P;d1ULW8PM79eIB1T
IFHPL6m`86EhJGAmJFImNfMbIG=dKg9U87=UM6I/HG@PIGQYM7eYIVE/LfEmK6m_
L210IG9b86i_M21kIFmSK6U`OFUV87=UM6I/HGAm3G/_@6EbLR1VHFacIB1TIFHP
HgEbLVE^M6I/HG@PI7E`NfMcHGIUNf=/JG1mLgA_L71UI7]WLVEcM6mbIB0b86ee
K21TMG0PLfEdIVaQM21TMG0P<S0`86MUNbPU9B13HFifHG<j@faYL21VHFU/IFAL
LRU`LVU^M20_@6EbLR1dLWEU86AUIR1`Kg0PIGQYM7eYIWekIg9ULgA_LVDPLfEd
IVaQM21UN6UdOFUVIFacIGe/Kfm`841ULW8PKVmd87]SK6U`OFUV87=UM6I/HGAm
3GeTIFH=;emSLb1^MFa/86AUIPd_IVMkLfEdIg9QNGeTIFH=;g=UM6=]NF]SKfa_
LR1gJ6EbIB1kL6m`87AbMFEmNfIQK7=UOFUVIFacI@ek;fHdNb1cIGASKGU[Hfm/
Kg9mI6EVOG/_ISAk<B1cMF8P=20a879_K6`P<g/c86U^I6Eh865TI21^IFLPI7E`
830PK7AkL6m`831mJFHP<b0a879_K6amLVE`IF5d87=UM79WHV=_K6mb871_L7eT
IFImJFIUK7=U3BmcIGASKfa_LW=`HF=U87MXIG9U87]`Kg0PM79eIGekIV5/LfEm
JFIUK7=U3G/_Lf=cNb1TMG0PLfEdHfm/Kg9cL65SIB0_Gf=c86EhHfPPI6EVOFAU
IRmV<g/PGf=c87=UM6=_K6mbLg1QHfDPLfEdHfm/Kg9mI6EV3Gek;fHcNb1cIGAb
If9SKfa_LWeTIFH_Lf=cNb1`Kg1mI6EVOFUVIFacI@d_96=S83DPHG9bHGTPI6EV
3BmVJFiTHfeiJf=eLgA_KF=_K6mb87MXIG9U87]`Kg0PM79eIGekIV5/LfEmJFIU
K7=U3Fi_M21k;fIYKVASKGU[HgEcM6m]Hfm/Kg9k96=S865cM6mbIGeTIFImJFH=
;g=UM6=eLgA_KF=_K6mb87MXIG9U87]`Kg0PM79eIGekIV5/LfEmJFIUK7=U3Fi_
M7/_LfEdHgEcM6m]Hfm/Kg9kIGQSJ21QK6mQI21`Kg0PL6m`83Ak=21YKVAUN21]
MF`P=20a879_K6amLVE`IF5d87=UM6=]NF]SKfa_LR1`Kg1mI6EVOFUV3BmVHg/f
834PLVm/K21VJFiTHfeiJf=eLgA_KF=_K6mb86EhHfPPLfEdHgEcM6m]Hfm/Kg9m
I6EV3BmcIGAcIG1QLV5dJFm^Ig9QNB1gJ6EbIB1kL6m`87AbMFEmNfIQK7=UOFUV
IFacI@e^KgAk;g=UM7=UL65bHGAYKfiWLV5i87]cNG=dIFeTJF=d82mcIGAWLV5i
86MUM21UN6ESOB1TIFImJFH=;g=WNb1cIGAcIG1QLV5dJFm^Ig9QNGeTIFH=;g=`
NbmOL6E^MR1hI6H_Gg1UKVPPN6AVOFAUIPd_LW0=NbmSMUmR87QTIRmSMUmb87QT
IPd_HgIOM21hI6H_HgIOK21hI6H=HgIOK21SMUmd86e_MVEdK`eSMUmb86=fGg@P
K6U^IGA_3F=fGg8PHgIOHR1/JFiUM6l=HgIOK21SMUmR86aYKVEdK`eSK6mcIG1Q
M6QmI6EV3BmbLW/_NG9QI6UeLb1hI6H=;gQbHFAYMG<PN6AV3BmSMUmR87QTIPd_
HgIOLR1hI6H=;f=fGg@PN6AV3BmSMUm/87QTIPeSMUm/87QbHFAYMG<PHFAT86=f
Gg@PKFmfIGA_3F=fGg8PN79QI6UeLb1cMF8PHgIOM21/JFiUM6l=Gf=fKGAh86=e
LW9UKWA]HGAbJGPPL6m`3F=eLW9UKWA`KfU^M21dLV5^LfaQM6D=N79QI6UeLb1i
LV5TJGEc87=SHFaU3C4P<20a834P<B1QLV=dKb0dNg1_L7ebIG1UHG@=Gf=fKGAh
87=UM6eQM79YN0eSMUmb86=fGf8PNG9QI6UeLb1cMF8PK6U^IGA_3EmSMVedN21S
MG9bIFidKF5dLVUh871_L0eSMG9bIFidL6mYKW@PM79QKW=/HGAU3GQbHFAYMG<P
NG9QI6UeLb1cHf5/I@d`834P;C4P<B0a865bHgA_83AkL6m`OG9UL6EQM0eOHgI]
M7PPLfEdKF5dLVUh3F=fGf`PN79QI6UeLb1QI6@PHgIOHR1/JFiUM6l=Gf=fKGAh
86=eLW9UKWA]HGAbJGPPL6m`3F=eLW9UKWA`KfU^M21dLV5^LfaQM6D=N79QI6Ue
Lb1iLV5TJGEc87=SHFaU3Bda830P;C4P;C4P<B1QLV=dKb0dNg1_L7ebIG1UHG@=
Gf=fKGAh87=UM6eQM79YN0eSMUm/86=fGg@PNG9QI6UeLb1QI6@PK6U^IGA_3EmS
MVedN21SMG9bIFidKF5dLVUh871_L0eSMG9bIFidL6mYKW@PM79QKW=/HGAU3GQb
HFAYMG<PNG9QI6UeLb1cHf5/I@d`82da834P;C4P<B1QLV=dKb0dNg1_L7ebIG1U
HG@=Gf=fKGAh87=UM6eQM79YN0eSK6mcIG1QM6QmI6EV3BmUL7]OHgI]M7PPHgEb
LVE^M6eQM79YN21`Kg0=M79QKW=/HGAU3G=SHFaU3C4P<21]KgIUM6l=<20`834P
<20c=S0PHG9S3F=/Kg=UL65dJ0eOHgI]M7PPLfEdKF5dLVUhOFAUIPd_MfAkGf=f
KGAh86=eLW9UKWA]HGAbJGPPL6m`3GAbHFicK65dI@ecHf5/I@d`830PKFmfIGA_
3C0P<20a83DP;C8PLVm/K21QLV=^3F=/Kg=UL65dJ0eOHgI]M7PPLfEdKF5dLVUh
OFAUIPd_HG=kGf=fKGAh86=eLW9UKWA]HGAbJGPPL6m`3GAbHFicK65dI@ecHf5/
I@d`830P<B0e82db879_K6`PHG9SKPeOHgI]M7PPLfEdKF5dLVUhOFAUIPd_I7<=
Nem`IFif85m`IFiX86iU86AeL7]cM6dPGg1UKVPPI7E`830PK6EkL6m`835mJFHP
Gg1UKWHPI7E`830PK6EkL6m`835mJFHPLf=QK6EmNem`IFiX87=UM6aYKVEgJFAd
J7eYIVE/LfDPLgAbKf]U87]bM6emJFImI6EV3BmTIW]VJFa/OFAUIPd_I6EkIFmV
JFa/OFAUIPd_GfMcM6/P=B1QLW9QNB1TIFH=;emWLgA[Hb0`86AUIPd_GfMcM7/P
>B1TJF=d869UIfU^86aUMVE/<W/_Gf=SLb1SMG9bIFidHfm/Kg9cL65SIB1TIFHP
;emSHb1KHgEbLVE^M6=_K6mbGB1TIFImNbmOHf<PFf=eLW9UKWAbIf9SKfa_LUeT
IFImJFIUK7=U87]SMG9bIFidL6mYKWAmLgA_L71UI21k;emSL21^MFa/86AUIWek
838PHG9bHGTPHG=dKg9U82mOHg0PIGQSJ21TIFImJFIUK7=U82mOHfHPHgEbLVE^
M6I_KW@PI6EV3BmOHfag86=eLW9UKWA/JFiUMfUTM6PPI6EV82mOHfaS86=eLW9U
KWA/JFiUHf5`86AUIR0_Gf=/JR1SMG9bIFidK6U^IFY_JFhPI6EV82mOHfe/86=e
LW9UKWA]JGAULVaYKFUd86AUIR1SMG9bIFidI6USM21UKVAmI6EV3BmXLg]^IGM`
HGAX86McHGIU87=dKGeTIFH=;fQSNbmOJ78PK6mQI21UN6=X86MUM21UN6ES86iU
Mg1QM6QmI6EV3BmXIG]OIg=dJb1OIg=dJf<PGfMcM21`MG@P;emWLgA[Hb1OIg=d
Jf<P<B1QI6@PLgA_LVDP3FMbIG=dKg9U879dKB0_GfMcM6]S85mWLgA[Hb0a87=e
HR1cM6mbIB1OIg=dJb1OIg=dJf<PIfEd86aUMVE/<W]TMG0P;emSHg<PIfEd87=U
M6=_K6mbLg1QHfDPI7E`82mOHf<PIfEd865/Kf5T871_L21cIGASKfa_LWekI7E`
82mOHf<PIfEd865/Kf5T871_L21cIGAbIf9SKfa_LWeYIVE/LfDPI7E`82mOHg0P
IfEd86AeL21^MFa/86Ea80e^KgAkHFa_HF@PL6m`86e_MVEdKgekL6m`OFUVIFac
IB1TMG0P;emSIR1WIG@PLfEdIVm^M0eTMG0_Gf=/Mb1WIG@PLfEdK6U^IGMYI7AX
86AeL2mOHfaS86MUM21cIGA/JFiUHf5`86AeL2mOHfaZ86MUM21cIGA/JFiUJVmY
KR1TMG0_Gf=]K21WIG@PLfEdKFUdIG9/JFeYM21`Kg1mI6EV3BmYI7/P;emYI21h
I6ImI6EV3BmOJFeQM79YN7]OMb0`830PGfPPGfUT830PKVEkKVEW830PGfQmNc0P
<7eYIVE/LfDPGf=fKGAh865cM6mbIGeTIFH=9B13Kg1iLVUWJ7@P:4<Y834i>C0/
834i>C4PHWTP@FA_HVDPDgUcM6E]Lb19KV=_LW1_LV5dIF@^3BDP@Fa/879YIfQd
Lb1bIG=ULWIUI2h=K6EfIF`b87/PLf5fIB0_I6m^M6a_HFA/IGIUK34PN6AV87eY
IPd_LgAQLWA^Kfa_HFAkNbm^Kfa_HF@PLf5fIB1TIFIm86UVOFAUIPd_IFiTKVm/
Kf5TNg]^Kfa_HF@PLVEcM6mbIGeYIR1mI6EV3BmdIG=dLgUcM6E]I6USM7]gJ6Eb
IG]cNG=dIFeTJF=d86EaNgAbMFEmNfIQK7=UOFUVIFacIGekIV5/LfEmJFIUK7=U
OFAUIPd_KV=_K6mbLb0a86AUIPd_Hfm/Kg9YKF5WIB1gJ6EbIG]`Kg0PM79eIGek
IV5/LfEmJFIUK7=UNbm^Hfm/Kg9c830=LgAQM7EcI6USM21RIFMYKR0=;g1bKf=U
Lg=SKfa_LW<PMfQULVEkL6m`871_L21`LVmSIG=cHfm/Kg9cOG/_I6EfJF=UJFiV
Kb1gJ6EbIG]`Kg0PI6EfJF=UJFiVKb0_@fm/Kg9c86]^KgM^3G]`Kg0PNfAUMVUS
IFU^IVlP;d=_K6mbLb1WIGAmOFUVOFUVOFUVIFacIB1UKV@PI6EV3FiSKfa_LW<P
<21^IG/_Hfm/Kg9YKF5WIB1dIG=dLgUcM6E]I6USM0d_LfEdHfm/Kg9dLV5^LfIU
LR1dIG=dLgUcM6E]I6USM0d_HgEbLVE^M6=_K6mbM79QKW=VIG8PM6EcM7=iLgAU
KFAYHg@=;f=eLW9UKWASKGU[Hfm/Kg8PM6EcM7=iLgAUKFAYHg@=HFiT865^I21Q
KV@PKVmdNbm^Hfm/Kg9c830PI6EVOFUVOFUVOFUV3FiSKfa_LW<PI7E`834PKVDP
IGQSJ21TMG0P<b1^IB1UN6=X83@PKVDPHFiT865^I21k;fiSKfa_LW<P<21TIFIm
JFH=KV=_K6mbLb0a86Ea86AeL21TMG0PKVmd87=dHG9dKVm/Kf5T3G/_I6mSK7Ed
JFeQIfEkFg/b=CDPKGE/879_MFiT86=fJB1RMf=/MG@PIGQSJ21WIG@P<SDe86AY
MWdP;fEhIF<PK6mQI21TMG0PHgEbLVE^M7AbHFicIVEb86EhHfQM80eSMWPPHVU^
I21cIGAdLV5^LfIULR1OMb1OJ20h85mYKF5dLVUh85mTLb1YKF5WIGeTIFImJFH=
KVmd86E^I6i_K6mQI0e^Hfm/Kg9c86AeL20c86Ea86EhHfPP=21ULB1_LPeTMG0P
I7E`86i_M21cM65bM6i_K6mQI0ek;fieK6a`LVmSNg]mOFAUIRmSKfiSHGAeM6U/
NbmUN6ES86a_HF@==b0]<B1bKfa/82mUN6ES86a_HFAmI6EV3BmTIFIcMF9SK7Ed
3G/a865TI21WIGAYKWAULWIQK21TIFImI6EV3BmcL6=_KV=QM7AbHFicIVEb820P
3G/_A6=/MG@PIGQSJ21TIFH_@f=/MG@PIGQSJ21TIFH_@V=/MG@PIGQSJ21TIFH_
@F=/MG@PIGQSJ21TIFH_KV=_KG1eM6DPIGQSJ21/I0eSMG9bIFidHfm/Kg9dLV5^
LfIULPeKNd5SK7Ed86iSKfe`MGAUOF=_KV=QM7EdJFaM86=fN0eKNd9SK7Ed86iS
Kfe`MGAUOF=_KV=QM7EdJFaM86=fN0eKNd=SK7Ed86iSKfe`MGAUOF=_KV=QM7Ed
JFaM86=fN0eKNdASK7Ed86iSKfe`MGAUOF=_KV=QM7EdJFaM86=fN0ecIGASKfa_
LWAbHFicIVEbOFAUIPd_LfEdMG1bIf9SK7EdL`ek;f9YM3=h879WHV=/MG@PK6E^
IgAX83<PLgER86AUIPd_HVUd<GPPHVUd<gPP<b1YI6Uf86AUIRmbHfaeM21bIf9S
K7Ed86AUIPd_If=/MG@PLV=/MG@P<B1RJG@cN21TIFIcMF9SK7Ed;f9SK7Ed879S
K7Ed838PHVUd<gPPI6EVLgERHfaeM7eTIFImJFHPKVmd820=IFiTKVm/Kf5T86iS
Kfa_LW<P<b1ULB1TMG0PI7E`86i_M21cM65bM6i_K6mQI0ek;c=SKfe`MGAUNfEh
HfPPHVUd<gPPKGE/3G9_MFiT86=fJB1WIG@P<SDe86AYMWeTIFH=;fA_HfaeM6U]
HFMUNbD_LVMRHfaeM21hI6HPL6m`80ecIGAeL79WHV=/MGAc;c=SKfe`MGAU879S
K7Ed86MSK7Ed869SK7Ed86AeL0ecL6=_KV=QM7AbHFicIVEb85mg85mX83PPGfU]
HGAbJGP=FbmOI7<PK6mQI20_IGQUHb1/Kf5T82mTMG0PK6mQI21TMG1MHgIh3Fie
K6a`LVmS86ieK6a`LVmS87AbMFDP<b1SKfa_LVU]HFMUOFAUIWeYIR1^Kg@PIFiT
KVm/Kf5T86iSKfa_LW<P=21ULB1TMG0PI7E`86i_M21cM65bM6i_K6mQI0ek;g=d
MFIVHfaeM7]SKGU[JFiTIGPP<b0]<B1bKfa/871eM7eTIFH=;fIdKfU^M7/a86Eh
HfPPLgER838e=B1]MF`PLVmeKV@PHgIYOFAUIPd_=6=_KG1eM6DPNb1UN6=X869Y
M3Ah86eeK21bKgE^I21SMVTPIfEd838e=B1TJGHPOB1TIFH=;f=_KG1eM6ESKGU[
HfaeM7]cIGAeL79WHV=/MGAc;f9YM3Ah879WHV=/MG@PK6E^IgAX83<PJFAYMR0d
86eeK20d87=eHR1TIFH=;f=]NF]SK7Ed869YM3Ah83@PHFAT87=dLVU^Ib1TIFH=
;f=SK7Ed86=]NF]SK7Ed86AUIPd_KF=/MG@PHf=/MG@P<B1RJG@dN21TIFIcMF9S
K7Ed3BmiHfaeM21SHfaeM20b869YM3Ah86AUIW=eHV=/MG@=;f]SK7Ed86=SK7Ed
83<PHVUd=7PPI6EVLgERHfaeM0d_HfeiJfU^I6Eh830PI6EV3C0P<B1RJG@aN0ek
I7E`82mSKGU[JFiTIGPPIGQSJ21RJG@aN21UN6=X87=eHR0d86eeK21TIFH=<b1]
MF`PI7E`879SK7Ed86EhHfPPIfEd838e=B1TJGHPIGQSJ21TMG0PIf=/MG@PIGQS
J21WIG@P<SDe86AYMPeUN6=X869SK7Ed86EhHfPPIfEd838e=B1TJGH=LfEdLVMR
Hfm/Kg8PHgEbLVE^M6=]NF]SKfa_LPeVM6mYKW@PJf=/MG@PLgAeIVISK7Ed3FId
KfU^M21iHfaeM21cM7EVIV=/MG@=IWA_JFid86eSK7Ed87=dMFIVHfaeM0eVM6mY
KW@PHf=/MG@PLgAeIVISK7Ed3GeVKg9mI6EV3BmTKf=/MGAYKF5WIG]YKWIQK6UT
Hfm/Kg9dHF9/ICmkHfm]L7EdIF=]NF]SK7EdOFUV3BldHfm]L7EdIB1SHfaeM21]
HfaeM21iHfaeM21[HfaeM21cL6=_KV=QM7AbHFicIVEb3Emg85mX83PPGfU]HGAb
JGQK;emTLb1/Kf5T82mUN6ES86a_HF@_I7E`86a_HF@PI7E`86AeL5dPHgIh80e^
MFa/L79_Hb1^MFa/L79_Hb1^MFa/L79_Hb1dLWEU83@PHfm/Kg9YKF5WIGeTIFIm
JFH=KVmd86E^I6i_K6mQI0e^Hfm/Kg9c830PIG4=I7E`86AeL21^Kg@PLgAQLWA^
Kfa_HF@=NbmSKfa_LVEhL65^I7]]NG=dLVU^IfEhL20`879WHV=/MG@=<b1SKg1i
3CLP;C4PLVm/K0ek<b1]MF`P<b1WIGAYKWAULWIQK21`MGAYKWAULWIQK21UN6=X
83<PHFAT86EhHfPP<b1SKg1iOFI_LV5/K0e`Kg0PL6m`871_L21`Kg0PL6m`OFAU
IPd_Hg9UHGAUIGQ`HFiTLgAbNbm]NG=dLVU^IfEhL21UN6=X87=d<21/IFiWM6PP
KGE/87=dLVU^Ib1TIFImI6EV3BmTKf=/MGAYKF5WIG/_LVMRHfaeM21hI6HPL6m`
83<PHg9UHGAUIGQ`HFiTLgAb85mg85mX83PPGfU]HGAbJGP=FbmOI7<PK6mQI20_
IGQUHb1/Kf5T82mSKfa_LVEhL65^I21/Kf5T82mUN6ES86a_HFAM86=fN0eVHFac
IB0c86=_K6mbJFeQIfEmI6EVOFUV86i_M21UKVA^Kfa_HF@=K6EfIF`b87/PI6m^
M6a_HFA/IGIUK34PLVEcM6mbIB1mJFH=K6EfIF`b86i_M7/PLf5fIB0_I6m^M6a_
HFA/IGIUK38PN6AV87eYIPd_LVMRHfaeM20`86AUIPd_I6mSK7EdJFeQIfEk;fQY
MV5/838e=B1TIFHP3E/_BFiTIGQUI20_A6EfJF=UDTM286QYMV5/879WHV=/MGAM
87=UM6=_K6mbLg1QHfD=GfU]HFMUI6USM21TMG0PHVEWJFhP3BmGJFAdJ21OMb1T
IFHP3Bm8IFUWJ7@PGfPPI6EV820=;dAUHfmTIB1K<21XJGIQK5dPI6EV820=;dU]
HFMUCF5dLVUh85mYKF5dLVUh86AUIPd_@VUdLe1ULT=_KG1_KVE^M20h86AUIR0=
;dU^M6EbL6m/HGAU86IQK7=U86AUIPeUKV@PJFeQIfEmI6EV3FaUMVE/<R1^KgAk
86A_KWA/Kf5TK6EfIF`b879ULgA_LVDPOFUV3BDUAFiTD79_He=UM0d_GfU]HFMU
I6USM20a=B1TJF=d869UIfU^82m9KF5WIEAiL6DP<B1TIFH_@VUdLe1ULT=_KG1_
KVE^M20h86AUIRm9KWAULW1_K65dIB1VHFacIB1TIFHPHgEbLVE^M6AYHg@PIFiT
86AUIPd_J65cHfm/Kg8PM79eIB1TIFH=;faUMVE/<R1cNG=dIFeTJF=d82m/HFiW
MF5WIFaUMVE/86]^KgM^3G]/HFiWMF5WIFaUMVE/838PIfEmNfIQK7=UOFUVIFac
IB1TIFH=;fI_MG9ULB1k=21YKVAUN21ULB0h834PLVm/K0dd86U^I6Eh86Ea83PP
<B1bKfa/3C@PJFiTIGPPIG4P>20a879_K6`==21YKVAUN21ULB0h834PLVm/K0e`
Kg0PL6m`871_L21`Kg0PHFiT865^I21QKVAm86AUIPd_LfEdMG1RHFiTLg]WLf5f
I@d_Gg=UM7AbHFicIVEb87=iLgAUKFAYHg@P;g=UM7AbHFicIVEb86MUM21TIFH=
;emSMG9bIFidM79QKW=VIG8PLgUcM6E]I6USM20_HgEbLVE^M7AbHFicIVEb86MU
M21TIFH=;emYKF5WIB1cNG=dIFeTJF=d82mYKF5WIB1WIG@PI6EV3BmRK65^Jb0`
85mSMG9bIFidM79QKW=VIG8PIGQUH`da85mSMG9bIFidM79QKW=VIG8PIGQUHb1U
LB1TIFH=;fiUIf5dJGIU869/HFi[Nc0PGf=eLW9UKWAdLV5^LfIULR1UN6ES830^
=B1/M7d=Nc0PGf=eLW9UKWAdLV5^LfIULR1UN6ES834PGf=eLW9UKWAdLV5^LfIU
LR1UN6ES86MdOFUVIFacIB1TIFH=;fU^MVEbM6ET?b1^IFMQM6UfIB1TIFH=;emS
MG9bIFidIg9QNB1cNG=dIFeTJF=d82mSMG9bIFidIg9QNB1WIG@PI6EV3FQQLf=_
K6mbNblTHR0`86AUIWdPNblTHR0e86AUIWdPJFIUK7=U3BmcIGASKGU[Hfm/Kg8P
MfQULVEkL6m`834P<20`830PLfEdHfeiJf=_K6mb85mSMG9bIFidIg9QNB0a86Eh
HfPPLgER3C0P<B0`830PLfEdHfeiJf=_K6mb85mSMG9bIFidIg9QNB0a86EhHfPP
LgER3C0P<20a830PLfEdHfeiJf=_K6mb85mSMG9bIFidIg9QNB0a86EhHfPPLgER
3C0P<20`834PLfEdHfeiJf=_K6mb85mSMG9bIFidIg9QNB0a86EhHfPPLgER3C@P
Nc@PHfm`NGdPLVE`IF5d3C4P<20`830PIVmeLVEaNblTHR0a87=dKg9UOFUV3C0P
<B0`830PIVmeLVEaNblTHR0b87=dKg9UOFUV3C0P<20a830PIVmeLVEaNblTHR0c
87=dKg9UOFUV3C0P<20`834PIVmeLVEaNblTHR0d87=dKg9UOFUV3C0P<20`830P
IVmeLVEaNblTHR0f87=dKg9UOFUVOFUV3F9/HFi[NblTHR0f87=dKg9UOFUV3BAR
830PIG4P968P=B1ULB1_LW/_96Ad830PI6EVOFUV;bATM20]<B1TIFHPIg9ULgA_
LVEmI6EV3BmTKfU]HFMUN`e/IGIUK39kJFeQIfEmNf9UIfU^3EMYI7AX84QUJFMX
M212JGAcD6Eb@fm]L6m^IFid84U]HFMUCF5dLVUh3DAUHfmTIB1/IFiWM6PP<R1U
L@ek;dAQM65CKgEbHfDPK6mQI21UKV@PJFeQIfEmN`e4IF=_I6DPK6E^IgAX83HP
IG4=NdeeK7AYL6aUA65dHE=_MG9SIG=kA65dHE=_MG9SIB0`86MUM214HGAQDfme
LV=U834PIfEd84AQM65CKgEbHfDP<R1WIGAmNbm4HGAQDfmeLV=U86a_HFAmJFIU
K7=U3DeeK7AYL6aUA65dHE=_MG9SIG<P<b1UKV@PA5=9@fm/Kg99KF5WIGek3DAU
HfmTIB1/IFiWM6PP>21ULG]=MFadJG1/IDAQM65CKgEbHfEcNdAQM65CKgEbHfDP
<21WIG@PA65dHE=_MG9SIB0a86MUM0e4HGAQDfmeLV=U838PIfEd84AQM65CKgEb
HfDP<b1WIGAmNbm4HGAQDfmeLV=U86a_HFAmJFIUK7=U3DeeK7AYL6aUA65dHE=_
MG9SIG<P=21UKV@PA5=9@fm/Kg99KF5WIGeYIWeYIVE/LfD=OFUVIFacI@emJFIU
K7=UOFAUIPd_I7Ak;g9WHV=/MG@PN6AV82mRMf=/MG@PN6AVOFAUIPd_Hfak96TP
LfEdKF5dLVUh87AbHFicK65dIB1cHf5/I@d_GgLPGfU]HFMUI6USM20_EfUTM6PP
IfEd86AUIPd_GfPPGfU]HFMUI6USM20_B6EYIfQd86MUM21TIFH=;emTLb1OJFeQ
IfETJF=d82m4HGAQDfmeLV=U86MUM21TIFH=I6mSK7EdJFeQIfEm86AUIPd_HfAk
96TPLfEdKF5dLVUh87AbHFicK65dIB1cHf5/I@e/IGIUK39kGfU]HFMUI6USM20_
@fm/Kg9CL65SIB1WIG@PLfEdHfm/Kg9cL65SIGeYIPd_GgLPGfU]HFMUI6USM20_
EfUTM6PPIfEd86AUIPd_GfPPGfU]HFMUI6USM20_B6EYIfQd86MUM21TIFH=;emT
Lb1OJFeQIfETJF=d82m4HGAQDfmeLV=U86MUM21TIFH=GfU]HFMUI6USM21RIFMY
KPd_BFeQIfE=HGAbJGPPGfU]HGAbJGPPI6EV3F=eLW9UKWATJF=d86E^I0eTKfU]
HFMUOB1TIFH=;fU]NbAY87=UM6eQM79YN21dLV5^LfaQM6DPLf=QK6DP3FaUMVE/
<W/_A6EfJF=UAg9QNB1cIGASKfa_LW=`HF=U830PLfEdIg9QNGeYIPd_GgLPGfU]
HFMUI6USM20_EfUTM6PPIfEd86AUIPd_GfPPGfU]HFMUI6USM20_B6EYIfQd86MU
M21TIFH=;emTLb1OJFeQIfETJF=d82m4HGAQDfmeLV=U86MUM21TIFH=GfU]HFMU
I6USM21RIFMYKPdU;dAUHfmTIB1K<20aGB1TIFHP80dU;eMYI7AX85mg86AUIPdU
;dQUJFMXM21OJ21TIFH=;dU]HFMUCF5dLVUh85mYKF5dLVUh86AUIPeSMG9bIFid
I6USM21UKV@P3FA_JFeQIfDPOFAUIPd_Hfm/Kg9YKF5WIB1gJ6EbIG]`Kg0_A5=9
@fm/Kg99KF5WIB1kHfm/Kg9YKF5WIGdPI6EVOG/_A5=9@fm/Kg99KF5WIG/=;bA^
Hb1hI6HPL6m`82m`LVmS<21hI6HP<b1YKVAUN20b86U^I6Eh86eeK20g865TI20h
86AYMR1SMVTPLgAbJFiW82mcM34PN6AV3BA^Hb0c86EaNg]`LVmS<21TMG0_Lg@`
87QTIR0`86EhHfPP<b1UN6=X86aUKVMdJ20c87=eHPekI7E`87=d<21UN6=X86MU
M20^<b1]MF`P<B1YKVAUN20a865TI21cM30PIGQSJ21WIG@P;SDi86eeK21QI6@P
<B1YKVAUN20b865TI21cM30PIGQSJ21WIG@P;S4a86eeK21QI6@=HgIY86EhHfPP
<b1TJGHPHgIY86EhHfPPLg@a83<P<B1bKfa/871eM7eVKg8PLg@aOGekNg1bKf<`
86AeL2mcM30PN6AV830PIGQSJ20d86EhHfPPK6E^IgAX83@PLgERNfAeL0ecM30P
IGQSJ21WIG@P;S<PKGE/3C4PJFiTIGPP<B1QI6@PLg@`86EhHfPPIfEd82he>B1]
MF`PHFAT3C4PJFiTIGPP<R1QI6@PLg@`86EhHfPPIfEd82ha<B1]MF`PHFAT3C4P
JFiTIGPP<b1QI6@PLg@`86EhHfPPIfEd865TI21TMG0P<SDe;S0PIgAkL6m`838e
=Bh`OFUV3C8e=Bh`86EhHfPPLgER86=fJ@eUN6=X83@PI6Uf86=fJB1UN6=X3G=d
<B0c834PLVm/K21`MGAmIVmb87=d<GemJFIUK7=U3FU]HFMUOFAUIWeYIVE/LfD=
;dm@BFU]HFMUNfU]HFMUOFAUIPd_96TPKF5dLVUh86AUIPd_HVUkLf=QK6DPM79Q
KW=/HGAU82AY86=eLW9UKWA]HGAbJGPPL6m`87AbHFicK65dIB1cHf5/IB1cIGAe
L69QKVAcOFAUIPd_IFUk96TPLfEdKF5dLVUhOFAUIPd_JF]k96TPLfEdKF5dLVUh
87AbHFicK65dIB1cHf5/IB0=;emg85mYKF5WIFAYHg@P;eMYI7AX86MUM21TIFH=
;emX85mYKF5WIFAYHg@P;dQUJFMXM21WIG@PI6EV3BmOI7<PGfU]HFMUI6USM20_
A65dHE=_MG9SIB1WIG@PI6EV3Emg85mX86IQK7=U85mYKF5dLVUh83DP;C4PLVm/
K21OI7<PJFeQIfE]HG=[OFAUIPd_LW=k<R1SKg1i87AbHFicK65dI@dc82da879_
K6`PKVEW879_M65dI@e^IFLPIGQSJ21^IFLPIGQSJ21dLV5^LfaQM6D=OFAUIPd_
Hg=kGf=fKGAh865cM6mbIB1SKfiSHGAm86AUIPd_IVAk;emVI21hI6ImI6EV3BmO
IVm^M4eQM79YN7/a830P<21OIV@P<21^IG/]<B0`831mNc4P<20`OFUVIFacIB1O
HgI]M7PPHG=dKg9UOFAUIPd_LVIk;emUKV=_I6U^I6Eh87QTIPe6KfidA6UbIF=d
Kg9i86EhHfPPJfi_MfhPN`eVJFiTIVm^M21TMG0PK6E^IgAX834PHFAT86AYHg@P
HVEWJFik<B1YKVAUN2m6BD@PKVEkI6EVOG]`Kg0PL6m`OFUVIFacIGeVKg9QK6`=
I7E`82m6KfidCV5]IB1UN6=X86AUIR16KfidE7U`IB0`86iUNbm5KV=_I6U^Ib15
KV=_I6U^Ib0b=CHPHG9bHGTPHfm`NB1TIFH=GfE^HfmTJFiTIGPP<21WIG/`85mU
KV=_I45bLR1OIFiSKfAYKVAUN21WIGAkI7E`87AiL6D_KV5]IGAiL6DPIG5kAFiS
KfAYKVLP<R1YKVAUN20b86U^I6Eh871eM21`Kg0P<B1QI6Am3G]UN6=X871_L7eY
IVE/LfEmIVmbHFa/871_L7eYIWeYIPeSMG9bIFidI6USM21UKV@=I6EVJFiUIVm^
M21`Kg0POG]`Kg0PL6m`OFUVIFacIGdPI6EV3BmSMW=VNb1VJFiTIVm^M21VM5=Y
NVDP<20`86IdDfUjIB1OIV@P<21^IG/]<B1]MFamJFHP<20`85mSMVedN21QLgA_
LVDP3FeQJfEVKfid87=UM6I_KWAmI6EV3Bm]IW/c82da879_K6`PIVU^I6I_KW@P
<b0a879_K6`PIGQSJ21VM5=YNVDPKGE/86EhHfPPIWACJGYU86eeK20`86EhHfPP
<21UN6=X80eOIV@P<21^IG/]<B1]MFamJFHP<20`85mSMVedN21QLgA_LVDPKF5[
IFI_KW@PLfEdIVm^M7eTIFH=;gMbJc4P:20Y86AUIPd_MfAYHg@P<CHPI6USM21T
IFH=;eM_LV/g=B0g=B1cM79YKVLPI6EV3Bm>KF]kEfmbJcLe86=fLb1TMG1mI6EV
3Bm>L7AkL7Ed86=fKWeTIFH=;fAXCfAXNdi]Jb0b83Li84i`M7eTIFH=;fAX@VAX
Ndi]Jb0b834a<B1>L7AmI6EV3BmTJ5=TJ7]>KF/P<R0h<b1>L7AmI6EV3BmcIUMY
I7AXNfMcHGIU830P<21]KgIUM6lP<20`86aYKVEdKb0`830PK6U^IGA_830P<21/
JFiUM6lPHfa_LfE`HGAX86=/JG0PLgAbJFiWMfUTM6PPIg9ULgA_LVEmI6EV3BmV
M7=k;fIdDfUjIB1UN6=X86AUIWeTIFH=;fe[AUAkI7E`;dI_KWADNG1U86MUM20`
86EaNfAeL21]HGQ/IFiWM6PPI6USM21RIFMYKPek<B1YKVAUN2m6BD@PKVDP<R1Y
KVAUN20_EFiYLGEUBD@PKVDPHFiTNfAUIWekL6m`871_L7eYIVE/LfEmIVmbHFa/
3F=eLW9UKWATJF=d86E^I0eTMG0_ATAUL5IUHgA_LR0b86=_L7TPIfEd3E]UN6=X
83HPJFiTIGPPIGQSJ20f86U^I6Eh86EhHfQkKF]6E20c834PLVm/K7eVKg9QK6`P
L6m`871_L5dPL7Ed86AeL7ek;gAUKG16E20a<R1TJF=d86AUIPedIFe`AU@PHVEW
JFh=;dI_KWA=HGAbJGPPFc4P<20`834P<20`GB1TIFH=;dI_KWADNG1U83<PI6EV
3FAeL2m5KV=_I6U^Ib1WIG@_AFiSKfAYKVLPIGQSJ21TIFH=;g1bKf<b838PJFiT
IGPPI6EV3FAeL2mVM34PIGQSJ21TIFH=;fId<R0a865bLV5i86AUIPd_AVm^M492
KgPPFc0P<20a835M86AUIPd_@WEYK6A3J65bNd=FA6USM21RIFMYKPeUN6=X86Ae
L2mVM6Ad87QTIR1RIFMYKPegI6USM21RIFMYKPd_HfQb87QTIRmSJ79cM21gLV/a
86AeL20`86=XLR1`MG@PI6EV3FId<R0`86MUM21^MFa/86EaNfId<B1TMG0PK6E^
IgAX838PHFAT86AYHg@PHVEWJFh=Nc4PJFiTIGP_ATU486iU838PJFiTIGPP;eE^
JG5eIDU486iU865^I7]TIFImNg1_L21`Kg1mJFIUK7=UOFI_LV5/K0d_D65YKWAD
NG1U838PI6EV;e=dLVm[IEMYI7AX82h`<S@P<216KfidCF5dLVUh86UTM79QKW=V
Kg9]871_L21TIFH=HgEbLVE^M6AYHg@PIFiT3Bma86EhHfPPI6EVJFiUIVm^M0eV
M38PIGQSJ20`86EhHfPPL7EdOFUV3FIdI7@_L79_Hc8PIfEd86EhIF<PIFiT86E^
I21UKVAmI6EV86E^I21dIFe`AUAmJFIUK7=U3C<PJFiTIGPPIGQSJ0eTIFIYKVEV
Kfid86EhHfPPL6m`OFAUIPd_KF9kI7E`86AX@VAX84I_KWA4JG9UHgA_LWTP<B1Y
KVAUN21[KVmgKPekIGQSJ21`Kg1mNfAe02<0002Q0<0oog0P<R1YKVAUN0eVJFiT
IVm^M7]RKfaTL79_HgdPIGQSJ0e]JdID871_L21`Kg0PL6m`86EhHfPPL6m`3GeY
IVE/LfDPOFAUIPd_KFmkI7E`86AXCfAX84I_KWA4JG9UHgA_LWTP<B1YKVAUN21[
KVmgKPekIGQSJ21`Kg1mNfAeL20b86U^I6Eh3FIYKVAVKfidNfmeM71bKf=m86Eh
HfP=KF]6E21`Kg0PL6m`871_L21UN6=X871_L0emJFIUK7=U87eTIFH=;fecNfAe
L21TJ5=TJ216KfidA6UbIF=dKg9i834PJFiTIGPPJfi_Mfh=NfEhHfPPL6m`OG]T
MG0P<R1YKVAUN0eVJFiTIVm^M7]CJ65T@fQQLWdPIGQSJ0e]JdID821`Kg0PL6m`
871_L21UN6=X871_L0emJFIUK7=U87eTIFH=;fmeM71bKf=kIW@a87=UM6I_KW@=
Ig=QMVDPHfQbLg@PLfIGJFAdJ21WLVEcM6mbI@ecIGASJ65bMfUTM6PPI69/LfQm
I6EV3BmRKfaTL79_Hg]VM34PLfEdIVm^M0eWLf5fI@eSJ79cM21cIUMYI7AX834P
JFiTIGPP<21^IG]UN6=X82h`=B1QI6@PIGQSJ7eYIPeWLVEcM6mbI@ecIGASJ65b
MfUTM6P=IW@a82m@HFU^M5AiL6DPIfEd838PKVD=Nc0P<21]KgIUM6lPIg=QMVDP
IW@b830PIfEd87=UM6I_KW@PHfQbLg@PLfQ_Mb1WLVEcM6mbIB1SJ79cM21cJ6mg
O@ek<20`86e_MVEdKb1WLf5fIB1SJ79cM21cJ6mg86MbIG=dKg9U82h`=B0`86e_
MVEdKb1SJ79cM21cJ6mgOFUVIFacIGeTIFH=;fARK7=XNf=eLW9UKWASKfa_LR1S
MG9bIFidHfm/Kg9cL65SIB0a;S0PLfEdIg9QN@eSJ79cM20`830PKFmfIGA_87=X
KgLPLfEdHfm/Kg9cL65SIB1cIGASKfa_LPeVM38P<21WIG@PLfEdIVm^M21SJ79c
M20`830PKFmfIGA_87=XKgMmI6EV3BmCJ65T@fQQLW/=IW@a87=UM6I_KW@=Ig=Q
MVD=HfQbLg@PLfIGJFAdJ20a86U^I6Eh830PKVEkIGQSJ20^<3DPHFAT86EhHfQm
JFH=Ig9ULgA_LVD=LfEdHfQQLWMYI7AX3F=XLW=d82h`=R0`86e_MVEdKb1cJ6mg
3C0P;S0e87AbHFicK65dIB1THVacJ7eTIFH=;gAcNg=XKgMmI6EV3BmdHG/_GfaU
M7AULU=`HF=U87QTIRmOLg1QHfEHM79Q87QTIWeTIFH=;gAVNbmOM6EhM5MYI7AX
87QTIPd_GfieKE=`HF=ULb1hI6H=;emcM79YKVM<IFiWM6PPN6AV3FAeL0UcM79Y
KVMgJFAdJ21`Kg0=GfaUM7AULU=`HF=U85mcM79YKVM<IFiWM6PP<B1cMF8PKGE/
865TI0eOLg1QHfEHM79Q85m^MFeCL65SIG<PKGE/865TI0eOM6EhM5MYI7AX86Eh
HfPPLgER82mgI6UV87QTIPeOLg1QHfEHM79Q830P<c8=MfAYIR1OLgAbJFiWC6E^
IgAX86AYMPeOK6EdM6EbDg1QHfDPHFAT3C0P=R0]<B1bKfa/865gJFAdJ7=XKgMm
I6EV3Bm`HW/_Ge1QIfECHGIU87=QMVDPI6EV;g=XKgM`HFMUNgeTIFImI6EV3Bm`
IG]OD65WIE=QMVDPLVEcM6mbIGeTIFH=;g1]Nem`KB1SMG9bIFidKF5dLVUh871_
L7eTIFH=;em`KB1]HGAbJGPPI6EV3Bm`Lg]cJ6mgL65WIB1OL6dPLfEdKF5dLVUh
OFAUIPe/IGIUK39k;fEV87]WLf5fIB0f865bLV5i865cM6mbIB1SKfiSHG@PI7E`
86EhIF=VKg9]86MbIG=dKg9UOFAUIWd=NbmUIW]WLf5fIB0f865bLV5i865cM6mb
IB1SKfiSHG@PKVEgL65dJ21TMG0PHVEWJFhPCF5dLVUh86=_KV=QM0e2@Vmh86Ae
L21TMG0P<21WIG@PIGQSJ20a86MUM21]KgIUM6l=I7E`86AeL20`86MUM21UN6=X
83<PIfEd86aYKVEdK`eTMG0PI7E`838PIfEd86EhHfPP<b1WIG@PK6U^IGA_3FAe
L20b86MUM21UN6=X834PIfEd86aYKVEdKb1SK6mcIG1QM6P=HfaYL21^IGM`HGAX
851QJFidD79_Hb1UKV@PIg9ULgA_LVEmI6EVOFUVIFacI@d_HV=kLf5fIB0a<B0a
879_K6`P<C0PI6USM21RIFMYKR0_@T9_N20e834PLVm/K20d865bLV5i865cM6mb
IB1TIFH=;deQM79YN20g834PLVm/K20f865bLV5i865cM6mbIB1TIFHP;dI_LVeD
NG1U834PI6EV;e1QJFidD79_Hg/_L70PIfEd86EhIF=mI6EVOFAUIPd_IF=kL6m`
879ULgA_LVEmI6EV3Bm`LVU^M7I]Nc4PMVebIF=/HFU]87I]LgAQM7Ec871_L21U
N6=X871_L20X820P820P820P820P820P820P820P820P82USMW<PL79YKW@P:5a^
:G1bJFid86I/MG=XOFAUIPd_LfEdKgIULW1bJFid87MXIG9U87]`Kg1mNbmcIGA_
MVEbL79YKWAkL6m`OFAUIWeYIVE/LfD=;g=cM78PNb0_97=cM79c86EhHfPPI6EV
82lTLg=dLR1UN6=X86AUIR0_97=cM79i86EhHfPPI6EV82lTLg=dLWPPIGQSJ21T
IFHP;d=_MG9YIG8PIVU^I6I_KW@P97=cM79c80ecHf5/IFI_KW@PLfEdIVm^M20T
Lg=dLWPP97=cM79i86ed87=dKB0a82da87=SHFaU82AcLgAb87=XKgLPLWA]87dP
I6EV3Bm4DdU2IFMYKU1QJFidD79_Hg/_L70PKF5bJg]SMG9bIFidIVU/IB1dKf]U
KR1^KgAkOFUV86AeL2m4DdU5KVA@HFU^M51bKf<=2FEaNg1_L21SKgE^M7A_KF5b
Jb1QLW9QNB1QLgA_LVDPHgIh869YKV@P;fEhIF<PK6mQI5eSMWPPI6EV84ACBDE^
I51QJFidD79_Hb1UN6UdO@d9Nf=_MFidM6m]HG9[83<`<21WM7]SKgE^M7A_KF5b
Jb1QLW9QNB1QLgA_LVDPHgIh869YKV@P;fEhIF<PK6mQI7eYIWeYIVE/LfEmK6m_
L7eTIFH=;dACBDE^I51QJFidD79_Hg]SMG9bIFidI6USM21UKVAmI6EV3Bm4DdU2
IFMYKU1QJFidDgERD79_Hb1kLf5fIB0a<B0a879_K6`P<C0PI6USM21TMG0P;g14
86EhHfPPI6EV869UIfU^80d9;d92KgPP=B0a879_K6`P=21QLW9QNB1QLgA_LVDP
I6EV82m=HGAbJGPP=b0a879_K6`P=R1QLW9QNB1QLgA_LVDPI6EV80d9;dI_LVeD
NG1U834PI6EV82m@HFU^M51bKf<PNb0_L70PIfEd86EhIF<POB1TIFHP;g1`OB1T
IFH=;dACBDE^I51QJFidDgERD79_Hb1kHVU^I21TIFHPIFiT8714OB1TIFH=;fUQ
HB1k;fUh86Uh86UhKR1QI6@PI6EVOB1TIFH=;fUQLc8PNbmYIf5`86EhHfPPI6EV
82mOLg@`86UQ86Uh86UWHG0PHFAT86MUM21TIFHPGg=d<7dPI6EV3BmYHG<PNbmc
M30PJF4PJGPPIfEd86AUIR1YHF4PLg@`OB1TIFH=;fTh=G<PNc0PJF5c<R0_@E=3
BDTh=DAUHfmTIB1VJFadIG8PLg@`879UHFAcM79YKVLPL6m`86UQHGdPI6EV3BmY
LVaULb1k<21YHG<b82m1Dd=9BCPeA6ESKfAU86IYK7AULR0_DWE^C6E^IgAXA6ES
KfAU86IYK7AULR1cM30PLVEQI7=dLVU^Ib1`Kg0PJF5QOB1TIFH=JFiYM6UQK6Uj
I@eUKV@=9BE5KVABIG=_MG9SI@e3ETAYHg@PHVEWJFhP<21YI20a86IT3EmUKV=_
I45bLR0`3E/=<cT_LGE_M6EcJFiWK6DP>CH_Ig9QMVD=<C8h;f9eK6aUM2mRMFa/
IG@_LGE_M6EcJFiWK69QLfD_IVa_LVU^;g5eKgAUI69/HV5cIBmUK6aYL7=YLbmT
HFMWIG8_I65WIfEbI69/;f=YLV=eKFI/IGP_L6EbM6Q_MG=QKV@_Df=QLVm^;fMe
JFacJFiWK6aUIW@_CdD_HWE/K6Ed;f9eK6aUM2mRMFa/IG@=;f9eK6aUM2maMFmd
IFaUIW@_LGE_M6EbJFMXM2maMFmdIFARK6aUIW@_LGE_M6ETHVabJFMXM2mRMFa/
IG@_IFiTHG=X;fE]I65cJ2mdJFaTIBmdLV5TIFeQLV/=;g=SHG9_KPd_IgEYK7=Y
KVM/LVUWJ7@_KfD_HWE/K6Ed;f9eK6aUM2mII6UULVEcJG<=;f9eK6aUM2mUN6=/
HFeTKgM^;f=UKW@_LgAULVaYKVL_HgEbLVE^HgT_NFE^;f9bKf]UKV9QLRmcIF=d
JFm^;fAYIG9ULfUc;f=_L7UbJFMXM2m_LVAVIFeYKVU^IBmWMFU/K6E]KgA/IFId
;fa_IfUSHFa^Kg@_J7U`J6E^;g9UIfUcM6EbIF@_KF5SLVm^3BmTIFMbIFD_L6ae
LfeYKWEc;gAgKg=eL6EbJFmb;gAXLVEULgE`IG9YKg8_HF=eM6D_KGD_L65bHFMb
HG1X;g1ULVU_I6=UKWAULVET;f=UI6U/K64_KfiULgE`IG9YKg8_Kg9TKF5cHgE/
JFiU;fMeJFa/IFe_M79YIfQd;fm^IG5eHG9dIG8_KfiUJ65/IRmdJ79UIG5eHG9d
IG9c;g5eIG=dJFm^I6mgKPd_@FMbHGIU;d5QHgEdIBm1HfUbHgE]IVaUN2m1M6U/
I6D_@FAYIG9ULfUc3Bm1LVU^I`d_@DD_@f=UI6U/K64_AFMbHGIU;dEQHgEdIBm5
Ig9QMVD_AFAYIG9ULfUc;dUWLV5fIBm9HF=eM6D_BF=YLV=eKFI/IGP_BFAYIG9U
LfUc3Bm5M6P_CWAYK6AU;dmWLV5fIBm?HF=eM6D_Cf=YLV=eKFI/IGP_CgAYK6AU
;dmTJFEbIG=YLbm]MFadJG1/NBm?LfaQLfP_EFMbHGIU;eEQHgEdIBmEHfUbHgE]
IVaUN2mEI6UULVEcJG<_FF5SMGAU;eAXKg9^;fMULVeQKVARK7<=;f5WLV5fIBmQ
HF=eM6D_HF=YLV=eKFI/IGP_HGAYK6AU;f5TJFEbIG=YL`d_HG9YKVL=;f5U;f=S
IFAYK6aQ;fEWLV5fIBmUHF=eM6D_IF=YLV=eKFI/IGP_IFAYIG9ULfUc3BmYIg9Q
MVD=;fUQHgEdI@d_JF=YLV=eKFI/IGP=;fUTJFEbIG=YL`d_IGAX;fidJFaTIBm_
Ig9QMVD_Kf5SMGAU;fmSJG9SMFeVK6Eh;fmdJFaTIBm_I6UULVEcJG<_I6UfJFAU
;fmcK65cJ2meIg9QMVD_MF5SMGAU;gESJG9SMFeVK6Eh;gETJFEbIG=YLbmiHF=e
M6D_M6Q_LVh_NFAYIG9ULfUc3EdPL7Ed3EmUKV=_I45bLR0a3E/=<cT_LGE_M6Ec
JFiWK6DP>CH_Ig9QMVD=<C8h;d5TJFEbIG=YLbm1LVU^Ibm3HfETJFa/HBm5HF=e
M6D_CWAYK6AU;dmTJFEbIG=YLbmEI6UULVEcJG<_HF5SMGAU3BmQIg9QMVD_HF=Y
LV=eKFI/IGP_HFAYIG9ULfUc;f5dJFaTIBmQLVU^IbmSHfETJFa/HBmUHF=eM6D_
IFMbHGIU3BmUHfUbHgE]IVaUN2mUI6UULVEcJG<_JF5SMGAU;fUWLV5fIBmYHfUb
HgE]IVaUN2mYI6UULVEcJG<_KWAYK6AU;fmQHgEdI@d_KfMbHGIU;fmSJG9SMFeV
K6Eh;fmTJFEbIG=YLbm_M6U/I6D_MF5SMGAU;gEWLV5fIBmeHfUbHgE]IVaUN2me
I6UULVEcJG<=;fAQIfMULRmTIFMbIFD_HfE^M2mcM6EbK6U^IbmcIF=dJFm^;f9e
K6aUM2m`HG9QIg9QL6P_IfEbKF5^I69/L`d_LVEWJG=dIG9UI2mSKg1iLVUWJ7@_
M79QI6E]HG9[;f5SMGAU;fAYIG9ULfUc;fi_M6EaMF5/;d55;dmcK65cJ0d_JFiV
JFiYM7T_L6aeLfeYKWEc;faULg=ULGEQK2mWLVEQM6EbIG5eHF`_NFE^;fee;g1Q
LWAYHFaTJFIV;g=eKFeQM6U_KPd_L79_I7ESM2m`JBmYKWAUIg9QK2m_LVAVIFeY
KVU^IBm_LVA]HG=SMFaYKVD_CfeUIf4_HFD_Kg=/HG=X3BmaMFEcM6U_KVA_Mfh_
IGQSK65]I6mgKRm/KfMYHf5/KVmd;g9QI6USHF`_IVa_LVU^;f5`L79_N6EaMF5/
;dAUK7AQ;fMeJFa/IFe_M6aUIW@=;fMeJFa/IFe_M79YIfQd;fE/K6U`LfUc;f9/
HFi[;d5WLV5fIBm1M6U/I6D_CgAYK6AU;dm5;fmU3BmUKVAQLfP_IFeTHG=X;g5e
KgAUI69/K6EVM2maMFmdIFARK79YIfQd;g5eKgAUK6EVM2maMFmdIG9YIfQd;fAY
MVUTIBm/KgYUKVMU3BmiI6UULVEcJG<_FFAYIG9ULfUc;fIbHF=dJFm^;f=eLW9U
KV=i;fMeJFacJFiWK6aUIW@_IgEYK7=YKVM/LVUWJ7@_IVT_IV`=;fAQIfMULVAR
K2m`IG9YKfASIFidIG9UI2maMFmdIG=YKVM/HV5cIBmaMFmdIFARK69QLfD_L6Eb
M6Q_MG=QKV@_@F=YLV=eKFI/IGP_AF=YLV=eKFI/IGP_@F5SMGAU3Bm5I6UULVEc
JG<_AFMbHGIU;dUQHgEdIBm9HfUbHgE]IVaUN2m9I6UULVEcJG<_BFMbHGIU;dmQ
HgEdIBm?HfUbHgE]IVaUN0d_HG1`K6D_CfMbHGIU;eEQHgEdIBmEHfUbHgE]IVaU
N2mEIg9QMVD_I6mdK6EcLfT_HfUbHgE]IVaUN2mdJFaTI@d_KF5SLVm^;f9bIGIU
;fA_M65SHfE^M2mbJFiW;f=UI6U/K64_J7E^If5bMFe/HGEd;fmWKfiUJbmSHG9_
KPeM871eM0eUKV@=9BE5KVA@LVm/KfLP3BDU@VEWJFiCIGAeL20=@eI4JF=d869U
IfU^3@dU9D9UIfU^DVEcKgEbHfDj86I_KW@PAfE^IGIQ3C4d86AYHg@PHVEWJFh=
;dI_KWA>HFeU82m7IFiUMV4PI6EV3Bm6KfidCF5dLVUh85/`;S0`<B0`830P<2h`
<34P<20`GB1TIFH=;dI_KWA9KVI_834`86AYHg@PI7E`869UIfU^3Bm6MFa/CV5]
IB0XAfE^IGIQ:B1TIFH=;dIQKFU/NDiQKFDP:4MUKVEfHBTPI6EV3BmEKVAULVaY
KVE@Kg=YM6U_KR0]<C0`86AUIPd_EFiTIG9/JFiUE6QYHf]^IG=c83D`86AUIPd_
DgAbJF]UKgEdD6mcJGAYKfhP<c0`86AUIPd_DgAbJF]UKgEdE6QYHf]^IG=c838e
86AUIPd_EfEYIfQd82Q=IFAYMFdY86AUIPd_BGAQK6US@FiWK6DP<21TIFH=;fUc
AVUhIFA@JGASJ21VHFacIB1TIFH=IFiT86AUIPd_GfM/NG1X82QH820Y86AUIPd_
IgP=N`d9<B1UN6=XN`d92FAeL20a=R0X820Y86=fLW<PGfM/NG1X86EhHfPP<B1U
N6=X871eM6U^M6EbMV5/834PJFiTIGPPIGQSJ0d92EmWK7U`J21SMVhPL7Ed3@T9
OFI_LPemI6EV3Bm@HFU^M5AiL6DP<21TIFH=;dI_KWADNG1U834PI6EV3Bm5KV=_
I6U^Ib0b=CHPHG9bHGT=<20a838e=B1k834PJFiTIGPPIGQSJ20_;Vi_M6AUIR1`
MG@POB1VKg8=<c0P<SDe86Mh3FAUIPd_AVm^M492KgPPFb0`830P<20`85dPI6EV
3F=eLW9UKWATJF=d86E^I0eTMG0P;e1bJGIQM6DP>21TJF=d86AeL21RIFMYKPd_
DTAkLgAbJFiW86=eLW9UKWAVJFaU86EhHfPPLVEQI6QUN7=dLVU^Ib1`Kg1mI6EV
3Bm>A7]TIFImI6EV3Bm>D7]`MGAmI6EV3Bm2K7EUEV5/MFEcFb0]<SD`830P<S8`
<20b<S0`GB1TIFH=;deYKTIUHGAeLVDPNb0a=R0a=WdPI6EV3Bm`HG=cMfmbI20e
>3<i86AUIPd_DgERLW<P=3<PHG9bHGT=CT@=<R1YKVAUN20_@fQQLU=dLVU^Ig<P
<SDf86AYHg@PI7E`869UIfU^3Bl^KVmdI6EV820a<21BA20b=4E3@T@`=C=5@d54
<cDbASDh<B1>A0d_F30a820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDP
CT@=;eP`<R0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<3<P
834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F30d820a<R1BA20b
=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;eP`=B0P<C8PDT@P<SA5@d94<3Dc
AD8i@C0g=DA1=3Q3@dE584i43BmH<3HP834b8594838dAD=2A30e<dE2>D4`=cE4
@C@h@d=5AB1>A0d_F30g820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDP
CT@=;eP`>20P<C4PDT@P<SA5@d94<3DcAD=1A3<e<THe>3He<R1>A0d_F30i820a
<R1BA20b=4E3@T@`=C=5@SHe@d@i@S4a=48`@DDPCT@=;eP`@B0P<C8PDT@P<SA5
@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<48P834b8594838dAD=2A30e<dE2
>D4`=cE4@C@h@d=5AB1>A0d_F313820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d
>4=3ADDPCT@=;eP`A20P<C8PDT@P<SA5@d94<3DcAD8f=D=4>D8a<CA2<45584i4
3BmH<4DP834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F316820a
<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePa<20P<C8PDT@P<SA5
@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<C4P834b8594838dAD=2A30e<dE2
>D4`=cE4@C@h@d=5AB1>A0d_F34b820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d
>4=3ADDPCT@=;ePa<b0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i4
3BmH<C@P834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F34e820a
<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePa=R0P<C8PDT@P<SA5
@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<CLP834b8594838dAD=2A30e<dE2
>D4`=cE4@C@h@d=5AB1>A0d_F34h820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d
>4=3ADDPCT@=;ePa>B0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i4
3BmH<D4P834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F352820a
<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePa@b0P<C8PDT@P<SA5
@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<D@P834a8594838dAD=2A30e<dE3
@D@c=C96=CPf=C8PCT@=;ePaAB0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3
@dE584i43BmH<DHP834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_
F38`820a<R1BA20b=4E3@T@`=C=5@SHe@d@i@S4a=48`@DDPCT@=;ePb<B0P=34P
DT@P<SA5@d94<3DcAD8f=dDc<cI1@C@g<CDa=3A4@CDh<dA2<T8aA4HcAD51ACI3
A394=cM1=CTg>44g=c4f3D<`ASM1@SPc@cT`=c=3>30a<S0i>38PCT@=;ePb<R0P
=3DPDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Pc<THg=3=6=cHi<495A4@c>34e<d8h
<cTc=4HaACLhA3U1=D@b>4I23D=5=T4h=38a=D93@TDgASU1=3TgACL`<CQ1ACPa
A21>A0d_F38c820a<CPPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6>4=6>356=48i
<SHg<S4b>493>DDe@d55@S4c@DDbA30c@dA5ATI53CPb<dE4<SHa@CHd>CLbAT@e
=dHf=cDb<d<`@d8a>48a=DHb@cHg>48b=d<a>C55=SDe=D4f=4<g=DI3<Pe6<T4f
=S@i@CA3=THg=c0`>4I1=3La<3U5<dA2<d8e@C51<c0eA38fAC13=S<b=CA5=dE4
<3Hi>D<g>34=AT52<30h>4<i=T8`@SU2=TI5AS52=C11<SE4<CU2@c0bADE2<S@b
<C92AD96=D@g<C8i=THa@d4PCT@=;ePb=20P<SL`8594838dAD=2A30e<dE2>3Le
<d=1=4@fASL`A48a<dDdAC8`=TE3>D8g<C=5=SE3=30c@c<i@STb@CL`ACTf>@de
<CPh@D=3>3<c<4<eAD4bAC8i@d8c@c8d@TDh=CU6A3TeAC@`<DH`<SDh=c<g=SLa
=3<i@c<`<d=1AC@=<34d=S@eA3PfACD`<SLc>3U1=S0eASM6<S=2@C8d=3Pe@T96
ASA1<CHe>393<3D`=dDa=3@dA452=C943C@e<d@f@cPe@S<f=cE4@dA6AC91<4De
<S16A3@i<S8dAC0b=d@e=CL`<D55@d8a<4E5@SE3<T54@CDc=0d`<3<h=T4e<cTe
<D94@STb=dE4<SLh=c93>C<a=48f<cLi<SA3ACTd=cE5@SDi@CM5=D<g>CM3=D95
=c@=>4A3<d4c=SDi=S0h=S16=c=5@C4a@d8gAD8f<cM4A3Tb=T=3>D91<3U2=c@a
<DHe<3<`@SLf=4I5@DA53CD`ASHi=TA6@CQ4>D8f>4Di>D8b=d55=SQ3A4DaAD4`
>CU2>DI6ASTcATHhAS4c=D8b>44aASU6<C8aA@dgA3@c<T<`<4<e>3<aAT=3>4Dh
<d<b=C93>C8`ASPf=cLh=S12>DI2@dE4<C<e@c16=3Le>393@DI4<DH=>DHh@DA6
>30f<C@bATE4@C@h=CDg@d<d@D8g=CI6<S55=S@d<cA6<34dASU1A4<e@cTc=4@c
<48e<S<h84i43BmH<SDP838g<B1BA20b=4E3@T@`=C=5@T94>4@hADA2@CDdAT54
=CTc<c0`@CTcA456<CA1<S4eAT51=SM5ASDe<356=SP`ASL=@S<`=C95@D8g<THa
=3<e<T<fASTc<C52AST`@S<h@SQ1=dHb@T@g=TE4=44d<S94A3Pe=3Q3=S=3=D@d
3CE2<c56=C52<C92<S@dAS@d=d@a<d8e>C<c=4<hAS<c<4<b>C@aA3Dh=D=2>4Hc
<48e@S0c<cLa<4@g<@e6<30g<cA6ACU5A3A3=c@`@c13AC8gA3Dg@S92AC8d@D@g
<SU6<dE3@c0b=S0g@T@`<CDa>456A4I2>CH=@C4f=3Q2=cHg@d=3AS14<3DhAS92
<34f=4E4=S8d=CDe=cM3>4Dd=S13AC@iAD=5=3@g=cLb=DI4=S563C4e<3@a@dE6
A3He<c0hAC96=T=2<T<g=c0i=d8g=d@f=cLcA48b<S56<T8g@cDb@CLa@S16@CI4
=4I2=`diASE2<d4g>4Hf=T=3<4E5=4Db=S<h@dE2=cI4=SH`@THd@SLfA391<3Dh
<CDg<CPd<c0h=4=2>CPf=DD=<SM4<3=2=4@eA3E5=T4g>4E2=cA5A3Db@S91=3Ha
ATE3@D<a@SDe<S<g@SHg@D@hA44f<SDhAS0`=cQ23DI2<DA3ASTd>3Hd=44fATI5
=SDh<T<a=S8c@D=5ADE1@T@a>CDb@SU6>44g>3U5>D@`ASDe=CDh=CTh=Pdb=21>
A0d_F38f820c=3PPDT@P<SA5@d94<3DcAD8h<c4e<CTaADH`=3M4<C<gA3U5>DI3
<4<h=T<g=DHf<4Db@CD`<dHd>355@TH`>4I53C8g=3De<d=1<C52=dI2=S95=c55
@cU3ASA3=CM6AD4d@CA2<c51<3=4@cHe=cDi=CHa<T8i>DE3<D4c<0dcAC8e=C11
@DH`<cI2@d4iA3Lc@cHbA3@`=cE3@d8`<C<f<DHc=cPb>3Dc=C<i<34a<TDf<3Ta
>3HgA4D==dA3@cQ6@d53<30d@dI6>3Ti<c@g@d8bASPf=D4iACHe=3Hf>DDgA34e
@CP`ADI6<TA4ACTg=SPiACPf3C4c=4H`=D8h<CQ6<cI1<SA6@cDc>34`<CPh<456
=CI2>D@g@cD`<TDbASHbAD@f@c0b@CU6@CQ4<d4g=@e1=d4aA34b=CA2@DDa@S94
=DI2<D8a=4@aAS@a>355@S94>CI4A312=SI5=dDa=3Hd>4E2=cDf=3Dh=S0=<cU5
@D8c=c4f=STi>496<313=cU2>3Df>3Hb@CH`>D=6=CLc>C0c<SDcADA4=48eASE1
=cI5@c96<C0a3DE6@S4e=DDe@SE4AD4c>3M4@dH`<SDi=S8dA3E3A3Tf@S<`=D<g
ASTd<S4e<C0`=T<`ASE3<c0`@cA6APdc<T94=DA1<cA1<c=3>C55AS94<SHeA4Dg
<TE1AT56>C96AS0f@S0e<38gACLf=SE1ADE3@d93<CQ6@cD=>DI6=3E2=SM1>C8a
AT@a=SE2AC=6A3<f@T52<4HgA4@g@d@h=TDiASPe<c=2<T=2>4Dg>D4b<T4g@d8`
3CTb=4@g@CA2@T4b<cTf<cE1=C<a>3Q6@D8h=SE1=CDeAS<b=38`>C56=T8`>CLb
ACDg=D54<cTe@T4eAPdi<cPc>C=6@cPi<cD`A4@d<cM2>44b<cI6<3@c<CT`@SU1
@SPPCT@=;ePb=b0P<c0PDT@P<SA5@d94<3DcAD8f=dDc<cI1@C@g<C@f>496ACPh
AD=6=3Li@CHfA3Lc<3La=S@d>44c<C4dASLi<TDe84i43BmH<SPP834`=B1BA20b
=4E3@T@`=C=5@STg@T56=4E1=SM2AT4e@S92=cHi=SA2AC<`<cTa>C<d@C=6>3Q1
>DI6>C<d=c@d=C8=<S8a=ST`=cU1=cE3=DHe>4DbAT<eATI2@D4`A391=3@d=4Hg
=S56A4A4AC<eAT96ACTbA4<f=SM4=S523CDdAT@e=S@c@T8g=456=c=2@SLhA48a
AT8c<dHf@S4f@D<h<4Hd<D4a=SPf<S0a<C14<DE4<d91=DDhA0de>3Pd<D4d=S@b
<C0h=dE3=4=6>C=1=C<a@c13=cHPCT@=;ePb>B0P<C0d8594838dAD=2A30e<dE2
>CM2@DHdAD4f=3Pc<c8c=313AD8dASTc=d8`<316ASLc=C4fAS4a=4H`>313>4=4
=`e4A34h<4Dh@C13@S8e<C0e<C0a=CTd=44eASTbA30f<THi=D8g=c@h<THdA455
<492>D51ACA1AC12>3T=<CTc>C=2=T8b<SM2@SQ3>CA2<4H`@D@`A3@hA3E3@d@i
@c13<3<h<3TaA354<TDf>4<aASQ4=DDa>4<b3CPg>3U4A44`=dDg@c0c<391@SA4
@C8c=CPf<T8PCT@=;ePb@B0P=c4PDT@P<SA5@d94<3DcAD8i@SQ4AT=6<cHe@dE4
>CHhADA5=C=4@S@c<DHb@CTc@c8a=S4iACHa=C8`@S<h=C533DA2<d8c=4<i=T8h
>3<a<c95=4<iA4I5A34d=392=cDb=dDa=3Q1<D56<cA4<cTa<D4e<dDg<4D`=3Pc
=@e6@d8`AS4d=T<gA3M6<3Df>CU2@CM284i43BmH<T8P83@i8594838dAD=2A30e
<dE2>3Le<d=1=4@fASM5A4A1>DA6<4<cAS94=T<e<cPa<4<a<D<f<SHg=C8a<T93
=4@`<`df@cHb<4Dc<c4`=STd@SU2=38aASQ2<dHhA34a>3M2@D8`@CI4=21>A0d_
F393820g<21BA20b=4E3@T@`=C=5@SHgAC<c=T51=3Hd=T8c>4<c>44c=S<e<4A3
@dI6=dE6=D@g>D@fAS4a<d52AS0d@cP=<D@g@d94ASM3=c13@T=6A3Pb<TI6@cDf
>D<d<CQ6@c@h<T8f=c15=T@g=SLc=c=5@c4bATA2AS0i>D<b3CE1>D<c<TDgAT<g
<CDf<C8h@SE384i43BmH<T@P838f8594838dAD=2A30e<dE2>C8gAD96=c94A48h
@DA1@CTh@c<c<S<c<C@dACE4A3I4<c<hAT@fASHPCT@=;ePbAB0P<SLPDT@P<SA5
@d94<3DcAD8f=dDc<cI1@C@g<CHg<CTg>CM1=d52<dA4@cE4=DDe>C=1@CLg<T54
ADI284i43BmH<THP83<`8594838dAD=2A30e<dE2>CPf>4=1=3U5ADHc@dDc>C4`
@c@`=c<h<T54@T4h<SHaASDb>44gATHd@CI4@d8h=b1>A0d_F3<`820a<cDPDT@P
<SA5@d94<3DcAD8h=cDc@d4dA3I6>316@S4h>394=cPg<S8i>3Pg<d8eADI3>34b
ATI3@SLe=CLb=d<f3D4b<CQ3<3H`@S4c>CE5AC0h=d=5@C@a<3E6<d@g=34h@C0h
>CM4<T8a<CI3=T<h<c@dASE6=SE1ACLg<0e5<T=2<4@cA38h>DI6=D95@c4b<CHi
<c8f>44i<c56=DDhAT@h>DA4>CE4@CM4@CE4A30b=T4e@dI2<T4=@T@`=T=4=c=5
=CM5=SQ6=S96>3Ha>C8`=34i<48h>353<S8d=TE3ATA1>D<d@cD`=44f@S8a@dHd
<cPa3CU1=T8a<SLf=d<b@S15<c4a@cDb@c96>D4i@S<c>21>A0d_F3<a820c=B1B
A20b=4E3@T@`=C=5@SPg=C=3@CA4=THh<THh=CTf=3M3>34d>3<h@SQ5=3Tb=cD`
=S54A4I6<cLb=T8d=cT=<DE5<cLf@D@b=21>A0d_F3<b820a=CPPDT@P<SA5@d94
<3DcAD8h=cDc@d4dA3I5A34iACTc=S94>CDi=C0aAD4g=cI2AC15@D8a=3Pa>395
<c51@dD`3D51<S92=T4bATE2=c11>3A5<D56@S4dA3I4>4I2A3Q2=CPe<D94=S53
A4Dc>30e@c@cA38eA4@`=d8`>0dd<44h<SE1>3U3@CI5>DE2<c0i<30b<3PdASQ1
A48i=3PdADI4@TDg=494AT@c<CPe<d4gAT8c<T8a=4H=<SU5=STc=D4c<S=4<CTc
@CI6<3E6=cHe<48e<TI4>CQ2@T@e<cI2<CI2=DDc=c<d=c@i@c0d=SE5<T@g3DD`
<cU3@cPcAD8h=cI5>3Tc=cA3=d8f=CI5=c8`<DA2<4Ha=S<b=S<`=cDdAD96@CE6
ACHdAT<h<CPf=0da@SPg@S<bA3PiA3E3>C9584i43BmH<c<P838c<B1BA20b=4E3
@T@`=C=5@SPg=C=3@CA4=THh@T8hAC94=cA2=30b<44d>3E5@T8b@dDf@cLb>353
AD@a<TE6=C<=A4<b=SM5>3A1=cTi>CPa<ST`A391<D4cATHc<4<a=4<d@CPi<SDa
=4@i=T@h=3Lc>CHf<c8g<4E2ASM23CLcAS0h=4Hi@S0d@c<`<cLf@CM6@THfASE4
AC0fA4E3>C<d>3E5=CQ4@S14=cPfAD@h@S@c<C0i@d<`APd`ACD`@c14=S<aA312
<D@a<4E2=3M5=T4d=D4fADA6ACA6=TA2ACA5=SHd<CU3A4@`AT51<394ACL`@c0=
>3TgA4@d<SI3=c<b=DA1<d<e<492>D<d=d4h@cU5>DI5AS16=CDc<dE1ASTi<3Li
<cThASPe@CDe=DDe3CE3=cHeA3<f>D<g=cHh@C@b=4I3=S=2<THe@d93=c4h=cM1
AC=3<34hAD8i<4A4@c@`@CTa@S8`>C4e=`df>CPg@dE6ACHe=CM2@DA4@C0`=3<g
<S=1<DE1>CA2<C8c<DDd@SE6AC0g=S8b=STcAS0g@C=6@dHc=c0=A491>C=5=C<f
<CTaA4<f<T@f@D55=d53=SLf=S<c@TA5=314AS@e<SLc84i43BmH<c@P83H`8594
838dAD=2A30e<dE2>3Le<d=1=4@fASLhASLgAC15@dI4AS92A4<a<CHi=cI2=S12
>4Hg@c8c@SHd@DDc@@e4>3Lf<T=4=DA6=c51=c=3@cHc=D4e=38a<454<44c@cU4
@d<b<S<d@d4f<D56@S16<4I1<TA1<493=CHPCT@=;ePc=B0P<C<b8594838dAD=2
A30e<dE2>3Le<d=1=4@fASQ3=T54A4Dg@cT`@d=3=T55A3I6AS8a<d@a>4Hg<c@e
A4Di@STb=@df>3Pf=STbATDb=3A2AC@b=SPd>DI5@D<h=T8gA393=4Hb@C<d@C8b
<S8g@CQ6<3Tb=38fA34a>DHa@d4=@c8e<4Hc<D4h<4=4@C16<355@T=5=d<hAT55
AD<i=CE5=D@f=3U3>C@a=cDi=3@hASDa>4=2=D55=S4a3CHc<D@g=d<g>451<cPc
=44f>3U2<4@f=3Pc<d@dACL`>3I2=SPf@SI3=d4c<C93AT<d<d@e=cHdAT=5A@dg
<cThAD=6AT93@cPi>3Ha<T52>491A3<PCT@=;ePc=R0P<S<f8594838dAD=2A30e
<dE2>3Le<d=1=4@fASQ1=SL`@S51@SL`AS53<d@`@d@d<CTa>4@h=d53=cE2@D8h
<4Hh=0df<30`<CE6A3Pi@c0c>44h@T8c=30a=SM6>34a@c<d=D8f@DA1<3TfAD4c
>C=5>C=4=495<T<c@SPd=T4=AD96<C@`AT96=4Di=30c<3M2@cHd<D<aAD8f@CPh
=DHd<CTfAS4a>D54<cP`=D54=d92<3T`<CTd<CE53D4g>CQ4@SI3=d@a>392@CA3
ASPdAS@b<THf<T<d=C4h<CDcA4DeATHa@SQ6<cLb=STa@S0g=452<S<d>@dc=cH`
=cI3ADHe<S0hAT54@TA2@C8d>3A3=d94@cD`A3@f=cHh<D8h=356<T4g<4E5<4E4
>C<i>DHdACT==c13<SU6=D55=3TeA3Le=SPi@C14AC4gAS<dASE3@S@b=C<b=3Li
=SH`<dA5AD96>DA1=3Hd@d@fA3933CU6<4Dg=dHf=CM6=dA1=4Da@T95>D=6<D=6
<c4fASDi>38a@dDa=dE3A3DcAD@h=c91>CA6<353=D@d@@deAS11<d@`@CI2ADHg
=S0b=3=4<TD`=T@d<3U4<C0e=d92A44iATA4>CI1@D<b>4@c@d<h84i43BmH<cLP
83Pf8594838dAD=2A30e<dE2>3Le<d=1=4@fASPd@CA5=cI4AC13@C51<S@b=396
>CE4=C4a=3A6=c0eAS0a=c4b@Pe2>D8hACA3=30d=D@eASTg>DDh<SQ4AT91<C<i
=dE2=T4iA4I5<c51>3Tf@SM6>38f<C4c@d4h<d@a<D<=A3@i>CTi=T=5<SA6<CLh
@T<e>C4h>D<c<C@cACE2<3DhA4=4@cE4@SU3ADHi=S13=cDa=B1>A0d_F3<h820c
<3DPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=cA5<4Hh>CQ2A34`<3P`=4Di=455
=S<g<S8iA30f<d92ACTi>CE53C8f=CQ5>C8e=4<fA3U2<3Pa>3A2=493<3@g<d<i
A3D`@c0h@c4cATD`=c54@T94<dI3<C4i=SQ1=395<0d`<3=6<4I2AT<aA4<g>4=5
<c0iASE5>C=6>CQ1>DDe=DHb<cE1@S8dA4=6=3Hc<TDf<SU1@cPe@dE5<c0==D8c
<cI4>D93>C<`A3Lb<c=4@SDdAS11@cHc<D8g>C15<d56@DI2<dI3=313ADH`<C@b
=3=4>DE1<DA53C55=34`<c8h=c4fASU1@cE3=c8h=CPb@STi=3Lh>D=1<SHa=cDa
ACU5<DHh<4Hc@c0a@DDh@SI2=cLf=Pe2@cLc<cM3=TI3>48a<393>D8d=C<e=DA2
@cM6<3<g>4Hf@CLb<CTc=d<bAS53A491=cHb=C@e=SHe>DH=<SQ3<c93=c8a@D4h
=D=6=CE6>D55>493@c@a=S56@C@h=S0a<D<f<dD`=3Di>4Db>4=6<cPd<S4`<CM5
3CM3<3Li@DA1<CH`@TE6<d<h=S95<d@a@c16<D@c>3PdA4<f=S4fAD8`<3Ph@d8b
=3I5<CI3<CDhACA2>@e5AC4e@D@e=DDd>3<i=CHh<c16<STd=dE4@dI6@STgAS0i
>3Q6=C0e<dA5>495A44c<3L`@T91>393=TD=<C14A4I3AC54AC8h<c@e@CU4<CM4
=3Ta>3Db@DE2<dA6=T@c=C16ACI5A3Q1=d@d=3LaADDe=4H`=c4i3C@f=c@i@d52
=C@PCT@=;ePc>B0P<S<f8594838dAD=2A30e<dE2>3Le<d=1=4@fASLf=3A4<T52
=492>3Tg=d95<T@f@cQ6>4D`=CA1>D=3>C=3=STaA0di=d8`=S4f=cE1=SPaA3E4
<4@a=DDg<CLi@d8h>3Dg@dE6@S@g@cHbADE5=CTf<cU2=3Tg<c=4@cQ1@c0==SM2
=cPi=c<e>D=6>C@f<c<iA3U5AT4e>4Hg=30g@CA6=48g<SHd@C<f=TI3@d<g>D=4
=3U4@SDh>3=33CE3=C94<cT`=3@c<4H`=DDc=c13@cDd<CM6@d55<d52>313<CLa
<S4h=c@h<D51=3Ha<cHh<ST`AD@f=0da<T=4@D@`>30f<cQ1>D@c=4<e@C56<T@f
<3Lh>C4`<cI3ACHh=DDcASA6@SHbATE4ACA2<4I6AT@e>4H=<CI2=4Hg>4@`@SDb
<d8b@S4b=C0d<T4i>DDf=d@f=cI5>D@g>4@`<CLc<S4i=dA1>D=5A3Da<THf<CQ6
3D@g<c0b@c13A4I1<cU5<d8g@cPb@c0`@CPb<cHf>CI4>CM4A4A2<30h<d@`<SPa
<S14=C<b<cHd=c96>0dh@c55AT8i@S<c<dI5@S53=cHg>C8bA3A6=cHb<cDg=S8e
<S56AS8h@C4e=C51@D=3A4<d84i43BmH<d4P83@c8594838dAD=2A30e<dE2=SM5
<c<f@D4d=c4f=c4i=cTg@CM1@S=4A4<eA3E5=CTc@D4g=c91A4D`A34e=3=3<0e6
<D<b@C14>4De=3M2=CQ6<c4`<313AD@g=b1>A0d_F3=2820h>21BA20b=4E3@T@`
=C=5@SHgAC<c=T51=3Hd=T8c>4<c>44c=S<e<4A3@dI6=dE6=D@g>D@fAS4a<d52
AS0d@cP=<D@g@d94ASM3=c13@T=6A3Pb<TI6@cDf>D<d<CQ6@c@h<T8f=c15=T@g
=SLc=c=5@c4bATA2AS0i>D<b3CE1>D<c<TDgAT<g<CDf<C8h@T4e=D96=c@iA4Da
<SDa>CHd=48a>3E6=cDa>DI2A3I4AC@f<cA184i43BmH<d<P83@a8594838dAD=2
A30e<dE2>3Le<d=1=4@fASM5A4@eAT92>C4a<CLa<C4i=S0e<3=2>3TaASDf@DA4
=cE6<C8i<0dc<352@CHi=T@e=dE6<C0b<TDi@cE684i43BmH<d@P83@a8594838d
AD=2A30e<dE2>3Le<d=1=4@fASM5A4@e=C14ASTi<DHg=c<fA3Tf<SPc=DE1>CDb
<S0f<3H`<314=Pd`>3<g@T4i@D8c>3Pb@CTf@d8e<C5184i43BmH<dDP83<h8594
838dAD=2A30e<dE2>3Le<d=1=4@f@cLgA30h<CH`=C95=4Hh<38i@cDd=c0iAT=3
@CM2>C0dA4=5<cE4=@e3<DHg<THb>D4i<S94<C4f84i43BmH<dHP834g<b1BA20b
=4E3@T@`=C=5@SU5=3@`<C8e=cU4@dDiASI5=TE4ACLh@CDfAC56<c<b@c@f@C94
AT8`=4A4ASLf@D4=<D@bAT=4@T<a=3L`<STeASTb>30g<C51AT@`=d51AC11=495
ACI5<CTc>CHb>D4i=3E5@D8aADDc=cDi3C51@CLa<C<d=cPg=D=6=C95A316=D4`
=dE2AD8eADA3=c52=CE2ASDh<DA6<CA4ASE6=3=2<3Pb@C8b=`e6=4=1=T<a=SM3
@cTe=dA5<TH`=S4`=THi<S93=492<cQ1=d8e@cDgACH`<3Le=4DhA311=3Ld<D=2
AST=<C@`A4I6=DDb@S8f=TE2A3I4>4@c<d51@dE3<T8g>DDg@DDc@CE4A30aATHi
=TA2>C@b<cU1<d=2A3Hi3D<c=34b<4A1<3@hACU4ADDb>D8g>4A1<3=4A394>C=6
>CI4=4=2>3@dASI5<30PCT@=;ePd<20P<c@i8594838dAD=2A30e<dE2>44a@C51
<D8i=DHa@S0e<3Th=T=4@C0a<4E3=c@d=C<i@CQ6@S@cAS<i@CPaA452@@db=4I6
A4<d<4I1=T@h=S<h=S@dAS95A3<b=SQ6=dE1<c8eAD@c<3Hc@SU2=TDd<30e>D8c
AC12@cQ3=3T==SI1>CPcA3U4A4Dh@C4b>34c=C<i@C12>D8`=D95>3LbAC<dADHf
>4@hAC<b<TI6<cE5<T8h<D4`=d963DHc=34dA3I1@SI3=cM5>44b<CPi=44gA3M4
=34e@T<f=D8d<315=S8iAC@i=dHbAC@b=TA5=DHgA3PdA@dhATDe<cQ6@C13<CDd
=DI1=C4`<S@g<TI1A496ACPg=T8h=cHe=SQ6AS0`>3@c@SD`>CDc<T8i=dHiA4@=
A4Db<c<fACI6@cTg@c94=D4g<4<c=S<b<CU4=30c=cE1<CU4AD4i=3Dg=DE2<SHd
<d54@S0c@SE4@CH`3C92>4I4<c8cAS15@T<`>D91@C<d=cE4@d<c>30h=SPc=d4g
ADDe@cA2>48dAS=2@CU2<dHc>CQ4<T52>@di@CI2=S4i@DE5AD4b=c8g@cM1@CM5
@T=2@dHa@dDg@cU3<S0gADA3ASL`>3LiA3E3ASU1A3D`<3PeAS@=AT<c=dI1@S@g
@c8h>496>455<DE5>C<gA3A1=c13=S0`=SM4AD=2=dE2=T4a<4A6=3Pe>C93@C93
=30g3DHb=S=4@C4i@SD`=SH`=T4`@CM1<SQ6=394A395AT4e@c15@T@c<d@c<3T`
@D<dACA2@cQ2=SM5@TA1>0e2@c8`<d8hAT4g=T4g=C8fAS<eAC0hASDd<SA2>CLi
@C<g<C=5ASTaADE2>C8g@S4i<SA5>D51A3A5AD8=@T@d=C11<TDh=SA5<cPd@cPd
=3<e=dHe<dI4=CHgAC@g>351<4<PCT@=;ePd<B0P=S0PDT@P<SA5@d94<3DcAD8h
<c4e<CTaADH`>C4c=CE5=S<a>D@cASTa<C0e=S53ACA1<T96>3I6=cM4=c52<D4c
3@00X@30?oli<dHeAC4dAD@f@cM3<d<g@c8b>D4c=dI4AC<d=cQ2<d=2<T<a<3M6
AS<g<T4e@c@c=S<h<S4b<3<f=SDPCT@=;ePd<R0P<CTa8594838dAD=2A30e<dE2
>3A1>3P`<cPd=d56=T4a<CHf=S16=d4d>3He=dE2>392<S0e<D55=C4f=dA1<TI1
<Pdc@dI4@CQ4ACHe<CU2=T<a@CTh>CDa<D<e=dE3@C8fASLi=3M6@SM3<SM5@THe
=cLhASTb<T<e<4De>38=@cQ4>34g>3Pf>44a<S11<cU6<CPc@SHb<D<h=S@dAT8f
ACU1<D4`>3Hi<DE1>C4b@cDc>DHc=D@i>48i3C0e@SHf<44f@T4c=3<d=cA1>CTg
@T8i=d=3@TDg=c=6<cTh>3Pb=SE1A4Dh<DE4>C@g=cH`=SI1=C4b<0daA316<S8f
ASHc>4A1=CM4>4<hAT@e<CDi=T<fADDg@S<cA3A1=c54<D53=4E3<SHa<dE5<3Th
ATHdA3T=>C15@CU3@d53@c8b=dDe@c8`>C@`>CU5<d8aA3Tg=d<a<48d=453=c<b
AT56=dHb=C<gAS92ATA3<d=43C8c<SDi=STi=3Dh=44hAT=6@C4c<cDPCT@=;ePd
<b0P<CHd8594838dAD=2A30e<dE2>3@e=c11<S0iASI5@SM5>3D`=cTdA494@SPc
@T8c<S55A4I4>3Q3=3E6<C0cAD55A0dbA44b<48c=CDh<S0f=STh@CDg@cE2<c15
A3Q2<d<f@CLi@S12@C<c=SA3=S=6<C<h<cE5=S4hAC8a>38==c16=D@i@S<`ADHg
=4E6A3Lc=D94<T=6@SHh<cDb@CE4A3Hh<T@`<456@CTdATE5=44a>3E6=4Di@T<b
3D4eAS54AS4i<D<`<D<aA3Df@dA6=dI4>44g<S@gAD4`<c<cASQ5@C@d=C=1>3A6
<c15=SDe=cQ1<SPfAPdfA3<e>CPeASPh<cA1>D8hAT92AC8iACTh=3<a=CQ2>D<b
AS=1AC52<3<h=TE2=cPgA48hA3PiA48gA38=AD@g<cU4<496>4<`>C4h<SQ5<dA6
AT4c<C96=R1>A0d_F3@d820a<S0PDT@P<SA5@d94<3DcAD8h<492=CE1AT8h=3Di
=3E4A3Dg>D92<C<d@c4bAS0a<TD`<DHg=S56@D4g>CHb=4I13CE1AS@h@CPaADE3
<SQ5<S0aAS<a@DE6=d8d=cM5@TE3>CLc@c<d<T@f=SHh<TH`>4De<c96>CE3A48i
@Pe2=CM5=c53A3Pg>CU2>3E4<d8a=S4i=dDeA4I6@C0b<THc=351@S4c>CPh<D<i
@c8c@c96>4I1=dA4AS8=<D95>4Df<3E5<cU5=T8f<SHg<CL`=3M2>3M2=C@c=SLg
=c54=DA6AC55AC54@C4f=SQ4<cPh<T54ADI284i43BmH=3DP83@g8594838dAD=2
A30e<dE2>DI3@D4`=c4e=4Hi@T8`<4@iAC52=4<`@d@bA3H`<CA4AS@cA3Tc@c16
<c53AS@b<Pe4@T8`>38a<S=1=c0`>3PgADI5AC56=SA5ASDb@T4iA31284i43BmH
=3HP83@a8594838dAD=2A30e<dE2>CTe>C@b=CTd<CI3=44g<4I6=3A5=44b<T4e
ADHc<4A1=d8f@DA4@SHb>C=2<cD`A0dc=S16=C0h@dE4AC<g=S8i<D@d<48e84i4
3BmH=3LP834f<R1BA20b=4E3@T@`=C=5@SPf@dDb<CLa@D4i<d4e=cDaA34f>C8g
=SQ2=CM2@S8`AS<`<T8`=SQ5A3Tg<CT`>CD=<d@a<CDbASQ6<T@i<3Tf<CLh=4E2
@C8f=SI1=S8bACDd<d@e<CM5@CLg<CI4@S=3=S8i=S4f<d<c=3E13CU4=SQ2<SI4
@D@h@SL`@cPdA3@f<3Q4@SE6@TDe@S@eAD=3<3Pa>3@i=S0a<cL`>3E1=3HbAS16
>3@i@`dc@D=1A3Hb=d51<C12=4E2=3Pc=C@i=3U6>DE1<d@f<S0g<SQ2AS=3<CLi
A3Ld<SPc=C<g>312=c<d<30=>D<g>4@h=SU2=D<hAS<cACM1>C=6>34i=4I4<3Td
=c8c<C0b>3Th<SHg=THd=T54>3Q4=3E4ATHf<cU23CTh=d@`<T8i=STi>4I2A3T`
<3U2@cHfA21>A0d_F3@h820d=b1BA20b=4E3@T@`=C=5@SPaAT@d=T8`=CLeA3Pd
=cM4<cM4<cE4<cQ4<3Dd<D8e>DI5<3La<THb<TE4=S4i@T4=<38b@C<a=cLd<c@a
=352>C4`@C@g=4=6=d8e=T@g=S=5=21>A0d_F3@i820b=B1BA20b=4E3@T@`=C=5
@SHc@S<e>DE5=3@`<c12>CQ1=c4`AS4`=d93=SQ1<cI5<S15@CDi<R1>A0d_F3A1
820a<3LPDT@P<SA5@d94<3DcAD8i@CQ5=T<hATE6<CHg<d8b@c0eACDc<cU2<cA4
@c92<CLc=3DcA4E1=c0g<TDh@DDi3C=5@c@`A455AS96=3=1=3M3>C8`@SPg>3Q6
=S<g<312A3<iA3Hc=cLg@STf<cP`<3Lf=C@g<cDd<T<d@Pdh@C@b=4<gAC=1@c0d
A3<g>4Ha@S93ATDd<cPg@TA5>C0gACU6ADHb=CE2AS@g=dDeAC8b@D<i@STc<c0=
=452@c11@c0iA3@a<T@fACLb<dA6=d<gAC4h@c0hA38aA21>A0d_F3A2820e=21B
A20b=4E3@T@`=C=5@SPg<DHe=cU1<D8b<d52=D51<SDaASQ1>3Li@SPbACI5<SLa
<SE2<3Te=3A6AT54<cT==4Hg@d51A34`A48`>3Hb>D=2<c@i=44h@TI5=c0a<CP`
=496<C=2=4A1@TA2<T8c84i43BmH=4<P83<`8594838dAD=2A30e<dE2>DHc=SPf
A3@g>3Hf=CDf=SLdA3U5<C@gAT<a<D@f=CP`@cHiA3E6<3I1=dD`@CPa=21>A0d_
F3A4820g=b1BA20b=4E3@T@`=C=5@SQ6<THa<4<a=SLaAT4g<T55<T8dA3U2=d<c
>C55<cPg<d@h@C8`=T54>3Ld<CM1=TH=<352@cI6A4I1=3Lc@c4f@D56<cPg>CA4
=cA2=SDcAD=5@c=6=454AC8`=SHeAD<g@CLgAC4b>3=2=cE33C55AS=3=SDe@TDg
<c8h=S0f<C=2@CLi@S0`<3Ta<cTa>C0PCT@=;ePdAB0P=CLPDT@P<SA5@d94<3Dc
AD8h<38g@S4e<d4b>48a@D=2@C55=4I2=3=6@CLaA3Te=c13>4=2@dDcAC95=SPb
<3Q53C8f=C4a@TE4<cE3=4I4<4@g>48b<4Dh@C=2=3=6=CI2<cM5=S0h<CLf=38c
=30eA3A4=cQ2=B1>A0d_F3A6820a<cDPDT@P<SA5@d94<3DcAD8h<SU5=3@d@S0e
>DHi=D4aA3@aATE3<3E5@C8b@D4a>D@c=48e@C12<d<gAC8`<34b3D@b<D<g<D4h
>D92AS8i<SLh>4<c>38g=dHg<T4dAS55ASQ6=C0`<CE6=cDa<355AS96>D4h>4A4
<354>@e5@D4i<DE1<T95@SL`AS8h@CHbA3A5>34a<C<h<D=1=cTg@cH`=SQ4=cQ2
<3Lc@CTf@C@eAD4d=CLa<d8=A3A2=30d@T93@dE1@S8f=3@i=3DfAC<c<SU3=S4h
<T95AC@fAC=2=c=6=3=5<3U2<3Dc<D55AC@c@D@g3CE5=c<`=3Q6@C8a@S96<SLb
<44a<SPi=3Hh=S<f<b1>A0d_F3D`820a<3<PDT@P<SA5@d94<3DcAD8iAS<f>3I4
=3M1<S<i<4E4<4Hh=D=4=SLf>4H`=38b@dE5A4@h@S53@CU6=D=4=C4c3C0a=T8d
>44iACDf@cU5>3M3@DD`ATA1<cI5@DA2>CQ6=dDc<3Th=CTg@SLd<cPa<S8g<D@d
=CQ3<CI6>0da>D4dA4De=SHd=C8e=4D`<3D`=CHeACHg<C<`@SHf=38e<3M1>D4`
=D8i=3<b>4<i>3Tg<cTfAT@d<DH==4=6AC@e@S53>CLg=D<b=d<c=c4e>34`@D8P
CT@=;ePe<B0P<CTa8594838dAD=2A30e<dE2>38iAC@d=48`=CU6AC@d=D8fA312
<3Lg<dE1>3Hc@cHdA3Pe=cPcAD@bASLb=S8`=@di<cDa@CM5@C<e=c4i<dH`=D8b
@S55<d@h@D8g<T94=C14<d<i=D@f<cLb@SPb<SHe@CTd@C<c=4@c<T@=@cTh>D8e
@d<`=c91=cPg@c4i>DA2>CPf=c8d=3<i<SPd>CDd<SLi@cDf<4@b@d4a=DE3AD4e
AT@i=cLc3CQ4>3Q4@S8f<c<c=c0h@CPd<4Hb=314A3I4ADI5@d<`<TDi@CDi>351
@c@d<S51@TI4=454A38hAS@c@Pe2=313ACU3AC=6@CDcACTbA312=c4c=D4c<4=3
=3Tb@THb<cA4AT55@DI2<3Lb<CH`=TA4@C<iACPc<TH=<cDhA4E5ADHf=T@e<3=3
@SLb@cE4>396@c4h<dA3<cDhA3Pi>CI4<34d<c<h>CThAT@gASE6@CHb@DI43D<b
@D=1=T51@D<f>DHb<cHb<d8g=cHPCT@=;ePe<R0P<CHc8594838dAD=2A30e<dE2
>DA1<c0b<C@b<c8fA3=4@dA1>D55<cDe=4Ha<3HaA30f@SPb<356@C<`=S@e@dHc
>0d`=DI2A4@g=dE1<D@bAT<fA3U1ATE2=D56=495<d=4>3H`<4I1=c52AT<dAS12
AS8aAD<b<dHe<CU3<C4=A4A6@d<i<cQ3ACHa<SLc=S4a=cI3@D4i@cU2=C8i@DA2
=T4d@T<g<CHi=353<CPg<c0`<c=1@CQ2@cH`3CQ1<STb=TA2>3Ti>CDiAC96@DDi
A456>34`=d8h@C8a<d@f<T54>3I2AS51@D4b@SE2AD8`=3A2=SP`<`dc<SM3AS4e
<S<`@S8c=SI1>48a@DHg@C0a<c16@C4h=c<a>D95@d@`=c8f<T4b@c8e=S8a<cM5
@DI1>DD=@dH`<c94=CPa<3Li@TA1<3DbASE5@c8cA4DPCT@=;ePe<b0P<S<g8594
838dAD=2A30e<dE2>DA1<c0b<C@b<3E6A351@dE4ASL`A44d@dDf=CPd>48c>CI3
<cHi@dD`=CTd<D=2=0e3@d4a=DI4<c@`ASHhASQ6ASQ5AS8i<34`=dD`<STe@T<h
@D51<cI1@d96>3I3>CHf=d8h>CHc<34e=44=<S56<SI6>C93<3Q5<DDh>C<g=S8b
ASDc=44`@S95A3Le@C0gACT`@S0g=cQ2<D@f=CE4@SH`=d<f<D<b3DDd@STe@S=2
@c<f<D4`@c<b<dE3<S8a<D4dA3Hc=3HbAD=5AT=4<S<d<dHg@S0a<d8h<44i@T@d
=c0h=0db<S<d>4<a<D<a=STd=D@g<3M3<48`A4@i=C55=38g<S55=CE1>CHa>30d
>315>C@g=D8i@CPf<cU3A3P=@dA4=c56@c<f=c95>30bA3Te@cQ3ATDe<494<3Pb
@C<b@T55=c4c@TDiAD8aASE2>4=6<S@h@CTc=T923CQ3>3Q2>3E5@CHd@D4c=c@f
@C<c>4@f>456AS4d<CM6@C8h<d<`<CA5AT96A312@c8hADHg=3Q2A316<0e1@S8e
<c4b>C8iA4E1AT@i@T92=D<h<S12=d<i<3Tf<44e=3Lf=CHgAD4g=TA1>495ACM2
=DHPCT@=;ePe=20P<cHPDT@P<SA5@d94<3DcAD8h=4E2<S@d=C91<30b<c4h=CPe
<34c>C=2=C0g<396A3<c<cLg<SPg=T4gACTa>C@f3DHi>3@a@D<d<T4e=B1>A0d_
F3De820a<CHPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I3=cTb=C<b<cE5AS@c=c94
<S4`@C55<dD`>3HfA3Q3@T@i<S0e<4Hh3C96<48aACI4@C0g=CI5@cQ6<391<3Pb
>C@h>454<CA6@SM1=TI1>CLd=3M3=D8a<D=1AS@a@S0g=3Ha=0e2@SA6AC52@DI6
>3He<d54=3P`=D95<44b=T<aAD4`@TI3<4@a>3A1>DA6AD<h=DA4=cU4=dE4<S0`
=CH=>D8b=D=1<T@eA38g@d54ASHa=cH`AC<iA355=353@dA1>CLi<CQ1=D8e@DDd
=cTe=D96<b1>A0d_F3Df820d<b1BA20b=4E3@T@`=C=5@SPc<CDa>C55AS0e@d91
<c@d@c94>CL`=391<3<i<d<b<STg=34h<44i<3Pg=D4g<CP=>34e>34a>D@e@T@`
>392=DA4=dI1>3M1=TDPCT@=;ePe=b0P>3TPDT@P<SA5@d94<3DcAD92>38g<DHb
<cTa=c0d<3A5=d8i=SQ2@DI3@d@gATDi=44`AS4b=c55>3@`<30g=D=23D@d>D8`
=3Td@SHbACHe@cDdAC0c<TDa@CA1AS13@T8`A456ADH`<CI2@dDc>34gA38i>48e
<cP`>C=3<@e1ASTb=D<c<CTbAS0h=d4`<T96<4Df=C<g=SU2=d8g<S8iAT=3<dA5
<44b=T8h<T=2@C=2=3Pc>D<b84i43BmH=CPP83Hd8594838dAD=2A30e<dE2>DA5
=d8`=T4h=cI1=C=3@SDi=C4e@TA6=4Db>4=4>CI2>DDa@SM5>3Hf=391@d=5=`e4
=T8`A4<b>D8i<C8i=3Le=c53<T<f@SM1@SE2>C@dA4Df<C@b>4<cASM2=3<i@C<a
ACI6=c4i=D=1@DD=<495<C4h>C<PCT@=;ePe>B0P=3PPDT@P<SA5@d94<3DcAD8i
A4Dg@S0f@CPg=SDe@TD`@d92=34g>C4dA34`>DA5A4Dh>CI2@C16AD93@d<c@SDd
3CPi<d96<C=2<3Q6=SPf<48h>3@i<D92>3M1@cA1=T@eAT@e<R1>A0d_F3E1820d
=R1BA20b=4E3@T@`=C=5@SU6@d51<3La=CHdA44b=S96<C@a<4I3ATDh=391@DE3
<cM4>C16<SA3<cPa=T8b@SL=@CM4@S0a@STd>CDg>3PhA34h<cT`A3@c=315ADE4
@d4PCT@=;ePe@R0P<cPPDT@P<SA5@d94<3DcAD8i=d91ASA5@CHg=496ASLcA48h
<C=1@d<i>3<h@c0e<CLe<D56=d55<DDg<d93@C<b3C53ASE4@cQ1@dDh=c53<cTP
CT@=;ePe@b0P<c4PDT@P<SA5@d94<3DcAD8i>3Hh@d4d>DE5AS=3=TDhA3LiAT4a
=T<h<cTg=cTc<cA4A495@CE6<S8i=CM2@TDc3CHa84i43BmH=D@P83<h8594838d
AD=2A30e<dE2>CM2@DHdAD4f=S4`>491<30fACLc=3=5<c54>CQ5=S54<cE4>3Pc
<3E1=SPdAS4eA0d`<cHc@C0`=3E3ASDg=3U684i43BmH=DDP83@a8594838dAD=2
A30e<dE2>3Le<d=1=4@fASM5A4A1<dDeATI3ACP`AS8i@S15AD=2=d=1<CI6@THi
AC4e@C0b>0e3=SA1=d4c>316=S11<SHb<SM1=T4f84i43BmH=DHP838e8594838d
AD=2A30e<dE2>3Le<d=1=4@f@CI6<44h=3Q2<c<fAS<f>D@a@C<`>3@iA3Hi<S<h
84i43BmH=S0P83<a8594838dAD=2A30e<dE2>D=2<STg<T=2<3Hf>CQ5AT4b=C16
@CH`<c0c=cI6ADE6>3<i=DA5@DHd<d<f>C<i<Pdg=b1>A0d_F3Ha820b<c4PDT@P
<SA5@d94<3DcAD8i>CDi=38e>C@cA3Hi>C8g<SA4>CU2=3E3@cU4<D8c=cTg<3Pc
=30c<C@`<dE2=DDf3CLc>38aADH`ASQ5@THe@C=6=CTi@S8i=DDa>4<i>38`>CU4
@S8b=cQ3@S13ASQ2>391=S0e=DDf@cQ5<0db<3M1<S8a@T4h=4@i>4=6=D@bAC0d
>4Hh>C15@DA1>392<cDa@SLa<3Lg=d4c@D8d=T8c<4Hg=c=3<d4==D4bASHb=C4f
@CLf<C=3>3Q1=d<i@SI3<4A1<S94@c4gAT=5<S0`=4@h@STb<CQ2=C8i>3Q2AS8e
<DDh3C@d=SA5>D8g@cDa<D@d<4H`AC13=34a=38h<c8g=C92AT<h>CPh>D@bA3<f
>4Hb=C0cA3<a<SI6ASPiAPdi>C12@CTdAS@a@SA3<cPg@S4h<DDe>3Tf=C0b>CM3
@D=4<S@d<4E6>3Td>D@fASA2ACTdADH`<S96ASD==44f<T@fAC<d=d=4<d8e<4I6
=3<b@TDd>D95=3Pc@dHa=CQ1A3E6@dHf<c91=c=6A3<h@TI3@C13@dI43D8c<DA2
=C4g<S52A44h>DDg=TE3=cE1@d<b=4=6<SDg@d8i=dHf@DE2=R1>A0d_F3Hb820b
<34PDT@P<SA5@d94<3DcAD8iA4Dg@S0f@CPg=SQ4@cHfAT51AC@g<d4e@CLc@T8e
A4@e>3Th>3<aAT4b@c4b>3<e3D8a=dI1AC<h<C12AS0`<S@d<SHe=D4d=4I5=48a
AS52<38c=TDh<d@h<S0d<T53=4Hg@S52=SE4@C94<`di=S0g@C4d=44fAS8e<D=6
<3E5=C11A3=3AC<d=d@`AST`<4<g@S8b>4<aA3Hb<4I6=SHh@d91A3E1<4@=<S4d
<S0a<3Tc<3PiAC@`@D@a<3I4ASU1@c@i=cQ6=c<h<S8c@dHgA38f>CDc=CU2@T96
<T4d<354<dDe3D4e<T=6=cTe<SHg@c@`=dE2AC8e@TDb=CI1>C93<C13>C53<cHg
=TDhAS0g<D<i=3<e<3Pb<cU6=T<f@`e4AT8i<48e<STc>4@e<dHeASU5@CDc@D8e
@d4hA3<e@T4f@SA4=THa=C11=4@i<4HdA352=T4b>D<d<cH==c0e@T4i>4I6>D@`
<T@e<3=4=T4c<T<a@D<b=TI4<3LgAD4f<CHf<c1684i43BmH=S<P834e=B1BA20b
=4E3@T@`=C=5@STiA30`@C4c=SE3AS@gA3HfAC<iA48a=cTa>D=5@cDi<4E1>3De
>C11<cDb=cE2>CP==3Pe=C8e@D=2<d8d=3H`<CHbAS0e=S<`>D53@T=2AD@e>4@e
=dI4AC8f<3Pg<4E5AD<f<dI3@c55@SE53CHg<T95A3<f<4A1=4@eA3@g<3Db=cE4
<311<CU6AT<i>4DgAT<b@cLe>C4hASM4@TE2@c@cATHd<dDh<@dg=c0e=S@d=C14
=cE4ADE2=CU1>451@cTi>3U3<DDiAC=1A3A1>34h=3I1@CU1<S55>CA4@TI1<cHf
=4H=>3=5<C52<4I3AC<g=D93>3M4=S<`>4E5=cPg<dHi@SLd>C53ASE4@cTi<SQ2
@S11<d<i<C<c=3=6ADDd3C4g>4E1=SPc=SLPCT@=;ePf=20P<CLc8594838dAD=2
A30e<dE2>D<f<C4a<DE1@SLd=cM6A4I6@C@h<cLa<D@e@d4g@S4h=S@f=C54=38h
<d4h=C=1<@e5@c<b<cHbACU5<CE6>C<`AD8h=T4h>3Ha>C55=cU3<356A3A2<SU6
<STcA4HhATH`=44a=TA2=4I5@CP==48`@SU4@CQ1=D93A44a<S4d<T8e=c4f=T4c
>CTcACTcACI1A3@a@cTf=C0`=C11=c8e<C=4<3Tg@DA53CM5<c52<T96>48h>DE1
@cDi>CU1=354<c8eA3U4@cDd<T<e<SHe=4HfAC<i<D@e<494ACE2<SU6<S11>0de
=4I4<44cACU6<S15<4Di=3@i=d@i>3=2<S0b@cDiA3Hh<D<c=SE1@SPf@c4c>D@d
=C8fA3Q6A455>38=<CLfASI5>44`<311@C8f>D91<d8a@CU5AD<`=C56=CLd<d@g
<30a<3@c>D@h=R1>A0d_F3He820a=c8PDT@P<SA5@d94<3DcAD8iAT=1@C0g<CDf
=3=3@DE2>3<i>3@d=C@f=4@h=3A2<D4bADDd=CE4ASI4<dDb=3Lc3C<e<SHi<d8b
=C0b=SU4=SLe<SU5=3=3<30a<SE4>DDd<d8f=4=5AT@c=C=5ACPb@S95<CPh=SDg
>4Hg@`e4=c=3<dDe=CI6@CA3AC8f=C0aAC93<3Di=3@e@DH`A354ADDg@CTe<34h
ATE3>4A6=d<c@TD`=CM6=c0==4=6A3A3<3@`<cDh=D8i=CPb<4=5<dE6>C0c>C91
<3TiATI2=TE4@CThASM4=TDa<4@b@S@e=30`A3Pa3CPf@S55>3Pi=CLf<C96<CPg
=34g<d4`A3Q5>C<a>3A2<d8f@d@e<CU5@DE6@cLg=3<dADDe>CE4=S=6@`dg>C51
ACQ1>D<c=394AD8c>C<i<30a@cTiAT8g=454@cHf=cM6=3U1@D@i@b1>A0d_F3Hf
820h=B1BA20b=4E3@T@`=C=5@STc<T<h=T@f<TDe=TDgAS16=S@g@DA3<44h=C8d
AD@g@dDcAS51=c8cAC@`>CA2=C8=@dHg<SE6@S<i@D92<3E5>DHa<dE3ACLc<D8f
<S53>4A3AC@e=D<i=T<a@T8`@TI1@CPc<3@fACE3=SQ23DA1=cDh<T=3=cE2=CPh
@T@hA3Tf<c95<CLf<cE6=CHa=d8d<d51@CHi@T4f@CM6AC@a84i43BmH=SLP838d
<21BA20b=4E3@T@`=C=5@SU4ACM2<3I1>3Li=DDdADI5ACLa<CDg=48b<c8h>CM3
<SA4=cE2A3Q2>D4d<D<`=d<=>C8iAC<`@D@a@S<h<C95<SLh>3A2>C<cADE1<395
=cM2ACTe@T8i=THi=DI6=T4g<cHf=C@i>CU6>3U13C=3=cPc<C4a=453=C4`<c0i
<STiA4=1@cDb>D51<SPg<DDc@c8h<3Q6<c56@D8g=S8e@C<b=3A1=CD`<0df<TA4
>D4cA4H`@cHd>4=5AS<a<D8a=d<i=S4a<DHd<S52=SQ4=C4c@c@a<S<a@CA3@d@g
=T52=3A3=4D=@C=4=CQ5@cI6<D4c=C@e<3HiAS0i@c@h@C92@cHg<SU5>DI1ADA3
<S0f=STh=cE4<3=1<3PaASPcA3A63CLaA313@T@c>356>3M2<d8i@c15AS4b@T<e
<c8a<D@`>CDi<C8e<D<a@D93=c8g@d8fASHfA4A6<SM1A@dbACTh=S4d@C=6=S<i
<396=S52<d4a=d=5A3TeAS8d=3<i=c@i>48cAC0a<3<c<3Hf<4E1=492>C0iAS<=
@C4i<S@iAT@b>3U3<dE2@CE5AS<a<d<c@TDi@CTb@C4f=T52=STi<cPaAT@i<S0f
ASE5=d4g>4Hb>34d84i43BmH=SPP834b<21BA20b=4E3@T@`=C=5@SU6<cHh=T@d
=d4b<c13<38bAD@f>4A3@CU4>D52<cI5<44g<T8a=cHd=S15>3U6<3D==CHi=S11
<3Hc=392>CM6=CL`=3Pe=SI1<4@g@T@cA3Q1<cT`AC4h@C13A30a>3Q4A4Dh@STg
<4<h<4953CDh>C55AS8g<SU3@C55@c0gA44a=3M6>C12AC8gAS0e<CLi<3Tb@S4`
=4=2ACDbA3Pa@THe=DDi<dI3=Pe4@D<`<4Ha=DDe=D56=4Dg=CHc=c0d@SPa>3Lb
>D94<394<d51@D@h<D=2=cTf<cE5ACE4@dI2@d93=T@PCT@=;ePf>B0P<cPPDT@P
<SA5@d94<3DcAD8f@c8aACM4=T<d>D8a<3La>CI1ATE2>3A3<d8a>C=3>CLg<313
<CE5@C=1=3A2A4A33DA3=D4i=D<c>3Tg=3Tb@d8PCT@=;ePf@B0P>C4PDT@P<SA5
@d94<3DcAD8f<CDi>C@g<4I1<3@g=S94=S=1@S4e=3HgA3Hb>DA5AC0g@S4c>D92
>3Lc@STeA3H`3CTgAT4i<3Ha=SDd<SU1@c8d@DA2@cDi<455<CPf=S91>4I4A4Dc
@S=4<C94AS@dACI6<S8cADE2=3L`=`e5AS8a@CDd=D51@CA3ACQ4=4<a=34d@DA5
@DDd=D8bAT8b>C@d<dA4<CA5ATA4=3=3@SA1=3U4A30gA3<=AC@PCT@=;ePf@R0P
=C<PDT@P<SA5@d94<3DcAD8i>3Hh@d4d>DE5AS0e<T94=T@c>CA6@D=1<3=4@SLf
<S0i@STgATHe<dA4=C8c=DE23DE5A44g=C4g@c0a<d=5=SPg=TDb<dA2=3Ha>CTb
=3Ti=CM6=S<h@D@gA30i=TDPCT@=;ePf@b0P<SDPDT@P<SA5@d94<3DcAD8f@c8a
ACM4=T<fA3Hg@CQ6=CHfASDh<c=2A4<g>CHa>C4bAT4e=D@PCT@=;ePfA20P<S4a
8594838dAD=2A30e<dE2@T@g<496=C92>C4g>CQ5@c15@DHc=c15A3U3ASI5>4@`
@SE4<c4i<D93ADHc<SE5<0de<S=3A4@e@c15@THbA494@DHe<T@d@S4i>3Dc<T<i
<cQ6@CU2A392<3<c=SPeASLg>3Le>C12ADD`AC4==SA5=3Q2<4Hi=D52<DHi=ST`
=STgA3DbADHi=C15@dDh>3Da@SE3@CDe>3@gA455=SDb@TE1<455=cU13CDb@SU5
=4Hf>D<e@cPdA34cAS@hAC54>CLc<S52<S0i<TE5=T<d>4<a=C@b<3DgA48e>3I1
@D8gACE4=`db=cM6@CE5A3La<C<f=dHc@c@e<CE5=T@a@C=1>C52@CHb<3Pa>3Hg
=SDc@c94<3=2@D93ACM1@S0hA3L=<c@a@c0f@C0d<DE3AS8c<T=5ASHb<D93<dE4
<S4g>DDc>4Dg<3@`=DA4A4I2=C=3AT93=SDi>C@eATHa3D=2=SLe=30a=S0`AT<d
<D4f@C14=D<b<T8c@C0f>48d>C0`>C8b@C<`=cA6@SPa<SU2<d8c<3P`=3<eA0e2
=R1>A0d_F3I5820a<CTPDT@P<SA5@d94<3DcAD8iAS<f>3I4=3M1<S<`@c0b<TE4
=SU6=c0i<SLh@cPb=cI1<30g=3<b>4De=D@a<DA23C51=d<`>C0e@S@g@T<e=CI3
AC92AS@e>4<`=4E2=D8c<THb=CU4@CTi@cLi=SDb>D@h>4Hf>395=C8c=0dgA454
AD4h=T56=4=1=d4dAS@c<S93=cLd=C4cA38e<D8b<C=1=D4b=D8d>3A6<C<b=3Lh
AS=4=CPcAD8=<SA3=CPa@d55=cA2A3@d=492ATI1=dA4AC4i@SU4A394AS<i=3Hf
=d8c@T8g<T@iA3Q1=CPdACI5=B1>A0d_F3I6820a<c4PDT@P<SA5@d94<3DcAD8i
A44c<38a=38c<ST`<CPc>C4g=d55=48`<4Dc<T@h>4I1<3D`AS@aADE3<S0`>3A4
3C4a@C@f@C8b@c@bAC4g>C53<cDiACLbATHb=C8h>CPh=D53ASE4=c<b>CHc=T<i
>CQ3<4<b=CM1@c@a<0dd=c<e@S52=c@iAT=1@CPg>C8d<d<h@dHg>3E6@C8d<SA1
=C8e<3Tf<D8a=S53>D8bAT8c=c56<C<f@T@=>DDh>4E3<d@d<S11ACPe<S4c<S8c
@D53=38bAT4a<3P`@cDc@D8h=3U6@dE5=30f<cA3<CPi<3=6@SQ63CTh@T@c=396
=cLh=4=6AD@h<cA6=SLPCT@=;ePg<20P<CLc8594838dAD=2A30e<dE2>D<f<C4a
<DE1@SQ3A4@e>3Q6>3Lg<DHiAC<h@D8e=c4b<CDe<3Di@T4a@SLg@c0e@`dd@c@i
@CLeASDg=S=2<dDdACA6<DA4AC8f<48e=T<f>3LcAS=2AS@i=3E6@cDa<dHf>3E6
ASQ6<392=4H=>316>DDd=CE5=TI4=d4`A311=c<d=SDcASH`=d52ATE2@cPeA4Ha
ACM1=3Lc=THf<SQ3ACU4<495=d8g3C13<cPiA353@T4e>CI2>34c@cHd<SDe@T@h
=cDh<D@h@dHf@THh=c8g@D93=3I6>4@i<d93@DA6ACPe<Pe3=TD`=C<h@SDa<cDa
<3Pi@c<e<SU2=395=C8d=34b=3A6=T51=D56@C@i@THd<THdAT8i=c8cAS@`=TH=
=THf@S0fAD91<CPf@CQ1=c0g>4<f=SI5<d<`=DE2=SPh=3Th=S95@CA3=T=4=b1>
A0d_F3La820a=c<PDT@P<SA5@d94<3DcAD8i@cHa<C4aAD52=c@g=dDa@c14=DDc
>DHe@cP`<D4g@SLh=CHe<c@`>3M5=3Th=THf3D53=4A5<3Pb<48b>CTh>D8e<CDb
@d4`ACE1=c56<S12=C=3AD4d<cTc@S8aAD=2ASM5>C@`ATA3=T8c@@dg<SHd=dHg
A48a<c@d=S8g@S92AS@h@CDc@S96<CHeADHfA494>311=DDc<S<c<D<c@C0g<SHg
@cA3ATD==SPhASU6<T96<S8d=CDi<S@d@C<`>CQ6<STcAD4i>CU3=30`=TDg>CQ5
<CU4A3@a=dHg=d51=SU6AC113CQ1>CDa<c@`=T93>CHaAS93@D4f<C13<DD`A44h
ASHg@dI3=S8b>3M3=S=3=S0a<3Hc<DDc>4E6@C55APe1>C@`=CDgA3Dd<30a<d93
<38b>4Hg>313@d4e@cPa<CDe@C13>38h>4Hc@S0`84i43BmH=c8P83Lh8594838d
AD=2A30e<dE2>C=5=dI3A492>C@g>3L`<d94>D<d<TI5=4Hi=dHb>C4a=CI6<DDe
@TA3<48f=cPb@Pdf<dA2ACU4=DA5@T@bA44cAT53<C0g<3T`@CE1@THa<c=1<30e
>38h@TA2>4<f<D<aA3Dd<4I6AT@d=cD=@DDdA3A2<dI2<cI3A353=T55>CT`<3A2
@CHb>3M1<T8h@d4a84i43BmH=c<P838a>21BA20b=4E3@T@`=C=5@SU2>D53<c@h
>30bAC8a>C0g<C52=4HaA3=3@dDh<THa@c55=D8c=3Ld@S=4>4=6<38=<CLd=c4c
A3A1<SHeASM6<cHh>C4iAT8g<c93AT<b@c@e@SI1=48d@C4c@CPi<SDa<c8d<4@f
=ST`=C0g3C=1<4<hACLbAC0f@CL`@c@b@D54AC<i<S8c@S4`ASHiAS<a@CDe<CI6
<3Pe<30fAD@c<d=6<3Ha<CI5>@db<SPc=3La<dA2<SPf<SI5=TE5<c<a=SPi@SE1
=cE1ASLb<C4a<d@a@DI4AT4`AD51<44iA4@h=cM3>CP=>D=2=THi=dHdA3Tb=3P`
@CU3>4<gAS=5A3M5=cD`<DE3>4E5@cPhA4D`>C<i=cM5@dDd<TI4>4Dg=DHa3CHc
AT<c<44`@CTg<SPg=T8i<c=3>392<S94<T91@cPa@STb@SE1<3L`<D<c=C8`=316
ASE1>3Tc>38hAPe3<44b>3E5A3Q6@S=6>C0g<T<`<S54ASE2@SH`ASDi@CDdASPc
=C4f=cTeAT95<DH`@C13=44cAT96<S<==4Hi>C@f<d@cACE4=DA3A21>A0d_F3Ld
820a<38PDT@P<SA5@d94<3DcAD8i=SLhASI3@c<h<SPh<CA2=SM1>3<h=4A2>3I2
<D4eA3Dd=D<f<34bA30d<CDeASA33D4c@DDa=30`=4=4@C95<S91>D8e<DE2=S4i
ACPg>48h=CTb=c4f@S<`A3Ta<C14ACLg@dDa@D55<3@gAPe4>CTg@C@f@TE1=c8a
=c@c>3Pa>3HdASA2AT94>312=cLd@cA5=dE2@c8`>DDa@S<g<SPa<4E3<4I2@DD=
=S4f=4A1AC<b<C4i<CDd<c0e>4E2AD@g84i43BmH=cDP834`=b1BA20b=4E3@T@`
=C=5@SU6<cHh=T@d=d54A4@`<3P`=c54ADD`=CL`<c96ACDe=S96AD@`<T55@SLa
=cTd<34=A395@S8i>CU4=4HeAS14>CTd<TA3@C=4@TDe<cDa=CDdA3U6=3Q2@SI6
=4@h=SH`=3U4<D4f=D<aAC913DA6=c4c@S16<4A2=T=6@TA5@THc>4Hf@S=1=cE4
=d8e=DI5<T=5<D=3>3<`<c8iA354=cPc<d<fA3M6@@e1>3Hc<3E4A4=1AT@c=c52
<d<g@S8c<4Dg<CLa=TDg=CA584i43BmH=cHP83@a8594838dAD=2A30e<dE2>DD`
<DDdAC<h=cPe=TA3<TI6<3E6<c<f=3La=TI3@SPfAT4g=THh<c4d>CLi>CDd=Pe5
ACPgA44h@DDa<SM2<3Hc=cA3<30c84i43BmH=cLP83Pe8594838dAD=2A30e<dE2
>4I1=d@e@D<eA396>3Tb<c4e=T<g=cM2<S0b@S4b=SPe<3E6AD4eA3A6@CLg<48g
=`dgAT4e@CPf@DE3=DA3>DI4@dI6A3<g@CPi>3Da<c=5@TE5=D<eAS@d@SPbA3U6
AC13>4@e<cU3@CTiAC8==CM6<d4`=CTg>48b<CI4@D8e=c53=d4f@CHcA44`ACTg
=T56ACDfAC93>D=3ACM6=CTPCT@=;ePg>20P=S<PDT@P<SA5@d94<3DcAD8i>4E6
>CI4@cE4>3Pg<c0g=S@`@SLb<dDhADE4=D51=CT`<cM6<3=5=cLgA48h@dI33DE6
<34bA34i<THc@SLa<CLf=TDc=T94@d53=C<aATI1<T<b=34c@STa=34h<3Df@D<i
AD91<d<i=3I3<Pe6AD@i=d@PCT@=;ePg>B0P>C4PDT@P<SA5@d94<3DcAD8iASPf
<4I3AD4f@c8h=44g>CHb<3@f<D<h<CLa=SHb@DHh>3Ph=SHc>D4g<493@dDg3DDd
@C0c=S@i=3He@dI6>C52<3Q1=48i<d=5@SDaA34i@SDh>CDf>C53@c51A30g<cLg
<3HdAC8d<dA2<0di@CQ3@d=6=CLi=C8a<3Hi=c<b=4<h>DHb@SPc=3Q5@cPe@C8f
<CPfA4=4<C8b@d=4AS4hAC<`ASDh>4@=AT4PCT@=;ePg@B0P=3HPDT@P<SA5@d94
<3DcAD8i>CDi=38e>C@cA4=4AS53@STd<dHc=c=4>D4e<DD`ASPg>3Pd<3H`=DI5
=3<h@SHb3D8i=S95=cP`@SPc<30d=c92=c=5@cQ3@D91@cDd=S<i84i43BmH=d8P
838b<21BA20b=4E3@T@`=C=5@STgAT@a<C94=D8d<3U6=C@g<3=6AT=3>D4c=D4h
<cLeA3@`<d4eAT91@S4`=THg>C<=<3Hh<SE1ACI1=d4iACI2>3HfACLb@CLh=c0g
=455@cDi=CT`>3Hh=D52=DA5>3Tc=cE2A3A1<T4f<CQ13C93>C8f=c14=3=5<S<f
@c=4>C<c<cE6=D=3<4<b=T96<3@fACDa=4DcASLb@SLh=S96ASPf=d4h>4@f<`e4
<4=5A4=6ADE2<d8i>311@DDcAC51@dA6@SPe=C<i=TA3>38cAC4f<CHf=CLg<d@h
AC4b<THc=4A4=cT=>CU4=313<S<d<C<b>4Dh@cTg=DHeAD@a=3ThA38f>DDaASI6
A4@iA3Hh<D@i<SM2@DE1=CI2=DI5>30d3DDd=c15>D4cA3Hd<C8g=TE2<48`<C15
>3E4<SU2>DA3<CI3@C8bA3U5AC@`@S0c@T@h<4Hh=cDf<C8g@`e2=3=2<SPd<S0d
<SE6<3La<3LcADHd>38f@S=5<3Lb=DI6<SHc<D<a@cTa=3@f=CU1AC8h<c<h<3M2
=S0=AD56=SLf<CT`<T8i@D8h>4@bAC8PCT@=;ePg@b0P<SDPDT@P<SA5@d94<3Dc
AD8f<cM6<cI2=THg<3<b=d92@SA6<3TbA4I4>3M5@THi=dA6@SPe=TDPCT@=;ePg
A20P<S8a8594838dAD=2A30e<dE2>CM6A34a<T@e@S8i<dDa=C0h=S@h=CLf>D<f
<cL`=d54=CA6@SHe=STe<SE1>CLh@`dbAC0a<DA3>3Ti>4Ha@cLaACQ4<S0g>CI4
ASQ4<CU2<3<c@cA1>4I5=C<h=cDc=d@d=DHf@cDh>3A5<T4=A4E2<T@d=DE2<44f
<c0b=D@b@SA6@cLc@d@e=T4b<CHh<cDb<cA4<cPa@cLcAD8f@d@a<cQ5>CHfA493
3D<`<3@a@d4i=TDg=d<f=d55ACTg@cDa=CI1=CPfACHe@SE6>44g=dA6=3L`>C11
A3<c=SHa=D54@CU1A0dg=4Db<DA5AD<`<T4`>DDi<T8h<4@cACM5<dE2=STe@SH`
=dA3<dH`@D@a<4E1<3Ti<3TaASPd>C8g=D4==TE4AD4h>4=6@dDf=TE2<S4h<3I6
<c@g<3Dg=TA5<cA4<3Ld=T=5A3<cASE2>3Te<c95ATI6@SA5<c0c3DHh=30g=dDg
@d@dA4E4<SPb=D@c=THb=T91A30g@dDg=CQ3@cQ2ACHcA3He@CE2>3M6AC0c<d91
>3<b@`daADHi=c54=c0h=dHb>C8c@d54=CDa84i43BmH=dDP834c>B1BA20b=4E3
@T@`=C=5@SPg=C=3@CA4=T<g>D=2<395>C8h<493<S=6A30fAS12ASA5>3D`<4D`
@S95@cTe@T@=<cHd=34h<d@a=T56<D@`=d8c@C8a>4Da@CU5@C@b@c56<T=6<d4i
=d8d=dE6<cLhASPbA4@b=d8i<S@a3CQ6<c4aAT=1A3Ti@cE3=30fAD=1AT@d@T8d
>D=3<SM1<SHb<D94<TE4>C@`=T93ASTfA4<e<30c<S4i<`d`<4<`=4HcA355<CI6
<D=6<3Q2@c<`AC<`@cE2=3=5>3=4AC92<S<g<cLf@TDcA4HgAC4g<D92=C8d<S8=
=3M6<dDb@DHe<CPaA3DaAS14=cPg@d=5=DDd@cA1=SHc=3E3A30PCT@=;ePgAR0P
<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH>30P83Pe8594838d
AD=2A30e<dE2>3<a=C4i<DE6<3Ta<cDeACHc<CU4<dHi<C4`=CHa@dDd@C92ASPf
ASLgA3La@S51<`di<dHeAC4dAD@f@cM3<d<g@c8b>D4c=dI4AC<d=cQ2<d=2<T<a
<3M6AS<g<T4e@c@c=S<h<S4b<3<fAT4=<dI2<c0g=C53<3HiAS8b<d8i<d<f>CTb
<c0`=3U1<STf>4Hf<S8g@STb@cLd@c@g=4DPCT@=;ePh<B0P<CLg8594838dAD=2
A30e<dE2>3<a=C4i<DE6<48g@d93=SPb=3M4=4DaA3<a>3Pi=CTi@d<`=4HcACTc
<d95=3@g=0dc<T<e@dDf@dDfAT@a<SA6=SDdATI2<3E3@DD`<c4iASDdAT@`<4Hf
=T4c@T@d=3De>D56<4H`>3Tf@T@==cU4@S=2@SI1AT8i@TH`<T4`@SA5>3=3A38d
@SDi=d4b@SLd<TE3AT4b=SA4=c55<dDf=SPiAS4`=34e3C0i@DHa@c96@C=1=3A1
@C0g=cL`=dA1@cQ6ASQ3>DDb>48h@DDg=SD`=C0a=d<f<THh<c@b@T4a=SP`@Pe6
@C0g<C@dA3<eATE5@c0h<S4hA3<hATI1AC4c>38d<DDg@c13=D8b@TH`@CD`>DDd
=495=4<h<3Q2=S8==CA4=T51<3M2>C4b<S<a>3Q1=d92AC8gAS15=S=5A3HcATHg
<SHf<cA5<D4a=3Q1>D4fAS1284i43BmH>38P838d=R1BA20b=4E3@T@`=C=5@SPd
=CL`@C8`>DHi<496<d8aA30g@d8e=38g<c<`AS8h=392@DHg<316ACU6A48g<4H=
<3M4@DDe@C15>CPe<44b@STb<SPaAS@i=C<a>CI2>D4g<T53=d<f=TDd@S=1=S<g
AD54=CM6ACI6AC4e3C4d=SQ4@SPc<3Pe=D@g<3U6<cH`=SLg>3M3@d8a=3A1=d4a
@c4h=TA4<SA2=D<f=S0a@DHb<T<e@DHcA@e3>C0dASDe<CHaADE6=C0g>D4c<S55
=d51AD@h>DE2A3HaAS56@C<c<S0c<4He=c51@cT`@SDb=SI2>3T=>DA4A3M3AS@c
ADDa<4Di>CHi>C4c@D94=c4i>34bA4Hh<cI6@cM2@D=2=C0`AC0b@S0e=D=1AS8a
A3A23DDe>3L`<d92=3Q2AC4a@T@f<38f<SA2ADA2AD<a=492>3D`=THe=CDdASI1
<C<a<cDi=4@a@cHc<T<g<@ddAST`<dA4@S=2<3E1A4@f>DDi=4Dc@S<b<3Hf@dA1
>3<b>3@f<THb<c4h=cA1=cH`>CA3>38a<S0e=3H=A3He=3I2>4E2>4DhAS<f=3Ti
AD@f=D<g@T94<4E5ACA1AT=5<D8b>CQ4=d52<3@fAS@e=30c=C0e=D8b3DE1=4@d
<cHaAS15A21>A0d_F3Pc820f=b1BA20b=4E3@T@`=C=5@SU6@d51<3La=CA6>D92
<314>DDa@SA3<4=4<T@f<34dA4Hd<d@i<d<`AS<a@dHd<S8=A492<3Pb<C8c@CL`
<3Ph=dE6ADDaASHdADHe<T91>DA6<SE2=4Hh>3=1<4=3>34e=DI1ASD`<3E1@CM1
3D8`@CHf=cM3A4E1<3@`84i43BmH>3@P834f=b1BA20b=4E3@T@`=C=5@SP`<SM2
<CDc@C8h@S51@d91<DDdAT8d<dI1=c54>CDg<4<h@d93AC=5<TDf>38`>4D=<SHe
<C52AD@c=D<dAT@`A3Lh@S8`ACQ1<d8d<dHe=T8c=dDf<3Pa=cHd<S<d<3E4=4@g
>3A3=351<3Th3CQ5<cM3>DDf=C<d@d4i>3Q2>492>4Db@cTbAS92=34c>C<g=cDb
@D8d<D<i<T4d=CDb@C53=CHd=d92>@de<CTg@T53AT4dAS55@C93=394@cPaAS=5
<34b@SA3>C0cASM3=3Lh@SPi<d@i=D4fADI5ASU1>3I1<CH=<cQ4A3U6A4E6>C4a
AC<gADI5>315<4I4@dE1ACLcA356@CPaA3@f>CU4<dHd@c16=3M1<dI2=C4cA4E4
3D53<T4`>454ASDc>3Pa>D<a@cHh>3Pi=cE1A3@gA494@cHPCT@=;ePh=B0P<CHa
8594838dAD=2A30e<dE2>38iAC@d=48`=CU6>CE1<D@d<DI5@c0eAD4b<T51<CU4
<cA2=D4`@S=3=dDb<30a<Pe4<S53=c51>3U2@THb>C8g>3Q3<cPb=cM6=c91=4Ha
ADHhASD`<34eASLe<C0aADHbASU1>3Q4A30aA3T=AD51>C55@C92AD8g<4Hb>44f
<T@dACPa<C4c>353@CLi=d<f<3HhA3Lh@S0g<d4i=T4d=DE1=3Dg<C=23D@d@S@`
=492@d=5@D8b=S@d>C@e=TDc<c8i@cHa>392ADDd=TDc@SLcAS@cAC0i@S0e<c51
ADDd<d54=`deACLc<3@hAT4b<D8bAS8g<S11<C8h>C@f>3Hc>CH`=cQ6@CTa=3Pf
AC<`=S0g<312>3Lc=4@cA3M5AT<=@cPe>C8h@C0d<C<c=S@e<392@DDg>21>A0d_
F3Pf820a=34PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I3=cTb=C<b<cE5AS@c=c94
<S4`@C55<dD`>3HfA3Q3@T@i<S0e<4Hh3C96<48aACI4@C0g=CI5@cQ6<391<3Pb
>C@h>454<CA6@SM1=TI1>CLd=3M3=D8a<D=1AS@a@S0g=3Ha=0e2@SA6AC52@DI6
>3He<d54=3P`=D95<44b=T<aAD4`@TI3<4@a>3A1>DA6AD<h=DA4=cU4=dE4<S0`
=CH=>D8b=D=1<T@eA38g@d54ASHa=cH`AC<iA355=353@dA1>CLi<CQ1=D8e@DDd
=cTe=D8`@DHa=S96AC8i3D@h<CQ6@S@b@S@`@dA4<4=6A4Hi<30gASHaAD4dAS4i
>DI3<SLg=dDfAB1>A0d_F3Pg820b=C400:40`3oo8594838dAD=2A30e<dE2>CTe
>C@b=CTd<d@f>CTb=c8dA3Ti@S@e@d<iA352<cLi=c0h<c@`<c4d<3=5@SE5=Pdg
<cPb<DE6<4HhAD96=D4cASDi>D8b>CE5<CQ3>CPb<3TiA48b<SLh@d8`@dHh@SPb
@CH`=CE5=T<hAC0=<S0g@C8b<D91>3A4>CQ3ASE4<TD`=3Q6>3T`AD54@CPb@S<e
<D8g<C0g=cM1<d52=3I2<c16=cLc@c=13CE1<THf<SDa=T4g=S4c@cPh@CM3>D8f
@c14@C8bA4<a=dI3AC8`<3A4>48i<S4h@SDb>CPh@THb=C55>0dd=3HdACU2=d<e
<C54=316<4D`@c@a<C@b>3<b=cDb@TI3>3Th>3U4<T@c=SQ6<SD`<d@c<C8fATHh
>DH=>CT`@T4i=4Hd<D8d@c<h=d8a>355=CPi=SD`<STg@d53A38d=315ASPi=3U4
=THd@TDi=4E6<38bATHe3CA1=S94=TDc=3M3A3=2=C16AS@c<T95=3U2AC@h<d=6
<CDh@D@eAT=6=S<b@CLcAT@c>496@d4`@d=6A0e2<c54@SDa=c8a@TA1>3U5=cI5
@cLe@D=3<SA3AS8e=d=2>CM6=T55=3<g<S0a>38bACM3=SDd@CHb@S8=>DI4>3I2
<4Hb<4<b=3LgADE6=D=3@B1>A0d_F3Ph820b=C0PDT@P<SA5@d94<3DcAD8i>CDi
=38e>C@cA3Hi>C8g<SA4>CU2=3E3@cU4<D8c=cTg<3Pc=30c<C@`<dE2=DDf3CLc
>38aADH`ASQ5@THe@C=6=CTi@S8i=DDa>4<i>38`>CU4@S8b=cQ3@S13ASQ2>391
=S0e=DDf@cQ5<0db<3M1<S8a@T4h=4@i>4=6=D@bAC0d>4Hh>C15@DA1>392<cDa
@SLa<3Lg=d4c@D8d=T8c<4Hg=c=3<d4==D4bASHb=C4f@CLf<C=3>3Q1=d<i@SI3
<4A1<S94@c4gAT=5<S0`=4@h@STb<CQ2=C8i>3Q2AS8e<DDh3C@d=SA5>D8g@cDa
<D@d<4H`AC13=34a=38h<c8g=C92AT<h>CPh>D@bA3<f>4Hb=C0cA3<a<SI6ASPi
APdi>C12@CTdAS@a@SA3<cPg@S4h<DDe>3Tf=C0b>CM3@D=4<S@d<4E6>3Td>D@f
ASA2ACTdADH`<S96ASD==44f<T@fAC<d=d=4<d8e<4I6=3<b@TDd>D95=3Pc@dHa
=CQ1A3E6@dHf<c91=c=6A3<h@TI3@C13@dI43D8c<DA2=C4g<S52A44h>DDg=TE3
=cE1@d<b=4=6<SDg@d8i=dHf@DDc>C53=S13=C12@cI4ACDcA3U4@`df<C53ADI3
=SQ6=C8c@CTa=cTe>21>A0d_F3Pi820b=CTPDT@P<SA5@d94<3DcAD8i>CDi=38e
>C@cA3Hi>C8g<SA4>CU2=3E3@cU4<D8c=cTg<3Pc=30c<C@`<dE2=DDf3CLc>38a
ADH`ASQ5@THe@C=6=CTi@S8i=DDa>4<i>38`>CU4@S8b=cQ3@S13ASQ2>391=S0e
=DDf@cQ5<0db<3M1<S8a@T4h=4@i>4=6=D@bAC0d>4Hh>C15@DA1>392<cDa@SLa
<3Lg=d4c@D8d=T8c<4Hg=c=3<d4==D4bASHb=C4f@CLf<C=3>3Q1=d<i@SI3<4A1
<S94@c4gAT=5<S0`=4@h@STb<CQ2=C8i>3Q2AS8e<DDh3C@d=SA5>D8g@cDa<D@d
<4H`AC13=34a=38h<c8g=C92AT<h>CPh>D@bA3<f>4Hb=C0cA3<a<SI6ASPiAPdi
>C12@CTdAS@a@SA3<cPg@S4h<DDe>3Tf=C0b>CM3@D=4<S@d<4E6>3Td>D@fASA2
ACTdADH`<S96ASD==44f<T@fAC<d=d=4<d8e<4I6=3<b@TDd>D95=3Pc@dHa=CQ1
A3E6@dHf<c91=c=6A3<h@TI3@C13@dI43D8c<DA2=C4g<S52A44h>DDg=TE3=cE1
@d<b=4=6<SDg@d8i=dHf@DDd<dI2>CLd<SPc=44i@C4h>3Pg>@dhAT8i>4E3=38c
=SA5A3@hA30b=C=1=C4g<3A6@CDb@dHiA3M6>21>A0d_F3Q1820b=CLPDT@P<SA5
@d94<3DcAD8i>CDi=38e>C@cA3Hi>C8g<SA4>CU2=3E3@cU4<D8c=cTg<3Pc=30c
<C@`<dE2=DDf3CLc>38aADH`ASQ5@THe@C=6=CTi@S8i=DDa>4<i>38`>CU4@S8b
=cQ3@S13ASQ2>391=S0e=DDf@cQ5<0db<3M1<S8a@T4h=4@i>4=6=D@bAC0d>4Hh
>C15@DA1>392<cDa@SLa<3Lg=d4c@D8d=T8c<4Hg=c=3<d4==D4bASHb=C4f@CLf
<C=3>3Q1=d<i@SI3<4A1<S94@c4gAT=5<S0`=4@h@STb<CQ2=C8i>3Q2AS8e<DDh
3C@d=SA5>D8g@cDa<D@d<4H`AC13=34a=38h<c8g=C92AT<h>CPh>D@bA3<f>4Hb
=C0cA3<a<SI6ASPiAPdi>C12@CTdAS@a@SA3<cPg@S4h<DDe>3Tf=C0b>CM3@D=4
<S@d<4E6>3Td>D@fASA2ACTdADH`<S96ASD==44f<T@fAC<d=d=4<d8e<4I6=3<b
@TDd>D95=3Pc@dHa=CQ1A3E6@dHf<c91=c=6A3<h@TI3@C13@dI43D8c<DA2=C4g
<S52A44h>DDg=TE3=cE1@d<b=4=6<SDg@d8i=dHf@DDd<cHd=D8f<SLa=4Hh=C52
@DHb@@d`=SE3<cPb@THa=c8b<dI1A4Df=3LdAD8e@S<b>CTf=cTh84i43BmH>48P
83<b<21BA20b=4E3@T@`=C=5@STi=CTd<SDi=3=4=STi<SLb=4@i>D8d=D=3>D@a
@S<g>CL`>3<d<3<a=30cAD8eACH==c<h<S55AS16>4E2ASE1<dHe>CU2<STeAC4h
@cTh<S0i>DA2<S8g>4=2<4=6>48h<T4f<3DeACI3>4D`3C8`=d4b<S52@CPdA3Th
@dHeA395<3@hASPi<4E1A44h<T8c=C52=c4`=cLg@C=1@S@f@S<`ASLg<d<c@@de
@C96=S8e<CI1=cHa<d<h>44g@cU2=T<`A44b<TA3<CM6@dDb<30dA3Q2>C8a>48e
<STh>496<SDaACP==3@f=4Di@SM3=C4aA3@`AS15<4<d<C4d<SPc<SLe<T96@cPi
>3PiA394<cHhAS8e<3=4<c4b=TI6>3U63CTi<491>CA6=352=4<c>3M2<CPaACDh
>CHe<38i=d=1@d@b=3@`ADHh>C@iA3I6=495>CA5AS0b<TI6=@dd@CHbA3I5<c@g
@d@c@SD`ATHd<c92AC@i@TDd>3=3AS4e>454=DI3ASHc<T4g<dI4<cQ2AT=1<4=3
AT@=@S<aA48e<CLb<D94@CPiACLfAD<g=D53@c8d@dHb=CM3@STgASI1AC@c>C4`
<D@a=D=5<S=6ADHg>C563D4d@TH`=d91@SH`=C12@c=3<DI2<DI1ASI5=D93AS<c
@TA5=THh<4@fAT@b=3<`@c92<CPa=493>4I1=Pe2=c@eA4E4@T<f@D8gACA2<44f
<C56@TI3=D4h<4H`A3Df>C96=cDf@cTcA4@hAS8fACQ5<3Pb=C0h=CH=@d<`AC11
=T8h@d8aA3<c@C=2<STa=SU5=T8b@CI5<4A2=CPi<T<g<21>A0d_F3Q3820c=C8P
DT@P<SA5@d94<3DcAD8i>CDi=38e>C@cA3Hi>C8g<SA4>CU2=3E3@cU4<D8c=cTg
<3Pc=30c<C@`<dE2=DDf3CLc>38aADH`ASQ5@THe@C=6=CTi@S8i=DDa>4<i>38`
>CU4@S8b=cQ3@S13ASQ2>391=S0e=DDf@cQ5<0db<3M1<S8a@T4h=4@i>4=6=D@b
AC0d>4Hh>C15@DA1>392<cDa@SLa<3Lg=d4c@D8d=T8c<4Hg=c=3<d4==D4bASHb
=C4f@CLf<C=3>3Q1=d<i@SI3<4A1<S94@c4gAT=5<S0`=4@h@STb<CQ2=C8i>3Q2
AS8e<DDh3C@d=SA5>D8g@cDa<D@d<4H`AC13=34a=38h<c8g=C92AT<h>CPh>D@b
A3<f>4Hb=C0cA3<a<SI6ASPiAPdi>C12@CTdAS@a@SA3<cPg@S4h<DDe>3Tf=C0b
>CM3@D=4<S@d<4E6>3Td>D@fASA2ACTdADH`<S96ASD==44f<T@fAC<d=d=4<d8e
<4I6=3<b@TDd>D95=3Pc@dHa=CQ1A3E6@dHf<c91=c=6A3<h@TI3@C13@dI43D8c
<DA2=C4g<S52A44h>DDg=TE3=cE1@d<b=4=6<SDg@d8i=dHf@DDd<dHc<3=3<cHd
=C<i@C8c=3M4>0dbAC=2>455=cA3>4<d>CM1@C51<c8c<3=5=CTb<CDc>D51@SU5
=cI1ACTfA3Hi@SPbAC0d@SM1=c13@cD=<D=3=CI5A34g=3=1=C<i>C4f=d@cA4De
ACP`A4=5<3A6<D8a>CDd@C4`<SDc=cTb<cQ6@DHi<4I1<SM53C@d=SDi=SE2<SHg
A3De<d8e<D@`AS<`A3DgAS0b@THh>D4e>30g<SHh=c8f>3=1>C<f=d<a@T8c<dHa
APdh@C4i>D@`A3De@cE6=3Q5ACA2>3Lb=c53>C0e<D<a<S94AS=4=316ADH`AR1>
A0d_F3Q4820b<SDPDT@P<SA5@d94<3DcAD8i>D@`<44a<cHe<c<`=D51=S93=S8h
@D55@SA1>DI2@SE6A314@SDa@D4b>C@d=TE23C96A3@c@T@c=C0cA4<f=T<gAC4e
@CQ4<c@i<4<aA4Hc@C@cAS0h=CU1>452<SPf<3Li@CI2<SE5AC0i>@e6@D92@SLa
@SI4>3Dc=D4d<T4b<SI4@c0g@c@a>30aA3I2=S<`=D=2<3Q5<SPa>C8i=44i=DI5
@S@hAT@==3@`A3DiASHa=d8dADHd@C<c<d8d<cU6<T<`A4@i<SI2<SU3>4E1=3He
@D56@D@e@C55@c=6A4=1@CU13CDaAT4g=48b@CE5>D8h@T93=4Hc@CTi<34f=TA5
=d4d@c0c<dDb<44a=D@g=SI5<C@g<T53<4I4<CPe<`dd@DHd=C53=392<d8h>3Tf
A4Hi=D8a@D4d>4HcA3Q2=S0b<S0f@S4d<495A3Tg<SA5@cM3@cM1AC@a=CL=@C=3
>C95<D=3=DDg@d@f@d4d<354AC56<CQ5A4A3<3Tg@cDe<CE6>C=4=S95ACE3=3@d
ACE4@C0f=C<i3CHf=T=2ACHa<D56>4@f<3<c<SL`@C@i@S@f@T8c@B1>A0d_F3Q5
820a>C4PDT@P<SA5@d94<3DcAD8iAT=1@C0g<CDf=3<d<C4`@S0a=3Q5<d<b@SM4
=34d<3Li<dDh@c<g>D@`ACDd@c963D8a<d4e<cLi>CI5=CDfAD<b@d=4ATI4>3I6
>CLd<c8d<3Di=S0b=3Hf=38e<3=1>4De@dE1ADDh>C12<Pe3<CHg<dHaASPh@T=5
=TDg<D4cASE4=SQ6ASPgAS=2@D<h@CA3=T8f>CP`>4Hf=D@d>3@a>C4i@C<h<C8=
ACDf=SI3@cA2=T8e<cA5ACPi<SPi>3DfAT<iAS4d=CLd=cI5<SA2>D52>3Pa<CE6
@SLf@DDaA3Df<cI43DDa@T91A3A6AC@`@dH`<S8iA3=5<SPh<cA3AT53=dE5=c<i
@C8aASPh<4I5@CHe=T@d>4Db=C8f=S@iAPdd=44iA3Hc=4I4=d4fAT@`<3<eA4A2
AS0`<496=CM6@C4h<CDgA3=3=DH`ATHf=c0cAT4i@TA3=T@`<T4=@TA4>38`=38d
A4Hg@S0e@S0a>C<g=R1>A0d_F3Q6820a>C8PDT@P<SA5@d94<3DcAD8iAT=1@C0g
<CDf=3<d<C4`@S0a=3Q5<d<b@SM4=34d<3Li<dDh@c<g>D@`ACDd@c963D8a<d4e
<cLi>CI5=CDfAD<b@d=4ATI4>3I6>CLd<c8d<3Di=S0b=3Hf=38e<3=1>4De@dE1
ADDh>C12<Pe3<CHg<dHaASPh@T=5=TDg<D4cASE4=SQ6ASPgAS=2@D<h@CA3=T8f
>CP`>4Hf=D@d>3@a>C4i@C<h<C8=ACDf=SI3@cA2=T8e<cA5ACPi<SPi>3DfAT<i
AS4d=CLd=cI5<SA2>D52>3Pa<CE6@SLf@DDaA3Df<cI43DDa@T91A3A6AC@`@dH`
<S8iA3=5<SPh<cA3AT53=dE5=c<i@C8aASPh<4I5@CHe=T@d>4Db=C8f=S@iAPdd
=44iA3Hc=4I4=d4fAT@`<3<eA4A2AS0`<496=CM6@C4h<CDgA3=3=DHf<SH`<D<a
@c15<c@f>D8f<C<=A3A2@cDa<S93=3@f=4=1<4E6A4<g<C@a84i43BmH>C0P838`
<21BA20b=4E3@T@`=C=5@SU6@d51<3La=CHd<c@a<C12<34d>4Dc@c92=d@d<C@`
=cTcACQ3<cLiA315=CA3<TH=@S4c@CDc=cTi=TDe=CI5@c93@dA6AT@h=THi=c@c
<S@`=CTf<38d=SHd<SD`<d4hACE3AD55ACPi<48b3D<a=SLcAS56>3Q2@dDfACLa
@C=6=D@f>4I6>3M6<d91@cQ1=4<f@SHi>30hASHeA3@h=34i<CU1<cPa<Pe5=CHf
=T=3=48f@SDc=4E5>3Tb>3Th=CI6@cU6<C@e=c@g=TDb=48i@D8h>34a=DI2=cI1
AC54=CHc=T@=AC52@T54=4I5=313AS0b<SU4<dDb>3Pc=4=6@D<gADDg<cU1<S56
>3P`ATE1=SDfA3@hAC8e<SHf=3U63C@d@CU4=S<dAT@g@CI6A30`<cE4A496<30`
@THe=dI1<CPa=CM4<d<eASHb@d4i@d@h<DDa=cPc=T95>0dg=44e=3H`>48eAT@`
AC8`@cM5AD@d=SQ1@dE3<cE4@SE6@D8hAS<a84i43BmH>C4P834i=b1BA20b=4E3
@T@`=C=5@SU6@d51<3La=CHd<c@a<C12<34d>4Dc@c92=d@d<C@`=cTcACQ3<cLi
A315=CA3<TH=@S4c@CDc=cTi=TDe=CI5@c93@dA6AT@h=THi=c@c<S@`=CTf<38d
=SHd<SD`<d4hACE3AD55ACPi<48b3D<a=SLcAS56>3Q2@dDfACLa@C=6=D@f>4I6
>3M6<d91@cQ1=4<f@SHi>30hASHeA3@h=34i<CU1<cPa<Pe5=CHf=T=3=48f@SDc
=4E5>3Tb>3Th=CI6@cU6<C@e=c@g=TDb=48i@D8h>34a=DI2=cI1AC54=CHc=T@=
AC52@T54=4I5=313AS0b<SU4<dDb>3Pc=4=6@D<gADDg<cU1<S56>3P`ATE1=SDf
A3@hAC8e<SHf=3U63C@d@CU4=S<dAT@g@CI6A30`<cE4A496<30`@THe=dI1<CPa
=CM4<d<eAS4f=C4d<c4a>D@a<c53=c4e@Pdi@C@b=3Da=C93>452@C=6@cU4@S55
A4<b<T@d=DDi<C0i84i43BmH>C8P83@d8594838dAD=2A30e<dE2=T<b<DDgA3I3
=3U2<C0g<CTf@DI5@SPd@c=2<CTc@cTg=c0`@c4e<cDi@CHiA48fAPe2<48a<4@f
A3=5<495A44i=dHgAC@d<C4dA3Hd84i43BmH>C<P83@e8594838dAD=2A30e<dE2
=T<b<DDgA3I3=3U2<C0g<CTf@DI5@SPd@c=2<CTc@cTg=c0`@c4eAD4a@d@aAC0c
@Pd`>C4d<S54ACI3@S0f=391=T91<C<e<C93<CA6A3@PCT@=;ePi=20P=C<PDT@P
<SA5@d94<3DcAD8f@c8aACM4=T<d>D8a<3La>CI1ATE2>3A3<d8a>C=3>CLg<313
<CE1=CHc>495AS=53C11<T4f<30c=SPi@C4a<D=6@S4hA3Lc=S<e@SPbAT@f>D4d
<356<c=5<c@b<dDPCT@=;ePi=B0P=C0PDT@P<SA5@d94<3DcAD8f@c8aACM4=T<d
>D8a<3La>CI1ATE2>3A3<d8a>C=3>CLg<313<CDc@c<gASA4<T@h3C<g<DH`@D<d
<TE3<c<h<c=2@SM4@d8e<CM1ASTgACPf<d8iACHe@TDPCT@=;ePi=R0P<S0g8594
838dAD=2A30e<dE2>DHc=SPfA3@g@C8c<4<`<S95A3HiASL`>C8g>4<h<SLf@C0`
=c@c<SQ5=CE4<C54@Pda@CM3<3T`=D8d=d93=CDf@dDb@THd=CQ3<3A5@SE2<c96
<SDiA44i>D<g>CHe<SU4>3Q6=SPbACDb<c@==dA1A4E1>3I1ASA3@CM1=4Hd<c8b
@cLg=3Da<d@b=C52<S4c@CE1<SE2=3PdAS4c<S@g>4HcA3Dh<dE23C8d@cDh<D=1
ACLd@T@d=3A2@TI6@CM4A4Da>D8iA4@bA4Hc>C@f=SM2<d92=c94>D@h@CDh=4Df
=3Dd@Pdf=SM2AD8g<CLhAD95=CHb<cQ4=d95=4A5@d4a=3TbAS<c<3Lg<c@e=3He
ACHi@cP`AS0i>C<g>DHg<48=<D8bACPi>CM6<cPc@S=5<cHdA4<i<3Pd>C<i<CU6
=44d<3<f<d<c>44i@C0h@d<dAC@aATHi=TI4=CTc3D4g=cM6=d4aASI4@DI4=34d
=dHg=SPf<455>C4c<CDf<4<`=3Tg<C4g@cM3<C4h=C8`>CQ5<21>A0d_F3Tg820a
=C4PDT@P<SA5@d94<3DcAD8iA44c<38a=38c<ST`<CPc>C4g=d55=48`<4Dc<T@h
>4I1<3D`AS@aADE3<S0`>3A43C4a@C@f@C8b@c@bAC4g>C53<cDiACLbATHb=C8h
>CPh=D53ASE4=c<b>CHc=T<i>CQ3<4<b=CM1@c@a<0dd=c<e@S52=c@iAT=1@CPg
>C8d<d<h@dHg>3E6@C8d<SA1=C8e<3Tf<D8a=S53>D8bAT8c=c56<C<f@T@=>DDh
>4E3<d@d<S11ACPe<S4c<S8c@D53=38bAT4a<3P`@cDc@D8h=3U6@dE5=30f<cA3
<CPi<3=6@SQ63CTh@T@c=396=cLh=4=6AD@h<cA6>C95@SE6=S<f<SL`ACPb@dI6
A44f>C52>4Hb<3Pe@d93A4I3<C0h=Pdf<R1>A0d_F3Th820a=C0PDT@P<SA5@d94
<3DcAD8iA44c<38a=38c<ST`<CPc>C4g=d55=48`<4Dc<T@h>4I1<3D`AS@aADE3
<S0`>3A43C4a@C@f@C8b@c@bAC4g>C53<cDiACLbATHb=C8h>CPh=D53ASE4=c<b
>CHc=T<i>CQ3<4<b=CM1@c@a<0dd=c<e@S52=c@iAT=1@CPg>C8d<d<h@dHg>3E6
@C8d<SA1=C8e<3Tf<D8a=S53>D8bAT8c=c56<C<f@T@=>DDh>4E3<d@d<S11ACPe
<S4c<S8c@D53=38bAT4a<3P`@cDc@D8h=3U6@dE5=30f<cA3<CPi<3=6@SQ63CTh
@T@c=396=cLh=4=6AD@h<cA6>D@b=CI4<dA6ATA3>CDe<CHd@dHh@T@d<T4b=SE5
=dDaACTd=C=4<R1>A0d_F3Ti820a=CLPDT@P<SA5@d94<3DcAD8iA44c<38a=38c
<ST`<CPc>C4g=d55=48`<4Dc<T@h>4I1<3D`AS@aADE3<S0`>3A43C4a@C@f@C8b
@c@bAC4g>C53<cDiACLbATHb=C8h>CPh=D53ASE4=c<b>CHc=T<i>CQ3<4<b=CM1
@c@a<0dd=c<e@S52=c@iAT=1@CPg>C8d<d<h@dHg>3E6@C8d<SA1=C8e<3Tf<D8a
=S53>D8bAT8c=c56<C<f@T@=>DDh>4E3<d@d<S11ACPe<S4c<S8c@D53=38bAT4a
<3P`@cDc@D8h=3U6@dE5=30f<cA3<CPi<3=6@SQ63CTh@T@c=396=cLh=4=6AD@h
<cA6>C0gASDh<T4i=c12<C<cAT<iASTb@SHh<cA1=D=5AT4i>3A2>4E6=0e5=3Tg
@SQ5=4E6=4=4@B1>A0d_F3U1820a=CLPDT@P<SA5@d94<3DcAD8iA44c<38a=38c
<ST`<CPc>C4g=d55=48`<4Dc<T@h>4I1<3D`AS@aADE3<S0`>3A43C4a@C@f@C8b
@c@bAC4g>C53<cDiACLbATHb=C8h>CPh=D53ASE4=c<b>CHc=T<i>CQ3<4<b=CM1
@c@a<0dd=c<e@S52=c@iAT=1@CPg>C8d<d<h@dHg>3E6@C8d<SA1=C8e<3Tf<D8a
=S53>D8bAT8c=c56<C<f@T@=>DDh>4E3<d@d<S11ACPe<S4c<S8c@D53=38bAT4a
<3P`@cDc@D8h=3U6@dE5=30f<cA3<CPi<3=6@SQ63CTh@T@c=396=cLh=4=6AD@h
<cA6>C94=C4b>CPiACDd>3U6@CU4<D=6>C0eAC96=3<bACM3@DHdACQ5@`e4=cA6
@CHi@cQ3=DHe=b1>A0d_F3U2820b<CTPDT@P<SA5@d94<3DcAD8iA44c<38a=38c
<ST`<CPc>C4g=d55=48`<4Dc<T@h>4I1<3D`AS@aADE3<S0`>3A43C4a@C@f@C8b
@c@bAC4g>C53<cDiACLbATHb=C8h>CPh=D53ASE4=c<b>CHc=T<i>CQ3<4<b=CM1
@c@a<0dd=c<e@S52=c@iAT=1@CPg>C8d<d<h@dHg>3E6@C8d<SA1=C8e<3Tf<D8a
=S53>D8bAT8c=c56<C<f@T@=>DDh>4E3<d@d<S11ACPe<S4c<S8c@D53=38bAT4a
<3P`@cDc@D8h=3U6@dE5=30f<cA3<CPi<3=6@SQ63CTh@T@c=396=cLh=4=6AD@h
<cA6=30b=dE1<4Hb@S12=4@d>3<iAD4i@d8e>DA6<CM3=394ACDh>C8eA@db<4E5
=3Pd=C15<SE3<SA5<44f<3U2A3A2<SM4@DE5@T=6=d92=dE2<SDc>4A3>C<h@d8b
AC=3<492=C0==c55=cDbACDf@c52>C<c=T8i<451=DA6=3Da>DA2=D@bADA3@cLg
=S<e<dH`@CLa=cU4>CDf<3Ph<c<`3D@`@C8f=3E1=d55A44g>C11=b1>A0d_F3U3
820a<SHPDT@P<SA5@d94<3DcAD8iAS<f>3I4=3M1A4A4<30h<3LaA4E5<3Dg<3<b
ATDe=CHbATE4<391AD8g<CLi=30a3D@bAD8b>CTiA3A6=DH`A3Ti=394@d4cA495
=C<e<CDe=4@iAS@h@T8fASA4>3Hf<3@iA351=SE3<DDb@@e4ASLa<d8`AS14@SI3
AT94AD96<cQ6=T8c@CLeA3M2=CE6AC93AC53@cPc<3<b>D@aA3Lh<c=3=T@gAT4=
@CPf<c0eA4A3@DI4<cLa@S=3=d8b<c15=c4g<CI5=cE2@S8`AC0g=SDg>312=d@`
>4Hc@THb=d8b=SHa3C0c=DA4@CD`@T<iAB1>A0d_F3U4820a<SDPDT@P<SA5@d94
<3DcAD8iAS<f>3I4=3M1A4A4<30h<3LaA4E5<3Dg<3<bATDe=CHbATE4<391AD8g
<CLi=30a3D@bAD8b>CTiA3A6=DH`A3Ti=394@d4cA495=C<e<CDe=4@iAS@h@T8f
ASA4>3Hf<3@iA351=SE3<DDb@@e4ASLa<d8`AS14@SI3AT94AD96<cQ6=T8c@CLe
A3M2=CE6AC93AC53@cPc<3<b>D@aA3Lh<c=3=T@gAT4=@CPf<c0eA4A3@DI4<cLa
@S=3=d8b<c15=c4g<CI5=cDb<CDb@SU1@c4f<C0f=D4a<D=3@d4dASTg=3M43CQ5
>CLa>C=5=c@PCT@=;ePiAB0P<C<e8594838dAD=2A30e<dE2>DHc=SPfA3@g@DA4
A30`>30g<DA5AC0e=c0c<TI5=CDf<TI5A30b@DE2=c4g>C@`<@e4<TE2<STi>D@d
ASE6<4@i>C@bA4=1<dA2ACDc=C4e=CA4>DHd>492=THdA3Pf=S0d>D@a@CHe@c55
<T4=A4Hg<C=2<4H`A48f@dI2A4E2AS<hASI2<d4g=D@g@SDeATDb@dDa@d<h<c0c
<SU4<D@g>3<c@cI4=dI13D4h=S<`=DA4@d56A3<g<D8c@cM2<S<`ACLa=c4fACLe
@T91<c4g=SU5@c0h@c=4>3@f@CHd=cPd<T4h<Pda@CD`>C@c=4<e<d8g=d@dADA3
A4@d=SI3=cI1=c8PCT@=;ePiAR0P<C<b8594838dAD=2A30e<dE2>DHc=SPfA3@g
@DA4A30`>30g<DA5AC0e=c0c<TI5=CDf<TI5A30b@DE2=c4g>C@`<@e4<TE2<STi
>D@dASE6<4@i>C@bA4=1<dA2ACDc=C4e=CA4>DHd>492=THdA3Pf=S0d>D@a@CHe
@c55<T4=A4Hg<C=2<4H`A48f@dI2A4E2AS<hASI2<d4g=D@g@SDeATDb@dDa@d<h
<c0c<SU4<D@g>3<c@cI4=dI13D4h=S<`=DA4@d56A3<g<D8c@cM2<S<`ACLa=c4f
ACLe@T8`@CE6<4=3=T8c<CDd<S4d@c@b=DDb=4E1@Pdc@T51<S15@C4`AC@g=C<a
ASLa=THc<T4PCT@=;eQ1<20P=CTPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=c0f
<C96=S91<CHbA3Hd@T91<44d>D92ADE2ACP`@T@`=3ThAT8i3D8a@dA3@SDcAD@g
<TE2<TDe@cPd@cI4<T51=3@a@THb@T53>4Hb<SQ2<cQ5<cU4>D8`@c=1<4A6ATDP
CT@=;eQ1<B0P<C<b8594838dAD=2A30e<dE2=SDd=TA4@C55<CQ3@S=2<D@c>CH`
=C4g>34f@C0e>451<T54<CL`>3Hg>4E2=S8a<`e3@T<f=SQ1A456=CA4=CHc=cHh
ATDaA3E3AD8h>4Dc<4A1=c=1@SA6A44d<3Df>CA2A3Pg=TDf=30g@D4==3<a<T@`
A3TcA3I3>C53ADDeAD51<c95@SDf>4E4>44g<DI1@CPa>CE2@CM6@SPf=SU4@cU4
>313>DE13D8`=SLg=cTb=c4b=495<c8`AS95<C4a<c52A34f=CA2>38gACI1AC4f
=353<T8a>D52>CP`@C14<CHb=@dh@CE6@d@g<cT`A48e=C8b<cDa<3Lb@dDPCT@=
;eQ1<R0P<CT`8594838dAD=2A30e<dE2>3Le<d=1=4@fASLa<SP`>C<i@CLg=c4a
@T8b=TI3<cDe<S92<3E5<T51@C=3@c95<@e6>D95=d<c<TI3<dHfAT@g@C@d=D54
ATA6=cPh<SPi@S=5@d8`=S0h<4H`<C<g=TE5<SHc=48a<30b@S<=<34b=TA6@c0`
@d<fA30dASE6>456@cLe<cA6=D<b>DDa<cI2<dDd=T94@S93<S<fA44d>DI6ACTf
A3923C<hADA6AS0gAS4f=CLc>CI5<dA1ACE1=C<f=SE1@c4f<S8e@d4i@C@e@CU5
<c0c=CDe<D4e@S4c<SLh<0d`=TI5@TI6>30dASDc=dA2@cHf@dE2A3M6=3E1<3=1
<TE4@D8`<d91ACU5<4Hh>C0e<C15@d94=S0hA3@==S93<S@d<THf=cE2AC0f<34g
>D4d<T=4AS4i@d52=dE3<3<`=355AT94AD8h@S8e=C<f@c4c=S0eA38`3C@b=TDg
=S@i>C8a=S0h@D<`A38b84i43BmH@C<P834e<R1BA20b=4E3@T@`=C=5@SPg=C=3
@CA4=T@dAS11<T8f<SDi=48h<C8h>DE5<cLf@S@c=SA2ASHh=CDd<cLc=cL=<T4`
ACA4@DDdACPb>C56<S53>CU5=D@h>454<3Lg=DHc<SDc<d4e@S<g=3<i=T=3>352
=48c<3Dg@c4e3DE1=3Di<cU3>3=4<S@dACLa<D@i<3Dc<3E3<3E1>C0`@cU3@C4a
<48`>DHbA44gAT92AD<f=3I5=c@a<@df<d4`<3E6>3@a<T@g<CU3@CQ3@c=1@cPc
<S8bA3A6<cI3A34`=C8g<d4e>3Tg<4@e<D8gACDfAS@f<CP=>3M1<CE3<S8a>3M3
ADDe@d@g=SE3>4<i@S54<c<hAS0e<cLg<CA6AT55AD@dA3@`@d53@T<e@d93A3L`
3DE4ASDPCT@=;eQ1=20P<c<e8594838dAD=2A30e<dE2>3Le<d=1=4@fASLiAT96
>CP`<CQ4A48e@T8d@CDb@CTi=CA4A3Db@cD`ASI3@D=3@`e5<S14<d8g>48h>453
=DE4=CLe<c51=CTg<DA6<3@hA48dA3M1@DDe>D56>4@c<4=1=3I1@C4fASLd=TH=
=4<`>4Dg>4A6A3DiA30f=CTb>C12<SA4AT55=S<bASI5=d@dACQ4=T@b@C8a<S<d
@DD`>C52<4@e<3@e3C51>3DeAT<d<d8`<TDc<D8c>C@b=38`<C91AD8g>D8h>3A3
<D94ATE4<TD`@d@h<c<b>C54=T<iA3Tg<Pdd<C8fATH`>30a=D8d<cM5@STdASU6
>38eASM6AS16@d@a<4I2<48b=4E4=3Pb=cA4ACI5@CA6@DE4=d<=@D4fAT8c@c15
<T8c<cE5>315<cD`=394>DE2AD92=S<bACLe@SI2@DI1AD=1>DE2>3<a=3M1>D@d
<4=63C<f>394=SPdAS=6<D@b@S8h=C=2=4<h@dH`<C8c<SLe=cD`@SDaA3T`=SDi
AS<b@dI1=SPg@S@eAD4h=`e4=C4hACDeA3E6=c8`=TI3A4=3=34g=CDb=30d<S@i
@TI1@c<e=SHfA3E1A34c<C@d<3Q6AS0d=cPaAST=<C52=T4h<c@b>D94=d91>CM5
A3L`>4E2=393AD8fA3=4ACA6@STf=S=4ADDb@c0`=cLiAT@g=C@b>CDh3CPi=C16
=S8h>CDc<D<fASLf<CPe<CPcA453AT53AT8bACDh<d91=S8iA30d=3Hf>C=1=c@h
<SDb=3Hg@@dg=T4`=T92=cLe<T4a=T8cAS4i@D=2=cLg>CI5>CM1=S=2@cDiAT<i
AD4b=4De@D@h<d8`@CU6=d8b=3H=>CU1ATDb<C8f@b1>A0d_F44e820a<34PDT@P
<SA5@d94<3DcAD8h=cDc@d4dA3I6>4I6@S=6=d4`@S0g@D94<3=4<D4e<c0d>DE3
@d@c=4=3<CA3<C@h3CU6<C<aACA5>D53A38g=44c@SHf>4DaA48eACM1<D<`<48g
@c91ACDh=T@i<3U3>DA2>C0c<T<d<T@i<`dh<d8c@dHeA3D`=T8d>34i@c4a<cDi
@c@i<d8d>CA4@cA1ASDh=DI1A3LfASDcA30e=S<dA34eASU5=D<==T8a<d8d@S@d
ADE6A3=1=C@e=34d<R1>A0d_F44f820g=b1BA20b=4E3@T@`=C=5@SPg=C=3@CA4
=THgA3Lh@S4d>D8a=SA5AD@d<3@g<D=5=TDhA3A2<3Dd=S<`=3Dh>CP=@D@a<CHg
A48a>3Ld<D=6ADDaAD8b=d92@D@f=3E2ACH`>4E6=c<b=S8g@d8b>C=3AT4f<dHb
=DDc<3Hg3CLh>C@c@CM5AC<cASE1<SHiAD=6A30a<dE6=CDe@D<h<T8PCT@=;eQ1
=b0P<S@e8594838dAD=2A30e<dE2>D=2<STg<T=2<TA6>48dA4A6>D4a@S=6=4=4
=c8c<T4i@T96=T<i@SI2>4I5A44`<`dc@CDf@SM4A4I5=3Le<CQ5=DHd@cDe@TA4
>C0`<SH`ADHa=3<`=TDb=3E1@S56AT8gAC92=3I2=4Db<ST=A4@c<d@b>CLb@CQ3
=34g=DE2ACU2=DHc@SHi@SA6@C92=T<f=3Lb=3M4<c@c@cE5=C8g=T8i@CU2=CDh
3C8bA3E2>4@g=453>3I5<4@`@dDc>3@g=494<d4f=c8g>4Dg<cE1=3Di>3Lh@T8e
AT53<T8bA3@`>C4c@`dh@DA3ASTf<cQ4<dDc>CTc=455>4De@CM5<DI2@d94@dI5
@c<e@SHfA396=d4c@CDc>CHh=T=5<dDh=CP=<SE5>395<c=2@CA2=T=4@S8a@D8h
@CE6=3M4>DE6=d4cAS54A38f<S95>DE4ATI2@c53=d@f<SU4@d<e3CI4A3<e<TA5
=d@`=CTc=34b=S4e<C<bA3U5=TI2=cE2ATDc=4I3ATI1ACHg@CPc<SU4@T8h<d=3
@S<`APdi=TE4>394AC<e@TDf=DHi@SLe<CQ6AS=1=d8eAC0b>DHi=DHfA354@d4g
@cDh<S@e<T51=cE5>311=S0=>4I5>C8i<CDhA21>A0d_F44h820c<C@PDT@P<SA5
@d94<3DcAD92@cHe@c0e>D<gAC8c<4DiA3U3<355<C=3@dA1ADDa<S8g=T4f=D=2
<S=1<30b=4=33CHc<3U1@DA3<D@`=CE3=T92A3U5=c8g>4D`<d4a=D53<CA3AD51
<D51ASPdA313<T<g@D<`ACE2<3Pi<@e6@C@f=cI4AS<i<d4d=SQ5=DI4<CHf=CHc
<cM6<S@e<dHd<C4bAC0b=c4i<S92<c4a>C0gAD@`<3M4=TD=>DHc<T@aAS=4<3Db
=SE3>C4`@D@e@d8d<38`>3Q5<S8h@T8f<CLg=30b<SPdASDe=CI4ACHd>DH`>3Lc
3C@f@CHg@T<`=TA2@CQ6A48e=4Hc=4@h>3@f<THg=SL`@SPeA3Ta<S@a@cU2<3Ld
=CA1A3@bA4HaAT8i=Pe3=c4`<dA2>CI6=CPc>D52>3HdADDh>C8c@cQ4<CDg@c92
=cQ5AS8g@c8h<DDg>DA5@S<e=c<dAS0dA4H=@C0f<S13@d51=T4a<d4d=3U4AT8a
@c53=3Lg<TE2=SHd<d<fA316>DI1A44hACP`=4E5@S4f@cA3@c0`3CP`>495@c12
A34i>3He<T8`AS@f=3Ph=dA4@C4eAC4c=cPc=38bASM6AT<`=TD`A4E1@cM3<D<b
>4E6<`e6=34h@dHi<4<`@c93@TE3A34c>4@h=T@d@S56>4A3<C@e<T8a@S91>CTd
ACPa@TH`@cA6=CQ6>3Pe<c4==c<h<3A3<S51<34bA4HhA34g@cLg>CHi<S8g<cI4
@d53<4=6<S<c=d=6@S4a=4I5@dA4=SPg@dDc>44f3D=6=SPb=DE3=c8h<T<b=dI1
=S4f=3He@SE3>D@PCT@=;eQ1>B0P<SPi8594838dAD=2A30e<dE2@T<f=D<`=CU3
=dE3A4HiAT4h<3Td<c0a<cLd=3HdA4I2=CT`=DDe=d8i@d92>CM1A@d`ASLh>3Pa
>3<c>C96>38`ACPh@cU5<cLi<d8g@d@f<cPe@CQ1ACHcA3Q3>3<f>3@c=3TeASPg
ACE5@SD==THb>4I2>CLb=453AS<f<CA4@SU2<SLh<3M2=48fADI2AS@h<SHaASDf
=cLi<c=1@d=6<c0aA3H`@c8h3CTh<4Hh=C4a=TD`=CHg<cDeACLgA493=DDi@cD`
AT@a=3A1=T54<S8a=C8h>C8gA3Q5@C8eA491=3E6APe6=3<iADI3AT8h@cHc=T95
<THh@C4c=3I2>D@a<3PbA44c>356<d<iA3Hi=3U6>CTf>D4c<cHg<S8hAC<=@CPb
=S@e@D54=T8b@C4i<311<c8fACDcA3M5>38h@S12=CTe@S93=D8d<cU6@SQ2<T<b
=SDh=D<hA3Di3DDh>393>CTh>4I1A3Dh<T@h=SPe=T=4@CLf=38f=T8f@CHiA4@e
=3@dASHg=3I3@S54@T@`AD94=C@eA0db@c0`AC8`=S<a=T<gA4=4=d@a<SM3=SI5
<c15>34e@TE2=dE4>C0d<CU4>CA1@CU3=S@f@SE2AC<h<C<=>3E6<c8d@cHa@DE1
=S8d=d<i<3I1AC4d@S8d=48g>3U5@d@h<3DcA44a=30f<3Tb=CTc>D@b@d92<cHa
3C8eASDf=c@i<S4d@cHc@CLh=cLd>44dA4@iAD8h=34gA3Ti=3Hc84i43BmH@D4P
83P`8594838dAD=2A30e<dE2>4@`>DHfA44d@c4h@TA1>C4`<cTe=d4gAD4bAT<e
>C4g<CHf=S@b@C8`=4=4AC@h@`e3>C=3AS=5>DA2AT4c<CHb>CQ6@c@d=dHeAT@e
<C@e>DDf=c4g>4De=DHc=TA2AT<b<dDcAS12A34d@cH==4<e@SA2<4=3AC8a>DA5
<4@b=4DcADHh<391@CDe@D4g@S<e@T=4<b1>A0d_F452820c<B1BA20b=4E3@T@`
=C=5@SU3@S8i=c93@S0iATDi=C8d@STh=S0c@C4d<cDi=S<e=CQ1A3Lf>D93A3He
=c14<TD=<dHPCT@=;eQ1@b0P<cLPDT@P<SA5@d94<3DcAD8i@d8b>CLb@d8`>D<b
AS=3<4I1>C<h>4=2@T8b=SDfAT=5>3E4<38g=CI1@D<d=d<f3C56<c8c<TE5=3Li
=SM584i43BmH@D@P83La8594838dAD=2A30e<dE2>3Le<d=1=4@fASM5A4A1<SI5
=C4`@c<e>353=dA3@cLgAT=6<T4g<d@d@c<bASQ6<0dd>CTe=D<e@cM6@SDi<S0e
<4E5=d96>3U6>3Hh@cM4<C8`<dDhA4Db<DI2=d4fASA1@cDd>C<i@CU3<4<=A4@e
<395AD4`=C92@c0`@THiAS0aAB1>A0d_F455820g>21BA20b=4E3@T@`=C=5@T92
<CI6@TDb=3Tf>34e=CM6<CE1=C<d@cQ2@d4d<4<i@c0b=SA3<CE1<SM2=34i<C<=
>44h=CHf>4E2@c=3@d96<T8h@TE4@c12>48c>38b=453=d4d@STf<S@g=CLf<c4f
@C@h>D=2=CA5>C8i3CTe=c=5>CTh=C@a>C@`=4Dg@SPb<dE6>C<f=d8g<DE4A3Ha
=21>A0d_F456820b<3<PDT@P<SA5@d94<3DcAD8h<SU5=3@d@S0e=STe@cTi=d95
<T94ADHi>34iASTf<STiASD`@d55@D94A4A5=3Df3CA1=S@e@cTg>C0a=D=3>D@e
<3P`>DE3=d54=3E1=cLg=d92<352=d<b>3M2A4H`>CTa=T@i>C<i=3@f=Pdf<4A1
<c0eA3L`A4HcASLb=dHi@C0c@S0e<453ACTc<C0b<4@b@D8eAC@d<38e=CQ4>3Li
<T=1=T@eA30==D=1AT8c@S4`=dI5>D8e=CH`>351=3U1<S91@C8f=dI6>C8`=cE4
<3Hf>CTcAC4c@D4i<SLbA3Q4AC133D92<DA5ASQ1<D<`>4E6AS<d<D=6=d92=4A6
<CTg<C91@c4h<4A2ASM4ASDhA3U4@ST`=3Q2=S8f<S=3<`dg=D4c@c0b>314<SHc
@S0i=d=5>352<3=3>3DdACHi@S55@d4cADE4A4@b<4<i>CE6ASTe@D8f=CHa>D8=
@DDa<STc@cI4=44b<C4i<30c=D@dAD94>DA4@TI1@SDiA3A5ACDd@D=6=4E1@B1>
A0d_F48`820b=3HPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6>316<c8e>4@c@cDf
@THb=C<a<3Db=T8a@d8a@DI3ADHf=cM5A3<a3CM1A4=1<dHg@cM4=30e<TE6A4H`
ATDe>CDb<3Td<30a@S4aAS14=cA2>D@b=dA5<S@c=4E2=d4`<CDf<0df=3Ti@dDf
=TD`@CPi@T=5=D56<d<d=34g=4<b<cQ2@S<d>D95@CLc=TH`ASTb>34c@S4d@C8e
A3U6<3P=@T8hATHg@D=2=T4d=S<aATHi=SA2ASM5=TE5=SM2<3La>CL`=dI5<T52
@S<i=d<b>44b@CTe@cTaAD@g3D<d<CHi=CPc>CLb=c8i@cLe<SE1AD@g>DA6A356
ACPh@TI2<DDf@cI6@SPf<TI1<d95<38d=cI4=S=5A0e4=4E1=T4g@D<b>DHh<3Le
AT8i@C=6<CTc@cA6@cPi<D4g=3Tg<38cA3M2AC0d<491>CM1<3Hd@CE5AD@=<CPi
=cDb=4<`>494<S0c@C52=D=1<3Lf@c<d@CTc<D95@T8b=cLaA30gAC@a@CDfA391
ASE5@C=2=C133C53@SQ2>30e<4Da<D55AC0cAD4h=d=5>492@CE2ACHf@S<d>3I2
@C<b=4I5=dE1=3Q3=3Lc<315=TE5=Pde<cTbAC<b=CT`<T8PCT@=;eQ2<B0P=S<P
DT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=dE4A3Db@d@g=3<f=3L`>3Q4=cPh<S4`
<38c=THi=3Ti@d55<4923CLd>C4iACPa>DA4>3A1=C0hAD4i@d4d@T56=d4d=4Dh
=C<f=cPa<S4cACDfASE3AD54>CHh=T53ASHd@`db>495=T4PCT@=;eQ2<R0P=CDP
DT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=dE4A3A3A4E6>38eAT4i=CDi=3@b<3E1
ASE1<4H`=C4e<c=6=SI63C51@SDbADHe@S<a>3Dd<TDd<C<c<D4i@dE6>4<b<CDi
<CI4@D@b@SHh>4<fAD96=c8e84i43BmH@S<P83Dd8594838dAD=2A30e<dE2>3Le
<d=1=4@f@cLi<STd>44`@CLd=S51A3Ph>453@c8f=SPh=3@hASA5>494>3=5APdi
=391@CP`<dDa=CPeAT4`ASQ6=TDaASTb>314A3Dc@T4`AD55=c0c<S=1<d54AC8P
CT@=;eQ2=20P>3<PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=c0i=38g<4A1<C<d
<48e=356=CDd=d@i=D92<D8d=3M2@cDc@CTe3CE4<TI3@dA6>34g<T92>D<d>3<i
>D@e>4@e=DI6ASTa>D=6ACTg@cA1<4<a>D@a@TDb@T54=DDd=STc<0e1ATHiASHc
@cDd=S96<CD`<c4hASHh>4Hi@c4f@T@h=351<S@i<3Pd@SLbAS<`84i43BmH@SDP
834a<R1BA20b=4E3@T@`=C=5@SU3@S8i=c93@S<c<dI6=3U3=d4iAS0b@C11=30c
=TDg<STd>48b>D4h>4<g<SU6>C0=@CA2=3@dA4<d=d96>CLe<dE3AD<`ASI1<3=2
@TI4ACQ2=DDb=THh@CI6@D=3A4Dg=c11>3U5<S@a@CPb3C95A48e=CU4ATA2<44g
@TH`AS0c>CPh=D4`A4De=356=cPe@d8`>4I2=4<`@D<g<C8g>C@h<S<`<3<h<`db
=c4gA44g@D92=3<g@d54AS8c>C16<cI1<d8dAS8f=DHg<T8e@DA2A3E2=21>A0d_
F48f820b<3@PDT@P<SA5@d94<3DcAD8h=3Dg<44b<3U6=S53=SI5=T53ADE5>4E5
=C0b=4E1<3@d<4@g@S95=dDe=cHg>D943CDg<34b<48cA4@b=4Hc<3TiA30h<TH`
AC0d=CLb<48hAS8g=cU5<dHi@cI6>DHa=3@c>DI5<CPd@S@f@`dd=4A4ACDhA4<d
<SDbA34cAS0g=4A1@S8gAS11<3HbA3P`<356<S4cAD<c=C4d@c<`<CLf=D54@d@b
@T8==S96@d<a<3@a<4<iACHa<CA5ADDe=3I5<THa=D53>3@a=SLi<CLgASA3<TDh
@S94AC<e=C4d<T4g@S963DHd<d4b>34dA34i=3He>D4iA4De@d54=3La@d@f=CHh
>3@f=D4cAD53@CM5<d8dADA4<C=6>3=3=4Dg=@d`@T@d@DHh@D4f@c91>3=6@cI2
@S@g@CA1ACTc=4D`AS@b<C<d=SPi>CPaA354A4DgA3Te@T8g<30aACD=ASTe<S8i
<4HhACPc<S94=c8e@c<g@T52>3Pa=c=5ASLiASA4<T8b<C=5@T@h@D9584i43BmH
@SLP83Dg8594838dAD=2A30e<dE2>DA1<c0b<C@b<dA5=T4d@c0fADI6=3@`002Q
0<0ood@i<T8d=dE6>D95A4<h=451>3Tb=D95@T<=@T=6=3Dg<D4e<SU4=C4c=S@c
<3M1AC52@cU4<T<f=314AD8`=D4h>3Pi>4Hb>3Q1@C0`@THf84i43BmH@SPP83@g
8594838dAD=2A30e<dE2>4E4ASTg@dDe>DHaAC15=TDi>3U1@SM4=D<f>C0`=cA3
=T<h=dHe=3A1<T53@dI2A@dc=S<a=d92>C4`A4I6<3Te@c4`=d4h>D@f<C0`<3Lc
=C1384i43BmH@STP83Pi8594838dAD=2A30e<dE2>356A3@f@S0e=cDiA3@f>CI4
=454=3Q6A4A3<SI2=d55>4HiAS=3<dI1<S0d@cM1=`e2AC8hA34f<CLb@SPi>D52
=C<aA3@`<4A1>C<d<3Ph@dD`<4E2@cQ6<CPiASM1@S4e<T8bAT91=3U6ASL=@c11
>CA5AT=4=STc=T=2<4HcAC8f=311>312=D8c@CTb<4HcA3Hb<T8hAD@e@c=4=d4h
=d<b<3@iAR1>A0d_F491820b<CHPDT@P<SA5@d94<3DcAD8i@SL`>CT`<CA6=CM3
=c91A44`ACHh=4HdAT@hA3L`<S@c<CPbA3M5@cH`=d8a@S0d3D8`=d<g=S16<cQ6
@SPa<THd@T8e<DA1ASDe<3M4<cT`>3Hc=DHe@T8d@cA6@C@h>C0c<c0i=3D`<d<d
=0di>3A3=3A3<d@f@C4`>4D`<3Th>C8g@D@g@T53>4Hd=cHaACPh@cDe<452ACU5
=SLe<S4a=d<aATHf>D<==353=DA5A44`<30d<d@a=SHe>3M3A4<c<3I1<d92@T@g
<393ACM6>454=4<aACM4@DE2@D<i<cTa<cPe3CE6=dE6=3E2=T54<D91=dA3@dDc
=D<d>CPd=c8c<c=5<D55ASI2@c15>48`=T95ADE2@TA3AS92ADDfA0df@T54<CDd
@d4iA4=5<3<`<T4`@STg<SLbATHf=cM2@S<g<351<CDc<T<f<3@`>4E3=CA2>CLf
=cA5AT8=@T=3<cHa=dA4<d4i<SA2@S8i=c<b>3A3@S53@CP`=DI6<SDb=T8f>CDa
<392<C0`AT52=CI1=c<c<T8d3C4i=c8`<c8a@c4b=R1>A0d_F492820b<C4PDT@P
<SA5@d94<3DcAD8f=D=4>D8a<C@dAC4c>315<d4a=cDc=T@f<S56A3Lf@S0c=D53
<S<h>C=2<CHi<SDe3CLf<d8a<D4g<cH`=D<a=cHf>4HcASDg@CQ4=S=2=48iAS8f
A3E6<dA4=C4e=dE4>3A1=D@a>3A3@SPi<@e3<c16A313<DA3<CTc@CHi=C8h@SDa
<CM6@dHgA34f>D91=D8c>3ThA495<3Tc>C=5<d4d=cHh>DHc=cT==3A3>4E4@TA2
=3U6<312>CDcAC<f<30gA3LcA3=3<cLb@S0f<DDb=3Pc=c54@C@e@TI3AC@hACTb
=cPg3CI1=d4f=4@a<38c>C8c<S96<4A2AC56@CHe=3@i=dDg=T8h=T8d<S16@c4h
=T@f>4<`@SPh@T<g=4D`@PdcASHi>DHa<34d>4Hi=4A6<C@h@SHhAC12=3Tg=TI6
>3<i<3Td@SD`ATHi<cTd=D<d<d4e>44eA3@f>3@=>C@g=SPe=THcASLh=d4a<CDh
<dA3<S93=D<b<S=4A3Q4=SDcAC8b<44a=DHa@cHa>CQ1@S@d=cLh=CHh3D@g84i4
3BmH@T<P834c<R1BA20b=4E3@T@`=C=5@STbASDg=c<g@C<eA4=3@cM1ATA3<cA4
=3U4A4I2>4<i=SLf=d95A356@CDgAT<cAS4=<34`<C4fAC8d@c54>4A4<30c@CP`
@c@i=c@h<T8fA396AD@h@CA3AC<cA3E4@TE6@C0b=cQ2>CTi@cHd3DHcADHf>34h
=TE2AS4`ATE1@dHg<d=3<SHh@CU2@T96<d<`AS0bAC<d<d8h=D<c<TDc<C8b<313
<TE6<Pdi<T<f>30g@SA5<CU6<C<a=cI1ACQ5A4Db@CA6@SDb=30`@d8f>C55<T52
>44i=C4cAS<c<3M5=3A3=T@=@d8i<S56<cE2=cLe<C@d@SU1@SI1@SHa84i43BmH
@T@P834g=B1BA20b=4E3@T@`=C=5@SQ5A4Hi=d=5=CU6@D@e<T<aATDa@CTgACI6
@CTe=4H`=CHhA393=C<hA3U2@dI6<CL=@TA3<cPdASU1>D@c=C@g<C4f@TDb@cHd
<38gAS=1<cU1>CTa@S4i<cLfA3Pc<C53=T8a<4I4>DA3@cA23DHf=c15<C@h=S55
<c@b@dHf<cI2@c8g@D<cAS52>C96@S52=3I5@d94<DHd<c0b=352@S0cAT8a<STh
=@e3AD8b=C=5=dA4=d4d=D<g=c<cA4<d<DA6AC0`ADA2=CI2@S8f<392=4<h@SI6
<d4g=CPf<d4f<CM1@S<=@STe@C0b@SLb=C4`=S0b>CA1@SI2<T4h>3DcATDi@d<a
A4A6ACPc@D8g<c4g=3HdAC4b=D<a=D8gAC123C54>355=cPa>C11<4I5=34i>CPg
=3Da=DHi=34a>C8iA4<d<TDa<DI4<3Di<c0d=38a84i43BmH@TDP83<f<R1BA20b
=4E3@T@`=C=5@T96<DH`=DHh=CA3<3Pc=CM6<D53=TI6@D4gA3=2<d4iA30e=cPd
>DHiA3E1AS8a@c<=@STi@SDg=SE6<3U6@CLa=cQ1=c@i<3Q6@CQ3ASTg=d=2=TE3
@C8g<T=4A394=T@h=T=1=TI2@CP`@TE53D<f=C4aA3T`=d4h=3=2=C@h<453=c0d
>3Tc>DDdA48e@C<i>CTh=dE1AC54@cHe@DDc<S4h@T51@C4`@@db=454A4<e=3I4
>4<`>C<`<cDg<4<d=456<SLcAS<fAS96ACA5@DA1@T4i<C4g>DHb=c=3AC<g<C53
<c<=>C8f<CQ2=C<d@d8f<S=3>48g@T@fAS@i<d<g@SHh<D8a@c95=CE4AC@e=CE1
=4=4@S<e@cA3=d@dASI13CE5ASDg=CTc<CPc=c0i<C0eA3Ph=d@`<4@h>CTf=SU2
@S=5<C=5AC12<S11=3<g@c8e<3=5@CE1AC0bA@df<DE2>CQ5ADDh<34`=C8b>D8f
<CPg@d=4=D91<cE3AS0b@DHg@T@i<DHi>CDdASA2<CPc=D<b@D96@c0=@S<g<STf
<THe=4A5@c92<c<fATDh<S54=dH`=c8g=cHi>C15=TA3<cU5=c0`=S@i@cLaAD=6
=313>DA23C0i<3A6ADI5>4@cA48gAD54AC0`>3A3=c<f<D<d=SDg=4Dd<STh@SLf
<D95>3U5@T55<cA4=CE6A3LcAPde=CM2A3P`=cHc>3Da@CTb<T8`=3Pf=c14@T93
=THg=d@`=T8g@S55@DDb<cA4>C=5<dI3=3@h@c@i>4@=<D=2A4@`=C<g=c@`=CHf
>394=S<h<c=3<S0`<C<f@DA1=3A5@CPi@DHa=D@i<S55=3Ta<cH`A3Hg@C933C8e
<dHf<TE4ACDdAS8a<D4b<TDe<d8h@T55=T8a=cHf=c0`>DE2>4<bA4Hb=S4e<DHd
<CL`<THb@DHf<Pe4>48`84i43BmH@THP834g>B1BA20b=4E3@T@`=C=5@SU4@C<`
<S4d<S<b=492@dA5A44eACQ5=C<bASHb>34e@SHh@SM3AC@f=48a>30eA4H=@CPf
AS4a@cLb=C<gAS<g@c0e=CU3=T91=3<g<SDe@CD`AC0e<c0e<3A2=3Ti>3Q1=SM3
<4@c<d95=CA23C92@c55<d4`=CTi>DDa<CTa=D56@CM4=CLg=CU5A3Pf@cLfA3E5
<cE1@D<e>CI3<S91@THf@TDc<T4aA0deAS16@T@b<d8bA3U2@C@i<SPd=d8`@C=5
@dDh=cLd=S=6<DHh>38f@d4f<d@h=SM1<C4a<dHg@D@b@ST=ACD`=3T`=C<b=T4i
<CLa>48f=30a=DDc@c@`@D@`A3@b=3Q1ADDeAD@gAC<h@S8e=T4`<dDf@SH`>CU3
3D4e>4De@SLd<CD`>4I2@c=3<d4h@SA2<T<e@S<e<d96>D@h>D<`=T4a@cM1@cPc
AC<e=c@d>CQ2@SPPCT@=;eQ3<20P<CLc8594838dAD=2A30e<dE2>DDd=30a<SDg
>DA4=cE4>3@iACE5@T=4@c<f<cL`<30b<STg@D@b@DE4<D<`@c8c>@dh@C@e<c8f
AS11=d8hASE1<CDc=c0f<d<a<S0f>CQ2=cU6=c8`@T=1<dE1@S94ACA2=cQ3ATHd
=d@b=4H=<48g<S@c@SA6@SU4=SHa=c4h<4I5@C<d=c92A38h=C8b=3<eACE3<S<c
A44i=D4eA3I2=3<d<SA3=c0d3C4`=STi=d94>CLf>4@fA4E2@THb=c0i@S0h=DDi
>CPi<d96>4@`>DE5ASHd=3A5<3@a<dHd<T4hAS=2>@dc>3HaA44e<44d=CT`<4@f
<S0c<C@g>30`=S13@ST`=4<e@C4d=S0iA3@h>4<e<4@g@DI4>3H`=dA3>D4=A4E4
@cE4@DHg=3Q5=3Pb@C<e=C8aA4H`@D@e@d92@CU3>3<a<3HbAT4b<3Ld@R1>A0d_
F4<a820d<R1BA20b=4E3@T@`=C=5@SHgAC<c=T51=3Lb<S92<STe>3PgA38fAC4b
<S@`<dDi<dHe@C4h<3@cA3=4A3I2<d<=@c<h@S0e>DHdAS<c@cHe<THe<TA3@S4c
84i43BmH@c8P83<c8594838dAD=2A30e<dE2>3Le<d=1=4@fASM5A4A1>DA6<30g
<S8`>452=SDi=S11>CLb@D=6@S8b@S0aA3M3@Pe3=3<b>3<PCT@=;eQ3<b0P=C0P
DT@P<SA5@d94<3DcAD92A3=3<CE4>CI3AD<eAT<gA4E3=SQ6=T56<34b>3Lg=48f
A3I5=DA6=SM4>C0c>C0a3C8cA3U4<dDb@d94>4A3=cPd>CPi<44d@d95<38c@S54
@D=6>CPb@CLPCT@=;eQ3=20P>C4PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6>3U2
=C8c>CDb<cI6=C@`<DA5>3Te>CE1A3Ld@DE4@d4d=3Pg<d@g3D<g=CHa<D<e<dE4
@T@cASU4=DHeA3=3<38c@DH`AT@a=D<f=C4eA3I2@c@c=cHeAT@fA3=5>CPd<3Q4
@@dg=4Dd<T8b=C4bACM1@D4cADHh@DI2>3Lf=c8i@DE3>C@h=34fA451ACE6<SPb
<cDf<CPg@CI5=CTh@SH==d@PCT@=;eQ3=B0P<SHe8594838dAD=2A30e<dE2>3Le
<d=1=4@f@cLi@CDi=48g<S4c>C16@C0i<T<`AC@bA3<bACDf>D<iA316>DDf@Pe2
@cPe=c0a=cThASM2>DDc<38a=dHh>3=4@cTe<4<`ADHc<3DiAT@fACI1ADHf@C8g
A456AS8c@C4aA30=@S0c@c4d=SHg<CTcAD52<cA1=S0a<SL`=CTe>D4a=3M4A3De
<CA6=C4iADI6=SA6<D4g=S@cA3PeA3@i3D4c=3Q4=CI5=c<`=d56@SD`<T51@cDd
<T4h<SPa<CM3<CPi<CHf<4Hd>CHhAD8b<4Hb=3@f@CDc@dE6<`dh<C8g@S<b@TI1
=S@e=D4aASE6@cPa@SM5<44b@THb>30b<T8e=SA2<dDa=c@h@T4i<C0i<C<e<C0f
>CP=>CTfACDa=CP`A4@`<TA2A48c@TA4=3U1@c8a<d<aA3L`@cLd=3=5<S0c=SQ3
=D92=391<D=5<cLd@SI13DA2=DA2<cI3>396=DI6@d4i@SDe>DE1A3A2@c4f@SHd
@TDf=S0e@SDd>DA1=44i=CM6<dI5=3E6A3Pi=`d`=SDa<S11A453A453ADI4<cE2
A493<T94<3A3<3Pd=c4f<4=5<456=D4a>3T`<dI4<D96=4Hi@cA3@D8=>3Ph@DHe
=T4dA4@c@c0f<S8`AS0`@T52<SDb=cPb@CLd=4=2>CLf>3Q5=3E6<c14>D<PCT@=
;eQ3=R0P=C0PDT@P<SA5@d94<3DcAD8hA30iASI4@C@iASE5@S4eA34f<CE1>CHa
AC<iACDa@C56=SU6=3Lc>4DgA3Pe=SLe3D4e=C@c<T=2<d4fAS4d=SLc>315<CA1
A48`@cDbAD=3A312=4@gA30PCT@=;eQ3=b0P=c<PDT@P<SA5@d94<3DcAD8i>38d
@C0f=3Tf>CM5>C0g@d4d@d<d>3Dh@d<e<c93@T96=S<bAT<dA38fADE1>CLe3DI5
@cDh<3A2<STd<4A1@D52<44h>C8e<DI4@T@a@TA4@CPc@C=5<C8i=3@b=3Lg@DHi
<34b<c4c@C11@PddADHa=TE5AD94=3U3@T53A3La@DE6=D93AB1>A0d_F4<h820g
<b1BA20b=4E3@T@`=C=5@STh<SA1<3Hd>CHi@c4i>C93>CE2AD@hAD=2<CU1<3A4
>4Dg@SQ3=3@h=DD`@c4c<D8=<cHi>314A3@d<TA5@C16<D8c=C4f<3Lf=S@c@TA6
@DD`=DI5<C4e>4=3>34i=CE6<cLh@cHfA356ADI23CTb=4E5<DDb>4@e@C8e<S8g
<TA5@cDb=T4g84i43BmH@cTP83Di8594838dAD=2A30e<dE2@SE6=4E1AT@f>C@b
>30f@CLd@dA4AT@c>453@D=2<S0i>30d>4A3ACDe@cPg=S8a@`e5<T@`=T4i>C4f
=d=3>34e>C51ACHi<c0f=S0e>D95@TDh=dHfA3@e=C@gASI1=493<4He=d<a>4<c
84i43BmH@d4P834b8594838dAD=2A30e<dE2>3Le<d=1=4@f<3I3=B1>A0d_F4=2
820h<21BA20b=4E3@T@`=C=5@SPc<CDa>C55AS0i<C<e=DDf<c4iA3=6>C4a<3Df
<D=5=44b@THh=THg=d@g<D8a@C<=>C=6=DDa=4E4=T<g@c=3=d<b<SU1<cM6A4Dc
=3Lh@S=3@S93<C0gATHc=c91=D<d<cHc>38a<S0c=STc3D8i=44e<D<i@THi<D4i
@T8i@c52<3Pb@SQ2@d@g@SI2@T93=CLc=c0PCT@=;eQ3@b0P<CHi8594838dAD=2
A30e<dE2>3<a=C4i<DE6<3Ta<cDeACHc<CU4<dHi<C4`=CHa@dDd@C92ASPfASLg
A3La@S51<`di<dHeAC4dAD@f@cM3<d<g@c8b>D4c=dI4AC<d=cQ2<d=2<T<a<3M6
AS<g<T4e@c@c=S<h<S4b<3<f>34=@d@c=S95<T@gADA6@cM1<c0g=S0g=S<h=4<b
<C4`=CQ3<30f=cPaASE3<48h=C0b>30d>C0c>48d>4<d3CE6A452<CE1>4Dh<DDi
AC8c<d8bAT53=cA2A3Dg>4<cADHf<dHd<SLiAT@c=3LfA4Db<S15<C@a<C4g=0e1
=4Hg=d51>34b@dD`=3Pi>496=SLi=CQ2>355@C<cA30d=3A3@CTb<3M1=c<`A4Dc
=355>3M3=CDc<3L==c14=c0b<SLi@cQ6=D8dADDf<c@b<TE1@d95=T91@SQ4<c4a
<4HPCT@=;eQ3A20P<S@d8594838dAD=2A30e<dE2>38iAC@d=48`=CU6>CE1<D@d
<DI5@c0eAD4b<T51<CU4<cA2=D4`@S=3=dDb<30a<Pe4<S53=c51>3U2@THb>C8g
>3Q3<cPb=cM6=c91=4HaADHhASD`<34eASLe<C0aADHbASU1>3Q4A30aA3T=AD51
>C55@C92AD8g<4Hb>44f<T@dACPa<C4c>353@CLi=d<f<3HhA3Lh@S0g<d4i=T4d
=DE1=3Dg<C=23D@d@S@`=492@d=5@D8b=S@d>C@e=TDc<c8i@cHa>392ADDd=TDc
@SLcAS@cAC0i@S0e<c51ADDd<d54=`deACLc<3@hAT4b<D8bAS8g<S11<C8h>C@f
>3Hc<c0a>315<CQ5<S4a<THd=SM1<C4e@CT`ACE3<3HdACH=<c8c=S0d<d4`=48g
A451=4@gASTe<STf<SHb<SE5@d53=44h<cDbASHh=S0e>CDiASDa<dHe<DE5=C51
3DHg<cE4=3<d@C0fAC8`=cTf@CPfACQ5@STh<C=3=3@c<D<a@D@a<C0h@C=6=cHf
>C@c=DHi=S94@CTbAPda<SQ4@dHg<CU3AS<h<4=6>30i<c15=C@d>3TfASPf@d=4
<TA2<S=1@S@`@cDg<CI2>3Lh@TE3ASQ5=c<==3<d=c=2<4<PCT@=;eQ3AB0P<CHh
8594838dAD=2A30e<dE2@S4b<S55<SI6@d=4>4E2>CM4@S<f<34g@dE1=48d=S4f
ATHaAT<g@cLf<c@f=T<d=Pdi=cE2<3Hd=ST`<SA5<4=2=D91>311>CDf=3E5<3Pd
ACHg<C95AS0c>44e=CHdA4Dh<T51<4Df=D=2<D4=>CDg@D4g=cTh@d8cAC4bA4@a
@c=1@dE6<T@d<C91@T@aAC=1=3<h>D4f=TA1<STbAS<e=4<i<4A1=S8b3C4a<SPa
@dDdA3Dh=C96ASI2>3Td=S@b@c8a@C<i=4E3>3A3=dD`<SPe>DDg<D4g<CPa>30g
ASM6=4I4A0dfACHg=3E5>C4aA34i>CA5=CTi=T<f>DE1=44h=D4b<4E5=SU1@CE5
<dI6A4=4=S4i<48c=CPcA4HbAC<=@DHc=T8d<SA1=CTbAS0fATHh=D4b=30a<cHg
=C8f=T4b@cHa84i43BmH@dHP838h<b1BA20b=4E3@T@`=C=5@T92A30b<3D`>D@g
<C0`=D<f@cHd@cDe@c56A38f<3I4>C<aA30c=cDi=4=1=C<iA3L==T8b>D=6@d8a
=cE4@cA4<S55=d4d>D51=3Pe@CDhACPf<S<g=34e=D8f>C8h=38a>4=1<S92=30h
=DHh3C95A3DgAD8h=4Da=SLiACPf<CP`@d=1=3@f=d@`<DI2<THa=DDc=311<T@i
=C4d@SDg@CE4=T4d@d@h=@e5<48i<3=3@SHh=C4`ASDa@cLa>44`@S0f<S0`AD<c
<C13=T91=3Da@CQ5=C<c=3M6>CHb@SQ4@dI6@C0=<3<d=THd>DA5@DDc=cPe=C4`
>DE6=SPfASM4>D54AC=6=CDf=3Hi=d@e<d4`AT<a@T<a>4Hg=D=6=3Q33CPg<cPa
@cPc<cDcAD54=4E6=CI5=cI3@d8`@SLh=c@a<cDh>311<TDc<3Pa<d@`A30d@STh
@CTc=SDc@@e3@c<g=30a<STb=DA6@S8a=cI1ACM1>456=d8f=T51<cE6A4@b=d<g
ADDa=D95<CTiA4=5AT92=c0h>4<=>3Q5<CDg>CI1@S96@CHeACU1=THf@DA1=4<b
<4@hASLi<4Hd=d@a@cM2=S4g>C0b@c<f<d=3A4Hh=THd3D=5@SI4=CLg<cHf<C<`
>3@eAT8f@CDhAC0cA3<a=TE2<d51=3=4<DA3=C8dAT<b@D<f=3Q2>3=6=d92<Pd`
@T8f<CU1>4=2@d4`@C@d<S52A456<S<f>21>A0d_F4@`820b=R1BA20b=4E3@T@`
=C=5@SU2ASM1>3M4>CU1ACM4>D<b@c4e<S=6<c8f>3U2@DI6=d=5ADA2@d=684i4
3BmHA34P838f8594838dAD=2A30e<dE2@SE6=4E1AT@f@d53<c0h=C0b<CE3@cLi
=4@g<T<d@S94AC0a=3@b=48PCT@=;eQ4<R0P<C8i8594838dAD=2A30e<dE2>D4h
ACI3>4I5>CM4=d=3AS=1AT<c@D<`<SQ1@cPd<CPh=S95AD95@c51@CHg<d@d=`da
=4@h<C<c<cQ2=TDbACU6=c0i@C4d>48g>D@iA3@a<SA6ACA6@SPbAS95@dDd=c55
>CHi<CHi=CLdACL==SE4<DA4=T91>311>3A5<3U5=CQ2>DHc@SLd=CA4@DHf<T51
A3Hi@T95=CDd<dDgAT8c@S4i=d92AS@i3CLh@C0g<SHi=D8dAS95@d4c=C95ASQ1
=SHh@SDfA3@h@C4c=d=5@D@e<S0c@cU3ACI1AC8e=D<h<S@i<Pdd@cTiATHbAC8c
@c=3<c0`>4@PCT@=;eQ4<b0P<C8h8594838dAD=2A30e<dE2>D4hACI3>4I5>4@a
=D=5>316@C12>4I5@cLi>CP`@SLi<cLe@dD`@SA2@C4e<4@f<@e3@d@a<STi@cPi
>DI3@D4g=STa<DA2<CU3<cTf>396@dDf@TDe<C14@d4a@DHh=T56<T4e<C@i<T56
>38=<S<`=D4f=DI2AT=3@cM2=44a<d@b>3Lb@SLh>4Df>3@`<cM4>4@f@d@`<C<f
>CTgADI5A3U3=352AT8c3C<a=44hAS96AD8h<dA2=cA2<CLgAC<a<S=6AC8g<dDa
<3Di<S=2=cHg=CE6=4@a@C0i<315>3Tb@CTdAPdg<dHi>3L`<CDc>D53<THe84i4
3BmHA3@P83La8594838dAD=2A30e<dE2=SM5<c<f@D4d=c4f=dHf<30cAS0f<S93
AS0g>3Tb=48i<D94=3@b=351@c0i<dDdA0d`<3Q5<4H`=DA5<cPc=cM6@S8c=3@d
@D@g@CD`ACHa>DE6AT55>3U3=S0a<THf@c16=cHf@SLhACU4>38==S8a@d<h<STa
A38`@CTh=C0eA4@h=b1>A0d_F4@e820g<21BA20b=4E3@T@`=C=5@SHgAC<c=T51
=3Hd=SPh=d55>48i=3I3@D<e<3Q5=C56>C<iAC95<CQ1<dI3<S16=D8=<CTc=c<f
>4@b=C<gA3@i<d@f@CLg<cLa<D92@c=1=d@f@d<i<CTa=S51=DA3ACE1<C<g@D4d
<C54<S0g3C0eAC91@d@e@DI3A3<f<d91>3=384i43BmHA3HP83Dc8594838dAD=2
A30e<dE2>3Le<d=1=4@fASM5A4A1>DA6<4<cAS94<C0g<3=2<T@i>D92<351<S51
=STd@S0eAPda@SLg@cP`@T<cA34c>3Pg=T8aA3Df<cA6=d4`=cTd=SA5@cTa@D=5
A454<S1484i43BmHA3LP83H`8594838dAD=2A30e<dE2>3Le<d=1=4@fASM5A4@e
=351=4I3=T<a=3Ti<C0a>DDiA356@S<`<C=2=S4dAD<eAPe6=CM1=D93ASTc>3@b
<CTgAT@g<3<f>4E4<cU5AC<h>38gA3LeAT4`<cQ6>3DgAT95A30eAD8f=T<f@D8P
CT@=;eQ4>20P<C4f8594838dAD=2A30e<dE2>DHh=S16@dE1=T<b>3A1=cTf<S0d
=S53>34g<CHf<T56>3Ph>3Hf<cU1=c12@d=5=`e5=44`<cHd>C@f=D=6ASTa@S0h
@CA2>C=3AD8e<D@a>D8e>3Te=STa@d<a@D@`=c<g=c0f=4Db=3=4@S0=>D4h@d=3
ASDg>CDb<C0f>CLc<SA3>3U6<T8h<c@hAD<h=D4b=S4h=TA3A34b<T=3A4Ha>4Dc
<4He>3Q43D@f<T8eA3Te<D<i=T@b<C4a>CP`A48hAD=6@THg>4=6=CTc=C4a=TE1
=3<d<S<gAT54A3TPCT@=;eQ4>B0P=c@PDT@P<SA5@d94<3DcAD8iA4Dg@S0f@CPg
=SDe@TD`@d92=34g>C4dA34`>DA5A4Dh>CI2@C16AD93@d<c@SDd3CPi<d96<C=2
<3Q6=SPf<48h>3@i<D92>3M1@cA1=T@eATA1=c13<TI5<d<aAC=2ACM4ASM1<CHa
=TE3=0dcADHa<CTa<STaAC8e<4I1<4<d=SLb<355A3Lb84i43BmHA44P838i8594
838dAD=2A30e<dE2<4E2<4Hc@DA5>D91<c52<d8d=c<h@C4g>3Ha@D55<cHdA3T`
AD8a<C8g@C=5>C<PCT@=;eQ4@R0P<C<i8594838dAD=2A30e<dE2>38f=c<f>CPh
>C13AD@b=DI4ACHi@dHb>CPi@T8e>D92ASPb<D94=SQ1@CTbA4<`A0dcAD8c=dDf
<44aA48b@D55<44g@c8h>CD`<c0g=30h<C8`A38f<311@CTh@C@aAC4a>CI5@CTa
<4<b@S@=@SA4<dD`@C0`@SLd<T8`<SLa@c=4=44i>DHh=c4e@T<`=CE5<DHd=c<f
=dI3@SA6A38f=4A4A3H`<dDf3CE2<TA6=cHe=d8b=T95<CPa=C4a@C54<S=3=c93
=C@b<dDf=CQ6AT@c@cA5AC0c=c=2<SHb=S0h>C4bA@de<cI3@S12@SU6A396@CM2
@DHi>CI6<3E4ASHh<CQ4ACLa<D@e=21>A0d_F4A3820d<b1BA20b=4E3@T@`=C=5
@SHf@TDa<c4c>34c<3<i<T<i=4Dd@TH`=T@i=cM3@T=4>CA6A3Hh<3=1A34gA48e
>48=<THh<SM3@C52=cM3<30f=S=5=TDfACM1AT8PCT@=;eQ4A20P=3<PDT@P<SA5
@d94<3DcAD8f=T95<C<a<cPa<c@hATE2>3<b<cP`=SM2<3Ld@SE1=dE6<3I6=dI2
=CHi<c4f<THb3D96AT55>CLc@d@d@SA6@dDf@SL`<C96>C0d84i43BmHA4DP83Ta
8594838dAD=2A30e<dE2>D<c@T<b=CU4@DHa=4Da@T95>D4i=T@e<D@a<D=6<c<e
<C8e=C8e>3@i<d92@cLbA0e6=cTb=C95@C14<cQ5>CD`=SDd@SPd>3@h<D91<3Q6
@c@h=353A392>392=D@d<T8b@c14@CM5ADH`=DD=@dE1AS51<4<d=C4`ATHa@C@b
<CHe<C4c<CHd<SE5<T@c=4<d@SH`AT=1=DHh<T8`<3Pe=C@a<38`@DI33CTf84i4
3BmHA4HP834`<21BA20b=4E3@T@`=C=5@SU3<d93<SDiA456=c<f>D4`=3E4AC<g
@d52<SLi<D54=493<D<h<T8h<cI6=SPe@C8==cA1=d4i=CM4@C<i=cM2<D92@C<c
ACA1ATHi@cA4<3P`<44i@cA2=3=5ASA4<T94<CA6@ST`>396@CH`3D4e<D<eA3De
<c96<456@dI1>C@`@d=5=4=3=c=4ACA2@D@c=T<dAT<aA3Lf@CPhATDf>4E5@CU4
@T93=0dhAS13ACTi@T<fA3Lc@T8d=SM5<B1>A0d_F4D`820h=b1BA20b=4E3@T@`
=C=5@SPg=C=3@CA4=THg<3Ha<THf<T4a=S95<cHc<T4iAC<d@CQ6=TDa<T54=3M5
<SQ1=CP=<3Hb=3@`=DI4<c16@S@d=CHhASDb<SPc=D8e>3I3A3Dh>D=4<CDi<C94
=3<`=DDe=d4gA34dAD<i>CE33CDf=c93>353<SPc=S8`<SH`=SPi<D<g<CU5<SA6
A34d>D@aACDcAC0e@CI1=cLc=30e<C=5<R1>A0d_F4Da820b>B1BA20b=4E3@T@`
=C=5@SPg=C=3@CA4=THh=4Hi=c8dAC@c@T<i=3U5=c53>3Lh@STd=SQ2<d8e=T@c
ACA484i43BmHAC8P83L`8594838dAD=2A30e<dE2=SM5<c<f@D4d=S@f@S<h@c<h
@C<f<cD`A4=3ATHgADHeA3LiA3I6<C4c@D96<3A3>0daA3M3@TA6=d<g<4=2@dI4
>38bATI3=CHi@c@a>4I3=3Pb@SHg<4DfA3Lf=c<g<dE3<C96A496<3Ti@c8==D4i
@c<bACM6@cLa=CHa<SQ2=D<PCT@=;eQ5<b0P<C8h8594838dAD=2A30e<dE2>D4h
ACI3>4I5>4@a=T<g>DE2=dHc@S4b=3Dh>DI6@DHd>CLc<d<b<SQ6<S@d=SDb@@e6
<44b=4@fAS0i>3@iA3E4<CA5=cQ6ADA5ASLeAD=2=cE6=cTh<38gA4Hd>4<a<SDa
=3Pa<T8dASE1>CP=>DHi<3@cATI6@D@h=3LhA4@c<cI3<SU4=CPc@D56AS<f=3Lg
>34h<CDd>4A5@CLe<DE6<c0h>3@d@SLg3C0d=C0b=3Q3=TA1@S0dASU3ADA5AC4c
=3A6@STg@c92=SU6A492<S<`AC<f=S8h<c13=3@b=d8g=SM5<0e2<c0f<351=C8e
A3Tc>39684i43BmHAC@P83<i<b1BA20b=4E3@T@`=C=5@TDc<393<C=4=455=D56
=C=4@SLe<4HhA44e@D8g=DDe@cA3<S96<c8e=D54=d4c@d8=<SHh>DE3AT@gASPd
=3@e<CM1<3DgA3HbATHc=c@f@CPc@cPbA4@dACTc@d55=491@cPeA3Pa=38d@TE3
3D8b<DA2AS@e=dI4@cHhAC8eA38`=cDg@c8g<CM4=S8h>C0iA3Dc@cLbAD8f<3<g
AT51=3Di>DI4=3E1A@e1<4@i@c16=CI4<C4g@S4e>4Hf<C14>353<c4b@c=1>DA6
>3@eASA2AS51<C@b>CTf>C0a>3Pi=S4f=CL=>391=S=6<4Dg@SI4@D96=D51@TI4
AS53AC14@C4c@dDe@C54>3A1<314AS4g=T@bA3<b=cTf=CM6=4943DI3<cLg<DDa
@cM2<T<`A393<SQ6<CT`<S0c=d<e=3TcAT4h@cTb=S4fAC8`=3=2>C=1@CM6A48e
@CDh=0e6<CTg=T@h=c8a@TDc<C93<SPg=T8cA44a<c@`A34d@THb@d4h>4E1=SDi
>C@c=T<`@T4f>3Hd>DE2AC<=@C56>48i=493@d@h=4A3A44a@d8f@CDd=cPhAS8f
<4Hc=D4h<TE5=THf>4@g=CHd<352>CE6@SDb=d@c3DA5AD@f<S<`>D4c@C8b=DA5
@DE6<CA3=SA5<CLc<T4d=48hA4A5<SPg@C52@d54ACQ5<CHiA4@aAS=1<Pdg@C<h
>C4e=452@c12=4E4=CI3>4@g<d<b<S<hA3Hh<4@d@TDe<3U4AC@a@SI5=3Lc=3=2
>DDc=cM1A48=<c<d=T<`A3Hg=dHd<4E2=S=6<3A1A44f=TI5=CM6=THc=SQ4AD8h
@c52>CDe@T54A3Hh@CLf<3<h=d8c3CDcACTcACHcA454>C0i@d51ACM3@SDaAT@e
A4<hAT@f=4Hh<3Da=T4d<S@f=SDh@T92@S<i@DI2=DDf<`e1>C=1=354<S<fA3I4
<THg@SI6=3A5=T8b>4E6AT4a@c94>4De<C4c<d52<cPi<CHe@DHf<S8i<d52=SH=
ACDf<D8g84i43BmHACDP83Pf8594838dAD=2A30e<dE2>3<a=C4i<DE6<3Ta<cDe
ACHc<CU4<dHi<C4`=CHa@dDd@C92ASPfASLgA3La@S51<`di<dHeAC4dAD@f@cM3
<d<g@c8b>D4c=dI4AC<d=cQ2<d=2<T<a<3M6AS<g<T4e@c@c=S<h<S4b<3<f>D<=
>C4b=cPf=TA1>4DbAD<g<DDe<S<`AS@h<dA2=SPf<cQ6>496@D@c<C16ATHa@d52
=34f<21>A0d_F4Df820g<b1BA20b=4E3@T@`=C=5@SU6@d51<3La=CA6>D92<314
>DDa@SA3<4=4<T@f<34dA4Hd<d@i<d<`AS<a@dHd<S8=A492<3Pb<C8c@CL`<3Ph
=dE6ADDaASHdADHe<T91>DA6<TA1ACLg@STeA4E1<T55@CLiA312=CTi=d=23D4a
AD=3ASPf<cU3>4<`<cU6ACE4=CE1=c<b84i43BmHACLP83P`8594838dAD=2A30e
<dE2>3<a=C4i<DE6<3Ta<cDeACHc<CU4<dHi<C4`=CHa@dDd@C92ASPfASLgA3La
@S51<`di<dHeAC4dAD@f@cM3<d<g@c8b>D4c=dI4AC<d=cQ2<d=2<T<a<3M6AS<g
<T4e@c@c=S<h<S4b<3<f>D<=AT@`A3@g>4=1>4=6>D@eASLc=cPiAT91=SP`AS@d
=S0f>CA3@cHi<b1>A0d_F4Dh820g<R1BA20b=4E3@T@`=C=5@SU6@d51<3La=CA6
>D92<314>DDa@SA3<4=4<T@f<34dA4Hd<d@i<d<`AS<a@dHd<S8=A492<3Pb<C8c
@CL`<3Ph=dE6ADDaASHdADHe<T91>DA4>D<e@cHe>C93>CPg=D8i@S13@d=6>3A1
@dHd3C53@S0`=STd@d@f>CHa<CQ5>4H`=dDc>21>A0d_F4Di820f=b1BA20b=4E3
@T@`=C=5@SU6@d51<3La=CA6>D92<314>DDa@SA3<4=4<T@f<34dA4Hd<d@i<d<`
AS<a@dHd<S8=A492<3Pb<C8c@CL`<3Ph=dE6ADDaASHdADHe<T91>DA6A34b>394
=3LdASHi@CHg>DI5=3@b<312@cLd3C4i<4@b<CDg<S@c@TI584i43BmHAD4P83@d
8594838dAD=2A30e<dE2=S=2<cDiADDd=30c<48i>44g<C16<C0g@T<f>44c=TDb
<4E1=D93<38gA3I3<S4g=@e6>3Pc=3LaAC@f=S8c<dA4<48fAS0h>3I1AT8b84i4
3BmHAD8P83D`8594838dAD=2A30e<dE2=S=2<cDiADDd=30c<48i>44g<C16<C0g
@T<f>44c=TDb<4E1=C=4=T4a>CHf<3Pd>@db>C8aASLd=TE3=3Ha<D8h=4Hf<451
A3Lh<THf<CLc=SI3A3Dg<39684i43BmHAD<P83Da8594838dAD=2A30e<dE2=S=2
<cDiADDd=30c<48i>44g<C16<C0g@T<f>44c=TDb<4E1=CHg<STc=d8hAC0iAPe2
A30dADDe=S@d>C8f@c4c=48d>496>4DiASA1@SPbATDc=3@c=T=3@c<PCT@=;eQ5
A20P=3DPDT@P<SA5@d94<3DcAD8f<d8c=CU5AC@d<3<`@STh@CLa<4Ha<3M2@cHh
@C<fAC8`AD4e=T95>4<b=dH`>3913CD`>CI6<48b<S<g=3Da@CHhA3U5<dE2<D94
@SQ6>21>A0d_F4E5820a=C@PDT@P<SA5@d94<3DcAD8h<SU5=3@d@S0e>DHi=D4a
A3@aATE3<3E5@C8b@D4a>D@c=48e@C12<d<gAC8`<34b3D@b<D<g<D4h>D92AS8i
<SLh>4<c>38g=dHg<T4dAS55ASQ6=C0`<CE6=cDa<355AS96>D4h>4A4<354>@e5
@D4i<DE1<T95@SL`AS8h@CHbA3A5>34a<C<h<D=1=cTg@cH`=SQ4=cQ2<3Lc@CTf
@C@eAD4d=CLa<d8=A3A2=30d@T93@dE1@S8f=3@i=3DfAC<c<SU3=S4h<T95AC@f
AC=2=c=6=3=5<3U2<3Dc<D55AC@c@D@g3CE5=c<`=3Q6@C8a@S96<SLb<44a<SPi
=3Hh=S<cAS0`AS0d@S8h=SDc@CQ3>CU5AD8d>493=3Da@S12<@deADE5AD4`<R1>
A0d_F4E6820a=S0PDT@P<SA5@d94<3DcAD8h<SU5=3@d@S0e>DHi=D4aA3@aATE3
<3E5@C8b@D4a>D@c=48e@C12<d<gAC8`<34b3D@b<D<g<D4h>D92AS8i<SLh>4<c
>38g=dHg<T4dAS55ASQ6=C0`<CE6=cDa<355AS96>D4h>4A4<354>@e5@D4i<DE1
<T95@SL`AS8h@CHbA3A5>34a<C<h<D=1=cTg@cH`=SQ4=cQ2<3Lc@CTf@C@eAD4d
=CLa<d8=A3A2=30d@T93@dE1@S8f=3@i=3DfAC<c<SU3=S4h<T95AC@fAC=2=c=6
=3=5<3U2<3Dc<D55AC@c@D@g3CE5=c<`=3Q6@C8a@S96<SLb<44a<SPi=3Hh=S=2
ACTh=3@f@cTf>4H`<T55=CLc<SLa<C4b=C4b=3Pf=Pe4@dI5@S4a@cE4<c<`ADA6
<T4f@B1>A0d_F4H`820b<CTPDT@P<SA5@d94<3DcAD8hAS0fA3HiAS15@cE5=4Df
@c96=S0d<STcASE2@cLf<T4f<C@i=C8aATA3=c4`=T4f3DHg@C<aA3Ti<SU6>3I1
<c4gAC16A3<g=D@e@SPeA3@`<44d=CH`A353=30fAC0i>C=3=c4e<3Le<cHdAPe5
@cA5=CU3>C@c<CQ6@d55@cDf=S<i>48`=SPaADH`AT4e<T53>DDf@S93>CDi@c4d
>C8d<CQ5ATE1=34=AS12>44c=C12<4A4@c<cA3<g@c0a@SQ1@S8d@CDhAC11>C@i
=cHg=S0gASHd>3PhAT8h@c52@D4h=dA23D@cA3Di>3PiAC=4=cU3=3<cA3D`ATDa
AC91=S95=CPcA44d=dI2ASPiASM6A4@`=cP`=C8b<cA2ACE1@@dd>3A6<3@a=dHb
A3=3@d@iASLbA3<i<SM5A3@`>CI1=C0c=CU5ADA6@C95=4<g<CTb=dE5A3@hAS51
=SP=@DH`=c55ADI3<T4gAD@cAD4a>C11<SP`=c8g@dE6A3D`@SM1>48a=D=6AC4i
@D8g<3HgA4@g=T<`=T=53C@f=S<g=cTh<48a=dA1<3M1>21>A0d_F4Ha820a=CDP
DT@P<SA5@d94<3DcAD8h<SU5=3@d@S0e>DHi=D4aA3@aATE3<3E5@C8b@D4a>D@c
=48e@C12<d<gAC8`<34b3D@b<D<g<D4h>D92AS8i<SLh>4<c>38g=dHg<T4dAS55
ASQ6=C0`<CE6=cDa<355AS96>D4h>4A4<354>@e5@D4i<DE1<T95@SL`AS8h@CHb
A3A5>34a<C<h<D=1=cTg@cH`=SQ4=cQ2<3Lc@CTf@C@eAD4d=CLa<d8=A3A2=30d
@T93@dE1@S8f=3@i=3DfAC<c<SU3=S4h<T95AC@fAC=2=c=6=3=5<3U2<3Dc<D55
AC@c@D@g3CE5=c<`=3Q6@C8a@S96<SLb<44a<SPi=3Hh=S<i@C8i@S=4=C92AT4i
@S=5<4I3=d8h=cTi>C0a=3A2<@dgA4I1<CPaAS4c84i43BmHAS8P834c=B1BA20b
=4E3@T@`=C=5@SPg=C=3@CA4=T<g>C8e<c8c=DE6=3<g<T@b<C11<DDcAC0h=SI4
>4=2A3Tb<3D`ASP=<TH`@S55=TA1<3Le=TE3>4H`<T4`>38i=3Ph@D@a=4I2=d4f
AT4i=c@d=d<e@S4a@d56=352<3Ld=S4d3D92=4I5<D91ATHh=SDc@D@d>30e@TD`
@C8f@c55@C12AT<`A34h=44iA4I5@cPeA4@g>D@gAD@b<30e=Pdi@S8e@d4bA3E4
<SM3@DA6=S4g=S15<cU4<DDd<D=3A44i=cTa>44e@SE1AC@g>CDe@S11@S8c<CM3
>44=ACDf<3Hf=cHa@d@h<TD`AS13@C8i<S91@SA4<T5584i43BmHAS<P834d<R1B
A20b=4E3@T@`=C=5@SPg=C=3@CA4=T<g>C8e<c8c=DE6=3<g<T@b<C11<DDcAC0h
=SI4>4=2A3Tb<3D`ASP=<TH`@S55=TA1<3Le=TE3>4H`<T4`>38i=3Ph@D@a=4I2
=d4fAT4i=c@d=d<e@S4a@d56=352<3Ld=S4d3D92=4I5<D91ATHh=SDc@D@d>30e
@TD`@C8f@c55@C12AT<`A34h=44iA4I5@cPeA4@g>D@gAD@b<30e=Pdi@S8e@d4b
A3E4<SM3@DA6=S4g=S15<cU4<DDd<D=3A44i=cTa>44e@SE1AC@g>CDe@S11<4Dd
=SHiACL=@C8b>CDd=S<d@dE5=T8cASE4@SU3>CU2A4I5@S8f<34h<DHh<48fASQ6
A48PCT@=;eQ6=20P<C<e8594838dAD=2A30e<dE2>3Le<d=1=4@f@cLi<SDc<S<e
ADHd<cLbA38a<44aAC=5<3Pf=T@h@d94>C8`=C16>0dbAS12<DDfA44`=cDfAD<h
AS0b@C0h<STd>3Q1A34dAT8g@CI6@CTg=3@g@cE2<C53@DHd<D8`=c@f<C@=@T8d
ATDa@T56ASPf=C=1A3@h<3E2AC11<SI3<DE1<496@c14<CPd@CU4ATE3>3E4A3Li
A3M5A38`<3Df3CU2<SE3@C94=D@b=d=1A4Hf<CLf<4Dc>D@aAC@a@d=4@CTg>C4h
@CE2=D55=3Li=CE2<3DeAS8`=S52=Pe4ADI6>4<b@S<fA452AS92@c0i<SM5=c0i
ATDe<c4PCT@=;eQ6=B0P<SHPDT@P<SA5@d94<3DcAD8f@c8aACM4=T<d>D8a<3La
>CI1ATE2>3A3<d8a>C=3>CLg<313<CDa<b1>A0d_F4Hf820c>B1BA20b=4E3@T@`
=C=5@SU3@S8i=c93@S0i=D@f<315A4=1AC<f<cE5>30b=CQ2>4E1<S12<dHi<4E1
=C8e<TD=AS13<T8fACPg<48f=34h>4He84i43BmHASLP834`<21BA20b=4E3@T@`
=C=5@SU3@S8i=c93@S0i@THf=SA5=CE6=c@h=C0a@DDf@SQ6<c16<c4h>CU4A4He
@C<`=3<==CE2ATHa@CA5=CA5A3Pi<D94<D94<cL`<3@d>C4d=DH`<T<`=CDa@c8a
AS<b@STa>3M2<D<h@dE2<CE63C=3@d96=SHf<S8g@SA6>48`A3Tg<4I2=CI5@C0i
@SA4=dA1=cTd=d94AS<`>4@b<C<b=D96=3U4>DE4=Pe4=CU6<S8f@dHi@d=6=3Ph
<dHb@R1>A0d_F4Hh820b=b1BA20b=4E3@T@`=C=5@SU3@S8i=c93@S0iA3E1=CD`
<30h>3M2=3@cA48i=S4c@T=3<C@i=4<e@T@PCT@=;eQ6>B0P>C4PDT@P<SA5@d94
<3DcAD8i@d8b>CLb@d8`>CQ3>3I6@C<b<494ASA3A451@T4b@dE4@T@h=T91AD8c
=dHcAS0h3C0f@T8bACPa<D<a=C14=T=6<cLd<C53=c52A4A6=C=6AD92=CPc<CT`
<c<b=CE5>3Tf=3Hb>3TcASHb@@dd@C8iA4De@SLc<392@SQ6@c8i=cM5A3Q1>4Hh
<3TaA3A2<3A3A4A5<DDiACPa<c8a=d4`ADHc<CTi=d4=@STPCT@=;eQ6@B0P<SDP
DT@P<SA5@d94<3DcAD8i@d8b>CLb@d8`>CHh>34i@C8eAS92=D54=THd=D@bASP`
ASTd=c@PCT@=;eQ6@R0P<C<b8594838dAD=2A30e<dE2>D=2<STg<T=2<3TeA3H`
=S<d<D51<48aASA2=S@h@S92<3Pi=c@e<cPa<cLb<C@a<0e5@cM6<CA4>3Dd=CPh
>DHi=C4a@cLb<C94A38dAD96A491<cA1ACM1=T<f=S56<DE6@T52=C0g>4@i>CP=
<3<cA3Pf<3@b=3U1>4@c@c93<d8h=c4eASPgAC8g<38h>CHg=CLg<cHd<S51<4A2
>3Hb>C4i@S<`=dHh3C4b<4@aATHc@cT`=S<d=T8d>D93=SPd<S@`<dH`A3H`AS<i
A34`=d@g@cU4@D=6>DI4>4Dc<T55@D@d@@db>C<d>CI6>C<i>CDg=C<c=DI2>CLg
A34PCT@=;eQ6@b0P>3PPDT@P<SA5@d94<3DcAD8i@d8b>CLb@d8`>C<hA38i=cLe
<T<i<cA6=SThAS<bAS4e>3I4@DA4=S53<4A4>C543C<`<SLgA30a<T=2AC13@cPe
=STfAD94<C0g<3Db=3=4<3E2=d95=c<i@T<h<T@hA4<d=S@f=C@e<cTi>@e1AC4i
@S56A492<SD`@cU4=3Tf=4=2AS95>30a@SI1<3I3@dHi@S8f=CI5ACTd@S<cASE3
>C@dAR1>A0d_F4I4820d=B1BA20b=4E3@T@`=C=5@SU3@S8i=c93@S0i=cLf>CA3
=cDa>CA4ATI4AT@h@CTa=T94ACM1AT=1<c@d<T95=dH=<dDh>3Q5@TI3<THi>C0d
>38a=THeAC<i=SLb=C=184i43BmHATDP83Pb8594838dAD=2A30e<dE2>D=2<STg
<T=2<3Hg=C<b=T<g=d4g@d52=cLeAT4f<DI6>CLf=dE1=C@d=cE6A451A0da<cHb
=DE3=S4g=dI4=SDi>3A3@D4b>@00X@300?]5=S<bAC55<S13<S0b@CQ4>34a>455
<c12<3U6<d8h>3=6<cE63C15@CA5<CPc<SDeAT@`>3Lb>DHiAS4h>3Tg=D4c=cTa
<S=4<T4c=ST`<CU384i43BmHATHP83<i8594838dAD=2A30e<dE2>D=2<STg<T=2
<3TeA3H`<3=6ACM5>D<a<c0a=TA2ACU3A4<c<S@f<S<`=c@h@DHd<`da>3<g@SDg
<dHa>CHgAT@h<CLPCT@=IFiT3FE^I0e`MG@=L7Ed3FAeL20_AVm^M4iQKFDPIfEd
86EhHfPPI6EVJFiUIVm^M21`Kg0=9BE5KVABIG=_MG9SIB0=3@00X@300IP_GemO
ATha82m7IFiUMV4P;dMUKVEfHB1TMG0PIVU^I6I_KW@PI7E`82m3J65bDgAbJFiW
Lb1[KVmgKR1kHVEWJFhP@fQQLU=dLVU^Ig<P;d5TJFEbIG=YLb1[KVmgKR1k;C4P
OG/]<GdPJFIUK7=U86E^I7dPNg1_L20]<GdPJFIUK7=U879V3C0PJF@=<B1VI0d`
838`<B1dLV5^LfaQM6D=<c0`82dc<30PLf=/J@dU9DE^I5=UM7E`80dU9D9UIfU^
D65WIE=UM7E`80e`K@dU9DE^I51QIfECIGAeL0d_A6EfJF=UDTM287=SL`d`830P
<21V<`d`;S4b=C0P<2ha<SD`87=`3B0`86aS3B0b86aZ3E@PLf4=9G1QIfDPLVES
M3XP<C<b83<f<b0d=S0P=CHc80ecM6d=<20`830PIS<=<CL^<cHa<20a=bhc=S4`
87=`3C4a;SDPK6d=830PK6X=KW0=<C0`<Bhe<CPb83<`;ST`=C8PKG@=<C0`<Bhe
<CPb83<`<SD^=SPa=b1/J@eTL`d0X@3000=WL`d00:40`02Z<20`830PIS<=KW0=
<C0f>Bhc<c0g834i=2ha=c@d86ed3C4`=ST^<c<`=b0a>C@^<CLd=20a<30a;SPh
<SHP<S8e;S<`<CLP>C<c;SL`=C4P<CTc;S@c<c@PHg@=>C@f;S<`>CTP<CDc;S@a
<SHP<C0`<Rhf<cDe82d`;R0a<30b;SHc=CDP;C0^86=d3C4`=ST^<c<`=b0a>C@^
<CLd=21/J@eSL0eTI@d0X@3000=WLPd00:40`004LWA]3@2Q0<00@7=dK@d`830P
<21V<`e^L0di>3P^=3Tg=B0c<38e;SHh<CLPKG@==CHf<Rhi=C8i83<`<SD^=SPa
=b1/J@eTL`d0X@3000=WL`d00:40`02i<20`830PIS<=KW0==C@i>Bhf>3@P<STe
=bhh=c0c86ed3CDd>CT^=SPd838i=CL^>3L`<b0e=3Hh;SDe=SLP<c0b=Bhc<CPe
83De<30^=38e83<`>C<^=3Tf86=d3CDe=30^=3@e>20c<3P`;SPi<C4P=CHi<bhh
=CPe83<`<S@^=CHe=R0e=STc;SPe>3DP<c0b=2he=SDf86=d3CDd>CT^=SPd838i
=CL^>3L`<b1/J@eSL0eTI@d00:40`003Ig8=002Q0<00179dK@d0X@3002McM6d=
<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`02`LgA]3C4^
=C0`<20`;S0`<30P<2h`<30`834^=C0`<20]<CT`;S@c<3PP;C@d<2hg>CLh86=c
3C8`>2hc<c8c86IdL`d_GemOATha86=fLfH=<20`830PIS<=AR1cH@da<SH^<S<a
=20f=3@^<c8c=b1]M0dXM21_LR1^:B1K>C8^<cLP=ST^=3PP<C8f;S8d83P`;S@f
83Hi;S@h830PGB1hLfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=0:40`027LgA]3C0P
<20`86Hc3Fi`3CDh;SDi<cDP=CP^=CTc=B0b=3Lg;S0b<cLP<CTa=bhe>C0a86E`
3FAU3C0P<20`86Hc3C4g;S<f<C0P<CL^<cHa<21cL0e^L0de>2he>C<e83Dh;SDi
<cDP<S@g=bh`<S<g834i<CL^=CT`<B1UL0eTL`ebM6d=002Q0<00CG=dK@d`;SDg
<3<P<2he=c0c830^=CL`<b1V<`e^L0de>2he>C<e83Dh;SDi<cDP<SPd<Bhf<3Db
834e=3H^=3Th<R1UL0eTL`ebM6d=002Q0<00CG=dK@d`;SDg<3<P<2he=c0c830^
=CL`<b1V<`e^L0de>2he>C<e83Dh;SDi<cDP<S0i>Bhd<S4e834e=3H^=3Th<R1U
L0eTL`ebM6d=002Q0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P
<20`86Hc3@00X@3008QcM6d=<Bhe<30`830^<30`<20`;S0`<30P<Bhe<30`82da
>C0^=3<`>20]=3@`;SLi=cPPHg<=<CDf;S8d>C8PIWAc3BmOGem6CS4PHgIcIPd`
830P<21V<`e687=Q3CH`=Rhh<STg834f<C0^<3<`=R1]M0dXKRTP87=XKgL=E21c
H@ebM6d=0:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`
87=`3C0P<20`86Hc3@00X@30095cM6d=<Bhe<30`830^<30`<20`;S0`<30P<Bhe
<30`82da>C0^=3<`>20]=3@`;SLi=cPPHg<=<20`830PIS<=AR1cH@db<S<^>3Pg
<R0a<cLe;SHe=SPPKG@=:6h[<Blb:B1K>C4^<CLP<C0d;S4d834`=2ha=20h=2h`
>20`85dPN7=XKgL=E21cH@ebM6d=002Q0<00179dK@d0X@3002McM6d=<20`830P
IS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`022LgA]3C4^=C0`<20`
;S0`<30P<2h`<30`834^=C0`<20]<CT`;S@c<3PP;C@d<2hg>CLh86=c3C0P<20`
86Hc3DHPLf4==34`;SDa>38P<C4a>Bhe>34g86ed3BQ^:c4Y85/i<Bha=b0a<3@^
<C@P<21M87QcJ6mg3E@PLf4=LWA]3@2Q0<00179dK@d0X@3002McM6d=<20`830P
IS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`01_LgA]3C4^=C0`<20`
;S0`<30P<2h`<30`834^=C0`<20]<CT`;S@c<3PP;C@d<2hg>CLh86=c3C0P<20`
86Hc3DHPLf4=<CLf=Bhf=cLi838e=CH^<S0f=21]M0dXJRTP87=XKgL=E21cH@eb
M6d=002Q0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21c
L0d`830P<21V<`d00:40`023LgA]3C4^=C0`<20`;S0`<30P<2h`<30`834^=C0`
<20]<CT`;S@c<3PP;C@d<2hg>CLh86=c3C0P<20`86Hc3DHPLf4=<S4f>2hc<S4g
838e=CH^<S0f=21]M0dXJR/a:B1K=3<^<CPP<C0d;S4d830PGB1hLfQ_M`eD87=Q
3G9dK@d00:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`
87=`3C0P<20`86Hc3@00X@30089cM6d=<Bhe<30`830^<30`<20`;S0`<30P<Bhe
<30`82da>C0^=3<`>20]=3@`;SLi=cPPHg<=<20`830PIS<=AR1cH@da<S4c;S@f
=CDP<SDe=Rhb<3Hd86ed3BQZ;C4Y85/d<bha>20e>Bhb<20`85dPN7=XKgL=E21c
H@ebM6d=0:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`
87=`3C0P<20`86Hc3@00X@300;=cM6d=<Bhe<30`830^<30`<20`;S0`<30P<Bhe
<30`82da>C0^=3<`>20]=3@`;SLi=cPPHg<=<S0h;S<c<S<PIWAc3BmOGem6CS4P
HgIcIPd`830P<21V<`e687=Q3C<a<cP^<cHh>B0b=C<f;SHg=C8PKG@=:7PPKg8P
JRTPFc4a<2hd=b0f>Bhd>20a<SH^<S@P>30^=3HP=ST^=3PP<21M87QcJ6mg3E@P
Lf4=LWA]3@00X@3000AbM6d=0:40`01GLgA]3C0P<20`86Hc3C4g;S<f<C0P<CL^
<cHa<21cL0e^L0di<3<^=38f<R0a>3Tb;S@c>C8PKG@=<C0i>2hg<cLg834h>C8^
=3<i<R1/J@eTL`ebM6d=002Q0<00A7=dK@d`830P<21V<`e^L0di<3<^=38f<R0a
<CHc;S8g=S8PKG@=<C0i>2hg<cLg834a=S<^<SLf<R1/J@eTL`ebM6d=0:40`015
LgA]3C0P<20`86Hc3Fi`3C4g=3<^<SHb>20b>C4d;SDf<SLPKG@=<CLd<bhb=S8h
83<a<3T^>3Ld<R1/J@eTL`ebM6d=002Q0<00A7=dK@d`830P<21V<`e^L0db=3Lh
;STc=S4P<STb<Bh`=c<PKG@=<S@g>2hi<cHa83<a<CH^<cPd=B1/J@eTL`ebM6d=
0:40`015LgA]3C0P<20`86Hc3Fi`3C<b<C@^=S0i=B0b>C8g;SDh<c@PKG@=<c8a
=2hf<3Te83<a<S8^>3Td>B1/J@eTL`ebM6d=002Q0<00?W=dK@d`830P<21V<`e^
L0de>2he>C<e83Dh;SDi<cDP<S@g=bh`<S<g834a=3T^<cHd>21UL0eTL`ebM6d=
0:40`004LgA]3@2Q0<000fMc3@00X@3013EXL`db=3Ha;SPc<SHP<C8g<bh`=S4i
86ed3C8d=cT^<CTc=R0a<SLc;S0f<CTPK6T=<S@g>Bha>C<f834h<3H^>C4c<b1/
J@db=3Ha;SPc<SHP<CP`=Rhi<C<c86aY3C8d=S4^>3<b=R0a<SLc;S0f<CTPK6T=
Hg0=834PJ6<=<20`830PIS<=838PK6X=KW0=<S@g>Bha>C<f834b<cL^>C4a=B1]
M0db=3Ha;SPc<SHP<C8c=bhi<C4e86aY3FAc3Fi`3C8d=cT^<CTc=R0a<SLb;SHc
<cDPKG@=<S@f<Bhh<c8f834b=c8^=S<c=B1/J@eTL`e^L0db=3Li;S4i<cHP<C<`
=bhc=CDe86ed3C8d=S4^>3<b=R0a<c0g;S<e=CDPK6T=I7<=KW0=<S@g>Bha>C<f
834c=38^<3Lg=R1]M0db=3Ha;SPc<SHP<C<d<Rh`=cLf86aY3FAc3Fi`3C8d=cT^
<CTc=R0a<cLf;SLi>CHPKG@=<S@f<Bhh<c8f834c=cH^=cTi=R1/J@eTL`e^L0db
=3Li;S4i<cHP<C@a<Bhe<S4g86ed3C8d=S4^>3<b=R0a=34a;SDb<CLPK6T=I7<=
KW0=<S@g>Bha>C<f834d=3H^<S@c=b1]M0db=3Ha;SPc<SHP<C@d=Rhb=3<g86aY
3FAc3Fi`3C8d=cT^<CTc=R0a=3P`;STf=CPPKG@=<S@f<Bhh<c8f834d>30^>CHe
>21/J@eTL`e^L0db=3Li;S4i<cHP<CDa=Bhf>3Lh86ed3C8d=S4^>3<b=R0a=C4e
;SHh=cPPK6T=I7<=KW0=<S@g>Bha>C<f834e=C0^=30i>B1]M0db=3Ha;SPc<SHP
<CDe<2hd<3Ti86aY3FAc3Fi`3C8d=cT^<CTc=R0a=CPe;S4c<CTPKG@=<S@f<Bhh
<c8f834e>3D^<C<a>B1/J@eTL`e^L0db=3Li;S4i<cHP<CHa>Bhh=C@PKG@=<S@f
<Bhh<c8f834f<CT^>3Dd86aY3FAc3Fi`3C8d=cT^<CTc=R0a=SDd;SDg=R1]M0db
=3Ha;SPc<SHP<CHe=2he=cHPK6T=I7<=KW0=<S@g>Bha>C<f834f>3T^<STh<B1]
M0db=3Ha;SPc<SHP<CHh>Bhb>CPa86aY3FAc3Fi`3C8d=cT^<CTc=R0a=c8d;S0b
<34PKG@=<S@f<Bhh<c8f834g<S@^<38`<B1/J@eTL`e^L0db=3Li;S4i<cHP<CLe
>2hg=38a86ed3C8d=S4^>3<b=R0a=cDh;SLd<S4PK6T=I7<=KW0=<S@g>Bha>C<f
834g>C<^=3Hd<R1]M0db=3Ha;SPc<SHP<CLi<bhd=S@b86aY3FAc3Fi`3C8d=cT^
<CTc=R0a>38h;S4h=S8PKG@=<S@f<Bhh<c8f834h<SP^<CPf<R1/J@eTL`eXI@d0
0:40`003Ig8=002Q0<00179dK@d0X@3000AcM6d=0:40`003Ig<=002Q0<040FQc
3C8b<S<^<C4h=B0a=CDe;S4g>3DPKG@=<S8b<bha<CPe834e<cL^>34g=B1/J@db
=c<`;STb>3@P<CDc=bhh<CLe86aY3C8g<c0^>C8h=20a=CDe;S4g>3DPK6T=<S8b
<bha<CPe834e=CD^<CLh=B1/J@eSL0dP<B1XH`d`830P<21V<`dP<R1/JPe^L0db
<CPb;S@h<SLP<CDc=bhh<CLe86ed3C8a>38^=3Pb=b0a=CDe;S4g>3DPK6T=I7<=
KW0=<S8a=bhb<3@g834e<cL^>34g=B1]M0db<S4g;S8`=3LP<CDe=Bha=cPe86aY
3FAc3Fi`3C8b=C4^>C8f=b0a=C<g;SPa=cDPKG@=<S8e<Bhi<SHg834e=CD^<CLh
=B1/J@eTL`e^L0db<SPf;SHd>3PP<CDc=bhh<CLe86ed3C8b>3H^=S@h>20a=CDe
;S4g>3DPK6T=I7<=KW0=<S<b<Bhc=c0h834e<cL^>34g=B1]M0db<c8a;S<g<3PP
<CDe=Bha=cPe86aY3FAc3Fi`3C8c=CH^<3Tb>B0a=C<g;SPa=cDPKG@=<S<e=Rh`
>C8i834e=CD^<CLh=B1/J@eTL`e^L0db<cT`;SPa=3TP<CDc=bhh<CLe86ed3C8c
>C0^>34d>B0a=CDe;S4g>3DPK6T=I7<=KW0=<S@b=Bhe<cLP<CDc=bhh<CLe86ed
3C8d<SD^=C<g834e=CD^<CLh=B1/J@eTL`e^L0db=3H`;S8e>B0a=C<g;SPa=cDP
KG@=<S@f<2hb=CTP<CDe=Bha=cPe86aY3FAc3Fi`3C8d>C@^>CPa<B0a=C<g;SPa
=cDPKG@=<S@i=2hi>34a834e=CD^<CLh=B1/J@eTL`e^L0db=C8i;SL`<c4P<CDc
=bhh<CLe86ed3C8e<ST^=c0c<B0a=CDe;S4g>3DPK6T=I7<=KW0=<SDf=2hd<SDb
834e<cL^>34g=B1]M0db=CHd;S@b=C8P<CDe=Bha=cPe86aY3FAc3Fi`3C8e>CT^
<C@g<R0a=C<g;SPa=cDPKG@=<SDi>Bha=3Lb834e=CD^<CLh=B1/J@eTL`e^L0db
=S<c;SPf>C<P<CDc=bhh<CLe86ed3C8f<c<^>3Hi<b0a=CDe;S4g>3DPK6T=I7<=
KW0=<SHf>2he>C4c834e<cL^>34g=B1]M0db=SHh;SDi<C<P<CDe=Bha=cPe86aY
3FAc3Fi`3C8g<3<^<c4c<b0a=C<g;SPa=cDPKG@=<SL`<bhc<C<c834e=CD^<CLh
=B1/J@eTL`e^L0db=c<h;S0c=C@P<CDc=bhh<CLe86ed3C8g<cP^<3<e=20a=CDe
;S4g>3DPK6T=I7<=J6D=002Q0<000fMb3@00X@3000AbM6d=0:40`01dLgA]3C0P
<20`86Hc3Fi`3CDh;SDi<cDP=CP^=CTc=B0a=cPf;STb<c4P<CTa<Bh`=cTg86E`
3FAU3C0P<20`86Hc3Fi`3CDh;SDi<cDP=CP^=CTc=B0a=cPf;STb<c4P<CTa<Bh`
=cTg86E`3FAc3G9dK@d0X@3007AcM6d=<20`830PIS<=KW0==CP^=CTc=B0e>2he
>C<e83<b=CP^<SHi>20a>C4a;S0g>CLPIG0=I6D=<20`830PIS<=KW0==CP^=CTc
=B0e>2he>C<e83<b=CP^<SHi>20a>C4a;S0g>CLPIG0=I7<=LWA]3@2Q0<002WAU
LVeYKV5dI@d0X02o0:00_P2J0000ohnP000000=70nP00004000000180000B000
0100800300P00000000000FR]``000000dL3j0000003A`?[0000<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0>H7oR?l10021oh7oPOn1oh7oPOn1oi_o0@00POn1oh7oPOn1oh7oPOnKo`40
087oPOn1oh7oPOnDo`0iPOn8o`40087oPOn1oh7oPOn1oh7oVol10021oh7oPOn1
oh7oPOn1oi_o0@00POn1oh7oPOn1oiCo03V1ohSo0@00POn1oh7oPOn1oh7oPOnK
o`40087oPOn1oh7oPOn1oh7oVol10021oh7oPOn1oh7oU?l0=X7oROom087oPOn1
oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOnEo`0fPOn9
ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1
oiGo03J1ohWoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21
oh7oPOn1oh7oUOl0=X7oR_ok087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1
oh7oWook087oPOn1oh7oPOnFo`0fPOn:oo/0POn1oh7oPOn1oh7oPOnOoo/0POn1
oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oiKo03J1oh_onP21oh7oPOn1oh7oPOn1
oj3onP21oh7oPOn1oh7oPOn1oj3onP21oh7oPOn1oh7oU_l0=X7oRooi087oPOn1
oh7oPOn1oh7oXOoi087oPOn1oh7oPOn1oh7oXOoi087oPOn1oh7oPOnGo`0fPOn<
ooP0POn1oh7oPOn1oh7oPOnRooP0POn1oh7oPOn1oh7oPOnRooP0POn1oh7oPOn1
oiOo03J1ohcon021oh7oPOn1oh7oPOn1oj;on021oh7oPOn1oh7oPOn1oj;on021
oh7oPOn1oh7oUol0=X7oS?og087oPOn1oh7oPOn1oh7oXoog087oPOn1oh7oPOn1
oh7oXoog087oPOn1oh7oPOnHo`0fPOn=ooH0POn1oh7oPOn1oh7oPOnTooH0POn1
oh7oPOn1oh7oPOnTooH0POn1oh7oPOn1oiSo03J1ohgomP21oh7oPOn1oh7oPOn1
ojComP21oh7oPOn1oh7oPOn1ojComP21oh7oPOn1oh7oV?l0=X7oSOoe087oPOn1
oh7oPOn1oh7oYOoe087oPOn1oh7oPOn1oh7oYOoe087oPOn1oh7oPOnIo`0fPOn=
ooD0POn1oh7oPOn1oh7oPOnUooD0POn1oh7oPOn1oh7oPOnUooD0POn1oh7oPOn1
oiWo03J1ohkom021oh7oPOn1oh7oPOn1ojKom021oh7oPOn1oh7oPOn1ojKom021
oh7oPOn1oh7oVOl0=X7oS_oc087oPOn1oh7oPOn1oh7oYooc087oPOn1oh7oPOn1
oh7oYooc087oPOn1oh7oPOnJo`0fPOn>oo<0POn1oh7oPOn1oh7oPOnWoo<0POn1
oh7oPOn1oh7oPOnWoo<0POn1oh7oPOn1oi[o03J1ohool@21oh7oPOn1oh7oPOn1
ojWol@21oh7oPOn1oh7oPOn1ojWol@21oh7oPOn1oh7oVol0=X7oSooa087oPOn1
oh7oPOn1oh7oZOoa087oPOn1oh7oPOn1oh7oZOoa087oPOn1oh7oPOnKo`0fPOn?
oo40POn1oh7oPOn1oh7oPOnYoo40POn1oh7oPOn1oh7oPOnYoo40POn1oh7oPOn1
oi_o03J1oi3ok`21oh7oPOn1oh7oPOn1oj_ok`21oh7oPOn1oh7oPOn1oj_ok`21
oh7oPOn1oh7oW?l0=X7oT?o_087oPOn1oh7oPOn1oh7oZoo_087oPOn1oh7oPOn1
oh7oZoo_087oPOn1oh7oPOnLo`0fPOnAonh0POn1oh7oPOn1oh7oPOn/onh0POn1
oh7oPOn1oh7oPOn/onh0POn1oh7oPOn1oico03J1oi7ok@21oh7oPOn1oh7oPOn1
ojgok@21oh7oPOn1oh7oPOn1ojgok@21oh7oPOn1oh7oWOl0=X7oTOo]087oPOn1
oh7oPOn1oh7o[Oo]087oPOn1oh7oPOn1oh7o[Oo]087oPOn1oh7oPOnMo`0fPOnB
on`0POn1oh7oPOn1oh7oPOn^on`0POn1oh7oPOn1oh7oPOn^on`0POn1oh7oPOn1
oigo03J1oi;oj`21oh7oPOn1oh7oPOn1ojooj`21oh7oPOn1oh7oPOn1ojooj`21
oh7oPOn1oh7oW_l0=X7oTooZ087oPOn1oh7oPOn1oh7o/?oZ087oPOn1oh7oPOn1
oh7o/?oZ087oPOn1oh7oPOnNo`0fPOnConX0POn1oh7oPOn1oh7oPOn`onX0POn1
oh7oPOn1oh7oPOn`onX0POn1oh7oPOn1oiko03J1oiCoj021oh7oPOn1oh7oPOn1
ok;oj021oh7oPOn1oh7oPOn1ok;oj021oh7oPOn1oh7oWol0=X7oU?oX087oPOn1
oh7oPOn1oh7o/_oX087oPOn1oh7oPOn1oh7o/_oX087oPOn1oh7oPOnOo`0fPOnD
onP0POn1oh7oPOn1oh7oPOnbonP0POn1oh7oPOn1oh7oPOnbonP0POn1oh7oPOn1
oioo03J1oiGoiP21oh7oPOn1oh7oPOn1okCoiP21oh7oPOn1oh7oPOn1okCoiP21
oh7oPOn1oh7oX?l0=X7oUOoV087oPOn1oh7oPOn1oh7o]?oV087oPOn1oh7oPOn1
oh7o]?oV087oPOn1oh7oPOnPo`0fPOnEonH0POn1oh7oPOn1oh7oPOndonH0POn1
oh7oPOn1oh7oPOndonH0POn1oh7oPOn1oj3o03J1oiGoi@21oh7oPOn1oh7oPOn1
okGoi@21oh7oPOn1oh7oPOn1okGoi@21oh7oPOn1oh7oXOl0=X7oU_oT087oPOn1
oh7oPOn1oh7o]_oT087oPOn1oh7oPOn1oh7o]_oT087oPOn1oh7oPOnQo`0fPOnF
on@0POn1oh7oPOn1oh7oPOnfon@0POn1oh7oPOn1oh7oPOnfon@0POn1oh7oPOn1
oj7o03J1oiKoh`21oh7oPOn1oh7oPOn1okOoh`21oh7oPOn1oh7oPOn1okOoh`21
oh7oPOn1oh7oX_l0=X7oUooR087oPOn1oh7oPOn1oh7o^?oR087oPOn1oh7oPOn1
oh7o^?oR087oPOn1oh7oPOnRo`0fPOnGon80POn1oh7oPOn1oh7oPOnhon80POn1
oh7oPOn1oh7oPOnhon80POn1oh7oPOn1oj;o03J1oiSoh021oh7oPOn1oh7oPOn1
ok[oh021oh7oPOn1oh7oPOn1ok[oh021oh7oPOn1oh7oXol0=X7oV?oQ087oPOn1
oh7oPOn1oh7o^OoQ087oPOn1oh7oPOn1oh7o^OoQ087oPOn1oh7oPOnRo`0fPOnE
onH0POn1oh7oPOn1oh7oPOndonH0POn1oh7oPOn1oh7oPOndonH0POn1oh7oPOn1
oj3o03J1oi;ok021oh7oPOn1oh7oPOn1ojkok021oh7oPOn1oh7oPOn1ojkok021
oh7oPOn1oh7oWOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0nkOoj087oYOol087oPOn1oh7oPOn1ooX0POnU
oo`0POn1oh7oPOn1oh7onP21ojGoo021oh7oPOn1oh7oUOl0?^gonP21ojGoo021
oh7oPOn1oh7oPOoj087oYOol087oPOn1oh7oPOn1ooX0POnUoo`0POn1oh7oPOn1
oiGo03k]ooX0POnUoo`0POn1oh7oPOn1oh7onP21ojGoo021oh7oPOn1oh7oPOoj
087oYOol087oPOn1oh7oPOnEo`0nkOoj087oYOol087oPOn1oh7oPOn1ooX0POnU
oo`0POn1oh7oPOn1oh7onP21ojGoo021oh7oPOn1oh7oUOl0?^gonP21ojGoo021
oh7oPOn1oh7oPOoj087oYOol087oPOn1oh7oPOn1ooX0POnUoo`0POn1oh7oPOn1
oiGo03k]ooX0POnUoo`0POn1oh7oPOn1oh7onP21ojGoo021oh7oPOn1oh7oPOoj
087oYOol087oPOn1oh7oPOnEo`0nkOoj087oYOol087oPOn1oh7oPOn1ooX0POnU
oo`0POn1oh7oPOn1oh7onP21ojGoo021oh7oPOn1oh7oUOl0?^gonP21ojGoo021
oh7oPOn1oh7oPOoj087oYOol087oPOn1oh7oPOn1ooX0POnUoo`0POn1oh7oPOn1
oiGo05c]ooX0b?oe0=_onP3BooL0d?ol087oPOn1oh7oPOn1ooX0b?oe0=_onP3B
ooL0d?ol087oPOn1oh7oPOn1ooX0b?oe0=_onP3BooL0d?ol087oPOn1oh7oPOnE
o`1dmOoV0=Ook`3]ooX0o?og0>7onP3koo80dool087oPOn1oh7oPOn9onH0eoo_
0>gonP3looL0hOoj0?_olP3Coo`0POn1oh7oPOn1ohWoiP3Gonl0kOoj0?com`3Q
ooX0noob0=?oo021oh7oPOn1oh7oUOl0M?GoiP3Gonl0kOoj0?com`3QooX0noob
0=?oo021oh7oPOn1oh7oROoV0=Ook`3]ooX0o?og0>7onP3koo80dool087oPOn1
oh7oPOn9onH0eoo_0>gonP3looL0hOoj0?_olP3Coo`0POn1oh7oPOn1oiGo07Ce
onH0f_oY0?3onP3nooD0hOoj0?kok@3Eoo`0POn1oh7oPOn1ohWoiP3JonT0l?oj
0?kom@3QooX0o_o]0=Goo021oh7oPOn1oh7oROoV0=[oj@3`ooX0o_oe0>7onP3n
ond0eOol087oPOn1oh7oPOnEo`1jmOoV0=_oiP3booX00Ooom03QooX00Oook03E
oo`0POn1oh7oPOn1ohWoiP3KonH0l_oj007ooo@0hOoj007oon`0eOol087oPOn1
oh7oPOn9onH0fooV0?;onP01oood0>7onP01ooo/0=Goo021oh7oPOn1oh7oUOl0
N_GoiP3KonH0l_oj007ooo@0hOoj007oon`0eOol087oPOn1oh7oPOn9onH0fooV
0?;onP01oood0>7onP01ooo/0=Goo021oh7oPOn1oh7oROoV0=_oiP3booX00Ooo
m03QooX00Oook03Eoo`0POn1oh7oPOn1oiGo08oeonH0gOof0?Som`3coo80nol0
0>7onP01oook0?_om`3Foo`0POn1oh7oPOn1ohWoiP3MooH0n?og0??olP3ko`00
hOoj007ooo/0noog0=Koo021oh7oPOn1oh7oROoV0=gomP3hooL0loob0?_o003Q
ooX00Ooon`3kooL0e_ol087oPOn1oh7oPOnEo`1dkOoj0=;om`3eooH0mOoe0=Oo
m@3eooX0e_ol087oPOn1oh7oPOn1ooX0d_og0?GomP3eooD0eooe0?GonP3Foo`0
POn1oh7oPOn1oh7onP3BooL0mOof0?Gom@3GooD0mOoj0=Koo021oh7oPOn1oh7o
UOl0M>gonP3BooL0mOof0?Gom@3GooD0mOoj0=Koo021oh7oPOn1oh7oPOoj0=;o
m`3eooH0mOoe0=Oom@3eooX0e_ol087oPOn1oh7oPOn1ooX0d_og0?GomP3eooD0
eooe0?GonP3Foo`0POn1oh7oPOn1oiGo07C]ooX0d_oh0?;on03eooL0eOog0??o
n03Hoo`0POn1oh7oPOn1oh7onP3BooP0l_oh0?Gom`3EooL0looh0=Soo021oh7o
POn1oh7oPOoj0=;on03booP0mOog0=Gom`3cooP0f?ol087oPOn1oh7oPOnEo`1d
kOoj0=Con03_ooP0m_oh0=Com`3booT0f?ol087oPOn1oh7oPOn1ooX0e?oh0>oo
n03fooP0e?og0?;on@3Hoo`0POn1oh7oPOn1oh7onP3DooP0kooh0?Kon03DooL0
l_oi0=Soo021oh7oPOn1oh7oUOl0M>gonP3DooP0kooh0?Kon03DooL0l_oi0=So
o021oh7oPOn1oh7oPOoj0=Con03_ooP0m_oh0=Com`3booT0f?ol087oPOn1oh7o
POn1ooX0e?oh0>oon03fooP0e?og0?;on@3Hoo`0POn1oh7oPOn1oiGo07C]ooX0
e?oi0>conP3fooP0e?oh0?7on@3Hoo`0POn1oh7oPOn1oh7onP3DooT0k?oj0?Ko
n03DooP0lOoi0=Soo021oh7oPOn1oh7oPOoj0=Con@3/ooX0m_oh0=Con03aooT0
f?ol087oPOn1oh7oPOnEo`1dkOoj0=Con@3/ooX0m_oh0=Con03aooT0f?ol087o
POn1oh7oPOn1ooX0e?oi0>conP3fooP0e?oh0?7on@3Hoo`0POn1oh7oPOn1oh7o
nP3DooT0k?oj0?Kon03DooP0lOoi0=Soo021oh7oPOn1oh7oUOl0M>gonP3DooT0
k?oj0?Kon03DooP0lOoi0=Soo021oh7oPOn1oh7oPOoj0=Con@3/ooX0m_oh0=Co
n03aooT0f?ol087oPOn1oh7oPOn1ooX0e?oi0>conP3fooP0e?oh0?7on@3Hoo`0
POn1oh7oPOn1oiGo07C]ooX0eOoh0>con03hooX0d_oj0>oon@3Hoo`0POn1oh7o
POn1oh7onP3EooP0k?oh0?SonP3BooX0kooi0=Soo021oh7oPOn1oh7oPOoj0=Go
n03/ooP0n?oj0=;onP3_ooT0f?ol087oPOn1oh7oPOnEo`1dkOoj0=GonP3YooT0
n?oj0=;onP3_ooT0f?ol087oPOn1oh7oPOn1ooX0eOoj0>Won@3hooX0d_oj0>oo
n@3Hoo`0POn1oh7oPOn1oh7onP3EooX0jOoi0?SonP3BooX0kooi0=Soo021oh7o
POn1oh7oUOl0M>gonP3EooX0jOoi0?SonP3BooX0kooi0=Soo021oh7oPOn1oh7o
POoj0=GonP3YooT0n?oj0=;onP3_ooT0f?ol087oPOn1oh7oPOn1ooX0eOoj0>Wo
n@3hooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oiGo07C]ooX0eOoj0>Won@3hooX0
d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7onP3EooX0jOoi0?SonP3BooX0kooi0=So
o021oh7oPOn1oh7oPOoj0=GonP3YooT0n?oj0=;onP3_ooT0f?ol087oPOn1oh7o
POnEo`1dkOoj0=GonP3YooT0n?oj0=;onP3_ooT0f?ol087oPOn1oh7oPOn1ooX0
eOoj0>Won@3hooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7onP3EooX0jOoi0?So
nP3BooX0kooi0=Soo021oh7oPOn1oh7oUOl0M>gonP3EooX0jOoi0?SonP3BooX0
kooi0=Soo021oh7oPOn1oh7oPOoj0=GonP3YooT0n?oj0=;onP3_ooT0f?ol087o
POn1oh7oPOn1ooX0eOoj0>Won@3hooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oiGo
07C]ooX0eOoj0>Won@3hooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7onP3EooX0
jOoi0?SonP3BooX0kooi0=Soo021oh7oPOn1oh7oPOoj0=GonP3YooT0n?oj0=;o
nP3_ooT0f?ol087oPOn1oh7oPOnEo`1dkOoj0=GonP3YooT0n?oj0=;onP3_ooT0
f?ol087oPOn1oh7oPOn1ooX0eOoj0>Won@3hooX0d_oj0>oon@3Hoo`0POn1oh7o
POn1oh7onP3EooX0jOoi0?SonP3BooX0kooi0=Soo021oh7oPOn1oh7oUOl0M>go
nP3EooX0jOoi0?SonP3BooX0kooi0=Soo021oh7oPOn1oh7oPOoj0=GonP3YooT0
n?oj0=;onP3_ooT0f?ol087oPOn1oh7oPOn1ooX0eOoj0>Won@3hooX0d_oj0>oo
n@3Hoo`0POn1oh7oPOn1oiGo07C]ooX0eOoj0>Won@3hooX0d_oj0>oon@3Hoo`0
POn1oh7oPOn1oh7onP3EooX0jOoi0?SonP3BooX0kooi0=Soo021oh7oPOn1oh7o
POoj0=GonP3YooT0n?oj0=;onP3_ooT0f?ol087oPOn1oh7oPOnEo`1dkOoj0=Go
nP3YooT0n?oj0=;onP3_ooT0f?ol087oPOn1oh7oPOn1ooX0eOoj0>Won@3hooX0
d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7onP3EooX0jOoi0?SonP3BooX0kooi0=So
o021oh7oPOn1oh7oUOl0M>gonP3EooX0jOoi0?SonP3BooX0kooi0=Soo021oh7o
POn1oh7oPOoj0=GonP3YooT0n?oj0=;onP3_ooT0f?ol087oPOn1oh7oPOn1ooX0
eOoj0>Won@3hooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oiGo07C]ooX0eOoj0>Wo
n@3hooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7onP3EooX0jOoi0?SonP3BooX0
kooi0=Soo021oh7oPOn1oh7oPOoj0=GonP3YooT0n?oj0=;onP3_ooT0f?ol087o
POn1oh7oPOnEo`1dkOoj0=Gon03/ooP0n?oj0=;onP3_ooT0f?ol087oPOn1oh7o
POn1ooX0eOoh0>con03hooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7onP3EooP0
k?oh0?SonP3BooX0kooi0=Soo021oh7oPOn1oh7oUOl0M>gonP3EooP0k?oh0?So
nP3BooX0kooi0=Soo021oh7oPOn1oh7oPOoj0=Gon03/ooP0n?oj0=;onP3_ooT0
f?ol087oPOn1oh7oPOn1ooX0eOoh0>con03hooX0d_oj0>oon@3Hoo`0POn1oh7o
POn1oiGo07C]ooX0e?oi0>conP3fooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7o
nP3DooT0k?oj0?KonP3BooX0kooi0=Soo021oh7oPOn1oh7oPOoj0=Con@3/ooX0
m_oj0=;onP3_ooT0f?ol087oPOn1oh7oPOnEo`1dkOoj0=Con@3/ooX0m_oj0=;o
nP3_ooT0f?ol087oPOn1oh7oPOn1ooX0e?oi0>conP3fooX0d_oj0>oon@3Hoo`0
POn1oh7oPOn1oh7onP3DooT0k?oj0?KonP3BooX0kooi0=Soo021oh7oPOn1oh7o
UOl0M>gonP3DooT0k?oj0?KonP3BooX0kooi0=Soo021oh7oPOn1oh7oPOoj0=Co
n@3/ooX0m_oj0=;onP3_ooT0f?ol087oPOn1oh7oPOn1ooX0e?oi0>conP3fooX0
d_oj0>oon@3Hoo`0POn1oh7oPOn1oiGo07C]ooX0e?oh0>oon03fooX0d_oj0>oo
n@3Hoo`0POn1oh7oPOn1oh7onP3DooP0kooh0?KonP3BooX0kooi0=Soo021oh7o
POn1oh7oPOoj0=Con03_ooP0m_oj0=;onP3_ooT0f?ol087oPOn1oh7oPOnEo`1d
kOoh0=Con03booP0mOoj0=;onP3_ooT0f?ol087oPOn1oh7oPOn1ooP0e?oh0?;o
n03eooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7on03DooP0l_oh0?GonP3BooX0
kooi0=Soo021oh7oPOn1oh7oUOl0M>gon03DooP0l_oh0?GonP3BooX0kooi0=So
o021oh7oPOn1oh7oPOoh0=Con03booP0mOoj0=;onP3_ooT0f?ol087oPOn1oh7o
POn1ooP0e?oh0?;on03eooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oiGo07S/ooT0
e?og0?GomP3eooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7o0?oi0=Com`3eooH0
mOoj0=;onP3_ooT0f?ol087oPOn1oh7oPOn1o`3on@3DooL0mOof0?GonP3BooX0
kooi0=Soo021oh7oPOn1oh7oUOl0QncomP3jo`400=oomP3hooL0looj0=;onP3_
ooT0f?ol087oPOn1oh7oPOn1o`3omP3jo`400=oomP3hooL0looj0=;onP3_ooT0
f?ol087oPOn1oh7oPOn1o`3omP3jo`400=oomP3hooL0looj0=;onP3_ooT0f?ol
087oPOn1oh7oPOnEo`27k?of0?[o0@00goof0?Som`3cooX0d_oj0>oon@3Hoo`0
POn1oh7oPOn1oh7o0?of0?[o0@00goof0?Som`3cooX0d_oj0>oon@3Hoo`0POn1
oh7oPOn1oh7o0?of0?[o0@00goof0?Som`3cooX0d_oj0>oon@3Hoo`0POn1oh7o
POn1oiGo06c/ond0gOoV0?;onP3BooX0kooi0=Soo021oh7oPOn1oh7oPOl0ond0
gOoV0?;onP3BooX0kooi0=Soo021oh7oPOn1oh7oPOl0ond0gOoV0?;onP3BooX0
kooi0=Soo021oh7oPOn1oh7oUOl0K>[ok`3LonT0l?oj0=;onP3_ooT0f?ol087o
POn1oh7oPOn1ookok`3LonT0l?oj0=;onP3_ooT0f?ol087oPOn1oh7oPOn1ooko
k`3LonT0l?oj0=;onP3_ooT0f?ol087oPOn1oh7oPOnEo`1/j_o_0=coj@3`ooX0
d_oj0>oon@3Hoo`0POn1oh7oPOn1oh7oo_o_0=coj@3`ooX0d_oj0>oon@3Hoo`0
POn1oh7oPOn1oh7oo_o_0=coj@3`ooX0d_oj0>oon@3Hoo`0POn1oh7oPOn1oiGo
06cYoo00fOo_0>gonP3BooX0kooi0=Soo021oh7oPOn1oh7oPOomoo00fOo_0>go
nP3BooX0kooi0=Soo021oh7oPOn1oh7oPOomoo00fOo_0>gonP3BooX0kooi0=So
o021oh7oPOn1oh7oUOl0C^Con03CooD0POoZoo`0POn1oh7oPOn1oh7on?oh0=?o
m@21on[oo021oh7oPOn1oh7oPOohooP0dooe087oj_ol087oPOn1oh7oPOnEo`1>
i?oh0=?om@21on[oo021oh7oPOn1oh7oPOohooP0dooe087oj_ol087oPOn1oh7o
POn1ooSon03CooD0POoZoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0f
POn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7o
POn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0@X7o^ook0=Ko
o021oh7oPOn1oh7oPOn1oloon`3Foo`0POn1oh7oPOn1oh7oPOo?oo/0e_ol087o
POn1oh7oPOnEo`12POnkoo/0e_ol087oPOn1oh7oPOn1oh7ocook0=Koo021oh7o
POn1oh7oPOn1oloon`3Foo`0POn1oh7oPOn1oiGo04:1okkon03Foo`0POn1oh7o
POn1oh7oPOoBooP0e_ol087oPOn1oh7oPOn1oh7od_oh0=Koo021oh7oPOn1oh7o
UOl0@X7o`Ooe0=Koo021oh7oPOn1oh7oPOn1omGom@3Foo`0POn1oh7oPOn1oh7o
POoEooD0e_ol087oPOn1oh7oPOnEo`12POo1ooD0e_ol087oPOn1oh7oPOn1oh7o
eOoe0=Koo021oh7oPOn1oh7oPOn1omGom@3Foo`0POn1oh7oPOn1oiGo04Z1ol?o
l`3Foo`0POn1oj;o0021oh7oPOn1okOol`3Foo`0POn1oj;o0021oh7oPOn1okOo
l`3Foo`0POn1oj;o0021oh7oPOoeo`1FPOo3oo/0o_ol0=Koo021oh7oZ?od087o
POn1oh7o_Ook0?koo03Foo`0POn1ojSom021oh7oPOn1okgon`3noo`0e_ol087o
POnXoo@0POn1oh7onol0EX7o`ook0?koo03Foo`0POn1ojWol@21oh7oPOn1okoo
n`3noo`0e_ol087oPOnYoo40POn1oh7oPOnooo/0o_ol0=Koo021oh7oZOoa087o
POn1oogo05N1ol?ooP3koo`0e_ol087oPOn[ond0POn1oh7oPOo1ooh0nool0=Ko
o021oh7oZoo]087oPOn1oh7o`Oon0?_oo03Foo`0POn1oj_ok@21oh7oPOl1ool0
BX7o^_ol0=Koo021oh7o[?o[087oPOn1oh7o^Ool0=Koo021oh7o[?o[087oPOn1
oh7o^Ool0=Koo021oh7o[?o[087oPOn1o`3o05J1ok[oo03Foo`0POn1ojgonP3h
ooX0POn1oh7oPOnioo`0e_ol087oPOn]ooX0n?oj087oPOn1oh7o^Ool0=Koo021
oh7o[Ooj0?SonP21oh7oPOl0o`1PPOoNood0hOol0=Koo021oh7o[_oj0?Gon`21
oh7oPOn1omkoo@3Qoo`0e_ol087oPOn^ooX0mOok087oPOn1oh7og_om0>7oo03F
oo`0POn1ojkonP3eoo/0POn1oh7o07:>ood0nooh0>Coo@3Qoo`0e_ol087oPOn^
oo`0l_ok087oPOn1ohooo@3kooP0i?om0>7oo03Foo`0POn1ojkoo03boo/0POn1
oh7oSoom0?_on03Tood0hOol0=Koo021oh7o[_ol0?;on`21oh7oP_l0LXkoo@3k
ooP0i?om0>7oo03Foo`0POn1ojooo@3^ood0POn1oh7oSoom0?_on03Tood0hOol
0=Koo021oh7o[oom0>koo@21oh7oPOn?ood0nooh0>Coo@3Qoo`0e_ol087oPOn_
ood0k_om087oPOn2o`1bS_om0?kolP3Wood0hOol0=Koo021oh7o/?ol0>koo021
oh7oPOn@ood0o_ob0>Ooo@3Qoo`0e_ol087oPOn`oo`0k_ol087oPOn1oi3oo@3n
oo80ioom0>7oo03Foo`0POn1ok3oo03^oo`0POn1oh?o07F>ood00Oook`3Yood0
hOol0=Koo021oh7o/?om0>coo021oh7oPOnAood00Oook`3Yood0hOol0=Koo021
oh7o/?om0>coo021oh7oPOnAood00Oook`3Yood0hOol0=Koo021oh7o/?om0>co
o021oh7oQ?l0MHkoo@01ooo_0>Woo@3Qoo`0e_ol087oPOn`ood0joom087oPOn1
oi7oo@01ooo_0>Woo@3Qoo`0e_ol087oPOn`ood0joom087oPOn1oi7oo@01ooo_
0>Woo@3Qoo`0e_ol087oPOn`ood0joom087oPOn4o`1bS_og0?Won`3Yood0hOol
0=Koo021oh7o/Ool0>_oo@21oh7oPOnAooL0nOok0>Woo@3Qoo`0e_ol087oPOna
oo`0joom087oPOn1oi7om`3ioo/0jOom0>7oo03Foo`0POn1ok7oo03[ood0POn1
ohCo07:>ooX0mOok0>[oo@3Qoo`0e_ol087oPOnaoo`0j_om087oPOn1oi;onP3e
oo/0j_om0>7oo03Foo`0POn1ok7oo03Zood0POn1oh7oT_oj0?Gon`3Zood0hOol
0=Koo021oh7o/Ool0>[oo@21oh7oQOl0LXkonP3eoo/0j_om0>7oo03Foo`0POn1
ok7oo@3Yood0POn1oh7oT_oj0?Gon`3Zood0hOol0=Koo021oh7o/Oom0>Woo@21
oh7oPOnBooX0mOok0>[oo@3Qoo`0e_ol087oPOnaood0jOom087oPOn5o`1bS_ok
0?;oo@3Zood0hOol0=Koo021oh7o/_ol0>Woo@21oh7oPOnBoo/0l_om0>[oo@3Q
oo`0e_ol087oPOnboo`0jOom087oPOn1oi;on`3bood0j_om0>7oo03Foo`0POn1
ok;oo03Yood0POn1ohGo07:>oo/0l_om0>[oo@3Qoo`0e_ol087oPOnboo`0jOom
087oPOn1oi;on`3bood0j_om0>7oo03Foo`0POn1ok;oo03Yood0POn1oh7oT_ok
0?;oo@3Zood0hOol0=Koo021oh7o/_ol0>Woo@21oh7oQOl0LXkon`3bood0j_om
0>7oo03[om80POn1olOoo03Yood0POn1oh7oT_ok0?;oo@3Zood0hOol0>_odP21
oh7oaool0>Woo@21oh7oPOnBoo/0l_om0>[oo@3Qoo`0jooB087oPOo7oo`0jOom
087oPOn5o`1bS_om0?3oo@3Zood0hOol0>_odP21oh7oa_ol0>[oo@21oh7oPOnB
ood0l?om0>[oo@3Qoo`0jooB087oPOo6oo`0j_om087oPOn1oi;oo@3`ood0j_om
0>7oo03[om80POn1olKoo03Zood0POn1ohGo07:>ood0l?om0?Soh@3_oo`0jooB
087oPOo6oo`0jool087oPOn1oi;oo@3`ood0n?oQ0>ooo03[om80POn1olKoo03[
oo`0POn1oh7oT_om0?3oo@3hon40kool0>_odP21oh7oa_ol0>_oo021oh7oQOl0
LXkoo@3`ood0n?oQ0>ooo03[om80POn1olKoo03[ood0POn1oh7oTOom0?3oo@3h
on40kool0>_odP21oh7oa_ol0>_oo@21oh7oPOnAood0l?om0?Soh@3_oo`0jooB
087oPOo6oo`0joom087oPOn4o`1bS_om0?3oo@3hon40kool0=Koo021oh7o/?om
0>coo021oh7oPOnAood0l?om0?Soh@3_oo`0e_ol087oPOn`ood0k?ol087oPOn1
oi7oo@3`ood0n?oQ0>ooo03Foo`0POn1ok3oo@3/oo`0POn1ohCo07:>ood0l?om
0?Soh@3_oo`0e_ol087oPOn`ood0k?ol087oPOn1oi7oo@3`ood0n?oQ0>ooo03F
oo`0POn1ok3oo@3/oo`0POn1oh7oTOom0?3oo@3hon40kool0=Koo021oh7o/?om
0>coo021oh7oQ?l0LXkoo@3`ood0n?oQ0>ooo03Foo`0POn1ok3oo03^oo`0POn1
oh7oT?om0?3oo@3hon40kool0=Koo021oh7o/?ol0>koo021oh7oPOn@ood0l?om
0?Soh@3_oo`0e_ol087oPOn`oo`0k_ol087oPOn3o`1bS_om0?3oo@3Zood0hOol
0=Koo021oh7o[ool0>ooo@21oh7oPOn?ood0l?om0>[oo@3Qoo`0e_ol087oPOn_
oo`0koom087oPOn1ohooo@3`ood0j_om0>7oo03Foo`0POn1ojooo03_ood0POn1
oh;o07:>ood0l?om0>[oo@3Qoo`0e_ol087oPOn^oo/0look087oPOn1ohooo@3`
ood0j_om0>7oo03Foo`0POn1ojkon`3coo/0POn1oh7oSoom0?3oo@3Zood0hOol
0=Koo021oh7o[_ok0??on`21oh7oP_l0LXkoo@3`ood0j_om0>7oo03Foo`0POn1
ojkonP3fooX0POn1oh7oS_om0?3oo@3Zood0hOol0=Koo021oh7o[_oj0?KonP21
oh7oPOn>ood0l?om0>[oo@3Qoo`0e_ol087oPOn^ooX0m_oj087oPOn1o`1dS_om
0?3oo@3Zood0hOol0=Koo021oh7o[Ooj0?SonP21oh7oPOn=ood0l?om0>[oo@3Q
oo`0e_ol087oPOn]ooX0n?oj087oPOn1ohgoo@3`ood0j_om0>7oo03Foo`0POn1
ojgonP3hooX0POn1oh7o0?l0J8koo@3`ood0j_om0>7oo03Foo`0POn1ojcoj`21
oh7oPOn=ood0l?om0>[oo@3Qoo`0e_ol087oPOn/on/0POn1oh7oSOom0?3oo@3Z
ood0hOol0=Koo021oh7o[?o[087oPOn1o`3o06R>ood0l?om0>[oo@3Qoo`0e_ol
087oPOnZonl0POn1oh7oRoom0?3oo@3Zood0hOol0=Koo021oh7oZ_o_087oPOn1
oh_oo@3`ood0j_om0>7oo03Foo`0POn1oj[ok`21oh7oPOono`1XS_om0?3oo@3Z
ood0hOol0=Koo021oh7oZOoa087oPOn1oh[oo@3`ood0j_om0>7oo03Foo`0POn1
ojWol@21oh7oPOn:ood0l?om0>[oo@3Qoo`0e_ol087oPOnYoo40POn1oh7ooOl0
J8koo@3`ood0j_om0>7oo03Foo`0POn1ojOomP21oh7oPOn7ood0l?om0>[oo@3Q
oo`0e_ol087oPOnWooH0POn1oh7oQoom0?3oo@3Zood0hOol0=Koo021oh7oYoof
087oPOn1oo[o062>ood0l?om0>[oo@3Qoo`0e_ol087oPOn1oh7oPOn1oj;oo@3`
ood0j_om0>7oo03Foo`0POn1oh7oPOn1oh7oX_om0?3oo@3Zood0hOol0=Koo021
oh7oPOn1oh7oUOl0H8koo@3`ood0j_om0>7oo03Foo`0POn1oh7oPOn1oh7oX_om
0?3oo@3Zood0hOol0=Koo021oh7oPOn1oh7oPOnRood0l?om0>[oo@3Qoo`0e_ol
087oPOn1oh7oPOnEo`1PS_om0?3oo@3Zood0hOol0=Koo021oh7oPOn1oh7oPOnR
ood0l?om0>[oo@3Qoo`0e_ol087oPOn1oh7oPOn1oj;oo@3`ood0j_om0>7oo03F
oo`0POn1oh7oPOn1oiGo062>ood0l?om0>[oo@3Qoo`0e_ol087oPOn1oh7oPOn1
oj;oo@3`ood0j_om0>7oo03Foo`0POn1oh7oPOn1oh7oX_om0?3oo@3Zood0hOol
0=Koo021oh7oPOn1oh7oUOl0H8koo@3`ood0j_om0>7oo03Foo`0POn1oh7oPOn1
oh7oX_om0?3oo@3Zood0hOol0=Koo021oh7oPOn1oh7oPOnRood0l?om0>[oo@3Q
oo`0e_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`12POn:
oo`0POn1ojGoo@21oh7oPOn1oh7oo_ol087oPOnUood0POn1oh7oPOn1ookoo021
oh7oYOom087oPOn1ooGo04:1oh[oo021oh7oYOom087oPOn1oh7oPOonoo`0POn1
ojGoo@21oh7oPOn1oh7oo_ol087oPOnUood0POn1oh7omOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`12POn:oo`0POn1ojGoo@21oh7oPOn1oh7oo_ol
087oPOnUood0POn1oh7oPOn1ookoo021oh7oYOom087oPOn1ooGo04:1oh[oo021
oh7oYOom087oPOn1oh7oPOonoo`0POn1ojGoo@21oh7oPOn1oh7oo_ol087oPOnU
ood0POn1oh7omOl0@X7oR_ol087oPOnUood0POn1oh7oPOn1ookoo021oh7oYOom
087oPOn1oh7oPOonoo`0POn1ojGoo@21oh7oPOoeo`12POn:oo`0POn1ojGoo@21
oh7oPOn1oh7oo_ol087oPOnUood0POn1oh7oPOn1ookoo021oh7oYOom087oPOn1
ooGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0@X7oR_ol087oPOnU
ood0POn1oh7oPOn1ookoo021oh7oYOom087oPOn1oh7oPOonoo`0POn1ojGoo@21
oh7oPOoeo`12POn:oo`0POn1ojGoo@21oh7oPOn1oh7oo_ol087oPOnUood0POn1
oh7oPOn1ookoo021oh7oYOom087oPOn1ooGo04:1oh[oo021oh7oYOom087oPOn1
oh7oPOonoo`0POn1ojGoo@21oh7oPOn1oh7oo_ol087oPOnUood0POn1oh7omOl0
@X7oR_ol087oPOnUood0POn1oh7oPOn1ookoo021oh7oYOom087oPOn1oh7oPOon
oo`0POn1ojGoo@21oh7oPOoeo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0@X7oR_ol087oPOnUood0POn1oh7oPOn1ookoo021oh7oYOom
087oPOn1oh7oPOonoo`0POn1ojGoo@21oh7oPOoeo`12POn:oo`0POn1ojGoo@21
oh7oPOn1oh7oo_ol087oPOnUood0POn1oh7oPOn1ookoo021oh7oYOom087oPOn1
ooGo04:1oh[oo021oh7oYOom087oPOn1oh7oPOonoo`0POn1ojGoo@21oh7oPOn1
oh7oo_ol087oPOnUood0POn1oh7omOl0@X7oR_ol087oPOnUood0POn1oh7oPOn1
ookoo021oh7oYOom087oPOn1oh7oPOonoo`0POn1ojGoo@21oh7oPOoeo`0fPOn:
oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo04:1oh[oo021oh7oYOom087oPOn1
oh7oPOonoo`0POn1ojGoo@21oh7oPOn1oh7oo_ol087oPOnUood0POn1oh7omOl0
@X7oR_ol087oPOnUood0POn1oh7oPOn1ookoo021oh7oYOom087oPOn1oh7oPOon
oo`0POn1ojGoo@21oh7oPOoeo`12POn:oo`0POn1ojGoo@21oh7oPOn1oh7oo_ol
087oPOnUood0POn1oh7oPOn1ookoo021oh7oYOom087oPOn1ooGo04:1oh[oo021
oh7oYOom087oPOn1oh7oPOonoo`0POn1ojGoo@21oh7oPOn1oh7oo_ol087oPOnU
ood0POn1oh7omOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1
oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1
oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`12POn:
oo`0POn1ojGoo@21oh7oPOn1oh7oo_ol087oPOnUood0POn1oh7oPOn1ookoo021
oh7oYOom087oPOn1ooGo04:1oh[oo021oh7oYOom087oPOn1oh7oPOonoo`0POn1
ojGoo@21oh7oPOn1oh7oo_ol087oPOnUood0POn1oh7omOl0EX7odOom0?;om@3I
oo`0POn1ojGoo@21oh7oPOn1olGoo@3booD0fOol087oPOnUood0POn1oh7oPOo5
ood0l_oe0=Woo021oh7oYOom087oPOn1ooGo06:1ookon`3Loo`0m?o_0=coo021
oh7oYOom087oPOn1oh7ol_ok0=coo03donl0g?ol087oPOnUood0POn1oh7oPOob
oo/0g?ol0?Cok`3Loo`0POn1ojGoo@21oh7oPOoeo`1FPOonoo/0g?ol0?Cok`3L
oo`0POn1oh7oPOn1oh7oT_ok0=coo03donl0g?ol087oPOn1oh7oPOn1oi;on`3L
oo`0m?o_0=coo021oh7oPOn1oh7oUOl0E87on03Loo`0mOo/0=koo021oh7oPOn1
oh7oPOnEooP0g?ol0?Gok03Noo`0POn1oh7oPOn1oh7oUOoh0=coo03eon`0g_ol
087oPOn1oh7oPOnEo`1PQ?oe0=goo@3eoo/0m_oj0=ooo021oh7oPOn1oh7oPOnH
ooD0gOom0?Gon`3fooX0gool087oPOn1oh7oPOn1oiSom@3Mood0mOok0?KonP3O
oo`0POn1oh7oPOn1oiGo0624ooD0gOom0?Gon`3fooX0gool087oPOn1oh7oPOn1
oiSom@3Mood0mOok0?KonP3Ooo`0POn1oh7oPOn1oh7oV?oe0=goo@3eoo/0m_oj
0=ooo021oh7oPOn1oh7oUOl0H8Kol`3Mood0m_ok0?;on`3Qoo`0POn1oh7oPOn1
oh7oV_oc0=goo@3foo/0l_ok0>7oo021oh7oPOn1oh7oPOnJoo<0gOom0?Kon`3b
oo/0hOol087oPOn1oh7oPOnEo`1hQ_ok0?koo03Ooo`0mOom0>ooo03Qoo`0POn1
ojGoo@21oh7oPOn1oo[on`3noo`0gool0?Goo@3_oo`0hOol087oPOnUood0POn1
oh7oPOojoo/0o_ol0=ooo03eood0kool0>7oo021oh7oYOom087oPOn1ooGo07j6
oo/0o_ol0=ooo03eood0kool0>7oo021oh7oYOom0:[o0961oh7oPOoBoo/0o_ol
0=ooo03eood0kool0>7oo021oh7oYOom0:[o0961oh7oPOoBoo/0o_ol0=ooo03e
ood0kool0>7oo021oh7oYOom0:[o0961oh7ocOl0N8KooP3koo`0gool0=ooo03Q
oo`0POn2ooFA/?om0;3omI61oh7oPOoGooh0nool0=ooo03Ooo`0hOol087oP_oe
TK3oo@2`ooFAPOn1oh7oeoon0?_oo03Ooo`0gool0>7oo021oh;omI6`ood0/?oe
TH7oPOoBo`1^POomoo`0h?om0=goo03Qoo`0POn3oo>A/Oom0;7oli61oh7oPOo?
oo`0h?om0=goo03Qoo`0POn3oo>A/Oom0;7oli61oh7oPOo?oo`0h?om0=goo03Q
oo`0POn3oo>A/Oom0;7oli61oh7odol0J87ooOol0>3oo@3Moo`0hOol087oQ?o`
TH7oh?o`TH7oPOn1om7oo03Pood0gOol0>7oo021ohCol961on3ol961oh7oPOoA
oo`0h?om0=goo03Qoo`0POn4oo2APOoPoo2APOn1omGo07:Rood0h?ol0>3oo@3M
oo`0hOol087oQ_o]TH7ohoo]TH7oPOn1ooOoo@3Poo`0h?om0=goo03Qoo`0POn6
onfAPOoSonfAPOn1oh7omoom0>3oo03Pood0gOol0>7oo021ohKokI61on?okI61
oh7oe_l0W]7oo@3kooP0iOom0>3oo03Roo`0gOom0=ooo021ohSonI7iooVAPOoW
ooVAnOoiTH7oPOnXood0nooh0>Goo@3Poo`0h_ol0=goo@3Ooo`0POn8ooVAnOoi
TH7oiooiTOWonI61oh7oZ?om0?_on03Uood0h?ol0>;oo03Mood0gool087oR?oi
TOWonI61onOonI7iooVAPOn1omSo09kAood0nooh0>Goo@3Poo`0h_ol0=goo@3O
oo`0POn9ooZAmOojTH7ojOojTOGonY61oh7oZOom0?_on03Uood0h?ol0>;oo03M
ood0gool087oROojTOGonY61onWonY7eooZAPOn1ojWoo@3kooP0iOom0>3oo03R
oo`0gOom0=ooo021ohWonY7eooZAPOoYooZAmOojTH7oPOoIo`2TdOom0?kolP3X
ood0h?ol0>;oo03Mood0gool087oROokTO;oo96good0]ookTO;oo961oh7oZOom
0?kolP3Xood0h?ol0>;oo03Mood0gool087oROokTO;oo96good0]ookTO;oo961
oh7oZOom0?kolP3Xood0h?ol0>;oo03Mood0gool087oROokTO;oo96good0]ook
TO;oo961oh7ofOl0Ym7oo@01ooo_0>[oo@3Poo`0hoom0=goo03Noo`0POn:oo^A
lOokTKSoo@2hoo^AlOokTH7oPOnZood00Oook`3Zood0h?ol0>?oo@3Moo`0g_ol
087oR_okTO7oni6hood0^?okTO7oni61oh7oZ_om007oonl0j_om0>3oo03Sood0
gOol0=koo021oh[oni7aoo^A^?om0;Soni7aoo^APOn1om[o0:OAood00Oook`3Z
ood0h?ol0>?oo@3Moo`0g_ol087oR_olTNooni6iood0^?olTNooni61oh7oZoom
007oonl0j_om0>3oo03Sood0gOol0=koo021oh[oo97_oo^A^Oom0;Soo97_oo^A
POn1oj_oo@01ooo_0>[oo@3Poo`0hoom0=goo03Noo`0POn:oobAkookTKWoo@2h
oobAkookTH7oPOoKo`2TdOog0?Won`3Zood0h?ol0>?oo@3Poo/0g?ol087oRook
TNkoo96iood0^OokTNkoo961oh7oZoog0?Won`3Zood0h?ol0>?oo@3Poo/0g?ol
087oRookTNkoo96iood0^OokTNkoo961oh7oZoog0?Won`3Zood0h?ol0>?oo@3P
oo/0g?ol087oRookTNkoo96iood0^OokTNkoo961oh7ofol0W]7onP3eoo/0joom
0>3oo03Uoo`0h?ok0=_oo021oh_oo97]oobAPOo]oobAkOolTH7oPOn[ooX0mOok
0>_oo@3Poo`0iOol0>3on`3Koo`0POn;oobAkOolTH7okOolTNgoo961oh7oZooj
0?Gon`3[ood0h?ol0>Goo03Poo/0fool087oRoolTNgoo961ongoo97]oobAPOn1
om_o09kAooX0mOok0>_oo@3Poo`0iOol0>3on`3Koo`0POn;oofAjoomTH7okOom
TN_ooI61oh7oZooj0?Gon`3[ood0h?ol0>Goo03Poo/0fool087oRoomTN_ooI61
ongooI7[oofAPOn1oj_onP3eoo/0joom0>3oo03Uoo`0h?ok0=_oo021oh_ooI7[
oofAPOo]oofAjoomTH7oPOoKo`2NdOok0?;oo@3[ood0h?ol0>Kon`3Roo/0fOol
087oRoomTN_oo961onkooI7[oobAPOn1ojcon`3bood0joom0>3oo03Voo/0h_ok
0=Woo021oh_ooI7[oobAPOo^oofAjoolTH7oPOn/oo/0l_om0>_oo@3Poo`0i_ok
0>;on`3Ioo`0POn;oofAjoolTH7ok_omTN_oo961oh7og?l1C=7on`3bood0joom
0>3oo03Vood0hooi0=Soo021ohcoo97ZoofAkool0?goo@3mood0oOol0?goo@3m
ood0oOol0?goo@3mood0oOol0?goo@3mood0oOol0?goo@3mo`00moolTN[ooI61
oh7o[?ok0?;oo@3[ood0h?ol0>Koo@3SooT0f?ol087oS?olTN[ooI7_oo`0oOom
0?goo@3moo`0oOom0?goo@3moo`0oOom0?goo@3moo`0oOom0?goo@3moo`0oOom
0?go003goobAj_omTH7oPOn/oo/0l_om0>_oo@3Poo`0i_om0>?on@3Hoo`0POn<
oobAj_omTNooo03mood0oOom0?goo03mood0oOom0?goo03mood0oOom0?goo03m
ood0oOom0?goo03mood0oOl00?Ooo97ZoofAPOn1omco0DoAoo/0l_om0>_oo@3P
oo`0i_om0>?on@3Hoo`0POn<oofAjOomTNooo03mood0oOom0?goo03mood0oOom
0?gonP01ooom0?goo@3moo`0oOom0?goo@3moo`0oOom0?go003goofAjOomTH7o
POn/oo/0l_om0>_oo@3Poo`0i_om0>?on@3Hoo`0POn<oofAjOomTNooo03mood0
oOom0?goo03mood0oOom0?gonP01ooom0?goo@3moo`0oOom0?goo@3moo`0oOom
0?go003goofAjOomTH7oPOn/oo/0l_om0>_oo@3Poo`0i_om0>?on@3Hoo`0POn<
oofAjOomTNooo03mood0oOom0?goo03mood0oOom0?gonP01ooom0?goo@3moo`0
oOom0?goo@3moo`0oOom0?go003goofAjOomTH7oPOoLo`5?dOom0?3oo@3[ood0
h?ol0>Soo03Soo/0eOol087oS?omTNWooI7_oo`0oOom0?goo@3moo`0oOom0?go
o@3mooX00Oooo@3mood0oOol0?goo@3mood0oOol0?goo@3mo`00moomTNWooI61
oh7o[?om0?3oo@3[ood0h?ol0>Soo03Soo/0eOol087oS?omTNWooI7_oo`0oOom
0?goo@3moo`0oOom0?goo@3mooX00Oooo@3mood0oOol0?goo@3mood0oOol0?go
o@3mo`00moomTNWooI61oh7o[?om0?3oo@3[ood0h?ol0>Soo03Soo/0eOol087o
S?omTNWooI7_oo`0oOom0?goo@3moo`0oOom0?goo@3mooX00Oooo@3mood0oOol
0?goo@3mood0oOol0?goo@3mo`00moomTNWooI61oh7og?l1Cm7oo@3`ood0nOoQ
0>koo03Xoo`0iOok0=?oo021ohcooI7YoofAkool0?goo@3mood0oOol0?goo@3m
ood0oOoj007oood0oOom0?goo03mood0oOom0?goo03mood0oOl00?OooI7YoofA
POn1ojcoo@3`ood0nOoQ0>koo03Xoo`0iOok0=?oo021ohcooI7YoofAkool0?go
o@3mood0oOol0?goo@3mood0oOoj007oood0oOom0?goo03mood0oOom0?goo03m
ood0oOl00?OooI7YoofAPOn1ojcoo@3`ood0nOoQ0>koo03Xoo`0iOok0=?oo021
ohcooI7YoofAkool0?goo@3mood0oOol0?goo@3mood0oOoj007oood0oOom0?go
o03mood0oOom0?goo03mood0oOl00?OooI7YoofAPOn1omco0:CAood0l?om0?Wo
h@3^oo`0j?ol0>Gon`3Coo`0POn<oobAj_omTK[oo@2joobAj_omTH7oPOn/ood0
l?om0?Woh@3^oo`0j?ol0>Gon`3Coo`0POn<oobAj_omTK[oo@2joobAj_omTH7o
POn/ood0l?om0?Woh@3^oo`0j?ol0>Gon`3Coo`0POn<oobAj_omTK[oo@2joobA
j_omTH7oPOoLo`2NdOom0?3oo@3ion40k_ol0>Woo@3Tood0d?ol087oRoomTN_o
o961onkooI7[oobAPOn1ojcoo@3`ood0nOoQ0>koo03Yood0i?om0=3oo021oh_o
oI7[oobAPOo^oofAjoolTH7oPOn/ood0l?om0?Woh@3^oo`0jOom0>Coo@3@oo`0
POn;oofAjoolTH7ok_omTN_oo961oh7og?l0W]7oo@3`ood0nOoQ0>koo03Yood0
i_ol0<ooo021oh_ooI7[oofAPOo]oofAjoomTH7oPOn[ood0l?om0?Woh@3^oo`0
jOom0>Koo03?oo`0POn;oofAjoomTH7okOomTN_ooI61oh7oZoom0?3oo@3ion40
k_ol0>Woo@3Voo`0cool087oRoomTN_ooI61ongooI7[oofAPOn1om_o09kAood0
l?om0?Woh@3^oo`0jOom0>Koo03?oo`0POn;oofAjoomTH7okOomTN_ooI61oh7o
Zoom0?3oo@3ion40k_ol0>Woo@3Voo`0cool087oRoomTN_ooI61ongooI7[oofA
POn1oj_oo@3`ood0nOoQ0>koo03Yood0i_ol0<ooo021oh_ooI7[oofAPOo]oofA
joomTH7oPOoKo`2NdOom0?3oo@3[ood0h?ol0>_oo03Vood0cOol087oRoolTNgo
o961ongoo97]oobAPOn1oj_oo@3`ood0joom0>3oo03[oo`0i_om0<goo021oh_o
o97]oobAPOo]oobAkOolTH7oPOn[ood0l?om0>_oo@3Poo`0jool0>Koo@3=oo`0
POn;oobAkOolTH7okOolTNgoo961oh7ofol0W]7oo@3`ood0joom0>3oo03[oo`0
j?ol0<coo021oh_oni7^oobAPOo]oo^Ak_olTH7oPOn[ood0l?om0>_oo@3Poo`0
jool0>Soo03<oo`0POn;oo^Ak_olTH7okOokTNkoo961oh7oZoom0?3oo@3[ood0
h?ol0>_oo03Xoo`0c?ol087oRookTNkoo961ongoni7^oobAPOn1om_o0:CAood0
l?om0>_oo@3Poo`0jool0>Soo03<oo`0POn:oobAkoolTKSoo@2hoobAkoolTH7o
POnZood0l?om0>_oo@3Poo`0jool0>Soo03<oo`0POn:oobAkoolTKSoo@2hoobA
koolTH7oPOnZood0l?om0>_oo@3Poo`0jool0>Soo03<oo`0POn:oobAkoolTKSo
o@2hoobAkoolTH7oPOoJo`2TdOom0?3oo@3[ood0h?ol0>coo@3Voo`0c?ol087o
ROolTO7oni6hood0]oolTO7oni61oh7oZ_om0?3oo@3[ood0h?ol0>coo@3Voo`0
c?ol087oROolTO7oni6hood0]oolTO7oni61oh7oZ_om0?3oo@3[ood0h?ol0>co
o@3Voo`0c?ol087oROolTO7oni6hood0]oolTO7oni61oh7of_l0Y=7oo@3`ood0
joom0>3oo03/ood0ioom0<[oo021ohWoni7coo^A]oom0;Ooni7coo^APOn1ojWo
o@3`ood0joom0>3oo03/ood0ioom0<[oo021ohWoni7coo^A]oom0;Ooni7coo^A
POn1ojWoo@3`ood0joom0>3oo03/ood0ioom0<[oo021ohWoni7coo^A]oom0;Oo
ni7coo^APOn1omWo0:CAood0l?om0>_oo@3Poo`0k?om0>Ooo@3:oo`0POn8ooZA
m_okTKKoo@2fooZAm_okTH7oPOnXood0l?om0>_oo@3Poo`0k?om0>Ooo@3:oo`0
POn8ooZAm_okTKKoo@2fooZAm_okTH7oPOnXood0l?om0>_oo@3Poo`0k?om0>Oo
o@3:oo`0POn8ooZAm_okTKKoo@2fooZAm_okTH7oPOoHo`26dOom0?3oo@3[ood0
h?ol0>koo03Vood0b_ol087oQoo[TH7oiOo[TH7oPOnWood0l?om0>_oo@3Poo`0
k_ol0>Koo@3:oo`0POn7on^APOoUon^APOn1ojOoo@3`ood0joom0>3oo03^oo`0
i_om0<[oo021ohOoji61onGoji61oh7oeol0Q]7oo@3`ood0joom0>3oo03^oo`0
i_om0<[oo021ohGokY61on;okY61oh7oY_om0?3oo@3[ood0h?ol0>koo03Vood0
b_ol087oQOo^TH7oh_o^TH7oPOnVood0l?om0>_oo@3Poo`0k_ol0>Koo@3:oo`0
POn5onjAPOoRonjAPOn1omKo08KAood0l?om0>_oo@3Poo`0k_ol0>Koo@3:oo`0
POn4oo6APOoOoo6APOn1ojCoo@3`ood0joom0>3oo03^oo`0i_om0<[oo021ohCo
lI61omoolI61oh7oY?om0?3oo@3[ood0h?ol0>koo03Vood0b_ol087oQ?oaTH7o
gooaTH7oPOoDo`26dOom0?3oo@3[ood0h?ol0>ooo@3TonD0h_ol087oP_oeTH7o
fooeTH7oPOnRood0l?om0>_oo@3Poo`0koom0>Coi@3Roo`0POn2ooFAPOoKooFA
POn1oj;oo@3`ood0joom0>3oo03_ood0i?oU0>;oo021oh;omI61om_omI61oh7o
d_l0Q]7oo@3`ood0joom0>3oo03_ood0i?oU0>;oo021oh7oYOom0:[o0961oh7o
WOom0?3oo@3[ood0h?ol0>ooo@3TonD0h_ol087oPOnUood0Z_l0TH7oPOnMood0
l?om0>_oo@3Poo`0koom0>Coi@3Roo`0POn1ojGoo@2Zo`2APOn1olgo083Aood0
l?om0>_oo@3Poo`0koom0>Coi@3Roo`0POn1ojGoo@21oh7oPOo5ood0l?om0>_o
o@3Poo`0koom0>Coi@3Roo`0POn1ojGoo@21oh7oPOo5ood0l?om0>_oo@3Poo`0
koom0>Coi@3Roo`0POn1ojGoo@21oh7oPOoeo`20dOom0?3oo@3[ood0h?ol0?7o
o03SonD0h_ol087oPOnUood0POn1oh7oaOom0?3oo@3[ood0h?ol0?7oo03SonD0
h_ol087oPOnUood0POn1oh7oaOom0?3oo@3[ood0h?ol0?7oo03SonD0h_ol087o
POnUood0POn1oh7omOl0@X7oR_ol087oPOnUood0POn1oh7oPOn1ookoo021oh7o
YOom087oPOn1oh7oPOonoo`0POn1ojGoo@21oh7oPOoeo`0fPOn:oo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[o
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
UOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oiGo04:1oh[oo021oh7oYOom087oPOn1oh7oPOonoo`0
POn1ojGoo@21oh7oPOn1oh7oo_ol087oPOnUood0POn1oh7omOl0@X7oR_ol087o
POnUood0POn1oh7oPOn1ookoo021oh7oYOom087oPOn1oh7oPOonoo`0POn1ojGo
o@21oh7oPOoeo`12POn:oo`0POn1ojGoo@21oh7oPOn1oh7oo_ol087oPOnUood0
POn1oh7oPOn1ookoo021oh7oYOom087oPOn1ooGo04:1oh[oo021oh7oYOom087o
POn1oh7oPOonoo`0POn1ojGoo@21oh7oPOn1oh7oo_ol087oPOnUood0POn1oh7o
mOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo04:1oh[o
o021oh7oYOom087oPOn1oh7oPOonoo`0POn1ojGoo@21oh7oPOn1oh7oo_ol087o
POnUood0POn1oh7omOl0@X7oR_ol087oPOnUood0POn1oh7oPOn1ookoo021oh7o
YOom087oPOn1oh7oPOonoo`0POn1ojGoo@21oh7oPOoeo`12POn:oo`0POn1ojGo
o@21oh7oPOn1oh7oo_ol087oPOnUood0POn1oh7oPOn1ookoo021oh7oYOom087o
POn1ooGo04:1oh[oo021oh7oYOom087oPOn1oh7oPOonoo`0POn1ojGoo@21oh7o
POn1oh7oo_ol087oPOnUood0POn1oh7omOl0=X7oR_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[o
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
UOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOnEo`12POn:oo`0POn1ojGoo@21oh7oPOn1oh7oo_ol087oPOnUood0
POn1oh7oPOn1ookoo021oh7oYOom087oPOn1ooGo04:1oh[oo021oh7oYOom087o
POn1oh7oPOonoo`0POn1ojGoo@21oh7oPOn1oh7oo_ol087oPOnUood0POn1oh7o
mOl0@X7oR_ol087oPOnUood0POn1oh7oPOn1ookoo021oh7oYOom087oPOn1oh7o
POonoo`0POn1ojGoo@21oh7oPOoeo`12POn:oo`0POn1ojGoo@21oh7oPOn1oh7o
o_ol087oPOnUood0POn1oh7oPOn1ookoo021oh7oYOom087oPOn1ooGo03J1oh[o
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
UOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0@X7oR_ol087oPOnUood0POn1oh7o
POn1ookoo021oh7oYOom087oPOn1oh7oPOonoo`0POn1ojGoo@21oh7oPOoeo`12
POn:oo`0POn1ojGoo@21oh7oPOn1oh7oo_ol087oPOnUood0POn1oh7oPOn1ooko
o021oh7oYOom087oPOn1ooGo04:1oh[oo021oh7oYOom087oPOn1oh7oPOonoo`0
POn1ojGoo@21oh7oPOn1oh7oo_ol087oPOnUood0POn1oh7omOl0@X7oR_ol087o
POnUood0POn1oh7oPOn1ookoo021oh7oYOom087oPOn1oh7oPOonoo`0POn1ojGo
o@21oh7oPOoeo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[o
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
UOl0@X7oR_ol087oPOnUood0POn1oh7oPOn1ookoo021oh7oYOom087oPOn1oh7o
POonoo`0POn1ojGoo@21oh7oPOoeo`12POn:oo`0POn1ojGoo@21oh7oPOn1oh7o
o_ol087oPOnUood0POn1oh7oPOn1ookoo021oh7oYOom087oPOn1ooGo04:1oh[o
o021oh7oYOom087oPOn1oh7oPOonoo`0POn1ojGoo@21oh7oPOn1oh7oo_ol087o
POnUood0POn1oh7omOl0@X7oR_ol087oPOnUood0POn1oh7oPOn1ookoo021oh7o
YOom087oPOn1oh7oPOonoo`0POn1ojGoo@21oh7oPOoeo`0fPOn:oo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[o
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
UOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7o
W_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7o
POn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[o
o021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
UOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oiGo04:1oh[oo021oh7oPOn1onKo0021oh7oPOnjoo`0
POn1oh7oPOoVo`00POn1oh7o^_ol087oPOn1oh7oi_l0087o/Ol0K87ob?om0?_o
n03Foo`0POo>oo<0POoSo`00POo=oo<0POn1oh7oo_om0?_on03Foo`0POo>oo<0
POoSo`00POo=oo<0POn1oh7oo_om0?_on03Foo`0POo>oo<0POoSo`00POo=oo<0
POngo`1/POo8ood0nooh0=Koo021olool021on_om021omCol021oh7oPOl0ood0
nooh0=Koo021olool021on_om021omCol021oh7oPOl0ood0nooh0=Koo021oloo
l021on_om021omCol021okWo06R1olSoo@3noo80fOol087odOo]087ok?od087o
e_o]087oPOn1ood0o_ob0=Woo021om7ok@21oncom021omKok@21oh7oPOom0?ko
lP3Ioo`0POoAond0POo/oo@0POoFond0POnjo`1[POo8ood00Oook`3Koo`0POoB
on/0POo^oo40POoIonX0POn1oh?oo@01ooo_0=_oo021om;oj`21onkol@21omWo
jP21oh7oPoom007oonl0fool087od_o[087ok_oa087ofOoZ087o_?l0Jh7ob?om
007oonl0fool087odooY087olOo]087og?oY087oPOn3ood00Oook`3Koo`0POoC
onT0POoaond0POoLonT0POn1oh?oo@01ooo_0=_oo021om?oj@21oo7ok@21omco
j@21okco06R1olSom`3ioo/0fool087oe?oW087om?oZ087og_oW087oPOn4ooL0
nOok0=_oo021omCoi`21ooCojP21omkoi`21oh7oQ?og0?Won`3Koo`0POoDonL0
POodonX0POoNonL0POnmo`1XPOo8ooX0mOok0=coo021omCoiP21ooKoj021omoo
iP21oh7oQOoj0?Gon`3Loo`0POoDonH0POofonP0POoOonH0POn1ohGonP3eoo/0
g?ol087oe?oV087om_oX087ogooV087o__l0J87ob?oj0?Gon`3Loo`0POoEonD0
POofonP0POoPonD0POn1ohGonP3eoo/0g?ol087oeOoU087om_oX087oh?oU087o
POn5ooX0mOok0=coo021omGoi@21ooKoj021on3oi@21okko06R1olSon`3bood0
lOoB087ojooS087on?oV087oh_oS087oPOn6oo/0l_om0?7odP21on_oh`21ooSo
iP21on;oh`21oh7oQ_ok0?;oo@3aom80POo[on<0POohonH0POoRon<0POnoo`1X
POo8oo/0l_om0?7odP21on_oh`21ooSoi@21on?oh`21oh7oQ_ok0?;oo@3aom80
POo[on<0POohonD0POoSon<0POn1ohKon`3bood0lOoB087ojooS087on?oU087o
hooS087o_ol0J87ob?ok0?;oo@3aom80POo[on<0POoion<0POoTon<0POn1ohKo
n`3bood0lOoB087ojooS087onOoS087oi?oS087oPOn6oo/0l_om0?7odP21on_o
h`21ooWoh`21onCoh`21okoo06R1olSoo@3`ood0lOoB087ojooR087on_oS087o
i?oR087oPOn7ood0l?om0?7odP21on_ohP21oo[oh`21onCohP21oh7oQoom0?3o
o@3aom80POo[on80POojon<0POoTon80POo0o`1XPOo8ood0l?om0=coo021omOo
h@21oo[oh`21onGoh@21oh7oQoom0?3oo@3Loo`0POoGon40POojon<0POoUon40
POn1ohOoo@3`ood0g?ol087oeooQ087on_oS087oiOoQ087o`?l0J87ob?om0?3o
o@3Loo`0POoGon40POokon40POoVon40POn1ohOoo@3`ood0g?ol087oeooQ087o
nooQ087oi_oQ087oPOn7ood0l?om0=coo021omOoh@21oo_oh@21onKoh@21ol3o
06R1olSoo@3`ood0g?ol087oeooQ087onooQ087oi_oQ087oPOn7ood0l?om0=co
o021omOoh@21oo_oh@21onKoh@21oh7oQoom0?3oo@3Loo`0POoGon40POokon40
POoVon40POo0o`1XPOo8ood0l?om0=coo021omOoh@21oocoh021onKoh@21oh7o
Qoom0?3oo@3Loo`0POoGon40POolon00POoVon40POn1ohOoo@3`ood0g?ol087o
eooQ087oo?oP087oi_oQ087o`?l0J87ob?om0?3oo@3Loo`0POoGon40POolon00
POoVon40POn1ohOoo@3`ood0g?ol087oeooQ087oo?oP087oi_oQ087oPOn7ood0
l?om0=coo021omOoh@21oocoh021onKoh@21ol3o06R1olSoo@3`ood0g?ol087o
eooQ087oo?oP087oi_oQ087oPOn7ood0l?om0=coo021omOoh@21oocoh021onKo
h@21oh7oQoom0?3oo@3Loo`0POoGon40POolon00POoVon40POo0o`1XPOo8ood0
l?om0=coo021omKohP21oo_oh@21onGohP21oh7oQoom0?3oo@3Loo`0POoFon80
POokon40POoUon80POn1ohOoo@3`ood0g?ol087oe_oR087onooQ087oiOoR087o
`?l0J87ob?om0?3oo@3Loo`0POoFon<0POojon40POoUon<0POn1ohKoo@3`ood0
g?ol087oe_oS087on_oQ087oiOoS087oPOn6ood0l?om0=coo021omKoh`21oo[o
h@21onGoh`21okoo06R1olSoo@3`ood0g?ol087oe_oS087on_oR087oi?oS087o
POn6ood0l?om0=coo021omKoh`21oo[ohP21onCoh`21oh7oQ_om0?3oo@3Loo`0
POoFon<0POojon80POoTon<0POnoo`1XPOo8ood0l?om0=coo021omKoh`21ooWo
h`21onCoh`21oh7oQ_om0?3oo@3Loo`0POoFon<0POoion<0POoTon<0POn1ohKo
o@3`ood0g?ol087oe_oS087onOoS087oi?oS087o_ol0J87ob?om0?3oo@3Loo`0
POoEonD0POohon<0POoSonD0POn1ohGoo@3`ood0g?ol087oeOoU087on?oS087o
hooU087oPOn5ood0l?om0=coo021omGoi@21ooSoh`21on?oi@21okko06R1olSo
o@3`ood0g?ol087oeOoU087on?oT087oh_oU087oPOn5ood0l?om0=coo021omGo
i@21ooSoi021on;oi@21oh7oQOom0?3oo@3Loo`0POoEonD0POohon@0POoRonD0
POnno`1XPOo8ood0l?om0=coo021omCoi`21ooKoiP21on3oi`21oh7oQ?om0?3o
o@3Loo`0POoDonL0POofonH0POoPonL0POn1ohCoo@3`ood0g?ol087oe?oW087o
m_oV087oh?oW087o_Ol0J87ob?om0?3oo@3Loo`0POoConP0POoeonL0POoOonP0
POn1ohCoo@3`ood0g?ol087odooX087omOoW087ogooX087oPOn4ood0l?om0=co
o021om?oj021ooGoi`21omooj021okgo06R1olSoo@3`ood0g?ol087od_o[087o
looX087ogOo[087oPOn2ood0l?om0=coo021om;oj`21oo?oj021omgoj`21oh7o
P_om0?3oo@3Loo`0POoBon/0POoconP0POoMon/0POnko`1XPOo8ood0l?om0=co
o021om7ok@21oo7ojP21om_ok@21oh7oPOom0?3oo@3Loo`0POoAond0POoaonX0
POoKond0POn1oh7oo@3`ood0g?ol087odOo]087olOoZ087ofoo]087o^_l0K87o
b?om0?3oo@3Loo`0POo@onl0POo_on/0POoJonl0POn1oh7o0?om0?3oo@3Loo`0
POo@onl0POo_on/0POoJonl0POn1oh7o0?om0?3oo@3Loo`0POo@onl0POo_on/0
POoJonl0POnio`1^POo8ood0l?om0=coo021olool@21oncok`21omOol@21oh7o
POl1ooom0?3oo@3Loo`0POo?oo40POo/onl0POoGoo40POn1oh7o0Oooo@3`ood0
g?ol087ocooa087ok?o_087oeooa087o^?l0E87oR_ol087ocOoe087ojOoa087o
e?oe087oPOn1okooo021olgom@21onWol@21omCom@21oh7oPOnooo`0POo=ooD0
POoYoo40POoDooD0POnfo`0nPOn:oo`0POn1ojOomP21oh7oPOn1oh?oo021oh7o
Yoof087oPOn1oh7oPool087oPOnWooH0POn1oh7on_l0@X7oR_ol087oPOnRo`00
POn1oh7oPOn1ookoo021oh7oX_l0087oPOn1oh7oPOonoo`0POn1oj;o0021oh7o
POoeo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo03J1oh[oo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oUOl0=X7oR_ol087oPOn1oh7oPOn1oh7oW_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOnEo`0fPOn:oo`0POn1oh7oPOn1oh7o
POnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oiGo03J1oh[oo021oh7o
POn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oUOl0=X7o
R_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POnEo`0fPOn:oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oiGo04:1oh[oo021omCoo021oh7oPOn1oh7oPOo@oo`0POoDoo`0
POn1oh7oPOn1oh7od?ol087oe?ol087oPOn1oh7oaol0CX7oR_ol087oe?ol087o
eOom087oPOn1oh7oPOl0oo`0POoDoo`0POoEood0POn1oh7oPOn1o`3oo021omCo
o021omGoo@21oh7oPOogo`1>POn:oo`0POoDoo`0POoEood0POn1oh7oPOn1o`3o
o021omCoo021omGoo@21oh7oPOn1oh7o0?ol087oe?ol087oeOom087oPOn1ooOo
05B1oh[oo021omCoo021omGoo@21omCoo@21oh7oPOnaoo`0POoDoo`0POoEood0
POoDood0POn1oh7o/Ool087oe?ol087oeOom087oe?om087oZ?l0E87oR_ol087o
e?ol087oeOom087oe?om087oPOn1ok7oo021omCoo021omGoo@21omCoo@21oh7o
POnaoo`0POoDoo`0POoEood0POoDood0POnXo`1DPOn:oo`0POoDoo`0POoEood0
POoDood0POn1oh7o/Ool087oe?ol087oeOom087oe?om087oPOn1ok7oo021omCo
o021omGoo@21omCoo@21ojSo05B1oh[oo021omCoo021omGoo@21omCoo@21oh7o
POnaoo`0POoDoo`0POoEood0POoDood0POn1oh7o/Ool087oe?ol087oeOom087o
e?om087oZ?l0E87oR_ol087oe?ol087oeOom087oe?om087oPOn1ok7oo021omCo
o021omGoo@21omCoo@21oh7oPOnaoo`0POoDoo`0POoEood0POoDood0POnXo`1D
POn:oo`0POoDoo`0POoEood0POoDood0POn1oh7o/Ool087oe?ol087oeOom087o
e?om087oPOn1ok7oo021omCoo021omGoo@21omCoo@21ojSo05B1oh[oo021omCo
o021omGoo@21omCoo@21oh7oPOnaoo`0POoDoo`0POoEood0POoDood0POn1oh7o
/Ool087oe?ol087oeOom087oe?om087oZ?l0E87oR_ol087oe?ol087oeOom087o
e?om087oPOn1ok7oo021omCoo021omGoo@21omCoo@21oh7oPOnaoo`0POoDoo`0
POoEood0POoDood0POnXo`1DPOn:oo`0POoDoo`0POoEood0POoDood0POn1oh7o
/Ool087oe?ol087oeOom087oe?om087oPOn1ok7oo021omCoo021omGoo@21omCo
o@21ojSo05B1oh[oo021omCoo021omGoo@21omCoo@21oh7oPOnaoo`0POoDoo`0
POoEood0POoDood0POn1oh7o/Ool087oe?ol087oeOom087oe?om087oZ?l0E87o
R_ol087oe?ol087oeOom087oe?om087oPOn1ok7oo021omCoo021omGoo@21omCo
o@21oh7oPOnaoo`0POoDoo`0POoEood0POoDood0POnXo`1DPOn:oo`0POoDoo`0
POoEood0POoDood0POn1oh7o/Ool087oe?ol087oeOom087oe?om087oPOn1ok7o
o021omCoo021omGoo@21omCoo@21ojSo05B1oh[oo021omCoo021omGoo@21omCo
o@21oh7oPOnaoo`0POoDoo`0POoEood0POoDood0POn1oh7o/Ool087oe?ol087o
eOom087oe?om087oZ?l0E87oR_ol087oe?ol087oeOom087oe?om087oPOn1ok7o
o021omCoo021omGoo@21omCoo@21oh7oPOnaoo`0POoDoo`0POoEood0POoDood0
POnXo`1DPOn:oo`0POoDoo`0POoEood0POoDood0POn1oh7o/Ool087oe?ol087o
eOom087oe?om087oPOn1ok7oo021omCoo021omGoo@21omCoo@21ojSo05B1oh[o
o021omCoo021omGoo@21omCoo@21oh7oPOnaoo`0POoDoo`0POoEood0POoDood0
POn1oh7o/Ool087oe?ol087oeOom087oe?om087oZ?l0E87oR_ol087oe?ol087o
eOom087oe?om087oPOn1ok7oo021omCoo021omGoo@21omCoo@21oh7oPOnaoo`0
POoDoo`0POoEood0POoDood0POnXo`1DPOn:oo`0POoDoo`0POoEood0POoDood0
POn1oh7o/Ool087oe?ol087oeOom087oe?om087oPOn1ok7oo021omCoo021omGo
o@21omCoo@21ojSo05B1oh[oo021omCoo021omGoo@21omCoo@21oh7oPOnaoo`0
POoDoo`0POoEood0POoDood0POn1oh7o/Ool087oe?ol087oeOom087oe?om087o
Z?l0E87oR_ol087oe?ol087oeOom087oe?om087oPOn1ok7oo021omCoo021omGo
o@21omCoo@21oh7oPOnaoo`0POoDoo`0POoEood0POoDood0POnXo`1DPOn:oo`0
POoDoo`0POoEood0POoDood0POn1oh7o/Ool087oe?ol087oeOom087oe?om087o
POn1ok7oo021omCoo021omGoo@21omCoo@21ojSo0321oh_oP@210840P@2108l0
POn;oh40P@210840P@2?087oRon10840P@210840S`00<87oRon10840P@210840
S`21oh_oP@210840P@2108l0POn;oh40P@210840P@2?000`POn;oh40P@210840
P@2?087oRon10840P@210840S`21oh_oP@210840P@2108l00321oh_oP@210840
P@2108l0POn;oh40P@210840P@2?087oRon10840P@210840S`00D87oPOn1omSo
o021omGoo@21omCoo@21oh7oPOn1oh7o0Oooo021omGoo@21omCoo@21oh7oPOn1
oh7o0Oooo021omGoo@21omCoo@21ojSo0521oh7oPOoHoo`0POoEood0POoDood0
POn1oh7oPOn1o`7ooo`0POoEood0POoDood0POn1oh7oPOn1o`7ooo`0POoEood0
POoDood0POnXo`1@POn1oh7of?ol087oeOom087oe?om087oPOn1oh7oPOl1oool
087oeOom087oe?om087oPOn1oh7oPOl1oool087oeOom087oe?om087oZ?l0D87o
POn1omSoo021omGoo@21omCoo@21oh7oPOn1oh7o0Oooo021omGoo@21omCoo@21
oh7oPOn1oh7o0Oooo021omGoo@21omCoo@21ojSo0521oh7oPOoHoo`0POoEood0
POoDood0POn1oh7oPOn1o`7ooo`0POoEood0POoDood0POn1oh7oPOn1o`7ooo`0
POoEood0POoDood0POnXo`1@POn1oh7of?ol087oeOom087oe?om087oPOn1oh7o
POl1oool087oeOom087oe?om087oPOn1oh7oPOl1oool087oeOom087oe?om087o
Z?l0D87oPOn1omSoo021omGoo@21omCoo@21oh7oPOn1oh7o0Oooo021omGoo@21
omCoo@21oh7oPOn1oh7o0Oooo021omGoo@21omCoo@21ojSo0521oh7oPOoHoo`0
POoEood0POoDood0POn1oh7oPOn1o`7ooo`0POoEood0POoDood0POn1oh7oPOn1
o`7ooo`0POoEood0POoDood0POnXo`1@POn1oh7of?ol087oeOom087oe?om087o
POn1oh7oPOl1oool087oeOom087oe?om087oPOn1oh7oPOl1oool087oeOom087o
e?om087oZ?l0D87oPOn1omSoo021omGoo@21omCoo@21oh7oPOn1oh7o0Oooo021
omGoo@21omCoo@21oh7oPOn1oh7o0Oooo021omGoo@21omCoo@21ojSo0521oh7o
POoHoo`0POoEood0POoDood0POn1oh7oPOn1o`7ooo`0POoEood0POoDood0POn1
oh7oPOn1o`7ooo`0POoEood0POoDood0POnXo`1@POn1oh7of?ol087oeOom087o
e?om087oPOn1oh7oPOl1oool087oeOom087oe?om087oPOn1oh7oPOl1oool087o
eOom087oe?om087oZ?l0D87oPOn1omSoo021omGoo@21omCoo@21oh7oPOn1oh7o
0Oooo021omGoo@21omCoo@21oh7oPOn1oh7o0Oooo021omGoo@21omCoo@21ojSo
0521oh7oPOoHoo`0POoEood0POoDood0POn1oh7oPOn1o`7ooo`0POoEood0POoD
ood0POn1oh7oPOn1o`7ooo`0POoEood0POoDood0POnXo`1@POn1oh7of?ol087o
eOom087oe?om087oPOn1oh7oPOl1oool087oeOom087oe?om087oPOn1oh7oPOl1
oool087oeOom087oe?om087oZ?l0D87oPOn1omSoo021omGoo@21omCoo@21oh7o
POn1oh7o0Oooo021omGoo@21omCoo@21oh7oPOn1oh7o0Oooo021omGoo@21omCo
o@21ojSo0521oh7oPOoHoo`0POoEood0POoDood0POn1oh7oPOn1o`7ooo`0POoE
ood0POoDood0POn1oh7oPOn1o`7ooo`0POoEood0POoDood0POnXo`1@POn1oh7o
f?ol087oeOom087oe?om087oPOn1oh7oPOl1oool087oeOom087oe?om087oPOn1
oh7oPOl1oool087oeOom087oe?om087oZ?l0D87oPOn1omSoo021omGoo@21omCo
o@21oh7oPOn1oh7o0Oooo021omGoo@21omCoo@21oh7oPOn1oh7o0Oooo021omGo
o@21omCoo@21ojSo04:1oh7oPOn1ojOoo@21omCoo@21oh7oPOn1oh7oPOo>ood0
POoDood0POn1oh7oPOn1oh7oc_om087oe?om087oZ?l0>87oPOn1oh7oPOn1ooKo
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21ojSo03R1oh7o
POn1oh7oPOofood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0
POnXo`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0?X7oPOn1okcon`21oh7oWook087oPOn1oh7oQook087oPOnOoo/0POn1oh7o
POn7oo/0POn1oioon`21olco06:1oh7oPOoZood0f_oh087okoom087oloom0<[o
n021oh7oPOn1okGoo@3JooP0POo_ood0POocood0b_oh087oPOn1oh7o]Oom0=[o
n021onooo@21oo?oo@3:ooP0POo<o`1RPOn1oh7oj_om0=[on021onooo@21oo?o
o@3:ooP0POn1oh7oPOneood0f_oh087okoom087oloom0<[on021oh7oPOn1okGo
o@3JooP0POo_ood0POocood0b_oh087oc?l0HX7oPOn1on[oo@3MooD0POo_ood0
POocood0cOoe087oPOn1oh7o]Oom0=gom@21onooo@21oo?oo@3=ooD0POn1oh7o
POneood0gOoe087okoom087oloom0<gom@21olco06:1oh7oPOoZood0g_od087o
koom087oloom0<kom021oh7oPOn1okGoo@3Noo@0POo_ood0POocood0c_od087o
POn1oh7o]Oom0=kom021onooo@21oo?oo@3>oo@0POo<o`1RPOn1oh7oj_om0=ko
m021onooo@21oo?oo@3>oo@0POn1oh7oPOneood0g_od087okoom087oloom0<ko
m021oh7oPOn1okGoo@3Noo@0POo_ood0POocood0c_od087oc?l0EX7oPOn1ol?o
n`3nood0POn1ojKon`3nood0POn1oh7oPOn>oo/0o_om087oPOnVoo/0o_om087o
POn1oh7oS_ok0?koo@21oh7oY_ok0?koo@21olco05J1oh7oPOo3ooh0noom087o
POnVooh0noom087oPOn1oh7oS_on0?_oo@21oh7oY_on0?_oo@21oh7oPOn1ohko
oP3kood0POn1ojKooP3kood0POo<o`1FPOn1oh7o`oon0?_oo@21oh7oY_on0?_o
o@21oh7oPOn1ohkooP3kood0POn1ojKooP3kood0POn1oh7oPOn>ooh0noom087o
POnVooh0noom087oc?l0?X7oPOn1ok[oo@21oh7oWOom087oPOn1oh7oQOom087o
POnMood0POn1oh7oPOn5ood0POn1oigoo@21olco04Z1oh7oPOnjood0POn1ol?o
o03Pood0POn1oh7oPOn5ood0POn1ol?oo03Pood0POn1oh7oPOn5ood0POn1ol?o
o03Pood0POo<o`1:POn1oh7o^_om087oPOo3oo`0h?om087oPOn1oh7oQOom087o
POo3oo`0h?om087oPOn1oh7oQOom087oPOo3oo`0h?om087oc?l0KX7oPOn1on[o
o@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1okGoo@3Eood0POo_ood0
POocood0jool0>3oo@21oh7oPOn1okGoo@3Eood0POo_ood0POocood0jool0>3o
o@21olco06j1oh7oPOoZood0eOom087okoom087oloom0>_oo03Pood0POn1oh7o
POneood0eOom087okoom087oloom0>_oo03Pood0POn1oh7oPOneood0eOom087o
koom087oloom0>_oo03Pood0POo<o`1^POn1oh7oj_om0=Goo@21onooo@21oo?o
o@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21oo?oo@3[oo`0h?om087o
POn1oh7o]Oom0=Goo@21onooo@21oo?oo@3[oo`0h?om087oc?l0KX7oPOn1on[o
o@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1okGoo@3Eood0POo_ood0
POocood0jool0>3oo@21oh7oPOn1okGoo@3Eood0POo_ood0POocood0jool0>3o
o@21olco06j1oh7oPOoZood0eOom087okoom087oloom0>_oo03Pood0POn1oh7o
POneood0eOom087okoom087oloom0>_oo03Pood0POn1oh7oPOneood0eOom087o
koom087oloom0>_oo03Pood0POo<o`1^POn1oh7oj_om0=Goo@21onooo@21oo?o
o@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21oo?oo@3[oo`0h?om087o
POn1oh7o]Oom0=Goo@21onooo@21oo?oo@3[oo`0h?om087oc?l0KX7oPOn1on[o
o@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1okGoo@3Eood0POo_ood0
POocood0jool0>3oo@21oh7oPOn1okGoo@3Eood0POo_ood0POocood0jool0>3o
o@21olco06j1oh7oPOoZood0eOom087okoom087oloom0>_oo03Pood0POn1oh7o
POneood0eOom087okoom087oloom0>_oo03Pood0POn1oh7oPOneood0eOom087o
koom087oloom0>_oo03Pood0POo<o`1^POn1oh7oj_om0=Goo@21onooo@21oo?o
o@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21oo?oo@3[oo`0h?om087o
POn1oh7o]Oom0=Goo@21onooo@21oo?oo@3[oo`0h?om087oc?l0KX7oPOn1on[o
o@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1okGoo@3Eood0POo_ood0
POocood0jool0>3oo@21oh7oPOn1okGoo@3Eood0POo_ood0POocood0jool0>3o
o@21olco07Z1oh7oPOoZood0noo`0>coo@21onooo@21oo?oo@3[oo`0h?om087o
POn1oh7o]Oom0?_ol03/ood0POo_ood0POocood0jool0>3oo@21oh7oPOn1okGo
o@3koo00k?om087okoom087oloom0>_oo03Pood0POo<o`1jPOn1oh7oj_om0?_o
l03/ood0POo_ood0POocood0jool0>3oo@21oh7oPOn1okGoo@3koo00k?om087o
koom087oloom0>_oo03Pood0POn1oh7oPOneood0noo`0>coo@21onooo@21oo?o
o@3[oo`0h?om087oc?l0NX7oPOn1on[oo@3koo00k?om087okoom087oloom0?So
hP3]ood0POn1oh7oPOneood0noo`0>coo@21onooo@21oo?oo@3hon80kOom087o
POn1oh7o]Oom0?_ol03/ood0POo_ood0POocood0n?oR0>goo@21olco07Z1oh7o
POoZood0noo`0>coo@21onooo@21oo?oo@3hon80kOom087oPOn1oh7o]Oom0?_o
l03/ood0POo_ood0POocood0n?oR0>goo@21oh7oPOn1okGoo@3koo00k?om087o
koom087oloom0?SohP3]ood0POo<o`1jPOn1oh7oj_om0?_ol03/ood0POo_ood0
POocood0n?oR0>goo@21oh7oPOn1okGoo@3koo00k?om087okoom087oloom0?So
hP3]ood0POn1oh7oPOneood0noo`0>coo@21onooo@21oo?oo@3hon80kOom087o
c?l0KX7oPOn1on[oo@3Eood0POo_ood0POocood0n?oR0>goo@21oh7oPOn1okGo
o@3Eood0POo_ood0POocood0n?oR0>goo@21oh7oPOn1okGoo@3Eood0POo_ood0
POocood0n?oR0>goo@21olco06j1oh7oPOoZood0eOom087okoom087oloom0>_o
o03Pood0POn1oh7oPOneood0eOom087okoom087oloom0>_oo03Pood0POn1oh7o
POneood0eOom087okoom087oloom0>_oo03Pood0POo<o`1^POn1oh7oj_om0=Go
o@21onooo@21oo?oo@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21oo?o
o@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21oo?oo@3[oo`0h?om087o
c?l0KX7oPOn1on[oo@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1okGo
o@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1okGoo@3Eood0POo_ood0
POocood0jool0>3oo@21olco06j1oh7oPOoZood0eOom087okoom087oloom0>_o
o03Pood0POn1oh7oPOneood0eOom087okoom087oloom0>_oo03Pood0POn1oh7o
POneood0eOom087okoom087oloom0>_oo03Pood0POo<o`1^POn1oh7oj_om0=Go
o@21onooo@21oo?oo@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21oo?o
o@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21oo?oo@3[oo`0h?om087o
c?l0KX7oPOn1on[oo@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1okGo
o@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1okGoo@3Eood0POo_ood0
POocood0jool0>3oo@21olco06j1oh7oPOoZood0eOom087okoom087oloom0>_o
o03Pood0POn1oh7oPOneood0eOom087okoom087oloom0>_oo03Pood0POn1oh7o
POneood0eOom087okoom087oloom0>_oo03Pood0POo<o`1^POn1oh7oj_om0=Go
o@21onooo@21oo?oo@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21oo?o
o@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21oo?oo@3[oo`0h?om087o
c?l0KX7oPOn1on[oo@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1okGo
o@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1okGoo@3Eood0POo_ood0
POocood0jool0>3oo@21olco06j1oh7oPOoZood0eOom087okoom087oloom0>_o
o03Pood0POn1oh7oPOneood0eOom087okoom087oloom0>_oo03Pood0POn1oh7o
POneood0eOom087okoom087oloom0>_oo03Pood0POo<o`1^POn1oh7oj_om0=Go
o@21onooo@21oo?oo@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21oo?o
o@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21oo?oo@3[oo`0h?om087o
c?l0KX7oPOn1on[oo@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1okGo
o@3Eood0POo_ood0POocood0jool0>3oo@21oh7oPOn1okGoo@3Eood0POo_ood0
POocood0jool0>3oo@21olco06j1oh7oPOoZood0eOom087okoom087oloom0>_o
o03Pood0POn1oh7oPOneood0eOom087okoom087oloom0>_oo03Pood0POn1oh7o
POneood0eOom087okoom087oloom0>_oo03Pood0POo<o`1^POn1oh7oj_om0=Go
o@21onooo@21oo?oo@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21oo?o
o@3[oo`0h?om087oPOn1oh7o]Oom0=Goo@21onooo@21oo?oo@3[oo`0h?om087o
c?l0CX7oPOn1on[oo@21okooo@21oo?oo@21oh7oPOn1oh7omOom087o_oom087o
loom087oPOn1oh7oPOoeood0POnoood0POocood0POn<o`1>POn1oh7oj_om087o
_oom087oloom087oPOn1oh7oPOoeood0POnoood0POocood0POn1oh7oPOn1ooGo
o@21okooo@21oo?oo@21ohco04j1oh7oPOoZood0POnoood0POocood0POn1oh7o
POn1ooGoo@21okooo@21oo?oo@21oh7oPOn1oh7omOom087o_oom087oloom087o
S?l0CX7oPOn1on[oo@21okooo@21oo?oo@21oh7oPOn1oh7omOom087o_oom087o
loom087oPOn1oh7oPOoeood0POnoood0POocood0POn<o`1>POn1oh7ok?ok087o
`Ook087omOok087oPOn1oh7oPOogoo/0POo1oo/0POoeoo/0POn1oh7oPOn1ooOo
n`21ol7on`21ooGon`21ohco04j1oh7oPOo/oo/0POo1oo/0POoeoo/0POn1oh7o
POn1ooOon`21ol7on`21ooGon`21oh7oPOn1oh7omook087o`Ook087omOok087o
S?l0CX7oPOn1ongon`21ol7on`21ooGon`21oh7oPOn1oh7omook087o`Ook087o
mOok087oPOn1oh7oPOogoo/0POo1oo/0POoeoo/0POn;o`1>POn1oh7ol_of087o
a_of087on_of087oPOn1oh7oPOolooH0POo6ooH0POojooH0POn1oh7oPOn1ooco
mP21olKomP21oo[omP21oh_o04j1oh7oPOobooH0POo6ooH0POojooH0POn1oh7o
POn1oocomP21olKomP21oo[omP21oh7oPOn1oh7oo?of087oa_of087on_of087o
Rol0CX7oPOn1oo;on021olCon021ooSon021oh7oPOn1oh7on_oh087oa?oh087o
n?oh087oPOn1oh7oPOojooP0POo4ooP0POohooP0POn9o`1>POn1oh7ol_ok087o
`Ook087omOok087oPOn1oh7oPOogoo/0POo1oo/0POoeoo/0POn1oh7oPOn1ooOo
n`21ol7on`21ooGon`21ohKo04j1oh7oPOoboo/0POo1oo/0POoeoo/0POn1oh7o
POn1ooOon`21ol7on`21ooGon`21oh7oPOn1oh7omook087o`Ook087omOok087o
Q_l0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo09X0003oQP@000000dL1P@0000@0000004P00018
0000400P00<02000000000001J:g30000003A`5j0003j`=71F80000DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko
01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587o
POn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7o
POn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7o
POn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7o
POn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7o
o_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l06X7oPOnhooh0POn1oh?ooP21oh7o
Poon0<co01Z1oh7o^?ok087oPOn6oo/0POn1ohKon`3?o`0JPOn1okWom`21oh7o
R_og087oPOn:ooL0d_l06X7oPOnioo@0POn1ohgom021oh7oSOod0=Go01Z1oh7o
^_o`087oPOnAoo00POn1oi7ol03Ho`0JPOn1ok[ok@21oh7oU?o]087oPOnDond0
fol06X7oPOnjonX0POn1oiOojP21oh7oUooZ0=ko01Z1oh7o^_oW087oPOnJonL0
POn1oi[oi`3Qo`0JPOn1ok_oi021oh7oWOoT087oPOnMon@0hol06X7oPOnkon40
POn1oj3oh@21oh7oX?oQ0>Ko01Z1oh7o^ooN087oPOnSomh0POn1oj?ogP3Yo`0J
POn1ok_of`21oh7oY_oK087oPOnVom/0k?l06X7oPOnkomP0POn1ojWof021oh7o
ZOoH0>oo01R10840S`3boh40P@2?0?;oP@2108l0l_l06840P@2<0?GoP@2108`0
mOn10840S03eo`0HP@2108T0n?n10840R@3hoh40P@290?So01R10840R`3foh40
P@2;0?KoP@2108/0m_l06X7oPOnkomD0POn1ojcoe@21oh7o[?oE0?;o01Z1oh7o
^ooG087oPOnZomL0POn1oj[oe`3`o`0JPOn1ok_ofP21oh7oYooJ087oPOnWomX0
kOl06X7oPOnkom`0POn1ojGog021oh7oYOoL0>_o01Z1oh7o^ooO087oPOnRoml0
POn1oj;og`3Xo`0JPOn1ok_oh`21oh7oW_oS087oPOnNon<0i?l06X7oPOnjonL0
POn1oi[oi`21oh7oV_oW0>7o01Z1oh7o^_oY087oPOnHonT0POn1oiSoj@3Oo`0J
POn1ok[ok021oh7oUOo/087oPOnEon`0g?l06X7oPOnjonh0POn1oi?okP21oh7o
Too^0=[o01Z1oh7o^_oa087oPOn@oo40POn1oi3ol@3Go`0JPOn1okWom021oh7o
SOod087oPOn=oo@0eOl06X7oPOniooL0POn1oh[om`21oh7oR_og0=;o01Z1oh7o
^Ook087oPOn6oo/0POn1ohKon`3>o`0JPOn1okSooP21oh7oPoon087oPOn3ooh0
c?l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0D
POn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l06X7oPOogooT0
POn1ohSon@21oh7oR?oi09;o01Z1oh7omooi087oPOn8ooT0POn1ohSon@2Bo`0J
POn1ooOon@21oh7oR?oi087oPOn8ooT0T_l06X7oPOogooT0POn1ohSon@21oh7o
R?oi09;o01Z1oh7omooi087oPOn8ooT0POn1ohSon@2Bo`0JPOn1ooOon@21oh7o
R?oi087oPOn8ooT0T_l06X7oPOogooT0POn1ohSon@21oh7oR?oi09;o01B1oh7o
POn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7o
POn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7o
POn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7o
POono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l09X7od_oe0=_onP21oh7o^Ooe0=_o
nP21oh7o^Ooe0=_onP21onSo04jRooP0kOoj0=Sok`3]ooX0o?og0=oon@21ok?o
n03]ooX0f?o_0>gonP3looL0gooi087o/ooh0>gonP3Honl0kOoj0?com`3OooT0
T_l0CZ;on03]ooX0f?o_0>gonP3looL0gooi087o/ooh0>gonP3Honl0kOoj0?co
m`3OooT0POncooP0kOoj0=Sok`3]ooX0o?og0=oon@2Bo`1>X?oh0?7on@3JonT0
l?oj0?kom@3OooT0POnaooP0lOoi0=[oj@3`ooX0o_oe0=oon@21ok7on03aooT0
f_oY0?3onP3nooD0gooi09;o056OooT0lOok0=WoiP3booX00Ooom03OooT0POn`
ooT0lOok0=WoiP3booX00Ooom03OooT0POn`ooT0lOok0=WoiP3booX00Ooom03O
ooT0T_l0DIoon@3aoo/0fOoV0?;onP01oood0=oon@21ok3on@3aoo/0fOoV0?;o
nP01oood0=oon@21ok3on@3aoo/0fOoV0?;onP01oood0=oon@2Bo`1JWooh0??o
nP3KooH0n?og0??olP3ko`00gooi087o/?oh0??onP3KooH0n?og0??olP3ko`00
gooi087o/?oh0??onP3KooH0n?og0??olP3ko`00gooi09;o04jMooP0mooi0=_o
m`3eooH0mOoe0=Gon@21ojkon03gooT0foog0?GomP3eooD0eOoi087o[_oh0?Oo
n@3KooL0mOof0?Gom@3EooT0T_l0CYgon03gooT0foog0?GomP3eooD0eOoi087o
[_oh0?Oon@3KooL0mOof0?Gom@3EooT0POn^ooP0mooi0=_om`3eooH0mOoe0=Go
n@2Bo`1>W?oi0?Oon`3IooP0l_oh0?Gom`3CooT0POn]ooT0mook0=Won03booP0
mOog0=?on@21ojgon@3goo/0fOoh0?;on03eooL0dooi09;o04jLooP0nOok0=[o
n03_ooP0m_oh0=;on@21ojgon03ioo/0f_oh0>oon03fooP0d_oi087o[Ooh0?Wo
n`3JooP0kooh0?Kon03BooT0T_l0CYcon03ioo/0f_oh0>oon03fooP0d_oi087o
[Ooh0?Won`3JooP0kooh0?Kon03BooT0POn]ooP0nOok0=[on03_ooP0m_oh0=;o
n@2Bo`1>V_oh0?gon@3JooT0k?oj0?Kon03BooT0POn[ooP0oOoi0=[on@3/ooX0
m_oh0=;on@21oj_on03mooT0f_oi0>conP3fooP0d_oi09;o04jIooT0o_oj0=So
n@3/ooX0m_oh0=;on@21oj[on@3nooX0f?oi0>conP3fooP0d_oi087oZ_oi0?ko
nP3HooT0k?oj0?Kon03BooT0T_l0CYWon@3nooX0f?oi0>conP3fooP0d_oi087o
Z_oi0?konP3HooT0k?oj0?Kon03BooT0POnZooT0o_oj0=Son@3/ooX0m_oh0=;o
n@2Bo`1AVOoh007ooo/0f?oh0>con03hooX0d?oi087oZ_oh007ooo/0f?oh0>co
n03hooX0d?oi087oZ_oh007ooo/0f?oh0>con03hooX0d?oi09;o04:Goo80f?oj
0>Won@3hooX0d?oi087oZ?ob0=SonP3YooT0n?oj0=3on@21ojSolP3HooX0jOoi
0?SonP3@ooT0T_l0@YOolP3HooX0jOoi0?SonP3@ooT0POnXoo80f?oj0>Won@3h
ooX0d?oi087oZ?ob0=SonP3YooT0n?oj0=3on@2Bo`12Uood0=KonP3YooT0n?oj
0=3on@21ojSom03FooX0jOoi0?SonP3@ooT0POnXoo@0e_oj0>Won@3hooX0d?oi
09;o04:FooH0eOoj0>Won@3hooX0d?oi087oYoof0=GonP3YooT0n?oj0=3on@21
ojOomP3EooX0jOoi0?SonP3@ooT0T_l0@YKomP3EooX0jOoi0?SonP3@ooT0POnW
ooH0eOoj0>Won@3hooX0d?oi087oYoof0=GonP3YooT0n?oj0=3on@2Bo`12U?oh
0=GonP3YooT0n?oj0=3on@21ojGon03EooX0jOoi0?SonP3@ooT0POnUooP0eOoj
0>Won@3hooX0d?oi09;o04:DooP0eOoj0>Won@3hooX0d?oi087oYOoh0=GonP3Y
ooT0n?oj0=3on@21ojGon03EooX0jOoi0?SonP3@ooT0T_l0@YCon03EooX0jOoi
0?SonP3@ooT0POnUooP0eOoj0>Won@3hooX0d?oi087oYOoh0=GonP3YooT0n?oj
0=3on@2Bo`12U?og0=KonP3YooT0n?oj0=3on@21ojGom`3FooX0jOoi0?SonP3@
ooT0POnUooL0e_oj0>Won@3hooX0d?oi09;o04:Foo<0f?oj0>Won@3hooX0d?oi
087oYooc0=SonP3YooT0n?oj0=3on@21ojOol`3HooX0jOoi0?SonP3@ooT0T_l0
@YKol`3HooX0jOoi0?SonP3@ooT0POnWoo<0f?oj0>Won@3hooX0d?oi087oYooc
0=SonP3YooT0n?oj0=3on@2Bo`12Uoob0=SonP3YooT0n?oj0=3on@21ojSolP3H
ooX0jOoi0?SonP3@ooT0POnXoo80f?oj0>Won@3hooX0d?oi09;o04jGoo/00?oh
0=Won03/ooP0n?oj0=3on@21ojSon`00ooP0fOoh0>con03hooX0d?oi087oZ?ok
003on03IooP0k?oh0?SonP3@ooT0T_l0CYOon`00ooP0fOoh0>con03hooX0d?oi
087oZ?ok003on03IooP0k?oh0?SonP3@ooT0POnXoo/00?oh0=Won03/ooP0n?oj
0=3on@2Bo`1>VOok0?conP3HooT0k?oj0?KonP3@ooT0POnZoo/0o?oj0=Son@3/
ooX0m_oj0=3on@21oj[on`3looX0f?oi0>conP3fooX0d?oi09;o04jJooX0o?oh
0=[on@3/ooX0m_oj0=3on@21oj_onP3looP0f_oi0>conP3fooX0d?oi087oZooj
0?con03JooT0k?oj0?KonP3@ooT0T_l0CY[onP3looP0f_oi0>conP3fooX0d?oi
087oZooj0?con03JooT0k?oj0?KonP3@ooT0POn[ooX0o?oh0=[on@3/ooX0m_oj
0=3on@2Bo`1>V_ok0?[on03KooP0kooh0?KonP3@ooT0POn[oo/0n_oh0=_on03_
ooP0m_oj0=3on@21oj_on`3jooP0fooh0>oon03fooX0d?oi09;o04jLoo/0m_oj
0=Won03booP0mOoj0=3on@21ojgon`3fooX0fOoh0?;on03eooX0d?oi087o[Ook
0?KonP3IooP0l_oh0?GonP3@ooT0T_l0CYcon`3fooX0fOoh0?;on03eooX0d?oi
087o[Ook0?KonP3IooP0l_oh0?GonP3@ooT0POn]oo/0m_oj0=Won03booP0mOoj
0=3on@2Bo`1>WOoj0?Kon03KooL0mOof0?GonP3@ooT0POn^ooX0m_oh0=_om`3e
ooH0mOoj0=3on@21ojkonP3fooP0foog0?GomP3eooX0d?oi09;o04jOooT0m?oh
0=_omP3hooL0looj0=3on@21ok3on@3dooP0foof0?Som`3cooX0d?oi087o/?oi
0?Con03KooH0n?og0??onP3@ooT0T_l0CYoon@3dooP0foof0?Som`3cooX0d?oi
087o/?oi0?Con03KooH0n?og0??onP3@ooT0POn`ooT0m?oh0=_omP3hooL0looj
0=3on@2Bo`12Wook0?3onP3IonH0l_oj0=3on@21ok3on`3`ooX0fOoV0?;onP3@
ooT0POn`oo/0l?oj0=WoiP3booX0d?oi09;o04:PooX0l?oh0=[oj@3`ooX0d?oi
087o/Ooj0?3on03JonT0l?oj0=3on@21ok7onP3`ooP0f_oY0?3onP3@ooT0T_l0
@Z3onP3`ooP0f_oY0?3onP3@ooT0POnaooX0l?oh0=[oj@3`ooX0d?oi087o/Ooj
0?3on03JonT0l?oj0=3on@2Bo`12X_oi0>kon03Honl0kOoj0=3on@21ok?on@3^
ooP0f?o_0>gonP3@ooT0POncooT0k_oh0=Sok`3]ooX0d?oi09;o02B1om;om@2b
ooT0POn1on?om@2booT0POn1on?om@2booT0T_l0987od_oe0;;on@21oh7ohooe
0;;on@21oh7ohooe0;;on@2Bo`0JPOn1ooOon@21oh7oR?oi087oPOn8ooT0T_l0
6X7oPOogooT0POn1ohSon@21oh7oR?oi09;o01Z1oh7omooi087oPOn8ooT0POn1
ohSon@2Bo`0JPOn1ooOon@21oh7oR?oi087oPOn8ooT0T_l06X7oPOohooP0POn1
ohWon021oh7oROoh09;o01Z1oh7on?oh087oPOn9ooP0POn1ohWon02Bo`0JPOn1
ooSonP21oh7oQooj087oPOn7ooX0T?l06X7oPOokooL0POn1oh[om`21oh7oR_og
093o01Z1oh7onoog087oPOn:ooL0POn1oh[om`2@o`0JPOn1o`3ol`21oh7oS_oc
087oPOn>oo<0Sol06X7oPOl0ooD0POn1ohcom@21oh7oS?oe08go01Z1oh7o0?oe
087oPOn<ooD0POn1ohcom@2=o`0JPOn1o`3omP21oh7oRoof087oPOn;ooH0S?l0
6X7oPOl0ooT0POn1ohSon@21oh7oR?oi08Wo01Z1oh7o0?oi087oPOn8ooT0POn1
ohSon@29o`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1
ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0
587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1oh7oPOn1oh7oPOono`0DPOn1
oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1oh7oPOn1ooko01B1oh7oPOn1
oh7oPOn1oh7oPOono`0DPOn1oh7oPOn1oh7oPOn1oh7oo_l0587oPOn1oh7oPOn1
oh7oPOn1ooko002P0;l0o`\>"], "NumberedFigure",
  ImageSize->{330, 201},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Figure 3.   The new point on top is calculated using the staggered \
leapfrog scheme, it contains information from the three black ones\
\>", \
"Caption"],

Cell[TextData[{
  "With (11) and (12) the explicit result for ",
  Cell[BoxData[
      \(\[Upsilon]\_2\)]],
  " is"
}], "Text",
  PageBreakAbove->True],

Cell[BoxData[{
    \(v\&\[RightVector]\_j\%\(n + 1\) = \(\[Upsilon]\_2\) \
\((v\&\[RightVector]\_k\%n, \[CapitalDelta]t)\)\), "\[IndentingNewLine]", 
    \(\(\(=\)\(v\&\[RightVector]\_j\%n - \(\[CapitalDelta]t\/\(2  \
\[CapitalDelta]x\)\)[
            B] \((v\&\[RightVector]\_\(j + 1\)\%n - 
              v\&\[RightVector]\_\(j - 1\)\%n - \(\[CapitalDelta]t\/\
\[CapitalDelta]x\)[
                  B] \((v\&\[RightVector]\_\(j + 1\)\%n - 
                    2  v\&\[RightVector]\_j\%n + 
                    v\&\[RightVector]\_\(j - 1\)\%n)\))\)\)\)\), "\
\[IndentingNewLine]", 
    \(\(\(=\)\(\([\[DoubleStruckL] - \(\((\[CapitalDelta]t\/\[CapitalDelta]x)\
\)\^2\)[B]\^2]\) 
          v\&\[RightVector]\_j\%n + \(1\/2\) \(\(\((\[CapitalDelta]t\/\
\[CapitalDelta]x)\)\^2\)[B]\^2\) \((v\&\[RightVector]\_\(j + 1\)\%n + 
              v\&\[RightVector]\_\(j - 1\)\%n)\) - \[IndentingNewLine]\(\
\[CapitalDelta]t\/\(2  \[CapitalDelta]x\)\)[
            B] \((v\&\[RightVector]\_\(j + 1\)\%n - 
              v\&\[RightVector]\_\(j - 1\)\%n)\)\)\)\)}], "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "differencing ",
  Cell[BoxData[
      \(\[ScriptCapitalL]\_1\)]]
}], "Subsubsection"],

Cell[TextData[{
  "The differencing scheme of ",
  Cell[BoxData[
      \(\[ScriptCapitalL]\_1\)]],
  " is somewhat simpler, because there is no space derivative. A second \
shorthand [A] is introduced for the LR matrix:"
}], "Text"],

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{\(v\&\[RightVector]\_j\%\(n + 1\)\), "=", 
        RowBox[{\(\(\[Upsilon]\_1\) \((v\&\[RightVector]\_k\%n, \
\[CapitalDelta]t)\)\), "=", 
          RowBox[{
            RowBox[{
              RowBox[{"[", 
                RowBox[{"\[DoubleStruckL]", "-", 
                  RowBox[{"\[CapitalDelta]t", 
                    RowBox[{"(", GridBox[{
                          {"0", "0"},
                          {"0", \([\(L'\^\(-1\)\) R']\)}
                          }], ")"}]}]}], "]"}], \(v\&\[RightVector]\_j\%n\)}],
             "=", \(\([A]\) \(\(v\&\[RightVector]\_j\%n\)\(.\)\)\)}]}]}]}]], \
"NumberedEquation"],

Cell[TextData[{
  "\n\tNow ",
  Cell[BoxData[
      \(\[Upsilon]\_1\)]],
  " and ",
  Cell[BoxData[
      \(\[Upsilon]\_2\)]],
  " are combined as in (7) :"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(v\&\[RightVector]\_j\%\(n + 1\)\)]],
  Cell[BoxData[
      \(\(\(=\)\(\([A]\)[\[DoubleStruckL] - \(\((\[CapitalDelta]t\/\
\[CapitalDelta]x)\)\^2\)[B]\^2] 
            v\&\[RightVector]\_j\%n + \(1\/2\) \(\(\(\((\[CapitalDelta]t\/\
\[CapitalDelta]x)\)\^2\)[A]\)[B]\^2\) \((v\&\[RightVector]\_\(j + 1\)\%n + 
                v\&\[RightVector]\_\(j - 1\)\%n)\) - \
\(\(\[CapitalDelta]t\/\(2  \[CapitalDelta]x\)\)[A]\)[
              B] \((v\&\[RightVector]\_\(j + 1\)\%n - 
                v\&\[RightVector]\_\(j - 1\)\%n)\)\)\)\)]],
  "\n"
}], "NumberedEquation"],

Cell["\<\
From (16) we get, through inserting the parameter matrices for [A] \
and [B] and separating for voltages and currents, at last to the discrete \
telegraph equations as shown in the next section.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["the discrete Telegraph Equations", "Subsubsection"],

Cell[BoxData[{
    \(u\&\[RightVector]\_j\%\(n + 1\) = \([\[DoubleStruckL] - \(\((\
\[CapitalDelta]t\/\[CapitalDelta]x)\)\^2\)[\(C'\^\(-1\)\) L'\^\(-1\)]]\) 
          u\&\[RightVector]\_j\%n + \(\(\(\[IndentingNewLine]\)\(1\)\)\/2\) \
\((\(\((\[CapitalDelta]t\/\[CapitalDelta]x)\)\^2\)[\(C'\^\(-1\)\) 
                    L'\^\(-1\)] \((u\&\[RightVector]\_\(j + 1\)\%n + 
                    u\&\[RightVector]\_\(j - 1\)\%n)\)\  - \(\[CapitalDelta]t\
\/\[CapitalDelta]x\)[
                  C'\^\(-1\)] \((i\&\[RightVector]\_\(j + 1\)\%n - 
                    i\&\[RightVector]\_\(j - 1\)\%n)\)\ )\)\), "\
\[IndentingNewLine]", 
    \(i\&\[RightVector]\_j\%\(n + 1\) = \([\[DoubleStruckL] - \
\[CapitalDelta]t[\(L'\^\(-1\)\) 
                R']]\) \((\([\[DoubleStruckL] - \(\((\[CapitalDelta]t\/\
\[CapitalDelta]x)\)\^2\)[\(L'\^\(-1\)\) C'\^\(-1\)]]\) 
              i\&\[RightVector]\_j\%n + \[IndentingNewLine]\(1\/2\) \((\(\((\
\[CapitalDelta]t\/\[CapitalDelta]x)\)\^2\)[\(L'\^\(-1\)\) 
                        C'\^\(-1\)] \((i\&\[RightVector]\_\(j + 1\)\%n + 
                        i\&\[RightVector]\_\(j - 1\)\%n)\) - \
\(\[CapitalDelta]t\/\[CapitalDelta]x\)[
                      L'\^\(-1\)] \((u\&\[RightVector]\_\(j + 1\)\%n - 
                        u\&\[RightVector]\_\(j - 1\)\%n)\))\))\)\)}], \
"NumberedEquation"],

Cell["\<\
There are now two coupled (voltage/current) grids; Point (n+1, j) \
is calculated from the three points on the line n below {(n, j+1), (n, j), \
(n, j-1)} in a left right symmetric way, the computational molecule is an \
isosceles triangle (cf. Fig. 3).\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["special treatment of the boundary", "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "At the edges (j = 1 or M) the outside points j = 0, M+1 are not available, \
so we have to modify our method. Mean values of differences in space and time \
(18) are used to calculate the edge points - to understand this look at Fig. \
4 .  As computational molecule there is now a rectangular box - (",
  StyleBox["Ref. 4",
    FontWeight->"Bold"],
  ", p.107):"
}], "Text"],

Cell[GraphicsData["PICT", "\<\
J;80000009`19@0A0_l<0?on0001;0000B`000000002RPC80000002Q09H02P40
000000000000X02H0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G
0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40000000000000X02H
0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G0:40UP0:0@000000
0000002P09P0X02I0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F
00X10000000000000:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I
0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F00X1000000000000
0:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40
000000000000X02H0:00V@2P09L07P0100X000000XX4b00/00T00`I7IFiUMV40
00<00`0=00`0;P04003o000[0@41800Y004P00070000000S0000X02n0:40`00=
HgEbLVE^M71_JFid3@00X02o0280V`4M0000X02n0:40`03=HgEbLVE^M71_JFid
838PJFiTIGPPLgER86EhHfPP<b1YKVAUN21cMF8=838h=B0PI6Uf86EhHfPP3B0a
=CDP86AYMR0c86U^I6Eh80dP<20PLgER83<PJFiTIGPP3B0`821cMF8P=20b879_
K6`P=B1YKVAUN20e86U^I6Eh87AbHFicK65dI@e^IFLPLf=QK6D==20b879_K6`P
KVEW86EhHfPPKVEW86EhHfPPM79QKW=/HGAU80dP<CDe821cMF8PM79QKW=/HGAU
3@00X@300DDU8E1C;D5TKf9U;C<^<215D5=6;C<^<0dU9D9_MFiTJFiW@Vmh>R0P
<20`838h=B0a=CDP3BDUE6UdK6Dj82Q<HGP^@diF:B0=9BE3LVEQM6mb>R13HFif
HG<P:3L^<2hb:B0=9BE3LVEQM6U_KTAQM6Dj82P`<Rlb=2l`<B10834a>S@c851=
:B0=9BE4Kf=eKFE^M51bKf=CIGAc>R14IFiUHV5O@f5^MV5c@gEcM6m]@fm/Kg9c
3BDU:b13ETAYHg@=9BE4Kf=eKFE^M4I_KWAc>R0=9BE4Kf=eKFE^M4iUIFAUI4I_
KWAc>R17IFiUMV4=3BDUA6mSMFeUKWA@LVmSIG=c@fm/Kg9c>R13NF5^84eQIfE^
M64PFFE/K6mg849/HF=[3BDUAFiT@fm]KFE^M7<=9BE2IFMYKU1bKfa_Ib0=002Q
0<1002DU@VEWJFiBIG=_MG9SICXPL79_Hg=UM213ETAYHg@=9BEDJGA/ICXPA6E^
IF9Q87=dHFiTHG9T86MbHG1XJF=c3BDUEVEbLfU_KSXP<Bh`<PdU9D=bIF5dJFm^
A65dICXP<C0_<C@_>CT=9BE3Kg1iLVUWJ7@j82Q3:B0a>CTd;20a>CTi84AUKVER
HB1CNG=dIFec;R11K6`PDVUWJ7Ac859ULfEbMVET3GEcIG9TJF=d82m3ETAYHg@P
<S0`86AYHg@PL7Ed3D=FA6USM21RIFMYKPd_JFifHFaYI6=_K6mbM65RK6Do87Ab
MFDPI6EV820P3Bm/IGIUK38P;faQKVMeHFMUK6EfIF`PMfQULVDPNg1_L21/HFiW
MF5WIFaUMVE/838PIfEmNfIQK7=UOB1YIVE/LfDPI6EV3FaUMVE/<R1^Kg@PNb0_
N7=XKgLPN`d`86=eLW9UKWA`KfU^M20e82da879_K6`PNg1_L21`Kg0PKFmfIGA_
86AeL20a865TI20c834PLVm/K21UN6=X86AeL20d834PLVm/K21UN6=X86MUM20`
879]KgIUM6lPHgEbLVE^M71_JFidOB1UN6=X86]cJ6mg3G1_L21`Kg0PL6m`871_
L7dPI6EV87dPJFH=;fU^JGAYHFaYNVD=Nd=FA6USM0ekI7E`87QSJ6ESJg]RJFiT
OFUV871_L21`Kg1mIVmbHFa/3F=eLW9UKWAcHg9UIFhP;emcL21UN6=X86AUIR0_
Gg=Q86EhHfPPI6EV82mOLfHPIGQSJ21TIFH=;dAUIV5eK7ACHg9UIFikGg=V85mc
HB0_Gg=`86a_HFAmI6EV3Bm4IFIQMFadDf=bIFE^D79_Hg/P;emcL21/Kf5TOFAU
IPd_LfEdLgAbKf]UHFAZMG=d87MXIG9UNg1_L21dLWEUOG]VHFacIGeYIVE/LfD=
NbmcHB0_LfEdLgAbKf]UHFAZMG=d86a_HF@PI6EV3Bm/JB0_K6U^IGA_86a_HF@P
I6EV3Bm]M20_KFmfIGA_86a_HF@PI6EV3BmSM20_HgEbMVEdKb1/Kf5T86AUIPd_
K6PPNb1SMG9bIFidL6mYKW@PIGQSJ21`Kg0PK6U^IGA_OF9YKV@PI6EV3Bm/MR1k
86=eLW9UKWA`KfU^M21`Kg0PIGQSJ21/JFiUM6mmHVU^I21TIFIm3G/_Lf5kNf=e
LW9UKWATJF=d85=dLVm[ID5TJWEcM4AYHg@PKVEkDgAbKf]U@FAZMG=dA6USM21R
IFMYKWeYIWek86=eLW9UKWATJF=d85=dLVm[ID5TJWEcM4AYHg@PIG5kIFiTOFUV
OFUVIFacIGdPHVU^I21TIFH=MG=ULVAYHg@P;e=dLVm[ID5TJWEcM4AYHg@P<C0`
86AYHg@PL7Ed3E=dLVm[ID5TJWEcM4AYHg@PHVEWJFh=;emhK0ekM79QKW=VKg9]
3Bhb=B1cMF8PLVmeKV@P;S8e865TI21UN6=X3Bhb=B1cMF8PLVmeKV@P;S8e865T
I21UN6=X3FUdLV5^LfI_LVd=OF9YKV@PI6EV3Bm/JG/PGgQ/86aYKVEdKgeRJFiT
86AUIPd_KGAk85mhK21]KgIUM6mmHVU^I21TIFH=;f=dNb1ON6`PHgEbMVEdKgeR
JFiT86AUIPd_K6PPNb1TMG0PGgQ/871_L21SMG9bIFidL6mYKW@PIGQSJ21`Kg0P
K6U^IGA_OF9YKV@PI6EV3Bm/MR1k86AeL21ON6`PL6m`86=eLW9UKWA`KfU^M21`
Kg0PIGQSJ21/JFiUM6mmHVU^I21TIFH=;g9`NemhK2mSMUmR87QTIRmSMUmb87QT
IPeON6`_HgIOM21hI6H_HgIOK21hI6H=HgIOK21SMUmd86e_MVEdK`eSMUmb86=f
Gg@PK6U^IGA_3F=fGg8PHgIOHR1/JFiUM6l=HgIOK21SMUmR86aYKVEdK`eSK6mc
IG1QM6P=OF9YKV@PI6EV3FE^I7eYIVE/LfEmI6EV3BmdIG9]JFiQM6D=NgEcIG9T
JF=d82mCM79_JfE1I6YeLgA4JF=d86]^KgM^87]SMG9bIFidI6USM21CM79_JfE1
I6YeLgA4JF=d86EaNfE^I7eYIWeYIPeSMG9bIFidI6USM213ETAYHg@PIG5kIFiT
OFUVOFAUIPd_KGQ=HGPP=S@PI6EV3Bm]N5=dJb1KKGQ=HGPPNfeQM79YN7dPLVE`
IF5dGFAUIPd_KGQ9I7PP<21TIFH=;g=dKG]]N5=dJb1]N4UTN20`86ad87/_KGQ9
I7PP<21cM6mbIGeYIR1]N4UTN21WIG@PHgEbLVE^M6eQM79YN21`Kg0P;fehBFAh
86ehBFAh834PHFAT87=dKg9UOFAUIPd_LWA]NfehBFAh834PIfDPNbm]N4UTN21]
N4UTN20a87=eHR1cM6mbIB1]N5=dJb1]N4UTN21WIG@PLfEdKF5dLVUhOFUV87eT
IFH=;g=SK21k83Lb86AYMR1UN6=X83Lb86AYMR1UN6=X87=SHFaU87dPI6EV3Bmc
HfaY87/P=c8PIGQSJ21TJGHPIGQSJ20g<R1UN6=X86AYMR1UN6=X87=SHFaU87dP
I6EV3BmOHgI]M7PPKF5dLVUh86AUIPd_GgAhM6edN21]HGAbJGPPI6EV3BmOJFiY
M6edN21]HGAbJGPPI6EV3BmhI6IkIGQSJ21TIFImI6EV3Bm]JFik<R1SKg1i86Md
NfEhHfQmJFHPL6m`OFAUIPd_KF5hNc8PHfm`NB1/M7]UN6=XOFUV871_L7eTIFH=
;d=FMVES838e=R1QLW9QNB1TIFH=;e@PM79eIB1TIFH=;dHPIV5/LfDPI6EV3BmO
JF@P<21TIFH=;emUKV=_I6U^I6Eh830PI6EV3BmOIFiSKfA1LW8P<b1QLW9QNB1T
IFH=;emVI20`86AUIPd_GgAUN7ACHGIU86ieK6`PI6EV3BmOK6EdM6EbDg1QHfDP
<21TIFH=;emcL65SIEQdLV4P<21TIFH=;em@HFMUDf5fIB1^MFa/86AUIPd_Gg1U
KVPP<Bh`86AUIPd_Gg1UKWHP<Bh`86AUIPd_Lf5fIC0PKWE/K21TIFH=;emg830P
I6EV3BmOJ20`86AUIPd_GfAc830PI6EV3BmXHg@PIV5/LfDPI6EV3Bm`Mb0`86AU
IPd_MfAYIR0`86AUIPd_M6E]L20`86AUIPd_HgEbLVmd830PI6EV3BmcHGIUJ65^
I6aULR1^MFa/86AUIPd_JF4P<21TIFH=;fUh830PI6EV3BmYN6hP<B1TIFH=;dee
K7AYL6aUA65dHE=_MG9SIG<PIV5/LfDPI6EV80d_I6ERMFL=NfAeL20_96E`Lb1U
N6=X86i_M21TIFIk;g=QMVEXHFiTK6Eb86EbLVmbI6USM20_J65^I6aUIG9bKg8P
IfEd86AUIPeULW9_LVAYHg@=;fQQKVA/IFEbLVmbNbAULW9_LR1RIFMYKPe^IGMU
LW9_LW/_KVEgIG9bKg8PIV5/LfDPI6EV3G=XKgM`HFMU3CLb83Lb87=SHFaU3Bm8
IFafIGAYHf4PIVU^I6I_KW@P;S8PLf=QK6EVKfid87=UM6I_KW@=;S8e83T^=R1]
KgIUM6l=:4EbLVmb>R0YLfQ_M`eULW9_LViQKFD=NfAeL21dNG1U;g=dLVU^IgAi
L6DPKVD=NbQSKfifIG9dIF@PIG9bKg8PKV5]IB1gJFa/86E^I21eL21YKR1dJ6Uc
87=dLVU^IbUSMW=mJFH=LfQ_MgeUN6ES3Bhb=B0i;S@PKFmfIGA_3BQ?IVIUKVAY
KVLP@fm]KF5^I3XP:G=XKgL=;f=_KFeQKV@PK6mQI0ekI7E`87AiL6D_LgAbJFiW
M7U`IB1^I@ek:6=_KWIULWAUI21SKfe]HFiT86iQKFDPMfU/K21UKV@PMG0PJFhP
M6QYLb1cM79YKVLYHgIcOFUV3G=XKgMmIGQUH`d^<SDP>Bhb86e_MVEdK`dXDgAQ
Hf/j82UcJ6mg3FmcM65SJ`ek;S8e86=eLW9UKWA`KfU^M20^<R1cMF8PIGQSJ21`
Kg0PKFmfIGA_3FAeL21dNG1U;g=dLVU^IgAiL6DPKVEkI7E`87AiL6D_JFidIFMU
LWAiL6DPIG4=<B1YKVAUN21dNG1U;g9UHFadNG1U86Ea86mb3C4PJFiTIGPPM7U`
IBm^HFeUM7U`IB1ULB1_LPe^Kg@PNgAiL6EmJFH=:6=_KWIULWAUI21cM65SJb1g
JFa/86E^I21eL21YKR1dJ6Uc87=dLVU^IbUSMW=mJFH=LfQ_MgeVKg9QK6`=LfQ_
Mg1QIfD=@eI4JF=d82mcHGIUJ65^I6aULR1WIG@PIGQUHgeYIPeUKVAmL7EdOFUV
OFAUIPd_K6=kLfEdK6U^IF=QL7eTIFH=;faZNg=UM6aYKVEZKfU^OFAUIPd_K6ek
LfEdKFUdIG9/JFeYM7eTIFH=;faVNg=UM6I/HGAmI6EV3BmSL7]SK6mcIG1QM6Qm
I6EV3Bm^L7]^IGM`HGAXOFAUIPd_971cNR0c<21QLW9QNB1TIFH=;bA`JGPP<21T
IFH=;fMcNfMcHGIU82A`LgXPI7E`82A`JGPPGg1UKVPPL7Ed82A`JGPP<B1QI6@P
Gg1UKWHPL7Ed82lTL6Uh82A`JGPP<R1QI6@PI6EVOFAUIPd_Ig9kIg9ULgA_LVD_
971YN20TL6Uh838PLgER86AUIR0TL7=j86AeL20TL6Uh86MUM20_Gg1UKVPPIGQS
J21TIFHP971YN20a865TI21WIG@P;em`IFif86EhHfPPI6EVOFAUIPd_K6UkK6U^
IGA_OB1TIFH=;faXNf=eLW9UKWA`KfU^M21UN6=X871_L21/JFiUM6mmI6EV3Bm/
MW]SMG9bIFidL6mYKW@PL6m`86EhHfPPK6U^IGA_OFAUIPd_KGAkKFmfIGA_OB1T
IFH=;emSMUm]J7]SMG9bIFidL6mYKW@PIGQSJ21`Kg0PKFmfIGA_OFAUIPd_Gf=f
GfefNf=eLW9UKWA`KfU^M21`Kg0PIGQSJ21]KgIUM6mmI6EV3BmSM7]SMG9fIGA_
OB1TIFH=;g9dNc@P;C8PLVm/K21]KgIUM6l=I7E`830PIGQSJ21bK6U^IGA_3FEh
HfPP<21bK6U^IGA_3FiUIb0`86EhHfPPLVaYKVEdK`eSK6mcIG1QM6QmI6EV3BmO
J78=N`ek;d1ULW8PIV5/LfDPI6EV86=eLW9UKWAVK65d86AeL7]WLf5fIG]UKf=/
JG1mLgA_L71UI7]WLVEcM6mbIB0b86eeK21TMG0PLfEdIVaQM21TMG0P<S0`86MU
NbPU9B13HFifHG<j@faYL21VHFU/IFALLRU`LVU^M20_@6EbLR1dLWEU86AUIR1`
Kg0PIGQYM7eYIWekIg9ULgA_LVDPLfEdIVaQM21UN6UdOFUVIFacIGe/Kfm`841U
LW8PKVmd87]UKf=/JG1mJFHPLfEdIVaQM7d=Nbm0IG9b86IQK7=U86AUIR1SMG9b
IFidIVaQM21TMG1kIg=QMVEkHfaYL7ecM6m`L6ETNfMbIG=dKg9U838PKGE/86Ae
L21cIGAVK65d86AeL20b<30PIfEk:2DU84=QKWIQLcY3K6U`86IQJFaUI5ab:G1b
JFid82m0IG9b87AbMFDPI6EV871_L21UN6UdOFUVOG]WLVEcM6mbIB1cIGAVK65d
86EhJGAmJFIUK7=UOFa_Kg0P@6EbLR1^Kg@PNf=/JG1mJFHPLfEdIVaQM7d=OFAU
IPd_Gf=c86ieK6`PI6EV3BmVIg]cIGAWLV5iOFAUIPd_LfEdHfeiJf=_K6mb87MX
IG9U87]`Kg0PM79eIGekIV5/LfEmJFIUK7=U3G/_ISAk87=UM6=]NF]SKfa_LWeT
IFImNbmV=7/a87=eHR0d834PLVm/K20cNc<PJFiTIGPPHFAT86iUIb1TMG0P<21/
M7]`Kg0P<7eYIR0c834PLVm/K7ebIG1UHG@PLfEdLVMRHfm/Kg8PL6m`OFAUIWeY
IVE/LfD=;g=UM6=_K6mbLg1QHfDPMfQULVDPNg1_L21dLWEUOG]VHFacIGeYIVE/
LfD=NbmcHg=k86AeL21cIGASKfa_LW=`HF=U82mOHg<PIGQSJ21TIFImI6EV;fHc
Nb1OHg<PLfEdHfm/Kg9cL65SIB1cIGASKfa_LWeTIFH=OG/_IS=k87=UM79WHV=_
K6mbOFAUIRmcHg=k871_L7eTIFImJFIUK7=U3BlTHf<P=B1QLW9QNB1TIFH=;fIY
KVASKGU[HgEcM6m]Hfm/Kg8PMfQULVDPNg1_L21dLWEUOG]VHFacIGeYIVE/LfD=
KVmd87/_IVU^I6=]NF]SMG=dKfeSKfa_LW/THf<PHG=dKg9UOFAUIWeYIPd_LfEd
HgEcM6m]Hfm/Kg8PMfQULVDPNg1_L21dLWEUOG]VHFacIGeYIVE/LfD=KVmdNbmc
IGASMG=dKfeSKfa_LW]UN6=X865/Kf5T871_L21`Kg0P=7/d86U^I6Eh86eeK20d
834PLVm/K7ebIG1UHG@PLfEdHfeiJf=_K6mb871_L7eTIFImJFH=;fISNcHP<B1b
Kfa/86IYKVASKGU[HgEcM6m]Hfm/Kg8PIGQSJ21cIGASMG=dKfeSKfa_LWeTIFH=
;g=UM7=UL65bHGAYKfiWLV5i87MXIG9U87]`Kg0PM79eIGekIV5/LfEmJFIUK7=U
3Fi_M7/_LfEdLfE`HG9QM6U_KVMbHGTPNg=iLgAUKFAYHg@P;g=UM6MbHGTPIfEd
86EhIF=m86AUIWeYIPd_LfMk87=UM7=UL65bHGAYKfiWLV5iOFAUIPd_Lg1k;em`
IFif87QTIRmOL6E^J21hI6ImI6EV3BmbL0ek;f=fGf8PN6AV;f=fGg8PN6AV3BmS
MUmd87QTIRmSMUm/87QTIPeSMUm/86=fGg@PKFmfIGA_3F=fGg8PHgIOM21/JFiU
M6l=HgIOLR1SMUmR86aYKVEdK`eSMUm/86=fGf8PK6U^IGA_3F=/Kg=UL65dJ7eT
IFH=;g9bNbmiLV5TJGEc87QTIPd_N79QI6UeLb1hI6H=;f=fGf8PN6AV3BmSMUmb
87QTIPd_HgIOM21hI6H=;f=fGf`PN6AV3F=fGf`PN79QI6UeLb1QI6@PHgIOM21]
KgIUM6l=HgIOLR1hLV5TJGEc87=eHR1SMUmd86aYKVEdK`eOHgI]M7PPHgEbLVE^
M6eQM79YN21`Kg0=HgEbLVE^M71_JFid87AbHFicK65dI@ehLV5TJGEc87UbHFAY
MG<PLf=QK6D=<B0`834P<B0a865bHgA_83AkL6m`OG9UL6EQM0eOHgI]M7PPLfEd
KF5dLVUh3F=fGg8PHgIOHR1iLV5TJGEc87=eHR1/JFiUM6l=Gf=fKGAh86=eLW9U
KWA]HGAbJGPPL6m`3F=eLW9UKWA`KfU^M21dLV5^LfaQM6D=N79QI6UeLb1iLV5T
JGEc87=SHFaU3C0P<B0]<B0a834PHG9SM6lP=7]`Kg1mLVE`IF5d3EmSMVedN21c
IGA]HGAbJGP=HgIOK21hLV5TJGEc865TI21SMUmR86aYKVEdK`eOHgI]M7PPHgEb
LVE^M6eQM79YN21`Kg0=HgEbLVE^M71_JFid87AbHFicK65dI@ehLV5TJGEc87Ub
HFAYMG<PLf=QK6D=;C4P<20]<B0]<B0a865bHgA_83AkL6m`OG9UL6EQM0eOHgI]
M7PPLfEdKF5dLVUh3F=fGf`PHgIOM21iLV5TJGEc865TI21/JFiUM6l=Gf=fKGAh
86=eLW9UKWA]HGAbJGPPL6m`3F=eLW9UKWA`KfU^M21dLV5^LfaQM6D=N79QI6Ue
Lb1iLV5TJGEc87=SHFaU3C0P;C4P<B0]<B0a865bHgA_83AkL6m`OG9UL6EQM0eO
HgI]M7PPLfEdKF5dLVUh3F=/Kg=UL65dJ7eTIFH=;fE`NemSMVedN21SMG9bIFid
KF5dLVUh871_L0edLV5^LfaQM6D=Lf=QK6D=<B0`86e_MVEdK`d`830P<B0`83<f
<21QLV<=Hfa_LfE`HGAX3EmSMVedN21cIGA]HGAbJGQmI6EV3BmgI7]OHgI]M7PP
HgEbLVE^M6eQM79YN21`Kg0=M79QKW=/HGAU3G=SHFaU3C0P<21]KgIUM6l=<20`
834P=B0]<R1bKfa/865bHfh=Hfa_LfE`HGAX3EmSMVedN21cIGA]HGAbJGQmI6EV
3BmQLg]OHgI]M7PPHgEbLVE^M6eQM79YN21`Kg0=M79QKW=/HGAU3G=SHFaU3C0P
<20a83DP;C8PLVm/K21QLV=^3EmSMVedN21cIGA]HGAbJGQmI6EV3BmTL`ekGg1U
KWHPGg1UKVPPKVDPI7E`Ng=dKB1OL6E^J21TMG0P<21/IG]`Kg0P<GeYIR1OL6E^
MR1TMG0P<21/IG]`Kg0P<GeYIR1cHf5/IGekGg1UKVPPLfEdK6U^IGMYI7AXOFUV
IFacIB1cM79_JfDPNg9dKGeYIWeTIFH=;fAVNfIYK6amI6EV3BmTIG]UKfIYK6am
I6EV3BmOIg=dJb0e865bLV5i86AUIPd_GfMcM6]S830PI6EV3BmOIg=dNb0i86AY
Hg@PHVEWJFhPK6EfIF`bNbmOHf=c86=eLW9UKWASKfa_LW=`HF=U86AUIR0_Gf=S
85]SMG9bIFidHfm/Kg9M86AUIWek;emSHb1KHgEbLVE^M79WHV=_K6mbGFAUIWeY
IVE/LfDPNf=eLW9UKWA`KfU^M7ecM6m`L6ET87/_Gf=`86ieK6`PI6EVOG/P<R1Q
LW9QNB1QLgA_LVDP;emSL21UN6=X86AUIWeYIVE/LfDP;emSIR1SMG9bIFidIVm^
M21TIFH=;emSK7LPHgEbLVE^M6aYKVEgJFAdJ21TIFHP;emSK6<PHgEbLVE^M6aY
KVESHG0PI6EV82mOHfaZ86=eLW9UKWA/JFiUJVmYKR1TIFHP;emSKF`PHgEbLVE^
M6eYM6EbK6U]JG@PI6EV86=eLW9UKWATJF=d86E^I7eTIFH=;fQcNfiUMg1QM6PP
Ig=QMVDPLgA]OFAUIPd_J6=k;emXLR1/Kf5T86EhHfPPIfEd86EhIF<PKVEgL65d
J7eTIFH=;fQUNemWLgA[85mWLgA[Hb1OIg=d871eM20_GfMcM6]S85mWLgA[Hb0a
865TI21cM6mbIB0=Ig9ULgA_LVDPLWA]82mOIg=dJf<PGfMcM6]S834PLgER87=d
Kg9U85mWLgA[85mWLgA[Hb1WIG@PK6EfIF`bNfAeL20_Gf=SLb1WIG@PLfEdHfm/
Kg9cL65SIB1TMG0P;emSHb1WIG@PHFa_HF@PL6m`87=UM6=_K6mbOG]TMG0P;emS
Hb1WIG@PHFa_HF@PL6m`87=UM79WHV=_K6mbOFUVIFacIB1TMG0P;emSL21WIG@P
I7E`86ieK6`PIG4P3Fi_M7]QK6mQI21`Kg0PKFmfIGA_OG]`Kg1mJFIUK7=U86Ae
L20_Gf=V86MUM21cIGAVKfid3FAeL2mOHfag86MUM21cIGA/JFiUMfUTM6PPI7E`
;emSK6<PIfEd87=UM6aYKVESHG0PI7E`;emSK6XPIfEd87=UM6aYKVEZKfU^86Ae
L2mOHfe/86MUM21cIGA]JGAULVaYKFUd871_L7eTIFH=;fUTNb0_GfUT87QTIWeT
IFH=;emYKF5dLVUhNemg830P<21OJ21OJF@P<21^IG]^IFLP<21OJ7ek<20`OFUV
IFacIB1OHgI]M7PPHG=dKg9UOFAUIPdU84=_L7UbJFMXM20X@bTP<CTi<2`P<CTi
<B1RNB11I6mRIB1CNG=dIFec84U^HfmbL6mbHGAUI2h=9B11K6`PLVUWJ7Ac879U
LfEbMVET;Pe/IGIUK38PNb1cHGIU82mTKfidK6mQI6aUMVE/<B1hI6HPOFUV3Bmc
M65bM6i_K6mQI7]k;fi_K6mQI21cHGIU86AUIWdPJFImI6EV3BmUKVA^Kfa_HFAk
Nfi_K6mQI21bIG=dKg9UOFUV87eTIFH=;gAULgAcNG=dIFeTJF=dNgMXIG9UNg=i
LgAUKFAYHg@PIG5kM79eIGekIV5/LfEmJFIUK7=UOG]VHFacIGeYIVE/LfEmI6EV
3Bm^Hfm/Kg9c834PI6EV3BmSKfa_LVU]HFMU87MXIG9UNg1_L21dLWEUOG]VHFac
IGeYIVE/LfEk;fiSKfa_LW<P<0ecM65dMG=TJF=d869UIfU^80d_L79_HfEcLf=_
K6mbLb1gJ6EbIG]`Kg0PL6m`871bKf=ULg=SKfa_LW=mNbmTIGIYHfEYKVI_87MX
IG9UNg1_L21TIGIYHfEYKVI_82m3Kfa_LW<PJfi_Mfh=Ng1_L21kI6EfJF=UJFiV
Kb0_@fm/Kg9c86MUM7emJFImJFImJFIUK7=U86E^I21TIFH=KV=_K6mbLb0`86iU
NbmSKfa_LVU]HFMU87AULgAcNG=dIFeTJF=d3BmcIGASKfa_LWAbHFicIVEb87AU
LgAcNG=dIFeTJF=d3BmSMG9bIFidHfm/Kg9dLV5^LfIULR1dIG=dLgUcM6E]I6US
M0d_HgEbLVE^M6=]NF]SKfa_LR1dIG=dLgUcM6E]I6USM0eQKV@PHFiT865^I21^
KgAk;fiSKfa_LW<P<21TIFImJFImJFImJFH=KV=_K6mbLb1TMG0P<B1^IB1UN6=X
86AeL20c86iU86EhHfPP=21^IB1QKV@PHFiT87/_KV=_K6mbLb0`86AUIWeYIPe^
Hfm/Kg9c834PIG4PI7E`86AeL21^Kg@PLgAQLWA^Kfa_HF@=NbmTKf=/MGAYKF5W
IG]KNc8e=B1]MF`PLVmeKV@PHgIY869gHfaeM21UN6=X86MUM20b=CDPI6UfOB0_
IGQUHb1/Kf5T86AeL21SMG9bIFidM79QKW=VIG8PIGQSJ5dP3F=fN21RJFiT87=U
M7AbHFicIVEb85mg85mX83PPGfU]HGAbJGPPGfAc86U]HFMUOFAUIWeYIPe^Kg@P
IFiTKVm/Kf5T3FiSKfa_LW<PI7E`83<PIG4PIGQSJ20d86Ea86mb3FAeL21TMG0P
KVmd87=dHG9dKVm/Kf5T3G/_KWE/K71bKf=kNgemI6EV;f=_KV=QM7EdJFak;fEh
IF<PK6mQI0dg82da879_K6`P;fEhIF<PK6mQI7eTIFH=;fAUIW=eHV=/MG@=Nc4P
HFAT86MUM6U^M6EbMV5/86AUIWeTIFH=;g=`Hfm^Hf5dM79QKW=VIG8P820=Nbm4
HfaeM21UN6=X86AUIRm3HfaeM21UN6=X86AUIRm2HfaeM21UN6=X86AUIRm1Hfae
M21UN6=X86AUIRm^Hfm]L7EdIB1UN6=X86aT3F=eLW9UKWASKfa_LWAbHFicIVEb
3E]k@F=/MG@PKV=_KG1eM6EmHfm^Hf5dMGAYK5dPHgIh3E]k@V=/MG@PKV=_KG1e
M6EmHfm^Hf5dMGAYK5dPHgIh3E]k@f=/MG@PKV=_KG1eM6EmHfm^Hf5dMGAYK5dP
HgIh3E]kA6=/MG@PKV=_KG1eM6EmHfm^Hf5dMGAYK5dPHgIh3G=UM6=_K6mbM79Q
KW=VIG9mI6EV3BmcIGAeL79WHV=/MGAc3G/_HVUd<gPPLVMRHfaeM21/IFiWM6PP
<b1cMF8PI6EV3BmRJG@aN21RJG@cN20c86UTJGHPI6EV;g9SK7Ed879WHV=/MG@P
I6EV3BmWHfaeM21bHfaeM20a869YM3=h86AUIW=eHV=/MG@_HV=/MG@PLV=/MG@P
<R1RJG@cN21TIFIcMF9SK7EdOFAUIWeYIR1^Kg@P80eUKVA^Kfa_HF@PKV=_K6mb
Lb0c86Ea86AeL21TMG0PKVmd87=dHG9dKVm/Kf5T3G/_<f=_KG1eM6EkIGQSJ21R
JG@cN21]MF`=LVmeKV@PHgIY86MUM20b=CDPI6UfOFAUIPd_I6mSK7EdJFeQIfEk
9BmbIf9SK7Ed87QTIR1`Kg0P3G=UM7E`LVMRHfaeM7<_<f=_KG1eM6DPLV=/MG@P
If=/MG@PHV=/MG@PI7E`3G=`Hfm^Hf5dM79QKW=VIG8PGgLPGfPP>21OJFeQM79Y
N0eK;emTLb1/Kf5T82mUN6ES86a_HF@P;fAeL21/Kf5T86AeL5eSMWP=KWE/K71b
Kf<PKWE/K71bKf<PM79eIB0c86=_K6mbJFeQIfEmI6EVOFUV86i_M21UKVA^Kfa_
HF@PKV=_K6mbLb0d86Ea86AeL21TMG0PKVmd87=dHG9dKVm/Kf5T3G/_LgAeIVIS
K7EdNf=]NF]YKVAUN20c82da879_K6`PL7EdOFAUIPd_IWA_JFidNc4PIGQSJ21c
MF8P<SDe86eeK21bKgE^I21SMVUmI6EV3BldHfm]L7EdIB1k86EhHfPPHVUd=7PP
KGE/879_MFiT86=fJB1WIG@P<SDe86AYMR1m86AUIPd_Hfm]L7EdIF=]NF]SK7Ed
Ng=UM7E`LVMRHfaeM7<_HVUd=7PPLVMRHfaeM21/IFiWM6PP<b1YI6Uf83@PKGE/
83@PLgER86AUIPd_HfeiJf=/MG@PHVUd=7PP=21QI6@PLgAbJFiW86AUIPd_Hf=/
MG@PHfeiJf=/MG@PI6EV3Bm]HfaeM21SHfaeM20a869YM3Ah86AUIW=eHV=/MG@=
;gUSK7Ed86=SK7Ed838PHVUd=7PPI6EVLgERHfaeM0d_Jf=/MG@PHf=/MG@P<b1R
JG@dN21TIFIcMF9SK7Ed3BmSKGU[JFiTIGPP<21TIFH=<20a869YM35h3G]TMG0P
;f=]NF]YKVAUN21UN6=X869YM35h86EhHfPPLgER83@PKGE/86AUIPdc86eeK21T
MG0PLV=/MG@PIGQSJ21WIG@P<SDe86AYMR1UN6=X86AeL21WHfaeM21UN6=X86MU
M20b=CDPI6Uf3FEhHfPPHV=/MG@PIGQSJ21WIG@P<SDe86AYMPecIGAbIf9SKfa_
LR1SMG9bIFidHfeiJf=_K6mb3FIdKfU^M21[HfaeM21cM7EVIV=/MG@=IWA_JFid
87USK7Ed87=dMFIVHfaeM0eVM6mYKW@PKF=/MG@PLgAeIVISK7Ed3FIdKfU^M21S
HfaeM21cM7EVIV=/MG@=OFI_LWeTIFH=;fA_HfaeM6U]HFMUNfU^MV5/JFASKfa_
LWAQHVaU?g]SKfe`MGAUHfeiJf=/MGAmJFH=;cASKfe`MGAU86=SK7Ed86eSK7Ed
87USK7Ed86]SK7Ed87=`Hfm^Hf5dM79QKW=VIG8=GgLPGfPP>21OJFeQM79YN5/_
GfAc86a_HF@P;fEhIF<PK6mQI2mTMG0PK6mQI21TMG0PI7E`GB1SMWPP3FieK6a`
LVmS86ieK6a`LVmS86ieK6a`LVmS87AbMFDP=21SKfa_LVU]HFMUOFAUIWeYIPe^
Kg@PIFiTKVm/Kf5T3FiSKfa_LW<P<21UL@eTMG0PI7E`86i_M21cM65bM6i_K6mQ
I0ek;f=_K6mbIGQ`HFiTNfeiLgAbJFiWIGQ`830PLVMRHfaeM0dc86=_L7T==b0]
<B1bKfa/3G/c86eeK20c86MUM6U^M6EbMV5/871eM6U^M6EbMV5/86EhHfPP<b1Q
I6@PIGQSJ20c86=_L7UmIVmbHFa/3G1_L21`Kg0PL6m`871_L21`Kg1mI6EV3BmS
LVEQM6EUN71QKVAcM79k;feiLgAbJFiWIGQ`86EhHfPPLg@`86aUKVMdJ21]MF`P
LgAbJFiW86AUIWeTIFH=;fA_HfaeM6U]HFMUNbmbIf9SK7Ed87QTIR1`Kg0P<b1S
LVEQM6EUN71QKVAcM78PGgLPGfPP>21OJFeQM79YN0eK;emTLb1/Kf5T82mUN6ES
86a_HF@P;f=_K6mbIGQ`HFiT86a_HF@P;fEhIF<PK6mQI5dPHgIh3FIQK7=U83<P
Hfm/Kg9YKF5WIGeTIFImJFHPKVmd86E^I6i_K6mQI0e/IGIUK38PNb1TKfidK6mQ
I6aUMVE/<B1bIG=dKg9U87eYIPe/IGIUK38PKVmdNb1cHGIU82mTKfidK6mQI6aU
MVE/<R1hI6HPOFUV3BmbIf9SK7Ed830PI6EV3BmTKf=/MGAYKF5WIG/_J6UfHF`P
<SDe86AUIR0=Fbm9KVAUN6ET82m4IGIYHfEBAd8PJ6UfHF`PLVMRHfaeM5dPLfEd
Hfm/Kg9cL65SI@eOJFeQIfETJF=d86AeL21RIFMYKR0=;eMYI7AX85mg86AUIR0=
;dQUJFMXM21OJ21TIFHP80d_A6ESKfAU85/`86QYMV5/GB1TIFHP80d_BFeQIfE=
HGAbJGPPGfU]HGAbJGPPI6EV3Bm2JGAcD6Eb@fm]L6m^IFid83PPI6EV80d_BFid
IG9`KfaQM6DPIV5/LfDPI6EV3FE^I21YKF5WIGeTIFH=K6EfIF`b86i_M7/PI6m^
M6a_HFA/IGIUK38PLVEcM6mbIB1mJFH=9BE5KVA@LVmSDfEd3BmOJFeQIfETJF=d
834e86AYHg@PHVEWJFhP;dU]HFMUE7U`IB0a86AUIRm2JGAcD6Eb@fm]L6m^IFid
83PPI6EV;dU^M6EbL6m/HGAU86IQK7=U86AUIR1SMG9bIFidI6USM21UKV@PI6EV
3BmXHG=SKfa_LR1dLWEU86AUIPd_K6EfIF`b87=iLgAUKFAYHg@P;faQKVMeHFMU
K6EfIF`PJfi_Mfh=NfaQKVMeHFMUK6EfIF`P<R1WIGekIV5/LfEmJFIUK7=U86AU
IPd_IVmeLVEa87/d86U^I6Eh86Ea83PP<B1bKfa/3C@PJFiTIGPPIG4P>20a879_
K6`==21YKVAUN21ULB0h834PLVm/K0dd86U^I6Eh86Ea83PP<B1bKfa/3G1_L21`
Kg0PL6m`871_L21QKV@PHFiT865^I7dPI6EV3BmcIGAeL69QKVAcNfMcHGIU3BmO
LfEdM79QKW=VIG8PLgUcM6E]I6USM20_LfEdM79QKW=VIG8PIfEd86AUIPd_Gf=e
LW9UKWAdLV5^LfIULR1cNG=dIFeTJF=d82mSMG9bIFidM79QKW=VIG8PIfEd86AU
IPd_GfU]HFMU87=iLgAUKFAYHg@P;fU]HFMU86MUM21TIFH=;f9/HFi[830PGf=e
LW9UKWAdLV5^LfIULR1UN6ES3C4PGf=eLW9UKWAdLV5^LfIULR1UN6ES86Ea86AU
IPd_KVEWHGAYMVDPHVaQKV]k<21OHgEbLVE^M7AbHFicIVEb86EhIF<P<2he86ad
O@ek<21OHgEbLVE^M7AbHFicIVEb86EhIF<P<B1OHgEbLVE^M7AbHFicIVEb86Eh
IF<PIgAmJFIUK7=U86AUIPd_JFifIG9dIF@o86iUIf5dJGIU86AUIPd_Gf=eLW9U
KWAWLV5i87=iLgAUKFAYHg@P;f=eLW9UKWAWLV5i86MUM21TIFH=J65cHfm/Kg9k
;bAR830PI6EVOB1k;bAR83DPI6EVOB1YIVE/LfD=;g=UM6=]NF]SKfa_LR1gJ6Eb
IG]`Kg0P<B0`830P<21cIGASKGU[Hfm/Kg8PGf=eLW9UKWAWLV5i834PIGQSJ21c
MF8=<20a830P<21cIGASKGU[Hfm/Kg8PGf=eLW9UKWAWLV5i834PIGQSJ21cMF8=
<20`834P<21cIGASKGU[Hfm/Kg8PGf=eLW9UKWAWLV5i834PIGQSJ21cMF8=<20`
830P<B1cIGASKGU[Hfm/Kg8PGf=eLW9UKWAWLV5i834PIGQSJ21cMF8==21k=21S
Kg1iOB1bIG1UHG@=<B0`830P<21VKgEbIG5k;bAR834PLgA_LVEmJFH=<20a830P
<21VKgEbIG5k;bAR838PLgA_LVEmJFH=<20`834P<21VKgEbIG5k;bAR83<PLgA_
LVEmJFH=<20`830P<B1VKgEbIG5k;bAR83@PLgA_LVEmJFH=<20`830P<21VKgEb
IG5k;bAR83HPLgA_LVEmJFImJFH=HVaQKV]k;bAR83HPLgA_LVEmJFH=968P<21U
LB0THR0e86Ea86mbNblTI7@P<21TIFImJFH_96Ad82da86AUIR1WLVEcM6mbIGeT
IFH=;fA_JFeQIfEk3FaUMVE/<W]YKF5WIGekHVEWJFh=EfUTM6PPB6EYIfQd849Y
M7=@IG93Kfe`KfiUKW@PBFeQIfE=HGAbJGP=A6ESKfAU86aUKVMdJ20b86Ea3G/_
A65dHE=_MG9SIB1/Kf5T86E^I21YKF5WIGek3DAUHfmTIB1/IFiWM6PP=R1UL@ek
CGE/M6U`K6E4HGAQDfmeLV=ULg]4HGAQDfmeLV=U830PIfEd84AQM65CKgEbHfDP
<B1WIG@PA65dHE=_MG9SIB0b86MUM7ek;dAQM65CKgEbHfDPK6mQI7eYIVE/LfD=
CGE/M6U`K6E4HGAQDfmeLV=ULb0c86E^I214DdU3Kfa_LTU]HFMUOG/=A6ESKfAU
86aUKVMdJ20h86EaNdeeK7AYL6aUA65dHE=_MG9SIG=kA65dHE=_MG9SIB0`86MU
M214HGAQDfmeLV=U834PIfEd3DAQM65CKgEbHfDP<R1WIG@PA65dHE=_MG9SIB0c
86MUM7ek;dAQM65CKgEbHfDPK6mQI7eYIVE/LfD=CGE/M6U`K6E4HGAQDfmeLV=U
Lb0d86E^I214DdU3Kfa_LTU]HFMUOFUVOFUVIFacI@emJFIUK7=U3GeYIVE/LfEm
I6EV3BmTM7/_LVMRHfaeM21hI6HP;f9gHfaeM21hI6ImI6EV3BmSK7/TJB1cIGA]
HGAbJGPPM79QKW=/HGAU87=SHFaU3BmOMb1OJFeQIfETJF=d82mGJFAdJ21WIG@P
I6EV3BmOJ21OJFeQIfETJF=d82m8IFUWJ7@PIfEd86AUIPd_GfAc85mYKF5WIFAY
Hg@P;dAQM65CKgEbHfDPIfEd86AUIPeTKf=/MGAYKF5WIGdPI6EV3BmSI7/TJB1c
IGA]HGAbJGPPM79QKW=/HGAU87=SHFaU3FaUMVE/<W]OJFeQIfETJF=d82m3Kfa_
LU=`HF=U86MUM21cIGASKfa_LW=`HF=UOFUV3BmOMb1OJFeQIfETJF=d82mGJFAd
J21WIG@PI6EV3BmOJ21OJFeQIfETJF=d82m8IFUWJ7@PIfEd86AUIPd_GfAc85mY
KF5WIFAYHg@P;dAQM65CKgEbHfDPIfEd86AUIPeOJFeQIfETJF=d869UIfU^3Bm9
KF5WIDeQM79YN21OJFeQM79YN21TIFH=HgEbLVE^M6AYHg@PIFiT3FA_JFeQIfEm
86AUIPd_JFek96TPLfEdKF5dLVUh87AbHFicK65dIB1cHf5/IB0=K6EfIF`bNbm4
IGIYHfE7LV5i87=UM6=_K6mbLg1QHfDP<21cIGAWLV5iOFUV3BmOMb1OJFeQIfET
JF=d82mGJFAdJ21WIG@PI6EV3BmOJ21OJFeQIfETJF=d82m8IFUWJ7@PIfEd86AU
IPd_GfAc85mYKF5WIFAYHg@P;dAQM65CKgEbHfDPIfEd86AUIPeOJFeQIfETJF=d
869UIfU^3BD_A6ESKfAU85/`835M86AUIR0P3BD_EfUTM6PPGgLPI6EV3BD_B6EY
IfQd85mX86AUIPd_BFeQIfE=HGAbJGPPGfU]HGAbJGPPI6EV3F=eLW9UKWATJF=d
86E^I20=I6mYKF5WIB1mI6EV3BmSKfa_LVU]HFMU87MXIG9UNg1_L2m4DdU3Kfa_
LTU]HFMU87]SKfa_LVU]HFMUOB1TIFImNbm4DdU3Kfa_LTU]HFMUN`d_96iS87QT
IR1`Kg0P;g1bKf<`87QTIR0c86U^I6Eh838PJFiTIGPPKGE/83LPHFAT83PPI6Uf
86=fJB1cM79YKVLP;g=d<B1hI6H=96iS83<PIG5kNg1bKf<`86AeL2mcM30PN6AV
830PIGQSJ20c86EhHfPPK6E^IgAX83<PLgER3G]TMG0PLg@`86EhHfPPIfEd82hc
86eeK20a86U^I6Eh834PHFAT87=d<21UN6=X86MUM20^=CTPKGE/865TI20a86U^
I6Eh838PHFAT87=d<21UN6=X86MUM20^<C4PKGE/865TI0eSMVTPIGQSJ20c86AY
MR1SMVTPIGQSJ21cM34P<b0a879_K6`PL7EdOFI_LR1cM35mOG]kL79_Hc0PI7E`
;g=d<21hI6HP<21UN6=X83@PIGQSJ21/IFiWM6PP=21cMF9kI7E`3G=d<21UN6=X
86MUM20^<b1]MF`=<B1YKVAUN20a865TI21cM30PIGQSJ21WIG@P;SDi86eeK21Q
I6@=<B1YKVAUN20b865TI21cM30PIGQSJ21WIG@P;S4a86eeK21QI6@=<B1YKVAU
N20c865TI21cM30PIGQSJ21WIG@PHFAT86AeL20b=CD^<21WM7]`Kg0P<SDe;S1m
JFH=<SDe;S0PIGQSJ21cMF8PHgIY3FEhHfPP=21TJGHPHgIY86EhHfP=Lg@a83<P
<B1bKfa/871eM7eVKg8PLg@aOGeYIVE/LfD=JFeQIfEmI6EVOFUVIFacI@d_Ce19
JFeQIfEkJFeQIfEmI6EV3BlTJB1]HGAbJGPPI6EV3BmRJG]cHf5/IB1dLV5^LfaQ
M6DP96TPHgEbLVE^M6eQM79YN21`Kg0PM79QKW=/HGAU87=SHFaU87=UM7E`HV5^
I7=mI6EV3BmUJG/TJB1cIGA]HGAbJGQmI6EV3BmYJg/TJB1cIGA]HGAbJGPPM79Q
KW=/HGAU87=SHFaU80d_GgLPGfU]HFMUI6USM20_EfUTM6PPIfEd86AUIPd_GfPP
GfU]HFMUI6USM20_B6EYIfQd86MUM21TIFH=;emTLb1OJFeQIfETJF=d82m4HGAQ
DfmeLV=U86MUM21TIFH=GgLPGfPPIV5/LfDPGfU]HGAbJGPP=B0]<B1bKfa/85mT
Lb1YKF5WIFeQLf]mI6EV3BmbLg/b86=_L7TPM79QKW=/HGAU3C<P;C4PLVm/K21^
IFLPLVmdHGAU3FiUIb1UN6=X86iUIb1UN6=X87AbHFicK65dI@emI6EV3BmSLg]O
HgI]M7PPHG=dKg9U86=_KV=QM7dPI6EV3BmVI7/_GfIT87QTIWeTIFH=;emVKfid
CF5dLVUhNc4P<20`85mVI20`86iUNbda830P<7ek<B0`831mJFIUK7=U85mSMVed
N21QLgA_LVEmI6EV3BmbIW/_GfE^HfmTJFiTIGPPN6AV3DI_KWA4JG9UHgA_LWTP
IGQSJ21[KVmgKR1k3FIYKVAVKfid86AeL21/IFiWM6PP<B1QI6@PI6USM21RIFMY
KW/a86U^I6Eh;dI9A21^IG]TIFImNg1_L21`Kg1mJFIUK7=UOFI_LV5/K0eTMG0P
;dI_KWA>HFeU86EhHfPPI6EV84I_KWADNG1U830PKVEk;dE^HfmTJFiW84E^HfmT
JFiW838e=R1QLW9QNB1SKg1i86AUIPeOIFiSKfAYKVAUN20`86MUNc0PGfE^HfmT
@G9b85mUKV=_I6U^I6Eh86MUM7]TMG0PM7U`IBm^HFeUM7U`IB1ULG]5KV=_I6U^
Ib0b86U^I6Eh838PJFiTIGPPL7Ed871_L20a865TI7d=NfEhHfPPL6m`OFUVIFac
IGeVKg9QK6`PL6m`OFUVOFUV3F=eLW9UKWATJF=d86E^I0eTIFIYKVEVKfid871_
L21mNg1_L21`Kg1mJFIUK7=UOB1TIFH=;f=fLfIk86IYKVAVKfid86IdDfUjIB0`
830PIWACJGYU85mVI20`86iUNbda86eeK7eYIR0`830PGf=fKGAh865cM6mbIB0=
KF5[IFI_KW@PLfEdIVm^M7eTIFH=;feVNc<P;C4PLVm/K21VJFiTIVm^M20c834P
LVm/K21UN6=X86IdDfUjIB1]MF`PIGQSJ21VM5=YNVDPKGE/830PIGQSJ20`86Eh
HfPP3EmVI20`86iUNbda86eeK7eYIR0`830PGf=fKGAh865cM6mbIB1]HF]UIVm^
M21cIGAVKfidOFAUIPd_Mg9[<B0X82TPI6EV3BmgI6USM20a=R1TJF=d86AUIPd_
EfmbJcLe83Le87=dLVU^Ib1TIFH=;di]Jg]GKg9[=cDPHgIc86AeL7eTIFH=;di`
M7]`MG@PHgI^OFAUIPd_I6Q?I6QkCVe[838P=cTPCW1dOFAUIPd_I6Q2I6QkCVe[
838P<C4a84i`M7eTIFH=;fAXDfAXNdi]Jb0b83Pc84i`M7eTIFH=;g=VEfUTM6Qk
Ig=QMVDP<20`86e_MVEdKb0`830PK6U^IGA_830P<21/JFiUM6lP<20`86aYKVEd
Kb1SK6mcIG1QM6PPHfaYL21cM79YKVMgJFAdJ21WLVEcM6mbIGeTIFH=;fIdLg/_
IWACJGYU86EhHfPPI6EVOFAUIPd_KF]6E7]TMG0_AVm^M5AiL6DPIfEd830PIG5k
I7E`86eQN6aUKVMdJ21TJF=d869UIfU^3G/a86U^I6Eh;dI9A21^IB0b86U^I6Eh
82mEKVUaMFE9A21^IB1QKVAkI6EVOG]`Kg0PL6m`OFUVIFacIGeVKg9QK6`=HgEb
LVE^M6AYHg@PIFiT3FAeL2m6A6E`EVESM6mb838PHfm`NB1WIG@=FfEhHfPP=R1Y
KVAUN21UN6=X83HPJFiTIGPPIGQSJ7]]JdID83<P<B1bKfa/OFI_LV5/K21`Kg0P
L6m`GB1`MG@PI7E`OG/_M6E]L4ID834b86AYHg@PI6EV3GAUKG16E21RIFMYKPd_
AVm^M4eQM79YN21K<B0`830P<B0`831M86AUIPd_AVm^M5AiL6DP<b1TIFH=I7E`
;dE^HfmTJFiW86MUM2m5KV=_I6U^Ib1UN6=X86AUIPd_L79_Hc8P<R1YKVAUN21T
IFH=I7E`;fId<B1UN6=X86AUIPd_IW@b834PHG9bHGTPI6EV3Bm6Kfid@T9_N21K
<20`834P<EdPI6EV3Bm2MFU/I4=XHG9k@eI4JF=d869UIfU^3FEhHfPPI7E`;fId
I7@PN6AV869UIfU^3GMTJF=d869UIfU^3BmSJ78PN6AV;f=XLW=d87MbJc4PI7E`
830PHfQb871eM21TIFH=IW@b830PIfEd86ieK6`PIG5kIW@a86AeL21/IFiWM6PP
<R1QI6@PI6USM21RIFMYKPek<B1YKVAUN2m6BD@PKVDP<R1YKVAUN20_EFiYLGEU
BD@PKVDPHFiTNfAUIWekL6m`871_L7eYIVE/LfEmIVmbHFa/3Bm@HFU^M5AiL6DP
<R1TIFH_DgAbKf]UEfUTM6PP;S0b=20`84I_KWA=HGAbJGPPJFAdLV5^LfI_LVdP
L6m`86AUIPeSMG9bIFidI6USM21UKV@=;g4PIGQSJ21TIFIYKVEVKfid3FId<R1U
N6=X830PIGQSJ21`MGAmJFH=IWATM2m`LVmS<R1WIG@PIGQUHb1UKV@PIFiT86E^
I7eTIFHPIFiT87AUKG16E7eYIVE/LfD=<b1YKVAUN21UN6=X3FAUIVU^IFI_KW@P
IGQSJ21`Kg1mI6EV3Bm]HW]TMG0PI6Q2I6PPAVm^M4AYLVESM6mbNB0a86U^I6Eh
86]^KgM^3G]UN6=X871_L7ekI7D08`000:40`3ooL20b86U^I6Eh3FIYKVAVKfid
Nf9_K6A`LVmSOB1UN6=X3Fe[AU@PL6m`871_L21`Kg0PIGQSJ21`Kg0=OFUVIFac
IB1mI6EV3Bm]Kg]TMG0PI6Q?I6PPAVm^M4AYLVESM6mbNB0a86U^I6Eh86]^KgM^
3G]UN6=X871_L7ekI7E`838PJFiTIGP=IVU^I6I_KWAkKgEdL79_HgdPIGQSJ0e]
JdID871_L21`Kg0PL6m`86EhHfPPL6m`3GeYIVE/LfDPOFAUIPd_KG=kI7E`86AX
DfAX84I_KWA4JG9UHgA_LWTP<B1YKVAUN21[KVmgKPekIGQSJ21`Kg1mNfAeL20b
86U^I6Eh3FIYKVAVKfidNe=XHFA3J65bOB1UN6=X3Fe[AU@P871_L21`Kg0PL6m`
86EhHfPPL6m`3GeYIVE/LfDPOFAUIPd_KgEdL79_Hg]VM34PLfEdIVm^M0eWLf5f
IB1SJ79cM21cIUMYI7AX86MbIG=dKg9U3G=UM6=XHG9gJFAdJ21THVacJ7eTIFH=
;f9_K6A`LVmSNfId<B1cIGAVKfid3FMcHGIU3F=XLW=d87=VEfUTM6PP<B1YKVAU
N20`86iUNfEhHfPP;S0e865TI21UN6=XOFUV3FMbIG=dKg9U3G=UM6=XHG9gJFAd
J0eVM34P;e1QJFidE7U`IB1WIG@P<R1^I@ek<20`86e_MVEdKb1WLf5fIB1VM38P
<21WIG@PLfEdIVm^M21SJ79cM21cJ6mg86MbIG=dKg9U86=XLW=d87=XKgMm3G/`
830PKFmfIGA_86McHGIU86=XLW=d87=XKgLPIg9ULgA_LVDP;S0e830PKFmfIGA_
86=XLW=d87=XKgMmJFIUK7=UOFAUIPd_I69/LfQkHgEbLVE^M6=_K6mb86=eLW9U
KWASKfa_LW=`HF=U834^<21cIGAWLV5i3F=XLW=d830P<21]KgIUM6lPLfQ_Mb1c
IGASKfa_LW=`HF=U87=UM6=_K6mb3FId<R0`86MUM21cIGAVKfid86=XLW=d830P
<21]KgIUM6lPLfQ_MgeTIFH=;e=XHFA3J65bN`eVM34PLfEdIVm^M0eWLf5fI@eS
J79cM21cIUMYI7AX834PJFiTIGPP<21^IG]UN6=X82h`=B1QI6@PIGQSJ7eYIPeW
LVEcM6mbI@ecIGASJ65bMfUTM6P=HfQbLg@P;S0f830PKFmfIGA_87=XKgL=<20^
<3DPM79QKW=/HGAU86ARK7=XOFAUIPd_M7=kLfQ_MgeTIFH=;gAQNbmOK6EdM6Eb
Dg1QHfDPN6AV;emcL65SIEQdLV4PN6AVOFAUIPd_M6Ik;emdIGQdEfUTM6PPN6AV
3BmOKWE]Dg1QHfEc87QTIPd_Gg=dLVU^IdaUKVMdJ21hI6H=I7E`2G=dLVU^IgMY
I7AX871_L0eOK6EdM6EbDg1QHfDPGg=dLVU^IdaUKVMdJ20a87=eHR1]MF`PHFAT
3EmcL65SIEQdLV4PGfieKE=`HF=ULb1]MF`PHFAT3EmdIGQdEfUTM6PPIGQSJ21c
MF8P;gMTJFHPN6AV3EmcL65SIEQdLV4P<20c<PegI6UV85mcM79YKVM<IFiWM6PP
I6Uf3Em/IGAdIG9CL65SIB1QI6@=<20f82da879_K6`PHGMYI7AXLfQ_MgeTIFH=
;g1RNbmOD65WIE=QMVDPLf5fIB1TIFH_LfQ_Mg1QIfEkOFAUIWeTIFH=;g1UNem@
HFMUDf5fIB1bIG=dKg9UOFAUIPd_L6ekGg1]86=eLW9UKWA]HGAbJGPPL6m`OFAU
IPd_Gg1]86eQM79YN21TIFH=;g1cNg=XKgM`HFMU85m`KB1cIGA]HGAbJGQmI6EV
3FaUMVE/<W/_IFHPNfMcHGIU83HPHG9bHGTPHG=dKg9U86=_KV=QM21TMG0PIGQU
HfI_LVdPIg9ULgA_LVEmI6EVO@ek;fEVNfMcHGIU83HPHG9bHGTPHG=dKg9U86=_
KV=QM21^IGM`HGAX86AeL21RIFMYKR1=HGAbJGPPHfm^Hf5d3D92KgPPI7E`86Ae
L20`86MUM21UN6=X834PIfEd86e_MVEdK`eTMG0PI7E`830PIfEd86EhHfPP<b1W
IG@PK6U^IGA_3FAeL21TMG0P<R1WIG@PIGQSJ20c86MUM21/JFiUM6l=I7E`838P
IfEd86EhHfPP<B1WIG@PK6U^IGA_86=/Kg=UL65dJ0eSK6U`86iUMg1QM6PPD65Y
KWA@LVmS86E^I21WLVEcM6mbIGeTIFImJFIUK7=U3BmRHg]cHGIU834a834PLVm/
K20a<21TJF=d869UIfU^82m2@Vmh83DP<B1bKfa/83@PHG9bHGTPHG=dKg9U86AU
IPd_CF5dLVUh83LP<B1bKfa/83HPHG9bHGTPHG=dKg9U86AUIR0_AVmbKEAiL6DP
<B1TIFH_D65YKWA@LVmSNbm`L21WIG@PIGQUHgeTIFImI6EV3BmUHg]`Kg0PLVEc
M6mbIGeTIFH=;g1bJFidMVek<B1fKG9UHfaQJFdPMVecM65dMG<PL6m`86EhHfPP
L6m`82PP820P820P820P820P820P820P820P820P:F=fLb1`LVU^M20XG6hYL79Y
KW@PIVaeLfQmI6EV3BmcIGA_MVEbL79YKW@PMfQULVDPNg1_L7ek;g=UM6mfIG9`
LVU^M7]`Kg1mI6EVOFUVIFacI@d_Lg=dLR1k82lTLg=dLW<PIGQSJ21TIFHP;bAc
LgAb86EhHfPPI6EV82lTLg=dLWTPIGQSJ21TIFHP;bAcLgAbN21UN6=X86AUIR0_
@fmeLVUULR1VJFiTIVm^M20TLg=dLW<P3G=SHFaUIVm^M21cIGAVKfid82AcLgAb
N20TLg=dLWTPKG@PLgA]834P;C4PLf=QK6DP97=cM78PLfQ_Mb1bM6dPOB1TIFH=
;dACBD9UIfU^D65YKWA@LVmSNbm`L21]HG9[Nf=eLW9UKWAVJFaU87A_JfE^86i_
M7]mJFHPI7E`;dACBDE^I51QJFidD79_H`d9IG5kL6m`86=_MFidM6m]HG9[865b
LV5i865cM6mbIB1SMWPPHVU^I20_IGQUHb1/Kf5TGF=fN21TIFHPA5=9AFiTD65Y
KWA@LVmS86EhJGAm3@UkHfmeKWAdKfeQLV/P<c0`86MdNf=_MFidM6m]HG9[865b
LV5i865cM6mbIB1SMWPPHVU^I20_IGQUHb1/Kf5TOFUVOFUVIFacIGe/Kfm`OFAU
IPd_A5=9AFiTD65YKWA@LVmSNf=eLW9UKWATJF=d86E^I7eTIFH=;dACBD9UIfU^
D65YKWACMF9@LVmS87]cHGIU834a834PLVm/K20a<21TJF=d86AeL20_L4@PIGQS
J21TIFHPHVEWJFhP3@T_@T9_N20e834PLVm/K20d865bLV5i865cM6mbIB1TIFHP
;deQM79YN20g834PLVm/K20f865bLV5i865cM6mbIB1TIFHP3@T_AVmbKEAiL6DP
<B1TIFHP;e1QJFidD79_Hb1k82m`L21WIG@PIGQUHb1m86AUIR0_L71m86AUIPd_
A5=9AFiTD65YKWACMF9@LVmS87]RJFiT86AUIR1UKV@PL4Am86AUIPd_JF5Q87/_
JGPPJGPPJGQ^865TI21TIFIm86AUIPd_JF5c<R1k;fUWHG0PIGQSJ21TIFHP;emc
M30PJF4PJGPPJFMQL21QI6@PIfEd86AUIR1OLg@`OB1TIFH=;fUQLb1k;g=d<21Y
HB1YN21WIG@PI6EV86UQHB1cM31m86AUIPd_JCPeLb1k<21YHG<b82m1Dd=9BCPe
A6ESKfAU86IYK7AULR1cM30PLVEQI7=dLVU^Ib1`Kg0PJF5QOB1TIFH=;fUbK6Ec
87/`86UQLc8P;d5C@dU9>3E4IF=_I6DPIVU/M6Eb82mBMFi<IFiWM6Q4IF=_I6DP
IVU/M6Eb87=d<21bIF5TLgAbJFiW871_L21YHF5m86AUIPeYKVUdJF5/JGYU3FE^
I0dU9DE^I59ULfmeLV=U3D=FA6USM21RIFMYKR0`86UT834PIV@=GfE^HfmT@G9b
830=F`dc>BmaMFmdIG=YKVM/IB0i=RmWLV5fI@da<SP_HWE/K6Ed;f9eK6aUM2ma
MFmdIG=YKVM/HV5cIBmVK6mbJFh_LGE_M6ETHVaRHG=U;fE/K6U`LfUc;fAQIfMU
LRmTHFMWIG9THV`_HfUbHgE]IVaUN2m`IG9dJ6meLf5^I2mCHf5bKfh_IgEYK7=Y
KVM/K6EVM2m?ABmRMFa/IG@_HWE/K6Ed;f9eK6aUM0d_HWE/K6Ed;g5eKgAUK6EV
M2maMFmdIG9YIfQd;g5eKgAUI69/K6EVM2maMFmdIFARK79YIfQd;f9eK6aUM2mU
KVAQLfP_IFeTHG=X;gAYK6AU;gAbHFAUKF5bJ`d_Lf=QLVm^3BmWMFU/LfU^Ifab
JFMXM2m_IBmRMFa/IG@_HWE/K6Ed;eUTJFEbIG=YL`d_HWE/K6Ed;fEhHfaQKFA_
Mfh_HfE^M2mcM6EbK6U^IbmSMG9bIFiSNBmiIFh_HW9_JfE^HV5b;g=UHgAYKfh_
I6UULVEcJG<_Hfm`NG9YIfQd;fmbI6IUKFU^JFiU;fMeJFa/IFe_M6aUIW@_K6mW
JF=QK6i_M2mXNG1XIFh_LVEWJG=dIG9UI2m]HF=bKfh=;fAUIg9UIBm`K7EcKFU^
MG<_M7M_LgE`IG9YKg8_M6QbIFEcMG1ULVU_LRmQHgEdIBm]MBm`HG9QIg9QL6P_
L6EbJFmTHfE^M6EbIF@_HfETJFa/HBm_KVEcMG1ULVU_LRm_LVA]HG=SMFaYKVD_
IgEYK6aUKFmdLVUWJ7@_KfiULGEQLWAULRm_KVEXHFaV;gAXLVEULGEQLWAULW<_
LGEULgAYKfiTKgM^3Bm1Ig9QMVD_@F5SMGAU;d5SJG9SMFeVK6Eh;d5dJFaTIBm1
I6UULVEcJG<=;d5bJFiW3Bm1ABm3HfETJFa/HBm5Ig9QMVD_AF5SMGAU;dEWLV5f
IBm5I6UULVEcJG<_BFMbHGIU;dUQHgEdIBm9HfUbHgE]IVaUN2m9I6UULVEcJG<=
;dEdJ2m>M6U/I6D_CfMbHGIU;dmQHgEdIBm?HfUbHgE]IVaUN2m?M6U/I6D_CfAY
IG9ULfUc;feeK7AYL6ai;dmcK65cJ2mEIg9QMVD_EF5SMGAU;eESJG9SMFeVK6Eh
;eETJFEbIG=YLbmIHF=eM6D_E6Q_LVh_IfEbKF5^I69/L`d_HFMbHGIU;f5QHgEd
IBmQHfUbHgE]IVaUN2mQM6U/I6D_HFAYIG9ULfUc3BmQLVU^I`d_HFD_Hf=UI6U/
K64_IFMbHGIU;fEQHgEdIBmUHfUbHgE]IVaUN2mUI6UULVEcJG<=;fUWLV5fI@d_
JF5SMGAU3BmYHfUbHgE]IVaUN0d_JFAYIG9ULfUc3BmUM6P_KWAYK6AU;fmWLV5f
IBm_HF=eM6D_Kf=YLV=eKFI/IGP_KgAYK6AU;fmTJFEbIG=YLbmTJGIYI6D_Kg=/
HG=X;gEWLV5fIBmeHF=eM6D_MF=YLV=eKFI/IGP_MFAYIG9ULfUc;gUQHgEdIBmd
J6mbKRmiI6UULVEcJG<=GB1`MG@=GfE^HfmT@G9b834=F`dc>BmaMFmdIG=YKVM/
IB0i=RmWLV5fI@da<SP_@FAYIG9ULfUc;d5bJFiW;d=SIFAYK6aQ;dEQHgEdIBm>
M6U/I6D_CfAYIG9ULfUc;eETJFEbIG=YLbmQHF=eM6D=;f5WLV5fIBmQHfUbHgE]
IVaUN2mQI6UULVEcJG<_HGAYK6AU;f5bJFiW;f=SIFAYK6aQ;fEQHgEdIBmUIg9Q
MVD=;fESJG9SMFeVK6Eh;fETJFEbIG=YLbmYHF=eM6D_JFMbHGIU;fUSJG9SMFeV
K6Eh;fUTJFEbIG=YLbm^M6U/I6D_Kf5SMGAU3Bm_Ig9QMVD_Kf=YLV=eKFI/IGP_
KfAYIG9ULfUc;fmdJFaTIBmeHF=eM6D_MFMbHGIU;gESJG9SMFeVK6Eh;gETJFEb
IG=YL`d_I65WIfEb;fAUIg9UIBmSIFid;g=dIG9/JFiW;g=UHgAYKfh_HWE/K6Ed
;g1QLV5WLV5`J2mWIG9]HFiTHVac3BmbIFMYLgAULVET;f=_L7UbJFMXM2mdLV5T
IFeQLV/_HF=eM6D_I6UULVEcJG<_KVmdIG5eHF`_@DD_Cg=/HG=X3BmYKVIYKVUd
NBm`K7EcKFU^MG<_K6EcLfEaMF5/;fMbIF5dIG9ULGEQK2miIFh_KGD_L65bM6UQ
K6AYIVH_LgE]KF5dJFm^3Bm`LVmTMF=d;g1Y;fU^M6EWLV5/;fmbI6IUKFU^JFiU
;fmbI6eQLf=eK6U^IBm?KFEWHBmQIBm_LfaQLfP=;g5eIG=dJFm^I6mgKRmUN6=/
HFeTKgM^;fa_IfUSHFa^Kg@_LV5TJF=QK2mVK6mbJFh_HG1`LVmhIG5eHF`_A6E/
M64_IgEYK6aUKFmdK6EVM0d_IgEYK6aUKFmdLVUWJ7@_IFa/JG1cJG<_HVaQKV/_
@FMbHGIU;d5dJFaTIBm?M6U/I6D_CdD_KfD=;fE^I65cJ2mUKFAQLfP_LGE_M6ET
HVa/IFId;g5eKgAUI69/LVUWJ7@_LGE_M6E/IFId;g5eKgAULVUWJ7@_I6UfJFAU
;fa_NVE^IfD=;gUTJFEbIG=YLbmII6UULVEcJG<_IW9QHgAYKfh_HgEbLVE^HgT_
IgEYK7=YKVM/K6EVM2mWMFU/LfU^IfabJFMXM2mVJBmVK0d_I65WIfEbI69/;g1U
LVU_I6=UKWAULVET;g5eKgAULfU^IfaRHG=U;g5eKgAUI69/HV5cIBm`IG9dJ6me
Lf5^I2m1HfUbHgE]IVaUN2m5HfUbHgE]IVaUN2m1HF=eM6D=;dETJFEbIG=YLbm5
Ig9QMVD_BF5SMGAU;dUSJG9SMFeVK6Eh;dUTJFEbIG=YLbm9Ig9QMVD_Cf5SMGAU
;dmSJG9SMFeVK6Eh3BmQL71/IBm?Ig9QMVD_EF5SMGAU;eESJG9SMFeVK6Eh;eEW
LV5fIBmTKgA/IG=cJBmSJG9SMFeVK6Eh;gAYK6AU3Bm]HF=bKfh_HW9UMVD_I6md
HF=SIFid;g9YKVL_HfETJFa/HBmXMFiWHG9eKFaQMG@_KfM_KVE[;f=QLVm^3EdP
L7Ed3FE^I0dU9DE^I51bKfa_Ib0=9BE2IFMYKU=UM7E`80e3ETAYHg@PHVEWJFh=
3BDU@VEWJFiBIG=_MG9SICXPIVm^M217IFiUMV4=<C@PI6USM21RIFMYKPd_AVm^
M4iQKFDP;dMUKVEfHB1TIFH=;dI_KWA=HGAbJGPPFc0^<30a830P<20`;S0`<B0`
831M86AUIPd_AVm^M4U^IVlP<C0PI6USM21TMG0PHVEWJFh=;dIeK6a>HFeU82Q7
IFiUMV4Y86AUIPd_AV5]JFaiCV5]IB0XAfE^IGIQ:B1TIFH=;eE^I6EbK6U^IE1_
LfUdJFm^82da<30PI6EV3BmEKVAULVaYKVEDJ6USJfiULg<P=C0PI6EV3BmCM79Y
JfE_MGA@Kg=YM6U_KR0c<30PI6EV3BmCM79YJfE_MGADJ6USJfiULg<P<SDPI6EV
3BmGIFUWJ7@P:4eUI6UeKBTPI6EV3Bm9M65/JF=1KVM/IB0`86AUIPd_JG=6JGQU
I51YM6=X86IQK7=U86AUIPeUKV@PI6EV3BmOIfaiL6PP:5PP82TPI6EV3BmWN0ek
3@Ta86EhHfQk3@T9I7E`834f82PP82TPHgIbLb1OIfaiL6PPIGQSJ20a86EhHfPP
L7EdJFidIG9fHF`P<B1YKVAUN21UN6=X3@T9GfM/NG1X86=fKR1`MG@=2@UmIVmb
3GeTIFH=;e1QJFidE7U`IB0`86AUIPd_AVm^M5AiL6DP<B1TIFH=;dE^HfmTJFiW
838e=R1QLW9QN@d`834P<SDe87/P<B1YKVAUN21UN6=X82l^KVmdI6EV871eM21m
86I_LPdc<20b=CDPIgP=I6EV3Bm6Kfid@T9_N21K830P<20`830PGB1TIFH=HgEb
LVE^M6AYHg@PIFiT3FAeL20_D79YMV5dIB0h86AYHg@PI7E`869UIfU^3BmBA7]c
M79YKVLPHgEbLVE^M6IYK6DPIGQSJ21bIF5TJ6EhLgAbJFiW871_L7eTIFH=;di4
NfAUIWeTIFH=;di@Ng1eM7eTIFH=;d9/MFEFHFaeIG=K82db=C0P<20b<S0`838b
<31M86AUIPd_CFU^AVEQM7EbIB1k834f834fOB1TIFH=;g1QLg=gKg9T83Dh<cTP
I6EV3BmCMF9bLb0d<b1QLW9QN@e>A0db86U^I6Eh82m3J65bDgAbJFiWLb0b=CHP
I6USM21TMG0PHVEWJFh=;bi^KgATIFHP834`8594838dAD=2A30e<dE3@D@c=C96
=CPa84i43BmH<34P834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_
F30b820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;eP`<b0P<C8P
DT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<3@P834b8594838dAD=2
A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F30e820a<R1BA20b=4E3@T@`=C=5@SU1
<3LeA44d>4=3ADDPCT@=;eP`=R0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3
@dE584i43BmH<3LP834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_
F30h820a<B1BA20b=4E3@T@`=C=5@d54<cDbASDh=SDb84i43BmH<3TP834b8594
838dAD=2A30e<dE2=SE3A3U2<C4d@S11AB1>A0d_F311820a<R1BA20b=4E3@T@`
=C=5@SU1<3LeA44d>4=3ADDPCT@=;eP`@R0P<C8PDT@P<SA5@d94<3DcAD8i@C0g
=DA1=3Q3@dE584i43BmH<4<P834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5
AB1>A0d_F314820a<R1BA20b=4E3@T@`=C=5@SHe@d@i@S4a=48`@DDPCT@=;eP`
AB0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<4HP834b8594
838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F34`820a<R1BA20b=4E3@T@`
=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePa<B0P<C8PDT@P<SA5@d94<3DcAD8i@C0g
=DA1=3Q3@dE584i43BmH<C8P834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5
AB1>A0d_F34c820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePa
=20P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<CDP834b8594
838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F34f820a<R1BA20b=4E3@T@`
=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePa=b0P<C8PDT@P<SA5@d94<3DcAD8i@C0g
=DA1=3Q3@dE584i43BmH<CPP834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5
AB1>A0d_F34i820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePa
@B0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<D8P834b8594
838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F353820a<R1BA20b=4E3@T@`
=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePaA20P<C4PDT@P<SA5@d94<3DcAD=1A3<e
<THe>3He<R1>A0d_F355820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDP
CT@=;ePaAR0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<S0P
834b8594838dAD=2A30e<dE2=SE3A3U2<C4d@S11AB1>A0d_F38a820d<B1BA20b
=4E3@T@`=C=5@SHgAC<c=T51=3La=C4d=4A1=CPcA48b@S54AS=5@D55=T=4<T@g
=d4e>CLh@CLg<CH=@c16=d52>3=3>C0g<d<h<34b<3Th<R1>A0d_F38b820d=B1B
A20b=4E3@T@`=C=5@SU1<3LeA44d>3<bASLd<dHg=ST`@TE4A3<h<CDc@SPc>C<d
AS55=cQ4>D4eA38hAT8=@dDf@CPd<S4e@T=2ACM6>D4d>CM5=c0a>455>35484i4
3BmH<S<P834a>21BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THh@dHh<DHd@STb=SLb
<C8h@T<iACE3@DE2<C=1AC94<3=3A4E6ATD=>38cAD@b=S51=S@i=c96A3DgASHg
=C8c@c13@S4h@S4eAS93=SLh@S8g@c4i<DDf=CDe@CHd@cLeAT<b3DHb@CHf=3U1
=4<fASLg<30hAT4d=c4`>DDcA48c@SE1<D4c<3E4<SI5<4<f<c8e=4DgAD@`=STi
@cLh<@e6@D8`<3Ph@cTf@S12>D8fATE6<D8e<44b=D@a>D93<395AD8b=38a<T95
@THeA3La<STfAS53@B1>A0d_F38d820b=c0PDT@P<SA5@d94<3DcAD8h=cDc@d4d
A3I6=c14@S4cACA5<S0fAD<i@SLa<dDf=D<d<3=3<cU2>C91=c15>CHi3CDa>3Q1
@d<h<c<`@cE5@C95<SU3@S=3<SA2ACPe>DI4>CE5=30aAS0b=CPg<cLf=c4d<cU3
<c0c@d55=0d`<C@f=3E4>3I5=C0b=c<h>D4f<3E6=dHb<d91<S@d>3E2@TI6=44a
=SDh<T<`=C0gAC4d=3A4@D8e<T@==3DcA3I3>3E2<cHg=DA3A4I5<T4`ACDb<4I4
=3Tb<SA5<38gA3De=c0a@DE3@S4`ADE2=D<b@DA1=C<d3C0`<cPf@CDc>CDa@TA2
>C8gAD@b=cPg<T<i<c4d@SHc=cTb=4=5>C@g=DE2=CU1=dDe@cLi=d<e@TDg=0dh
A4<c@C<f=CTf<3Pf<4Hg<dE1<C53@SM5@SHc=dA4>C8f@d<i@T4`>D8g=34aASD`
<c12=cHdATE1A4D==C16=STfA4I1>4@i@SHhACTi@S8g@DDf>4=4AC55@C0i>D8i
ATI6>C=6ASQ6<C<e@S8h@C56>DHa<S553CM4=3<b@c0`@cDh<c56@d<hACPc@c8e
<T<i<S16>3Hg=cPf<48iAT93AD@a<cE3<4Hd=cDh<T=1AT@aAPdiASQ1A4Hh<3Ha
=396ADA1=3Pe=CM3@cA1@SLe=THb<DDf=3@c=4H`<CA6>D54@cE3>C<dA3<`@SDb
<cPPCT@=;ePb=B0P<SLa8594838dAD=2A30e<dE2@T@hA3Q5A491=CA6@D@e>C<c
<311>C=4@DHa=44b<CE6@D4f=dE6=CD`<DHf>316=`e2<c0e<TE1@SLbAS4d<cDb
@cI6>C<a<D96>C12<cQ2>44gAS92A3LfAD@d@C@b<TA4>3Dd>4<f<d<eA3@==D8c
<DHe<D8a<T8b=3A6=3@gA34c@SDi<c<d@cQ6<c<`@c8i=354=CPe@d8hAS<`@SE2
<3<c=c4`A3La3DH`<3Lc=4I5>DE4=4<g=313<4=5<SM4=CM2<T95<SA1A3Lb>DHc
AD=3<38f<3M2A30a=C4h@DI4AT8i=Pe1<CHd>48g=SM3@d=6<4@`=CQ6<T8`<CHd
AD@f<S@e=CDg=d<hAC@f<4=5=3U5@dDd=3Lg=c8eAT@f<DH=<CD`=353ADI4=SDc
<3Q5<THf@d8b@cLg<3Tg@SLgA3Hg=c=4@S8b<DHb@SM3=C91=c52<4I1=T@dAT8g
3CU6=D8c@CLhASHf@d<`ADDdAC8f<cQ3AD8g=T@f=S12ASA2=cI4<T4`=CPa=CLa
>3@c<3Pd@d8i>3HeA@db=d@`<d8dA3E4=DDf@CLhAD8g=4E4=C92<T4d=S56AD=1
@c52=CDb<cM2=SM1A3Q4@CHb=CQ6<30g>48=AT8aA4=6>C@h=S@d@CI6ATDf=CPb
@c4f<S=1@dE5AD52A34i=C92>DHh@CLh>DDiA316=CDe=CPe>CPf3C8d84i43BmH
<SHP83<d>21BA20b=4E3@T@`=C=5@SPc<CDa>C55AS0d=d@a<cM4>DDiAT<`@cPf
@cLeASH`AC91=C0cAS@h<DE2AS0hATD=<SLd=CDc@d4a<D8gAT8f<TDg<DE3>D=6
=4<e=dI5@CA1=48c<D4`<dA3=SDg=CTe=S4b@STiAD<a@C<`3C=5<SDe<451AS0c
=T93@CU4=c=3=S94=30g=D=3@S0a<cHaAS<g>38h=C<e<cT`<C4bACH`>C4h=SM4
A@dgA4=3>4I3@D<`<3A3ATHh>CTc=3M3@S96>3He@CU5=SDd=SHiACM4<CE1>315
ATHbA4A5>CLf>3U5>3H=<C<dAS0e@SPa>4Hc=T4b=4I3=C<h<C0a>3P`@DHe=T8i
A3M3=C0bAC96=S95A3I3<391>DI1>4@c@CLe3D4g@C54<C8e=491AC52<T@eAT8a
@S4dA356=34h<DE2<T@i=TA4<48f=TDgAC4d=S@hAD8g=CHd=CPf<0dc>DE1@S<g
<CHf>CTh@TH`<4<g>D8h=CHh=S91=S0i@dHe=c<i<3<b=C=5A4@d@SE6=D4g=TE3
<THa<34=ADI2<CDeACE2=DA5@C<h=dA3AS0b=CTf<SA4=D=4>CI2<c0e@cM6>C@b
<CDa<30f@c16=D<c<313=4I63C<b@T@eA44c=44c<d<i<DE6<T@b=SE4ACLbAD56
@DHi<TI6<3I2<3D`<SM5=cHf=D55AD=3@T<a>4I3=@diATHd=D8f=d4i<S56A34f
=D95<dI4<cI2@D8`ASM4A3M3A3PfACU6>3Dc<d8b@d8hACLi@C8b@CM3@S0=>C8d
A3M1=492@C8c>CHc=D4e<c4h>4I1@SPf=D4e=CE6<c8d<S0i<DHf@S0i=c95=CLe
@D@c>CE2@CE63CTc>3<i<dI3>3Tc=C14A3@c=d8h@C8c=TH`=3<a>C12>D52>21>
A0d_F38g820c<21BA20b=4E3@T@`=C=5@SHgAC<c=T51=3La=3Hh@TI5>3Q5@dHd
=cU1=SI4=c<`=c4f=3@h@C<a<CA6=cTbACDPCT@=;ePb>20P<C0e8594838dAD=2
A30e<dE2>CM2@DHdAD4f=d96@CE2<T8g=STf=495<c0c>C4i<cA1<dHh>44iATHi
<c@g=3@e<Pdb<S4f>C0g>D4g=D<eASDhAC96@cE6AT91@C14<T4d=3@dASLf<DI4
A4A5<cE6@TI5>C94@cHf=d@f<D8==CA6A3Df=3=2@SLd@DHg<d92=cQ4@S56@S<c
ASI2<CI1@cP`AS@a@C4f>3Hb<34a<4@aAD@c@T4eACQ43CDh>3@a@C@f=38a<3Pg
AD<d@dHi<d4e<c53<4<g=R1>A0d_F38i820a<3@PDT@P<SA5@d94<3DcAD8i=d91
ASA5@CHd>3<c<S<d<4=5@SA6>C<g@S0`<4I6=c<e<CI6<C4dAS0h<4<h@d@g3DA4
<CP`ACQ1<4=2<SDa<3Da<34e>C@d@CE6>C94<3HbASTe@SLg=3PbASA4@DD`@T8i
@D55=455<48h>@da>C<i<d8f@S8b=d92>4<i=48`AS11A314=3Q4=D=3A3U3<4<`
<cP`>C54<D@bACHh@c56>4@eAC4h@c8=>3Lh>DA4@C0gACM3<3<`<T52=4A1<S<e
>3Hb@R1>A0d_F391820g<B1BA20b=4E3@T@`=C=5@SU2>4A6@dHc=SE3AD@i=SQ5
A4De<dA2=3<aAS91>C=3<S4f<CU5=S4e<S12<cPe<D<=A48c@S<d@cTf@SPh<c4c
<TDd@cU4ATE4<C@d<T8g=C8gAC4d>44a@DHc=4@c>C4a@CDcACL`AC0d>3<e3DI3
@S16<C@f@cM4=dH`=CHi>D91=d8PCT@=;ePb@R0P=3TPDT@P<SA5@d94<3DcAD8h
=cDc@d4dA3I6=dE4A44iA4H`@c=6<T@f@cDc>34`@c4a@cHb=SLe<S4b@T<dA30c
3CI3=S8`AC<c<C0f>CA2>D8d<S56>48cASQ4<C4h=d91@S11=T@d84i43BmH<T<P
83L`8594838dAD=2A30e<dE2=SM5<c<f@D4d=S@f@S<h@c<h@C<f<cD`A4=3ATHg
ADHeA3LiA3I6<C4c@D96<3A3>0daA3M3@TA6=d<g<4=2@dI4>38bATI3=CHi@c@a
>4I3=3Pb@SHg<4DfA3Lf=c<g<dE3<C96A496<3Ti@c8==D4i@c<bACM6@cLa=CHa
<SQ2=D<PCT@=;ePbA20P<SHPDT@P<SA5@d94<3DcAD8i<SM5@THg<TA4@SQ1A451
>CQ3<c<b<c<a=3A5=DA4=T@c<cQ6A3I6=R1>A0d_F395820b=b1BA20b=4E3@T@`
=C=5@SHgAC<c=T51=3La=SLa>CLi=d4g@D8cA4A3=D@eACDi<d51=cLb@DA5AT8P
CT@=;ePbAR0P<c0PDT@P<SA5@d94<3DcAD8i>3Hh@d4d>DE5AS=3AC<i<C13=30g
<cPb@DA2@CPb=S56=C8h@CM6ASA1=TA3@SPg84i43BmH<c0P834c=B1BA20b=4E3
@T@`=C=5@SPg=C=3@CA4=THh<4I2<CPh<T@g>3Lb<STh>3Lc@SE5AT<h<C96AT=2
=cDe=c8g@cH=@C8a>4<`=S12<C<i=DE5<3Pg@dE1=34`=DHcA3Ld<CQ1<3Pi=d@b
@S4a=T<f@cPc=3A6=DHf=D55=cL`3DDb@d8`A3=4<SPiATHe@TE3<C8a=STc<SHh
@CTc<DHeACQ6A3PiA4@i=DA1=dA1=DA4<38f@CE3AT8b@@e2A30f@d@g<dDe=dDf
>4Hf<THh=S4i<S0d<CT`@SPh<D<b<S@fAD=6A44i@cA3=C0d@CI2<S53AS@c>34=
>D4f@S4b=cHg@c92<4Dc<C53=C93<THi@CU2<c<h84i43BmH<c4P83<e8594838d
AD=2A30e<dE2>3Le<d=1=4@fASPbASPe>CHd=d<h<C@h<cQ2>4Dd>C8g=C0f<DA4
ATHc=c8f@S@g>@daADDc=cI1A38d84i43BmH<c8P834e>21BA20b=4E3@T@`=C=5
@SPg=C=3@CA4=TE4<CU5>C<f<T@i=CTe<355@CLg=T95<4E1@S4d>34h<TDc<D53
AC0=@D4b<T8f@C96AD8g<44h=4Da@DI2<CA4=T@hAT94>48e>3Da@T@f<D=4AC<h
<3E3=3=4<SE4A30g@S0h3C@`@CPb=D4h>D=1=TDiAD8c<3T`<38`>3A6>454@STd
>3A5ATA2ACLd@TA6A3<a>3Dc@CM6@S<b@S4dAPdb>DDf>C<e@C<b<d@a>C=1=TH`
=DHg=SD`@SDbAT@i>492A3Dc=T8a=T8eAC<g<c@g=3U3<3@f=DDbA3L=AC0c>D=3
>3=5@SPg=TDh>C<g=4<g@SHe=TDg<S0aA48`AS4f<c8f<c0g=CA5@TI1=DI5=SA6
@cPa>3Hd3C52>3M2<c94>3U4=D<i<TDPCT@=;ePc<b0P<S<a8594838dAD=2A30e
<dE2>3Le<d=1=4@fASQ2@SQ5<T@g=48d<38`@C@h=DE2@S93ACI3=c8h<D=5A34b
ADHe<`e4@c8f=dDh=44g>CTi>34b>C14<T4a@C=6AS<`@c4d@cA1>3Tb=C4dA3Tf
A3Pd=c<i=SHc<SL`AD96=d8==c=6<3PdASU2<3A3<c0c=cI1=dI2ASI6=DA5<3I4
AD<i<c@h=DDe>4A2<4@g>3I5A3Q2=3<a<3U3@c163C15=C13<4@f<c54<48aA34`
AD8d=dDf@C@e@CI5A4I5=4HfA495=4Df=S@a>D=4A316@D4`<TA5=c13<0dh>CM4
A3@b=T<g<c8eA44c@cD`@T8i@c@g@CQ3>DDiATE6<4He=C<cAD56>CT`=cTc>CQ6
>3E1=CDeACD==D<g=SE4<cHi@cLg=SQ1=38dAT<f<d8bASE3@T<g<CPg=d55<d<`
<CQ5@ST`A4A3=311>C52<S0i<CDg3CHi>3M3ADI5=SDe=d91A4A1<30d<cLb<d4a
AD4i=48a<S<aACA2=DI5<3Lf<S8f>C=6<3M1<dI3AS<g<0e4@T4i<dDe<cHa>C54
@cHbA3I1@DDg@D<f=cHf<c=2A4Dd<4A6=3Db=c<PCT@=;ePc=20P=S0PDT@P<SA5
@d94<3DcAD8h=cDc@d4dA3I6=cQ6=cM5<4E3ATA6<T94@c4a=STg=T8f<48hASM3
<S=2=SA1AC=13D@h=cHb@d@eA4Hg<D4g<d=3=S<e@CDd<S4`@D@`@C=3>DA3@c8b
<cA3@CHa@DI2<4H`AT4bA44`@T<e=R1>A0d_F3<e820a<c8PDT@P<SA5@d94<3Dc
AD8h=cDc@d4dA3I6>4<f@DA4ACM3>C13@d<f@DE4=TI6<S4cA34hASLc=3E4ACU2
>C8e3CHh>3Hf>C96AC8d=495=38f>3@iATE1@cPf@SM4<T<dAS91<cA1<S8b<SM1
>4H`>C8d<SI4<C4iAS53@@e3<SD`AS<a@CP`@dA1<4H`<DE2@dDg@cQ6@DE5@cTe
=DDeA3Hd>D<i=34g=CTd=3Q6=C4h@d8e@DDf<C4==S<aA3Lg@cLh@D4c>3<d@CHh
>D8`A3Hd>3<cA3A5=c0h=T8f>3I2=T<g@C<a<T=6@c@cA3Dg=SA6@dE53CLc>CQ5
@dI6@T=3>3Th=S4b@D8h@T54<b1>A0d_F3<f820b<cHPDT@P<SA5@d94<3DcAD8h
=cDc@d4dA3I6>44f=c12<D52=c16<D<cA313A3@a>C4hA3Pg@D<g=D91@SP`ASPd
3CH`<30a=DI4>3U3<3<h@CQ2@S<d<34f=dHh<C53<c@e@SI1A44`>CI5@C<i<dDi
<d@d@TDb@c=2>3@f@@e5@THa=316@THdACTd<3<`=d93=S@a@c55@SI1>3PeAS@a
>CI6<C4i@D@c>30e@D@g@T8`>C0a>C@a=DD=@CLi>4A2=T<gA34h<T91=4=6>3A6
=38bASHb@c@e<CPa=C=4ACE6AS52>4Hc=c8f>C52<3Ld@D8b<c@i3C<g=S0g=T=5
ASDb<3Q6@DA2A491<S@h=4<g@TA3=C14=3Hg=SPa@SPd<DHb@CL`ADD`AD@i<cTi
ASA5>@dg<4<b>DHe@DDd>CE4=cDf>3U1<4A5<CM6<cA6=D=2=38e<c8d=cTf=S0c
A4E5@THiA44d=SA3A3I4<T<=>DH`ACLgASHe=dHgA44dAC52@TDi@dHa@dHc<CI6
=CTh<S53AC4gAD=4=C=5A3Pg<T4i=4H`<D<eA3A13CE6<44cA311=T95ASLf<38d
<d@bAC0fA3@`>D@a<3Dg@T94@CU6A4@i=T51@c8hA3=3@cPPCT@=;ePc=b0P>3HP
DT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6>3A1=4Dg=TA5<4=1<D4b=38d<THi=D@e
<C4d=4Hg<3E6<34g<C923D8i@SQ5=4<d<3@eA3E6>CLiACPb>4A6@T4a<cTgAD8f
@CU4ATDc<D4h>CI2=dHh<SHa<C=3@CPcA34a@`e4=3Ti>CTf@dDb=4Ha=cQ2@cDi
<CPi@c<a=3=5=D8`=CQ4@dA3=DA2>D=5ASTf<4<g=C4e84i43BmH<cPP83<`=B1B
A20b=4E3@T@`=C=5@SPg=C=3@CA4=THg=4D`ASPi>494<C0`>30dACTd@DDf<cLb
<SU4<3Hc@T95>CTi=DD=<SHe>4Di<SDd@cI4>D8`>34h=48d@T<`=3Lc@cU4=C13
<3Q3<C=6AC0g<DA2@T@cAT<a<CTf>44d<TD`3C0`<dH`AT96@c54@cLh@dDc<3U6
=DDi<dHi>44iACDeAS8c=D52<SA4@dHd=S<bACHb>D53>3E3ADDc<0de@S<c=T@i
@T<i<c14=c8c<dA2=CA6<453=S<a@SLi<4Dc@DI1AT8cAT<d<4=5AS0a=38d<d@i
AD4aA4D=<DDd<C0c<SPg<CI6>D53=D<g<SPe>392>CTd=cPi@d4b=S4g=C55>DDa
ASP`AS=3<351ACQ2=T8g=cHf3D93=c<c=d<fAT<h@S4`<T<i@S@e<cDeA493=dH`
<cLhASI1=c8a>C<g@c96<D=4@T4g=S8e=3Df=SDiAPdb>4<c<T<g<S51@CPe@dHe
=DHi@DDh@T=3=34f<DI1=3Pf<34a@cHcAC0d=CThAC8h@dHc>3@b<C0a=dD==d<`
=cU1A44a=S12ADHc@cPf<TDcA353<4HaA3<h>3A4@cHf<CI5@S0`>3Q3@S8d=TDa
=T<a=CQ5=48i3DE5<CE1A3DeAC@h<cTe=SPc<4Hb>C@gADA3ATI2>CM6<3Th>4He
<3DcA4Dh@TE4@C<`=c12@T4h<T<fA@da<4A4AT=5<DA5<SPc=3E1>D@a=d@d>C4h
=C91AD8cA4HfA3<e<4I5=TE4>44gA3@d=c55ACDdAS0g<CT==3Hg=3U3@D8e=21>
A0d_F3<i820b<cHPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=cHd=4@b@D8d@T8h
>CLg@TDbA3I3>4HhAC0e=44i@d<i<d<f>C543CTg@S0f<CHg=D4f>354=D@`A34e
ACLa=cU3@SPh=CM3ADI2=3M3=S95ADDe>CHc>D8d>CLc<dA3>453<0df=d8g>3Tg
<cDi@dHi=3Hc<cU4>DE6@CDhASLd<3M1=4Hd@SLb=SA1<cHfAT=3@cLi@d@d>DA2
=CPh<d<==D<e<T@c>C0d=3<`AS0eAC<g<4=3=C@a=dI3@DDc@D8h<4<a=c4b<CPg
=3Pa@D4d=S4c=SPb>C15A3Hd3C4b@dA1A30h<3Hc>44iA3<d@cE1<DHbA3H`=cPi
<C0c=T=5=SPeAC=6=4I2=S96ADA5=48`ATI6A3DhAPda=T8dASLhA312=C8c@S92
<C8e<3@b@CTiACHgA3Hg=TDiA3LhA30a=c<b<CTgA44i@dE4=C4bASHa>4H=A3Lc
<393<4=4AT4c>DDc@SM3>393<311>38c=SHi=T@i=dA4A48`<3PcA30b>34b<4@e
<c8c=S@g<THh3CQ3<DE6@SU2<c<cATE2<D<g=SLi<S94=4Hg=S8c=CLf<SDb<DI6
<SQ1<CDe<D51@d=4@c@PCT@=;ePc@B0P=3<PDT@P<SA5@d94<3DcAD8f=dDc<cI1
@C@g<CHg<CTg>CM1=d52<dA4@cE4=DDe>C=1@CLg<T54AC14<CDd<d<`3DHa@c91
<4@hACDd=d8e>4Hc<C0`<4=5A3Lg84i43BmH<d8P83Ph8594838dAD=2A30e<dE2
=SM5<c<f@D4d=S@f@S<h@c<h@C<f<cD`A4=3ATHgADHeA3LiA3I6<C4c@D96<3A3
>0daA3M3@TA6=d<g<4=2@dI4>38bATI3=CHi@c@a>4I3=3Pb@SHg<4DfA3Lf=c<g
<dE3<C96A496<3Ti@c8==D4i@c<bACM6@cLa=CHa<SQ2@CDe@THg=3U4AC4b=C4i
=S@d@S4h=DHg=C4iAT94=TA5=3Hc=44PCT@=;ePc@b0P=34PDT@P<SA5@d94<3Dc
AD8h=cDc@d4dA3I6=dE4A3E6@T8i<C4a=c4a<CTf<3D`<d8h>C56=CI1A4@g=DHa
<ST`3C<`<D91=STfA3DgADHa<38bACU3=DHPCT@=;ePcA20P=34PDT@P<SA5@d94
<3DcAD8h=cDc@d4dA3I6=dE4A3De<4A6>CTaASLg<cI4>CHb>3<eAD4i=C8b<3H`
=S0`<4@f3C0h<cM2@CU1@S<h>391>CI3@SDa<D4PCT@=;ePcAB0P<cPPDT@P<SA5
@d94<3DcAD8h=cDc@d4dA3I3=cM4<3Pa=S0e<TDdASP`<SU3=C@g<3U6@d=1=d8i
<3A4@dDc=D@e3D<aASLbAS8i@CTb<T@a<CHPCT@=;ePcAR0P<CLc8594838dAD=2
A30e<dE2>DDd=30a<SDg>DA3ACU6=TDfADA5=cQ1=CI5<DHc<c93=3I1<TA6@S0d
A4A6=cI1@@daA396@dA2@c4d=c0b>CE6>C8h<3La<D56A30g@D55<44d@TE5=TDa
>C<i=S8i@CTd=DE1@S55AC<g=CT=<D51=c4a<c@g>3Le@dHe<TE4<4He@C0gAD95
@SE5A4<g<D8e=D96=CPaA4Ha=4A6=DHd<d8`>391<S8g3DHd@d4f@c4f=d=3>CDg
A4DbAS0f<C0fASTb<T<d@T8c>44g@SE3=CM5=S0`=cDdACQ4<44d=c@a@d96>@da
=314ATHeAC92<SHfAD94=T@hA3<c@D53AD<b@SLiACM1AC=1=DA4<356ASTfA48i
=38c>D4c@d94=ST=@c<d<C8`A44`=3Q5>DA5AC8i@SLhA44`<dA4<T@i<dHi=T@d
@d8h=3A6=TD`<21>A0d_F3@`820c=3TPDT@P<SA5@d94<3DcAD8h@C51<D4a@STe
AS52<3D`>CPf@dA1<34`AD<g=3@e<cU1>4I2=3=6<cU1>354@D913C8dATI4@c@`
AT4fA3Pf<cPf=3A6<TE4<c8f>4HgAD4c<SE5A3<`=S=2>D8fAC@`<3Di@S=5<493
>4<d>@df=T4i>3=4>DA4ACQ1<C8h<C<e<cU1<48i@S0e@TDh=c95<cA5ASHhA3Q5
<c8bATHc=DDb@SPa@C0g@TH=AS<d<CA4=T52=T<g=dDh@C8a>3Td@CM4=d@d<CE2
@cHe@S@`<4Df<SU5=3TgAS95=38fA4DeASM4>3A53CQ6ACDc>4I1<4<a=C@eAT4e
<C0b=3LbAT54@TI5>3Lf@SPg=SDf>4I6<30h=3=2=C0i=C<b@STgASU4A0e4AC8c
<cI5=TI3>CM3<T@e@CL`@c<f<c8a>D@d<3<g=D4a>DA5@CTd=CLeAD8b=S@c@DA2
<3=2=DA1=S0=<T8hAT@c<S=6<4E2@c0i@T51<c@g=DA3@c<h<3Pf>3<g@CM5ACE3
=48h@SA6<d91>D8cAS<i>4@b@D8i3CU1=T8f<CU1ADE5@C8g<SM3=d51=dE2@d93
AS53ACM3>D<b<3M5A4=6=c0h=cU4=D=6>D54=C0`>3E6=0e6@c<gAT52=3M3<SPh
@THh@DDaADDi<cM4=44g<4<f<30f=dA5@d8gAD8f@C4`A4Hd>3Di<T=1<T<d<3L=
AS8f<dA1<CU2=C0f=S0f@C11=d4b>4Hd<TA4<TE6@CE3<4E2A3<cA3<`>C11@cA5
=493>48f=dE2A44h3D93<S0c@SQ6@CLf@CLe<SI6<cE5<3Q6=C@b=48i=cU1<cLa
<dE6>C55AD8i<SM2<CTb=4Di@D54=4E5@Pe2A3@e<44bACPf=4Dc>3A3>3@d<cDg
ASDcAT@e=SM5=3Lh<D4`@b1>A0d_F3@a820f<21BA20b=4E3@T@`=C=5@SPc<CDa
>C55AS0i<C<e=DDf<c4iA3=6>C4a<3Df<D=5=44b@THh=THg=d@g<D8a@C<=002Q
0<0oocTcASE5<CA5A3I3=d<c@cM3<S8i@C<gATA5<c@g>48c@d8b@c4`=dI6<cLb
@CE3=3<f<cPb<C8`<cHf=B1>A0d_F3@b820a>C4PDT@P<SA5@d94<3DcAD8h=44h
>30c>3@g@DHf@C4a=SHf<4Hg@C@h=SDgAD8h<T8b<3Da@DDe<CHgA44bAT4b3C=3
ATA1>4A5=SDa>D8f@c51>CPi=C4a@cDgAD=1<SI6=cTd=dI2=d<b=dE2ASDg=cQ6
>C8b@cD`ACDh<Pe3>4@h<CLh>3Hh@C4b<44c>DHa>3=2=S8a@cPf=3A6@SI5>D4a
@C0h=STaAD4i<C93=C<iAS<eA3Th@ST=<3E2=SH`@CI2@C<d<c@g=44i>CM2@STg
@d=2ACLg<dHc>CPh>38f=D54ACPaAD@i=3Lg=S0f=T4e<C8`3C54<4Hb<SI6=S<h
A44e=d@h@cQ6A3Da=CTf@cI5ACM2<c=4=44g<D@a@D<dAD<b=S4cADD`>CQ6ASA4
>@di<4E1>D=3@D=3<S8gACE3<S0i=30i>DDc@S54>CLg@c4`@S@d@D<g<c96@DHg
AS8e<cM6<T96A4<c@d@=<S<b=CTf>CTd=CPd@CQ6@dI1<C<c=B1>A0d_F3@c820a
=S@PDT@P<SA5@d94<3DcAD8h=3Dg<44b<3U6=TE2=dDh=C0g>CA4@TA2>3=2@S<b
<DE4AT@h>4<d=DHa<3=5@DE43C94@C8`@S<e=CPb<3Hf>CQ1=CM3=D8c<4E4>48c
@cI1=cU2<491<c<f=4<f<dHa<cPc=DDf<CQ5<S4h<Pdg<4HeA3U2<c15ASLdADI4
=c<e@T@b@dI2=SPc=C91=DA4=SPbA30`@DI1>CA6ADDd@C4h=DHdACU2@c8=@CE6
<DA6<CTa@c0a@c54=CI3A4HgAT@h@CLb=3M5@C0c<c=6>4E1=3@e<d4h=4Hc<4Df
=CDg>44b>3I63CI4<cDi>3E6>3Pc=44i@SQ6@T95<SU5>CPd<c4e>48i@c96<d55
<D8`<cPfAD8g>3M4@SQ4>3U4@SM4<Pe5A3Lc>D@`@THh@c0i<CPb>4DcA4I6@C<a
<THf84i43BmH=3@P834b<21BA20b=4E3@T@`=C=5@SP`@T8e=D56@SPd=CTd=DA4
=CLi@T8a<cA3<C96<34bAC0aASLf<DI1@CLi=S8dAT4==D56=3Q1>355AD<b>4Db
<356<c51ADHg@S@g=dE2AD<i=c=3<c@bA3Hf=SPbAS0hACDc<THi=D=4@SU23D8e
=dDg<D=4>3Li>D8h=D@c@S4f<CTgACE4ATI1<38bAS<d<D52<C<i>3Pa@cU3<S=3
<THhAT4gA4A6<Pda@TDhACH`=DDc>DDf@SHb=SLa=c0d=d8h=d8e=3<f=cLg<D@e
A4I5<DE5<DA1<CHf>4@c>3Pb@DA5AT8PCT@=;ePd=B0P=3LPDT@P<SA5@d94<3Dc
AD8iAT=1@C0g<CDdASU2@S0`A3U5<D8d@c13A394=S0a=4A6=3=4>C=3<4Hc<D=6
=38b3DA2@S0h<S4b<d4g<30h>3M5ATE5<DHf=4E6=C92@CU4<48PCT@=;ePd=R0P
=34PDT@P<SA5@d94<3DcAD8i>CDi=38e>C@a=T<d@CL`ATHd=4Dd@C8b@CE5AS<`
A44g@SI1A4A2=S8i<d8c=C143C<f<4He<3Q3ADA5<cLf<STaA3@`@SDPCT@=;ePd
=b0P<CHb8594838dAD=2A30e<dE2>3I3AC8a=c51@CTc@CDg=C54<CHi<SLf>48e
=d92<S16<c0b@S0f>4E4>CLa>C0i=@dcA34a=C96>4HbA3T`>CHa=cPdAD91<SHf
=T4f<S95=C@cA3Da=dE1=cLa=TA2<d<f<STf<CHc@c<d=D4=>D@f>48b=TA1A3Q2
=c13>3A4=3H`>4A2=DI2ACE2=3E5@d<`>34h=3Tf<34c=c0h=D4d=S96<4Hh=3U3
3C=1@d54=S8g@D4a<48dAD8d>3<e=3Td>DHiAD4cA3Hb<3Lb>496<d<a=cU4=c@b
>3<e<cLh<48g<c@`<0di@cLhA3Pf>D8e@cQ6<c=5=d4i<dHh<CTdAT@`>C@g<S<a
<38h>CPb=SLfAS@f@D@h>4@d=DA6ASHc>D8=>CPgA30b@STf>CThAT94>C0`>D93
=SI484i43BmH=3PP83@g8594838dAD=2A30e<dE2>356A3@f@S0e=cE4>3@g=d@c
=d@c=D@c>4@`=C@a@SDiATD`=c4bAS8bAD@f<CU2@@d`<S91<c4g=c@c=34d<D8i
<C11=3Ld@dHg@SDfA3Lf<dDd84i43BmH=3TP838e8594838dAD=2A30e<dE2=S=2
<cDiADDd=30c<48i>44g<C16<C0g@T<f>44c=TDb<4E1=CTb84i43BmH=44P834`
=b1BA20b=4E3@T@`=C=5@SU1>4Df@cQ6ADHa=SLc@S93<3E5=C<c>D8c=4A3<T8a
=c<d=C=4AD4g<3LbACQ1ACT=<dE3=314@DE6<THd<d4d=d<i<S12>3Lh>4Hf<cL`
<494<cU4=S<g=cM2>CHc>30`=cHe=3Lc=C@b@cA23CQ1=38d@cM5<d53<3A4<cLh
AS52<T=6AC@c>3M2A4Di<3M5>DI5AS8e=D96=3LgACE5<S91@cU2>C<c<0dd@D93
<453<3U4=34bA3I5=c8cA4Hg@cM5<CQ3<3Q4<S5484i43BmH=48P83Dd8594838d
AD=2A30e<dE2>3LaASDg>D4a@S8c@D8e@D4b=C56>44h=cU2>395=TDb=c4b=D8`
>CDd=4I6@D@c>@ddASM3@D54<C14@S0h=S8i@d8c=3Td@CQ2ATDg<34a>30d@THa
<d8dA452A48b@S<PCT@=;ePd@b0P<c0PDT@P<SA5@d94<3DcAD8iAS<f>3I4=3Lh
=SHe=CHf=cA4>DDa=3M6@c4aA3He>313=SU4=DH`=T4gAC11>34d84i43BmH=4@P
83Lg8594838dAD=2A30e<dE2>4HbAS4`@c4f=c56@CLb@DDb@SA4>D8g@c<i<DDc
>3LcA3Q1<S0f@D@h=c@a=d4fAPd`<D93=TI4AT4d=c=3<CI1@DHc>3Li=4@g=48f
=C=5@dE3<dHd@DA5<S0f=SE5@cM1=cM5<C8h<d8g=D<=<DE6<d<f=CE2ACLc<SPf
<3Ha<d91=cU2<30`>C4c>C4i<21>A0d_F3A5820e=b1BA20b=4E3@T@`=C=5@SP`
<SM2<CDc@C8h@S51@d91<DDdAT8d<dI1=c54>CDg<4<h@d93AC=5<TDf>38`>4D=
<SHe<C52AD@c=D<dAT@`A3Lh@S8`ACQ1<d8d<dHe=T8c=dDf<3Pa=cHd<S<d<3E4
=4@g>48e84i43BmH=4HP834c=B1BA20b=4E3@T@`=C=5@SPb>DDd=3A2<3DiASTe
@C54=356AD<`=DE1<S91@C4iA3<d@SE1<48c@cM5<S0`<C8=A38a@cLa@CPi@T96
<STb=cPh@c<h<SLgASLb@CA6<DE6>4He<30a=DHg=C4`<DE6<THi@CPhA4@`<D@i
3DE1@CTaAD4b@TE2=c16<SQ1=S94=4Dh<C4a<cPa@d4g>CM3=S0f>4@g>48`=c=1
>CI1=3E5@C@e=c4c@Pe4=48d<3A2@T=3AD52<SHd=3Td=CI5<c<b>D<f<CPb@TE5
=3I5<d8g<dHd<dD`>D8`=C<a@DE5=3=1A3L==DDg<c0d>4I1<S52<THb=c8`@C4b
>3Td=SPf<cHc84i43BmH=C0P834`<b1BA20b=4E3@T@`=C=5@SU6<cHh=T@d=d4b
<cT`AD@`ASPe@d@f=cHhAS0d<S93ADE4A3Q2<D=1>DHe@d@e<C<=<34f@S@h@CU5
=CI3>DDh=d=1AC16A44c=TE1A48i>4HgAC<`>CPe>CM2=c@c>34b<SLaA3@e>4<a
=THh3C4i@CA4ACDf=S@e<SDdAC0`=C0e=SE5=SLa<c12=SHd<SD`=d4i@C0e@STd
<c8h@cTh>CLc>CI6A3@aAPdd@dI5=3E2<D<i=cLe@c8g@c<g<CDh<C11@R1>A0d_
F3Da820a>C4PDT@P<SA5@d94<3DcAD8h<SU5=3@d@S0e>DI5=3@e@SI4<48`=cLc
AD4h=S=3=SA4>3Dg>3=5A396=c8f<S0e3CTc=C51=dE1<cDg<CTcAS0e@S92<DDc
A3Q1@SLb@T@e<4@c@cTeA3Hc=c92>38b=SE1>CA1<c<dA3<bA0e3>CPi@SE3@c0g
<T4g>3M3<CTiA48i>3Hg<S@d<cTb>3@i=C@b=cU3=CH`A393@C4eAD=5@CE6A3Tg
=c<=>4@h>4A2<SHc<c<g<3Q1>3@`AS8d<4A4=TA5ATE3@c0bACU1=CTh<D53=3@b
<D52AT@d@DA4<SQ6=3=23D8d<4=5>D=5<dI1=C=5>C94<48g<C<e@C<`@d<d>C92
AS8c=4A6@DE1AT8`=c8a=S0fA4A1<cU5>3<bAPdc=CQ4ADE5ASHfA3D`<d=2=c93
=D@h<TI3<CPcA4<c=CQ4>3Ti=T@`<C@c<cPi>CQ6A3M6=DI1=S91AT@=@c91@d4f
@D51@cHiAS8c=S8c@SLg=R1>A0d_F3Db820a=S<PDT@P<SA5@d94<3DcAD8iA44c
<38a=38c<SI4<dA3A44i@DDc=CDdAS4`=S54<3I2>38`<DI1<c0f=3E3AS<h3C0e
AT94A3LgAD4aA396@cI4>D56AD8e@DHd@TDc@d@h=S0`AT4g<D96@cA6<496<S55
@c8cASDa>D<a<@e4A4I3@cTc>4=5=S4b=c<f<C4g=T=1@CU3>D8e<SU1A48f@CA2
@cLa=STd<D<a>3Lc<30c<d51>493=S0=>44b>C8fA48h>CTi=CU5<TI1ACU4@DHh
<C0g@SQ1<S4cA3Hb@D@h=T96<D51@C92=D95@S0d=48f>30c3C<b=d=6<CDb<c12
<S<f=T4h@S51ASM1<34c<4I1<CPg<c4i@TE3A30g<SHb@C93<SDf<S4c=dE1AT4i
A@e3AS0c<T@e>34`=cU2A44`=C96=DE3<S=4AB1>A0d_F3Dc820b<cLPDT@P<SA5
@d94<3DcAD8iA44c<38a=38`=DI4<D53ADA6=c14@CA3ACHe>3@h@S<i=T<c=SU3
AC0e>C@a@d8d3D=3@C4eAT@c=316=SQ6>4I6>4E6<ST`<C0gAC0b>CE2@cQ1@D4c
=T53@THh=T<i=SHg@SPi=S<`<CDd@@db<DHb=THi<T<`>4DaACPi<cLf<S96=C<d
@C12<TE4=cE1<3M5>C12<3Lg>48aA3He=DA2=S0g@cHa@c8=ACA2>CE2<d93<cHa
@C13<c8cAD<b<S4a@CA4=S<d=S95@dE6@d@b<c@cASM2<34c@SP`@CU2A3@g<3Pd
3C8b<c@h@c4a@c4f>C@eA3L`=d<`@S14A3Te<DDd<SLb<DDe=D4i=S4h<3@h<4Di
=3Le@SU1>3Hc>D=4>0e3A4@g<DI3<cHg<TDh<394>CE3>4=6ACD`@T@`>391<c92
@DDg<C=2ACU5@S56=D8h@dHb=3Q1>C<f@T8=>4<h>48h=DE1=SA1@C<g=3I1<c<h
A3Hh@DI6<C@a=dI1<SPc@c0a=4E6@TI4<493<SQ5ASLd>494<4H`3D52<SDc<C8i
<SU4AD56A3U2@T8e@cPb<48g@cT`>CH`@CDd=cHe=SM5@CLfA44h@TE5=d8eAR1>
A0d_F3Dd820c=R1BA20b=4E3@T@`=C=5@SPdAD8b=3@e<T4`<38c<CPe>3D`<C<i
<d8e<3L`<TI4<c<c=cLb>3Lf@CM5>C4i=3H=ASTh=351@c@b@CDe84i43BmH=CDP
834a=R1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=T<g>C8e<c8c=DE6=3<g<T@b<C11
<DDcAC0h=SI4>4=2A3Tb<3D`ASP=<TH`@S55=TA1<3Le=TE3>4H`<T4`>38i=3Ph
@D@a=4I2=d4fAT4i=c@d=d<e@S4a@d56=352<3Ld=S4d3D92=4I5<D91ATHh=SDc
@D@d>30e@TD`@C8f@c55@C12AT<`A34h=44iA4I5@cPeA4@g>D@gAD@b<30e=Pdi
@S8e@d4bA3E4<SM3@DA6=S4g=S15<cU4<DDd<D=3A44i=cTa>44e@SE1AC@g>CDe
@THc84i43BmH=CHP83@c8594838dAD=2A30e<dE2>3<a=C4i<DE6<3E3@T4c=3A3
<T@i=c0d<T4`<cTc@c8b>CLd<CP`@CT`>3Le@CLa>0dh<CDh<C4iA3E2A30h<T8e
A4@gAT4h=d4fAB1>A0d_F3Dg820h>B1BA20b=4E3@T@`=C=5@T8h<SLaAS8c>C4g
<3@`=4Dg@STf>491AT=3A3M6ACTd@C16<C8g<DDh=30`<3Le@d8=A3@i@S0d>CA2
=S95=SE3=CA5<3<bAC51=456<4=2@S14@DI5AS0a=T93AC<h<CM4<STh@SDc>30i
<d<a3D56>C8e@c<a>C96<3Pg@C0b@TH`ACHe<cLf>D8g@SLb<SU6@d<cA4D`@C8f
@SPb@d91<d8d>3<i@c8PCT@=;ePe>20P=S@PDT@P<SA5@d94<3DcAD8iA4Dg@S0f
@CPg=T4e<d=2=CTe<CE2A4HdAC8h@d@i=T8iAC52=dDh=SHd<T53@dDg3D@f@S14
@c8i@STa<STd=cDg<D<b@cI2=d52=D8i=3A4ACHa=38h@c=6=d8d<cU1<c55=THg
<CTe@d51A@d`@TDa<CPi<b1>A0d_F3Di820d>21BA20b=4E3@T@`=C=5@SU4ACM2
<3I1>3Lf=CE2AC13@T8d<CLi<CA4<C0iA4E4ACPi=T91<4I5@T=3@c=2=C@=>3Tc
@THa<d8`>4Hf>3H`@SPh=3Ta@T8h=d53=44fA3E6A3Db84i43BmH=D4P83@f8594
838dAD=2A30e<dE2>DI3@D4`=c4e=SA4@C8f<THa=34`AT=6ACPd<T51AD<c=d@i
<4Hb=4<c>34f@S92=`e1=dA2<352>C@i=CLh>3Q4<CPc>C14=3<d<4E5ADA3@B1>
A0d_F3E2820c>21BA20b=4E3@T@`=C=5@STg@T56=4E1=SLd@TI6=c=4@SPa<d53
@cTh<cQ3<3Da=cDa@DHg@DDaACLc@T=1<c8=<D=6=DA3>453ACPg<D<c>B1>A0d_
F3E3820c<B1BA20b=4E3@T@`=C=5@STh=SQ3@C@iADE6<d<fACQ4=cU6@C4f@cPc
>CLg>C<c=4A4@TE1=DHb<STe=d92AC<==S4PCT@=;ePeA20P<cPPDT@P<SA5@d94
<3DcAD8i=d91ASA5@CHf<C0h@T4`<3I5=c<d<dDc<D@i>4Df<D@c=D@h>3<`=D4f
>3A6<CE43C0c=S=1<30d=D=6=CLd>DHPCT@=;ePeAB0P=34PDT@P<SA5@d94<3Dc
AD8h=cDc@d4dA3I6=dE4A44cACE6AT=5>316<SU2<4E5@d8g@d4a=TI2ASU5<CE1
<38h3D<f=44g@C<h<4Hf<44b=S8b=d4f@CHPCT@=;ePeAR0P<SDPDT@P<SA5@d94
<3DcAD8h=cDc@d4dA3I1=TH`@CPd>48c<cI6<cHiA351<c0h=3U4=STb<cPPCT@=
;ePf<20P<c4PDT@P<SA5@d94<3DcAD8i@d8b>CLb@d8`=SHi>4E6@C8e<4I1=S0c
<3<g=TI5ADHh<cTeA4E1AS@c@cHi<cTb3CLg84i43BmH=S4P838c<B1BA20b=4E3
@T@`=C=5@STi=CTd<SDi=3=4=STi<SLb=4@i>D8d=D=3>D@a@S<g>CL`>3<d<3<a
=30cAD8eACH==c<h<S55AS16>4E2ASE1<dHe>CU2<STeAC4h@cTh<S0i>DA2<S8g
>4=2<4=6>48h<T4f<3DeACI3>4D`3C8`=d4b<S52@CPdA3Th@dHeA395<3@hASPi
<4E1A44h<T8c=C52=c4`=cLg@C=1@S@f@S<`ASLg<d<c@@de@C96=S8e<CI1=cHa
<d<h>44g@cU2=T<`A44b<TA3<CM6@dDb<30dA3Q2>C8a>48e<STh>496<SDaACP=
=3@f=4Di@SM3=C4aA3@`AS15<4<d<C4d<SPc<SLe<T96@cPi>3PiA394<cHhAS8e
<3=4<c4b=TI6>3U63CTi<491>CA6=352=4<c>3M2<CPaACDh>CHe<38i=d=1@d@b
=3@`ADHh>C@iA3I6=495>CA5AS0b<TI6=@dd@CHbA3I5<c@g@d@c@SD`ATHd<c92
AC@i@TDd>3=3AS4e>454=DI3ASHc<T4g<dI4<cQ2AT=1<4=3AT@=@S<aA48e<CLb
<D94@CPiACLfAD<g=D53@c8d@dHb=CM3@STgASI1AD8f84i43BmH=S8P838`<B1B
A20b=4E3@T@`=C=5@SU4ACM2<3I1>3Lf>4A3=SI6@D55=3Lc@CE1=c=2@SE4A3Dh
>CPh<c56@C93<C8h<cD=@S4gAT55<cPa<496<30b=3@b=SDe@C@dATDd@S56<D8`
<S<fACPcA3Pb<3@b@D<dASM2<D8f=DA1<T@c3CTf<3M1<C@d@CI6<SDa@dH`=DDe
<454<d=5<c@gA316>C0`@cM2<S8h@c54=S8`ATHf=SQ3@T54=D4`A0db<C@b<34`
>C<`>3U5=311A34`=TA6>D53=3Tg>4Hg<cPb<S=3ASM4<SHi=C<e>D92@THb@C@`
<D@cACD=@CDb@dHg>CDb=SM3=30gAD95<SE2AC8e=T4i<T<a<4<i<D<c=SLfACQ6
<3La@cTd<cD`>38c>DHf@cI33DA6@ST`@SDb>C<hA3DcASE6>DE1=C=1@SE3@CQ4
<cE2@CI2=4@fAS4e<44dA3T`ASA4<D8f@C8i@c@c=Pdg<3E2@CThATHiA30bA3D`
<d@f@C<b@c51@c8fAT@`=cM5@CHa=SHc<4HPCT@=;ePf<b0P<CDe8594838dAD=2
A30e<dE2>CU4<311<C<f=D=6=3M4=SI5<cU4@S4g>C4i@dE3=CT`AD4h=CDi<44c
=C8g=D8i>0dd>3De<SE1@d8c@S@d=S0a=S96<3Df<c0i@D=2@d95A3DhA3DgATA5
<SH`>3L`ADE5@cHcAT=3<DE2=DD==SLb@TE4<cH`A44dA3E4=3L`=C8g=D@`<44a
>DI6@cThACM6@c93=cDi<CQ6=dA2AD93=3=6AS@cACPa3CLg<3Df=3@e<4@g=DA5
AD8e>D4h@D53>CTh>D<aACU5<d54=44h<CPd=T51>D4b<DDi=4A2AT4c=SHdAPdh
<dDa<D8`AT=5<cLe@T<h=d@f<c0hADDg>3LcASU2=c@i<D=6=DA3>CTb>492<44c
@cTa<c<d<dI5AC@=<CLhAD4f>3<f=b1>A0d_F3Hd820a=c<PDT@P<SA5@d94<3Dc
AD8i@cHa<C4aAD52=c@g=dI4ATI1=3Pc=c4aA3E3@CM2<CPf=3He<D@d<SPc@CPe
<d4a3DE3<c8c=S95>DDa=DHi<c15@SPf@CPh=S4i<DDg>D<`<DI4=48b>DHb>C=4
ASQ6AS0d@C4fA48dATE1>0dd@S12>DA1>44e@T=4@C4b<C@b@SDg<CHf@C<i>C=5
>C=5=T54=353>CHe<30e<44g<SDa<d@`>CM1A4D==dDc<D8b@THh@SPiAD53=CTi
>D4d<D@c<SE4>DA3=C@b@cDb=SDdASI5<cTaA3D`@TA5=D8b>DHb<44h3CDdAT@`
@C=5>DHb<4D`ACTd=3TgA3Th<d8b<393=CU4=SPa@c<f=D52>3I3<C<iA3@e<SI4
>4I4@DDh<Pda=cI6=TDh@C0`<451<SHi@T4c@S51>DE5@c0e<DHe=c@cA3L`<34`
=3<iA3Pf84i43BmH=SDP834g<R1BA20b=4E3@T@`=C=5@SU6@d51<3La=CHd<d=1
AD8h<cTh=3@e=3HdA3Pd=48a@C95AC@e=DA6=T@cAC8d=c<=<cDb=STc@S8e<38f
>D@f=cDb>DDd<d<`<34b=D@iAC@c@SHd@dE6A3<e<dE5>392<TDa>3Pf=CLhASM3
3D@g<d<cACDe=TI1=4=5<SHe<355<T<`=CTd=3E1AS14<DA5ACM1>CD`<CQ6AD<h
A4Hg@c=2AC0e=dHg<0dd@dI4=4<`=30c=CPe@STe>38`@dDcADHi<3<i<T4`>CU6
AT8fADA1>CQ6=d@fAC4`A392=3Dd<314>34=>3I2<DDh>3Te=cHa<THa>3Ld<CLc
@C14>4Di<c4h=48c@SI3A3Da>DE1ADI3=cLd<cA5ACDi=D@f<dI33CLi<D55>44i
@c<d<TA5@S<i<cT`<353>CU6@SLd@DA3=SHg=dHd>D51A3U384i43BmH=SHP83Pe
8594838dAD=2A30e<dE2>C<b@cPfA3HbACDfACM6<4Hf=3M1A4<`@CPe<SA5A3M3
AC=6<D4g<S=5=30i=48e<Pe3ASLb=DI2<cU1@T8`=DDiAS4cAD=5=c<a@SHb<D<h
A4=5=3De@cTf@c52@S12AT51>3<`=3I5=D<f>48=A44g=CPb@d<g=D8e>3Q2A3Q4
>CHc<TDa=cHc=DHe=S4g@S@c@D51=SU2@CI1=dI5=34PCT@=;ePf=b0P<S@`8594
838dAD=2A30e<dE2>DA5=d8`=T4h=cTeACA5ATE5=c4a=CLd@S8c<SPi=d<b=4@g
=D94>48i@C@a@c0g@`di<SU5<c11A352<cPa<TDb=cPh=48i<c=5AD4`<TDg=d95
>CE2@STfASTeATHf@CLc=SHe=3Ti>DHh>D4=<d<g>3<a<C4d@D<e<C0c<3Tb>CU4
@d53=C8i@D4b>3LaAC=3<SP`>4Hc<DI1@SLf<SE1<c8d=44e=C0`3CHbA4@i@C=4
AS13=S@h@dE6<c4a@S4g@cTf<C4aAS@b<D8f>4@e<C=3=34b<c51=4=3A3Lf@D8d
=4<dA@e1<d@e>4E3=THa@C<e=3D`=SU6<3U3=3Q1<T93=SLb>DDiAT55A4<b<3Hf
>CPg=D@`<d4`>356>3=4=4H==c54<4=2A3<h<DHh=d8c@SU3<4E6<C92@cDc<S4a
A30i=CTa<SDa@c51@T<g<SM3@SI6=SI4A4Hb=d553C95>CPf<CA1<dHf<cT`<THf
<D8c@C4g@dE4>CE6<S@d<cTg=3Th@S=5<34`<c<`=SH`AD4d@T8i<3U6<`e1<CTb
=3U6A38h>D<cAD91=DE6<c4c@c=2ACU1>C91<CHf@D8f>CTc>356A3Tb<3I6=DDg
@CLhAS8h<C@PCT@=;ePf>20P<C8`8594838dAD=2A30e<dE2>DHc=SPfA3@g@C8c
<4<`<S95A3HhA4=1>D@i@D8c=TD`@CLb@S4g=S@f<4Dh>DH`=@de=STf<44`=S<d
<T8i=dHe=c0d>3Df=T4`A3M2A3=4>44c>C15<CQ1<4=4<34h>4A4ACQ2>CL`@cP`
@TD==CPi<DE6<SLb>D=1<DE3<3M4@C4d=dHi<495<SM6<3Da=cT`>C92<C0d@d95
=C94>352ASDeACTcAT<f3DA1@c0`AS4eACDe@DHdACLe=S<g<3A2>34h=c8i@T@`
<T@c@D51A3Pa@d8g>CHc=DE5=DA3AT93@T<fA21>A0d_F3Hi820c>21BA20b=4E3
@T@`=C=5@SI3<S55=d@f@c@i@S4`=c4i=T56AD8h=4<c@S4i<d<i=cL`<4<a=DE1
<d4d=494A4<=A4<e@CTe@c<h>CLd>C93@R1>A0d_F3I1820i<B1BA20b=4E3@T@`
=C=5@SHa=CTi=3L`AT4`=3Lf<T@f<d52<CDd=SM4=S8iA4E5<3M2<C<i@T8h=c=2
>CE4=S0=>CM6@CT`=S4f=C@b>D53<SA1A493=CT`@DDa>3Hf<T4hATA4AC=2<d@a
<TA6=3A5=THb<S=5AD8d=c0g3DE6<S51=C@e@D51=4=5>4@d@c4d<CA1A4E1AC@e
@S96@S8i=3@cA4@a=4E6A4@d<d=2=44d>DA4<3M4<`e5=21>A0d_F3I2820e<b1B
A20b=4E3@T@`=C=5@STh=SQ3@C@iADE6<3Db@T@fA3<i=4I1@d4`<dA2=cHb<3U2
>CM6ASDcA4@e<S<eAD8=ADE4@CLe<CM3<34c@dDf>3LfAC8cA48d=S4i>C8d>CTe
=dHf<cQ1A3M4<3TfAB1>A0d_F3I3820b=B1BA20b=4E3@T@`=C=5@SI3<S55=d@f
@cI4=SM1>4He=SI6=CPc<d94@cLi=S4i<C96@CDeA21>A0d_F3I4820b<C4PDT@P
<SA5@d94<3DcAD92A3L`@THe<T8i<CLi>4E3<4E1AS<g<4E4>D=6=TDhA312=D@c
<CTa@T=5AS<b=DD`3CDb<d=4A3E3<4E2AS94@TA1ASDbA3A2<CTh=C<b@cTc>4I1
>D94<T8`<c<f>3E6=cLh=cDi<495AC15<@df=4Dd>48`ASTe@D8aASTf>C0f>CM4
=C95ASTe<4E3ACPh=C52=D=1=CDh=3M4@DDf=C92AD4`@DDg>D4==C92>DDdASHi
@cE3>3A4<C=6=3Q5<D@i=c<b<D8b<3TbADDf@c@h@c4e=38`=CM4@SDh=T51@SM5
=D@g3C8g=dI1=DE4=c4a<cHgAS=3=3Da=DDfA351<d4i<D91=S8`>34h=SLf=C=3
<T@`<d91@T=5=d52<3Q4=`dc=353<3I1<3@aAD=6<S<b@dE6=S8a@T<cAD@b<CLi
AC<hACL`=30eA4A4AT8e<d=6@T<f=CTi=3E6AS4=@d8f=cDd<34f<316@c@a@CI1
<4@e@c8b@S=1<3Hh@S@i<30i<S91<c0g=4I2>34b>D8c@S<`>30d<cE43D8f84i4
3BmH=TDP834a>B1BA20b=4E3@T@`=C=5@SU6<cHh=T@d=d4b<c13<38bAD@f>DHg
<3Tb=cQ3>38g=T4`<3Ld<c8hACDeA34aA48=<D4g@c0i<3E2=3M2@cDe=T=5<T96
=3Dh@c0dAD8e@S<bAS8e>DA1>CU3=cTf=C8iA3PhASHh<TDe<S<d3CM4@DA5@CPf
@DHd@d4g@CA6=3<b<T<g=c@e<C=4<SDa@S8a<d4e@C8e@S@h=4Ha<c8d=cQ6<d@e
>3=5@Pdb=4<e>353@DDg=494=3@d@T96AT4gA4A5<CU2>DA4<TA6<cTd=SHg@S=2
@SLbA3U4>44e>3A5=TDe84i43BmH=THP834c<B1BA20b=4E3@T@`=C=5@SU4@C<`
<S4d<S<b>C0a>3<i<CLg@DDd@S0`AC<bA3PhAT4`=C16=355AD<b<30h=4@=<C51
=3I1<S93=395<CLi<D<c=CU5=c96AS8e<SPi>3Pe@D=6=D@g<c8i=S<f@cTi>4<`
@c8e=d53=34`3C@g<cE2<D8g=3U6@d51>3Li<S@c@cQ3ASLh=DI1<S@b=44e<SD`
>CHa@S4f<D<i@S96@S<g<DHa<cI2A0diACPhAD<cA3@b<455>3Db<C<b<S=1@D<d
<S96@C4`>313=C=1@SPd>DI3ADDd<3Hc=4<a>3T`<dI2>4H=>CQ2A3<d<THg=cPd
@dI5A3Pc=4Hf=b1>A0d_F3L`820a=c<PDT@P<SA5@d94<3DcAD8i@cHa<C4aAD52
>4=4A3Dh>4Hh=cLaASU5<cQ1@SDg<C8a=CD`=CU2@C52=cM3<3E33CA3=3U1=cE6
=CLf<d8cACA5=4HaA4A5<SH`@SDf@cHh=c=6<d96=3Td=DI3=C4cASHh=DI6>4H`
<T8dAPdh<4HiAC@e=DDfAT@g@C14<44g<c@f=C=6=S0g@D96AD93>3E4AS55=d4d
=c<fASHb>4=5>D@`@TDg@SL=<4<c>3U4<D=2@CDi=T8h<C=3=S@b=CE2A3Pg=CPa
A3Q3ASI2ASPg<SM1@T<d=THhA3Tc@T=1A4I5>3Db3D<fAC0e<cQ2=C4c=C4`>3U3
<cDb>D8d<TDe<S@d<C8d=4Hf@D4e@DI1=3U2AS@bASA6@STg<S=6=30fAPdfASI2
<3I5@T4a>3I1>44g<3Lh@cHf=TDc@c0eAD8f>3Pd>CPf<TE1=4<f@d@g84i43BmH
=c4P834g<b1BA20b=4E3@T@`=C=5@SU3=S4a<C55@D8g=3LgAC53<4@eAC<iASE3
>30a@CM2=cPe=SDc=30h=dDd>CPfASH=@D<dA4D`>38`@S8i>CPi@SDa=C93@C15
=D4g<DHb<48e<d=5@C@c>C=2<S55@d96=dDi=316A4<f@S=13CLb=S@gASM4@S4c
=3@f<SM2<T96=3Q1=C=2<THa=SE5ASI4@T@h<44eAC<b<c<a@c=1<3Lb=SM3=4=6
A@df>3Q6>DHb@THb<S@e=CTb=3A1<c0i>4Hb>C=5@CTi>D<d<30fACLi>4Da>DA4
=34gASLg@D4f>DI5<44=>44i=C4c=30f@T<i=S56<T=1@CHa<4<aAC14@CQ6=SM3
AT<f<S8h=d<f<d<f<34`=S<aAC<hADI1<DE63D4i=30e=CM4=C@`<34c@T<`<S8h
ASLh<4=3@CE3>34a=CE1<4<h<SPhAS=2<30PCT@=;ePg<R0P=cPPDT@P<SA5@d94
<3DcAD8i<dDgAT=4@T8i=3Lh=c0c@T@i@c@bATDdASTgAS8i<C4e=THaACE2A4<`
@SHg>3923CHcA495>D@eA4E2A394@C=6@D<a<3L`>C11=D52AS4c<d4`<3Dh<SQ2
A48h@cHa@c54=C@`ATI6A3@g=@e1ACA4=48cAT8c=T=4<D<f@DDi>C0`=491=S8h
=d4b@SQ3@C4PCT@=;ePg<b0P<S4h8594838dAD=2A30e<dE2>D8i@D<c=3Ph<395
<S4i<3La<D8dAS54<d=3ACPbAS53<DDe@S<d=cA2<d@h@dH`<Pda=c@g<C=4=44b
=SE6=dHc=SPi<CU6@SLc<T=6@c93=3E2=T4d@SA1<C=1>3Tb=C4c<S@`A3Hf>C0e
<3L=<d4`@cQ5=c95<3I1=c13=391@DA5<cTb<S=2<C16=SU6<c51=CDa=TH`>3D`
<3I5A3<c@dH`=S4a=TDi3C8b>3<d=c4cA48b>3Hb=TDfADDc<c4f>3U2=D4g=D56
=c8a<C4cA351ATA6@C15@D4`@CU4A3Pg=d<i>0di@d8fASTgASA4>C8d>311>D<h
@cM6<dE4=dDg=C0aAD<hADE3>3Q4AC0i<cTg=dE3AC@bAT@hACLeAS4==S=6@c<`
@C11>CLb>3Lf@STc<d<h<T8b<T@b@T53>352>C92=D4`=c0a@c<e<S0d<4I6=D4h
>C<h<SQ63D<`@C8h=DE4>4I2<dHi<3Lb@c0b<DA6=D92=S16=CU1=CA6>3<e<CHg
>CE6@TDaAS11<4<d@C=6@THb<`ddASTi=3HcA3=5=D@eA4=484i43BmH=c@P834`
<R1BA20b=4E3@T@`=C=5@STf=cQ6=T=3<cPb>3Pa=48f=d4h<cPdA48h=T8a@CE4
=C@e@cH`<C94<3@a=CE6=4<=@C=1AC4d<30d@dA1<TDb<T4i@SDaAD8f<CU5>3Lh
@SPe>C8g<CI2<c14>C4a<4A5=cM3AC51@DD`=3M63D@i>CM1=3I2AD4g<S4g=3<h
>34h=SA6=496@T@h<48g=cA3=4DgAD93<S0iAC52<cLb>34`AD<`AT91A@df<CHd
A455<c8a<CTa=C@c<3DhAD95A3LPCT@=;ePg=B0P<C0g8594838dAD=2A30e<dE2
>DHc=SPfA3@g@DA4A30`>30g<DA5AC0e=c0c<TI5=CDf<TI5A30b@DE2=c4g>C@`
<@e4<TE2<STi>D@dASE6<4@i>C@bA4=1<dA2ACDc=C4e=CA4>DHd>492=THdA3Pf
=S0d>D@a@CHe@c55<T4=A4Hg<C=2<4H`A48f@dI2A4E2AS<hASI2<d4g=D@g@SDe
ATDb@dDa@d<h<c0c<SU4<D@g>3<c@cI4=dI13D4h=S<`=DA4@d56A3<g<D8c@cM2
<S<`ACLa=c4fACLe=4DPCT@=;ePg=R0P=34PDT@P<SA5@d94<3DcAD8iAC0aACA5
<cPg>3DfA4<bATH`=DHc<cHd=c4fAT=2>3I6@CLfASPc<C@i=cTi=C@f3DE5>3M4
@CQ1AC4b=d8`=S<g=4<`<3<PCT@=;ePg=b0P>3DPDT@P<SA5@d94<3DcAD8hAT4g
A3E1@cE4<THh>C8c<CDf@cLg=d8b<392<C8f>3D`=DI5@CE4=4I1=cL`@SLg3CM6
@CE1>3I1AD<eA4<iATA3ATI4<cM1>3Th=C4c<dE2ADDe@cE6=3A2>394>DI5<4<h
A3Dc>D=1>CU5<Pde=dHc@C0e>CLh@S8a=TA1@SDg<D<g@CI1=S=4@C15>CLf@DI5
=CI5<T<i@d=5=dHe>B1>A0d_F3Lh820f<b1BA20b=4E3@T@`=C=5@SThADHi=TA3
=D@h>3Lc<3Lf=312=c8cACQ5AD@e@D4e>C0c=dH`<dDg=cM4@SQ3AT<=ADH`<C94
<CTbAS=2=c4a=cHfAC<f@TA3@D<e<c56AT4b@c8d<C=2>C4d<CP`=CI1@cU5@T4c
@cTd=T<b3DI5A3TgA21>A0d_F3Li820i<B1BA20b=4E3@T@`=C=5@SU6>3H`AT=5
@CI3<SPd@CLi=S8`=3Ha@cPa=c4f=S91ASPh>3Pf=S<i@CL`@T=3ACL=ACA1<3<f
=3Td=SE3ATHi<D8`>44d@STc@dE2=C54<CU2=CPi=CHi<D=3<D54<3Lc=cL`=SA5
<S@cA48`3CU1>4=3@dHe=cTe<S4`=STg<c8d@cPiAS92>3<d>4E3>3E1<SHa>3I4
@d@a<S93@dA6<CQ5<c16=CPhA0e6@B1>A0d_F3M1820d=R1BA20b=4E3@T@`=C=5
@STi=CTd<SDi=3=4@dA6<D=2>C@cAS<g<d@i@CDaAC16>3Lh>3@`=S0eATDd<cQ2
=S8=@STf<TDg>312>3<`<3@g<T8g<dE3>4=1@T53=C@f<cTPCT@=;ePg@R0P<S8`
8594838dAD=2A30e<dE2>CM6A34a<T@e@S@`>DHe=3L`<dI6@d<i@C<e@CPc=cE4
=30c@CE6@T52<C0fASLi<`d`=SPb=D55=T4g@CU5=T8h=SI5=c91=cPg<3Ld@DE3
=CTe>C0h=SPe@D8eA4Dh>C<g=D94=44b@CHa>44=<T<i<SHg<4@d<dDb<cI3<d@i
<c<c=DHe@d<`@c8f@TH`=3I5=C4dAC=6=c92=cPf<TI6>3Hg@CPhA3Hc3D@`@dE4
@dI5AD8c@STh<451AC=5<D53A4I2>3De<cTfA4<h<S=5<CHa=SHe=cLcA3Q5<C8b
AS<dA4@g>@di>D@d<4<b<c@a<c8hACQ3>CLeASE5A34d>CQ4<SHiAC56=TI4A3U4
=SPaA3Tb=d91AD4e=T8eATDh<3@=AC@g<4Di@C=4=S@a<SLfAD8`@S0a<4Dh=D@b
>D8iA4<a=T=1<S94>DE5=312<3=2A3P`ASPg=CHa<SM33D8d<d8b>3@b<3@b=DH`
=c4`=c=5AS@h<SI2<dD`=c8eATHb=S<a@c53>C4d=3He>D55<SPc<cP`=d8f<0e5
@DHf=cHa>C0b@SU1@SPhA395<R1>A0d_F3M3820b=B1BA20b=4E3@T@`=C=5@SHc
=dHc=T8fASL`<c8g@T92=4H`>C94AT@h=dE2ASTgA4I2>3DfAB1>A0d_F3M4820b
<S4PDT@P<SA5@d94<3DcAD8i=dI4<C4bA3E2<STcAC4e<3Pf=3Pe=cHi@cHc=c0g
@D@e=4I2=SDf>CDb=D4i=cQ33C95<34aA4<h>CThAS53=c55>4@b<3Li=TA6>4@a
>D8`<c=3=44hATDe<cPg=C<gA3@eASI3=CPh=4Db@@e4AD8bA3@eAD8`@CHc<38e
A392=4I3=c=3A3Df@C8a=SPc=C8c=4@c>353=c=5@SI3A34c>4Di=SI4@T<=@c0`
=353@CTfACLg@cHg@DE5>CM3=C4e=T4e>3I5=SE2=DHh@CLgA4Hd=c0i<454<c<f
=S4e@DA1>D543CLdAC8aA4E5@c0b@C0iACTb@SP`A3=5=dDcAD8f>CE2=S0gA4<c
AS11A34`AD4`>CT`>C56>3@i<SLe@@dfADA5@CPh@dI3ACHfAD8b<CP`=THc=3L`
=CLfA4Dc=4@`=c@f@dE4<c=6=D8h>CDc<TE6ATI2=4Dc<3<=ASPd<3LgACM3A3A4
AD@b>38eA3<fAS8f@T54<3M3ACLe>4=3>495=S=4=SE1=D8h=dI5<3<c@T4h<c93
3C55ASTg<D@g<3PgAS8i<S=3@D@e=C4PCT@=;ePgAB0P<C<i8594838dAD=2A30e
<dE2>3Le<d=1=4@f@cLi@d8`<TDi<SP`@T<b<dI4<3I6<496=4Dh=C0`AC12<TE3
>CE2A0dc=S@d<CPcA34f@DHaA30g@S=1<S4hAC51>DE1=393<DHb@dHc@CTg@S@g
ADHc=cQ6>394A38g@STb=34=>4Hc<C56@d54>CU3=D<d<3I5@d56A3A2@S@i@d<b
=d4b=S8a@T@bAD@i=30f@T=6>CI4@cD`<3<b<CTc3C0`@c0dAS=4<DDa=THa@dH`
>493<c15<c13=D8d<dDh<dA5<T8b<cLc=cI2AC=4ASM5<CLa@T8e<S@b<Pdd=dHc
AC91ASDa>354=C56<4@g>3M3@dDeACA3=44f=S<d=D=4<21>A0d_F3M6820a<R1B
A20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePh<20P>3DPDT@P<SA5@d94
<3DcAD8h<c4e<CTaADH`>C4c=CE5=S<a>D@cASTa<C0e=S53ACA1<T96>3I6=cM4
=c52<D4c3CTcASE5<CA5A3I3=d<c@cM3<S8i@C<gATA5<c@g>48c@d8b@c4`=dI6
<cLb@CE3=3<f<cPb<C8`<cI6@@dcAT8c<3Le<D<`=SU6<S8c@STc@cHi>C8c<30d
>D4b>CHhASHb<SM2>C93=cA3=3LdAB1>A0d_F3Pa820a=cLPDT@P<SA5@d94<3Dc
AD8h<c4e<CTaADH`@SM3@T<f>38d=d@dAC54<c4h>3Te>CU3@c0dAS=5>C<c@TDd
=3Ld3C<b@cE3ACI3ACI6A34b=4Hf=CA6AT8`=D=1AC0c<CU6=CA6A30`ASHf@C=2
A3@d=CDi@DH`AS0h>CI2A0dg>DA2<d92=T56@SU2AS0b@C12=4Dh<d=4<SA2=CTg
@C92=c@bAD=6@C8f=4@g<DDcACHf>3U6<C0d<CD=<3U1AS53<TI1<d4d=451<3Lg
=c0gA453>4I6>4<iAC8h@SQ1ACLf=C0e<34g@cHbASPc=392@C4f>3123DI1<3La
=3A4<cE6ADE3<3Pb<CQ4<cQ6AT55<C<h<S@aACM3<4<e@S92AS11=C0iAC@d@TDd
@cP`>48f<Pde=4@f@D4`=d8i<C8b<c4h>44g@T95<SM6<4Df<dE4=S=6ASLb=SHc
=4Da@C4d>44i@CI6<48PCT@=;ePh<R0P<S@f8594838dAD=2A30e<dE2>3@e=c11
<S0iAST`@THc@S54<3M3@SDd<SLc<c16<SPd<T91ASL`<4I5>DI4@SL`APd`=dA1
ACE1<4Di>3D`@C92>C8b>356=3Te<c4i=T8i@CLb@D<g@cHfACA2<d4f<cM5@D@e
=dI5=TI5<CD=<C@f>4A2>3<`>3DeA3L`>DHc=S0f=cLh=d=3@S4d=44g@C53<CPf
A4@b=48e@cHf<351AS8b@cE1AS=53D<i<3A6=CDa=S55ADHe<3Li@C<b<DDg@D55
A3PiAD94=S56<DI1<c<b<3<`ASDg<D53>C12=C8f=T8h>@diA4A4=d=6=3=5AC4`
ACTi=STi<C=1@T@g<CTh<C94ASPc=TI3=d91@d8e<315<392<3De@d56<S54=48=
ACDh=c0c@T8d>495<C52A3H`<SHb=495A495@c4d@T8h=C0fASDe=CA6=T4a<c4c
=CTdA353=S<b@cLa3CA6>C0cA4A2<d8`=D54A3HiACTdAC=2<c8`=SI3A44h<c8h
=3HbAS8c<CPg=44g=S0i=4<h<S4b<3Dd=Pe4=SDd=T8hAD8hACQ6<cHd>CU5A3He
@cM2@T@`ADE5=456@dDa@S8i>4@g@D8`=3I6=3Dd<3<e<3De@S8=AD4dA3@c=S56
<4E484i43BmH>3<P83Hg8594838dAD=2A30e<dE2>DI3@D4`=c4e=4Hi@T8`<4@i
AC52=4<`@d@bA3H`<CA4AS@cA3Tc@c16<c53AS@b<Pe4@T8`>38a<S=1=c0`>3Pg
ADI5AC56=SA5ASDb@T4iA4Hb=D8dASPh<d4`@d<h<CDeAT56=C0`=D51=d4=@S11
=SHg=d=4AD4`=30PCT@=;ePh=20P<CHg8594838dAD=2A30e<dE2>30b=d8a=C=1
<SQ2<D53@T4aACA6@S@cAT4g<D@i=CL`@cQ3@T=5<dDbACHh<S0hA@db=SDa<D95
A3<e@cA6A314=cQ2<S15>44c@S@cASDf@S<gACH`>34g=S@b<c@`=D@dA3Lh=4<d
<D4`>CP=>4Dc=d<iACHe<cA3@CTh>48h@T8hAC93>C96<T8d<C<i<cLg=C91@S@a
@cTb@C@e=C91<D<e=S@g@T8i3CDa>CM2@D=6@CA6<DE1<T<d<TA3>356<dD`<C92
=4<i<3=6=d<d=cQ2>3TcA3Te@CI5ATE6>D4h=T4a=Pdc>4A4>DI4ADHi<C55<cM5
ATDh<4D`ATA3AD55=c=4<DI1>354=3Hi>D@cASA3<4Hd=d4cAT8e<C=4AD@=@D<b
@C0h@DA6=C<h>34i@c53=SPh>3Tg=D54=3M4@TA3=R1>A0d_F3Pe820a=S4PDT@P
<SA5@d94<3DcAD8h<SU5=3@d@S0e>DHi=D4aA3@aATE3<3E5@C8b@D4a>D@c=48e
@C12<d<gAC8`<34b3D@b<D<g<D4h>D92AS8i<SLh>4<c>38g=dHg<T4dAS55ASQ6
=C0`<CE6=cDa<355AS96>D4h>4A4<354>@e5@D4i<DE1<T95@SL`AS8h@CHbA3A5
>34a<C<h<D=1=cTg@cH`=SQ4=cQ2<3Lc@CTf@C@eAD4d=CLa<d8=A3A2=30d@T93
@dE1@S8f=3@i=3DfAC<c<SU3=S4h<T95AC@fAC=2=c=6=3=5<3U2<3Dc<D55AC@c
@D@g3CE5=c<`=3Q6@C8a@S96<SLb<44a<SPi=3Hh=S<i=S0g>4I1>C4d>3I5<c0f
<3L`<48h=c<dA3=4=dE6@`e3>3Di<SQ1<3@a<c<f=3D`<T91ACLh84i43BmH>3HP
834d<B1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=T<g>C8e<c8c=DE6=3<g<T@b<C11
<DDcAC0h=SI4>4=2A3Tb<3D`ASP=<TH`@S55=TA1<3Le=TE3>4H`<T4`>38i=3Ph
@D@a=4I2=d4fAT4i=c@d=d<e@S4a@d56=352<3Ld=S4d3D92=4I5<D91ATHh=SDc
@D@d>30e@TD`@C8f@c55@C12AT<`A34h=44iA4I5@cPeA4@g>D@gAD@b<30e=Pdi
@S8e@d4bA3E4<SM3@DA6=S4g=S15<cU4<DDd<D=3A44i=cTa>44e@SE1AC@g>CDe
@S11AS4f<TI5<ST=A3Pa>4I2=392=313A4@`@dI4AST`<3M6=S55@CA6<CTiAT<b
=cLgACI584i43BmH>3LP838e<@00X@30?olPDT@P<SA5@d94<3DcAD8i>CDi=38e
>C@cA3Hi>C8g<SA4>CU2=3E3@cU4<D8c=cTg<3Pc=30c<C@`<dE2=DDf3CLc>38a
ADH`ASQ5@THe@C=6=CTi@S8i=DDa>4<i>38`>CU4@S8b=cQ3@S13ASQ2>391=S0e
=DDf@cQ5<0db<3M1<S8a@T4h=4@i>4=6=D@bAC0d>4Hh>C15@DA1>392<cDa@SLa
<3Lg=d4c@D8d=T8c<4Hg=c=3<d4==D4bASHb=C4f@CLf<C=3>3Q1=d<i@SI3<4A1
<S94@c4gAT=5<S0`=4@h@STb<CQ2=C8i>3Q2AS8e<DDh3C@d=SA5>D8g@cDa<D@d
<4H`AC13=34a=38h<c8g=C92AT<h>CPh>D@bA3<f>4Hb=C0cA3<a<SI6ASPiAPdi
>C12@CTdAS@a@SA3<cPg@S4h<DDe>3Tf=C0b>CM3@D=4<S@d<4E6>3Td>D@fASA2
ACTdADH`<S96ASD==44f<T@fAC<d=d=4<d8e<4I6=3<b@TDd>D95=3Pc@dHa=CQ1
A3E6@dHf<c91=c=6A3<h@TI3@C13@dI43D8c<DA2=C4g<S52A44h>DDg=TE3=cE1
@d<b=4=6<SDg@d8i=dHf@DDd<cLb<34h<S95=d<f=CA1=S92<PdiAT@h=T8`AS8`
@c8d=cM5ADHe@d=184i43BmH>3PP838e<21BA20b=4E3@T@`=C=5@STi=CTd<SDi
=3=4=STi<SLb=4@i>D8d=D=3>D@a@S<g>CL`>3<d<3<a=30cAD8eACH==c<h<S55
AS16>4E2ASE1<dHe>CU2<STeAC4h@cTh<S0i>DA2<S8g>4=2<4=6>48h<T4f<3De
ACI3>4D`3C8`=d4b<S52@CPdA3Th@dHeA395<3@hASPi<4E1A44h<T8c=C52=c4`
=cLg@C=1@S@f@S<`ASLg<d<c@@de@C96=S8e<CI1=cHa<d<h>44g@cU2=T<`A44b
<TA3<CM6@dDb<30dA3Q2>C8a>48e<STh>496<SDaACP==3@f=4Di@SM3=C4aA3@`
AS15<4<d<C4d<SPc<SLe<T96@cPi>3PiA394<cHhAS8e<3=4<c4b=TI6>3U63CTi
<491>CA6=352=4<c>3M2<CPaACDh>CHe<38i=d=1@d@b=3@`ADHh>C@iA3I6=495
>CA5AS0b<TI6=@dd@CHbA3I5<c@g@d@c@SD`ATHd<c92AC@i@TDd>3=3AS4e>454
=DI3ASHc<T4g<dI4<cQ2AT=1<4=3AT@=@S<aA48e<CLb<D94@CPiACLfAD<g=D53
@c8d@dHb=CM3@STgASI1AC<i<D<f<4<e<493=TA5=C=4>DA33CHa<D=5AT<f>4He
<S=1>C4g>CDh84i43BmH>3TP838e>B1BA20b=4E3@T@`=C=5@STi=CTd<SDi=3=4
=STi<SLb=4@i>D8d=D=3>D@a@S<g>CL`>3<d<3<a=30cAD8eACH==c<h<S55AS16
>4E2ASE1<dHe>CU2<STeAC4h@cTh<S0i>DA2<S8g>4=2<4=6>48h<T4f<3DeACI3
>4D`3C8`=d4b<S52@CPdA3Th@dHeA395<3@hASPi<4E1A44h<T8c=C52=c4`=cLg
@C=1@S@f@S<`ASLg<d<c@@de@C96=S8e<CI1=cHa<d<h>44g@cU2=T<`A44b<TA3
<CM6@dDb<30dA3Q2>C8a>48e<STh>496<SDaACP==3@f=4Di@SM3=C4aA3@`AS15
<4<d<C4d<SPc<SLe<T96@cPi>3PiA394<cHhAS8e<3=4<c4b=TI6>3U63CTi<491
>CA6=352=4<c>3M2<CPaACDh>CHe<38i=d=1@d@b=3@`ADHh>C@iA3I6=495>CA5
AS0b<TI6=@dd@CHbA3I5<c@g@d@c@SD`ATHd<c92AC@i@TDd>3=3AS4e>454=DI3
ASHc<T4g<dI4<cQ2AT=1<4=3AT@=@S<aA48e<CLb<D94@CPiACLfAD<g=D53@c8d
@dHb=CM3@STgASI1AC@cAT8i=c@b>3<d@CU1<CPh>3Li3CQ6@SThAD<d<S<f=4E4
=3Q4<38e<d4e<CL`=4I1=C93ASU4=dHh84i43BmH>44P838e=b1BA20b=4E3@T@`
=C=5@STi=CTd<SDi=3=4=STi<SLb=4@i>D8d=D=3>D@a@S<g>CL`>3<d<3<a=30c
AD8eACH==c<h<S55AS16>4E2ASE1<dHe>CU2<STeAC4h@cTh<S0i>DA2<S8g>4=2
<4=6>48h<T4f<3DeACI3>4D`3C8`=d4b<S52@CPdA3Th@dHeA395<3@hASPi<4E1
A44h<T8c=C52=c4`=cLg@C=1@S@f@S<`ASLg<d<c@@de@C96=S8e<CI1=cHa<d<h
>44g@cU2=T<`A44b<TA3<CM6@dDb<30dA3Q2>C8a>48e<STh>496<SDaACP==3@f
=4Di@SM3=C4aA3@`AS15<4<d<C4d<SPc<SLe<T96@cPi>3PiA394<cHhAS8e<3=4
<c4b=TI6>3U63CTi<491>CA6=352=4<c>3M2<CPaACDh>CHe<38i=d=1@d@b=3@`
ADHh>C@iA3I6=495>CA5AS0b<TI6=@dd@CHbA3I5<c@g@d@c@SD`ATHd<c92AC@i
@TDd>3=3AS4e>454=DI3ASHc<T4g<dI4<cQ2AT=1<4=3AT@=@S<aA48e<CLb<D94
@CPiACLfAD<g=D53@c8d@dHb=CM3@STgASI1AC@c=S@e@SHb=c4dASPe<D91AS91
3C0f=D<c>392AS4g<S8cAT54ACHd=cA5@SE2<c8i>CHg>CPPCT@=;ePh@R0P<c8`
8594838dAD=2A30e<dE2>CTe>C@b=CTd<d@f>CTb=c8dA3Ti@S@e@d<iA352<cLi
=c0h<c@`<c4d<3=5@SE5=Pdg<cPb<DE6<4HhAD96=D4cASDi>D8b>CE5<CQ3>CPb
<3TiA48b<SLh@d8`@dHh@SPb@CH`=CE5=T<hAC0=<S0g@C8b<D91>3A4>CQ3ASE4
<TD`=3Q6>3T`AD54@CPb@S<e<D8g<C0g=cM1<d52=3I2<c16=cLc@c=13CE1<THf
<SDa=T4g=S4c@cPh@CM3>D8f@c14@C8bA4<a=dI3AC8`<3A4>48i<S4h@SDb>CPh
@THb=C55>0dd=3HdACU2=d<e<C54=316<4D`@c@a<C@b>3<b=cDb@TI3>3Th>3U4
<T@c=SQ6<SD`<d@c<C8fATHh>DH=>CT`@T4i=4Hd<D8d@c<h=d8a>355=CPi=SD`
<STg@d53A38d=315ASPi=3U4=THd@TDi=4E6<38bATHe3CA1=S94=TDc=3M3A3=2
=C16AS@c<T95=3U2AC@h<d=6<CDh@D@eAT=6=S<b@CLcAT@c>496@d4`@d=6A0e2
<c54@SDa=c8a@TA1>3U5=cI5@cLe@D=3<SA3AS8e=d=2>CM6=T55=3<i<C0aA34e
@dDb<dI5ASLi<DH=@CA2AS0g@T52=S0e<493<d<aAT8aAT56=TDe@T=6<c=2A4Df
ASP`A3I6A38d<c13<T8a>34d@T<hAT4f3D8g=3E4ADA2@cI1@SM5=48`@CHa<DI2
AT<e@CP`AS14=CHi<THg=CI3>C=4A3Q6<SI5>4D`>38e<3Pe=Pe3@c15<44f@SQ3
@S54<c=1<d8b>C4f>DDf@S91=TD`A48e>3Tb@cL`84i43BmH>4<P83<e<R1BA20b
=4E3@T@`=C=5@STi=CTd<SDi=3=4=STi<SLb=4@i>D8d=D=3>D@a@S<g>CL`>3<d
<3<a=30cAD8eACH==c<h<S55AS16>4E2ASE1<dHe>CU2<STeAC4h@cTh<S0i>DA2
<S8g>4=2<4=6>48h<T4f<3DeACI3>4D`3C8`=d4b<S52@CPdA3Th@dHeA395<3@h
ASPi<4E1A44h<T8c=C52=c4`=cLg@C=1@S@f@S<`ASLg<d<c@@de@C96=S8e<CI1
=cHa<d<h>44g@cU2=T<`A44b<TA3<CM6@dDb<30dA3Q2>C8a>48e<STh>496<SDa
ACP==3@f=4Di@SM3=C4aA3@`AS15<4<d<C4d<SPc<SLe<T96@cPi>3PiA394<cHh
AS8e<3=4<c4b=TI6>3U63CTi<491>CA6=352=4<c>3M2<CPaACDh>CHe<38i=d=1
@d@b=3@`ADHh>C@iA3I6=495>CA5AS0b<TI6=@dd@CHbA3I5<c@g@d@c@SD`ATHd
<c92AC@i@TDd>3=3AS4e>454=DI3ASHc<T4g<dI4<cQ2AT=1<4=3AT@=@S<aA48e
<CLb<D94@CPiACLfAD<g=D53@c8d@dHb=CM3@STgASI1AC@cAS<`<d<c=S@e<cU1
<S<d=d@h3C95<d8h@DDg=4<h@c@i=d51<D4c<S<`<dDe>C8a=C<i@D52>DDg=T55
>CI4=SU2>395<3A2=d4g<4=3=@da@d<e=TE4<CLd<d4e<cTi<CHgA3=4ACE5>314
@dD`=4Ha@S4i=CA1<C0b=C<g>C8c>4I1AST`AT4b=dD==3@f=CTf=D8b=SM4=CDc
@SDaA316<c14=CM6<392ASPi@CDh<3Lb=SPg<SHh<d4i<cHg@c52@S<cAS563CQ1
<CTiA314=CE3=DHd>4E5=48h=c8g<D<i<3Da@c4b<TA6<d@d<4I5AS1684i43BmH
>4@P838b=B1BA20b=4E3@T@`=C=5@STiA30`@C4c=SDc<c0e@D4f<T<f<SQ1@DE2
=44iAT92=DI4<4A2=C51@C8i=3@fAD8=<TI4=3=2A3<e<3=4@cHf@cM5<CE1>4@c
=3T`@c54AS=1=3=6<3Pe>D4h@D8b>3H`=cU1=T8b=DE5<3Ti3DI1@T92=c52=T@h
=C<e@C@b@C8b=TA3<3M3=34h<354=T8f<c0e@d8`>4Db>34i<STd@CTeATE2=3Q6
A0dd=314=CU6=S4g@SA5ASA1<c<c@S@c>DHb@c14A3Tb=T8b>D<hAD4d=SE1@DI1
A3E1<DE3<dI4@d51>D4==C56@CLd@S91=DDi@SQ2@T<dAS=1>CT`<CHfA4Dg@CA3
<3<cAC8`@C4eA3Lf=TDa=3Lb@D<`AT@a>3Dc3CA1AS@e<D<d<T8c@SPh>CI4ASTe
@S51@C@hAS=4>48f<38b<3I2<C@`@TE4>CLb=4E3=d=3=d55=34e=`e1<d<i<TDa
@d<eACM3A3I3@C@`<DA5<DHa>4E4A4<`>CM3=CDa=DHi<d@f<TE5=D<d=3A5=DA1
<3He<cT==SHf@d95=S4a@DHhA3H`<c<b=c11=3U2=3I2@S=184i43BmH>4DP834i
<B1BA20b=4E3@T@`=C=5@SU6@d51<3La=CHd<c@a<C12<34d>4Dc@c92=d@d<C@`
=cTcACQ3<cLiA315=CA3<TH=@S4c@CDc=cTi=TDe=CI5@c93@dA6AT@h=THi=c@c
<S@`=CTf<38d=SHd<SD`<d4hACE3AD55ACPi<48b3D<a=SLcAS56>3Q2@dDfACLa
@C=6=D@f>4I6>3M6<d91@cQ1=4<f@SHi>30hASHeA3@h=34i<CU1<cPa<Pe5=CHf
=T=3=48f@SDc=4E5>3Tb>3Th=CI6@cU6<C@e=c@g=TDb=48i@D8h>34a=DI2=cI1
AC54=CHc=T@=AC52@T54=4I5=313AS0b<SU4<dDb>3Pc=4=6@D<gADDg<cU1<S56
>3P`ATE1=SDfA3@hAC8e<SHf=3U63C@d@CU4=S<dAT@g@CI6A30`<cE4A496<30`
@THe=dI1<CPa=CM4<d<eAS16ASHg<3=6@CU2A4<fA30b@@e2A4@h<S0d<SA4ASM2
<3E2<34i<cLf84i43BmH>4HP834i<R1BA20b=4E3@T@`=C=5@SU6@d51<3La=CHd
<c@a<C12<34d>4Dc@c92=d@d<C@`=cTcACQ3<cLiA315=CA3<TH=@S4c@CDc=cTi
=TDe=CI5@c93@dA6AT@h=THi=c@c<S@`=CTf<38d=SHd<SD`<d4hACE3AD55ACPi
<48b3D<a=SLcAS56>3Q2@dDfACLa@C=6=D@f>4I6>3M6<d91@cQ1=4<f@SHi>30h
ASHeA3@h=34i<CU1<cPa<Pe5=CHf=T=3=48f@SDc=4E5>3Tb>3Th=CI6@cU6<C@e
=c@g=TDb=48i@D8h>34a=DI2=cI1AC54=CHc=T@=AC52@T54=4I5=313AS0b<SU4
<dDb>3Pc=4=6@D<gADDg<cU1<S56>3P`ATE1=SDfA3@hAC8e<SHf=3U63C@d@CU4
=S<dAT@g@CI6A30`<cE4A496<30`@THe=dI1<CPa=CM4<d<eASHb=S0a@c53<4Dc
=3Hi@SHa<`e4=493=C4b<T<d=3Hd@d4`ADI4@cLa=34PCT@=;ePi<20P<S0`8594
838dAD=2A30e<dE2>DI3@D4`=c4e=S@c=34a<48`<C@hAC=3<T8gA3@a=30g>C=5
>4<c=cU4<4De=4<bAPe2<C=1=C<g>CTfACDe=TE3<T=3A4I6A3PfASTg=3<b=30e
>CH`<S@f=S@b=C0c@CQ5=D=5@DE5>3T`@S8=@c4f=c=6<DHh>493ACI5=c51<dHe
A3HhATHh=dHc@T53>44d@cI2=STh<3Q6=SE4=3Pd<CTa>D4c>34b3DDe=SHf@d<d
@SI2=C<dADDh>C8h>CPe=TI3>DHa=3Dg=3LfAC8d@SU1@SPh<C4eAT8g=T55<D@e
=S<fA0e5<D92@D@dATDd<4=6<38b>D@cAC8h>3<d@dI1@cM5ACLc>D4b<DHh>316
AD4f=CI4=3Q5<SDb=SHd>DH==3A1>D@f<cA6A3M1=TI4<30c=DA4@TH`<312ASDg
AT4a>34e=d@c@cE6=S93@CU3A3PaAC4g>3<f@TDh3CLd@CDd=S0h@SE6A315<S13
=dE5A3@f>453AD<c=DA2=DI1@SQ6<c4PCT@=;ePi<B0P<CTg8594838dAD=2A30e
<dE2>DI3@D4`=c4e=S@c=34a<48`<C@hAC=3<T8gA3@a=30g>C=5>4<c=cU4<4De
=4<bAPe2<C=1=C<g>CTfACDe=TE3<T=3A4I6A3PfASTg=3<b=30e>CH`<S@f=S@b
=C0c@CQ5=D=5@DE5>3T`@S8=@c4f=c=6<DHh>493ACI5=c51<dHeA3HhATHh=dHc
@T53>44d@cI2=STh<3Q6=SE4=3Pd<CTa>D4c>34b3DDe=SHf@d<d@SI2=C<dADDh
>C8h>CPe=TI3>DHa=3Dg=3LfAC8d@SU1@SPh<C4eAT8g=T55<D@e=S<fA0e5<D92
@D@dATDd<4=6<38b>D@cAC8h>3<d@dI1@cM5ACLc>D4b<DHh>316AD4f=CI4=3Q5
<SDb=SHd>DH==3A1>D@f<cA6A3M1=TI4<30c=DA4@TH`<312ASDgAT4a>34e=d@c
@cE6<CHe<C@c<C4iA34c<D<g<CE23CU1=38d=C4e<T<h@D91<dI3>DA2<DE4@c8b
A3@eACTa<3TPCT@=;ePi<R0P=3@PDT@P<SA5@d94<3DcAD8f@c8aACM4=T<d>D8a
<3La>CI1ATE2>3A3<d8a>C=3>CLg<313<CDc=CU1=SU4@SI63D8`@S4`A3I4<dD`
@TE4@CTgASM5=3@a<CA4=S@PCT@=;ePi<b0P=3DPDT@P<SA5@d94<3DcAD8f@c8a
ACM4=T<d>D8a<3La>CI1ATE2>3A3<d8a>C=3>CLg<313<CE5@C53A355<3=23C0i
<C@b<DA5=T=2<3Hd<T4f@T4a<cDa<T<a=4I4=21>A0d_F3Td820e<b1BA20b=4E3
@T@`=C=5@SI3<S55=d@f@c@i@S4`=c4i=T56AD8h=4<c@S4i<d<i=cL`<4<a=D4e
=S<h@TE6<dD=<44b@CH`<3<f>3U1<C4a@dI2<CQ4=c<f<cE2>396A3Hi@C@`<DHc
<dDc=38cAB1>A0d_F3Te820e<21BA20b=4E3@T@`=C=5@SI3<S55=d@f@c@i@S4`
=c4i=T56AD8h=4<c@S4i<d<i=cL`<4<a=C=3<cM6=4@bA3P=<cLaAS11@c@bAD<c
<cPc<d92=dA3@SDa=d56>CM5>3Hc@SU5=SE2AB1>A0d_F3Tf820b<3LPDT@P<SA5
@d94<3DcAD8iAS<f>3I4=3M1<S<`@c0b<TE4=SU6=c0i<SLh@cPb=cI1<30g=3<b
>4De=D@a<DA23C51=d<`>C0e@S@g@T<e=CI3AC92AS@e>4<`=4E2=D8c<THb=CU4
@CTi@cLi=SDb>D@h>4Hf>395=C8c=0dgA454AD4h=T56=4=1=d4dAS@c<S93=cLd
=C4cA38e<D8b<C=1=D4b=D8d>3A6<C<b=3LhAS=4=CPcAD8=<SA3=CPa@d55=cA2
A3@d=492ATI1=dA4AC4i@SU4A394AS<i=3Hf=d8c@T8g<T@iA3Q1=CPdACHd=CA2
3CHf=d95@SLa=cQ5@TDe=S8c>4@g@TDdA4E3@C4d>C96<c<`=cLc=3Dd=SE5=SU3
>316<3Ti<cLiASL`@Pda@S95>3Ti=dHc>3=2<dDc=SA4@cT`>3@i<cTa>DHd@C@`
<cHc@c<h@CU1<3Q3@cA5=356ASTfAT@e>C<=@CLg=dHg@C56=TA1AT@d<C@gASLf
>3H`@DDi<C<a=CH`@c0d>CLa<CM3=d<a<CPe<S0i>4D`84i43BmH>CLP834e<B1B
A20b=4E3@T@`=C=5@SU4@C<`<S4d<S<b>C0a>3<i<CLg@DDd@S0`AC<bA3PhAT4`
=C16=355AD<b<30h=4@=<C51=3I1<S93=395<CLi<D<c=CU5=c96AS8e<SPi>3Pe
@D=6=D@g<c8i=S<f@cTi>4<`@c8e=d53=34`3C@g<cE2<D8g=3U6@d51>3Li<S@c
@cQ3ASLh=DI1<S@b=44e<SD`>CHa@S4f<D<i@S96@S<g<DHa<cI2A0diACPhAD<c
A3@b<455>3Db<C<b<S=1@D<d<S96@C4`>313=C=1@SPd>DI3ADDd<3Hc=4<a>3T`
<dI2>4H=>CQ2A3<d<THg=cPd@dI5A3Pc=4Hi<TE2=DHf<cHb=c15>393ATI4@CHi
<D8hAS8`>3E3@T=4AT<a<3Pf3CHb84i43BmH>CPP834e<21BA20b=4E3@T@`=C=5
@SU4@C<`<S4d<S<b>C0a>3<i<CLg@DDd@S0`AC<bA3PhAT4`=C16=355AD<b<30h
=4@=<C51=3I1<S93=395<CLi<D<c=CU5=c96AS8e<SPi>3Pe@D=6=D@g<c8i=S<f
@cTi>4<`@c8e=d53=34`3C@g<cE2<D8g=3U6@d51>3Li<S@c@cQ3ASLh=DI1<S@b
=44e<SD`>CHa@S4f<D<i@S96@S<g<DHa<cI2A0diACPhAD<cA3@b<455>3Db<C<b
<S=1@D<d<S96@C4`>313=C=1@SPd>DI3ADDd<3Hc=4<a>3T`<dI2>4H=>CQ2A3<d
<THg=cPd@dI5A3Pc=4HiA38e=T@cA4I6A4<i=CDa=SA3ASQ2A3@b@C8f=DDgAC55
>C@e<d@b84i43BmH>CTP834e=b1BA20b=4E3@T@`=C=5@SU4@C<`<S4d<S<b>C0a
>3<i<CLg@DDd@S0`AC<bA3PhAT4`=C16=355AD<b<30h=4@=<C51=3I1<S93=395
<CLi<D<c=CU5=c96AS8e<SPi>3Pe@D=6=D@g<c8i=S<f@cTi>4<`@c8e=d53=34`
3C@g<cE2<D8g=3U6@d51>3Li<S@c@cQ3ASLh=DI1<S@b=44e<SD`>CHa@S4f<D<i
@S96@S<g<DHa<cI2A0diACPhAD<cA3@b<455>3Db<C<b<S=1@D<d<S96@C4`>313
=C=1@SPd>DI3ADDd<3Hc=4<a>3T`<dI2>4H=>CQ2A3<d<THg=cPd@dI5A3Pc=4Hi
<3M6=CPb@CTg<48a<c=6@cU6>C92=SPc=44e@dE6@CTh=48hADHd3DDd>CM2>4Dd
ADHd@dA184i43BmH>D4P834e=b1BA20b=4E3@T@`=C=5@SU4@C<`<S4d<S<b>C0a
>3<i<CLg@DDd@S0`AC<bA3PhAT4`=C16=355AD<b<30h=4@=<C51=3I1<S93=395
<CLi<D<c=CU5=c96AS8e<SPi>3Pe@D=6=D@g<c8i=S<f@cTi>4<`@c8e=d53=34`
3C@g<cE2<D8g=3U6@d51>3Li<S@c@cQ3ASLh=DI1<S@b=44e<SD`>CHa@S4f<D<i
@S96@S<g<DHa<cI2A0diACPhAD<cA3@b<455>3Db<C<b<S=1@D<d<S96@C4`>313
=C=1@SPd>DI3ADDd<3Hc=4<a>3T`<dI2>4H=>CQ2A3<d<THg=cPd@dI5A3Pc=4Hi
<T@e<C8i>3U5=C@h>DI1>D@a@dHi<3E5<THd<c95=d=1ASA5>4E33D@g=4I1=SU3
>4<eASDg84i43BmH>D8P838a>B1BA20b=4E3@T@`=C=5@SU4@C<`<S4d<S<b>C0a
>3<i<CLg@DDd@S0`AC<bA3PhAT4`=C16=355AD<b<30h=4@=<C51=3I1<S93=395
<CLi<D<c=CU5=c96AS8e<SPi>3Pe@D=6=D@g<c8i=S<f@cTi>4<`@c8e=d53=34`
3C@g<cE2<D8g=3U6@d51>3Li<S@c@cQ3ASLh=DI1<S@b=44e<SD`>CHa@S4f<D<i
@S96@S<g<DHa<cI2A0diACPhAD<cA3@b<455>3Db<C<b<S=1@D<d<S96@C4`>313
=C=1@SPd>DI3ADDd<3Hc=4<a>3T`<dI2>4H=>CQ2A3<d<THg=cPd@dI5A3Pc=4Hd
<38gAD4`AS92<48dA3@h<cU5@CU3@SDiA4Ha=d<d<TA5=CPi<SE53C8`ADDd>3@e
<4Db=D<b=4D`@CH`>D94=48b=dA1ADE2@dHg@T8gAD8b=C<hA4<i<cQ3@S95<d<`
@T8e<0dg<DDg=C95=CI3<D8i<c<f@ST`@D4eA4Hd=C4iA48eA395A4=3=cLf<cDc
AS11=c4g>D@i=CH`>3Pc<c0=A311<SHd=D4g@DE4@CLi<44g84i43BmH>D<P834b
=R1BA20b=4E3@T@`=C=5@SU6<cHh=T@d=d54A4@`<3P`=c54ADD`=CL`<c96ACDe
=S96AD@`<T55@SLa=cTd<34=A395@S8i>CU4=4HeAS14>CTd<TA3@C=4@TDe<cDa
=CDdA3U6=3Q2@SI6=4@h=SH`=3U4<D4f=D<aAC913DA6=c4c@S16<4A2=T=6@TA5
@THc>4Hf@S=1=cE4=d8e=DI5<T=5<D=3>3<`<c8iA354=cPc<d<fA3M6@@e1>3Hc
<3E4A4=1AT@c=c52<d<g@S8c<4Dg<CLa=TDg=D92<S15<3Lf=CLh<48gA30hAS=2
AS8g@S8f=S4=<3<eA4A1=C12@cU584i43BmH>D@P834b=B1BA20b=4E3@T@`=C=5
@SU6<cHh=T@d=d54A4@`<3P`=c54ADD`=CL`<c96ACDe=S96AD@`<T55@SLa=cTd
<34=A395@S8i>CU4=4HeAS14>CTd<TA3@C=4@TDe<cDa=CDdA3U6=3Q2@SI6=4@h
=SH`=3U4<D4f=D<aAC913DA6=c4c@S16<4A2=T=6@TA5@THc>4Hf@S=1=cE4=d8e
=DI5<T=5<D=3>3<`<c8iA354=cPc<d<fA3M6@@e1>3Hc<3E4A4=1AT@c=c52<d<g
@S8c<4Dg<CLa=TDg=C8a=C92>D53<CHa<3He@C4a@d=3@CA6>CLd=d@=>4Di=c4i
<dDg=21>A0d_F3U5820a<cDPDT@P<SA5@d94<3DcAD8iAS<f>3I4=3M1A4A4<30h
<3LaA4E5<3Dg<3<bATDe=CHbATE4<391AD8g<CLi=30a3D@bAD8b>CTiA3A6=DH`
A3Ti=394@d4cA495=C<e<CDe=4@iAS@h@T8fASA4>3Hf<3@iA351=SE3<DDb@@e4
ASLa<d8`AS14@SI3AT94AD96<cQ6=T8c@CLeA3M2=CE6AC93AC53@cPc<3<b>D@a
A3Lh<c=3=T@gAT4=@CPf<c0eA4A3@DI4<cLa@S=3=d8b<c15=c4g<CI5=cE2@T4c
<CLf>DE3<3Q3<d@h=3I1=S@g>3@b@CPb3C51=C0i=3<d@cDc@SLgA3A5A4=4A3@f
=T<g=T4g<R1>A0d_F3U6820a<c8PDT@P<SA5@d94<3DcAD8iAS<f>3I4=3M1A4A4
<30h<3LaA4E5<3Dg<3<bATDe=CHbATE4<391AD8g<CLi=30a3D@bAD8b>CTiA3A6
=DH`A3Ti=394@d4cA495=C<e<CDe=4@iAS@h@T8fASA4>3Hf<3@iA351=SE3<DDb
@@e4ASLa<d8`AS14@SI3AT94AD96<cQ6=T8c@CLeA3M2=CE6AC93AC53@cPc<3<b
>D@aA3Lh<c=3=T@gAT4=@CPf<c0eA4A3@DI4<cLa@S=3=d8b<c15=c4g<CI5=cE2
@S11=DH`@d<f@S<a=C@b<CA3=38eAC8dAD523C=2@D4b<4E1<C15=3Le<c56=c4f
AS<b@B1>A0d_F44`820e>B1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THg<3Ha<THf
<T4a=S94=SA2@T4`@C@i@T95AD95>312A30d>CQ6@ST=@S53A4=2=C=5A3LbAD8b
ACE3>3A3=T@b@D4d=352AS92@D<hAS8b>48c>4Dc>D@i@S13<d4`A4I6AB1>A0d_
F44a820a<c8PDT@P<SA5@d94<3DcAD8f=C@fA4A1<DDa>4=2<d8aA3<i=S0e<CLh
<CI1<3Dh@D4b@D@a=c0h=SLhAD8f<S4c3D=2@cHf>454@DHe=4@e=S<g=SQ6AC54
=D=5@SPhAC<`A44g<d52=4I4@C@`=CHi=494>3LfACHd<3M1@@dd<c4bA314>C=4
=T<i<D=5ACE5@D4c<TE2=CHhAD@h@CLaAT51>34i=D91=dI2>3Hf>DA3>D@h<4<i
AD4=@S0f=cLg>C8g<C8d@TDc<S16<TDa<C4c<D94<CHe=48h<SM5=T55<CHd<D<b
@S4i@D8i>311<4@a=S8e3CQ1=DI3A3Lc>C14@SDe<S8c=C4`=c93AB1>A0d_F44b
820a>C0PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=c4b>30i<cU1=cLg<C52@S8f
AT<c=CDb<T8`=DDb@D51<d=3<TDa3DHi@TDg@c<bAT<cASI6A3M1=3@e@DA6A4Hg
>3Pb>3U2<dE3@S0f<3P`AS0a<cLfADDb=S<d@S4`<392<`d`<C8fA4I3<313@cI4
<3A6=DHh@DI3=cDc=4He@c8iAC4c=T8cAC@f@TA2<T<b<cI4@C@iATI5>CI4<T8=
<cQ5A4I6<3M6<CHe=c<i=TDcA455=D4e<cHf=D53<CHb<SE3@CU1=3E1>DDc<3<e
=CDa@CE2<C<b=cP`3C0fATE2ATHh<3A6=C<gA493=SI3AD94=dHd=D4`<d4bADA1
@S0c@T55>DD`ASPi<3Da<4E3@T@f<3Q4=0df<T<b=3@bASHg=D95<3H`<CLi@C@b
@dA6<CU3@D8gAD<`<c0d<DE6@TA5@SQ2<SDe<cI3<C<f<3E4<S0==38fACLf=3Ti
<S4f<3Q1@c14<S8PCT@=;eQ1<b0P<CDb8594838dAD=2A30e<dE2>3Le<d=1=4@f
A3A6<44b@SHb=CTd@SPa<SPiADDc=cI2=3<f=496=SPe=C@c=c<g=`db@C15=4A1
ACA5>38i<DHb<D<i>DDeA3Ph@D@`=cLeAS<b=C<c@CE2<cLd<cTf@d<h<D8d@S<`
=CM3<CD=AD4d=CTc>D<h<d@b=3A5=c4aA3T`=C<`=D<`=D4i<313>D=1<C4`@S0i
AS94@CM6@T95@cHd=TDg=34a3CHc@C0`=DHh=34bA3La>D=1>4=3<d53>3<b<S94
=4Hc=T=4<C0e<SLc@CDh>CL`A3Da@SM5=CI6=3Ha>0dh=d4a=D<b<S4h=d=5ACE3
A3Lf=D<h@cU2<D@c<cQ6<3Dc=cLa=4I6@DE5A3A4=313@D=2@cE3@T=4=c0=ADA6
=B1>A0d_F44d820c<cDPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=cU6@THi>30a
>4A4@SE2@SA1=C91>CTe=4A4=C93=C16=T=1@d=33DDb<4@c@SLh@SPh@D<eAD@e
=cDc<D4e>CLaA4H`=3Q4@SA4=d51ACDi@DHhA3<`@d4d=T51<CI6=c@fAPdd@c0h
ACLhA4I4=CU4<3He>C8i<48b=4A6@DDf<c96=TDgA3A5>4@fA391<S4b<cA1AC0i
<D8`A3D`=3D=<D4h=CE6@c@c@S0bAC<a@S<i=38d<S0a<T55@SLi@SPh=4<a@TA6
AD@bAC13A3Pc<c8i<D@f@cU4>CLb3C@a<SI6AS0h<34e@S@c=dE2>CA6>DHh<SE6
=dI6<4I3A34`AT8`@S8dAD@d>38g=4A5=TE1=4I1AD@g@`e1@CI6@S=3<4Db@S<c
=DDh<4Dc=C0d<T@iAD95@T8f<c95=cE2=T91AT55@d4iAD8h<c4d=d4iA3@`@dH=
<cHh<T@f>3A6<dHaA392<SPe<d8d@cQ3AS0a<S<b=cDg=C12=C54>C0f=CU6<c93
AT4f>3M2=3E5@CPg3D@e<CQ5=CE4=DHg<S0fAT=4@d<d<CLe=C8d<3@b=3U2AT53
<cDf=SI4=D54<C<a=3@`>4I6<3@g>356>@da<D8f@CPc=38i@T@g@T4i=dE4=c0h
AD8d<T=5@SI4<dA5=4I2>CHf<dA5AC93<30g=cU6A3Le=38i=CP=>3Te<4Hf<SPi
=C<a@cI6=cHa>3Da>3=4@D=6@D=6@S95=CPc@T4f<SU4<3@d=SHi<d4g=3Pb=C8d
=SM13CLf@C0f@T8g=cDb@C4f@S=6<CU1@d8g=cLi=TDi=d4f<d93=CU6@cU5@C8d
ACE1A3Pc@S11>DHg@S8d=Pdi>D56AC8a<SI384i43BmH@CDP834`<B1BA20b=4E3
@T@`=C=5@SPg=C=3@CA4=THhATI2<dHg@C12<3M1@T@`<d@a@CDc<3@iAD=3A3<d
@d<a=4<a=3P=>DHa<c55=4Di@D=4<SLd@C=2=SHhAC54@SE5=d4a@c0`@SM3<T55
=CPfA3T`>D<iA48i<3<b@c@bA3Tc3CPc@S=3ASE4=C0f@S@h<CU3<C4c=CU3=3Tc
@S@i=4A3=456=CPeAT54=cI6=C=4<3Df<cA4<CE6>DDe@`df@S4c@SA2=3A5ADI4
<d4e=3Dd<C@b84i43BmH@CHP83Lg8594838dAD=2A30e<dE2>3Le<d=1=4@fASM4
=cQ2<C@i@S4f=4E5A3@`=3La@dDfACQ4=48`=C@f<c0d=CPi>0e1A34a=SM4@S4h
=c@a@dI5AC55@S8g@T91A3Hd=D95=S0hADHg<c8f<SM3@S8i<d=6@CHcAS8eAC<`
=SL==cPi=3=1=dE5<c=6=D4b=SU5@dI4<34cADHe=CE1@cPb@R1>A0d_F44g820b
=3DPDT@P<SA5@d94<3DcAD8i@d8b>CLb@d8bA4Hh@SA4A4Hi@C52<dHd@d@g<S<b
@CU2@THf@cU2=T8hATE4@C0c3C=1=CI2=dA4ATDd=cDa>4DeASA3=CE2A4@i<30b
=S15AS4d<c0fAC8d=D52<DI6@SM5<T8d=T8dAC8b>@e4A3<cA38i=c91>4<d<CLe
AD95>D8eAS=2=SU2=4I1<T8f@cHd=c8d=d@c=3=3=DDe<SLf@SU1>D8e=CP=<S94
=D8hA3Ld@D<h=TD`A313AC<h=3Ld@T@c@CHg<SLhACLc=D4d=CTh=cQ2@SE6@D<b
@S94=30i<C=33CQ1A4=6>CHc>4@cAC<i>C<d@DDhACE1=dDaAT93@TA3ATE3<cE2
=SI4<THg@C=1=C<i=SPf@dDcACPe>0db=DDh<TDc<d91=48f@dA2<S51@SQ1=DHd
=d@iADHg@C=6<DA4<SHb<TDiADA6AT93<D<gA3Hb>DA3@cD==TA4<cDbA4DgA30e
>C<d<C8f<CDa<c94>DDfAT8g=D96AC<dAT=6AT55=SM1>3<b>DA2@SPc@d=2<c16
3CTfAD@h<TA5<cE2ACHeASU2=cDa>4I6<d4g@SE5<38iASTeASI4<DA3@CM3=CPb
=3Db@D4g=DDh<44f<0dhATDi<STa=CQ484i43BmH@CPP83<a=21BA20b=4E3@T@`
=C=5@T93=SE3<3Di@cM5<S<`ACU4>D<`<DDa<d=3A455AC4b<SLf@CHe@d8b<d4`
<38d@d<==S<`>D51A4<aA30e=D<f@T94>DDg<SLhAC0c@C4e@D<a=4=5@D4a@D56
>3A4<4<b@cM1@c15=D8`>3Ta3DI1=3Hg=TA6<cTc@C@f>4DeAT@a=SHe=S<c=dHb
=3DcAS@a<C95<38g<CTb<T8c<C4i<3M5A30`=d@fA@diAS<bA356<d@`=C8f=D<i
<C11A3E3@S@`<S0h>4Db<SQ2@SHa=cLd<38b>3A6=CDe=TA5=S@iAS0h=c<==3I1
=SM2@c0fA491>4I4@SDdAS<dA3Ph=3HbASLf=c12>3E4>C4b=353>D8`=c@e=454
=394AS56@STf3D<g<C0cA48i=THe>3<i@D8h=SA5ACPi<S=3>4@a=CM3<T8g>4E6
<SM3<SPaACLiA4E2<cDg<cA6<3A4APe1<3Hb<4=3@D4f@C4c@C@d>DA6@S53<D<d
=cLbAD8f=S@c@cI4<4HiAT54@CQ5>30dADE2<CI3=4=3<30=>30h@TE3<494<CTh
=SDb@S16=3Hd>3PgA4A1<CE5<C<g>3<d<S96=dI6@c0fAC14AD53=d<a@c8hADHc
3DHd<CQ3AST`@c13<T=2AD=4<C<hA3PfA3A2<DHhA4<a=3Db@S52<T4i>CA5>352
AS13=4He>4Hh>3Dc<@dg<cP`=4<b<D4`<C94ASQ4<CM3=cLi=STb<SLc=TA3@D<`
@dHb<c<g@dI2<C4dATE3A4@f>3M3AC<h@CH=@dHf>38eAD<g<SPb@c8gAT4f<CHd
=SE2=D<iA21>A0d_F44i820b>3TPDT@P<SA5@d94<3DcAD92@cHe@c0e>D<gAD=4
ASU6@CP`>C@c<34c=c@d=SA4AT8e>C0eACDg@SU3@T8i=d553C16=cPh>34h<c<i
<THh<S15>3Q3>DDc=cTc@SM3A3Hc>3E1>455=S=4>4<h<cHh=3<d>CE6>3M5=DE2
=@dfAS8hAT8i=c8d@D=6<cHa=4A2>D8b=cP`=d8d@SI5AT96=3Pb=S56=CHg=cTc
<d53@dHc<354=S13<SP=>CP`ASPe<C4fAC0e=SLc=CE5=cM4@T<eACU3=C16A34d
=44f@D@b<S4e<SPi<SM4>4E1<SE4@T4d=DI63DHd<cU5AT=6@SQ3=S<f@TDbASQ1
<C<d=T8iA34`>394@C<h<DHc@cU4=STd>DHi>CHi@C<c=SLb<SQ5<`e1>38f=3E1
@D@f@S91<CT`<44c<SI5=C=4=dDh<SQ2<48e>CE2<T<e@S@c>DI2>48b@c8f=CPe
@cQ4=CT=ACPh<T<i>CPhAT54=CPbA3Pf>3Df@dA1=cHd<SHf@SI1=SU4A3Dd=3A6
=SLd=T=2<DA2A315@T@e=3E43C93<315<S0f<c4f@cM4@d@gA34b=d<f=TDc<4Dh
<CE2AD8gAD@i<3@a>D@i=451>D<f=3I2=D95<cPa<`dh=DHc<SA3=S51AD4f<S@g
@cT`=T55<CA2<S@d@SLh>DE3A3P`=C=4@C4d<3H`>C8e>C<iA393@T8c=S4=<SE6
=CHg=3Tb<CA3=S=1=cPg=c@h@CA4A3U5@SPd<CM4>CTd=S<PCT@=;eQ1@B0P>30P
DT@P<SA5@d94<3DcAD8hA30iASI4@CA3<CQ2A44i<C0c>CDg@CM5@C96@cDi<CLa
=SHf=391<S0d@dA5=3Q33D<i<d=6<dDiA496@C<a=S8i>4I3=3@gASE6A3Da=3Di
ACHg<CLhACDeAS<fA496@c8cAC=6<494<CA3=Pdd@cE2=48`@d=5<S4iA4D`A38d
AC=5ASP`<T51=CE1@CM2<cE2@d@c84i43BmH@D8P83<a8594838dAD=2A30e<dE2
>D=2<STg<T=2<3U6ACTe<SA2>CPf<3=1<C@c=CTf<cDe>454=cHi@T=4=SDg<4@b
A@dcAR1>A0d_F453820c=b1BA20b=4E3@T@`=C=5@SU3@S8i=c93@S0i@c96<d<`
AT4i<cPh@d92@S8f=CI6@dDh=D@`<SLe=T51@c@g@cH=<DHc<S<bADDd=cTf=dDP
CT@=;eQ1A20P=c4PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=dE4A44b=TDe<C13
<cDh<D<gA4=3=cM6@dHb@CLcA3A3<c96>4H`3C@i>CDe@cE3=dI2=CTb<3D`ADDg
@THh>DHh=SQ3=d@a<S0cACQ4AC8aAT8g@CI6=453=C@i<cU1>D<`@`e4A3D`<TE5
@C0e<T93<312ASU6<35584i43BmH@DDP83Lh8594838dAD=2A30e<dE2@T8a=TI2
AC8d>CHh<CDe=dHa=D4e<cA3>493@C@`@cU3<38f=4<a=D4b=d8d<CTa<`dh@CPe
=SHhAD93<d=3@THb@SQ2ADA3<48h@S<h<S8d@D<g@CA2>CHb=3Le=cHc<CI1=3Pi
@d8e=4Di<ST=>CDg<dDi>CPe=34i=30dACM2>38cADHi<cHg@SLaADA4=S4d84i4
3BmH@DHP838`<b1BA20b=4E3@T@`=C=5@SPb>DDd=3A2<3Df>CE3>CTg@TDb@TA5
ASTh<CU6>CHb>CU6=C13@DE1@TA4A4Dd=CH==44f=3E3>CLi<34e@d<iA3D`>30i
AD<g@D@d=D4g=cLg@T8`<D8g@c8h=d94AS0i>C4fA3Ti<cTd=3Hf3CH`A44c<3E4
=c14AS=6=c8gASU1<3=2<3D`@D=5>C<a<38`A391@SE5=3@`<SDe>4@h=cTb@d4f
A3E4<0de@d56@S=2<C0gATDi@SDe=S0h<D4d>D4b<T51<SHgATHi<S0g=D@`=SHi
>C=5<C=1@CTb=c94>4A5<4<=@T8aA4E6>44a@c0hADI6<c@a@dHg@T8dA4Ha>CLa
<T53<CP`A496=dA6=CQ4>DA2>C0d>48f<SHb<d<c3CLe@C=3<38h<4@b=S=2<3Tg
@dDh<D8`<d<h=CA5=SU2<DE3@C=5ADA4A38`@cTi=DI6>CE1@SHe=S4i@Pe1AC4b
>C=3=T@d@C8a<CT`<3<eA3A5@T@iA4A2AT52=CU4=4E5=CA1@dHdAD5184i43BmH
@S0P838d=R1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THh<4Hc<SDhA3=3=CI2AS8e
<c4`=C8f@S53@S51AT=5ASHg=dE4<c4==d54@d4cASM3=d@d<3DbADI4AS16ACDi
=C8`>C@`<352<C56<4@g=48iA38gA4Db=3<dAD8g@C0a=CH`3CHd>CU3ACHfAC11
>3U2@dDe@DHc@c@d<CLd@c8c>492<c@i@TE1=c<fAS16>C8h<C=2<CA1<SE4>DH`
>0e2@SQ6ASM1@d8f@C@f<c56ASTf=496=dDfADDf=d8`=c4i=c0gATDb@D92<cTg
@c8h@C91>CE3>C55A3L=@c@a=STe>3<i=c8g<SU3=cDb=D55A3LiA4I4<DI5>3Q2
AT8aACI3=TI2>3HbAT4c@TD`<S@g=T@f<dE43D@dAD4f@CM1@c8iASP`=cE6@SU1
<dHa>C=3=4I3>3Ta@CLd>CL`<S=4=d95<3@`@T4i=d4`=SA1=DE5A0da>3Tg=C8d
@c0h@T@b<3=1<D8e@d4`=cI3<cA1>C<a@TE2@S8g=c54<3M5=351=CI4<T56=DE1
<d8e<4<=<D=2>48h<3D`AC4a@DE5<3=5@CPg@dDh@T91=D95=SI2<c@h=T91<c8d
ATDgAD4d>4<d=c<`<4DfADDf3CDc>C95<c8e>C0b@R1>A0d_F48a820f<b1BA20b
=4E3@T@`=C=5@SPg=C=3@CA4=THgADA4=C93A3Ld<cHd=c0h>4@g>3Pb<C0`<S<f
ASTd>CU3@DD`@T8==c@i<CU5>34iA4@h=44e<3Q5@CU3@CA2@DHg@C@dACPe<cHg
>34b<C=5=CI6=D=5@D@i=SPf@D=6=SA33C8h@TDf@B1>A0d_F48b820e=B1BA20b
=4E3@T@`=C=5@SPg=C=3@CA4=THgADA4=4=4ADHh<SE6@CTe=CTd=38`=D56=D4`
AS0e<CDc<dHf=TH=<D52=C95ASE2<c4h=C@bAC@a<c<a@CU3ADHh@c8a=CTa=TA1
A392=SPh@cI5@THg<SDPCT@=;eQ2<b0P=C@PDT@P<SA5@d94<3DcAD8h=cDc@d4d
A3I3=cTb>C@h@C11=c@f<D54>3Ph@D=3<SHf>3Pd=3Q6=4Dh@T@h<dE63CTd<T51
>30cAC4e>3E6@C16>4HfAC56>C8h<4A4=C=2@C15@DDg<3<b<d4c@DA5<R1>A0d_
F48d820h<b1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THg<3Td<SL`A44a<c@`@SDd
<DHe=C@gA3Te@T8a@S@d=d93=C=1>CD==D@bAT=3A4Hh<CLb@T8i@c@h<cTiA3Dh
A3DeATI6>C4i@dI5>CM3=44`@c4iA352AC92@D@eAC@f>C<`3D56ASU6=S=3=C@f
<THa=C0c<CQ6=SPhASU3<CI2A3Pd<D4b=3T`>3A2=c96<c0PCT@=;eQ2=B0P<C4b
8594838dAD=2A30e<dE2>D=2<STg<T=2<c<cATHd>D<g@CU6<391<44d<3<fACLb
>C@h@S8i@CPh@cLb>DHi<0e1=48d=3A4@c@g@THi=cDcAD=5@c16=T4`<d92ATA5
>48eAC8fASQ1=TI1@d=4ACLg<44h>DDb=351>38=<TE4@SDe>DA6A48`@CM2AS16
<3<i>3Pe@C14ACDd<DHg>3E3@S0hAT8d@c11@cLa<SLi=3Pb<c0`<cPc3C8g<CM4
@CM1@T8d<cM3@DA6<S<i<4Hc=T4c@SA6<SHeASLb@SE1A494=D8d84i43BmH@SHP
838`=21BA20b=4E3@T@`=C=5@SPd=CL`@C8`>DHf<D<f=TDf@D=5ADDhADDe<38d
AD4`=3@`A3M2<TDgACDg=SLi@T@==CL`<C8`@S=4A38dAS<`>CU4<3PbAS15<3@e
=c8`@SQ6<SLg>DDcASU3=THiAS4d=3<iATDa>3A2=3I33C@dA4A5=CQ4@c@b=C94
<C=6<3LdA452<SM6<44`=S94>30`<DHb<C=5@c<e<CA3<c0a=cHe@DA3A392@Pdf
<TI3@c4`=34`@cU5=S4a=4E5ACDd=TDbAS4e@D<h=34f=cTa=cM6=4<bACQ2<TA5
<cDe<C@b@CM2<TH=AS@c@C8h<CA4<CTd=SDi@CU4ACE3@D@d=c53A3He=SPh=3He
@C=5@D=1=dDc@SA5A4@a<dHh<d<dACLe3C12A3A1ASQ1@CI3<T4h<dI3=T92=3M1
=455>C<dAC16=38a<c@f>3Ti>354<DA4ACM4>CE2@SL`<355=@e6>CDb<ST`ASQ5
>3<b<T@g<SE3<cM2@D8h>34g<dE6=cU6=4@b@S8a<dE2A3Q1@TDPCT@=;eQ2=b0P
=CLPDT@P<SA5@d94<3DcAD8iA44c<38a=38cA4Df@CA3<3I5ATHd=3000:40`3oo
A3Tb@S@gADHi@TE4@cPd@D4h>C8e@TE2@`e2@dHd=CLa@CDb>D@e<C<f=3<`=d55
<D93>D@b@cHd<4A5@S0e@CPh>3ThAS8h>451<312ASHPCT@=;eQ2>20P=3LPDT@P
<SA5@d94<3DcAD8hADA6>CM3ACDiAS55<4DfACTh>D52=d@e@cHi<30g=4<f@cPg
ASDd=44b@D=3AT953C<f<c4g@T8i<C14ATH`>CE3<C0g@CPiA3Ha<30`=c<e<4<P
CT@=;eQ2>B0P>3TPDT@P<SA5@d94<3DcAD8h<DI4=3I2<3Dg=CU4=3Hi=T@d@D@d
>4I4A4<b=T8g@DDhASU6<d<cAT4b<3A3=d4g3D95<SQ4<CHa=c92>3Ti@D8e<c54
=30`A44i<c@`>3Q3AC0`AD93>4Ha>3U6=d52<CDb@S96@T4d>DI6=`e3<44i=4E6
@d@f>C<f@d8`AS=5<SHd<44h<48e@S=1>C8`AS=4=S8b@SQ5A3E3<d@g@CPg@c8`
=3U684i43BmH@T4P838a=R1BA20b=4E3@T@`=C=5@SU2=c0i>C0a=4He=d<g<T54
@C15=SPdASA6A3Q4=c0b=3<a>394=dE3=S0g@S52<3@=@S0g@cLf<4Hc>4I2>34b
ASA2@SDaA456=CD`=d@c>C0h=S<eASE2@SA3=4I1=3Pi<3<c<3Td=C0c@c@d3CTh
=4<d=4<cA3I1<C0hAC0`>CPi<SM1A3M2@D<hAS@g=S55>3Q3=CD`@D95>DDf=cDb
<C4g@c56ASHi@`dd<D<eA4E4@C0`<3@cA34f=SDh=d=4@c<`=T4c@T92A3L`<T=5
=dHh@D@d@c55=dA1AD91@cTc>C4c>3D==DHgADHd=D8f@D@a@T4gA4=3AC<e@c@i
>3@g<S<c<dDa@DE6=T93<4Dh@S0f@TE5AD92A4=6<T95ACI43CI2@D@a=CA3@CU4
@dD`<c0b@C12>CLb=c96ASHg=d92<cL`<D4a=C<b@cH`=30hAD<e=48i=cHg=4E6
@Pe2@d<c=S4gA4@c@CTb=492<STg<c8h=4=2<D=1>30eATHb=C8f@SHi=C4`<T8a
<316@D8e=T4g<c<b@S@=<CTg<S0c<S53<C8f84i43BmH@T8P838a<B1BA20b=4E3
@T@`=C=5@SHe@d@i@S4a=3A5<C<h<4Dc@C4g=C<fA3Hb<DI4=cI2<3<e@D<b<cPi
<d8a=STb=CD==cHc@S4a@CLc=S0e@c4g=SHhAS=6=CM1>4@f<d8d@SU6<SI4=DHc
A4@e<CDgAD@h=44eA34h=4=2>3Ta3D<c<4I4<4<aA4<a>C=1=STe<SQ2=C4a=dI3
ASM4<CHi@T4e@S<h>CQ4@TD`>C<i<dDc@C@g=SPiAS<g>@dd=4<hADA2A48d>DH`
<48i=C=5<cH`<3M4=c=4<d<c=c92<3HaAC8d>3<g<DA1=3E2AT=5=3Q5>C8g>3L=
=T4g@CHdA34`<S<i<S<b<TH`A495<DI1=SDd=3TgACLf@SPf@S@b<4I3<CPfA3Hh
@c12>3Q2@cLdAC123C=6=STiAS4`<C@hASTdA4Ha=3Q2=SQ5<48d>CLfATHh<cT`
>CA2=C16ASTc>C@e@c@c@CDh@CE4=3Hh=0di=3Lf>3DfAS=6=cPg@C4a=CPcA4<b
<T<e@c8b<dA4>4@f=C=5<S8`@C4eAS53=S4i>452=3@g=cPe=SP=A3LPCT@=;eQ2
@b0P<C<b8594838dAD=2A30e<dE2>C96=CLg<cM1<cE4@d=3=d56A4<c=4@d>DA4
AT8h@cTf=cHg@TE4<DI1=CM6@c=6<@d`<C0a<CI5<SA3<D@hA4@`<3=1>313=3Tg
=3Pb@SI4<TI5A3Q1=4=5<c=4=DA2ADI1<38g>48i>CU3=S@=AS=5ASHh<CPfAD96
<C16AD53ASLc@d<b=SQ1>D92@THc@c16<395<c@c@SPe@c<bAC<a<S8`<4<bADHb
3CTb@cHh<3M2=4Da>DHa<c4g=T55>4E4AC91=4I2=C8d<313@SHi<DDb@D8h@CTe
<C=6<c<`=dDd=4<fA0e3@STb<DHc=D8g=cDa=3A2>D52=T52=S4PCT@=;eQ2A20P
<CLe8594838dAD=2A30e<dE2>4E4ASTg@dDe>DI1A3Db@c56AC51>CM5=TI1>CDd
AS0e=SQ4<T<e<cQ4>D93ATHa=`e2A4<c>3A6>D4iA3<e=3La<CI2AC93=S@`<SM6
<d4c>D4i>C52<CTc=cI4>3<a<D<f@S4`AT@iA4=3=48=ASHg<4Da=3Pf<DDc=393
ASHc=T93<SM1@c=6<D8i<TI2<D8d=TE3@T@aAS@c<38d<D92<3=6@S4b>CPe3D=5
@S8e<dDgA4@g@C@e@cLg<c=4@c@aA4I5<315A48e=T92<SH`<T8d@cQ2=THc@CLe
>3Hc@CHa=d52<`e2>CE1<392=c8e<C0f<38i=452=T8b@CPh=C=6ACU3@c54A4I5
>3=1@SLc<CLd=SA5<C8e@c4e@SM5<48=<D@h<DDg>34i<44`ATDd<CTi>3Ld=C4e
ASTd<C4i<SU4@c@bAC4aAT@`=CTc<3@d<S4PCT@=;eQ2AB0P<cHb8594838dAD=2
A30e<dE2@THaAS0eASPe=4<`>3<e=dHa@D<fATI1@CM4<d8c@CU4<3Dg>3@iASU4
=D56<S53<`e2>CU2=CLf=DH`>DI1=c4g>44g=3T`>4I1>4=6>CLg@d8fAD=1<SLb
@dA4<T@fA3Pf@d4fAT91>312ADD=@cHe<C54>C0g@CPd<d8e=3P`@D<g<3@h>C<i
ACA4@SE1<cTi>CPgAD55<DA3=SE1AC<b<CQ2@D51<C113C8d@DA4@cDd=T@h@c0i
<c0c=CL`@c@d@DHb=c=6<cI6<TI5=4E1A452@CTa<CLiAS8g<d=5<cLa<D<c<`di
<SHa>48e<cA3@SHb<d<h@SM2A3I6=3Tc@cM2=SPa@S53<TDe=DA5=3De=D4d@dA2
<cE3=4<gA3A6=T4==DE6=CLe>C<a>3<g<3Ta<3E4>3PgA30`A3Pi>CHf>D92<dDa
<dE5<48b<44d<cM3<SD`<dE1=D55<3953CHaAD8i>4E5ACP`<C0e<S8i@SHa>3M3
@d@e@T4c=D=6<391ASM2A3TaASTi=CA6=48a>3<e@c91@TI3<0e2<cLb>CHbASDd
A4E3<T8c<cI6ACPb<D@gAS0g<SLg=STi<4DfA4<c>DDg<30f=3U3=c55@dHd<4<i
A48=<3T`=4I5ATDhA3=4@SM5@DA5<30h=4<g<cHa@c@f=CLdAC@b>CQ2=cHa@TDh
>DE2@DDc=4@e=DI4=c=63CDe=d94>30g=S<h=C51>C8b@S0d>3Hg<4A2@T<fASLg
A30f@SM2<DE1AC8c=4@i<dDcAT<d=3Q3=3ThA0da@d94A30e<cLg=30e=SHh<T@f
<cPc<d<b<30a<cI1A44d=4E1>3U1AS4eA3Tb<DDd>C4c=S14=SM1<T<=<SDcASHb
ADA5=CA6<S4a@C8bACDc@SQ2@DDf@S4g=SHg<30iAD8h@c94AS8f<CDaAS@a=c0b
AS91ASHb3D@h@S0PCT@=;eQ2AR0P<CLi8594838dAD=2A30e<dE2>DA1<c0b<C@b
<c8d@T93A4E4@CE5>4De<c96=S8h<CE2=SQ2=d=5=3Hd@S4h<3E4APe1>3I6<C53
=c8e<cM6<cM3<3De>D<f@T4d<cLb=CE1=C15<3Dc<3D`=48d>CTh>44f=d<`A3<c
@TDe=48=<T93<DDc@C0e>CTiAC4a>C4e@DI1=d@e=cLe>DE4>3I3=cI4=DDc=D51
@cDi=T<b<T52ASI2AC<b@C543CE6<4I2A38c@S94>D91=3Tb>3@g@S11<dE3ACPg
=c@f<dHaASPh<SI3@CHcA3Pf=d4a<C4cASM1A392>@e5=C0d>C0e<c8f@CTa=c4h
@SHd<34eAC=3=311A314=38d>455ACE5A3M5<cQ2<SDf@C0cACI2=S0i>D<=@CDh
ACE2=c@a=C0hAT93<d<c@CQ2=48b@cE2<cDc@THiA3Pi@c0f@C53=d53>3=5<cDg
=3@i>492>21>A0d_F4<`820a=c<PDT@P<SA5@d94<3DcAD8iAC@d<34b=CLiA4@g
=D@h=3U5=DE2@dA3<cHc=c0`<38b>CM1A391AD@a@c13<S<i3CQ1=3Dc<SI6<44g
@SQ6=D4a=C<g<3Hc@c4b<3Hi>48g>DHg<S12@d4cAD52<TA5=48g>4=6AS@gA38d
APd`@SLb=3=2=4I2>D@f=S4g<CP`ATE1<c@g<T94<SPe<S8d<cE5=D<b<c=4@CTe
@CE4=T8d<c@b=4<g<3@=<C0f>CTg@T@i=cHhA3I4AD92AS8g<3U2<3PeACTi>3Tc
@THhA30iADE6=S@d=4D`=34cAS@b@CQ6<d8i3C<h=S54@CD`@C@e>C0`A3Hb<3<a
=3Lh<30f<4=2>C0d@cE1<C@f<3U4=3Ph@cD`A3M1AT@h=S0gA4<i@@e4ADA3=DA1
ASLd>4Dd>391<cDe<S54AS11A3E3@T91>D<h<c4`=S96@C8`=cA284i43BmH@c4P
83@b8594838dAD=2A30e<dE2=SM5<c<f@D4d=c8b<T8b>CDh>3M4<SI5<C8b=30c
ACTcASE1<CP`=3=4<dA4=T8c@`e3<cQ2<3DiASA6<c=3=SDbASDbA4=2<C<PCT@=
;eQ3<R0P<c<PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=dE4A44iA4H`<3Lb<S0h
@D8f=CTf<44i=c91@dI2<S92<354=d=23D<d<c8h<b1>A0d_F4<c820e<21BA20b
=4E3@T@`=C=5@T94<d<a=D@i=T=5@cE6@cM4AD<f>4Hf@DH`<C8h=cLd@SI4=TDe
A4Hf=d@i<3<i<34=<S=4>D@cAC93@T@hA4<g>3@i>3T`@CA3@TD`<S=2<DA1@dHi
>391=b1>A0d_F4<d820i<B1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THh>D8e<S<i
=C8c=THe=30aA4Dh>CDi=D54=cA1ADA3@C@d>3LcA3L=@cLe=S4a@cDcADA2A3=6
>D@eASE4<d<`<S=1AS16A34e@cHe<CE4=T93=3<g=SE6A3I4<dDi>3@`>4A13CLd
AC@b@S8e<C95=d51@C=5ASQ1AT8h=cHg<SU1AD<i=3Pd<CI4@D55=DHb>38c=CHa
>3M1=TDe>CQ2=PdgA21>A0d_F4<e820b=SDPDT@P<SA5@d94<3DcAD8h=cDc@d4d
A3I3=cU1=CTd@SLb<C<i<4I1<3Tb@c15=394<c95=CHi@cU4<4HiACI23D93>3Dg
<34g>CQ6=d8iAC<`<S4gASPh<dA3>CD`@c15AS<`=CU6A3I5=T55ASI1<SM4@DI6
<S=1<C54<0e2<3=3<C@f=SLa>C=5@D8c=44f<34b=c0e>CDi@C4d=dA4=CDa=4He
<CU5ATHf=4Ha@CLf=3=4>3E4=3T=@C<d>4@e=TDg<c0g@DI2=C0b@D53=C@b@CPb
>34a=d<a>3Ta=SH`AS@i=SQ5@S8`AS8d=3I1=C=3ADHc3CPa<SM2<c92AT4f=3De
@C56=DI3>352=dD`@C92AS8h<38b@SDf=48cAC4g=3Q2@CTa<3Ta<cDa<3Hi>0di
>CI5=C4e>314A30bA494@S=2A4@d>D53<S4c@c54=c13=c@d<dDb<3<f>4<e@T8d
<T4a@dDc=cA2=T4=A48eA48c=T<h<THeATI3@CU2=CDiAD54=493<CI2=SA2ACHf
<3E2=C@iA44d@CTe=dHcATDd=DI4>3Tg3C0f=C4b<454@D=4@D=5AT@c=D94@T<b
@T@`=4<`>3@g<CH`@dD`@DHe@C4h>C0cAT@a@THdASU3=4=1@Pdh>3Q1ASDf@CA4
A3=3<3Hb<S16<312@D8b=C8g>391=c@d@d8i=cHh>4Dd=DHc<4@i@b1>A0d_F4<f
820e<21BA20b=4E3@T@`=C=5@SQ4<3U6=TA1=3U6=DE2<CE4<CHa=D4i=S55<cU5
=C51<DHf>DHd=c<hACM4>3Df=cD=@CDe=3<b@d8c@CI6<C@f=c<h<4Da=454@S13
=C95@d=4<48dA3M4<21>A0d_F4<g820g<b1BA20b=4E3@T@`=C=5@STh<SA1<3Hd
>CHi=dDi<3M3@CA3@c@h=CQ3@cDc<T=2@THf<c96@cA4<SI5AD4i=cD=ATE3=CP`
=48b>C@`A451@D8`@CPi<SDaATA2A352A4A1>3=1<dDa<STd=38d=cM1AST`<C8c
<C=1<4523CA5AS4fADE5@T@d>D=2@D=4=c51ADHe@T=584i43BmH@cPP83Lc8594
838dAD=2A30e<dE2>CPb=44`=S@i=SU3<CTi<T<i=D95A3Q5@d8a>D4`=4@hACM2
>4<d=3PeAC13<C<a@Pdc=STh<4A4=3@bA4E1<4Ha@S<e<CH`=cHf=3=2A4I1AC0e
ATDa<CDh@d<h<CTe=DHc=cQ3=SI4<DI5AT8=>C8dADDaAC8hA3E1<SDb<SLbA4E3
=C8f@CLPCT@=;eQ3>B0P=CTPDT@P<SA5@d94<3DcAD92=DHdAD56A3Hi=38h<3I1
=cA3A4A6A3<h@D=1@d8b<3Th<3@hA4=5=CE3>3Lf<S533DDbA30f@CTi<CHg@d<h
<CDi<D55=STc<3Hf<3Di@TE2ACPgASI4=3De=3M6=T4d@T<`ASDg@c4h@c<PCT@=
;eQ3@B0P<C8PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3H`=T<e84i43BmH@d8P83P`
8594838dAD=2A30e<dE2>3<a=C4i<DE6<3Ta<cDeACHc<CU4<dHi<C4`=CHa@dDd
@C92ASPfASLgA3La@S51<`di<dHeAC4dAD@f@cM3<d<g@c8b>D4c=dI4AC<d=cQ2
<d=2<T<a<3M6AS<g<T4e@c@c=S<h<S4b<3<f>C<=@STd@CDa@cU2ASTa@CU2@SU3
<D8`>392>493A3M2=T92@T<e=c<g<21>A0d_F4=3820a=STPDT@P<SA5@d94<3Dc
AD8h<c4e<CTaADH`>C4c=CE5=S<a>D@cASTa<C0e=S53ACA1<T96>3I6=cM4=c52
<D4c3CTcASE5<CA5A3I3=d<c@cM3<S8i@C<gATA5<c@g>48c@d8b@c4`=dI6<cLb
@CE3=3<f<cPb<C8`<cHh<@e3A3<f<TDbA3M5A4I3=d4c<3Lf<3Lf<cPd@c8a<C0e
>4<`<3Hg>356=D<`@SPe<38h<3@i<3<h@S@h@c@==DI4@D8a=D4hACPaACU5<S<c
@S96@D<g=494=CLh@c=5ASHcAS@b=cU6A3<d=cI4AC8b<4Da=34a<CLd3D4dASLg
@D4h<C93AC0d>3Th@THf=cTe>48h<DE1<c=4<3@d=4=1>C8`=d4g<c14AC<d<DDh
=d<e=C<`=`dg<4@g<38b=cU3>4He@SA5ACHc=38bAD53@TDf@T52>4@c<C4`AR1>
A0d_F4=4820b=3@PDT@P<SA5@d94<3DcAD8h<SU5=3@d@S0e>DHi=D4aA3@aATE3
<3E5@C8b@D4a>D@c=48e@C12<d<gAC8`<34b3D@b<D<g<D4h>D92AS8i<SLh>4<c
>38g=dHg<T4dAS55ASQ6=C0`<CE6=cDa<355AS96>D4h>4A4<354>@e5@D4i<DE1
<T95@SL`AS8h@CHbA3A5>34a<C<h<D=1=cTg@cH`=SQ4=cQ2<3Lc@CTf@C@eAD4d
=CLa<d8=A3A2=30d@T93@dE1@S8f=3@i=3DfAC<c<SU3=S4h<T95AC@fAC=2=c=6
=3=5<3U2<3Dc<D55AC@c@D@g3CE5=c<`=3Q6@C8a@S96<SLb<44a<SPi=3Hh=S<c
<34h<4Da>4Db<C4bAS@f=d4a<CE1>C15=D<`=SA5=Pdc<S<f<3@c@C0d@SM4@D4d
A3M6>CDb>CHb=S8b=DE3@D<d@CPc=C96=SPf<3Di=CU6=C4cASDaADDe<D4=ASLc
=D@d<cA1<3I5<S0g>CI1>3I5>4E2>CPa<d<d=3<a@c51A34a<3Q1<dHg=SHi=3<e
ASTf<TA1>C963C4b>4A3ASLa>D=6<cP`@dHh<3Tc<4De=3@h>CI6>3I3@d@bA48b
<d52=313=CLa=T8h=cQ2AD=6>4Dg<`dd<c@g<d8`@b1>A0d_F4=5820a=SPPDT@P
<SA5@d94<3DcAD92<C8b<DDb=TI3@d@hAD8i=dA2<cH`<CM3AD4d@S@f<CI6AS56
@cM3=cHc=3Hf@c@f3CTg=D8`=S@f>C0b=4D`@d8e@T4h<44i=CHd=DD`>3A5=SLa
<TE6<3<h@CDe=SA4ACPb@D4`ACHe@d8a@@di=CM1@CLg>CQ3@S=5<C94A353<d53
ADHbA3@a<T52A355<d4d<cPi@CHfA44b>C96<cDd@cT`A44f<S8=<C4b>353ACA4
=CPe<TI6=T8h>C@f=393<S51<cTdAD<h=4<gAC0b>3DiACLa@CLa>34h<3M6=dHd
ATA43CI5=SLd=DDi<C54<CTi=4De>CTf@cHiAD4d@CPe@C8`ADDf>D51=DDcATI4
@d@f<CT`@S<e>3=4AS95<`e1AS<f@S@b=44e>C96<3I6ASPe@C8d<34c=SLe<SHf
@C93=S4PCT@=;eQ3AR0P<SPc8594838dAD=2A30e<dE2@T94<38`=C0iA3La<30e
@cI3=SA3=CE3<DI4<SH`=T@i<c54<3<g=CTd@d4e<cU4=`df@S8i@dI3@S4g=DA3
=4@b<DDg@C@i@D4d>3E1=CQ5>3Hb<cLd<CDe@SHi<SPd<S4h@d4b<T8d<3PeASP=
<TE4=CM5@SPdAC4f=cU5>3Ha>313@d4d=3HgA30aAT8bAS4eAC<d<44bA3Te<CA2
=CM1=D@f@CA3A3Pe3DD`@ST`<d=2=SPe<C16=C53=c4h@C12<3Hb<315@c<a<4<f
@T4d=C51>4De<c<d=dHi=S92>4A3ATI1<0d`<c@fAS@iA4E1AC<g>3De<C0iADHf
>3I6=d@i@DA5<dHe=CHd=STgA3Dc@C16@c52@c4hASLe@dHd>4<=>3Lc>353>3<c
=C=5@D@dADHe=TDg=T=3@S12=cPg=34c=CPh<44bAC<`>34cA314<3A2>CQ1>C<f
=C=13D=3<cLd<34b>C8eA4I2<S4g=T55=d4h@DHg@SHf@D4c=DI4A38g@cM5AC4e
@TDa>CU4@dE6@T8g<3Ph@`dh>4Da=CLi=T52<TI1=SE5>D4fASI1A44d@c8`A3Q6
=cT`AS@gA353=d8f<CLi<393<cHc@d=4ASPfAS@=@dE2=T@e=cLc=SHa<c0h=3E6
@SI1=CQ5<3=4<c4fAD8c@D4d<d@aA4<e<SA6@c91@cHd>48h<dHg@T8b3C12@SHa
>D4h@d93@C11=3@b<D94@DHb<cHh84i43BmHA30P838f8594838dAD=2A30e<dE2
>D96=d4h=d@i>D55=d@i@c93<CDb<dHc<SHh>D91ATHg@dE5A493@dHPCT@=;eQ4
<B0P<SHPDT@P<SA5@d94<3DcAD92=DHdAD56A3I3@D<c<3Pe<38a=D=3=cTdA3Lb
@cA2<TA5<34d=38d@R1>A0d_F4@b820a<STPDT@P<SA5@d94<3DcAD8i@CQ5=T<h
ATDi=d@g@d=6<d56@c=1@c0b>453>3@a>3Pf<TE5@TE3<D51=SLcA3@g3C4dA3Pa
<c<c>48fAC95>DHg<3U1<C@h@SLiA3U4=34b=4I5=4I2>396<TE3AC@g<DDi=STa
=STe=cA5=`df=D@aA4@f@T4h<44h=4D`>DDe>48iAS=2=c@e=4A1ASHb@D54=SU2
@TDe=C@cACM6@S=2<CTg@T96=3T==cQ1<3Lb=STe@SA6<TE3@C<e<TE6>44f=SQ2
=CI4=3Q1<C<g@dE1A3Db<3=3>D=5=T55<SDe@cPb=3Tb3CA3>CU6AS95<S=3<d<c
<30hA21>A0d_F4@c820a<SPPDT@P<SA5@d94<3DcAD8i@CQ5=T<hATDhA34e@dDh
<4I1<48hATE3=cTi>312=cTc=cE3AC12=491<CD`A3Ha3D=3A34b>CU3>3TiAT=1
@CLf>C4aA48a>D<c>CHh<TI3ACI2ACDa<4A3@C51ASPf@DHb@CDa=3Tb@DHh<Pdb
<c0e@CHeAT96@d=3=d8d@C4cA38h=c92=cPhACHh=30c=d@hA3I3A30a<cHi>CM5
ATE4>D<d<D96@S<=<c4d@CQ6<TI5@SPcA48g=48a=cM5<c4b<dI5<SLcAC4`=CTb
<d8g=SLe=DHdA351<3T`<4Dh>C91>CA63CLcASTh=c0a=C<i@D<bASDPCT@=;eQ4
=20P=c4PDT@P<SA5@d94<3DcAD8f=dDc<cI1@C@g<CHgASH`<3=6<3Hb<T=6<3Lh
>C8d@STa@T@d=38d<D53<3TcACA43C0`>4D`AS0eA4Dc>3<g=dI2<S<d=3A1A3M1
=C15=S4iADI6@DDh>D<f<34bASI3<4Hg=SI2=cQ5>D@h<Pdf<S53@cPb>C54<S11
>CPe<3E4A3Pg84i43BmHA3DP83L`8594838dAD=2A30e<dE2=SM5<c<f@D4d=S@f
>3Pg@DDh@STd=T=1@cD`>4De<DHi<cU5<TDa>44cAT<b<4He@Pda>C<g<cHhA38e
<cM4=3TcA3I1=cLc=c4a@T93<d4gA3I3@cTa>C4f<D4eA4=5=D4a<cM1@C@a<D@b
<3L=<3E5<T53A3E1AT=4<cHc@T4h<d<PCT@=;eQ4=R0P=C<PDT@P<SA5@d94<3Dc
AD8h=cDc@d4dA3I6=dE4A44iA4H`@c=6<T@a<3L`<d8bA3Ti@T8`<D4b<D4f>CA2
<3E63C52=cM3>312@c=4<C<h>3Lf@S54=CHc=4Hg@C0g>C@f=4E3>C51@dE4@D@b
<4@PCT@=;eQ4=b0P=S0PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=dE4A3Dd<D4d
AT<f@c4d>CTa<34iACU4<DI2<c0a<d8f<CA5@cE63DHe=d4e@T=6>C<h=38a>CM6
A3L`<cHhAD@c>DE5<cPh<SM4=cE6@C0c>4Hh=CM6@TE4<3E5@SHf@cI1@R1>A0d_
F4@h820a<CHPDT@P<SA5@d94<3DcAD8iASPf<4I3AD4f@c8h=44g>CHb<3@f<D<h
<CLa=SHb@DHh>3Ph=SHc>D4g<493@dDg3DDd@C0c=S@i=3He@dI6>C52<3Q1=48i
<d=5@SDaA34i@SDh>CDf>C53@c51A30g<cLg<3HdAC8d<dA2<0di@CQ3@d=6=CLi
=C8a<3Hi=c<b=4<h>DHb@SPc=3Q5@cPe@C8f<CPfA4=4<C8b@d=4AS4hAC<`ASDh
>4@=A3Hb@SE4>CDa@cTfA38a<C4i>314@SQ5@dI2ASLh@dHe>C<e<C4fAD4d<c@b
<cM6@DA4>B1>A0d_F4@i820g=21BA20b=4E3@T@`=C=5@SU4ACM2<3I1>3Lf=CE2
AC13@T8d<CLi<CA4<C0iA4E4ACPi=T91<4I5@T=3@c=2=C@=>3Tc@THa<d8`>4Hf
>3H`@SPh=3Ta@T8h=d53=44fA3E6A44g<4<bATDc@c55<d95=dA6=d4a=S4fAD<d
3C=5AS4a>C4b>C55<SD`AT4`@c@f=c8`<DE4=c8PCT@=;eQ4@B0P<STPDT@P<SA5
@d94<3DcAD8`AD8`AS=1A4Di@T4c<D8c@S@g<cQ1<CLh=S51@DDc=SA4>C15@S4a
<SM1<dDi<b1>A0d_F4A2820a<cTPDT@P<SA5@d94<3DcAD8h<SHg<cHi>3Pi<4=5
A38eATA5=SU3AS8i>3U2@SDi@T96>38a@T@f>451>C94@c143C=5@S<gACH`@C54
@S91@DD`@CM3<SPi=C0c<3Ld<3Pa<S14<SH`<451>CQ1=355<C4i=TE1>C4`@c92
=0e2=4@cAC11<312=c@b@S0b=c53<d@d@CTiASPg<CE2@c0e=DDaAS@g<cHgAT=2
=4I4<SHdA4A4=S0cACH==D8bA4Hg=SDg@S8f@TDa>34e<C51<D@b<d<g<T<e=38c
ACHe>4I6A3=3=4E5<3<g<d8b=S8f<3Pi<C953CDc=T=2<492>DI4<TI1=d91ASTi
=TH`=DA6=SPa>4A5=c4aA3Dd84i43BmHA4<P83@c8594838dAD=2A30e<dE2=SI2
AC4c<C<h<C<`<cTb@cTdACA2AS0fA3Tg=d=2@d@i=4I4=SP`<d54<CM4@SDh@Pdb
ASPb=d=1<D8g=d<`<3Hf<dDfACI5=d56@R1>A0d_F4A4820d<b1BA20b=4E3@T@`
=C=5@SHf@TDa<c4c>34c=3Q6AD8h<c8c>30f=d8`=cA2=D4gADH`=THgAT8e=STc
<CHbAS8=@TI6@DDi=c=3A3A2=4I3ACI2=c0a<THi<3@PCT@=;eQ4AB0P>C4PDT@P
<SA5@d94<3DcAD8i@c=2@c8e>DA1AS4dAC52@TDi@CTfA3DaA34a@dHc<cDa<SDe
<SDh=3Tc@T93=c943DHg>C8e<TE1<4@c>4Di=C0f=CA2>3@h=3Pa@T4`>4I3=3Pd
<D=4<T8h<T8eA3@b@S93<4A1=dE5AS0eA@e3AD56<D4`@c@e<C16AS51=38a=SDa
<C<a=S@b=DDbA3<d@cA2=S16@d4eASPb@S0`>3De=34`<S11AT<=>CHPCT@=;eQ4
AR0P<C0`8594838dAD=2A30e<dE2>D<c@T<b=CU4@DHg<cHi@C0d=DA5<cM3@D8b
=cTa@D@d@T<a@cPb@SPc=THf>3E1<Pdg=44g@CTe=dA1<cTg=d8a@T91<c=5=456
ASU3=4@`>30`@CU3=48d<dE6=4@b@T@a=4I2>C0h<TI1=S0=@CDa@cE4=CDc<TH`
@DI3AT4i=313@dDd@d<g<dA5=491A3<f@cA6@c54=cI1>3Q6ACHhADE1>DA2@T<d
3CQ6<4=5>CU2@cI4=c=2@S@f=dDa84i43BmHAC0P83Pg8594838dAD=2A30e<dE2
>3Le<d=1=4@fASL`=S4bASHb@C4f<TDc=S<b@CU5<cA1>4HfAC4b@D@d=dDb>44e
>0d`=S8d=30eAT@c<4I2=3@e=SQ6=C8b>3<e@SDh=T=4=CPi@d@a=CTa<T@d<c0e
ACDg@CM4<CA5@cTi=D<==CHg<T<h<D<b>3<f<S0b=S0f>3Ta@cLa>DDb=4I4<C@i
A355=C=5<3E1=T4g=c<d<3Da<dDb84i43BmHAC4P838i8594838dAD=2A30e<dE2
>3Le<d=1=4@fASPdASTg<SA5=3=2@cTd>DDg<D<h=cQ2>C@f>48c@SDfA3=5=4@P
CT@=;eQ5<R0P=c0PDT@P<SA5@d94<3DcAD8f=dDc<cI1@C@f=3I2<cQ3<cQ1<cHc
=C14@d=6ASM5ASE4=cU4=THa<C=1@TH`=4<h3C54=d=2A4Hg@cL`@d93AT@h<S96
AT<e=SU3=34hAT<d>392=SL`ACI4=cHg<cLcAD<a<TI4@TH`>CU3<Pde@CU3<c95
=dI3=c4e=S4b>48e@b1>A0d_F4Dc820a<SPPDT@P<SA5@d94<3DcAD8i@CQ5=T<h
ATDhA34f@cLiAD8gAS=2<C8d=CPiATI1AS@i=c<c@c8b>4Hb=3@f=C913DH`@C8d
A3I6<3Th=3U4=D@a=4Dg>4I5A4E6=cE5@d8g=DHg>CP`<SM4AS@h@c4b=C4d>34b
@SA6=D4i>0diAST`=3=6ATI1A3Pd=cQ4A3<c=T<b>D@e>3=1@DI6<cHd=cLh<CPa
=C@hA4E1=cDaADHc<3Ph=3A2=cL=<3@e<38d>4<fA452<3A6>D=5A4E5<C<d=4I2
>CM3<T8f>DI4@T8b<c15<cHf<SPc<4<d=38g@SLf=dD`3D8c<3H`<D4e<SE4>C<h
<THPCT@=;eQ5=20P<cTc8594838dAD=2A30e<dE2AC<`<T<a<d@d@DDe@DHe<dA2
=cD`ASQ4@CE1@SLeACE3=4<b<THc<SDe@D@g@C=3@Pdb=SPiAD=6A3M6>3@d=3Da
=d4`=CM4=S96AS<g=3I1>3=3>394A3A5>C=3@DDd@T53>3E4>34d<SA2AD<=@S8a
A496=3DgATA3=SQ5<SE4<S0g=CM3<SLa=d@f<SPi<3U4=C=3=c95@SH`<cM6@D4d
=CTiAT@d=D553D4`A3U3<4He=T@a<CM2<CDhASHa<4@h<D<c<C93<d4iA4Hh=3E6
=496<D4a=38i>CHi<34h>3Tf<CHe=`dh<T4f<dH`ACM2=TA1@THe@D52ATA6<D=5
<4A1<C=3ACE1<D@h=44`<4A6<CLfA394<c8g>CHe=dHd@T@=AT<c=cLaAC53=d8b
@c14<T<b>4Ha>C0b<3<g@cDd>C=6@CQ3>C8f<CI5<S0d<d8i<d51=dI4@SE1=CPd
3DHa>CLfA3Pg<S52AC<a<T<b>3Lf@S=4@C4c=314<CA2AS93@CPhAD4f=CTi=3<f
@c12@CHh=S@iAD95<`e1<DHh@STd@T=3A3PdA4=4@C53@SI1=C@g>3Q6<SH`AS<e
@CPbADDfASHhA3Le=S@`<D8i=DI2=C8gA3<=A4E5A3Hb<c0i@C=1<S8eA4E1ADHa
=4<f=4Da=c<b@C@d@SQ4A4Db>3M1<D93@DA5>4Da=SU4A356<d4b3CM1<cPi<CDd
@D93<48dAD@e=T<hA3Lc@c8b<cQ4=SP`A3A2ACD`>DA5=352=TDd=c<d<d8iAC<g
=d54@Pdc<c@f@c14=SLgAS@`AD8f<dH`=454@CHfATDe=dHfAS<f>4A5@SQ3<D8i
=CE2@DA4=SQ1=cH`<cPg@S<==C=5>C=5=S=4@D@i<3U3@D55=d=2=C56A3E4@cQ6
A3HdASP`=C4f@C@b=3Hf=CQ2@T92<cU1AT8eACHc3D4i<d4d<D@b<cI4=T@bASM2
=THd=4Df@S8hADI6@C53<T@hACDa<C<c@D8c>3Ta=SE1ASHb<STc@D8f=Pe5=CHa
@SLPCT@=;eQ5=B0P>3HPDT@P<SA5@d94<3DcAD8h<c4e<CTaADH`>C4c=CE5=S<a
>D@cASTa<C0e=S53ACA1<T96>3I6=cM4=c52<D4c3CTcASE5<CA5A3I3=d<c@cM3
<S8i@C<gATA5<c@g>48c@d8b@c4`=dI6<cLb@CE3=3<f<cPb<C8`<cHi@`di<C8g
>3HfA44hAC95@cLaACDb<c16=3PcA48f>3Hc>4Hh@TI1A3<a<4I6AS53@D8d<CH`
84i43BmHACHP83Lc8594838dAD=2A30e<dE2>DI3@D4`=c4e=4Hi@T8`<4@iAC52
=4<`@d@bA3H`<CA4AS@cA3Tc@c16<c53AS@b<Pe4@T8`>38a<S=1=c0`>3PgADI5
AC56=SA5ASDb@T4iA4HbA455=cM2>CE4AD4b@DE1=cU4<48e>CTg@d8=@C55@d=6
>3Hc>D<h@c0c>DI5=D@e=D4g<c8PCT@=;eQ5=b0P>30PDT@P<SA5@d94<3DcAD8h
<c4e<CTaADH`>C4c=CE5=S<a>D@cASTa<C0e=S53ACA1<T96>3I6=cM4=c52<D4c
3CTcASE5<CA5A3I3=d<c@cM3<S8i@C<gATA5<c@g>48c@d8b@c4`=dI6<cLb@CE3
=3<f<cPb<C8`<cHi@`e6A314=3Lh@d4h@dHiA3E6=c<g>3U6@T4f>316=3@f<3Hi
=4=3=STc84i43BmHACPP83Lb8594838dAD=2A30e<dE2>DI3@D4`=c4e=4Hi@T8`
<4@iAC52=4<`@d@bA3H`<CA4AS@cA3Tc@c16<c53AS@b<Pe4@T8`>38a<S=1=c0`
>3PgADI5AC56=SA5ASDb@T4iA4@i@cE3=SDi<T<i>3Le@SU2<4=3@dHh=453AS@=
<D=2<30f>CA3A3Hi=S4a>4DhAS0gAC<h84i43BmHACTP83Hg8594838dAD=2A30e
<dE2>DI3@D4`=c4e=4Hi@T8`<4@iAC52=4<`@d@bA3H`<CA4AS@cA3Tc@c16<c53
AS@b<Pe4@T8`>38a<S=1=c0`>3PgADI5AC56=SA5ASDb@T4iA4I4<C8h<T@d=cA6
=SU1=SLiATDd=38`<493=c@=<CT`A38a=CLb=3=2ATDPCT@=;eQ5@B0P=3@PDT@P
<SA5@d94<3DcAD8f<d8c=CU5AC@d<3<`@STh@CLa<4Ha<3M2@cHh@C<fAC8`AD4e
@T<`<SM4=T<b<CLe3DHh>3<d=c55=3Hf<S<cA4@`@SI6<3Ph=T56@S8PCT@=;eQ5
@R0P=C0PDT@P<SA5@d94<3DcAD8f<d8c=CU5AC@d<3<`@STh@CLa<4Ha<3M2@cHh
@C<fAC8`AD4e<d@f@C4i=SH`>3@i3C8i<S56=c@fAD<d=S4a@SPdASH`@D54=cPb
ASHa=c<f=T=4=CL`<THPCT@=;eQ5@b0P=C4PDT@P<SA5@d94<3DcAD8f<d8c=CU5
AC@d<3<`@STh@CLa<4Ha<3M2@cHh@C<fAC8`AD4e=SLb>C<g@SQ5<3U63D94<3A5
ACDf=3@i<SI3<C<d@S@h@THhACU6=452>396AC<d=3<f@d=3<b1>A0d_F4E4820d
=B1BA20b=4E3@T@`=C=5@SHc@S<e>DE5=3@`<c12>CQ1=c4`AS4`=d93=SQ1<cI5
<S15@CDf@TDh@c8gAS0h<T4==C0i=TH`@S8b<cLd=C51=SQ4>DDcAD8a@TA2>4Hh
84i43BmHADDP834e=21BA20b=4E3@T@`=C=5@SPb>DDd=3A2<3DiASTe@C54=356
AD<`=DE1<S91@C4iA3<d@SE1<48c@cM5<S0`<C8=A38a@cLa@CPi@T96<STb=cPh
@c<h<SLgASLb@CA6<DE6>4He<30a=DHg=C4`<DE6<THi@CPhA4@`<D@i3DE1@CTa
AD4b@TE2=c16<SQ1=S94=4Dh<C4a<cPa@d4g>CM3=S0f>4@g>48`=c=1>CI1=3E5
@C@e=c4c@Pe4=48d<3A2@T=3AD52<SHd=3Td=CI5<c<b>D<f<CPb@TE5=3I5<d8g
<dHd<dD`>D8`=C<a@DE5=3=1A3L==DDg<c0d>4I1<S52<THb=c8`@C4b>3Td=SPf
<c=6<316<3A2<SPf=C=1>4<i>DE5@S@h@T<d=C52<48a3CE5ADE5@C0b84i43BmH
ADHP834f<21BA20b=4E3@T@`=C=5@SPb>DDd=3A2<3DiASTe@C54=356AD<`=DE1
<S91@C4iA3<d@SE1<48c@cM5<S0`<C8=A38a@cLa@CPi@T96<STb=cPh@c<h<SLg
ASLb@CA6<DE6>4He<30a=DHg=C4`<DE6<THi@CPhA4@`<D@i3DE1@CTaAD4b@TE2
=c16<SQ1=S94=4Dh<C4a<cPa@d4g>CM3=S0f>4@g>48`=c=1>CI1=3E5@C@e=c4c
@Pe4=48d<3A2@T=3AD52<SHd=3Td=CI5<c<b>D<f<CPb@TE5=3I5<d8g<dHd<dD`
>D8`=C<a@DE5=3=1A3L==DDg<c0d>4I1<S52<THb=c8`@C4b>3Td=SPf<d95>CPd
=3I3>CHhAS0b@DDe=c<b=c4a<C8e<C8d>3Hf3DA3ATE2<C53=D@c<c15A4Hb@CI1
84i43BmHAS0P838a>B1BA20b=4E3@T@`=C=5@SQ6<3I4=SU6<4E3=DDdACI3<THf
<3@b>C=6=D93=cHb@CHa=3Te<S56A4<g<C0f@CH=ASM1<c54>CTb>DHh=T4c<CM5
<4I4<cLeA3E2>3E4=30`@C@e=S14<D<d<3I5<3Ti<d<g<CD`=cDc=SA63DE3=4De
>D<i=3<a>4I3@DE3=CHf<cTh@S0f>355AS16@CDb@D<iACI2<T<i=CU3<C@i<S@a
>4E6AD4d<@e6<48h@C<e<48`A4A3<c=4<cM3<352>452<SA1=CQ5<44i=3Tg=SLf
<3M6=S@h>3Q6@SQ3<D91@CPgA48=A3=4=CTh>3U5<d@g>D<d<c=4=C16AC55<T4f
<TDe>3=4@C@gAT96>3U6=dI4A30g>30e<S8c=495=D513C@h=4H`=34gAS94<d=3
A3U6=c94<cTb=dE4=30i=T4e<3<e>DE5A4I1<TDd@cLa>C8gADE4=3Q6<D4f>0e1
AS0g<DE5AT<b@CM5A3=5@C4i<44b>30g<SM3ADI4=C12=d4h@S4e@dI5<CU1@SL`
=SM4A3Lf@c0f@dD==3Hf<cLg>CP`@S4gA44`=d4h84i43BmHAS4P834e=B1BA20b
=4E3@T@`=C=5@SPb>DDd=3A2<3DiASTe@C54=356AD<`=DE1<S91@C4iA3<d@SE1
<48c@cM5<S0`<C8=A38a@cLa@CPi@T96<STb=cPh@c<h<SLgASLb@CA6<DE6>4He
<30a=DHg=C4`<DE6<THi@CPhA4@`<D@i3DE1@CTaAD4b@TE2=c16<SQ1=S94=4Dh
<C4a<cPa@d4g>CM3=S0f>4@g>48`=c=1>CI1=3E5@C@e=c4c@Pe4=48d<3A2@T=3
AD52<SHd=3Td=CI5<c<b>D<f<CPb@TE5=3I5<d8g<dHd<dD`>D8`=C<a@DE5=3=1
A3L==DDg<c0d>4I1<S52<THb=c8`@C4b>3Td=SPf<cU1<SU2<d@e<T96@CU2<dD`
AT<g@SPg>CTi<34d=48a3CM4AT4a>356<C<PCT@=;eQ6<R0P<C<e8594838dAD=2
A30e<dE2>3Le<d=1=4@f@cLi<SDc<S<eADHd<cLbA38a<44aAC=5<3Pf=T@h@d94
>C8`=C16>0dbAS12<DDfA44`=cDfAD<hAS0b@C0h<STd>3Q1A34dAT8g@CI6@CTg
=3@g@cE2<C53@DHd<D8`=c@f<C@=@T8dATDa@T56ASPf=C=1A3@h<3E2AC11<SI3
<DE1<496@c14<CPd@CU4ATE3>3E4A3LiA3M5A38`<3Df3CU2<SE3@C94=D@b=d=1
A4Hf<CLf<4Dc>D@aAC@a@d=4@CTg>C4h@CE2=D55=3Li=CE2<452<S<a=d<h@@e5
=CH`=SHg=S53A3PbAC16<4=1<STb<T52=4@b@DDPCT@=;eQ6<b0P<C@b8594838d
AD=2A30e<dE2>3Le<d=1=4@f@cLi<SDc<S<eADHd<cLbA38a<44aAC=5<3Pf=T@h
@d94>C8`=C16>0dbAS12<DDfA44`=cDfAD<hAS0b@C0h<STd>3Q1A34dAT8g@CI6
@CTg=3@g@cE2<C53@DHd<D8`=c@f<C@=@T8dATDa@T56ASPf=C=1A3@h<3E2AC11
<SI3<DE1<496@c14<CPd@CU4ATE3>3E4A3LiA3M5A38`<3Df3CU2<SE3@C94=D@b
=d=1A4Hf<CLf<4Dc>D@aAC@a@d=4@CTg>C4h@CE2=D55=3Li=CE2<44`AC@f=SU5
=`e1<S8i=C@f<cA3ADDf@S=6=DA2>D<i>D94ATE2<SH`<CPaASP`@SI6>4I4@R1>
A0d_F4Hd820a<cDPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I3=cTb=C<b<cE5AS@c
=c94<S4`@C55<dD`>3HfA3Q3@T@i<S0e<4Hh3C96<48aACI4@C0g=CI5@cQ6<391
<3Pb>C@h>454<CA6@SM1=TI1>CLd=3M3=D8a<D=1AS@a@S0g=3Ha=0e2@SA6AC52
@DI6>3He<d54=3P`=D95<44b=T<aAD4`@TI3<4@a>3A1>DA6AD<h=DA4=cU4=dE4
<S0`=CH=>D8b=D=1<T@eA38g@d54ASHa=cH`AC<iA355=353@dA1>CLi<CQ1=D8e
@DDd=cTe=D8`=CE6<S0f<D8f3DA5ATHh@c92<cI4@D96<T93<3Tb=dDg<3U6ACDc
<B1>A0d_F4He820b=R1BA20b=4E3@T@`=C=5@SI3<S55=d@f@c@i@S4`=c4i=T56
AD8h=4<c@S4i<d<i=cL`<4<a=C4c84i43BmHASHP83<i8594838dAD=2A30e<dE2
>D=2<STg<T=2<3TeA3H`<4E4@d55<cHc=DDh<38e>48hAD4b<48cAST`AD4e<SDb
A@e6<4<b@SI5>3L`@SHd<CPhASDPCT@=;eQ6=b0P<C0`8594838dAD=2A30e<dE2
>D=2<STg<T=2<3U2ASHf=4De=DHg=3Pe<351ACI2>4Hc<4Hc<CPi>DA4ASE1<c0d
<`de=D96AS51=4De=4E4>3Ta@T@a@T@c=c0`=3@i<C@eAS0b@c0e=C53<S56<c92
>C4h=d8a@cQ3AD8a=DH=<d=3@THf=SHb<SM2=4Hh@S14>CL`AT8e=TE1<3U2=4@g
A44g>C@g@TA6<c0hA38a<c8e@THd>D@iAD@f3D@e>DHb<SI3ASU3@dHd>3PcAS92
84i43BmHASPP838g8594838dAD=2A30e<dE2>D=2<STg<T=2<3U4=D4e=C0`<3Ph
=d8d=3=4@STf<C=2@d<a=3Td@cE2A21>A0d_F4Hi820i<B1BA20b=4E3@T@`=C=5
@SU3@S8i=c93@S0i>4<h=TI1<c8`@TA6=4=4@D52@C93ADA2A3Pf@T55@S<gAS=6
<3P=<3I2@S95>34a@c4e<4@f@dHc=c@a<D<g<D94A4He<dI5@T8e>3<a>C0c<c8e
=DDh>CHd=S8h>C=6=S913CA1<SU4ACE2=c<`<T92>4I3<STg=dE4>44hASP`>C54
=48`=4=4A4DaACU5>34c<S4g@C15AS<a>CTg@@e2>B1>A0d_F4I1820b=B1BA20b
=4E3@T@`=C=5@SU3@S8i=c93@S0i=SPh<CU1<SE6<T8e@D@fAS@eA396>316>C@g
=21>A0d_F4I2820a<c8PDT@P<SA5@d94<3DcAD8i@d8b>CLb@d8`>CE4=S0f<c@a
@D4`@S56=48f=3Q2<T8`>3Tg=3Dc>34c=c8a=34`3DE3=dHa=4@h=C@e>3PiASTe
<C53=c8a<TA4<SA5@TI4@T4c=455=d4f@cHf<DHaADI2@D8e<3LhA3Ti>0d`<c=4
>3H`=38d>D4hA3=3<T<c@SPg<CE6>3M5<SL`<SPi=SLe=cLc=S@b<D4`A48h=S8i
<CU2<c0gASP=<C8`A356AS=3>C0f<c@f@S@i@T<f>3@b=30cAS14=S16<cU4<C0g
A3M3>DA1@dHiAT@hAC<b@DE1A3A13C8i<c@i=THi<cTi=CLe<c<eAT8i=cM4<B1>
A0d_F4I3820h>21BA20b=4E3@T@`=C=5@SU3@S8i=c93@S0i<cQ4<STg=cDb@cTc
=4Hf>CQ6<c96<CDh=TA1A4@f<D<`A4@i<D@=<c0b=cM4<34b@d95<4=3>3Df>CI5
@T@a<3L`=C8d<d@`=D8g@TDg<cU2@cPbA3Q4@c@f=3He=3Dc>CTi3D55<CU2<DI4
@T8b=C13>D@d>CHd@d96<TDh<352=T4`=T=3ASU2<SHe=TE5>CA2<c=6=D<i=3A6
84i43BmHAT@P83@e8594838dAD=2A30e<dE2>D=2<STg<T=2<3Tg=cHi=4<g=C4i
=4A6ATA6A3Q1>C4f@TA5=d56@d4c=3@b@TDgAPdcACPh>4E2AT<bASTi<3@h<S4f
ASE5<cTf=c8e<d4PCT@=;eQ6AB0P>38PDT@P<SA5@d94<3DcAD8i@d8b>CLb@d8`
=SLe<c8f@cLg@CM3@D8g=cE6@CHaATHi=cHgAD4e=3@g=DI4@D543C4c=S8eAD<f
<CLgAT@f=CTh=4=1@C8i002Q0<00ndDf<c95<DDb<4<b<391>4@h<C4h@DDc<48`
>DHc@SPh<dHc=DH=<4E1=4Da>3<b=CE6A30h=c8iASU6<CPh>CLe@C<g>C4b<d@b
@C<f>C0a>D<PCT@=;eQ6AR0P<cTPDT@P<SA5@d94<3DcAD8i@d8b>CLb@d8`>CE4
=S0`<dI5=dDi@c4c<34fA495>D=4@c<b=3Hb<c0g=3Q1AS@c3C4h<cM2=CLcAS4i
=SM6A3Pa=b1>A0eUKV@=IFiT3G1eM0e`MG@=I7E`82m6KfidCV5]IB1WIG@PIGQS
J21TIFIYKVEVKfid871_L0dU9DE^I59ULfmeLV=U80d=002Q0<01bbmOGem6CS4P
;dMUKVEfHB0_AfE^IGIQ86AeL21VJFiTIVm^M21TMG0P;d=XHG9CM79YKVMc86]^
KgM^87]RIFMYKR13J65bDgAbJFiWLb0_@FAYIG9ULfUc86]^KgM^87/]<B1mNbda
OB1YIVE/LfDPIFiTOB1kL6m`82daOB1YIVE/LfDPLVH=<21YI0da86IT3C0P<CDe
87AbHFicK65dI@dc<30P;C<`<21cHfaY3BDUAFiTDfEdMG0P3BDU@VEWJFi@HFMU
DfEdMG0P3G1]3BDUAFiTD65WIE=UM7E`3Bm4IGIYHfEBAd8PLf=c3C0P<20`86Hc
3C0^<C8e<20`;S4b=C0PLg0=830PK6<=838PK6X=E21cH@dUL65WIB1bIF=d>R0a
=SDP=CLh83@d>20g<c<P3G=dK@d`830P<21V<`e^L0de>2he>C<e83Dh;SDi<cDP
<C8a<2hf=cHh83Hf<bha=SPh86E`3FAU3C0P<20`86Hc3C4g;S<f<C0P<CL^<cHa
<21cL0da<Bhe86a]3B0`86aZ3Fi`3CDh;SDi<cDP=CP^=CTc=B0a<S4`;SHg=SPP
=SHc;S4f>3PPIG0=I7<=LWA]3@00X@3003ecM6d=<20`830PIS<=KW0==CP^=CTc
=B0e>2he>C<e838c=3H^<3Pg>20f=cH^<CPi=B1UL0eTL`ebM6d=002Q0<00M7=d
K@d`830P<21V<`e^L0de>2he>C<e83Dh;SDi<cDP<C8`<Rhh=S@a834d=CL^=3<e
=R1UL0eTI@d`830P<21V<`e^L0de>2he>C<e83Dh;SDi<cDP<C8`<Rhh=S@a834d
=CL^=3<e=R1UL0eTL`ebM6d=0:40`01dLgA]3C0P<20`86Hc3Fi`3CDh;SDi<cDP
=CP^=CTc=B0b<c<h;S8g=C8P<C@e=bhd<cDf86E`3FAU3C0P<20`86Hc3Fi`3CDh
;SDi<cDP=CP^=CTc=B0b<c<h;S8g=C8P<C@e=bhd<cDf86E`3FAc3G9dK@d0X@30
04YcM6d=<2he=c0c830^=CL`<b0`;SDg<3<PIS<=KW0==CP^=CTc=B0e>2he>C<e
83Le;S8f=CLP=SHc;S4f>3PPIG0=I7<=LWA]3@2Q0<00BW=dK@d`;SDg<3<P<2he
=c0c830^=CL`<b1V<`e^L0de>2he>C<e83Dh;SDi<cDP=SL^=3Dc834d=CL^=3<e
=R1UL0eTL`ebM6d=0:40`01=LgA]3C0^=CL`<b0`;SDg<3<P<2he=c0c86Hc3Fi`
3CDh;SDi<cDP=CP^=CTc=B0a<S0b;SPf=34P<S8f=2hg<S<a86E`3FAc3G9dK@d0
0:40`01=LgA]3C0^=CL`<b0`;SDg<3<P<2he=c0c86Hc3Fi`3CDh;SDi<cDP=CP^
=CTc=B0b<c<h;S8g=C8P<S8f=2hg<S<a86E`3FAc3G9dK@d00:40`01:LgA]3C0^
=CL`<b0`;SDg<3<P<2he=c0c86Hc3Fi`3CDh;SDi<cDP=CP^=CTc=B0f=bhd=C<P
<S8f=2hg<S<a86E`3FAc3G9dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^
<C8e<21cL0d`830P<21V<`d00:40`01LLgA]3C8`>2hc<c8c86IdL`d_GemOATha
834^=B0a;SDPKFH=<20`830PIS<=AR1cH@db=SHh;S0a<C@P<CDd>Bhd=c4c86ed
3BQf:B0PLfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc
3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00G7=dK@da=CH^<S@i<R1V
M7<=;emOGdI><B0a;SDP<Bhe86eV3C0P<20`86Hc3DHPLf4=<SPf<bhc<S8i834d
<3H^<S@b>B1]M0dXKRTP87=XKgL=E21cH@ebM6d=0:40`004LWA]3@2Q0<009g=d
K@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@3003]cM6d=
<20`830PIS<=AR1cH@db>3<g;S8h<C@P<CHg>Bhf=cTPKG@=:4dY821cJ6mg3E@P
Lf4=LWA]3@00X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b
=C0PLg0=<20`830PIS<=002Q0<00Fg=dK@db<3P^<c<b<b1VM7<=;emOGdI><B0a
;SDP<Bhe86eV3C0P<20`86Hc3DHPLf4=<SHd<Bhi=STh83Le=Bhb<3@e86ed3BQf
:B0PLfQ_M`eD87=Q3G9dK@d00:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`
;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@30071cM6d=<CDf;S8d>C8PIWAc
3BmOGem6CS4P<Bhe834^=B1]IPd`830P<21V<`e687=Q3C8h<cH^<SPa=20f<C4^
>CLf<B1]M0dXKR/a:B1K<C<f;SLf834e=Rhb<B0`85dPN7=XKgL=E21cH@ebM6d=
0:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P
<20`86Hc3@00X@3003]cM6d=<20`830PIS<=AR1cH@db>34a;S8c>CPP>3Pe;S@a
<S8PKG@=:4dY821cJ6mg3E@PLf4=LWA]3@00X@3000AbM6d=0:40`00WLgA]3C0P
<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00FW=dK@db<3P^
<c<b<b1VM7<=;emOGdI><B0a;SDP<Bhe86eV3C0P<20`86Hc3DHPLf4==3Hg;SD`
<CLP=c0c;S4b<C@PKG@=:7HY821cJ6mg3E@PLf4=LWA]3@2Q0<00179dK@d0X@30
02McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`01^
LgA]3C4e=Rhb=3Tb86IdL`d_GemOATha834^=B0a;SDPKFH=<20`830PIS<=AR1c
H@df=S4^>34c<R0e=CT^>3Tc86ed3BQ^:c4Y85/a<cH^=cHP<CDf;S8a830PGB1h
LfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e
<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00CW=dK@d`830P<21V<`e687=Q3CHc
=Bhg=c4g83Pc<bhc<STa86ed3BQ=;C4Y85/a>3@^=c4P>3P^>34P<21M87QcJ6mg
3E@PLf4=LWA]3@2Q0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^
<C8e<21cL0d`830P<21V<`d00:40`01KLgA]3C8`>2hc<c8c86IdL`d_GemOATha
834^=B0a;SDPKFH=<20`830PIS<=AR1cH@dd>30^=C8b=B0a=C8c;S@b>CPPKG@=
:7HY821cJ6mg3E@PLf4=LWA]3@00X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc
3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00FW=dK@da=CH^<S@i<R1V
M7<=;emOGdI><B0a;SDP<Bhe86eV3C0P<20`86Hc3DHPLf4==SLe;SPc=20a<cP`
;S8`<C<PKG@=:6hY821cJ6mg3E@PLf4=LWA]3@2Q0<00179dK@d0X@3002McM6d=
<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`01?LgA]3C0P
<20`86Hc3DHPLf4==S@h;SLi<SDP<CHe<bhf<cLd86ed3BQ=;C4Y85/a>3@^=c4P
>3P^>34P<21M87QcJ6mg3E@PLf4=LWA]3@00X@3000AbM6d=0:40`01?LgA]3C0P
<20`86Hc3C4g;S<f<C0P<CL^<cHa<21cL0e^L0dc<cL`;S4c<SPP<21]M0dc<cL`
;S4c<SPP<SHh<Rhb=cPPK6T=I7<=LWA]3@00X@3002McM6d=<20`830PIS<=<2ha
<SD`830^<C8e<21cL0d`830P<21V<`d00:40`02HLgA]3C8`>2hc<c8c86IdL`d_
GemOATha834^=B0a;SDPKFH=<20`830PIS<=AR1cH@dc=C4c;S<f<C<P<S0g<2hc
<38PKG@=:69_MFiTHG9i:B1K<CT`;SDh834h>Bhc=R0a>38^<c@P<CPb;S<d834h
>2ha=20a=c8^>3PP<C8`;SL`830PGB1hLfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=
0:40`00:M6EbKFU^HGAU3@2P0;l0X02n09X0003oSj0000000XX3j00000@00000
04P000180000400P00<02000000000001J:hW0000002RP?X000000::0n/0000`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7o
POn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7o
WOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7o
POn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7o
POoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0h
POn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7o
WOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7o
POn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7o
POnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087o
POn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7o
POn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo
03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7o
POnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087o
POn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7o
POn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0
POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7o
POn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087o
b?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7o
POn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0
POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKo
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7o
POn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0
POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7o
POn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7o
POn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7o
e_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87o
POn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigo
o@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7o
POn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7o
WOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7o
POn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7o
POoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0h
POn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7o
WOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7o
POn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7o
POnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087o
POn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7o
POn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo
03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7o
POnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087o
POn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7o
POn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0
POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7o
POn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087o
b?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7o
POn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0
POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKo
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7o
POn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0
POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7o
POn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7o
POn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7o
e_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87o
POn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigo
o@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7o
POn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7o
WOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7o
POn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7o
POoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0h
POn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7o
WOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7o
POn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7o
POnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087o
POn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7o
POn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo
03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7o
POnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087o
POn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7o
POn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0
POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7o
POn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087o
b?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7o
POn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0
POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKo
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7o
POn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0
POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7o
POn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7o
POn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7o
e_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87o
POn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigo
o@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7o
POn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7o
WOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7o
POn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7o
POoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0h
POn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7o
WOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7o
POn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7o
POnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087o
POn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7o
POn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo
03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7o
POnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087o
POn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7o
POn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0
POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7o
POn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087o
b?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7o
POn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0
POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKo
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7o
POn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0
POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7o
POn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1oigoo@21olSo04:1ohSon`21oh7oPOn1omGoo@21oh7o
POo?oo/0POn1oh7oPOoEood0POn1oh7ocook087oPOn1oh7oeOom087ob?l0@X7o
R_oi087oPOn1oh7oeOom087oPOn1om7on@21oh7oPOn1omGoo@21oh7oPOoAooT0
POn1oh7oPOoEood0POo8o`12POn<ooL0POn1oh7oPOoEood0POn1oh7odoog087o
POn1oh7oeOom087oPOn1om?om`21oh7oPOn1omGoo@21olSo04:1ohoom021oh7o
POn1omGoo@21oh7oPOoFoo@0POn1oh7oPOoEood0POn1oh7oe_od087oPOn1oh7o
eOom087ob?l0@X7oT?oc087oPOn1oh7oeOom087oPOn1omOol`21oh7oPOn1omGo
o@21oh7oPOoGoo<0POn1oh7oPOoEood0POo8o`12POn@oo<0POn1oh7oPOoEood0
POn1oh7oeooc087oPOn1oh7oeOom087oPOn1omOol`21oh7oPOn1omGoo@21olSo
0561oi3onP01oool087oPOn1oh7oeOom087oPOn1omOonP01oool087oPOn1oh7o
eOom087oPOn1omOonP01oool087oPOn1oh7oeOom087ob?l0CX7oT?ol0?goo021
oh7oPOn1omGoo@21oh7oPOoGoo`0oOol087oPOn1oh7oeOom087oPOn1omOoo03m
oo`0POn1oh7oPOoEood0POo8o`1APOn@o`400?[oo021oh7oPOn1omGoo@21oh7o
POoGo`400?[oo021oh7oPOn1omGoo@21oh7oPOoGo`400?[oo021oh7oPOn1omGo
o@21olSo04:1ohOoo021oh7oPOn1omGoo@21oh7oPOo>oo`0POn1oh7oPOoEood0
POn1oh7oc_ol087oPOn1oh7oeOom087ob?l0BX7oc_ok0<3oo021oh7oPOn1omGo
o@21oh7oUOok0<3oo021oh7oPOn1omGoo@21oh7oUOok0<3oo021oh7oPOn1omGo
o@21olSo05J1om[oo03mooD0`ool087oPOn1oh7oeOom087oPOnQoo`0oOoe0<?o
o021oh7oPOn1omGoo@21oh7oXOol0?gom@33oo`0POn1oh7oPOoEood0POo8o`1^
POoJoo`0o_oc0>[oo@3Ooo`0POn1oh7oPOomoo/0goom087oPOnQoo`0o_oc0>[o
o@3Ooo`0POn1oh7oPOomoo/0goom087oPOnQoo`0o_oc0>[oo@3Ooo`0POn1oh7o
POomoo/0goom087ob?l0M87of_ol007ooo40joom0=ooo021oh7oPOn1o`7oooT0
goom087oPOnQoo`00Oool@3[ood0gool087oPOn1oh7o0Ooon@3Oood0POn1oj7o
o001oooa0>_oo@3Ooo`0POn1oh7oPOl1oooi0=ooo@21olSo07B1om[oo000oo`0
o?oi0>coo@3Ooo`0POn1oh7oPOog0=ooo@21oh7oXOol003oo03looT0k?om0=oo
o021oh7oPOn1ooL0goom087oPOnQoo`00?ol0?con@3/ood0gool087oPOn1oh7o
m`3Oood0POo8o`1XPOoJooP0n?ok0>coo@3Ooo`0POn1oh7oQ?od0=ooo@21oh7o
XOoh0?Son`3/ood0gool087oPOn1ohCom03Oood0POn1oj7on03hoo/0k?om0=oo
o021oh7oPOn4oo@0goom087ob?l0J87of_oi0?Koo03/ood0gool087oPOn1ohGo
l`3Oood0POn1oj7on@3foo`0k?om0=ooo021oh7oPOn5oo<0goom087oPOnQooT0
m_ol0>coo@3Ooo`0POn1oh7oQOoc0=ooo@21olSo06R1om[onP3eoo/0kOom0=oo
o021oh7oPOn5oo<0goom087oPOnQooX0mOok0>goo@3Ooo`0POn1oh7oQOoc0=oo
o@21oh7oXOoj0?Gon`3]ood0gool087oPOn1ohGol`3Oood0POo8o`1gPOoJooX0
m?ol0>goo@3Ooo`0POn1oh7oQOoj007ooo`0goom087oPOnQooX0m?ol0>goo@3O
oo`0POn1oh7oQOoj007ooo`0goom087oPOnQooX0m?ol0>goo@3Ooo`0POn1oh7o
QOoj007ooo`0goom087ob?l0M87of_ok0??oo03]ood0gool087oPOn1ohGoo03m
oo`0goom087oPOnQoo/0lool0>goo@3Ooo`0POn1oh7oQOol0?goo03Oood0POn1
oj7on`3coo`0kOom0=ooo021oh7oPOn5oo`0oOol0=ooo@21olSo07N1om[on`3c
oo`0kOom0=ooo021oh7oPOn5o`400?[oo03Oood0POn1oj7on`3coo`0kOom0=oo
o021oh7oPOn5o`400?[oo03Oood0POn1oj7on`3coo`0kOom0=ooo021oh7oPOn5
o`400?[oo03Oood0POo8o`1^POoJoo`0l_ol0>goo@3Ooo`0POn1oh7oPOoloo`0
goom087oPOnQoo`0l_ol0>goo@3Ooo`0POn1oh7oPOoloo`0goom087oPOnQoo`0
l_ol0>goo@3Ooo`0POn1oh7oPOoloo`0goom087ob?l0M87of_ol0?;oo03]ood0
gool087oPOn1ol?on`30oo`0goom087oPOnQoo`0l_ol0>goo@3Ooo`0POn1oh7o
`ook0<3oo03Oood0POn1oj7oo03boo`0kOom0=ooo021oh7oPOo3oo/0`?ol0=oo
o@21olSo0821om[oo03boo`0kOom0=ooo021oh7oPOo?oo`0oOoe0<?oo03Oood0
POn1oj7oo03boo`0kOom0=ooo021oh7oPOo?oo`0oOoe0<?oo03Oood0POn1oj7o
o03boo`0kOom0=ooo021oh7oPOo?oo`0oOoe0<?oo03Oood0POo8o`2<POoJoo`0
l_ol0>goo@3Ooo`0POn1oh7ocool0?kol`3Zood0gool0=ooo@21oh7oXOol0?;o
o03]ood0gool087oPOn1olooo03noo<0j_om0=ooo03Oood0POn1oj7oo03boo`0
kOom0=ooo021oh7oPOo?oo`0o_oc0>[oo@3Ooo`0goom087ob?l0Sh7of_ol0?;o
o03jon<0k?ol087oPOn1olooo001oooa0>_oo@3Ooo`0goom087oPOnQoo`0l_ol
0?[oh`3/oo`0POn1oh7ocool007ooo40joom0=ooo03Oood0POn1oj7oo03boo`0
n_oS0>coo021oh7oPOo?oo`00Oool@3[ood0gool0=ooo@21olSo09R1om[oo03b
oo`0n_oS0>coo021oh7oPOo?oo`00?ol0?con@3/ood0gool0=ooo@21oh7oXOol
0?;oo03jon<0k?ol087oPOn1olooo000oo`0o?oi0>coo@3Ooo`0goom087oPOnQ
oo`0l_ol0?[oh`3/oo`0POn1oh7ocool003oo03looT0k?om0=ooo03Oood0POo8
o`2<POoJoo`0l_ol0?[oh`3/oo`0POn1oh7ocooh0?Son`3/ood0gool0=ooo@21
oh7oXOol0?;oo03jon<0k?ol087oPOn1oloon03hoo/0k?om0=ooo03Oood0POn1
oj7oo03boo`0n_oS0>coo021oh7oPOo?ooP0n?ok0>coo@3Ooo`0goom087ob?l0
S87of_ol0?;oo03jon<0k?ol087oPOn1oloon@3foo`0k?om0=ooo03Oood0POn1
oj7oo03boo`0n_oS0>coo021oh7oPOo?ooT0m_ol0>coo@3Ooo`0goom087oPOnQ
oo`0l_ol0?[oh`3/oo`0POn1oh7ocooi0?Koo03/ood0gool0=ooo@21olSo08b1
om[oo03boo`0kOom0=ooo021oh7oPOo?ooX0mOok0>goo@3Ooo`0goom087oPOnQ
oo`0l_ol0>goo@3Ooo`0POn1oh7ocooj0?Gon`3]ood0gool0=ooo@21oh7oXOol
0?;oo03]ood0gool087oPOn1oloonP3eoo/0kOom0=ooo03Oood0POo8o`2<POoJ
oo`0l_ol0>goo@3Ooo`0POn1oh7ocooj0?Coo03]ood0gool0=ooo@21oh7oXOol
0?;oo03]ood0gool087oPOn1oloonP3doo`0kOom0=ooo03Oood0POn1oj7oo03b
oo`0kOom0=ooo021oh7oPOo?ooX0m?ol0>goo@3Ooo`0goom087ob?l0S87of_ol
0?;oo03]ood0gool087oPOn1oloon`3coo`0kOom0=ooo03Oood0POn1oj7oo03b
oo`0kOom0=ooo021oh7oPOo?oo/0lool0>goo@3Ooo`0goom087oPOnQoo`0l_ol
0>goo@3Ooo`0POn1oh7ocook0??oo03]ood0gool0=ooo@21olSo08b1om[oo03b
oo`0kOom0=ooo021oh7oPOo?oo/0lool0>goo@3Ooo`0goom087oPOnQoo`0l_ol
0>goo@3Ooo`0POn1oh7ocook0??oo03]ood0gool0=ooo@21oh7oXOol0?;oo03]
ood0gool087oPOn1oloon`3coo`0kOom0=ooo03Oood0POo8o`2<POoJoo`0l_ol
0>goo@3Ooo`0POn1oh7ocool0?;oo03]ood0gool0=ooo@21oh7oXOol0?;oo03]
ood0gool087oPOn1olooo03boo`0kOom0=ooo03Oood0POn1oj7oo03boo`0kOom
0=ooo021oh7oPOo?oo`0l_ol0>goo@3Ooo`0goom087ob?l0S87of_ol0?;oo03]
ood0gool087oPOn1olooo03boo`0kOom0=ooo03Oood0POn1oj7oo03boo`0kOom
0=ooo021oh7oPOo?oo`0l_ol0>goo@3Ooo`0goom087oPOnQoo`0l_ol0>goo@3O
oo`0POn1oh7ocool0?;oo03]ood0gool0=ooo@21olSo0::<ooT0iooj0?Soo03b
oo`0kOom0=ooo021oh7oPOo?oo`0l_ol0>goo@3Ooo`0goom087oPOoCooT0iooj
0?Soo03boo`0kOom0=ooo021oh7oPOo?oo`0l_ol0>goo@3Ooo`0goom087oPOoC
ooT0iooj0?Soo03boo`0kOom0=ooo021oh7oPOo?oo`0l_ol0>goo@3Ooo`0goom
087ob?l0XX_onP3Woo/0mool0?;oo03]ood0gool087oPOn1olooo03boo`0kOom
0=ooo03Oood0POn1om;onP3Woo/0mool0?;oo03]ood0gool087oPOn1olooo03b
oo`0kOom0=ooo03Oood0POn1om;onP3Woo/0mool0?;oo03]ood0gool087oPOn1
olooo03boo`0kOom0=ooo03Oood0POo8o`2RRooi0>Son`3goo`0l_ol0>goo@3O
oo`0POn1oh7ocool0?;oo03jon<0k?ol0=ooo@21oh7od_oi0>Son`3goo`0l_ol
0>goo@3Ooo`0POn1oh7ocool0?;oo03jon<0k?ol0=ooo@21oh7od_oi0>Son`3g
oo`0l_ol0>goo@3Ooo`0POn1oh7ocool0?;oo03jon<0k?ol0=ooo@21olSo0::;
ooT0jOoj0?Ooo03boo`0kOom0=ooo021oh7oPOo?oo`0l_ol0?[oh`3/oo`0goom
087oPOoBooT0jOoj0?Ooo03boo`0kOom0=ooo021oh7oPOo?oo`0l_ol0?[oh`3/
oo`0goom087oPOoBooT0jOoj0?Ooo03boo`0kOom0=ooo021oh7oPOo?oo`0l_ol
0?[oh`3/oo`0goom087ob?l0XX[onP3Yoo/0m_ol0?;oo03]ood0gool087oPOn1
olooo03boo`0n_oS0>coo03Oood0POn1om7onP3Yoo/0m_ol0?;oo03]ood0gool
087oPOn1olooo03boo`0n_oS0>coo03Oood0POn1om7onP3Yoo/0m_ol0?;oo03]
ood0gool087oPOn1olooo03boo`0n_oS0>coo03Oood0POo8o`2RR_oi0>_onP3f
oo`0l_ol0>goo@3Ooo`0POn1oh7ocool0?;oo03jon<0k?ol0=ooo@21oh7odOoi
0>_onP3foo`0l_ol0>goo@3Ooo`0POn1oh7ocool0?;oo03jon<0k?ol0=ooo@21
oh7odOoi0>_onP3foo`0l_ol0>goo@3Ooo`0POn1oh7ocool0?;oo03jon<0k?ol
0=ooo@21olSo0::9ooX0jook0?Goo03boo`0kOom0=ooo021oh7oPOo?oo`0l_ol
0>goo@3Ooo`0goom087oPOo@ooX0jook0?Goo03boo`0kOom0=ooo021oh7oPOo?
oo`0l_ol0>goo@3Ooo`0goom087oPOo@ooX0jook0?Goo03boo`0kOom0=ooo021
oh7oPOo?oo`0l_ol0>goo@3Ooo`0goom087ob?l0N8Won@3/oo/0POn1oh7oPOo[
oo`0l_ol0>goo@3Ooo`0goom087oPOo@ooT0k?ok087oPOn1oh7ojool0?;oo03]
ood0gool0=ooo@21oh7od?oi0>con`21oh7oPOn1on_oo03boo`0kOom0=ooo03O
ood0POo8o`1hR?oj0>gon`21oh7oPOn1on[oo03boo`0kOom0=ooo03Oood0POn1
oloonP3]oo/0POn1oh7oPOoZoo`0l_ol0>goo@3Ooo`0goom087oPOo?ooX0kOok
087oPOn1oh7oj_ol0?;oo03]ood0gool0=ooo@21olSo07R8ooX0kOok087oPOn1
oh7oj_ol0?;oo03]ood0gool0=ooo@21oh7ocooj0>gon`21oh7oPOn1on[oo03b
oo`0kOom0=ooo03Oood0POn1oloonP3]oo/0POn1oh7oPOoZoo`0l_ol0>goo@3O
oo`0goom087ob?l0N8Son@3_ooX0POn1oh7oPOoZoo`0l_ol0>goo@3Ooo`0goom
087oPOo?ooT0kooj087oPOn1oh7oj_ol0?;oo03]ood0gool0=ooo@21oh7ocooi
0>oonP21oh7oPOn1on[oo03boo`0kOom0=ooo03Oood0POo8o`1hQooj0>oon`21
oh7oPOn1onWoo03boo`0kOom0=ooo03Oood0POn1olkonP3_oo/0POn1oh7oPOoY
oo`0l_ol0>goo@3Ooo`0goom087oPOo>ooX0kook087oPOn1oh7ojOol0?;oo03]
ood0gool0=ooo@21olSo08Z7ooT0lOoj087oPOn1oi_on@3WooX0n?ol0?;oo03]
ood0gool0=ooo@21oh7oc_oi0?7onP21oh7oPOnKooT0iooj0?Soo03boo`0kOom
0=ooo03Oood0POn1olkon@3aooX0POn1oh7oVooi0>OonP3hoo`0l_ol0>goo@3O
oo`0goom087ob?l0RXKonP3aoo/0POn1oh7oVOoj0>Oon`3goo`0l_ol0>goo@3O
oo`0goom087oPOo=ooX0lOok087oPOn1oiWonP3Woo/0mool0?;oo03]ood0gool
0=ooo@21oh7ocOoj0?7on`21oh7oPOnIooX0iook0?Ooo03boo`0kOom0=ooo03O
ood0POo8o`2:Q_oi0?;on`21oh7oPOnIooT0j?ok0?Ooo03boo`0kOom0=ooo03O
ood0POn1olgon@3boo/0POn1oh7oVOoi0>Son`3goo`0l_ol0>goo@3Ooo`0goom
087oPOo=ooT0l_ok087oPOn1oiWon@3Xoo/0mool0?;oo03]ood0gool0=ooo@21
olSo09k[o`2AWOoi0??onP21oo?o0021oh7oZ?oi0>WonP3goo`0l_ol0>goo@3O
oo`0goom087o/_l0TIgon@3cooX0POoco`00POn1ojSon@3YooX0mool0?;oo03]
ood0gool0=ooo@21ok;o096MooT0looj087olol0087oPOnXooT0jOoj0?Ooo03b
oo`0kOom0=ooo03Oood0POo8o`2NlOodTJ;onP3coo/0POohoo@0POn1ojgonP3Y
oo/0m_ol0?;oo03]ood0gool0=ooo@21okSom96RooX0look087on?od087oPOn]
ooX0jOok0?Koo03boo`0kOom0=ooo03Oood0POnhooBAX_oj0??on`21ooSom021
oh7o[Ooj0>Won`3foo`0l_ol0>goo@3Ooo`0goom087ob?l0W_7om96RooT0mOoj
087on?od087oPOn]ooT0jooj0?Koo03boo`0kOom0=ooo03Oood0POnhooBAX_oi
0?GonP21ooSom021oh7o[Ooi0>_onP3foo`0l_ol0>goo@3Ooo`0goom087o^?od
TJ;on@3eooX0POohoo@0POn1ojgon@3[ooX0m_ol0?;oo03]ood0gool0=ooo@21
olSo0:[coo2AXooj0?Gon`21ooSol@21oh7onOl00;OonP3[oo/0mOol0?;oo03]
ood0gool0=ooo@21ok[ol96SooX0mOok087on?oa087oPOoio`00]ooj0>_on`3e
oo`0l_ol0>goo@3Ooo`0goom087o^_o`TJ?onP3eoo/0POohoo40POn1ooWo002g
ooX0jook0?Goo03boo`0kOom0=ooo03Oood0POo8o`1jm?o^TJCon@3foo/0POoj
ond0POn1ooD0_?oi0>con`21oo_oo@21ok_okY6TooT0m_ok087on_o]087oPOoe
0;con@3/oo/0POokood0POnkonjAY?oi0?Kon`21oo[ok@21oh7om@2looT0k?ok
087onoom087ob?l0Q_KonY7hooZAY_oi0?OonP21oocojP21oh;om02looX0kOok
087on_om087o_OojTOSonY6VooT0mooj087oo?oZ087oP_od0;conP3]oo/0POoj
ood0POnmooZAn?ojTJKon@3gooX0POolonX0POn2oo@0_?oj0>gon`21oo[oo@21
olSo08Kgoo^Am?okTJKonP3goo/0POolonP0POn5oo00__oj0>gon`21oo[oo@21
okkoni7doo^AY_oj0?Oon`21oocoj021ohGol02nooX0kOok087on_om087o__ok
TOConi6VooX0mook087oo?oX087oQOo`0;konP3]oo/0POojood0POo8o`26mool
TO;oo96VooT0nOoj087oo?oX087oQ_o^0;oon@3_ooX0POojood0POnnoobAl_ol
TJKon@3iooX0POolonP0POn6onh0_ooi0>oonP21oo[oo@21okkoo97boobAY_oi
0?WonP21oocoj021ohKokP2oooT0kooj087on_om087ob?l0T_Soo97aoo^AY_oj
0?Won`21oocoiP21ohWon03looP0`?oj0>oon`21ooWoo@21okooo97aoo^AY_oj
0?Won`21oocoiP21ohWon03looP0`?oj0>oon`21ooWoo@21okooo97aoo^AY_oj
0?Won`21oocoiP21ohWon03looP0`?oj0>oon`21ooWoo@21olSo09;hoofAkook
TJOon@3kooX0POolonD0POn;oo/0m?ok0<7on@3aooX0POoiood0POnooofAkook
TJOon@3kooX0POolonD0POn;oo/0m?ok0<7on@3aooX0POoiood0POnooofAkook
TJOon@3kooX0POolonD0POn;oo/0m?ok0<7on@3aooX0POoiood0POo8o`2Bn_ok
TNkoo96VooX0nook087oo?oS087oS?ol0?;oo030ooX0lOok087on?om087o`Ook
TNkoo96VooX0nook087oo?oS087oS?ol0?;oo030ooX0lOok087on?om087o`Ook
TNkoo96VooX0nook087oo?oS087oS?ol0?;oo030ooX0lOok087on?om087ob?l0
T_[oo97]oobAY_oj0?_on`21oocoh`21ohgoo03aoo/0`Ooi0?;on`21ooSoo@21
ol7oo97]oobAY_oj0?_on`21oocoh`21ohgoo03aoo/0`Ooi0?;on`21ooSoo@21
ol7oo97]oobAY_oj0?_on`21oocoh`21ohgoo03aoo/0`Ooi0?;on`21ooSoo@21
olSo09;joofAjoomTJKon@3mooX0POolon<0POn=ood0kook0<;on@3cooX0POoh
ood0POo1oofAjoomTJKon@3mooX0POolon<0POn=ood0kook0<;on@3cooX0POoh
ood0POo1oofAjoomTJKon@3mooX0POolon<0POn=ood0kook0<;on@3cooX0POoh
ood0POo8o`2Bn_omTN_oo96VooX0oOok087onooR087oT?ok0>koo031ooX0look
087omoom087o`OomTN_oo96VooX0oOok087onooR087oT?ok0>koo031ooX0look
087omoom087o`OomTN_oo96VooX0oOok087onooR087oT?ok0>koo031ooX0look
087omoom087ob?l0UO_oo97ZoofAY_oi007oooX0POolon40POn@oo`0kOol0<7o
n@3eooX0POogood0POo2oobAj_omTJKon@01oooj087oo?oQ087oT?ol0>goo031
ooT0mOoj087omoom087o`_olTN[ooI6VooT00OoonP21oocoh@21oi3oo03]oo`0
`Ooi0?GonP21ooOoo@21olSo0;?koofAjOomTJGonP01oook0?7on`3Woo`0fOok
0=koh@21oi3oo@3[ood0`?oj0?Gon`21ooKoo@21ol;ooI7YoofAYOoj007ooo/0
lOok0>Ooo03Ioo/0g_oQ087oT?om0>_oo@30ooX0mOok087om_om087o`_omTNWo
oI6UooX00Ooon`3aoo/0iool0=Won`3Non40POn@ood0joom0<3onP3eoo/0POof
ood0POo8o`2`noomTNWooI6UooT00?ok0?7on`3Xoo/0fooi0=koh@21oi3oo@3[
oo`0`Ooi0?Kon`21ooKoo@21ol;ooI7YoofAYOoi003on`3aoo/0j?ok0=_on@3N
on40POn@ood0jool0<7on@3foo/0POofood0POo2oofAjOomTJGon@00oo/0lOok
0>Son`3KooT0g_oQ087oT?om0>_oo031ooT0m_ok087om_om087ob?l0Y?_ooI7Y
oofAYOob0?7onP3Yoo/0gOog0=koh@21oi7oo03Zood0`Ooi0?OonP21ooKoo@21
ol;ooI7YoofAYOob0?7onP3Yoo/0gOog0=koh@21oi7oo03Zood0`Ooi0?OonP21
ooKoo@21ol;ooI7YoofAYOob0?7onP3Yoo/0gOog0=koh@21oi7oo03Zood0`Ooi
0?OonP21ooKoo@21olSo0:CkoobAj_omTJCom03`ooX0jOok0>3om03Non40POnA
ood0jOom0<3onP3goo/0POoeood0POo2oobAj_omTJCom03`ooX0jOok0>3om03N
on40POnAood0jOom0<3onP3goo/0POoeood0POo2oobAj_omTJCom03`ooX0jOok
0>3om03Non40POnAood0jOom0<3onP3goo/0POoeood0POo8o`2Tn_omTN_oo96T
oo@0l?oi0>_onP3Qoo<0gOoR087oTOom0>Woo@30ooT0nOoj087omOom087o`Oom
TN_oo96Too@0l?oi0>_onP3Qoo<0gOoR087oTOom0>Woo@30ooT0nOoj087omOom
087o`OomTN_oo96Too@0l?oi0>_onP3Qoo<0gOoR087oTOom0>Woo@30ooT0nOoj
087omOom087ob?l0Y?[ooI7[oofAX_of0>oon@3[ooX0hOoc0=goh`21oi3oo@3Y
ood0_ooj0?Won`21ooCoo@21ol7ooI7[oofAX_of0>oon@3[ooX0hOoc0=goh`21
oi3oo@3Yood0_ooj0?Won`21ooCoo@21ol7ooI7[oofAX_of0>oon@3[ooX0hOoc
0=goh`21oi3oo@3Yood0_ooj0?Won`21ooCoo@21olSo0;?joofAjoomTJ;omP3_
ooT0k?oi0>7onP01oool0=goh`21oi3oo03Zood0_ooi0?_onP21ooCoo@21ol7o
oI7[oofAX_of0>oon@3/ooT0hOoj007ooo`0gOoS087oT?ol0>[oo@2oooT0nooj
087om?om087o`OomTN_ooI6RooH0kooi0>con@3QooX00Oooo03Mon<0POn@oo`0
j_om0;oon@3kooX0POodood0POo8o`2`n_olTNgoo96QooP0k_oh0>gon@3Qoo`0
oOol0=goh`21ohooo@3[oo`0__oj0?_on`21oo?oo@21ol7oo97]oobAXOoh0>ko
n03]ooT0hOol0?goo03Mon<0POn?ood0jool0;konP3koo/0POocood0POo1oobA
kOolTJ7on03^ooP0kOoi0>7oo03moo`0gOoS087oSoom0>_oo02nooX0nook087o
loom087ob?l0/oWoo97^oobAXOoh0>kon03^ooP0hOl1003joo`0gOoT087oS_om
0>_oo@2mooX0nook087oloom087o`?olTNkoo96QooP0k_oh0>kon03Qo`400?[o
o03Mon@0POn>ood0joom0;gonP3koo/0POocood0POo0oobAk_olTJ7on03^ooP0
k_oh0>7o0@00n_ol0=goi021ohkoo@3[ood0_Ooj0?_on`21oo?oo@21olSo0:Ch
oofAkoolTJ3on03^ooL0kooh0=Soo03LonH0POn=ood0joom0;gon@3mooX0POoc
ood0POnooofAkoolTJ3on03^ooL0kooh0=Soo03LonH0POn=ood0joom0;gon@3m
ooX0POocood0POnooofAkoolTJ3on03^ooL0kooh0=Soo03LonH0POn=ood0joom
0;gon@3mooX0POocood0POo8o`2TmoomTO7oni6OooX0kOog0?3om`3Hoo`0fooW
087oSOol0>goo02looX0oOok087ol_om087o__omTO7oni6OooX0kOog0?3om`3H
oo`0fooW087oSOol0>goo02looX0oOok087ol_om087o__omTO7oni6OooX0kOog
0?3om`3Hoo`0fooW087oSOol0>goo02looX0oOok087ol_om087ob?l0YoOoo97b
oobAPoof0?7oo@00oo`0f?ol0=_oj021oh_oo03^oo`0_?oi007oooX0POobood0
POnnoobAl_olTH?omP3aood00?ol0=Soo03KonP0POn;oo`0k_ol0;con@01oooj
087ol_om087o__olTO;oo963ooH0lOom003oo03Hoo`0fooX087oRool0>koo02l
ooT00OoonP21oo;oo@21olSo0;?foo^Am_okTH;oo000oo`0lOom003oo03Hoo`0
f_oZ087oROom0>ooo02jooX00Ooon`21oo7oo@21okgoni7foo^AP_ol003oo03a
ood00?ol0=Soo03JonX0POn9ood0kool0;[onP01oook087olOom087o_OokTOKo
ni62oo`00?ol0?7oo@00oo`0f?ol0=[ojP21ohWoo@3_oo`0^_oj007ooo/0POoa
ood0POo8o`2im_o[TH7oo000oo`0l_om007ooo`0f?ol0=Woj`21ohWoo03aoo/0
^_oi003on`3aoo/0iool0:Koo@21okgoji61oo`00?ol0?;oo@01oool0=Soo03I
on/0POn9oo`0lOok0;[on@00oo/0lOok0>Ooo02Vood0POnmon^APOol003oo03b
ood00Oooo03Hoo`0fOo[087oROol0?7on`2jooT00?ok0?7on`3Woo`0Y_om087o
b?l0/oCokY61o`3oo000oo/0loom007ooo`0f?ol0=Ook`21ohKoo03boo`0^Oob
0?7on`3Xoo/0Y_om087o^oo^TH7o0?ol003on`3cood00Oooo03Hoo`0eoo_087o
Q_ol0?;oo02ioo80lOok0>Son`2Vood0POnkonjAPOl0oo`00?ok0??oo@01oool
0=Soo03Gonl0POn6oo`0l_ol0;WolP3aoo/0j?ok0:Koo@21olSo0;Kboo:APOon
oo`00Oooo03doo`00Oooo03Hoo`0e_oa087oQ?ok0?KonP2hoo@0l?oj0>Won`2V
ood0POnioo:APOonoo`00Oooo03doo`00Oooo03Hoo`0e_oa087oQ?ok0?KonP2h
oo@0l?oj0>Won`2Vood0POnioo:APOonoo`00Oooo03doo`00Oooo03Hoo`0e_oa
087oQ?ok0?KonP2hoo@0l?oj0>Won`2Vood0POo8o`2WlOoeTH7oo?ol007ooo/0
mOom0?koo03Hoo`0e?oe087oP_o[0;Kom03`ooX0jOok0:Koo@21okSomI61ooco
o001oook0?Goo@3noo`0f?ol0=Com@21oh;oj`2foo@0l?oj0>Won`2Vood0POnh
ooFAPOoloo`00Ooon`3eood0o_ol0=Soo03DooD0POn2on/0]_od0?3onP3Yoo/0
Y_om087ob?l0Z^_o0961ooOoo03noo`0m_ol0?koo03Hoo`0col0087oPOojonh0
]?of0>oon@3[ooX0Y_om087o/_l0TH7omool0?koo03foo`0o_ol0=Soo03?o`00
POn1oo[okP2dooH0kooi0>_onP2Vood0POnbo`2APOogoo`0o_ol0?Koo03noo`0
f?ol0<oo0021oh7on_o^0;ComP3_ooT0jooj0:Koo@21olSo09:1on3oo03noo`0
m_om0?goo03Hoo`0POn1olGolP2booH0kooi0>_onP2Vood0POn1ojOoo03noo`0
m_om0?goo03Hoo`0POn1olGolP2booH0kooi0>_onP2Vood0POn1ojOoo03noo`0
m_om0?goo03Hoo`0POn1olGolP2booH0kooi0>_onP2Vood0POo8o`2BPOoPoo`0
oOol0?Soo03moo`0f?ol087oPOo4ooD0[ooh0>kon@3/ooT0Y_om087oPOnWoo`0
oOol0?Soo03moo`0f?ol087oPOo4ooD0[ooh0>kon@3/ooT0Y_om087oPOnWoo`0
oOol0?Soo03moo`0f?ol087oPOo4ooD0[ooh0>kon@3/ooT0Y_om087ob?l0TX7o
h?ol0?goo03hood0o?ol0=Soo021oh7o`Ooj0:gon03^ooP0kOoi0:Koo@21oh7o
Yool0?goo03hood0o?ol0=Soo021oh7o`Ooj0:gon03^ooP0kOoi0:Koo@21oh7o
Yool0?goo03hood0o?ol0=Soo021oh7o`Ooj0:gon03^ooP0kOoi0:Koo@21olSo
08b1on3oo03moo/0n_ol0?coo03Hoo`0POn1oh7oi_oh0>kon03^ooP0Y_om087o
POnWoo`0oOok0?[oo03loo`0f?ol087oPOn1onKon03^ooP0k_oh0:Koo@21oh7o
Yool0?gon`3joo`0o?ol0=Soo021oh7oPOoVooP0k_oh0>kon02Vood0POo8o`2H
POoPoo`0o?ol0?[oo@3koo`0o?o`0>koo021oh7oPOoUooX0kOog0>oon02Vood0
POn1ojOoo03loo`0n_om0?_oo03loo00k_ol087oPOn1onGonP3]ooL0kooh0:Ko
o@21oh7oYool0?coo03jood0nool0?col03^oo`0POn1oh7oiOoj0>gom`3_ooP0
Y_om087ob?l0S87oh?ol0?con`3kood0nool0?col03^oo`0POn1oh7ob_og0?3o
m`2Vood0POn1ojOoo03loo/0noom0?_oo03loo00k_ol087oPOn1ol[om`3`ooL0
Y_om087oPOnWoo`0o?ok0?_oo@3koo`0o?o`0>koo021oh7oPOo:ooL0l?og0:Ko
o@21olSo09R1on3oo03koo`0o?ol0?_oo03loo00k_ol087oPOn1ol[omP3aood0
0?ol0:Koo@21oh7oYool0?_oo03loo`0nool0?col03^oo`0POn1oh7ob_of0?7o
o@00oo`0Y_om087oPOnWoo`0nool0?coo03koo`0o?o`0>koo021oh7oPOo:ooH0
lOom003oo02Vood0POo8o`2TPOoPoo`0nool0?coo@3joo`0o?o`0>koo021oh7o
POo:oo`00?ol0?7oo@00oo`0Y_om087oPOnWoo`0nool0?coo@3joo`0o?o`0>ko
o021oh7oPOo:oo`00?ol0?7oo@00oo`0Y_om087oPOnWoo`0nool0?coo@3joo`0
o?o`0>koo021oh7oPOo:oo`00?ol0?7oo@00oo`0Y_om087ob?l0Yh7oh?ol0?_o
n`3noo`0n_ol0?col03^oo`0POn1oh7ob_ol003oo03bood00Oooo02Vood0POn1
ojOoo03koo/0o_ol0?[oo03loo00k_ol087oPOn1ol[oo000oo`0l_om007ooo`0
Y_om087oPOnWoo`0nook0?koo03joo`0o?o`0>koo021oh7oPOo:oo`00?ol0?;o
o@01oool0:Koo@21olSo09^1on3oo03joo`0o_om0?Woo03Hoo`0POn1oh7ob_ol
003on`3cood00Oooo02Vood0POn1ojOoo03joo`0o_om0?Woo03Hoo`0POn1oh7o
b_ol003on`3cood00Oooo02Vood0POn1ojOoo03joo`0o_om0?Woo03Hoo`0POn1
oh7ob_ol003on`3cood00Oooo02Vood0POo8o`2NPOoPoo`0n_ok003oo03ioo`0
f?ol087oPOn1ol[oo001oool0?Coo001oool0:Koo@21oh7oYool0?[on`00oo`0
nOol0=Soo021oh7oPOo:oo`00Oooo03doo`00Oooo02Vood0POn1ojOoo03joo/0
0?ol0?Woo03Hoo`0POn1oh7ob_ol007ooo`0m?ol007ooo`0Y_om087ob?l0Vh7o
h?ol0?Woo000ood0n?ol0=Soo021oh7oPOo:oo`00Ooon`3eood0o_ol0:Koo@21
oh7oYool0?Woo000ood0n?ol0=Soo021oh7oPOo:oo`00Ooon`3eood0o_ol0:Ko
o@21oh7oYool0?Woo000ood0n?ol0=Soo021oh7oPOo:oo`00Ooon`3eood0o_ol
0:Koo@21olSo08b1on3oo03iooL0n?ol0=Soo021oh7oPOo:oo`0o_ol0?Koo03n
oo`0Y_om087oPOnWoo`0nOog0?Soo03Hoo`0POn1oh7ob_ol0?koo03foo`0o_ol
0:Koo@21oh7oYool0?Wom`3hoo`0f?ol087oPOn1ol[oo03noo`0m_ol0?koo02V
ood0POo8o`2<POoPoo`0n?oi0?Ooo03Hoo`0POn1oh7ob_ol0?koo03food0oOol
0:Koo@21oh7oYool0?Son@3goo`0f?ol087oPOn1ol[oo03noo`0m_om0?goo02V
ood0POn1ojOoo03hooT0mool0=Soo021oh7oPOo:oo`0o_ol0?Koo@3moo`0Y_om
087ob?l0S87oh?ol0?Son@3goo`0f?ol087oPOn1ol[oo03moo`0n?ol0?goo02V
ood0POn1ojOoo03hooT0mool0=Soo021oh7oPOo:oo`0oOol0?Soo03moo`0Y_om
087oPOnWoo`0n?oi0?Ooo03Hoo`0POn1oh7ob_ol0?goo03hoo`0oOol0:Koo@21
olSo08b1on3oo03hooT0mool0=Soo021oh7oPOo:oo`0oOol0?Soo@3loo`0Y_om
087oPOnWoo`0n?oi0?Ooo03Hoo`0POn1oh7ob_ol0?goo03hood0o?ol0:Koo@21
oh7oYool0?Son@3goo`0f?ol087oPOn1ol[oo03moo`0n?om0?coo02Vood0POo8
o`2<POoPoo`0mook0?Koo03Hoo`0POn1oh7ob_ol0?gon`3joo`0o?ol0:Koo@21
oh7oYool0?Oon`3foo`0f?ol087oPOn1ol[oo03moo/0n_ol0?coo02Vood0POn1
ojOoo03goo/0m_ol0=Soo021oh7oPOo:oo`0oOok0?[oo03loo`0Y_om087ob?l0
S87oh?ol0?Oon`3foo`0f?ol087oPOn1ol[oo03loo`0n_om0?_oo02Vood0POn1
ojOoo03goo/0m_ol0=Soo021oh7oPOo:oo`0o?ol0?[oo@3koo`0Y_om087oPOnW
oo`0mook0?Koo03Hoo`0POn1oh7ob_ol0?coo03jood0nool0:Koo@21olSo0821
on3oo03Voo`0f?ol087oPOn1ol[oo03loo/0noom0?_oo02Vood0POn1ojOoo03V
oo`0f?ol087oPOn1ol[oo03loo/0noom0?_oo02Vood0POn1ojOoo03Voo`0f?ol
087oPOn1ol[oo03loo/0noom0?_oo02Vood0POo8o`20POoPoo`0i_ol0=Soo021
oh7oPOo:oo`0nool0?coo03koo`0Y_om087oPOnWoo`0i_ol0=Soo021oh7oPOo:
oo`0nool0?coo03koo`0Y_om087oPOnWoo`0i_ol0=Soo021oh7oPOo:oo`0nool
0?coo03koo`0Y_om087ob?l0P87oh?ol0>Koo03Hoo`0POn1oh7ob_ol0?_oo03l
ood0n_ol0:Koo@21oh7oYool0>Koo03Hoo`0POn1oh7ob_ol0?_oo03lood0n_ol
0:Koo@21oh7oYool0>Koo03Hoo`0POn1oh7ob_ol0?_oo03lood0n_ol0:Koo@21
olSo0821on3oo03Voo`0f?ol087oPOn1ol[oo03koo/0o_ol0?[oo02Vood0POn1
ojOoo03Voo`0f?ol087oPOn1ol[oo03koo/0o_ol0?[oo02Vood0POn1ojOoo03V
oo`0f?ol087oPOn1ol[oo03koo/0o_ol0?[oo02Vood0POo8o`20POoPoo`0i_ol
0=Soo021oh7oPOo:oo`0n_ol0?koo@3ioo`0Y_om087oPOnWoo`0i_ol0=Soo021
oh7oPOo:oo`0n_ol0?koo@3ioo`0Y_om087oPOnWoo`0i_ol0=Soo021oh7oPOo:
oo`0n_ol0?koo@3ioo`0Y_om087ob?l0P87oh?ol0>Koo03Hoo`0POn1oh7ob_ol
0?[on`00oo`0nOol0:Koo@21oh7oYool0>Koo03Hoo`0POn1oh7ob_ol0?[on`00
oo`0nOol0:Koo@21oh7oYool0>Koo03Hoo`0POn1oh7ob_ol0?[on`00oo`0nOol
0:Koo@21olSo06:1oh7oPOn1oh7oe_ol0?Woo000ood0n?ol0:Koo@21oh7oPOn1
oh7oPOnMoo`0nOol003oo@3hoo`0Y_om087oPOn1oh7oPOn1oigoo03ioo`00?om
0?Soo02Vood0POo8o`1FPOn1oh7oPOn1omKoo03iooL0n?ol0:Koo@21oh7oPOn1
oh7oPOnMoo`0nOog0?Soo02Vood0POn1oh7oPOn1oh7oWOol0?Wom`3hoo`0Y_om
087ob?l0EX7oPOn1oh7oPOoFoo`0n?oi0?Ooo02Vood0POn1oh7oPOn1oh7oWOol
0?Son@3goo`0Y_om087oPOn1oh7oPOn1oigoo03hooT0mool0:Koo@21olSo05J1
oh7oPOn1oh7oe_ol0?Son@3goo`0Y_om087oPOn1oh7oPOn1oigoo03hooT0mool
0:Koo@21oh7oPOn1oh7oPOnMoo`0n?oi0?Ooo02Vood0POo8o`1FPOn1oh7oPOn1
omKoo03hooT0mool0:Koo@21oh7oPOn1oh7oPOnMoo`0n?oi0?Ooo02Vood0POn1
oh7oPOn1oh7oWOol0?Son@3goo`0Y_om087ob?l0EX7oPOn1oh7oPOoFoo`0mook
0?Koo02Vood0POn1oh7oPOn1oh7oWOol0?Oon`3foo`0Y_om087oPOn1oh7oPOn1
oigoo03goo/0m_ol0:Koo@21olSo05J1oh7oPOn1oh7oe_ol0?Oon`3foo`0Y_om
087oPOn1oh7oPOn1oigoo03goo/0m_ol0:Koo@21oh7oPOn1oh7oPOnMoo`0mook
0?Koo02Vood0POo8o`1:POn1oh7oPOn1omKoo03Voo`0Y_om087oPOn1oh7oPOn1
oigoo03Voo`0Y_om087oPOn1oh7oPOn1oigoo03Voo`0Y_om087ob?l0BX7oPOn1
oh7oPOoFoo`0i_ol0:Koo@21oh7oPOn1oh7oPOnMoo`0i_ol0:Koo@21oh7oPOn1
oh7oPOnMoo`0i_ol0:Koo@21olSo04Z1oh7oPOn1oh7oe_ol0>Koo02Vood0POn1
oh7oPOn1oh7oWOol0>Koo02Vood0POn1oh7oPOn1oh7oWOol0>Koo02Vood0POo8
o`1:POn1oh7oPOn1omKoo03Voo`0Y_om087oPOn1oh7oPOn1oigoo03Voo`0Y_om
087oPOn1oh7oPOn1oigoo03Voo`0Y_om087ob?l0BX7oPOn1oh7oPOoFoo`0i_ol
0:Koo@21oh7oPOn1oh7oPOnMoo`0i_ol0:Koo@21oh7oPOn1oh7oPOnMoo`0i_ol
0:Koo@21olSo04Z1oh7oPOn1oh7oe_ol0>Koo02Vood0POn1oh7oPOn1oh7oWOol
0>Koo02Vood0POn1oh7oPOn1oh7oWOol0>Koo02Vood0POo8o`0hPOn1oh7oPOn1
oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0
>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1
oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1
oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1
oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21
oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1
oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8
o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1
oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21
oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1
oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om
087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1
oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21
olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1
oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom
087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1
oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoF
ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1
oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom
087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1
oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnM
ood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1
oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1
omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1
oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnM
ood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1
oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1
oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1
oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1
oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0
>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1
oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1
oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1
oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21
oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1
oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8
o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1
oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21
oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1
oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om
087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1
oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21
olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1
oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom
087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1
oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoF
ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1
oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom
087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1
oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnM
ood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1
oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1
omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1
oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnM
ood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1
oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1
oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1
oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1
oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0
>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1
oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1
oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1
oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21
oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1
oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8
o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1
oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21
oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1
oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om
087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1
oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21
olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1
oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom
087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1
oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoF
ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1
oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom
087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1
oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnM
ood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1
oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1
omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1
oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnM
ood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1
oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1
oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1
oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1
oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0
>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1
oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1
oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1
oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21
oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1
oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8
o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1
oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21
oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1
oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om
087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1
oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21
olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1
oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom
087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1
oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03j1ol_on`21oh7oPOn1
oi;oo@21oh7oT_ok087oPOn1oh7oT_om087oPOnBoo/0POn1oh7oPOnBood0POo8
o`1:POoGoo`0oOoe087oPOn1oh7oUOom087oPOnNoo`0oOoe087oPOn1oh7oUOom
087oPOnNoo`0oOoe087oPOn1oh7oUOom087ob?l0BX7oeool0?kol`21oh7oPOn1
oiKoo@21oh7oW_ol0?kol`21oh7oPOn1oiKoo@21oh7oW_ol0?kol`21oh7oPOn1
oiKoo@21olSo04f1omOoo001oooa087oPOn1oh7oUoom087oPOnNoo`00Oool@21
oh7oPOn1oiOoo@21oh7oW_ol007ooo40POn1oh7oPOnGood0POo8o`1FPOoGoo`0
0?ol0?con@21oh7oPOn1oiSoo@21oh7oW_ol003oo03looT0POn1oh7oPOnHood0
POn1oikoo000oo`0o?oi087oPOn1oh7oV?om087ob?l0BX7oeooh0?Son`21oh7o
POn1oiSoo@21oh7oW_oh0?Son`21oh7oPOn1oiSoo@21oh7oW_oh0?Son`21oh7o
POn1oiSoo@21olSo04Z1omOon@3foo`0POn1oh7oPOnHood0POn1oikon@3foo`0
POn1oh7oPOnHood0POn1oikon@3foo`0POn1oh7oPOnHood0POo8o`1@POoGooX0
mOok087oPOn1oh7on`2Oood0POn1oikonP3eoo/0POn1oh7oPOok09ooo@21oh7o
W_oj0?Gon`21oh7oPOn1oo/0Woom087ob?l0G87oeooj0?Coo021oh7oPOn=oo`0
oOoe0:;oo@21oh7oW_oj0?Coo021oh7oPOn=oo`0oOoe0:;oo@21oh7oW_oj0?Co
o021oh7oPOn=oo`0oOoe0:;oo@21olSo05b1omOon`3coo`0POn1oh7oSOol0?ko
l`2Sood0POn1oikon`3coo`0POn1oh7oSOol0?kol`2Sood0POn1oikon`3coo`0
POn1oh7oSOol0?kol`2Sood0POo8o`1OPOoGoo/0lool087oPOn1ohgoo001oooa
0:Coo@21oh7oW_ok0??oo021oh7oPOn=oo`00Oool@2Tood0POn1oikon`3coo`0
POn1oh7oSOol007ooo40Y?om087ob?l0J87oeool0?;oo021oh7oPOn=oo`00?ol
0?con@2Uood0POn1oikoo03boo`0POn1oh7oSOol003oo03looT0YOom087oPOnN
oo`0l_ol087oPOn1ohgoo000oo`0o?oi0:Goo@21olSo05b1omOoo03boo`0POn1
oh7oSOoh0?Son`2Uood0POn1oikoo03boo`0POn1oh7oSOoh0?Son`2Uood0POn1
oikoo03boo`0POn1oh7oSOoh0?Son`2Uood0POo8o`1LPOoGoo`0l_ol087oPOn1
ohgon@3foo`0YOom087oPOnNoo`0l_ol087oPOn1ohgon@3foo`0YOom087oPOnN
oo`0l_ol087oPOn1ohgon@3foo`0YOom087ob?l0G87oeool0?;oo021oh7oPOn=
ooX0mOok0:Koo@21oh7oW_ol0?;oo021oh7oPOn=ooX0mOok0:Koo@21oh7oW_ol
0?;oo021oh7oPOn=ooX0mOok0:Koo@21olSo05b1omOoo03boo`0POn1oh7oSOoj
0?Coo02Vood0POn1oikoo03boo`0POn1oh7oSOoj0?Coo02Vood0POn1oikoo03b
oo`0POn1oh7oSOoj0?Coo02Vood0POo8o`1LPOoGoo`0l_ol087oPOn1ohgon`3c
oo`0Y_om087oPOnNoo`0l_ol087oPOn1ohgon`3coo`0Y_om087oPOnNoo`0l_ol
087oPOn1ohgon`3coo`0Y_om087ob?l0G87oeool0?;oo021oh7oPOn=oo/0lool
0:Koo@21oh7oW_ol0?;oo021oh7oPOn=oo/0lool0:Koo@21oh7oW_ol0?;oo021
oh7oPOn=oo/0lool0:Koo@21olSo05b1omOoo03boo`0POn1oh7oSOol0?;oo02V
ood0POn1oikoo03boo`0POn1oh7oSOol0?;oo02Vood0POn1oikoo03boo`0POn1
oh7oSOol0?;oo02Vood0POo8o`1LPOoGoo`0l_ol087oPOn1ohgoo03boo`0Y_om
087oPOnNoo`0l_ol087oPOn1ohgoo03boo`0Y_om087oPOnNoo`0l_ol087oPOn1
ohgoo03boo`0Y_om087ob?l0G87oeool0?;oo021oh7oPOn=oo`0l_ol0:Koo@21
oh7oW_ol0?;oo021oh7oPOn=oo`0l_ol0:Koo@21oh7oW_ol0?;oo021oh7oPOn=
oo`0l_ol0:Koo@21olSo05b1omOoo03boo`0POn1oh7oSOol0?;oo02Vood0POn1
oikoo03boo`0POn1oh7oSOol0?;oo02Vood0POn1oikoo03boo`0POn1oh7oSOol
0?;oo02Vood0POo8o`1LPOoGoo`0l_ol087oPOn1ohgoo03boo`0Y_om087oPOnN
oo`0l_ol087oPOn1ohgoo03boo`0Y_om087oPOnNoo`0l_ol087oPOn1ohgoo03b
oo`0Y_om087ob?l0G87oeool0?;oo021oh7oPOn=oo`0l_ol0:Koo@21oh7oW_ol
0?;oo021oh7oPOn=oo`0l_ol0:Koo@21oh7oW_ol0?;oo021oh7oPOn=oo`0l_ol
0:Koo@21olSo05b1omOoo03boo`0POn1oh7oSOol0?;oo02Vood0POn1oikoo03b
oo`0POn1oh7oSOol0?;oo02Vood0POn1oikoo03boo`0POn1oh7oSOol0?;oo02V
ood0POo8o`1LPOoGoo`0l_ol087oPOn1ohgoo03boo`0Y_om087oPOnNoo`0l_ol
087oPOn1ohgoo03boo`0Y_om087oPOnNoo`0l_ol087oPOn1ohgoo03boo`0Y_om
087ob?l0LXWon@3WooX0n?ol0?;oo021oh7oPOn=oo`0l_ol0:Koo@21oh7od?oi
0>OonP3hoo`0l_ol087oPOn1ohgoo03boo`0Y_om087oPOo@ooT0iooj0?Soo03b
oo`0POn1oh7oSOol0?;oo02Vood0POo8o`1bR?oj0>Oon`3goo`0l_ol087oPOn1
ohgoo03boo`0Y_om087oPOo?ooX0iook0?Ooo03boo`0POn1oh7oSOol0?;oo02V
ood0POn1oloonP3Woo/0mool0?;oo021oh7oPOn=oo`0l_ol0:Koo@21olSo07:8
ooT0j?ok0?Ooo03boo`0POn1oh7oSOol0?;oo02Vood0POn1oloon@3Xoo/0mool
0?;oo021oh7oPOn=oo`0l_ol0:Koo@21oh7ocooi0>Son`3goo`0l_ol087oPOn1
ohgoo03boo`0Y_om087ob?l0LXSon@3YooX0mool0?;oo021oh7oPOn=oo`0l_ol
0:Koo@21oh7ocooi0>WonP3goo`0l_ol087oPOn1ohgoo03boo`0Y_om087oPOo?
ooT0jOoj0?Ooo03boo`0POn1oh7oSOol0?;oo02Vood0POo8o`1bQooj0>Won`3f
oo`0l_ol087oPOn1ohgoo03boo`0Y_om087oPOo>ooX0jOok0?Koo03boo`0POn1
oh7oSOol0?;oo02Vood0POn1olkonP3Yoo/0m_ol0?;oo021oh7oPOn=oo`0l_ol
0:Koo@21olSo07:7ooT0jooj0?Koo03boo`0POn1oh7oSOol0?;oo02Vood0POn1
olkon@3[ooX0m_ol0?;oo021oh7oPOn=oo`0l_ol0:Koo@21oh7oc_oi0>_onP3f
oo`0l_ol087oPOn1ohgoo03boo`0Y_om087ob?l0LXKonP3[oo/0POn1oh7oV_oi
0>OonP3hoo`0l_ol0:Koo@21oh7ocOoj0>_on`21oh7oPOnJooT0iooj0?Soo03b
oo`0Y_om087oPOo=ooX0jook087oPOn1oi[on@3WooX0n?ol0?;oo02Vood0POo8
o`1bQ_oi0>con`21oh7oPOnIooX0iook0?Ooo03boo`0Y_om087oPOo=ooT0k?ok
087oPOn1oiWonP3Woo/0mool0?;oo02Vood0POn1olgon@3/oo/0POn1oh7oVOoj
0>Oon`3goo`0l_ol0:Koo@21olSo07:5ooX0kOok087oPOn1oiSon@3Xoo/0mool
0?;oo02Vood0POn1olconP3]oo/0POn1oh7oV?oi0>Son`3goo`0l_ol0:Koo@21
oh7oc?oj0>gon`21oh7oPOnHooT0j?ok0?Ooo03boo`0Y_om087ob?l0T^go096J
ooX0kOok087on_l0087oPOoao`00/Ooi0>WonP3goo`0l_ol0:Koo@21okCo096J
ooX0kOok087on_l0087oPOoao`00/Ooi0>WonP3goo`0l_ol0:Koo@21okCo096J
ooX0kOok087on_l0087oPOoao`00/Ooi0>WonP3goo`0l_ol0:Koo@21olSo09;c
ooBAX?oi0>oonP21o`3om021oh7ooOod0;KonP3Yoo/0m_ol0?;oo02Vood0POnj
ooBAX?oi0>oonP21o`3om021oh7ooOod0;KonP3Yoo/0m_ol0?;oo02Vood0POnj
ooBAX?oi0>oonP21o`3om021oh7ooOod0;KonP3Yoo/0m_ol0?;oo02Vood0POo8
o`2<mOo`TJ7onP3_oo/0POl0oo40POn1oo00^?oi0>_onP3foo`0l_ol0:Koo@21
okcol96QooX0kook087o0?oa087oPOo`0;Son@3[ooX0m_ol0?;oo02Vood0POnl
oo2AXOoj0>oon`21o`3ol@21oh7ol02hooT0jooj0?Koo03boo`0Y_om087ob?l0
Q_KokY6RooT0lOoj08;ok@21ohCokP2hooX0jook0?Goo03boo`0Y_om087o_Oo^
TJ;on@3aooX0P_o]087oQ?o^0;SonP3[oo/0mOol0?;oo02Vood0POnmonjAX_oi
0?7onP22ond0POn4onh0^?oj0>_on`3eoo`0l_ol0:Koo@21olSo06khon^AX_oj
0?7on`22on/0POn7on/0^Ooi0>con`21ood0POnoon^AX_oj0?7on`22on/0POn7
on/0^Ooi0>con`21ood0POnoon^AX_oj0?7on`22on/0POn7on/0^Ooi0>con`21
ood0POo8o`20n?ojTOSonY6SooT0l_ok08?oj@21ohSojP2iooX0kOok087o0?om
087o_oojTOSonY6SooT0l_ok08?oj@21ohSojP2iooX0kOok087o0?om087o_ooj
TOSonY6SooT0l_ok08?oj@21ohSojP2iooX0kOok087o0?om087ob?l0P?WonY7e
oo^AY?oi0??onP24onL0POn:onP0^_oj0>gon`21o`3oo@21ol3onY7eoo^AY?oi
0??onP24onL0POn:onP0^_oj0>gon`21o`3oo@21ol3onY7eoo^AY?oi0??onP24
onL0POn:onP0^_oj0>gon`21o`3oo@21olSo083ioobAl_okTJConP3coo/0PooV
087oRooW0;_on@3_ooX0POl0ood0POo0oobAl_okTJConP3coo/0PooV087oRooW
0;_on@3_ooX0POl0ood0POo0oobAl_okTJConP3coo/0PooV087oRooW0;_on@3_
ooX0POl0ood0POo8o`23n_omTNkooI6TooT0mOoj08Coi@21ohcoiP2jooX0kook
087o0Oooo@21ol7ooI7^oofAY?oi0?GonP24onD0POn<onH0^_oj0>oon`21o`7o
ood0POo1oofAk_omTJCon@3eooX0Q?oU087oS?oV0;[onP3_oo/0POl1ooom087o
b?l0Po_oo97^oobAY?oj0?Gon`24on<0POn>on@0^ooi0?7onP21o`7oood0POo2
oobAk_olTJConP3eoo/0Q?oS087oS_oT0;_on@3aooX0POl1ooom087o`_olTNko
o96TooX0mOok08Coh`21ohkoi02kooT0lOoj087o0Oooo@21olSo083loobAk?om
TJCon@3foo/0Q?oS087oSooS0;[onP3aoo/0POonood0POo3oobAk?omTJCon@3f
oo/0Q?oS087oSooS0;[onP3aoo/0POonood0POo3oobAk?omTJCon@3foo/0Q?oS
087oSooS0;[onP3aoo/0POonood0POo8o`20o?olTNcooI6TooT0mooj08Coh`21
ohooh`2jooT0l_ok087oo_om087o`oolTNcooI6TooT0mooj08Coh`21ohooh`2j
ooT0l_ok087oo_om087o`oolTNcooI6TooT0mooj08Coh`21ohooh`2jooT0l_ok
087oo_om087ob?l0P?cooI7[oofAXooj0?Oon`23on<0POn?on<0^_oi0??onP21
ookoo@21ol?ooI7[oofAXooj0?Oon`23on<0POn?on<0^_oi0??onP21ookoo@21
ol?ooI7[oofAXooj0?Oon`23on<0POn?on<0^_oi0??onP21ookoo@21olSo083l
oofAj_omTJCon@3iooX0PooR087oT?oR0;[onP3coo/0POomood0POo3oofAj_om
TJCon@3iooX0PooR087oT?oR0;[onP3coo/0POomood0POo3oofAj_omTJCon@3i
ooX0PooR087oT?oR0;[onP3coo/0POomood0POo8o`20oOomTNWooI6SooX0nOok
08?oh@21oi7oh@2jooT0mOoj087ooOom087oa?omTNWooI6SooX0nOok08?oh@21
oi7oh@2jooT0mOoj087ooOom087oa?omTNWooI6SooX0nOok08?oh@21oi7oh@2j
ooT0mOoj087ooOom087ob?l0P?gooI7YoofAXooi0?_onP23on40POnAon40^Ooj
0?Gon`21oocoo@21olCooI7YoofAXooi0?_onP23on40POnAon40^Ooj0?Gon`21
oocoo@21olCooI7YoofAXooi0?_onP23on40POnAon40^Ooj0?Gon`21oocoo@21
olSo083moofAjOomTJ;onP3koo/0P_oQ087oTOoQ0;Won@3foo/0POolood0POo4
oofAjOomTJ;onP3koo/0P_oQ087oTOoQ0;Won@3foo/0POolood0POo4oofAjOom
TJ;onP3koo/0P_oQ087oTOoQ0;Won@3foo/0POolood0POo8o`20oOomTNWooI6R
ooX0nook08;oh@21oi7oh@2iooT0mooj087oo?om087oa?omTNWooI6RooX0nook
08;oh@21oi7oh@2iooT0mooj087oo?om087oa?omTNWooI6RooX0nook08;oh@21
oi7oh@2iooT0mooj087oo?om087ob?l0P?goo97ZoofAX_oi0?gonP22on40POnA
on40^?oj0?Oon`21oo_oo@21olCoo97ZoofAX_oi0?gonP22on40POnAon40^?oj
0?Oon`21oo_oo@21olCoo97ZoofAX_oi0?gonP22on40POnAon40^?oj0?Oon`21
oo_oo@21olSo08KloofAjoolTJ7onP3moo/0POl0on80POn@on80^?oi0?WonP21
oo_oo@21ol?ooI7[oobAXOoj0?gon`21o`3ohP21oi3ohP2hooT0nOoj087onoom
087o`oomTN_oo96QooX0oOok087o0?oR087oT?oR0;Son@3iooX0POokood0POo8
o`29o?omTN_ooI6PooT00OoonP21o`3oh`21ohooh`2fooX0nOok087on_om087o
`oomTN_ooI6PooT00OoonP21o`3oh`21ohooh`2fooX0nOok087on_om087o`oom
TN_ooI6PooT00OoonP21o`3oh`21ohooh`2fooX0nOok087on_om087ob?l0Yoco
o97/oofAWooj007ooo/0lOok0>Ooo03Hoo/0hooS087oSooS0;Kon@3kooX0POoj
ood0POo3oobAk?omTIoonP01oook0?7on`3Woo`0f?ok0>?oh`21ohooh`2fooT0
nooj087on_om087o`oolTNcooI6OooX00Ooon`3aoo/0iool0=Son`3Son<0POn?
on<0]_oi0?_onP21oo[oo@21olSo0:CloobAk?omTIoon@00oo/0lOok0>Son`3J
ooT0hooS087oSooS0;GonP3koo/0POoiood0POo3oobAk?omTIoon@00oo/0lOok
0>Son`3JooT0hooS087oSooS0;GonP3koo/0POoiood0POo3oobAk?omTIoon@00
oo/0lOok0>Son`3JooT0hooS087oSooS0;GonP3koo/0POoiood0POo8o`2Hnool
TNkoo96Ooo80lOoj0>Won`3LooL0hooS087oS_oT0;GonP3koo/0POoiood0POo2
oobAk_olTIoolP3aooX0jOok0=com`3Son<0POn>on@0]Ooj0?_on`21ooWoo@21
ol;oo97^oobAWoob0?7onP3Yoo/0g?og0>?oh`21ohkoi02eooX0nook087onOom
087ob?l0V?[oo97_oofAWOod0?3onP3Yoo/0good0>;oi@21ohcoiP2dooT0oOoj
087onOom087o`OolTNoooI6Moo@0l?oj0>Won`3Ooo@0h_oU087oS?oV0;Con@3m
ooX0POoiood0POo1oobAkoomTIgom03`ooX0jOok0=oom03RonD0POn<onH0]?oi
0?gonP21ooWoo@21olSo09Sioo^AlookTIgom03`ooT0jooj0>3ol`3QonH0POn;
onL0/ooj0?gon`21ooSoo@21ol3oni7coo^AWOod0?3on@3[ooX0h?oc0>7oiP21
oh_oi`2cooX0oOok087on?om087o`?okTO?oni6Moo@0l?oi0>_onP3Poo<0hOoV
087oRooW0;?onP3moo/0POohood0POo8o`2KnOojTOKonY6KooH0kooi0>_onP3P
oo<0hOoW087oR_oX0;;on@01oooj087on?om087o`?ojTOKonY6KooH0kooi0>_o
nP3Poo<0hOoW087oR_oX0;;on@01oooj087on?om087o`?ojTOKonY6KooH0kooi
0>_onP3Poo<0hOoW087oR_oX0;;on@01oooj087on?om087ob?l0_?SonY7hooZA
V_of0>oon@3/ooT0h?oj007ooo`0h?oZ087oQooZ0;3onP01oook0?7on`3Woo`0
[?om087o_oojTOSonY6JooH0kooi0>con@3PooX00Oooo03PonX0POn7onX0/?oj
007ooo/0lOok0>Ooo02/ood0POnoooZAn?ojTI[omP3_ooT0k?oi0>3onP01oool
0>3ojP21ohOojP2`ooX00Ooon`3aoo/0iool0:coo@21olSo0:[hon^AV?oh0>ko
n03]ooT0h?ol0?goo03Oon/0POn7on/0[ooi003on`3aoo/0j?ok0:coo@21okoo
ji6HooP0k_oh0>gon@3Poo`0oOol0=ooj`21ohOoj`2_ooT00?ok0?7on`3Xoo/0
[?om087o_oo[TISon03^ooP0kOoi0>3oo03moo`0goo[087oQoo[0:oon@00oo/0
lOok0>Son`2/ood0POo8o`2Qm_o^TIOon03^ooP0k_oh0>3o0@00n_ol0=gok`21
oh?okP2^oo80lOoj0>Won`2/ood0POnmonjAUooh0>kon03^ooP0h?l1003joo`0
gOo_087oPoo^0:kolP3aooX0jOok0:coo@21okgokY6GooP0k_oh0>kon03Po`40
0?[oo03Monl0POn3onh0[_ob0?7onP3Yoo/0[?om087ob?l0V?ColY6EooP0k_og
0>oon03Goo`0g?oa087oPOl0oo80Zood0?3onP3Yoo/0[?om087o^oobTIGon03^
ooL0kooh0=Ooo03Loo40POn1o`3olP2[oo@0l?oj0>Won`2/ood0POnkoo:AUOoh
0>kom`3_ooP0eool0=col@21oh7o0?ob0:_om03`ooX0jOok0:coo@21olSo09Sc
ooFAT_oj0>gom`3`ooL0eool0=[om@21oh7ooOoe0:Wom03`ooT0jooj0:coo@21
ok[omI6BooX0kOog0?3om`3Goo`0f_oe087oPOomooD0ZOod0?3on@3[ooX0[?om
087o^_oeTI;onP3]ooL0l?og0=Ooo03JooD0POn1oogom@2Yoo@0l?oi0>_onP2/
ood0POo8o`20POoMooH0lOom003oo03Goo`0POn1oh7oiOof0>oon@3[ooX0[?om
087oPOnTooH0lOom003oo03Goo`0POn1oh7oiOof0>oon@3[ooX0[?om087oPOnT
ooH0lOom003oo03Goo`0POn1oh7oiOof0>oon@3[ooX0[?om087ob?l0S87ogOol
003oo03aood00?ol0=Ooo021oh7oPOoUooH0kooi0>con@2/ood0POn1ojCoo000
oo`0lOom003oo03Goo`0POn1oh7oiOof0>oon@3/ooT0[?om087oPOnToo`00?ol
0?7oo@00oo`0eool087oPOn1onGomP3_ooT0k?oi0:coo@21olSo08n1omgoo000
oo`0l_om007ooo`0eool087oPOn1onCon03^ooP0kOoi0:coo@21oh7oY?ol003o
o03bood00Oooo03Goo`0POn1oh7oi?oh0>kon03]ooT0[?om087oPOnToo`00?ol
0?;oo@01oool0=Ooo021oh7oPOoTooP0k_oh0>gon@2/ood0POo8o`2?POoMoo`0
0?ok0??oo@01oool0=Ooo021oh7oPOoTooP0k_oh0>kon02/ood0POn1ojCoo000
oo/0loom007ooo`0eool087oPOn1onCon03^ooP0k_oh0:coo@21oh7oY?ol003o
n`3cood00Oooo03Goo`0POn1oh7oi?oh0>kon03^ooP0[?om087ob?l0TX7ogOol
007ooo`0m?ol007ooo`0eool087oPOn1onCon03^ooL0kooh0:coo@21oh7oY?ol
007ooo`0m?ol007ooo`0eool087oPOn1onCon03^ooL0kooh0:coo@21oh7oY?ol
007ooo`0m?ol007ooo`0eool087oPOn1onCon03^ooL0kooh0:coo@21olSo08n1
omgoo001oook0?Goo@3noo`0eool087oPOn1on?onP3]ooL0l?og0:coo@21oh7o
Y?ol007ooo/0mOom0?koo03Goo`0POn1oh7ohooj0>gom`3`ooL0[?om087oPOnT
oo`00Ooon`3eood0o_ol0=Ooo021oh7oPOoSooX0kOog0?3om`2/ood0POo8o`2<
POoMoo`0o_ol0?Koo03noo`0eool087oPOn1olSomP3aood00?ol0:coo@21oh7o
Y?ol0?koo03foo`0o_ol0=Ooo021oh7oPOo8ooH0lOom003oo02/ood0POn1ojCo
o03noo`0m_ol0?koo03Goo`0POn1oh7ob?of0?7oo@00oo`0[?om087ob?l0V87o
gOol0?koo03food0oOol0=Ooo021oh7oPOo8oo`00?ol0?7oo@00oo`0[?om087o
POnToo`0o_ol0?Koo@3moo`0eool087oPOn1olSoo000oo`0lOom003oo02/ood0
POn1ojCoo03noo`0m_om0?goo03Goo`0POn1oh7ob?ol003oo03aood00?ol0:co
o@21olSo09^1omgoo03moo`0n?ol0?goo03Goo`0POn1oh7ob?ol003oo03bood0
0Oooo02/ood0POn1ojCoo03moo`0n?ol0?goo03Goo`0POn1oh7ob?ol003oo03b
ood00Oooo02/ood0POn1ojCoo03moo`0n?ol0?goo03Goo`0POn1oh7ob?ol003o
o03bood00Oooo02/ood0POo8o`2KPOoMoo`0oOol0?Soo@3loo`0eool087oPOn1
olSoo000oo/0loom007ooo`0[?om087oPOnToo`0oOol0?Soo@3loo`0eool087o
POn1olSoo000oo/0loom007ooo`0[?om087oPOnToo`0oOol0?Soo@3loo`0eool
087oPOn1olSoo000oo/0loom007ooo`0[?om087ob?l0WX7ogOol0?gon`3joo`0
o?ol0=Ooo021oh7oPOo8oo`00Oooo03doo`00Oooo02/ood0POn1ojCoo03moo/0
n_ol0?coo03Goo`0POn1oh7ob?ol007ooo`0m?ol007ooo`0[?om087oPOnToo`0
oOok0?[oo03loo`0eool087oPOn1olSoo001oool0?Coo001oool0:coo@21olSo
0:N1omgoo03loo`0n_om0?_oo03loo00kOol087oPOn1olSoo001oook0?Goo@3n
oo`0[?om087oPOnToo`0o?ol0?[oo@3koo`0o?o`0>goo021oh7oPOo8oo`00Ooo
n`3eood0o_ol0:coo@21oh7oY?ol0?coo03jood0nool0?col03]oo`0POn1oh7o
b?ol007ooo/0mOom0?koo02/ood0POo8o`2TPOoMoo`0o?ok0?_oo@3koo`0o?o`
0>goo021oh7oPOo8oo`0o_ol0?Koo03noo`0[?om087oPOnToo`0o?ok0?_oo@3k
oo`0o?o`0>goo021oh7oPOo8oo`0o_ol0?Koo03noo`0[?om087oPOnToo`0o?ok
0?_oo@3koo`0o?o`0>goo021oh7oPOo8oo`0o_ol0?Koo03noo`0[?om087ob?l0
Y87ogOol0?_oo03loo`0nool0?col03]oo`0POn1oh7ob?ol0?koo03food0oOol
0:coo@21oh7oY?ol0?_oo03loo`0nool0?col03]oo`0POn1oh7ob?ol0?koo03f
ood0oOol0:coo@21oh7oY?ol0?_oo03loo`0nool0?col03]oo`0POn1oh7ob?ol
0?koo03food0oOol0:coo@21olSo0:B1omgoo03koo`0o?om0?[oo03loo00kOol
087oPOn1olSoo03moo`0n?ol0?goo02/ood0POn1ojCoo03koo`0o?om0?[oo03l
oo00kOol087oPOn1olSoo03moo`0n?ol0?goo02/ood0POn1ojCoo03koo`0o?om
0?[oo03loo00kOol087oPOn1olSoo03moo`0n?ol0?goo02/ood0POo8o`2TPOoM
oo`0nook0?koo03joo`0o?o`0>goo021oh7oPOo8oo`0oOol0?Soo@3loo`0[?om
087oPOnToo`0nook0?koo03joo`0o?o`0>goo021oh7oPOo8oo`0oOol0?Soo@3l
oo`0[?om087oPOnToo`0nook0?koo03joo`0o?o`0>goo021oh7oPOo8oo`0oOol
0?Soo@3loo`0[?om087ob?l0V87ogOol0?[oo03nood0nOol0=Ooo021oh7oPOo8
oo`0oOok0?[oo03loo`0[?om087oPOnToo`0n_ol0?koo@3ioo`0eool087oPOn1
olSoo03moo/0n_ol0?coo02/ood0POn1ojCoo03joo`0o_om0?Woo03Goo`0POn1
oh7ob?ol0?gon`3joo`0o?ol0:coo@21olSo09R1omgoo03joo/00?ol0?Woo03G
oo`0POn1oh7ob?ol0?coo03jood0nool0:coo@21oh7oY?ol0?[on`00oo`0nOol
0=Ooo021oh7oPOo8oo`0o?ol0?[oo@3koo`0[?om087oPOnToo`0n_ok003oo03i
oo`0eool087oPOn1olSoo03loo`0n_om0?_oo02/ood0POo8o`2HPOoMoo`0nOol
003oo@3hoo`0eool087oPOn1olSoo03loo/0noom0?_oo02/ood0POn1ojCoo03i
oo`00?om0?Soo03Goo`0POn1oh7ob?ol0?con`3kood0nool0:coo@21oh7oY?ol
0?Woo000ood0n?ol0=Ooo021oh7oPOo8oo`0o?ok0?_oo@3koo`0[?om087ob?l0
S87ogOol0?Wom`3hoo`0eool087oPOn1olSoo03koo`0o?ol0?_oo02/ood0POn1
ojCoo03iooL0n?ol0=Ooo021oh7oPOo8oo`0nool0?coo03koo`0[?om087oPOnT
oo`0nOog0?Soo03Goo`0POn1oh7ob?ol0?_oo03loo`0nool0:coo@21olSo08b1
omgoo03hooT0mool0=Ooo021oh7oPOo8oo`0nool0?coo@3joo`0[?om087oPOnT
oo`0n?oi0?Ooo03Goo`0POn1oh7ob?ol0?_oo03lood0n_ol0:coo@21oh7oY?ol
0?Son@3goo`0eool087oPOn1olSoo03koo`0o?om0?[oo02/ood0POo8o`2<POoM
oo`0n?oi0?Ooo03Goo`0POn1oh7ob?ol0?_on`3noo`0n_ol0:coo@21oh7oY?ol
0?Son@3goo`0eool087oPOn1olSoo03koo/0o_ol0?[oo02/ood0POn1ojCoo03h
ooT0mool0=Ooo021oh7oPOo8oo`0nook0?koo03joo`0[?om087ob?l0S87ogOol
0?Son@3goo`0eool087oPOn1olSoo03joo`0o_om0?Woo02/ood0POn1ojCoo03h
ooT0mool0=Ooo021oh7oPOo8oo`0n_ol0?koo@3ioo`0[?om087oPOnToo`0n?oi
0?Ooo03Goo`0POn1oh7ob?ol0?[oo03nood0nOol0:coo@21olSo08b1omgoo03g
oo/0m_ol0=Ooo021oh7oPOo8oo`0n_ok003oo03ioo`0[?om087oPOnToo`0mook
0?Koo03Goo`0POn1oh7ob?ol0?[on`00oo`0nOol0:coo@21oh7oY?ol0?Oon`3f
oo`0eool087oPOn1olSoo03joo/00?ol0?Woo02/ood0POo8o`2<POoMoo`0mook
0?Koo03Goo`0POn1oh7ob?ol0?Woo000ood0n?ol0:coo@21oh7oY?ol0?Oon`3f
oo`0eool087oPOn1olSoo03ioo`00?om0?Soo02/ood0POn1ojCoo03goo/0m_ol
0=Ooo021oh7oPOo8oo`0nOol003oo@3hoo`0[?om087ob?l0M87ogOol0>Koo03G
oo`0POn1oh7ob?ol0?Wom`3hoo`0[?om087oPOnToo`0i_ol0=Ooo021oh7oPOo8
oo`0nOog0?Soo02/ood0POn1ojCoo03Voo`0eool087oPOn1olSoo03iooL0n?ol
0:coo@21olSo07B1omgoo03Voo`0eool087oPOn1olSoo03hooT0mool0:coo@21
oh7oY?ol0>Koo03Goo`0POn1oh7ob?ol0?Son@3goo`0[?om087oPOnToo`0i_ol
0=Ooo021oh7oPOo8oo`0n?oi0?Ooo02/ood0POo8o`1dPOoMoo`0i_ol0=Ooo021
oh7oPOo8oo`0n?oi0?Ooo02/ood0POn1ojCoo03Voo`0eool087oPOn1olSoo03h
ooT0mool0:coo@21oh7oY?ol0>Koo03Goo`0POn1oh7ob?ol0?Son@3goo`0[?om
087ob?l0M87ogOol0>Koo03Goo`0POn1oh7ob?ol0?Son@3goo`0[?om087oPOnT
oo`0i_ol0=Ooo021oh7oPOo8oo`0n?oi0?Ooo02/ood0POn1ojCoo03Voo`0eool
087oPOn1olSoo03hooT0mool0:coo@21olSo07B1omgoo03Voo`0eool087oPOn1
olSoo03goo/0m_ol0:coo@21oh7oY?ol0>Koo03Goo`0POn1oh7ob?ol0?Oon`3f
oo`0[?om087oPOnToo`0i_ol0=Ooo021oh7oPOo8oo`0mook0?Koo02/ood0POo8
o`1dPOoMoo`0i_ol0=Ooo021oh7oPOo8oo`0mook0?Koo02/ood0POn1ojCoo03V
oo`0eool087oPOn1olSoo03goo/0m_ol0:coo@21oh7oY?ol0>Koo03Goo`0POn1
oh7ob?ol0?Oon`3foo`0[?om087ob?l0BX7oPOn1oh7oPOo@oo`0i_ol0:coo@21
oh7oPOn1oh7oPOnGoo`0i_ol0:coo@21oh7oPOn1oh7oPOnGoo`0i_ol0:coo@21
olSo04Z1oh7oPOn1oh7od?ol0>Koo02/ood0POn1oh7oPOn1oh7oUool0>Koo02/
ood0POn1oh7oPOn1oh7oUool0>Koo02/ood0POo8o`1:POn1oh7oPOn1om3oo03V
oo`0[?om087oPOn1oh7oPOn1oiOoo03Voo`0[?om087oPOn1oh7oPOn1oiOoo03V
oo`0[?om087ob?l0BX7oPOn1oh7oPOo@oo`0i_ol0:coo@21oh7oPOn1oh7oPOnG
oo`0i_ol0:coo@21oh7oPOn1oh7oPOnGoo`0i_ol0:coo@21olSo04Z1oh7oPOn1
oh7od?ol0>Koo02/ood0POn1oh7oPOn1oh7oUool0>Koo02/ood0POn1oh7oPOn1
oh7oUool0>Koo02/ood0POo8o`1:POn1oh7oPOn1om3oo03Voo`0[?om087oPOn1
oh7oPOn1oiOoo03Voo`0[?om087oPOn1oh7oPOn1oiOoo03Voo`0[?om087ob?l0
>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1
oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1
oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1
oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21
oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1
oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8
o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1
oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21
oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1
oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om
087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1
oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21
olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1
oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom
087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1
oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoF
ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1
oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom
087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1
oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnM
ood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1
oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1
omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1
oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnM
ood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1
oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1
oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1
oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1
oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0
>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1
oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1
oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1
oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21
oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1
oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8
o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1
oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21
oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1
oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om
087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1
oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21
olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1
oh7oPOnMood0POo8o`14POn1oh7oPOn1oh7oe_om0=_onP21oh7oPOn1oh7oPOn1
ol[oo@3KooX0POn1oh7oPOn1oh7oPOo:ood0fooj087omOl0A87oPOn1oh7oPOn1
omKoo@3KooX0POn1oh7oPOn1oh7oPOo:ood0fooj087oPOn1oh7oPOn1oh7ob_om
0=_onP21ooGo04B1oh7oPOn1oh7oPOoFood0fooj087oPOn1oh7oPOn1oh7ob_om
0=_onP21oh7oPOn1oh7oPOn1ol[oo@3KooX0POoeo`14POn1oh7oPOn1oh7oe_om
0=_onP21oh7oPOn1oh7oPOn1ol[oo@3KooX0POn1oh7oPOn1oh7oPOo:ood0fooj
087omOl0A87oPOn1oh7oPOn1omKoo@3KooX0POn1oh7oPOn1oh7oPOo:ood0fooj
087oPOn1oh7oPOn1oh7ob_om0=_onP21ooGo04B1oh7oPOn1oh7oPOoFood0fooj
087oPOn1oh7oPOn1oh7ob_om0=_onP21oh7oPOn1oh7oPOn1ol[oo@3KooX0POoe
o`14POn1oh7oPOn1oh7oe_om0=_onP21oh7oPOn1oh7oPOn1ol[oo@3KooX0POn1
oh7oPOn1oh7oPOo:ood0fooj087omOl0A87oPOn1oh7oPOn1omKoo@3KooX0POn1
oh7oPOn1oh7oPOo:ood0fooj087oPOn1oh7oPOn1oh7ob_om0=_onP21ooGo04B1
oh7oPOn1oh7oPOoFood0fooj087oPOn1oh7oPOn1oh7ob_om0=_onP21oh7oPOn1
oh7oPOn1ol[oo@3KooX0POoeo`14POn1oh7oPOn1oh7oe_om0=_onP21oh7oPOn1
oh7oPOn1ol[oo@3KooX0POn1oh7oPOn1oh7oPOo:ood0fooj087omOl0A87oPOn1
oh7oPOn1omKoo@3KooX0POn1oh7oPOn1oh7oPOo:ood0fooj087oPOn1oh7oPOn1
oh7ob_om0=_onP21ooGo04B1oh7oPOn1oh7oPOoFood0fooj087oPOn1oh7oPOn1
oh7ob_om0=_onP21oh7oPOn1oh7oPOn1ol[oo@3KooX0POoeo`14POn1oh7oPOn1
oh7oe_om0=_onP21oh7oPOn1oh7oPOn1ol[oo@3KooX0POn1oh7oPOn1oh7oPOo:
ood0fooj087omOl0A87oPOn1oh7oPOn1omKoo@3KooX0POn1oh7oPOn1oh7oPOo:
ood0fooj087oPOn1oh7oPOn1oh7ob_om0=_onP21ooGo04B1oh7oPOn1oh7oPOoF
ood0fooj087oPOn1oh7oPOn1oh7ob_om0=_onP21oh7oPOn1oh7oPOn1ol[oo@3K
ooX0POoeo`14POn1oh7oPOn1oh7oe_om0=_onP21oh7oPOn1oh7oPOn1ol[oo@3K
ooX0POn1oh7oPOn1oh7oPOo:ood0fooj087omOl0A87oPOn1oh7oPOn1omKoo@3K
ooX0POn1oh7oPOn1oh7oPOo:ood0fooj087oPOn1oh7oPOn1oh7ob_om0=_onP21
ooGo05J1oh7oPOn1oh7oPOoFood0fooj0?Son@3NooP0POn1oh7oPOn1oh7oQoom
0=_onP3hooT0g_oh087oPOn1oh7oPOn1ohOoo@3KooX0n?oi0=kon02bo`1jPOn1
oh7oPOn1oh7oe_om0=_onP3jooD0hoob0>gonP3]ooX0n?oj087oPOn1oh7oPOn1
om3oo@3KooX0n_oe0>?olP3]ooX0kOoj0?SonP21oh7oPOn1oh7oPOo@ood0fooj
0?[om@3Soo80kOoj0>gonP3hooX0nol0Q87oPOn1oh7oPOn1omKoo@3KooX0o?oa
0>OokP3_ooX0kOoj0?SonP3lo`00POn1oh7oPOn1oh7oe_om0=_onP3loo40ioo^
0>oonP3]ooX0n?oj0?co0021oh7oPOn1oh7oPOoFood0fooj0?col@3Wonh0kooj
0>gonP3hooX0o?l00027POn1oh7oPOn1oh7oe_om0=_onP3monl0j_oZ0?7onP3]
ooX0n?oj0?go0@00POn1oh7oPOn1oh7oe_om0=_onP3monl0j_oZ0?7onP3]ooX0
n?oj0?go0@00POn1oh7oPOn1oh7oe_om0=_onP3monl0j_oZ0?7onP3]ooX0n?oj
0?go0@0008B1oh7oPOn1oh7oPOoFood0fooj0?kok@3/onP0l_oj0>gonP3hooX0
o_on087oPOn1oh7oPOn1omKoo@3KooX0o_o]0>coj03booX0kOoj0?SonP3nooh0
POn1oh7oPOn1oh7oe_om0=_onP3nond0k?oX0?;onP3]ooX0n?oj0?kooP00RX7o
POn1oh7oPOn1omKoo@3KooX00Oooj`3^onH0looj0>gonP3hooX00Oooo@21oh7o
POn1oh7oPOoFood0fooj007oon/0k_oV0??onP3]ooX0n?oj007oood0POn1oh7o
POn1oh7oe_om0=_onP01ooo[0>koiP3cooX0kOoj0?SonP01ooom002LPOn1oh7o
POn1oh7oe_om0=_onP00ooX0noof0?3omP3jooH0m?oj0>gonP3hooX00?ol087o
POn1oh7oPOn1omKoo@3KooX00?oj0?_omP3`ooH0n_of0?ConP3]ooX0n?oj003o
o021oh7oPOn1oh7oPOoFood0fooj003onP3kooH0l?of0?[omP3dooX0kOoj0?So
nP00oo`008B1oh7oPOn1oh7oPOoFood0food0?Oom`3booL0m_og0?GonP3]ooX0
n?od087oPOn1oh7oPOn1omKoo@3Koo@0moog0?;om`3fooL0mOoj0>gonP3hoo@0
POn1oh7oPOn1oh7oe_om0=_om03gooL0l_og0?Kom`3eooX0kOoj0?Som000QX7o
POn1oh7oPOn1omKoo@3KooD0m?oi0??on03booP0m_oj0>gonP3hooD0POn1oh7o
POn1oh7oeOom0=_om@3dooT0looh0?;on03fooX0kOoj0?Som@21oh7oPOn1oh7o
POoEood0fooe0?Con@3cooP0l_oh0?KonP3]ooX0n?oe003o08N1oh7oPOn1oh7o
POoFood0foof0?;on@3dooT0l?oi0?KonP3]ooX0n?of087oPOn1oh7oPOn1omCo
o@3KooH0l_oi0?Con@3`ooT0m_oj0>gonP3hooH0POn1oh7oPOn1oh7oe?om0=_o
mP3booT0m?oi0?3on@3fooX0kOoj0?SomP01ool0QX7oPOn1oh7oPOn1omKoo@3K
ooL0l?oj0?Gon@3^ooT0mooj0>gonP3hooL0POn1oh7oPOn1oh7odoom0=_om`3`
ooX0mOoi0>kon@3gooX0kOoj0?Som`21oh7oPOn1oh7oPOoCood0foog0?3onP3e
ooT0k_oi0?OonP3]ooX0n?og0?ko08J1oh7oPOn1oh7oPOoFood0fooh0>oonP3e
ooT0k_oi0?OonP3]ooX0n?oh087oPOn1oh7oPOn1om;oo@3KooP0kooj0?Gon@3^
ooT0mooj0>gonP3hooP0POn1oh7oPOn1oh7od_om0=_on03_ooX0mOoi0>kon@3g
ooX0kOoj0?Son03mo`26POn1oh7oPOn1oh7oe_om0=_on03^ooX0mooi0>con@3h
ooX0kOoj0?Son021oh7oPOn1oh7oPOoBood0fooh0>konP3gooT0k?oi0?SonP3]
ooX0n?oh087oPOn1oh7oPOn1om;oo@3KooP0k_oj0?Oon@3/ooT0n?oj0>gonP3h
ooP0oOl0QX7oPOn1oh7oPOn1omKoo@3KooT0kOoj0?Oon@3[ooX0n?oj0>gonP3h
ooT0POn1oh7oPOn1oh7odOom0=_on@3]ooX0mooi0>_onP3hooX0kOoj0?Son@21
oh7oPOn1oh7oPOoAood0fooi0>gonP3gooT0jooj0?SonP3]ooX0n?oi0?co08J1
oh7oPOn1oh7oPOoFood0fooi0>gonP3gooX0j_oj0?SonP3]ooX0n?oi087oPOn1
oh7oPOn1om7oo@3KooT0kOoj0?OonP3ZooX0n?oj0>gonP3hooT0POn1oh7oPOn1
oh7odOom0=_on@3]ooX0mooj0>[onP3hooX0kOoj0?Son@3lo`26POn1oh7oPOn1
oh7oe_om0=_on@3]ooX0mooj0>[onP3hooX0kOoj0?Son@21oh7oPOn1oh7oPOoA
ood0fooi0>gonP3gooX0j_oj0?SonP3]ooX0n?oi087oPOn1oh7oPOn1om7oo@3K
ooT0kOoj0?OonP3ZooX0n?oj0>gonP3hooT0o?l0QX7oPOn1oh7oPOn1omKoo@3K
ooT0k?oj0?Won@3ZooT0nOoj0>gonP3hooX0POn1oh7oPOn1oh7od?om0=_on@3/
ooX0nOoi0>[on@3iooX0kOoj0?SonP21oh7oPOn1oh7oPOo@ood0fooi0>conP3i
ooT0j_oi0?WonP3]ooX0n?oj0?_o08J1oh7oPOn1oh7oPOoFood0fooj0>_onP3i
ooX0j?oj0?WonP3]ooX0n?oj087oPOn1oh7oPOn1om3oo@3KooX0jooj0?WonP3X
ooX0nOoj0>gonP3hooX0POn1oh7oPOn1oh7od?om0=_onP3[ooX0nOoj0>SonP3i
ooX0kOoj0?SonP3ko`26POn1oh7oPOn1oh7oe_om0=_onP3[ooX0nOoj0>SonP3i
ooX0kOoj0?SonP21oh7oPOn1oh7oPOo@ood0fooj0>_onP3iooX0j?oj0?WonP3]
ooX0n?oj087oPOn1oh7oPOn1om3oo@3KooX0jooj0?WonP3XooX0nOoj0>gonP3h
ooX0nol0QX7oPOn1oh7oPOn1omKoo@3KooX0jooj0?WonP3XooX0nOoj0>gonP3h
ooX0POn1oh7oPOn1oh7od?om0=_onP3[ooX0nOoj0>SonP3iooX0kOoj0?SonP21
oh7oPOn1oh7oPOo@ood0fooj0>_onP3iooX0j?oj0?WonP3]ooX0n?oj0?_o08J1
oh7oPOn1oh7oPOoFood0fooj0>_onP3iooX0j?oj0?WonP3]ooX0n?oj087oPOn1
oh7oPOn1om3oo@3KooX0jooj0?WonP3XooX0nOoj0>gonP3hooX0POn1oh7oPOn1
oh7od?om0=_onP3[ooX0nOoj0>SonP3iooX0kOoj0?SonP3ko`26POn1oh7oPOn1
oh7oe_om0=_onP3[ooX0nOoj0>SonP3iooX0kOoj0?SonP21oh7oPOn1oh7oPOo@
ood0fooj0>_onP3iooX0j?oj0?WonP3]ooX0n?oj087oPOn1oh7oPOn1om3oo@3K
ooX0jooj0?WonP3XooX0nOoj0>gonP3hooX0nol0QX7oPOn1oh7oPOn1omKoo@3K
ooX0jooj0?WonP3XooX0nOoj0>gonP3hooX0POn1oh7oPOn1oh7od?om0=_onP3[
ooX0nOoj0>SonP3iooX0kOoj0?SonP21oh7oPOn1oh7oPOo@ood0fooj0>_onP3i
ooX0j?oj0?WonP3]ooX0n?oj0?_o08J1oh7oPOn1oh7oPOoFood0fooj0>_onP3i
ooX0j?oj0?WonP3]ooX0n?oj087oPOn1oh7oPOn1om3oo@3KooX0jooj0?WonP3X
ooX0nOoj0>gonP3hooX0POn1oh7oPOn1oh7od?om0=_onP3[ooX0nOoj0>SonP3i
ooX0kOoj0?SonP3ko`26POn1oh7oPOn1oh7oe_om0=_onP3[ooX0nOoj0>SonP3i
ooX0kOoj0?SonP21oh7oPOn1oh7oPOo@ood0fooj0>_onP3iooX0j?oj0?WonP3]
ooX0n?oj087oPOn1oh7oPOn1om3oo@3KooX0jooj0?WonP3XooX0nOoj0>gonP3h
ooX0nol0QX7oPOn1oh7oPOn1omKoo@3KooX0jooj0?WonP3XooX0nOoj0>gonP3h
ooX0POn1oh7oPOn1oh7od?om0=_onP3[ooX0nOoj0>SonP3iooX0kOoj0?SonP21
oh7oPOn1oh7oPOo@ood0fooj0>_onP3iooX0j?oj0?WonP3]ooX0n?oj0?_o08J1
oh7oPOn1oh7oPOoFood0fooj0>_onP3iooT0j_oi0?WonP3]ooX0n?oj087oPOn1
oh7oPOn1om3oo@3KooX0jooj0?Won@3ZooT0nOoj0>gonP3hooX0POn1oh7oPOn1
oh7od?om0=_onP3[ooX0nOoi0>[on@3iooX0kOoj0?SonP3ko`26POn1oh7oPOn1
oh7oe_om0=_on@3]ooX0mooj0>[onP3hooX0k_oi0?SonP21oh7oPOn1oh7oPOo@
ood0fooi0>gonP3gooX0j_oj0?SonP3^ooT0n?oj087oPOn1oh7oPOn1om3oo@3K
ooT0kOoj0?OonP3ZooX0n?oj0>kon@3hooX0nol0QX7oPOn1oh7oPOn1omKoo@3K
ooT0kOoj0?OonP3ZooX0n?oj0>kon@3hooX0POn1oh7oPOn1oh7od?om0=_on@3]
ooX0mooj0>[onP3hooX0k_oi0?SonP21oh7oPOn1oh7oPOo@ood0fooi0>gonP3g
ooX0j_oj0?SonP3^ooT0n?oj0?_o08J1oh7oPOn1oh7oPOoFood0fooi0>gonP3g
ooT0jooj0?SonP3^ooT0n?oj087oPOn1oh7oPOn1om3oo@3KooT0kOoj0?Oon@3[
ooX0n?oj0>kon@3hooX0POn1oh7oPOn1oh7od?om0=_on@3]ooX0mooi0>_onP3h
ooX0k_oi0?SonP3ko`26POn1oh7oPOn1oh7oe_om0=_on03_ooT0mooi0>con@3h
ooX0kooh0?SonP21oh7oPOn1oh7oPOo@ood0fooh0>oon@3gooT0k?oi0?SonP3_
ooP0n?oj087oPOn1oh7oPOn1om3oo@3KooP0kooi0?Oon@3/ooT0n?oj0>oon03h
ooX0nol0QX7oPOn1oh7oPOn1omKoo@3KooP0kooj0?Gon@3^ooT0mooi0?3on03h
ooX0POn1oh7oPOn1oh7od?om0=_on03_ooX0mOoi0>kon@3gooT0l?oh0?SonP21
oh7oPOn1oh7oPOo@ood0fooh0>oonP3eooT0k_oi0?Oon@3`ooP0n?oj0?_o08J1
oh7oPOn1oh7oPOoFood0foog0?7on@3eooT0k_oi0?Oon@3aooL0n?oj087oPOn1
oh7oPOn1om3oo@3KooL0lOoi0?Gon@3^ooT0mooi0?7om`3hooX0POn1oh7oPOn1
oh7od?om0=_om`3aooT0mOoi0>kon@3gooT0lOog0?SonP3ko`26POn1oh7oPOn1
oh7oe_om0=_om`3aooT0m?oi0?3on@3eooX0l_of0?SonP21oh7oPOn1oh7oPOo@
ood0foog0?7on@3dooT0l?oi0?GonP3booH0n?oj087oPOn1oh7oPOn1om3oo@3K
ooL0lOoi0?Con@3`ooT0mOoj0?;omP3hooX0nol0QX7oPOn1oh7oPOn1omKoo@3K
ooH0looi0??on03booP0mOoi0?Com@3hooX0POn1oh7oPOn1oh7od?om0=_omP3c
ooT0looh0?;on03eooT0m?oe0?SonP21oh7oPOn1oh7oPOo@ood0foof0??on@3c
ooP0l_oh0?Gon@3dooD0n?oj0?_o08J1oh7oPOn1oh7oPOoFood0food0?Oom`3b
ooL0m_og0?Con03foo@0n?oj087oPOn1oh7oPOn1om3oo@3Koo@0moog0?;om`3f
ooL0m?oh0?Kom03hooX0POn1oh7oPOn1oh7od?om0=_om03gooL0l_og0?Kom`3d
ooP0m_od0?SonP3ko`2QPOn1oh7oPOn1oh7oe_om0=_on`01oooj0?_omP3`ooH0
n_of0?;om`3kooT00?oj0?SonP21oh7oPOn1oh7oPOo@ood0fook007oooX0noof
0?3omP3jooH0l_og0?_on@00ooX0n?oj087oPOn1oh7oPOn1om3oo@3Koo/00Ooo
nP3kooH0l?of0?[omP3booL0nooi003onP3hooX0nol0OH7oPOn1oh7oPOn1omKo
o@3LooX0o_o[0>koiP3aonX00OoonP3hooX0POn1oh7oPOn1oh7od?om0=conP3n
on/0k_oV0?7ojP01oooj0?SonP21oh7oPOn1oh7oPOo@ood0g?oj0?koj`3^onH0
lOoZ007oooX0n?oj0?_o07Z1oh7oPOn1oh7oPOoFood0g?oj0?kok03/onP0koo/
0?konP3hooX0POn1oh7oPOn1oh7od?om0=conP3non`0k?oX0>ook03nooX0n?oj
087oPOn1oh7oPOn1om3oo@3LooX0o_o/0>coj03_on`0o_oj0?SonP3ko`1jPOn1
oh7oPOn1oh7oe_om0=conP3monh0j_oZ0>gokP3mooX0n?oj087oPOn1oh7oPOn1
om3oo@3LooX0oOo^0>[ojP3]onh0oOoj0?SonP21oh7oPOn1oh7oPOo@ood0g?oj
0?gokP3ZonX0kOo^0?gonP3hooX0nol0NX7oPOn1oh7oPOn1omKoo@3Loo/0n_oa
0>OokP3Zoo00o?oj0?SonP21oh7oPOn1oh7oPOo@ood0g?ok0?[ol@3Wonh0j_o`
0?conP3hooX0POn1oh7oPOn1oh7od?om0=con`3joo40ioo^0>[ol03looX0n?oj
0?_o07Z1oh7oPOn1oh7oPOoFood0g?ok0?Wom03Soo80i_od0?[onP3hooX0POn1
oh7oPOn1oh7od?om0=con`3ioo@0hoob0>Kom03jooX0n?oj087oPOn1oh7oPOn1
om3oo@3Loo/0nOod0>?olP3Voo@0n_oj0?SonP3ko`1FPOn1oh7oPOn1oh7oe_om
0<_on@3NooP0h?oj087oPOn1oh7oPOn1ojooo@3;ooT0g_oh0>3onP21oh7oPOn1
oh7oPOn_ood0booi0=kon03PooX0f_l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1
oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoF
ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1
oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom
087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1
oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnM
ood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1
oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1
omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1
oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnM
ood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1
oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1
oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1
oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1
oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0
>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1
oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1
oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1
oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21
oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1
oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8
o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1
oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21
oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1
oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om
087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1
oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21
olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1
oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom
087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1
oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoF
ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1
oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom
087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1
oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnM
ood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1
oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0E^go0961oh7ol_l0
TH7oPOoao`2APOn<ood0POndo`2APOn1oo;o0961oh7olOl0TH7oS?om087o]?l0
TH7oPOobo`2APOn1oo7o0961ohcoo@21olSo05KcooBAPOn1ookom961oh7ooOod
TH7oT_om087o^_odTH7oPOonooBAPOn1oogom961oi;oo@21ok[om961oh7oo_od
TH7oPOomooBAPOnBood0POo8o`1:mOo`TH7oPOoaTH7oPOo`TH7oU?om087o_?o`
TH7oPOoaTH7oPOo`TH7oU?om087o_?o`TH7oPOoaTH7oPOo`TH7oU?om087ob?l0
B_KokY61ohCokI61ohCokY61oiGoo@21okgokY61ohCokI61ohCokY61oiGoo@21
okgokY61ohCokI61ohCokY61oiGoo@21olSo04[honZAPOn8onZAPOn7onZAPOnG
ood0POnoonZAPOn8onZAPOn7onZAPOnGood0POnoonZAPOn8onZAPOn7onZAPOnG
ood0POo8o`1^n?okTOKoni61ohSonY7gooZAPOn8oo^Am_okTH7oUoom087o_ook
TOKoni61ohSonY7gooZAPOn8oo^Am_okTH7oUoom087o_ookTOKoni61ohSonY7g
ooZAPOn8oo^Am_okTH7oUoom087ob?l0K_Woni7doo^APOn:ooZAm?okTH7oR_ok
TOConi61oiSoo@21ol3oni7doo^APOn:ooZAm?okTH7oR_okTOConi61oiSoo@21
ol3oni7doo^APOn:ooZAm?okTH7oR_okTOConi61oiSoo@21olSo06kioobAl_ok
TH7oRoolTO7oni61oh_oo97boo^APOnIood0POo0oobAl_okTH7oRoolTO7oni61
oh_oo97boo^APOnIood0POo0oobAl_okTH7oRoolTO7oni61oh_oo97boo^APOnI
ood0POo8o`1^n_omTNkooI61ohcoo97_oobAPOn<oofAk_omTH7oVOom087o`Oom
TNkooI61ohcoo97_oobAPOn<oofAk_omTH7oVOom087o`OomTNkooI61ohcoo97_
oobAPOn<oofAk_omTH7oVOom087ob?l0K_coni7]oofAPOn>oo^Ak_olTH7oSook
TNgooI61oi[oo@21ol?oni7]oofAPOn>oo^Ak_olTH7oSookTNgooI61oi[oo@21
ol?oni7]oofAPOn>oo^Ak_olTH7oSookTNgooI61oi[oo@21olSo06kloobAk?om
TH7oS_olTNgoo961ohooo97/oofAPOnJood0POo3oobAk?omTH7oS_olTNgoo961
ohooo97/oofAPOnJood0POo3oobAk?omTH7oS_olTNgoo961ohooo97/oofAPOnJ
ood0POo8o`1^o?omTN_ooI61ohkooI7[oofAPOn?oofAjoomTH7oV_om087o`oom
TN_ooI61ohkooI7[oofAPOn?oofAjoomTH7oV_om087o`oomTN_ooI61ohkooI7[
oofAPOn?oofAjoomTH7oV_om087ob?l0K_cooI7[oobAPOn?oofAjoolTH7oT?om
TN_oo961oi_oo@21ol?ooI7[oobAPOn?oofAjoolTH7oT?omTN_oo961oi_oo@21
ol?ooI7[oobAPOn?oofAjoolTH7oT?omTN_oo961oi_oo@21olSo06kmoobAj_om
TH7oT?olTN[ooI61oi7oo97ZoofAPOnKood0POo4oobAj_omTH7oT?olTN[ooI61
oi7oo97ZoofAPOnKood0POo4oobAj_omTH7oT?olTN[ooI61oi7oo97ZoofAPOnK
ood0POo8o`1^oOomTNWooI61oi3ooI7YoofAPOnAoofAjOomTH7oVoom087oa?om
TNWooI61oi3ooI7YoofAPOnAoofAjOomTH7oVoom087oa?omTNWooI61oi3ooI7Y
oofAPOnAoofAjOomTH7oVoom087ob?l0K_gooI7YoofAPOn@oofAjOomTH7oTOom
TNWooI61oi_oo@21olCooI7YoofAPOn@oofAjOomTH7oTOomTNWooI61oi_oo@21
olCooI7YoofAPOn@oofAjOomTH7oTOomTNWooI61oi_oo@21olSo06kmoofAjOom
TH7oT?omTNWooI61oi7ooI7YoofAPOnKood0POo4oofAjOomTH7oT?omTNWooI61
oi7ooI7YoofAPOnKood0POo4oofAjOomTH7oT?omTNWooI61oi7ooI7YoofAPOnK
ood0POo8o`1^oOomTNWooI61oi3ooI7YoofAPOnAoofAjOomTH7oVoom087oa?om
TNWooI61oi3ooI7YoofAPOnAoofAjOomTH7oVoom087oa?omTNWooI61oi3ooI7Y
oofAPOnAoofAjOomTH7oVoom087ob?l0K_goo97ZoofAPOn@oobAj_omTH7oTOol
TN[ooI61oi_oo@21olCoo97ZoofAPOn@oobAj_omTH7oTOolTN[ooI61oi_oo@21
olCoo97ZoofAPOn@oobAj_omTH7oTOolTN[ooI61oi_oo@21olSo06kloofAjool
TH7oSoomTN_oo961oi3ooI7[oobAPOnKood0POo3oofAjoolTH7oSoomTN_oo961
oi3ooI7[oobAPOnKood0POo3oofAjoolTH7oSoomTN_oo961oi3ooI7[oobAPOnK
ood0POo8o`1^o?omTN_ooI61ohkooI7[oofAPOn?oofAjoomTH7oV_om087o`oom
TN_ooI61ohkooI7[oofAPOn?oofAjoomTH7oV_om087o`oomTN_ooI61ohkooI7[
oofAPOn?oofAjoomTH7oV_om087ob?l0K_coo97/oofAPOn>oobAkOolTH7oSool
TNcooI61oi[oo@21ol?oo97/oofAPOn>oobAkOolTH7oSoolTNcooI61oi[oo@21
ol?oo97/oofAPOn>oobAkOolTH7oSoolTNcooI61oi[oo@21olSo06kkoobAkOom
TH7oS_okTNkoo961ohkoo97]oofAPOnJood0POo2oobAkOomTH7oS_okTNkoo961
ohkoo97]oofAPOnJood0POo2oobAkOomTH7oS_okTNkoo961ohkoo97]oofAPOnJ
ood0POo8o`1^n_omTNkooI61ohcoo97_oobAPOn<oofAk_omTH7oVOom087o`Oom
TNkooI61ohcoo97_oobAPOn<oofAk_omTH7oVOom087o`OomTNkooI61ohcoo97_
oobAPOn<oofAk_omTH7oVOom087ob?l0K_[oo97`oobAPOn<oo^AlOokTH7oS?ol
TO3oo961oiWoo@21ol7oo97`oobAPOn<oo^AlOokTH7oS?olTO3oo961oiWoo@21
ol7oo97`oobAPOn<oo^AlOokTH7oS?olTO3oo961oiWoo@21olSo06kioo^Alool
TH7oR_okTO?oni61oh[oni7coobAPOnHood0POo0oo^AloolTH7oR_okTO?oni61
oh[oni7coobAPOnHood0POo0oo^AloolTH7oR_okTO?oni61oh[oni7coobAPOnH
ood0POo8o`1^n?okTOKonY61ohWonY7fooZAPOn9oo^Am_ojTH7oV?om087o_ook
TOKonY61ohWonY7fooZAPOn9oo^Am_ojTH7oV?om087o_ookTOKonY61ohWonY7f
ooZAPOn9oo^Am_ojTH7oV?om087ob?l0K_SonY7hoo^APOn6ooZAnOojTH7oQooj
TOSoni61oiKoo@21okoonY7hoo^APOn6ooZAnOojTH7oQoojTOSoni61oiKoo@21
okoonY7hoo^APOn6ooZAnOojTH7oQoojTOSoni61oiKoo@21olSo04[fonjAPOn3
onnAPOn3onjAPOnEood0POnmonjAPOn3onnAPOn3onjAPOnEood0POnmonjAPOn3
onnAPOn3onjAPOnEood0POo8o`1Fm?obTH7oPOl0oo6APOn1o`3olY61oi?oo@21
ok_olY61oh7o0?oaTH7oPOl0oo:APOnCood0POnkoo:APOn1o`3olI61oh7o0?ob
TH7oToom087ob?l0E_?om961oh7oo_odTH7oPOomooBAPOnBood0POnjooBAPOn1
ookom961oh7ooOodTH7oT_om087o^_odTH7oPOonooBAPOn1oogom961oi;oo@21
olSo05KcooFAPOn1oocomI61oh7ooOoeTH7oTOom087o^_oeTH7oPOolooFAPOn1
oogomI61oi7oo@21ok[omI61oh7oo?oeTH7oPOomooFAPOnAood0POo8o`0hPOn1
oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom
087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1
oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnM
ood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1
oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1
omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1
oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnM
ood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1
oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1
oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1
oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1
oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0
>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1
oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1
oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1
oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21
oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1
oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8
o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1
oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21
oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1
oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om
087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1
oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21
olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1
oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom
087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1
oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoF
ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1
oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom
087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1
oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnM
ood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1
oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1
omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1
oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnM
ood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1
oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1
oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1
oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1
oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0
>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1
oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1
oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1
oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21
oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1
oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8
o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1
oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21
oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1
oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om
087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1
oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21
olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1
oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom
087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1
oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoF
ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1
oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom
087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1
oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnM
ood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1
oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1
omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1
oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnM
ood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1
oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1
oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1
oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1
oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0
>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1
oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1
oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1
oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21
oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1
oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8
o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1
oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21
oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1
oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om
087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1
oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21
olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1
oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom
087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1
oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoF
ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1
oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom
087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1
oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnM
ood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1
oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1
omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1
oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnM
ood0POo8o`0hPOn1oh7oPOn1oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1
oh7oPOn1oh7oWOom087ob?l0>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1
oigoo@21oh7oPOn1oh7oPOn1oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1
oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POo8o`0hPOn1oh7oPOn1
oh7oe_om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087ob?l0
>87oPOn1oh7oPOn1omKoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1
oigoo@21olSo03R1oh7oPOn1oh7oPOoFood0POn1oh7oPOn1oh7oPOnMood0POn1
oh7oPOn1oh7oPOnMood0POo8o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl009X0003oPi`000000XX0i`0000@00000
04P000180000400P00<02000000000001J:hW0000002RP3P0003j`::1<P0000<
POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7o
POn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco
00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7o
POn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7o
c?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387o
POn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7o
POo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<
POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7o
POn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco
00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7o
POn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7o
c?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387o
POn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7o
POo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<
POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7o
POn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco
00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7o
POn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7o
c?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387o
POn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7o
POo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<
POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7o
POn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco
00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7o
POn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7o
c?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387o
POn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7o
POo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<
POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7o
POn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco
00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7o
POn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7o
c?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387o
POn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7o
POo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<
POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7o
POn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco
00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7o
POn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7o
c?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387o
POn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7o
POo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<
POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7o
POn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco
00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7o
POn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7o
c?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387o
POn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7o
POo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<
POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7o
POn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco
00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7o
POn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7o
c?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387o
POn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7o
POo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<
POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7o
POn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco
00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7o
POn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7o
c?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387o
POn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7o
POo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<
POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7o
POn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco
00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7o
POn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7o
c?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387o
POn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7o
POo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<
POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7o
POn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco
00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7o
POn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7o
c?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387o
POn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7o
POo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<
POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7o
POn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco
00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7o
POn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7o
c?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387o
POn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7o
POo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<
POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7o
POn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco
00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7o
POn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7o
c?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387o
POn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7o
POo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<
POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7o
POn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco
00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7o
POn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7o
c?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387o
POn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7o
POo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<
POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7o
POn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco
00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7o
POn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7o
c?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387o
POn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7o
POo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<
POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7o
POn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco
00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7o
POn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7o
c?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387o
POn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7o
POo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<
POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7o
POn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco
00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7o
POn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7o
c?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387o
POn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7o
POo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<
POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7o
POn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco
00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7o
POn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7o
c?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387o
POn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7o
POo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<
POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7o
POn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco
00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco01C5ooX0
POnQooX0POnQooX0POoMo`0DaOoj087oXOoj087oXOoj087ogOl05<GonP21oj7o
nP21oj7onP21omgo01C5ooX0POnQooX0POnQooX0POoMo`0DaOoj087oXOoj087o
XOoj087ogOl05<GonP21oj7onP21oj7onP21omgo01C5ooX0POnQooX0POnQooX0
POoMo`0DaOoj087oXOoj087oXOoj087ogOl05<GonP21oj7onP21oj7onP21omgo
01C5ooX0POnQooX0POnQooX0POoMo`0DaOoj087oXOoj087oXOoj087ogOl05<Go
nP21oj7onP21oj7onP21omgo01C5ooX0POnQooX0POnQooX0POoMo`0DaOoj087o
XOoj087oXOoj087ogOl05<GonP21oj7onP21oj7onP21omgo01C5ooX0POnQooX0
POnQooX0POoMo`0DaOoj087oXOoj087oXOoj087ogOl0?_gon@3RooT0n?oj0>co
m`3MooX0Xooi0>;on@3hooX0k?og0=gonP2SooT0h_oi0?SonP3/ooL0gOoj0:Oo
06D0oo@0iooc0?_onP3`oo00l?oj0?_om`01oooi0>SonP3@oo@0iooc0?_onP3`
oo00l?oj0?_om`01oooi0>SonP3@oo@0iooc0?_onP3`oo00l?oj0?_om`01oooi
0>SonP3Ao`1Pl@3[oo00o?oj0?;ok03booX0o?of0?konP3Xoo/0d?oa0>_ol03l
ooX0l_o/0?;onP3looH0o_oj0>Son`3@oo40joo`0?conP3bon`0l_oj0?comP3n
ooX0j?ok0=3o063`0>gok@3nooX0looY0?ConP3noo@0o_oi0>Won`3@oo00kOo]
0?konP3conT0m?oj0?kom03nooT0jOok0=3ol03]ond0o_oj0??oj@3dooX0o_od
0?kon@3Yoo/0d?l0Hnl0koo/0?konP3donL0mOoj007ooo<0oOoj0>[onP3@onl0
koo/0?konP3donL0mOoj007ooo<0oOoj0>[onP3@onl0koo/0?konP3donL0mOoj
007ooo<0oOoj0>[onP3@o`1VkP3aonX00OoonP3eonD0m_oj007ooo<0oOoi0>_o
n`3?onh0lOoZ007oooX0mOoU0?KonP01oooc0?gon@3[oo/0coo^0?7ojP01oooj
0?Goi@3fooX00Oool`3mooT0jook0<oo09?n0?_om`3booH0n_oj003onP3fooL0
nOof0?KonP00ooX0nol1003mooT0k?oj0<oooP3kooL0l_of0?[onP00ooX0m_og
0?WomP3fooX00?oj0?_o0@00oOoi0>conP3?ooh0noog0?;omP3jooX00?oj0?Ko
m`3iooH0m_oj003onP3ko`400?gon@3/ooX0col0H_Kon03cooP0m_od0?Oon03e
ooP0m_od0?;onP3/oo/0`ooh0??on03foo@0mooh0?Gon03foo@0l_oj0>con`33
ooP0looh0?Kom03gooP0mOoh0?Kom03booX0k?ok0<ko06;eooT0m?oh0?Com@3g
ooX0lOoi0?Oom@3aooT0k_oj0<;on@3dooP0m?oe0?OonP3aooT0mooe0?7on@3^
ooX0`_oi0?Con03dooD0mooj0?7on@3gooD0lOoi0>konP3>o`1Rm?oj0?Gon03b
ooH0n?oi0?7on@3gooL0k_oj0>konP31ooX0mOoh0?;omP3hooT0lOoi0?Oom`3^
ooX0k_oj0<7onP3eooP0l_of0?Son@3aooT0moog0>konP3^ooX0c_l0H_Con@3f
ooT0l?og0?SonP3_ooX0moog0>kon@3_oo/0`?oi0?Kon@3`ooL0n?oj0>oonP3g
ooL0k_oi0>oon`30ooT0m_oi0?3om`3hooX0kooj0?Oom`3^ooT0kook0<go06;d
ooT0m_oj0>kon03hooX0kooj0?Oon03/ooX0l?oj0<3on@3fooX0k_oh0?SonP3_
ooX0mooh0>conP3`ooX0`?oi0?KonP3^ooP0n?oj0>oonP3gooP0k?oj0?3onP3=
o`1Flooj0?Oon@3^ooP0gooj0?Oon@3[ooT0lOok0;konP3gooT0k_oh0=oonP3g
ooT0jooi0?7on`2nooX0mooi0>kon03OooX0mooi0>_on@3aoo/0c?l0E_?onP3g
ooX0k?oi0=oonP3gooT0j_oj0?;onP2nooX0mooj0>con@3OooX0mooi0>[onP3b
ooX0__oj0?OonP3/ooT0gooj0?Oon@3ZooX0l_oj0<co05KcooX0mooj0>con@3O
ooX0mooi0>[onP3boo/0_Ooj0?OonP3/ooT0gooj0?Oon@3ZooX0l_ok0;gonP3g
ooX0k?oi0=oonP3gooT0j_oj0?;on`3;o`1Flooj0?OonP3/ooT0gooj0?Oon@3Z
ooT0look0;gonP3gooX0k?oi0=oonP3gooT0j_oi0??on`2mooX0mooj0>con@3O
ooX0mooi0>[on@3coo/0bol0E_?onP3hooX0j_oj0=oonP3gooX0j?oj0?ConP2m
ooX0n?oj0>[onP3OooX0mooj0>SonP3dooX0_Ooj0?SonP3ZooX0gooj0?OonP3X
ooX0m?oj0<_o05KcooX0n?oj0>[onP3RooL0mooj0>Son@3eoo/0_?oj0?SonP3Z
ooX0h_og0?OonP3XooT0mOok0;conP3hooX0j_oj0>;om`3gooX0j?oi0?Gon`3:
o`1Flooj0?SonP3ZooX0ioob0?OonP3WooX0m_oj0;conP3hooX0j_oj0>OolP3g
ooX0iooj0?KonP2looX0n?oj0>[onP3Woo80mooj0>OonP3fooX0b_l0E_?onP3h
ooX0j_oj0>_okP3gooX0iooi0?Oon`2kooX0n?oj0>[onP3[onh0mooj0>Oon@3g
oo/0^ooj0?SonP3ZooX0joo^0?OonP3WooT0mook0<Wo05KcooX0n?oj0>[onP3^
on/0mooj0>KonP3goo/0^ooj0?SonP3ZooX0k_o[0?OonP3VooX0mook0;_onP3h
ooX0j_oj0>koj`3gooX0i_oj0?Oon`39o`1Flooj0?SonP3ZooX0lOoX0?OonP3V
ooT0nOoj0;_onP3hooX0j_oj0?7oj03gooX0i_oi0?WonP2kooX0n?oj0>[onP3a
onP0mooj0>Kon@3iooX0bOl0E_?onP3hooX0j_oj0??oiP3gooX0i_oi0?Won`2j
ooX0n?oj0>[onP3conH0mooj0>Kon@3ioo/0^_oj0?SonP3ZooX0looV0?OonP3V
ooT0nOok0<So06GcooX0n?oj0>[onP3eond00OoonP3gooX0iOoj0?[onP2jooX0
n?oj0>[onP3eond00OoonP3gooX0iOoj0?[onP2jooX0n?oj0>[onP3eond00Ooo
nP3gooX0iOoj0?[onP38o`1Rlooj0?SonP3ZooX0m_oa0?[onP3gooX0iOoi0?_o
n`2iooX0n?oj0>[onP3foo40n_oj0?OonP3UooT0nook0;WonP3hooX0j_oj0?Ko
l@3jooX0mooj0>Gon@3koo/0aol0H_?onP3hooX0j_oj0?Oom03fooX0mooj0>Co
nP3koo/0^Ooj0?SonP3ZooX0mood0?KonP3gooX0i?oj0?_on`2iooX0n?oj0>[o
nP3goo@0m_oj0?OonP3TooX0nook0<Oo06;cooX0n?oj0>_on@3gooL0looj0?Oo
nP3TooT0oOoj0;WonP3hooX0jooi0?Oom`3cooX0mooj0>Con@3mooX0^Ooj0?So
nP3[ooT0moog0??onP3gooX0i?oi0?gonP37o`1Rlooj0?OonP3/ooT0n?oh0?7o
nP3gooX0hooj0?gon`2hooX0mooj0>con@3hooP0lOoj0?OonP3SooX0oOok0;So
nP3gooX0k?oi0?Son03aooX0mooj0>?onP3moo/0a_l0IO?onP3gooX0k?oi0?So
n@3`ooX0mooj0>?on@01oooj0;SonP3gooX0k?oi0?Son@3`ooX0mooj0>?on@01
oooj0;SonP3gooX0k?oi0?Son@3`ooX0mooj0>?on@01oooj0<Ko06GcooX0mooj
0>con@3iooT0kooj0?OonP3RooX00Ooon`2gooX0mooj0>con@3iooT0kooj0?Oo
nP3RooX00Ooon`2gooX0mooj0>con@3iooT0kooj0?OonP3RooX00Ooon`35o`1F
looj0?OonP3]ooP0nOoj0>oon@3gooX0h_ob0;OonP3gooX0kOoh0?WonP3_ooT0
mooj0>;olP2gooX0mooj0>gon03iooX0kooi0?OonP3Roo80aOl0E_?onP3fooX0
k_oh0?WonP3_ooT0mooj0>;ol`2fooX0m_oj0>kon03iooX0kooi0?OonP3Roo<0
]_oj0?KonP3^ooP0nOoj0>oon@3gooX0h_oc0<Co05KcooX0m_oj0>oom`3iooX0
l?oh0?OonP3Qoo@0]_oj0?KonP3_ooL0nOoj0?3on03gooX0hOod0;KonP3fooX0
koog0?WonP3`ooP0mooj0>7om034o`1Flooj0?Kon@3aooH0nOoj0?7om`3gooX0
hOod0;KonP3fooT0lOof0?WonP3aooL0mooj0>7om02fooX0m_oi0?7omP3iooX0
lOog0?OonP3Qoo@0a?l0E_?onP3eooT0looe0?Won@3cooH0mooj0>3omP2eooX0
mOoi0??om@3iooT0loof0?OonP3PooH0]Ooj0?Gon@3cooD0nOoi0??omP3gooX0
h?of0<?o05KcooX0m?oh0?Kom03iooP0m_od0?OonP3PooH0]Ooj0?Con03foo@0
nOoh0?Kom03gooX0h?of0;GonP3dooP0m_od0?Won03foo@0mooj0>3omP33o`1R
looj0?ComP3jooX00?oj0?Som`3koo40mooj0=oon02dooX0m?of0?[onP00ooX0
n?og0?_ol@3gooX0gooh0;ConP3dooH0n_oj003onP3hooL0nooa0?OonP3OooP0
`_l0FO?onP3conX00OoonP3honT00?oj0?OonP3OooP0]?oj0??ojP01oooj0?So
j@00ooX0mooj0=oon02dooX0looZ007oooX0n?oY003onP3gooX0gooh0<;o05cc
ooX0l_o[007oooX0moo[007oooX0mooj0=kon@2dooX0l_o[007oooX0moo[007o
ooX0mooj0=kon@2dooX0l_o[007oooX0moo[007oooX0mooj0=kon@32o`1Flooj
0?7ok@3nooX0m_o^0?gon@3hooX0g_oj0;?onP3aond0o_oj0?KokP3mooT0n?oj
0=konP2cooX0lOo]0?konP3fonh0oOoi0?SonP3NooX0`Ol0E_?onP3`onl0oOoj
0?Gol03kooX0n?oj0=konP2cooX0l?o_0?gonP3eoo00nooj0?SonP3NooX0/ooj
0?3ok`3mooX0mOo`0?_onP3hooX0g_oj0<7o05KcooX0k_oc0?_onP3coo@0nOoj
0?SonP3Noo/0/_oj0>kol`3kooX0lood0?WonP3hooX0g_ok0;;onP3^oo<0nooj
0??om03iooX0n?oj0=kon`30o`0Ve_oi0>7on@2mooX0UOoi0>7on@2mooX0UOoi
0>7on@2mooX0`?l0587oh_oj087oXOoj087oXOoj0<3o01B1on;on`21oj3on`21
oj3on`2oo`0DPOoSooX0POnQooX0POnQooX0_ol0587ohook087oX?ok087oX?ok
0;ko01B1onConP21oj7onP21oj7onP2no`0DPOoUooX0POnQooX0POnQooX0_Ol0
587oi_oj087oXOoj087oXOoj0;co01B1onOon@21oj;on@21oj;on@2lo`0DPOoY
ooP0POnSooP0POnSooP0^ol0587olOoa087oZ_oa087oZ_oa0;[o01B1oo7ol@21
oj[ol@21oj[ol@2jo`0DPOoaoo80POnYoo80POnYoo80^Ol0587olOod087oYood
087oYood0;Oo01B1oo7om@21ojKom@21ojKom@2fo`0DPOoaooP0POnSooP0POnS
ooP0/ol0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0
387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1
oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<
o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1
oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1
olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1
oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1
oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0
387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1
oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<
o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1
oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1
olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1
oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1
oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0
387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1
oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<
o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1
oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1
olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1
oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1
oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0
387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1
oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<
o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1
oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1
olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1
oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1
oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0
387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1
oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<
o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1
oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1
olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1
oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1
oh7oc?l0387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0
387oPOn1oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1
oh7oPOo<o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<
o`0<POn1oh7oPOn1olco00b1oh7oPOn1oh7oc?l0387oPOn1oh7oPOo<o`00X02o
0?l\>"], "NumberedFigure",
  ImageSize->{293, 156},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Fig. 4   The unknown point in the upper right edge is calculated \
from the three black ones by relating average differences in time and space \
via the matrices [A] and [B].\
\>", "Caption"],

Cell["\<\
These calculations are called implicit, because the term to be \
solved for shows up on the right and the left hand side in the equations \
(18). \
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\(\(\(v\&\[RightVector]\_M\%\(n + 1\)\)\(-\)\) 
                    v\&\[RightVector]\_M\%n + \ \(\(v\&\[RightVector]\_\(M - 
                            1\)\%\(n + 1\)\)\(-\)\) 
                    v\&\[RightVector]\_\(M - 1\)\%n\)\/\(2  \
\[CapitalDelta]t\)\),
            "TraditionalForm"], "=", 
          RowBox[{
            RowBox[{
              RowBox[{\(-\([B]\)\), 
                
                FormBox[\(\(\(v\&\[RightVector]\_M\%\(n + 1\) - 
                        v\&\[RightVector]\_\(M - 1\)\%\(n + 1\) + 
                        v\&\[RightVector]\_M\%n - 
                        v\&\[RightVector]\_\(M - 1\)\%n\)\/\(2  \
\[CapitalDelta]x\)\)\(\[IndentingNewLine]\)
                  \),
                  "TraditionalForm"]}], "\[Rule]", 
              FormBox[\(v\&\[RightVector]\_M\%\(n + 1\)\),
                "TraditionalForm"]}], "=", 
            RowBox[{\(v\&\[RightVector]\_\(M - 1\)\%n\), "+", 
              
              RowBox[{\(\(\([\[DoubleStruckL] + \(\[CapitalDelta]t\/\
\[CapitalDelta]x\)[
                            B]]\)\^\(-1\)\)[\[DoubleStruckL] - \(\
\[CapitalDelta]t\/\[CapitalDelta]x\)[B]]\), 
                RowBox[{"(", 
                  RowBox[{
                    FormBox[\(v\&\[RightVector]\_M\%n\),
                      "TraditionalForm"], "-", 
                    FormBox[\(v\&\[RightVector]\_\(M - 1\)\%\(n + 1\)\),
                      "TraditionalForm"]}], ")"}]}]}]}]}], 
        TraditionalForm]]],
  "\n\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\(\(\(v\&\[RightVector]\_1\%\(n + 1\)\)\(-\)\) 
                    v\&\[RightVector]\_1\%n + \ \(\(v\&\[RightVector]\_2\%\(n \
+ 1\)\)\(-\)\) v\&\[RightVector]\_2\%n\)\/\(2  \[CapitalDelta]t\)\),
            "TraditionalForm"], "=", 
          RowBox[{
            RowBox[{
              RowBox[{\(-\([B]\)\), 
                
                FormBox[\(\(v\&\[RightVector]\_2\%\(n + 1\) - 
                        v\&\[RightVector]\_1\%\(n + 1\) + 
                        v\&\[RightVector]\_2\%n - 
                        v\&\[RightVector]\_1\%n\)\/\(2  \[CapitalDelta]x\)\),
                  "TraditionalForm"]}], "\[IndentingNewLine]", "\[Rule]", 
              FormBox[\(v\&\[RightVector]\_1\%\(n + 1\)\),
                "TraditionalForm"]}], "=", 
            RowBox[{\(v\&\[RightVector]\_2\%n\), "+", 
              
              RowBox[{\(\(\([\[DoubleStruckL] - \(\[CapitalDelta]t\/\
\[CapitalDelta]x\)[
                            B]]\)\^\(-1\)\)[\[DoubleStruckL] + \(\
\[CapitalDelta]t\/\[CapitalDelta]x\)[B]]\), 
                RowBox[{"(", 
                  RowBox[{
                    FormBox[\(v\&\[RightVector]\_1\%n\),
                      "TraditionalForm"], "-", 
                    FormBox[\(v\&\[RightVector]\_2\%\(n + 1\)\),
                      "TraditionalForm"]}], ")"}]}]}]}]}], TraditionalForm]]]
}], "NumberedEquation"],

Cell["\<\
After formation of the inverse matrix and multiplication with [A] \
we get these expressions:
right side:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[
              RowBox[{\(u\&\[RightVector]\_M\%\(n + 1\)\), "=", 
                RowBox[{\(u\&\[RightVector]\_\(M - 1\)\%n\), "+", 
                  
                  RowBox[{\(\(\([\[DoubleStruckL] - \(\(\((\[CapitalDelta]t\/\
\[CapitalDelta]x)\)\^2\)[C'\^\(-1\)]\)[
                                L'\^\(-1\)]]\)\^\(-1\)\)[\[DoubleStruckL] + \
\(\(\((\[CapitalDelta]t\/\[CapitalDelta]x)\)\^2\)[C'\^\(-1\)]\)[
                          L'\^\(-1\)]]\), 
                    RowBox[{"(", 
                      RowBox[{\(u\&\[RightVector]\_M\%n\), "-", 
                        FormBox[\(u\&\[RightVector]\_\(M - 1\)\%\(n + 1\)\),
                          "TraditionalForm"]}], ")"}]}]}]}],
              "TraditionalForm"], "-", "\[IndentingNewLine]", 
            RowBox[{"2", \(\[CapitalDelta]t\/\[CapitalDelta]x\), 
              FormBox[
                SuperscriptBox[
                  RowBox[{"[", 
                    
                    FormBox[\(\[DoubleStruckL] - \(\(\((\[CapitalDelta]t\/\
\[CapitalDelta]x)\)\^2\)[C'\^\(-1\)]\)[L'\^\(-1\)]\),
                      "TraditionalForm"], "]"}], \(-1\)],
                "TraditionalForm"], 
              RowBox[{
                FormBox["",
                  "TraditionalForm"], "[", \(C'\^\(-1\)\), 
                "]"}], \((i\&\[RightVector]\_M\%n - 
                  i\&\[RightVector]\_\(M - 1\)\%\(n + 1\))\)}]}], ","}], 
        TraditionalForm]]],
  "\n\n",
  Cell[BoxData[
      FormBox[
        RowBox[{\(i\&\[RightVector]\_M\%\(n + 1\)\), "=", 
          
          RowBox[{\([\[DoubleStruckL] - \[CapitalDelta]t[\(L'\^\(-1\)\) 
                    R']]\), 
            RowBox[{"(", 
              RowBox[{\(i\&\[RightVector]\_\(M - 1\)\%n\), "-", 
                RowBox[{"2", \(\[CapitalDelta]t\/\[CapitalDelta]x\), 
                  FormBox[
                    SuperscriptBox[
                      RowBox[{"[", 
                        
                        FormBox[\(\[DoubleStruckL] - \
\(\(\((\[CapitalDelta]t\/\[CapitalDelta]x)\)\^2\)[L'\^\(-1\)]\)[C'\^\(-1\)]\),
                          
                          "TraditionalForm"], "]"}], \(-1\)],
                    "TraditionalForm"], 
                  RowBox[{
                    FormBox["",
                      "TraditionalForm"], "[", \(L'\^\(-1\)\), 
                    "]"}], \((u\&\[RightVector]\_M\%n - 
                      u\&\[RightVector]\_\(M - 1\)\%\(n + 1\))\)}], "+", 
                "\[IndentingNewLine]", 
                
                RowBox[{\(\(\([\[DoubleStruckL] - \(\(\((\[CapitalDelta]t\/\
\[CapitalDelta]x)\)\^2\)[L'\^\(-1\)]\)[
                              C'\^\(-1\)]]\)\^\(-1\)\)[\[DoubleStruckL] + \
\(\(\((\[CapitalDelta]t\/\[CapitalDelta]x)\)\^2\)[L'\^\(-1\)]\)[
                        C'\^\(-1\)]]\), 
                  RowBox[{"(", 
                    RowBox[{\(i\&\[RightVector]\_M\%n\), "-", 
                      FormBox[\(i\&\[RightVector]\_\(M - 1\)\%\(n + 1\)\),
                        "TraditionalForm"]}], ")"}]}]}], ")"}]}]}], 
        TraditionalForm]]]
}], "NumberedEquation"],

Cell["and left side:", "Text",
  PageBreakAbove->Automatic],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            
            FormBox[\(u\&\[RightVector]\_1\%\(n + 1\) = 
                u\&\[RightVector]\_2\%n + \(\([\[DoubleStruckL] - \(\(\((\
\[CapitalDelta]t\/\[CapitalDelta]x)\)\^2\)[C'\^\(-1\)]\)[
                                L'\^\(-1\)]]\)\^\(-1\)\)[\[DoubleStruckL] + \
\(\(\((\[CapitalDelta]t\/\[CapitalDelta]x)\)\^2\)[C'\^\(-1\)]\)[
                          L'\^\(-1\)]] \((u\&\[RightVector]\_1\%n - 
                        u\&\[RightVector]\_2\%\(n + 1\))\)\),
              "TraditionalForm"], "+", "\[IndentingNewLine]", 
            RowBox[{"2", \(\[CapitalDelta]t\/\[CapitalDelta]x\), 
              RowBox[{
                FormBox[
                  SuperscriptBox[
                    RowBox[{"[", 
                      
                      FormBox[\(\[DoubleStruckL] - \(\(\((\[CapitalDelta]t\/\
\[CapitalDelta]x)\)\^2\)[C'\^\(-1\)]\)[L'\^\(-1\)]\),
                        "TraditionalForm"], "]"}], \(-1\)],
                  "TraditionalForm"], "[", \(C'\^\(-1\)\), 
                "]"}], \((i\&\[RightVector]\_1\%n - 
                  i\&\[RightVector]\_2\%\(n + 1\))\)}]}], ","}], 
        TraditionalForm]]],
  "\n\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{\(i\&\[RightVector]\_1\%\(n + 1\)\), "=", 
              
              RowBox[{\([\[DoubleStruckL] - \[CapitalDelta]t[\(L'\^\(-1\)\) 
                        R']]\), 
                RowBox[{"(", 
                  RowBox[{\(i\&\[RightVector]\_2\%n\), "+", 
                    RowBox[{"2", 
                      RowBox[{
                        SuperscriptBox[
                          RowBox[{
                            FormBox[\(\[CapitalDelta]t\/\[CapitalDelta]x\),
                              "TraditionalForm"], 
                            "[", \(\[DoubleStruckL] - \(\(\((\[CapitalDelta]t\
\/\[CapitalDelta]x)\)\^2\)[L'\^\(-1\)]\)[C'\^\(-1\)]\), "]"}], \(-1\)], 
                        "[", \(L'\^\(-1\)\), 
                        "]"}], \((u\&\[RightVector]\_1\%n - 
                          u\&\[RightVector]\_2\%\(n + 1\))\)}], "+", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                      RowBox[{
                        FormBox[
                          SuperscriptBox[
                            RowBox[{"[", 
                              
                              FormBox[\(\[DoubleStruckL] - \(\(\((\
\[CapitalDelta]t\/\[CapitalDelta]x)\)\^2\)[L'\^\(-1\)]\)[C'\^\(-1\)]\),
                                "TraditionalForm"], "]"}], \(-1\)],
                          "TraditionalForm"], "[", 
                        
                        FormBox[\(\[DoubleStruckL] + \
\(\(\((\[CapitalDelta]t\/\[CapitalDelta]x)\)\^2\)[L'\^\(-1\)]\)[C'\^\(-1\)]\),
                          
                          "TraditionalForm"], 
                        "]"}], \((i\&\[RightVector]\_1\%n - 
                          i\&\[RightVector]\_2\%\(n + 1\))\)}]}], ")"}]}]}],
            "TraditionalForm"], "\[IndentingNewLine]"}], TraditionalForm]]]
}], "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{

Cell["explicit boundary conditions", "Subsubsection"],

Cell["\<\
Now the boundary conditions may be specified in the following ways:
open \[Rule] set i = 0, leave u as in (19) or (20); 
short \[Rule] set u = 0, leave i as in (19) or (20);
termination with z right/left \[Rule] set u = i  * (+/- z), leave i as in \
(19) / (20).\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Code (Gaussian Pulse with Reflections)"
}], "Subsection",
  PageBreakAbove->Automatic],

Cell["RAM requirements: Front End 40 MB, Kernel 10 MB.", "Text"],

Cell["\<\
As an example the propagation of gaussian pulses placed in the \
middle of each of two wires is presented. In order to demonstrate clearly the \
propagation and reflection properties the mutual coupling, which disturbs the \
shape of the pulses,  is set to zero.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Definitions", "Subsubsection"],

Cell[BoxData[{
    \(\(npl = 100;\) (*\ number\ of\ plots, \ 
      may\ be\ set\ to\ smaller\ number\ if\ memory\ is\ tight\ *) \), "\
\[IndentingNewLine]", 
    \(\(dt = 1. *10\^\(-12\);\)\  (*\ 1\ psec\ *) \), "\[IndentingNewLine]", 
    \(\(dx = 0.004;\)\  (*\ 
      4\ mm\ *) \[IndentingNewLine] (*dx\/\(\(\ \)\(dt\)\) \[GreaterGreater] \
\ speed\ of\ propagation\ for\ stability, \ 
      trade - off\ with\ computational\ speed\ *) \), "\[IndentingNewLine]", 
    \(\(\[Mu]\_0 = 4.  \[Pi]*10\^\(-7\)\ ;\)\), "\[IndentingNewLine]", 
    \(\(\[Epsilon]\_0 = 
        10\^\(-9\)/\((35.95  \[Pi])\);\)\), "\[IndentingNewLine]", 
    \(\(m = 250;\)\  (*\ 
      array\ dimension\  \[Rule] \ space\ distance\ m*dx\  = \ 
        1\ m\ *) \), "\[IndentingNewLine]", 
    \(\(nmax = 4000;\)\ \  (*\ simulation\ time\ steps, \ 
      time\ \(considered : \ nmax\ *\ dt\)\ \ *) \), "\[IndentingNewLine]", 
    \(\(pl = Round[nmax/npl];\)\  (*\ 
      snapshot\ after\ every\ pl\ timesteps\ *) \), "\[IndentingNewLine]", 
    \(\(k = 2;\) (*\ 
      2\ wires\  \[Rule] \ dimension\ of\ matrices\ *) \)}], "Input",
  CellLabel->"In[1]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters per Unit Length", "Subsubsection"],

Cell[BoxData[{
    RowBox[{\(res = 2. ;\), 
      "   ", \( (*\ 
        resistance\ in\ \[CapitalOmega]\ per\ meter\ *) \)}], "\
\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"rm", "=", 
        RowBox[{"(", GridBox[{
              {"res", "0"},
              {"0", "res"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{\(cap = \[Epsilon]\_0*\[Pi]/2;\), 
      "  ", \( (*\ 
        capacitance\ in\ F\ per\ meter\ \ *) \)}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"cm", "=", 
        RowBox[{"(", GridBox[{
              {"cap", "0"},
              {"0", "cap"}
              }], ")"}]}], ";", \( (*\ no\ mutual\ coupling\ *) \), 
      "\[IndentingNewLine]", \(ci = Inverse[cm]\), 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{\(ind = 2*\[Mu]\_0/\[Pi];\), 
      " ", \( (*\ 
        inductance\ in\ H\ per\ meter\ \ *) \)}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"lm", "=", 
          RowBox[{"(", GridBox[{
                {"ind", "0"},
                {"0", "ind"}
                }], ")"}]}], ";"}], 
      " ", \( (*\ 
        no\ mutual\ coupling\ *) \)}], "\[IndentingNewLine]", \(li = 
        Inverse[lm];\), "\[IndentingNewLine]", 
    RowBox[{\(zl = 0.5 \@\( ind/cap\);\), 
      " ", \( (*\ 
        too\ low\ Termination\ left\ \ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(zr = 2.0 \@\( ind/cap\);\), \( (*\ 
        too\ high\ Termination\ right\ \ *) \)}]}], "Input",
  CellLabel->"In[10]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Initialization and Setup of Coefficient Matrices", "Subsubsection"],

Cell[BoxData[{
    \(\(id = IdentityMatrix[k];\)\), "\[IndentingNewLine]", 
    \(u1 = \(u0 = Table[0. , {m}, {k}]\); \ 
    i1 = \(i0 = Table[0. , {m}, {k}]\);\), "\[IndentingNewLine]", 
    \(m1 = id - \(\((dt\/dx)\)\^2\) ci . li; 
    m2 = \(1\/2\) \(\((dt\/dx)\)\^2\) \((ci . li)\); 
    m3 = \(-\(1\/2\)\) \((dt\/dx)\) ci;\), "\[IndentingNewLine]", 
    \(m4 = \((id - dt\ li . rm)\) . \((id - \(\((dt\/dx)\)\^2\) li . ci)\); 
    m5 = \(1\/2\) \(\((dt\/dx)\)\^2\) \((id - dt\ li . rm)\) . \((li . ci)\); 
    m6 = \(-\(1\/2\)\) \((dt\/dx)\) \((id - dt\ li . rm)\) . 
          li;\), "\[IndentingNewLine]", 
    \(\(m8 = 
        Inverse[id - \(\((dt\/dx)\)\^2\) 
                ci . li] . \((id + \(\((dt\/dx)\)\^2\) 
                ci . li)\);\)\), "\[IndentingNewLine]", 
    \(m9 = 2 \( dt\/dx\) Inverse[id - \(\((dt\/dx)\)\^2\) ci . li] . ci; 
    m10 = id - dt\ li . rm;\), "\[IndentingNewLine]", 
    \(\(m11 = 
        2 \( dt\/dx\) \((id - dt\ li . rm\ )\) . \ 
            Inverse[id - \(\((dt\/dx)\)\^2\) li . ci] . 
            li\ ;\)\), "\[IndentingNewLine]", 
    \(\(m12 = \((id - dt\ li . rm\ )\) . 
          Inverse[id - \(\((dt\/dx)\)\^2\) 
                li . ci] . \((id + \(\((dt\/dx)\)\^2\) 
                li . ci)\);\)\)}], "Input",
  CellLabel->"In[20]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Static Initial Condition", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(u0 = Transpose[u0];\)\), "\[IndentingNewLine]", 
    \(\(u0[\([1]\)] = \(u0[\([2]\)] = 
          Table[\ Exp[\(-\((i - 125)\)\^2\)/80], {i, 1, 
              m}]\);\)\), "\[IndentingNewLine]", 
    \(\(u0 = Chop[Transpose[u0]];\)\), "\[IndentingNewLine]", 
    \(\(p1 = 
        ListPlot[\(Transpose[u0]\)[\([1]\)], 
          PlotRange \[Rule] {{0, m}, {0, 1}}, PlotJoined \[Rule] True, 
          AxesLabel -> {"\<Length [4 mm]\>", "\<Amplitude\>"}];\)\)}], "Input",\

  CellLabel->"In[30]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P00025A000`40O003h00OogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo002aOol6000>Ool40015Ool:000;Ool4000>Ool4000mOol:0009Ool6000>Ool4000jOol<
000;Ool4000>Ool4000jOol<0009Ool6000>Ool4003aOol00:moo`X000Yoo`P004=oo`X000Uoo`P0
00Yoo`P003]oo`X000Moo`X000Yoo`P003Qoo``000Uoo`P000Yoo`P003Qoo``000Moo`X000Yoo`P0
0>moo`00[goo0`001Goo0`002Goo0P0017oo0P00Agoo0P003Goo0P0017oo0P002Woo0P0017oo0P00
?goo0P002goo0`001Goo0`002Goo0P0017oo0P00>Goo0`001Woo0P002Goo0P0017oo0P002Woo0P00
17oo0P00>Goo0`001Woo0P001goo0`001Goo0`002Goo0P0017oo0P00kgoo002hOol20008Ool20006
Ool20016Ool2000<Ool20006Ool20008Ool20006Ool2000nOol2000DOol20008Ool20006Ool2000i
Ool3000?Ool20006Ool20008Ool20006Ool2000iOol3000GOol20008Ool20006Ool2003^Ool00;Uo
o`8000Moo`8000Ioo`8004Ioo`8000aoo`8000Ioo`8000Qoo`8000Ioo`8003ioo`8001Eoo`8000Mo
o`8000Ioo`8003Yoo`<000ioo`8000Ioo`8000Qoo`8000Ioo`8003Yoo`<001Moo`8000Moo`8000Io
o`800>ioo`00^Goo0P001Woo0P0027oo0P00AGoo0P002goo0P0027oo0P001Woo0P0027oo0P00?Goo
0P005Goo0P001Woo0P0027oo0P00>Woo0`0037oo0P0027oo0P001Woo0P0027oo0P00>Woo0`005Woo
0P001Woo0P0027oo0P00kGoo002iOol20006Ool20008Ool20015Ool2000;Ool20008Ool20006Ool2
0008Ool2000mOol2000EOol20006Ool20008Ool2000kOol3000;Ool20008Ool20006Ool20008Ool2
000kOol3000EOol20006Ool20008Ool2003]Ool00;Uoo`8000Ioo`8000Qoo`8004Eoo`8000]oo`80
00Qoo`8000Ioo`8000Qoo`8003eoo`8001Eoo`8000Ioo`8000Qoo`8003aoo`<000Yoo`8000Qoo`80
00Ioo`8000Qoo`8003aoo`<001Aoo`8000Ioo`8000Qoo`800>eoo`00^Goo0P001Woo0P0027oo0P00
AGoo0P002goo0P0027oo0P001Woo0P0027oo0P00?Goo0P005Goo0P001Woo0P0027oo0P00?Goo0`00
2Goo0P0027oo0P001Woo0P0027oo0P00?Goo0`004goo0P001Woo0P0027oo0P00kGoo002hOol20007
Ool20008Ool20015Ool2000;Ool20008Ool20006Ool20008Ool2000mOol2000DOol20007Ool20008
Ool2000nOol30008Ool20008Ool20006Ool20008Ool2000nOol3000AOol20007Ool20008Ool2003]
Ool00;1oo`8000Eoo`<000Moo`8000Qoo`8004Eoo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8003eo
o`8000aoo`8000Eoo`<000Moo`8000Qoo`8003moo`8000Qoo`8000Qoo`8000Ioo`8000Qoo`8003mo
o`8000Uoo`8000Eoo`<000Moo`8000Qoo`800>eoo`00/7oo2@0027oo0P0027oo0P00AGoo0P002goo
0P0027oo0P001Woo0P0027oo0P00?Goo0P0037oo2@0027oo0P0027oo0P00@7oo0P001goo0P0027oo
0P001Woo0P0027oo0P00@7oo0P0027oo2@0027oo0P0027oo0P00kGoo002`Ool200000goo00000003
0009Ool20008Ool20015Ool2000;Ool20008Ool20006Ool20008Ool2000mOol2000<Ool200000goo
000000030009Ool20008Ool20010Ool20007Ool20008Ool20006Ool20008Ool20010Ool20008Ool2
00000goo000000030009Ool20008Ool2003]Ool00;1oo`80011oo`8000Ioo`8004Ioo`8000aoo`80
00Ioo`8000Qoo`8000Ioo`8003ioo`8000aoo`80011oo`8000Ioo`8003Qoo`8000Moo`8000Qoo`80
00Ioo`8000Qoo`8000Ioo`8003Qoo`8000Moo`8000Qoo`80011oo`8000Ioo`800>ioo`00/7oo0P00
47oo0P001Woo0P00AWoo0P0037oo0P001Woo0P0027oo0P001Woo0P00?Woo0P0037oo0P0047oo0P00
1Woo0P00>7oo0`001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P00>7oo0`001Woo0P0027oo0P00
47oo0P001Woo0P00kWoo002`Ool2000AOol20004Ool20013Ool300000goo0000000=Ool20004Ool2
000:Ool20004Ool2000kOol300000goo0000000<Ool2000AOol20004Ool2000iOol40004Ool2000:
Ool20004Ool2000:Ool20004Ool2000iOol40004Ool20009Ool2000AOol20004Ool2000hOol60015
Ool5001BOol5000@Ool00;1oo`X000Uoo`P004=oo`H000eoo`P000Yoo`P003]oo`H000aoo`X000Uo
o`P003Yoo`P000]oo`P000Yoo`P003Yoo`P000Yoo`X000Uoo`P003Qoo`P004=oo`D0059oo`D0011o
o`00/7oo2P002goo1000B7oo0`003goo10003Woo1000@7oo0`0037oo2P002goo1000?Woo1@003Woo
10003Woo1000?Woo1@002goo2P002goo1000@7oo0`00@Woo0P00F7oo0P0047oo003oOoooOonbOol3
0011Ool2001HOol2000@Ool00?mooomook=oo`80045oo`8005Qoo`80011oo`00ogooogoo/goo0P00
@Goo0P00F7oo0P0047oo003oOoooOom`Ool@0007Ool80007Ool60003Ool6000>Ool2000:Ool60007
Ool60003Ool6000KOol2000@Ool7000EOol60002Ool40002Ool:0002Ool40002Ool40008Ool2000@
Ool00?mooomoog1ooa0000Ioo`/000Eoo`H000=oo`H000Moo`D0009oo`8000Uoo`T000Eoo`H000=o
o`H001]oo`80011oo`L001Eoo`H0009oo`@0009oo`X0009oo`@0009oo`@000Qoo`80011oo`00ogoo
ogooM7oo0P0027oo0P001Goo0P001goo10001Woo0P001goo0P001goo2`0027oo0`0017oo10001Woo
0P001goo0P007Goo0P004goo0P006Goo0P0017oo0P0017oo0P0017oo0P0017oo0P0017oo0P002Woo
0P0047oo003oOoooOomdOol20008Ool20004Ool2000BOol20007Ool20006Ool30005Ool40008Ool2
0007Ool20006Ool20007Ool2000MOol2000COol2000IOol20004Ool20004Ool20004Ool20004Ool2
0004Ool2000:Ool2000@Ool00?mooomoogAoo`8000Qoo`8000=oo`8001=oo`8000Moo`8000Ioo`80
00Moo`<000Qoo`8000moo`8000Moo`8001eoo`8001=oo`8001Uoo`8000Aoo`8000Aoo`8000Aoo`80
00Aoo`8000Aoo`8000Yoo`80011oo`00ogooogooM7oo0P0027oo0P000goo0P004goo0P001goo0P00
1Goo0P002Goo0P0027oo0P003goo0P001goo0P007Goo0P002goo30005goo0P0017oo0P0017oo0P00
17oo0P0017oo0P0017oo0P002Woo0P0047oo003oOoooOomdOol20008Ool20003Ool?0006Ool20007
Ool20005Ool20009Ool20008Ool2000?Ool20007Ool2000MOol2000;Ool<000GOol20004Ool20004
Ool20004Ool20004Ool20004Ool2000:Ool2000@Ool00?mooomoogAoo`8000Qoo`8000=oo`l000Io
o`8000Moo`8000Eoo`8000Uoo`8000Qoo`8000moo`8000Moo`8001eoo`8000]oo`8000Ioo`800003
Ool007oo01Ioo`8000Aoo`8000Aoo`8000Aoo`8000Aoo`8000Aoo`8000Yoo`80011oo`00Egooo`00
o`001`005Woo0P003Goo0P002goo0P001Woo0P001goo0P001Goo0P002Goo0P0027oo0P003goo0P00
1goo0P007Goo0P0037oo0P001Goo0P006Goo0P0017oo0P0017oo0P0017oo0P0017oo0P0017oo0P00
2Woo0P0047oo001GOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0A
Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0B
Ool00`00Oomoo`0AOol00`00Oomoo`05Ool3000:Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00
Oomoo`0BOol00`00Oomoo`08Ool20008Ool00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0B
Ool00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0B
Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0DOol2000=Ool3000:Ool20006Ool20007
Ool20005Ool20009Ool20008Ool2000?Ool20007Ool2000MOol2000<Ool30004Ool2000IOol20004
Ool20004Ool20004Ool20004Ool20004Ool2000:Ool2000@Ool005Moo`03001oogoo015oo`03001o
ogoo019oo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo019oo`03001o
ogoo015oo`03001oogoo019oo`03001oogoo019oo`03001oogoo015oo`03001oogoo00Qoo`8000Qo
o`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo00Ioo`8000Yoo`03001o
ogoo015oo`03001oogoo019oo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001o
ogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo019oo`03001oogoo015oo`03001o
ogoo01Aoo`8000ioo`8000Uoo`8000Moo`<000Ioo`8000Ioo`8000Moo`<000Qoo`8000moo`<000Io
o`8001eoo`8000eoo`8000Aoo`8001Uoo`8000Aoo`8000Aoo`8000Aoo`8000Aoo`8000Aoo`8000Yo
o`80011oo`00Egoo00<007ooOol0I7oo00<007ooOol0I7oo00<007ooOol02Woo00<007ooOol0Bgoo
00<007ooOol02Woo00<007ooOol0I7oo00<007ooOol0I7oo00<007ooOol057oo0P003goo0`001Goo
0`0027oo100017oo0`001Woo0`001Goo100017oo3@0027oo100017oo0P007Woo0P003Woo0P000goo
0P006Goo0`000Woo10000Woo0`0017oo0`000Woo10000Woo0`002Woo0P0047oo001GOol00`00Oomo
o`3IOol00`00Oomoo`19Ool00`00Oomoo`3`Ool2000@Ool90007Ool<0008Ool=0002Ool=0008Ool:
000NOol2000>Ool30002Ool2000GOol?0003Ool?000;Ool2000@Ool005Moo`03001oogoo0=Yoo`03
001oogoo04Moo`03001oogoo0?5oo`80019oo`H000Qoo`@0009oo`D000]oo`D0009oo`@000Ioo`80
00moo`80009oo`D001moo`8000moo`80009oo`8001Moo`@00003Ool000000080009oo`<000Aoo`@0
0003Ool000000080009oo`<000aoo`80011oo`00Egoo00<007ooOol0fWoo00<007ooOol0Agoo00<0
07ooOol0lGoo0P00Agoo0P003goo0P009Woo0P0047oo0P0000=oo`000000@goo0P0047oo001GOol0
0`00Oomoo`3KOol00`00Oomoo`15Ool00`00Oomoo`3^Ool:0013Ool2000?Ool2000VOol2000AOol4
0013Ool2000@Ool005Moo`03001oogoo0=aoo`03001oogoo04=oo`03001oogoo0>moo`X004=oo`80
00moo`8002Ioo`80015oo`@004=oo`80011oo`00Egoo00<007ooOol0g7oo00<007ooOol0@goo00<0
07ooOol0ogoo?Goo0P003Goo10009Woo1@003goo0`00@7oo1@0047oo001GOol00`00Oomoo`3MOol0
0`00Oomoo`11Ool00`00Oomoo`3oOom=Ool4000VOol5001BOol5000@Ool005Moo`03001oogoo0=eo
o`03001oogoo045oo`03001oogoo0?moon=oo`00Egoo00<007ooOol0gGoo00<007ooOol0@Goo00<0
07ooOol0ogoohgoo001GOol00`00Oomoo`3NOol00`00Oomoo`0oOol00`00Oomoo`3oOooTOol005Mo
o`03001oogoo0=ioo`03001oogoo03moo`03001oogoo0?moonAoo`00Egoo00<007ooOol0ggoo00<0
07ooOol0?Goo00<007ooOol0ogooiGoo001GOol2003POol00`00Oomoo`0mOol00`00Oomoo`3oOooU
Ool005Moo`03001oogoo0=moo`03001oogoo03eoo`03001oogoo0?moonEoo`00Egoo00<007ooOol0
h7oo00<007ooOol0>goo00<007ooOol0ogooiWoo001GOol00`00Oomoo`3POol00`00Oomoo`0kOol0
0`00Oomoo`3oOooVOol005Moo`03001oogoo0>1oo`03001oogoo03]oo`03001oogoo0?moonIoo`00
Egoo00<007ooOol0h7oo00<007ooOol0>goo00<007ooOol0ogooiWoo001GOol00`00Oomoo`3QOol0
0`00Oomoo`0iOol00`00Oomoo`3oOooWOol005Moo`03001oogoo0>5oo`03001oogoo03Uoo`03001o
ogoo0?moonMoo`00Egoo00<007ooOol0hGoo00<007ooOol0>Goo00<007ooOol0ogooigoo001GOol0
0`00Oomoo`3QOol00`00Oomoo`0iOol00`00Oomoo`3oOooWOol005Moo`03001oogoo0>9oo`03001o
ogoo03Moo`03001oogoo0?moonQoo`00Egoo00<007ooOol0hWoo00<007ooOol0=goo00<007ooOol0
ogooj7oo001GOol00`00Oomoo`3ROol00`00Oomoo`0gOol00`00Oomoo`3oOooXOol005Moo`03001o
ogoo0>9oo`03001oogoo03Moo`03001oogoo0?moonQoo`00Egoo00<007ooOol0hWoo00<007ooOol0
=goo00<007ooOol0ogooj7oo001GOol00`00Oomoo`3SOol00`00Oomoo`0eOol00`00Oomoo`3oOooY
Ool005Moo`800>Aoo`03001oogoo03Eoo`03001oogoo0?moonUoo`00Egoo00<007ooOol0hgoo00<0
07ooOol0=Goo00<007ooOol0ogoojGoo001GOol00`00Oomoo`3SOol00`00Oomoo`0eOol00`00Oomo
o`3oOooYOol005Moo`03001oogoo0>=oo`03001oogoo03Eoo`03001oogoo0?moonUoo`00Egoo00<0
07ooOol0i7oo00<007ooOol0<goo00<007ooOol0ogoojWoo001GOol00`00Oomoo`3TOol00`00Oomo
o`0cOol00`00Oomoo`3oOooZOol005Moo`03001oogoo0>Aoo`03001oogoo03=oo`03001oogoo0?mo
onYoo`00Egoo00<007ooOol0i7oo00<007ooOol0<goo00<007ooOol0ogoojWoo001GOol00`00Oomo
o`3TOol00`00Oomoo`0cOol00`00Oomoo`3oOooZOol005Moo`03001oogoo0>Aoo`03001oogoo03=o
o`03001oogoo0?moonYoo`00Egoo00<007ooOol0iGoo00<007ooOol0<Goo00<007ooOol0ogoojgoo
001GOol00`00Oomoo`3UOol00`00Oomoo`0aOol00`00Oomoo`3oOoo[Ool005Moo`03001oogoo0>Eo
o`03001oogoo035oo`03001oogoo0?moon]oo`00Egoo00<007ooOol0iGoo00<007ooOol0<Goo00<0
07ooOol0ogoojgoo001GOol00`00Oomoo`3UOol00`00Oomoo`0aOol00`00Oomoo`3oOoo[Ool005Mo
o`03001oogoo0>Eoo`03001oogoo035oo`03001oogoo0?moon]oo`00Egoo0P00iWoo00<007ooOol0
<Goo00<007ooOol0ogoojgoo001GOol00`00Oomoo`3VOol00`00Oomoo`0_Ool00`00Oomoo`3oOoo/
Ool005Moo`03001oogoo0>Ioo`03001oogoo02moo`03001oogoo0?moonaoo`00Egoo00<007ooOol0
iWoo00<007ooOol0;goo00<007ooOol0ogook7oo001GOol00`00Oomoo`3VOol00`00Oomoo`0_Ool0
0`00Oomoo`3oOoo/Ool005Moo`03001oogoo0>Ioo`03001oogoo02moo`03001oogoo0?moonaoo`00
Egoo00<007ooOol0iWoo00<007ooOol0;goo00<007ooOol0ogook7oo001GOol00`00Oomoo`3VOol0
0`00Oomoo`0_Ool00`00Oomoo`3oOoo/Ool005Moo`03001oogoo0>Ioo`03001oogoo02moo`03001o
ogoo0?moonaoo`008Goo10003Woo0`002Woo30002goo00<007ooOol0igoo00<007ooOol0;Goo00<0
07ooOol0ogookGoo000OOol8000;Ool50009Ool<000;Ool00`00Oomoo`3WOol00`00Oomoo`0]Ool0
0`00Oomoo`3oOoo]Ool001moo`8000Aoo`8000]oo`D000Yoo`<000Ioo`8000]oo`03001oogoo0>Mo
o`03001oogoo02eoo`03001oogoo0?mooneoo`007Woo0P001Woo0P002Woo1@002goo0`004Woo00<0
07ooOol0igoo00<007ooOol0;Goo00<007ooOol0ogookGoo000NOol20006Ool2000;Ool3000=Ool3
000AOol00`00Oomoo`3WOol00`00Oomoo`0]Ool00`00Oomoo`3oOoo]Ool001eoo`8000Qoo`8001]o
o`<0011oo`03001oogoo0>Moo`03001oogoo02eoo`03001oogoo0?mooneoo`007Goo0P0027oo0P00
77oo0`003goo00<007ooOol0igoo00<007ooOol0;Goo00<007ooOol0ogookGoo000MOol20008Ool2
000MOol3000>Ool4003VOol00`00Oomoo`0]Ool00`00Oomoo`3oOoo]Ool001eoo`8000Qoo`8001io
o`<000eoo`03001oogoo0>Moo`03001oogoo02eoo`03001oogoo0?mooneoo`007Goo0P0027oo0P00
7goo0`0037oo00<007ooOol0j7oo00<007ooOol0:goo00<007ooOol0ogookWoo000MOol20008Ool2
000POol2000<Ool00`00Oomoo`3XOol00`00Oomoo`0[Ool00`00Oomoo`3oOoo^Ool001eoo`8000Qo
o`80025oo`8000]oo`03001oogoo0>Qoo`03001oogoo02]oo`03001oogoo0?moonioo`007Goo0P00
27oo0P008Goo0P002goo00<007ooOol0j7oo00<007ooOol0:goo00<007ooOol0ogookWoo000NOol2
0006Ool2000IOol20007Ool2000;Ool00`00Oomoo`3XOol00`00Oomoo`0[Ool00`00Oomoo`3oOoo^
Ool001ioo`8000Ioo`8001Uoo`<000Ioo`8000]oo`03001oogoo0>Qoo`03001oogoo02]oo`03001o
ogoo0?moonioo`007goo0P0017oo0P006Woo100017oo0P0037oo00<007ooOol0j7oo00<007ooOol0
:goo00<007ooOol0ogookWoo000OOol8000KOol8000=Ool00`00Oomoo`3XOol00`00Oomoo`0[Ool0
0`00Oomoo`3oOoo^Ool0025oo`@001moo`D000ioo`03001oogoo0>Qoo`03001oogoo02]oo`03001o
ogoo0?moonioo`00Egoo00<007ooOol0j7oo00<007ooOol0:goo00<007ooOol0ogookWoo001GOol0
0`00Oomoo`3YOol00`00Oomoo`0YOol00`00Oomoo`3oOoo_Ool005Moo`03001oogoo0>Uoo`03001o
ogoo02Uoo`03001oogoo0?moonmoo`00Egoo00<007ooOol0jGoo00<007ooOol0:Goo00<007ooOol0
ogookgoo001GOol00`00Oomoo`3YOol00`00Oomoo`0YOol00`00Oomoo`3oOoo_Ool005Moo`800>Yo
o`03001oogoo02Uoo`03001oogoo0?moonmoo`00Egoo00<007ooOol0jGoo00<007ooOol0:Goo00<0
07ooOol0ogookgoo001GOol00`00Oomoo`3YOol00`00Oomoo`0YOol00`00Oomoo`3oOoo_Ool005Mo
o`03001oogoo0>Uoo`03001oogoo02Uoo`03001oogoo0?moonmoo`00Egoo00<007ooOol0jGoo00<0
07ooOol0:Goo00<007ooOol0ogookgoo001GOol00`00Oomoo`3YOol00`00Oomoo`0YOol00`00Oomo
o`3oOoo_Ool005Moo`03001oogoo0>Uoo`03001oogoo02Uoo`03001oogoo0?moonmoo`00Egoo00<0
07ooOol0jWoo00<007ooOol09goo00<007ooOol0ogool7oo001GOol00`00Oomoo`3ZOol00`00Oomo
o`0WOol00`00Oomoo`3oOoo`Ool005Moo`03001oogoo0>Yoo`03001oogoo02Moo`03001oogoo0?mo
oo1oo`00Egoo00<007ooOol0jWoo00<007ooOol09goo00<007ooOol0ogool7oo001GOol00`00Oomo
o`3ZOol00`00Oomoo`0WOol00`00Oomoo`3oOoo`Ool005Moo`03001oogoo0>Yoo`03001oogoo02Mo
o`03001oogoo0?mooo1oo`00Egoo00<007ooOol0jWoo00<007ooOol09goo00<007ooOol0ogool7oo
001GOol00`00Oomoo`3ZOol00`00Oomoo`0WOol00`00Oomoo`3oOoo`Ool005Moo`800>]oo`03001o
ogoo02Moo`03001oogoo0?mooo1oo`00Egoo00<007ooOol0jWoo00<007ooOol09Woo00<007ooOol0
ogoolGoo001GOol00`00Oomoo`3ZOol00`00Oomoo`0VOol00`00Oomoo`3oOooaOol005Moo`03001o
ogoo0>]oo`03001oogoo02Eoo`03001oogoo0?mooo5oo`00Egoo00<007ooOol0jgoo00<007ooOol0
9Goo00<007ooOol0ogoolGoo001GOol00`00Oomoo`3[Ool00`00Oomoo`0UOol00`00Oomoo`3oOooa
Ool005Moo`03001oogoo0>]oo`03001oogoo02Eoo`03001oogoo0?mooo5oo`00Egoo00<007ooOol0
jgoo00<007ooOol09Goo00<007ooOol0ogoolGoo001GOol00`00Oomoo`3[Ool00`00Oomoo`0UOol0
0`00Oomoo`3oOooaOol005Moo`03001oogoo0>]oo`03001oogoo02Aoo`03001oogoo0?mooo9oo`00
Egoo00<007ooOol0jgoo00<007ooOol097oo00<007ooOol0ogoolWoo001GOol00`00Oomoo`3[Ool0
0`00Oomoo`0TOol00`00Oomoo`3oOoobOol005Moo`03001oogoo0>]oo`03001oogoo02Aoo`03001o
ogoo0?mooo9oo`00Egoo00<007ooOol0jgoo00<007ooOol097oo00<007ooOol0ogoolWoo001GOol0
0`00Oomoo`3[Ool00`00Oomoo`0TOol00`00Oomoo`3oOoobOol005Moo`03001oogoo0>]oo`03001o
ogoo02Aoo`03001oogoo0?mooo9oo`00Egoo0P00kGoo00<007ooOol08goo00<007ooOol0ogoolWoo
001GOol00`00Oomoo`3/Ool00`00Oomoo`0SOol00`00Oomoo`3oOoobOol005Moo`03001oogoo0>ao
o`03001oogoo029oo`03001oogoo0?mooo=oo`00Egoo00<007ooOol0k7oo00<007ooOol08Woo00<0
07ooOol0ogoolgoo001GOol00`00Oomoo`3/Ool00`00Oomoo`0ROol00`00Oomoo`3oOoocOol005Mo
o`03001oogoo0>aoo`03001oogoo029oo`03001oogoo0?mooo=oo`00Egoo00<007ooOol0k7oo00<0
07ooOol08Woo00<007ooOol0ogoolgoo001GOol00`00Oomoo`3/Ool00`00Oomoo`0ROol00`00Oomo
o`3oOoocOol005Moo`03001oogoo0>aoo`03001oogoo029oo`03001oogoo0?mooo=oo`008Goo1000
3Woo0`0047oo1`002Woo00<007ooOol0k7oo00<007ooOol08Woo00<007ooOol0ogoolgoo000OOol8
000;Ool5000?Ool7000:Ool00`00Oomoo`3/Ool00`00Oomoo`0ROol00`00Oomoo`3oOoocOol001mo
o`8000Aoo`8000]oo`D0019oo`8000aoo`03001oogoo0>aoo`03001oogoo029oo`03001oogoo0?mo
oo=oo`007Woo0P001Woo0P002Woo1@004Woo0P0037oo00<007ooOol0k7oo00<007ooOol08Woo00<0
07ooOol0ogoolgoo000NOol20006Ool2000;Ool3000COol2000<Ool00`00Oomoo`3]Ool00`00Oomo
o`0POol00`00Oomoo`3oOoodOol001eoo`8000Qoo`8001Qoo``000Yoo`03001oogoo0>eoo`03001o
ogoo021oo`03001oogoo0?moooAoo`007Goo0P0027oo0P0067oo30002Woo00<007ooOol0kGoo00<0
07ooOol087oo00<007ooOol0ogoom7oo000MOol20008Ool2000HOol20006Ool200000goo001oo`09
Ool4003/Ool00`00Oomoo`0POol00`00Oomoo`3oOoodOol001eoo`8000Qoo`8001Uoo`8000Eoo`80
00aoo`03001oogoo0>eoo`03001oogoo021oo`03001oogoo0?moooAoo`007Goo0P0027oo0P006Goo
0`0017oo0P0037oo00<007ooOol0kGoo00<007ooOol087oo00<007ooOol0ogoom7oo000MOol20008
Ool2000JOol20004Ool2000<Ool00`00Oomoo`3]Ool00`00Oomoo`0POol00`00Oomoo`3oOoodOol0
01eoo`8000Qoo`8001]oo`8000=oo`8000aoo`03001oogoo0>eoo`03001oogoo021oo`03001oogoo
0?moooAoo`007Goo0P0027oo0P006goo0`000Woo0P0037oo00<007ooOol0kGoo00<007ooOol087oo
00<007ooOol0ogoom7oo000NOol20006Ool2000MOol20002Ool2000<Ool00`00Oomoo`3]Ool00`00
Oomoo`0POol00`00Oomoo`3oOoodOol001ioo`8000Ioo`8001ioo`800003Ool0000000aoo`03001o
ogoo0>eoo`03001oogoo021oo`03001oogoo0?moooAoo`007goo0P0017oo0P0087oo100037oo00<0
07ooOol0kGoo00<007ooOol087oo00<007ooOol0ogoom7oo000OOol8000POol4000<Ool00`00Oomo
o`3]Ool00`00Oomoo`0POol00`00Oomoo`3oOoodOol0025oo`@002=oo`<000aoo`03001oogoo0>io
o`03001oogoo01ioo`03001oogoo0?moooEoo`00Egoo00<007ooOol0kWoo00<007ooOol07Woo00<0
07ooOol0ogoomGoo001GOol00`00Oomoo`3^Ool00`00Oomoo`0NOol00`00Oomoo`3oOooeOol005Mo
o`03001oogoo0>ioo`03001oogoo01ioo`03001oogoo0?moooEoo`00Egoo00<007ooOol0kWoo00<0
07ooOol07Woo00<007ooOol0ogoomGoo001GOol00`00Oomoo`3^Ool00`00Oomoo`0NOol00`00Oomo
o`3oOooeOol005Moo`800>moo`03001oogoo01ioo`03001oogoo0?moooEoo`00Egoo00<007ooOol0
kWoo00<007ooOol07Woo00<007ooOol0ogoomGoo001GOol00`00Oomoo`3^Ool00`00Oomoo`0NOol0
0`00Oomoo`3oOooeOol005Moo`03001oogoo0>ioo`03001oogoo01ioo`03001oogoo0?moooEoo`00
Egoo00<007ooOol0kWoo00<007ooOol07Woo00<007ooOol0ogoomGoo001GOol00`00Oomoo`3^Ool0
0`00Oomoo`0NOol00`00Oomoo`3oOooeOol005Moo`03001oogoo0>ioo`03001oogoo01ioo`03001o
ogoo0?moooEoo`00Egoo00<007ooOol0kWoo00<007ooOol07Woo00<007ooOol0ogoomGoo001GOol0
0`00Oomoo`3_Ool00`00Oomoo`0LOol00`00Oomoo`3oOoofOol005Moo`03001oogoo0>moo`03001o
ogoo01aoo`03001oogoo0?moooIoo`00Egoo00<007ooOol0kgoo00<007ooOol077oo00<007ooOol0
ogoomWoo001GOol00`00Oomoo`3_Ool00`00Oomoo`0LOol00`00Oomoo`3oOoofOol005Moo`03001o
ogoo0>moo`03001oogoo01aoo`03001oogoo0?moooIoo`00Egoo00<007ooOol0kgoo00<007ooOol0
77oo00<007ooOol0ogoomWoo001GOol00`00Oomoo`3_Ool00`00Oomoo`0LOol00`00Oomoo`3oOoof
Ool005Moo`03001oogoo0>moo`03001oogoo01aoo`03001oogoo0?moooIoo`00Egoo0P00l7oo00<0
07ooOol077oo00<007ooOol0ogoomWoo001GOol00`00Oomoo`3_Ool00`00Oomoo`0LOol00`00Oomo
o`3oOoofOol005Moo`03001oogoo0>moo`03001oogoo01aoo`03001oogoo0?moooIoo`00Egoo00<0
07ooOol0kgoo00<007ooOol077oo00<007ooOol0ogoomWoo001GOol00`00Oomoo`3_Ool00`00Oomo
o`0LOol00`00Oomoo`3oOoofOol005Moo`03001oogoo0>moo`03001oogoo01aoo`03001oogoo0?mo
ooIoo`00Egoo00<007ooOol0kgoo00<007ooOol077oo00<007ooOol0ogoomWoo001GOol00`00Oomo
o`3`Ool00`00Oomoo`0JOol00`00Oomoo`3oOoogOol005Moo`03001oogoo0?1oo`03001oogoo01Yo
o`03001oogoo0?moooMoo`00Egoo00<007ooOol0l7oo00<007ooOol06Woo00<007ooOol0ogoomgoo
001GOol00`00Oomoo`3`Ool00`00Oomoo`0JOol00`00Oomoo`3oOoogOol005Moo`03001oogoo0?1o
o`03001oogoo01Yoo`03001oogoo0?moooMoo`00Egoo00<007ooOol0l7oo00<007ooOol06Woo00<0
07ooOol0ogoomgoo001GOol00`00Oomoo`3`Ool00`00Oomoo`0JOol00`00Oomoo`3oOoogOol005Mo
o`03001oogoo0?1oo`03001oogoo01Yoo`03001oogoo0?moooMoo`00Egoo00<007ooOol0l7oo00<0
07ooOol06Woo00<007ooOol0ogoomgoo001GOol2003aOol00`00Oomoo`0JOol00`00Oomoo`3oOoog
Ool005Moo`03001oogoo0?1oo`03001oogoo01Yoo`03001oogoo0?moooMoo`00Egoo00<007ooOol0
l7oo00<007ooOol06Woo00<007ooOol0ogoomgoo001GOol00`00Oomoo`3`Ool00`00Oomoo`0JOol0
0`00Oomoo`3oOoogOol005Moo`03001oogoo0?1oo`03001oogoo01Yoo`03001oogoo0?moooMoo`00
Egoo00<007ooOol0l7oo00<007ooOol06Woo00<007ooOol0ogoomgoo001GOol00`00Oomoo`3aOol0
0`00Oomoo`0HOol00`00Oomoo`3oOoohOol005Moo`03001oogoo0?5oo`03001oogoo01Qoo`03001o
ogoo0?moooQoo`00Egoo00<007ooOol0lGoo00<007ooOol067oo00<007ooOol0ogoon7oo000QOol4
000>Ool3000?Ool5000=Ool00`00Oomoo`3aOol00`00Oomoo`0HOol00`00Oomoo`3oOoohOol001mo
o`P000]oo`D000aoo`P000aoo`03001oogoo0?5oo`03001oogoo01Qoo`03001oogoo0?moooQoo`00
7goo0P0017oo0P002goo1@0037oo0P0017oo0`002goo00<007ooOol0lGoo00<007ooOol067oo00<0
07ooOol0ogoon7oo000NOol20006Ool2000:Ool5000;Ool20006Ool3000:Ool00`00Oomoo`3aOol0
0`00Oomoo`0HOol00`00Oomoo`3oOoohOol001ioo`8000Ioo`8000]oo`<000]oo`8000Qoo`8000Yo
o`03001oogoo0?5oo`03001oogoo01Qoo`03001oogoo0?moooQoo`007Goo0P0027oo0P0067oo0P00
27oo0P002Woo00<007ooOol0lGoo00<007ooOol067oo00<007ooOol0ogoon7oo000MOol20008Ool2
000HOol20008Ool2000:Ool00`00Oomoo`3aOol00`00Oomoo`0HOol00`00Oomoo`3oOoohOol001eo
o`8000Qoo`8001Qoo`8000Qoo`8000Yoo`@00?1oo`03001oogoo01Qoo`03001oogoo0?moooQoo`00
7Goo0P0027oo0P0067oo0`001Woo0`002Woo00<007ooOol0lGoo00<007ooOol067oo00<007ooOol0
ogoon7oo000MOol20008Ool2000HOol40004Ool3000;Ool00`00Oomoo`3aOol00`00Oomoo`0HOol0
0`00Oomoo`3oOoohOol001eoo`8000Qoo`8001Qoo`800003Ool0000000D000aoo`03001oogoo0?5o
o`03001oogoo01Qoo`03001oogoo0?moooQoo`007Goo0P0027oo0P006Goo00<007ooOol01@003Goo
00<007ooOol0lGoo00<007ooOol067oo00<007ooOol0ogoon7oo000MOol20008Ool2000IOol2000C
Ool00`00Oomoo`3bOol00`00Oomoo`0FOol00`00Oomoo`3oOooiOol001ioo`8000Ioo`8001Yoo`<0
019oo`03001oogoo0?9oo`03001oogoo01Ioo`03001oogoo0?moooUoo`007Woo0P001Woo0P006goo
0`004Goo00<007ooOol0lWoo00<007ooOol05Woo00<007ooOol0ogoonGoo000OOol20004Ool2000M
Ool3000@Ool00`00Oomoo`3bOol00`00Oomoo`0FOol00`00Oomoo`3oOooiOol001moo`P001ioo`P0
00Yoo`03001oogoo0?9oo`03001oogoo01Ioo`03001oogoo0?moooUoo`008Goo10008Woo1P002Woo
00<007ooOol0lWoo00<007ooOol05Woo00<007ooOol0ogoonGoo001GOol00`00Oomoo`3bOol00`00
Oomoo`0FOol00`00Oomoo`3oOooiOol005Moo`03001oogoo0?9oo`03001oogoo01Ioo`03001oogoo
0?moooUoo`00Egoo00<007ooOol0lWoo00<007ooOol05Woo00<007ooOol0ogoonGoo001GOol00`00
Oomoo`3bOol00`00Oomoo`0FOol00`00Oomoo`3oOooiOol005Moo`03001oogoo0?9oo`03001oogoo
01Ioo`03001oogoo0?moooUoo`00Egoo0P00lgoo00<007ooOol05Woo00<007ooOol0ogoonGoo001G
Ool00`00Oomoo`3bOol00`00Oomoo`0FOol00`00Oomoo`3oOooiOol005Moo`03001oogoo0?=oo`03
001oogoo01Eoo`03001oogoo0?moooUoo`00Egoo00<007ooOol0lgoo00<007ooOol05Goo00<007oo
Ool0ogoonGoo001GOol00`00Oomoo`3cOol00`00Oomoo`0DOol00`00Oomoo`3oOoojOol005Moo`03
001oogoo0?=oo`03001oogoo01Aoo`03001oogoo0?moooYoo`00Egoo00<007ooOol0lgoo00<007oo
Ool057oo00<007ooOol0ogoonWoo001GOol00`00Oomoo`3cOol00`00Oomoo`0DOol00`00Oomoo`3o
OoojOol005Moo`03001oogoo0?=oo`03001oogoo01Aoo`03001oogoo0?moooYoo`00Egoo00<007oo
Ool0lgoo00<007ooOol057oo00<007ooOol0ogoonWoo001GOol00`00Oomoo`3cOol00`00Oomoo`0D
Ool00`00Oomoo`3oOoojOol005Moo`03001oogoo0?=oo`03001oogoo01Aoo`03001oogoo0?moooYo
o`00Egoo00<007ooOol0m7oo00<007ooOol04goo00<007ooOol0ogoonWoo001GOol00`00Oomoo`3d
Ool00`00Oomoo`0COol00`00Oomoo`3oOoojOol005Moo`03001oogoo0?Aoo`03001oogoo01=oo`03
001oogoo0?moooYoo`00Egoo00<007ooOol0m7oo00<007ooOol04goo00<007ooOol0ogoonWoo001G
Ool2003eOol00`00Oomoo`0COol00`00Oomoo`3oOoojOol005Moo`03001oogoo0?Aoo`03001oogoo
01=oo`03001oogoo0?moooYoo`00Egoo00<007ooOol0m7oo00<007ooOol04goo00<007ooOol0ogoo
nWoo001GOol00`00Oomoo`3dOol00`00Oomoo`0BOol00`00Oomoo`3oOookOol005Moo`03001oogoo
0?Aoo`03001oogoo019oo`03001oogoo0?mooo]oo`00Egoo00<007ooOol0m7oo00<007ooOol04Woo
00<007ooOol0ogoongoo001GOol00`00Oomoo`3eOol00`00Oomoo`0AOol00`00Oomoo`3oOookOol0
05Moo`03001oogoo0?Eoo`03001oogoo015oo`03001oogoo0?mooo]oo`00Egoo00<007ooOol0mGoo
00<007ooOol04Goo00<007ooOol0ogoongoo001GOol00`00Oomoo`3eOol00`00Oomoo`0AOol00`00
Oomoo`3oOookOol005Moo`03001oogoo0?Eoo`03001oogoo015oo`03001oogoo0?mooo]oo`00Egoo
00<007ooOol0mGoo00<007ooOol04Goo00<007ooOol0ogoongoo001GOol00`00Oomoo`3eOol00`00
Oomoo`0AOol00`00Oomoo`3oOookOol005Moo`03001oogoo0?Eoo`03001oogoo015oo`03001oogoo
0?mooo]oo`00Egoo00<007ooOol0mGoo00<007ooOol04Goo00<007ooOol0ogoongoo001GOol00`00
Oomoo`3eOol00`00Oomoo`0AOol00`00Oomoo`3oOookOol005Moo`800?Ioo`03001oogoo015oo`03
001oogoo0?mooo]oo`00Egoo00<007ooOol0mGoo00<007ooOol04Goo00<007ooOol0ogoongoo001G
Ool00`00Oomoo`3fOol00`00Oomoo`0?Ool00`00Oomoo`3oOoolOol005Moo`03001oogoo0?Ioo`03
001oogoo00moo`03001oogoo0?moooaoo`00Egoo00<007ooOol0mWoo00<007ooOol03goo00<007oo
Ool0ogooo7oo001GOol00`00Oomoo`3fOol00`00Oomoo`0?Ool00`00Oomoo`3oOoolOol005Moo`03
001oogoo0?Ioo`03001oogoo00moo`03001oogoo0?moooaoo`00Egoo00<007ooOol0mWoo00<007oo
Ool03goo00<007ooOol0ogooo7oo001GOol00`00Oomoo`3fOol00`00Oomoo`0?Ool00`00Oomoo`3o
OoolOol0025oo`@000ioo`<000ioo`H000eoo`03001oogoo0?Ioo`03001oogoo00moo`03001oogoo
0?moooaoo`007goo20002goo1@0037oo200037oo00<007ooOol0mWoo00<007ooOol03goo00<007oo
Ool0ogooo7oo000OOol20004Ool2000;Ool5000;Ool30004Ool3000;Ool00`00Oomoo`3fOol00`00
Oomoo`0?Ool00`00Oomoo`3oOoolOol001ioo`8000Ioo`8000Yoo`D000Yoo`<000Ioo`<000Yoo`03
001oogoo0?Ioo`03001oogoo00moo`03001oogoo0?moooaoo`007Woo0P001Woo0P002goo0`002goo
0P0027oo0P002Woo00<007ooOol0mWoo00<007ooOol03goo00<007ooOol0ogooo7oo000MOol20008
Ool2000HOol20008Ool2000:Ool00`00Oomoo`3fOol00`00Oomoo`0?Ool00`00Oomoo`3oOoolOol0
01eoo`8000Qoo`8001Qoo`8000Qoo`8000Yoo`03001oogoo0?Ioo`03001oogoo00moo`03001oogoo
0?moooaoo`007Goo0P0027oo0P0067oo0`001Woo0`002Woo1000mWoo00<007ooOol03Goo00<007oo
Ool0ogoooGoo000MOol20008Ool2000IOol30004Ool3000;Ool00`00Oomoo`3gOol00`00Oomoo`0=
Ool00`00Oomoo`3oOoomOol001eoo`8000Qoo`8001Yoo`P000aoo`03001oogoo0?Moo`03001oogoo
00eoo`03001oogoo0?moooeoo`007Goo0P0027oo0P006Woo200037oo00<007ooOol0mgoo00<007oo
Ool03Goo00<007ooOol0ogoooGoo000MOol20008Ool2000IOol30004Ool3000;Ool00`00Oomoo`3g
Ool00`00Oomoo`0=Ool00`00Oomoo`3oOoomOol001eoo`8000Qoo`8001Qoo`8000Qoo`8000Yoo`03
001oogoo0?Moo`03001oogoo00eoo`03001oogoo0?moooeoo`007Woo0P001Woo0P006Goo0P0027oo
0P002Woo00<007ooOol0mgoo00<007ooOol03Goo00<007ooOol0ogoooGoo000NOol20006Ool2000I
Ool20008Ool2000:Ool00`00Oomoo`3gOol00`00Oomoo`0=Ool00`00Oomoo`3oOoomOol001moo`80
00Aoo`8001]oo`<000Aoo`@000Yoo`03001oogoo0?Moo`03001oogoo00eoo`03001oogoo0?moooeo
o`007goo20006goo2P002goo00<007ooOol0mgoo00<007ooOol03Goo00<007ooOol0ogoooGoo000Q
Ool4000OOol6000=Ool00`00Oomoo`3gOol00`00Oomoo`0=Ool00`00Oomoo`3oOoomOol005Moo`03
001oogoo0?Moo`03001oogoo00eoo`03001oogoo0?moooeoo`00Egoo00<007ooOol0mgoo00<007oo
Ool03Goo00<007ooOol0ogoooGoo001GOol00`00Oomoo`3hOol00`00Oomoo`0;Ool00`00Oomoo`3o
OoonOol005Moo`03001oogoo0?Qoo`03001oogoo00]oo`03001oogoo0?moooioo`00Egoo00<007oo
Ool0n7oo00<007ooOol02goo00<007ooOol0ogoooWoo001GOol2003iOol00`00Oomoo`0;Ool00`00
Oomoo`3oOoonOol005Moo`03001oogoo0?Qoo`03001oogoo00]oo`03001oogoo0?moooioo`00Egoo
00<007ooOol0n7oo00<007ooOol02goo00<007ooOol0ogoooWoo001GOol00`00Oomoo`3hOol00`00
Oomoo`0;Ool00`00Oomoo`3oOoonOol005Moo`03001oogoo0?Qoo`03001oogoo00]oo`03001oogoo
0?moooioo`00Egoo00<007ooOol0n7oo00<007ooOol02goo00<007ooOol0ogoooWoo001GOol00`00
Oomoo`3hOol00`00Oomoo`0;Ool00`00Oomoo`3oOoonOol005Moo`03001oogoo0?Qoo`03001oogoo
00]oo`03001oogoo0?moooioo`00Egoo00<007ooOol0n7oo00<007ooOol02goo00<007ooOol0ogoo
oWoo001GOol00`00Oomoo`3iOol00`00Oomoo`09Ool00`00Oomoo`3oOoooOol005Moo`03001oogoo
0?Uoo`03001oogoo00Uoo`03001oogoo0?mooomoo`00Egoo00<007ooOol0nGoo00<007ooOol02Goo
00<007ooOol0ogooogoo001GOol00`00Oomoo`3iOol00`00Oomoo`09Ool00`00Oomoo`3oOoooOol0
05Moo`03001oogoo0?Uoo`03001oogoo00Uoo`03001oogoo0?mooomoo`00Egoo00<007ooOol0nGoo
00<007ooOol02Goo00<007ooOol0ogooogoo001GOol00`00Oomoo`3iOol00`00Oomoo`09Ool00`00
Oomoo`3oOoooOol005Moo`800?Yoo`03001oogoo00Uoo`03001oogoo0?mooomoo`00Egoo00<007oo
Ool0nGoo00<007ooOol02Goo00<007ooOol0ogooogoo001GOol00`00Oomoo`3iOol00`00Oomoo`09
Ool00`00Oomoo`3oOoooOol005Moo`03001oogoo0?Yoo`03001oogoo00Moo`03001oogoo0?mooomo
o`5oo`00Egoo00<007ooOol0nWoo00<007ooOol01goo00<007ooOol0ogooogoo0Goo001GOol00`00
Oomoo`3jOol00`00Oomoo`07Ool00`00Oomoo`3oOoooOol1Ool005Moo`03001oogoo0?Yoo`03001o
ogoo00Moo`03001oogoo0?mooomoo`5oo`00Egoo00<007ooOol0nWoo00<007ooOol01goo00<007oo
Ool0ogooogoo0Goo001GOol00`00Oomoo`3jOol00`00Oomoo`07Ool00`00Oomoo`3oOoooOol1Ool0
05Moo`03001oogoo0?Yoo`03001oogoo00Moo`03001oogoo0?mooomoo`5oo`00Egoo00<007ooOol0
nWoo00<007ooOol01goo00<007ooOol0ogooogoo0Goo001GOol00`00Oomoo`3jOol00`00Oomoo`07
Ool00`00Oomoo`3oOoooOol1Ool005Moo`03001oogoo0?]oo`03001oogoo00Eoo`03001oogoo0?mo
oomoo`9oo`00Egoo00<007ooOol0ngoo00<007ooOol01Goo00<007ooOol0ogooogoo0Woo001GOol0
0`00Oomoo`3kOol00`00Oomoo`05Ool00`00Oomoo`3oOoooOol2Ool005Moo`03001oogoo0?]oo`03
001oogoo00Eoo`03001oogoo0?mooomoo`9oo`00Egoo0P00o7oo00<007ooOol01Goo00<007ooOol0
ogooogoo0Woo001GOol00`00Oomoo`3kOol00`00Oomoo`05Ool00`00Oomoo`3oOoooOol2Ool005Mo
o`03001oogoo0?]oo`03001oogoo00Eoo`03001oogoo0?mooomoo`9oo`00Egoo00<007ooOol0ngoo
00<007ooOol01Goo00<007ooOol0ogooogoo0Woo001GOol00`00Oomoo`3lOol00`00Oomoo`03Ool0
0`00Oomoo`3oOoooOol3Ool005Moo`03001oogoo0?aoo`03001oogoo00=oo`03001oogoo0?mooomo
o`=oo`00Egoo00<007ooOol0o7oo00<007ooOol00goo00<007ooOol0ogooogoo0goo001GOol00`00
Oomoo`3lOol00`00Oomoo`03Ool00`00Oomoo`3oOoooOol3Ool005Moo`03001oogoo0?aoo`03001o
ogoo00=oo`03001oogoo0?mooomoo`=oo`00@Woo2P002goo00<007ooOol0o7oo00<007ooOol00goo
00<007ooOol0ogooogoo0goo0012Ool:000;Ool00`00Oomoo`3mOol01@00Oomoogoo0000ogooogoo
1Woo0016Ool2000?Ool00`00Oomoo`3mOol01@00Oomoogoo0000ogooogoo1Woo0016Ool2000?Ool0
0`00Oomoo`3mOol01@00Oomoogoo0000ogooogoo1Woo0016Ool2000?Ool00`00Oomoo`3mOol01@00
Oomoogoo0000ogooogoo1Woo0016Ool2000?Ool00`00Oomoo`3nOol00`00Ool0003oOoooOol7Ool0
04Ioo`8000moo`03001oogoo0?ioo`03001oo`000?mooomoo`Moo`00AWoo0P003goo1000oWoo00<0
07ooOol0ogooogoo1Woo0016Ool2003oOoooOoooOolKOol004Ioo`800?mooomooomooa]oo`00AWoo
0P00ogooogooogoo6goo0016Ool2003oOoooOoooOolKOol004Ioo`800?mooomooomooa]oo`00AWoo
0P00ogooogooogoo6goo0016Ool2003oOoooOoooOolKOol0049oo`<00003Ool000000?mooomooomo
oa]oo`00@Woo1P00ogooogooogoo6goo0015Ool3003oOoooOoooOolKOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol002aoo`T00?mooomooomoobioo`00;7oo2@00ogooogooogoo;Woo000^Ool2003oOooo
OoooOolcOol002ioo`800?mooomooomooc=oo`00;Woo0P00ogooogooogoo<goo000^Ool2003oOooo
OoooOolcOol000Ioo`L000Aoo`d0009oo`@0009oo`@000Aoo`80009oo`H000Moo`d000Aoo`h000Uo
o`H000]oo`D0009oo`@000Ioo`H0009oo`@000Ioo`P00?mooomookmoo`001Woo1`0017oo3@000Woo
10000Woo100017oo0P0000=oo`0000001`001Goo3@0017oo3P0027oo2@0027oo300017oo2@0000=o
o`0000000P001Goo2`00ogooogoo_Goo0008Ool2000:Ool20004Ool20004Ool20004Ool20006Ool5
0004Ool40009Ool2000@Ool2000=Ool30004Ool40006Ool30004Ool40005Ool40004Ool50006Ool2
0007Ool4003oOoooOonlOol000Qoo`8000Yoo`8000Aoo`8000Aoo`8000Aoo`8000Ioo`<000Qoo`80
00Uoo`80011oo`8000eoo`8000Moo`8000Ioo`8000Ioo`<000Eoo`8000Qoo`<000Eoo`800?mooomo
olQoo`002Goo0P0027oo0P001Goo0P0017oo0P0017oo0P001Woo0`0027oo0`0027oo0P0047oo0P00
3Goo0P003goo0P001goo0P0017oo0`0027oo0`0017oo0P00ogooogoobGoo0009Ool20008Ool20005
Ool20004Ool20004Ool20006Ool2000:Ool20008Ool2000@Ool2000=Ool2000?Ool20007Ool20004
Ool2000:Ool20004Ool2003oOoooOoo9Ool000Uoo``000Eoo`8000Aoo`8000Aoo`8000Ioo`8000Yo
o`8000Qoo`80011oo`8000eoo`8000moo`8000Moo`8000Aoo`8000Yoo`8000Aoo`l00?mooomookao
o`002Woo2P001Woo0P0017oo0P0017oo0P001Woo0P002Woo0P0027oo0P0047oo0P003Goo0P003goo
0P001goo0P0017oo0P002Woo0P0017oo3`00ogooogoo_7oo000:Ool20006Ool20006Ool20004Ool2
0004Ool20006Ool2000:Ool20008Ool2000@Ool2000=Ool2000?Ool20007Ool20004Ool2000:Ool2
0004Ool2000;Ool2003oOoooOonlOol000]oo`8000Aoo`8000Moo`8000Aoo`8000Aoo`8000Ioo`<0
00Qoo`<000Qoo`80011oo`8000eoo`8000moo`8000Moo`8000Aoo`<000Qoo`<000Aoo`<000Yoo`80
0?mooomookaoo`002goo0P0017oo0P001goo0P0017oo0P0017oo0P001Woo0`0027oo0P002Goo0P00
47oo0P003Goo0P003goo0P001goo0P001Goo0P0027oo0`001Goo0P002Goo0P00ogooogoo_Goo000;
Ool20003Ool30007Ool30002Ool40002Ool30006Ool50004Ool3000:Ool2000@Ool20009Ool=0008
Ool20007Ool20006Ool30004Ool50006Ool30005Ool3003oOoooOonnOol000aoo`80009oo`8000Io
o`l000Eoo`@00003Ool0000000H000]oo`8000aoo`H000Uoo`d000Ioo`@000Aoo`D000Moo`P00003
Ool0000000Moo`T00?mooomookmoo`0037oo0P000Woo0P001Woo100000=oo`0000000P000Woo0`00
1Woo10000Woo1P0037oo0P0037oo1P003Goo0P003Goo100017oo1@0027oo1P000Woo0P002Goo1P00
ogooogoo`7oo000<Ool5000cOol2000OOol2000ZOol2003oOoooOoo?Ool000Uoo`P003=oo`8001mo
o`8002Yoo`800?mooomoolmoo`002Goo1`00=7oo0P007goo0P00:Woo0P00ogooogoocgoo000oOol7
000?Ool3000=Ool2000WOol5003oOoooOoo?Ool003moo`L000moo`<003Ioo`D00?mooomoolmoo`00
EGoo0`00ogooogooogoo2goo001EOol3003oOoooOoooOol;Ool00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo0000\
\>"], "Graphics",
  CellLabel->"From In[30]:=",
  Evaluatable->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
A  gaussian pulse is placed in the middle of the wires, it is going \
to divide into two separate components.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculate Evolution in Time and produce Plots", "Subsubsection",
  CellFrame->False,
  PageBreakAbove->True],

Cell["\<\
The output of the next cell shows the pulses at progressing time \
intervals. If their enclosing cell bracket is selected and the Menu Command \
\"Animate selected Graphics\" is chosen, they display an animation.\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ this\ cell\ produces\ npl\ plots, \ 
      view\ as\ animation\ *) \
\[IndentingNewLine]Timing[\[IndentingNewLine]Do[\[IndentingNewLine]{ (*\ 
            main\ loop, \ 
            calculate\ line\ n + 
              1\ in\ u\ and\ i\ grid\ *) \[IndentingNewLine]Do[{jp1 = j + 1; 
              jm1 = j - 1; \[IndentingNewLine]u1[\([j]\)] = 
                m1 . u0[\([j]\)] + \ 
                  m2 . \((u0[\([jp1]\)] + u0[\([jm1]\)])\) + 
                  m3 . \((i0[\([jp1]\)] - i0[\([jm1]\)])\); 
              i1[\([j]\)] = 
                m4 . i0[\([j]\)] + \ 
                  m5 . \((i0[\([jp1]\)] + i0[\([jm1]\)])\) + 
                  m6 . \((u0[\([jp1]\)] - u0[\([jm1]\)])\)}, {j, 2, 
              m - 1}]; \[IndentingNewLine] (*\ 
            edges\ *) \[IndentingNewLine]u1[\([m]\)] = 
            u0[\([m - 1]\)] + m8 . \((u0[\([m]\)] - u1[\([m - 1]\)])\) - 
              m9 . \((i0[\([m]\)] - 
                    i1[\([m - 1]\)])\); \[IndentingNewLine]i1[\([m]\)] = 
            m10 . i0[\([m - 1]\)] - 
              m11 . \((u0[\([m]\)] - u1[\([m - 1]\)])\) + 
              m12 . \((i0[\([m]\)] - 
                    i1[\([m - 1]\)])\); \[IndentingNewLine]u1[\([1]\)] = 
            u0[\([2]\)] + m8 . \((u0[\([1]\)] - u1[\([2]\)])\) + 
              m9 . \((i0[\([1]\)] - 
                    i1[\([2]\)])\); \[IndentingNewLine]i1[\([1]\)] = 
            m10 . i0[\([2]\)] + m11 . \((u0[\([1]\)] - u1[\([2]\)])\) + 
              m12 . \((i0[\([1]\)] - i1[\([2]\)])\); \[IndentingNewLine] (*\ 
            static\ boundary\ conditions\ \ \(open : \ set\ i\) = 0, \ 
            short : \ set\ u = 0\ *) \[IndentingNewLine]u1[\([m, 2]\)] = 
            zr\ i1[\([m, 2]\)];  (*\ 
            termination\ right\ with\ z\ *) \[IndentingNewLine]u1[\([1, 
                2]\)] = \(-zl\)\ i1[\([1, 2]\)]; \  (*\ 
            termination\ left\ with\  - 
              z\ *) \[IndentingNewLine]u1[\([1, 1]\)] = 0. ; \  (*\ 
            wire\ 1  
              left\ short\ circuit\ *) \[IndentingNewLine]i1[\([m, 1]\)] = 
            0. ; \  (*\ wire\ 1  right\ open\ end\ *) \[IndentingNewLine]u0 = 
            u1; i0 = i1;  (*\ 
            advance\ one\ step\ in\ time\ *) \[IndentingNewLine] (*\ 
            do\ a\ snapshot\ of\ the\ voltages\ *) \[IndentingNewLine]If[
            Mod[n, pl] \[Equal] 
              0, \[IndentingNewLine]{ (*\ 
                plot\ voltage\ wire\ 1\ *) \[IndentingNewLine]p1 = 
                ListPlot[\(Transpose[u1]\)[\([1]\)], 
                  PlotRange \[Rule] {{0, m}, {\(-0.6\), 1}}, 
                  PlotJoined \[Rule] True, 
                  DisplayFunction \[Rule] Identity]; \[IndentingNewLine] (*\ 
                plot\ current\ wire\ 1\ *) \[IndentingNewLine]p2 = 
                ListPlot[250\ \(Transpose[i1]\)[\([1]\)], 
                  PlotRange \[Rule] {{0, m}, {\(-0.8\), 0.6}}, 
                  PlotJoined \[Rule] True, 
                  DisplayFunction \[Rule] Identity]; \[IndentingNewLine] (*\ 
                plot\ voltage\ wire\ 2\ *) \[IndentingNewLine]p3 = 
                ListPlot[\(Transpose[u1]\)[\([2]\)], 
                  PlotRange \[Rule] {{0, m}, {\(-0.6\), 1}}, 
                  PlotJoined \[Rule] True, 
                  DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[
                GraphicsArray[{{p1}, {p2}, {p3}}], 
                DisplayFunction \[Rule] $DisplayFunction]; \
\[IndentingNewLine] (*\ 
                get\ rid\ of\ small\ numbers\ to\ accelerate\ calculation\ \
*) \[IndentingNewLine]u0 = Chop[u0]; i0 = Chop[i0]; Print[n]}]}, {n, 
          nmax}]\[IndentingNewLine]]\), "\[IndentingNewLine]", 
    \(Print["\<Fertig !\>"]\)}], "Input",
  CellLabel->"In[34]:=",
  CellFrame->True,
  AnimationDisplayTime->0.287328,
  Background->GrayLevel[0.849989]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23176 L
.276 .23176 L
.28 .23176 L
.284 .23176 L
.288 .23176 L
.292 .23176 L
.296 .23176 L
.3 .23176 L
.304 .23176 L
.308 .23176 L
.312 .23176 L
.316 .23176 L
.32 .23176 L
.324 .23176 L
.328 .23176 L
.332 .23176 L
.336 .23176 L
.34 .23176 L
.344 .23176 L
.348 .23176 L
.352 .23176 L
.356 .23176 L
.36 .23176 L
.364 .23176 L
.368 .23177 L
.372 .23177 L
.376 .23178 L
.38 .23179 L
.384 .23181 L
.388 .23185 L
.392 .23192 L
.396 .23205 L
.4 .23225 L
Mistroke
.404 .2326 L
.408 .23315 L
.412 .23402 L
.416 .23535 L
.42 .23732 L
.424 .24019 L
.428 .24423 L
.432 .2498 L
.436 .25726 L
.44 .26701 L
.444 .2794 L
.448 .29473 L
.452 .31318 L
.456 .33476 L
.46 .35927 L
.464 .38628 L
.468 .4151 L
.472 .4448 L
.476 .47427 L
.48 .50225 L
.484 .52743 L
.488 .54856 L
.492 .56453 L
.496 .57448 L
.5 .57786 L
.504 .57448 L
.508 .56453 L
.512 .54856 L
.516 .52743 L
.52 .50225 L
.524 .47427 L
.528 .4448 L
.532 .4151 L
.536 .38628 L
.54 .35927 L
.544 .33476 L
.548 .31318 L
.552 .29473 L
.556 .2794 L
.56 .26701 L
.564 .25726 L
.568 .2498 L
.572 .24423 L
.576 .24019 L
.58 .23732 L
.584 .23535 L
.588 .23402 L
.592 .23315 L
.596 .2326 L
.6 .23225 L
Mistroke
.604 .23205 L
.608 .23192 L
.612 .23185 L
.616 .23181 L
.62 .23179 L
.624 .23178 L
.628 .23177 L
.632 .23177 L
.636 .23176 L
.64 .23176 L
.644 .23176 L
.648 .23176 L
.652 .23176 L
.656 .23176 L
.66 .23176 L
.664 .23176 L
.668 .23176 L
.672 .23176 L
.676 .23176 L
.68 .23176 L
.684 .23176 L
.688 .23176 L
.692 .23176 L
.696 .23176 L
.7 .23176 L
.704 .23176 L
.708 .23176 L
.712 .23176 L
.716 .23176 L
.72 .23176 L
.724 .23176 L
.728 .23176 L
.732 .23176 L
.736 .23176 L
.74 .23176 L
.744 .23176 L
.748 .23176 L
.752 .23176 L
.756 .23176 L
.76 .23176 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35315 L
.38 .35313 L
.384 .35311 L
.388 .35306 L
.392 .35298 L
.396 .35284 L
.4 .3526 L
Mistroke
.404 .35221 L
.408 .35159 L
.412 .35064 L
.416 .3492 L
.42 .34711 L
.424 .34414 L
.428 .34007 L
.432 .33464 L
.436 .32765 L
.44 .31896 L
.444 .30856 L
.448 .2966 L
.452 .28349 L
.456 .26988 L
.46 .25669 L
.464 .24505 L
.468 .23623 L
.472 .23151 L
.476 .23201 L
.48 .23853 L
.484 .25142 L
.488 .27043 L
.492 .29473 L
.496 .32292 L
.5 .35316 L
.504 .38341 L
.508 .41159 L
.512 .43589 L
.516 .4549 L
.52 .46779 L
.524 .47432 L
.528 .47482 L
.532 .4701 L
.536 .46128 L
.54 .44964 L
.544 .43644 L
.548 .42284 L
.552 .40972 L
.556 .39777 L
.56 .38736 L
.564 .37867 L
.568 .37168 L
.572 .36626 L
.576 .36218 L
.58 .35921 L
.584 .35712 L
.588 .35569 L
.592 .35473 L
.596 .35412 L
.6 .35373 L
Mistroke
.604 .35349 L
.608 .35335 L
.612 .35326 L
.616 .35322 L
.62 .35319 L
.624 .35318 L
.628 .35317 L
.632 .35317 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23176 L
.276 .23176 L
.28 .23176 L
.284 .23176 L
.288 .23176 L
.292 .23176 L
.296 .23176 L
.3 .23176 L
.304 .23176 L
.308 .23176 L
.312 .23176 L
.316 .23176 L
.32 .23176 L
.324 .23176 L
.328 .23176 L
.332 .23176 L
.336 .23176 L
.34 .23176 L
.344 .23176 L
.348 .23176 L
.352 .23176 L
.356 .23176 L
.36 .23176 L
.364 .23176 L
.368 .23177 L
.372 .23177 L
.376 .23178 L
.38 .23179 L
.384 .23181 L
.388 .23185 L
.392 .23192 L
.396 .23205 L
.4 .23225 L
Mistroke
.404 .2326 L
.408 .23315 L
.412 .23402 L
.416 .23535 L
.42 .23732 L
.424 .24019 L
.428 .24423 L
.432 .2498 L
.436 .25726 L
.44 .26701 L
.444 .2794 L
.448 .29473 L
.452 .31318 L
.456 .33476 L
.46 .35927 L
.464 .38628 L
.468 .4151 L
.472 .4448 L
.476 .47427 L
.48 .50225 L
.484 .52743 L
.488 .54856 L
.492 .56453 L
.496 .57448 L
.5 .57786 L
.504 .57448 L
.508 .56453 L
.512 .54856 L
.516 .52743 L
.52 .50225 L
.524 .47427 L
.528 .4448 L
.532 .4151 L
.536 .38628 L
.54 .35927 L
.544 .33476 L
.548 .31318 L
.552 .29473 L
.556 .2794 L
.56 .26701 L
.564 .25726 L
.568 .2498 L
.572 .24423 L
.576 .24019 L
.58 .23732 L
.584 .23535 L
.588 .23402 L
.592 .23315 L
.596 .2326 L
.6 .23225 L
Mistroke
.604 .23205 L
.608 .23192 L
.612 .23185 L
.616 .23181 L
.62 .23179 L
.624 .23178 L
.628 .23177 L
.632 .23177 L
.636 .23176 L
.64 .23176 L
.644 .23176 L
.648 .23176 L
.652 .23176 L
.656 .23176 L
.66 .23176 L
.664 .23176 L
.668 .23176 L
.672 .23176 L
.676 .23176 L
.68 .23176 L
.684 .23176 L
.688 .23176 L
.692 .23176 L
.696 .23176 L
.7 .23176 L
.704 .23176 L
.708 .23176 L
.712 .23176 L
.716 .23176 L
.72 .23176 L
.724 .23176 L
.728 .23176 L
.732 .23176 L
.736 .23176 L
.74 .23176 L
.744 .23176 L
.748 .23176 L
.752 .23176 L
.756 .23176 L
.76 .23176 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00Woo0`0000=oo`00Ool00Woo00D007ooOomoo`0000=oo`03001oo`00008000=oo`05001o
ogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
0`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`8002Yoo`8000eoo`03001oogoo03Moo`0077oo00<0
07ooOol0:Woo00<007ooOol02goo00<007ooOol0=goo000LOol2000/Ool00`00Oomoo`09Ool00`00
Oomoo`0hOol001aoo`03001oogoo02]oo`03001oogoo00Uoo`03001oogoo03Qoo`002goo0P0017oo
00@007ooOomoo`D0009oo`8002aoo`03001oogoo00Uoo`03001oogoo03Qoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool00`00Oomoo`0/Ool00`00Oomoo`07Ool00`00Oomoo`0iOol000Yoo`04
001oogoo0009Ool00`00Oomoo`02Ool2000]Ool00`00Oomoo`07Ool00`00Oomoo`0iOol000Yoo`04
001oogoo000:Ool01@00Oomoogoo0000;Woo00<007ooOol01goo00<007ooOol0>Goo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`8002eoo`03001oogoo00Moo`03001oogoo03Uoo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0/Ool00`00Oomoo`06Ool00`00Oomo
o`0jOol000]oo`8000Uoo`<000=oo`8002eoo`03001oogoo00Ioo`03001oogoo03Yoo`0077oo00<0
07ooOol0;Goo00<007ooOol01Goo00<007ooOol0>Woo000;Ool20004Ool00`00Oomoo`03Ool30002
Ool2000^Ool00`00Oomoo`05Ool00`00Oomoo`0jOol000Yoo`04001oogoo000:Ool01@00Oomoogoo
0000;goo00<007ooOol01Goo00<007ooOol0>Woo000:Ool01000Oomoo`001goo1@000Woo0P00;Woo
00<007ooOol01Goo00<007ooOol0>Woo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001o
ogoo02eoo`03001oogoo00Eoo`03001oogoo03Yoo`002Woo00@007ooOol000Qoo`03001oo`0000=o
o`8002moo`03001oogoo00=oo`03001oogoo03]oo`002Woo00@007ooOol000Uoo`8000=oo`03001o
ogoo02ioo`03001oogoo00=oo`03001oogoo03]oo`002goo0P002goo00@007ooOomoo`8002moo`03
001oogoo00=oo`03001oogoo03]oo`0077oo00<007ooOol0;Woo00<007ooOol00goo00<007ooOol0
>goo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2000_Ool00`00Oomoo`03Ool00`00Oomoo`0k
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0;Woo00<007ooOol00goo
00<007ooOol0>goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8002moo`03001oogoo
009oo`03001oogoo03aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo02ioo`03001oogoo
009oo`03001oogoo03aoo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8002moo`03001oogoo
009oo`03001oogoo03aoo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo02moo`05
001oogooOol0000nOol000]oo`8000Yoo`8000=oo`80031oo`05001oogooOol0000nOol001aoo`03
001oogoo02moo`05001oogooOol0000nOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`80031o
o`05001oogooOol0000nOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
;goo00D007ooOomoo`0003ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000`Ool0
1@00Oomoogoo0000?Woo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0<7oo00<007oo0000
?goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80035oo`03001oo`0003moo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0`Ool00`00Ool0000oOol000]oo`80
00Uoo`<000=oo`80035oo`80041oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Mo
o`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomo
o`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol000]oo`8000Aoo`03001oogoo009oo`<007Qoo`002Woo00@007ooOol000Moo`05001oogoo
Ool0001gOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool0
1000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000]o
o`8000Uoo`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`80
00Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo10000goo0P00Lgoo000:Ool01000Oomoo`001goo00<007oo
Ool017oo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007ooOol00goo0P00Lgoo000;Ool2
000:Ool20003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004
Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo
0003Ool50002Ool01000Oomoo`001goo1@000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00@007ooOol000=oo`8007=oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo079o
o`002Woo00@007ooOol000Uoo`8000=oo`8007=oo`002goo0P002goo00D007ooOomoo`0007Aoo`00
77oo0P00Lgoo000LOol00`00Oomoo`0^Ool00`00Oomoo`11Ool000]oo`8000Aoo`04001oogooOol5
0002Ool2000_Ool20012Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0;Goo
00<007oo0000@Woo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo00<007ooOol0;Goo
00<007oo0000@Woo000:Ool01000Oomoo`002Woo00@007ooOomoo`8000ioo`<000Aoo`8000Uoo`<0
00Aoo`8000Aoo`80009oo`03001oogoo00<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eo
o`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`0<Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool2
000017oo001oo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool2000017oo001oo`00
0goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo
0P002Goo0`000goo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009o
o`04001oogoo0002Ool2000017oo001oo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo
00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001o
ogoo009oo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogooOol40003Ool01000Oomo
o`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00
Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`00
27oo0P0017oo00@007ooOol0009oo`06001oogoo001oo`000Woo0P000goo00<007ooOol017oo00@0
07ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogoo
Ool007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007oo
Ool00goo0P000Woo00@007oo0000009oo`05001oogooOol00003Ool50003Ool20006Ool30004Ool2
0004Ool20006Ool30002Ool50003Ool20006Ool001aoo`8002]oo`03001oogoo00=oo`03001oogoo
03moo`0077oo00<007ooOol0:7oo0P001goo00<007ooOol0?Woo000LOomY000<Ool001aoo`03001o
ogoo019oo`03001oogoo019oo`03001oogoo00Moo`03001oogoo00Aoo`800003Ool007oo01=oo`03
001oogoo019oo`03001oogoo00Yoo`0077oo0P00<Woo00<007ooOol017oo00<007ooOol0=goo000L
Ool00`00Oomoo`0aOol00`00Oomoo`03Ool2000iOol001aoo`80039oo`03001oogoo00=oo`03001o
ogoo03Qoo`0077oo00<007ooOol0<Woo00<007ooOol00Woo00<007ooOol0>7oo000LOol00`00Oomo
o`0bOol01@00Oomoogoo0000>goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00<goo00D007oo
Oomoo`0003]oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0bOol01@00Oomo
ogoo0000>goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00<goo00@007ooOol003aoo`00
2Woo00@007ooOol000Yoo`05001oogooOol0000eOol00`00Ool0000lOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo0P00=7oo00<007oo0000?7oo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo03=oo`8003eoo`002goo0P002Goo0`000goo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo
000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`D0009oo`80
07=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol0
00]oo`8000]oo`05001oogooOol0001dOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2
001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;
Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo
0000M7oo0003Ool50002Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo
00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=o
o`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00@007ooOomoo`80
07=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P00Lgoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Ao
o`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Io
o`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`8000eoo`05001oogooOol00002Ool0
1000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@0
07ooOol000Yoo`05001oogooOol0000BOol01000Oomoo`000Woo00<007ooOol01goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80015o
o`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo10000goo00@007ooOol0
00Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomo
ogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uoo`<000=oo`8000eoo`03001oogoo00Ao
o`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo
00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool0
1`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yo
o`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool2
0006Ool30002Ool50003Ool20006Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOomY000<
Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool300000goo001oo`02Ool01@00Oomoogoo
00000goo00<007oo00000P000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo0P00:Woo
0P003Goo00<007ooOol0=goo000LOol00`00Oomoo`0ZOol00`00Oomoo`0;Ool00`00Oomoo`0gOol0
01aoo`8002aoo`03001oogoo00Uoo`03001oogoo03Qoo`0077oo00<007ooOol0:goo00<007ooOol0
2Goo00<007ooOol0>7oo000;Ool20004Ool01000Oomoogoo1@000Woo0P00;7oo00<007ooOol02Goo
00<007ooOol0>7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo02aoo`03001o
ogoo00Moo`03001oogoo03Uoo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8002eoo`03001o
ogoo00Moo`03001oogoo03Uoo`002Woo00@007ooOol000Yoo`05001oogooOol0000^Ool00`00Oomo
o`07Ool00`00Oomoo`0iOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00;Goo00<0
07ooOol01goo00<007ooOol0>Goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo02aoo`03001oogoo00Ioo`03001oogoo03Yoo`002goo0P002Goo0`000goo0P00;Goo00<007oo
Ool01Woo00<007ooOol0>Woo000LOol00`00Oomoo`0]Ool00`00Oomoo`05Ool00`00Oomoo`0jOol0
00]oo`8000Aoo`03001oogoo00=oo`<0009oo`8002ioo`03001oogoo00Eoo`03001oogoo03Yoo`00
2Woo00@007ooOol000Yoo`05001oogooOol0000_Ool00`00Oomoo`05Ool00`00Oomoo`0jOol000Yo
o`04001oogoo0007Ool50002Ool2000^Ool00`00Oomoo`05Ool00`00Oomoo`0jOol000Yoo`04001o
ogoo0007Ool01000Oomoo`000goo00<007ooOol0;Goo00<007ooOol01Goo00<007ooOol0>Woo000:
Ool01000Oomoo`0027oo00<007oo00000goo0P00;goo00<007ooOol00goo00<007ooOol0>goo000:
Ool01000Oomoo`002Goo0P000goo00<007ooOol0;Woo00<007ooOol00goo00<007ooOol0>goo000;
Ool2000;Ool01000Oomoogoo0P00;goo00<007ooOol00goo00<007ooOol0>goo000LOol00`00Oomo
o`0^Ool00`00Oomoo`03Ool00`00Oomoo`0kOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`80
02moo`03001oogoo00=oo`03001oogoo03]oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`0^Ool00`00Oomoo`03Ool00`00Oomoo`0kOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo0P00;goo00<007ooOol00goo00<007ooOol0>goo000:Ool01000Oomoo`001goo
10000goo00<007ooOol0;Woo00<007ooOol00Woo00<007ooOol0?7oo000:Ool01000Oomoo`001goo
00<007ooOol017oo0P00;goo00<007ooOol00Woo00<007ooOol0?7oo000:Ool01000Oomoo`0027oo
00<007ooOol00goo00<007ooOol0;Woo00<007ooOol00Woo00<007ooOol0?7oo000;Ool2000:Ool2
0003Ool2000`Ool01@00Oomoogoo0000?Woo000LOol00`00Oomoo`0_Ool01@00Oomoogoo0000?Woo
000;Ool20004Ool00`00Oomoo`02Ool30003Ool2000`Ool01@00Oomoogoo0000?Woo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo02moo`05001oogooOol0000nOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo0P00<7oo00D007ooOomoo`0003ioo`002Woo00@007oo
Ool000Qoo`<000=oo`03001oogoo031oo`03001oo`0003moo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2000aOol00`00Ool0000oOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0<7oo00<007oo0000?goo000;Ool20009Ool30003Ool2000aOol20010Ool001ao
o`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol0
01Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Io
o`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(40\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23176 L
.276 .23176 L
.28 .23176 L
.284 .23176 L
.288 .23176 L
.292 .23176 L
.296 .23176 L
.3 .23176 L
.304 .23176 L
.308 .23176 L
.312 .23176 L
.316 .23176 L
.32 .23176 L
.324 .23176 L
.328 .23176 L
.332 .23176 L
.336 .23176 L
.34 .23176 L
.344 .23176 L
.348 .23176 L
.352 .23176 L
.356 .23177 L
.36 .23177 L
.364 .23178 L
.368 .23179 L
.372 .23181 L
.376 .23186 L
.38 .23193 L
.384 .23206 L
.388 .23227 L
.392 .23262 L
.396 .23317 L
.4 .23403 L
Mistroke
.404 .23531 L
.408 .23719 L
.412 .23989 L
.416 .24364 L
.42 .24871 L
.424 .25538 L
.428 .26391 L
.432 .27451 L
.436 .28728 L
.44 .3022 L
.444 .31908 L
.448 .33755 L
.452 .35707 L
.456 .37694 L
.46 .39642 L
.464 .41472 L
.468 .43117 L
.472 .44525 L
.476 .45669 L
.48 .46545 L
.484 .47173 L
.488 .47592 L
.492 .47846 L
.496 .47978 L
.5 .48018 L
.504 .47978 L
.508 .47846 L
.512 .47592 L
.516 .47173 L
.52 .46545 L
.524 .45669 L
.528 .44525 L
.532 .43117 L
.536 .41472 L
.54 .39642 L
.544 .37694 L
.548 .35707 L
.552 .33755 L
.556 .31908 L
.56 .3022 L
.564 .28728 L
.568 .27451 L
.572 .26391 L
.576 .25538 L
.58 .24871 L
.584 .24364 L
.588 .23989 L
.592 .23719 L
.596 .23531 L
.6 .23403 L
Mistroke
.604 .23317 L
.608 .23262 L
.612 .23227 L
.616 .23206 L
.62 .23193 L
.624 .23186 L
.628 .23181 L
.632 .23179 L
.636 .23178 L
.64 .23177 L
.644 .23177 L
.648 .23176 L
.652 .23176 L
.656 .23176 L
.66 .23176 L
.664 .23176 L
.668 .23176 L
.672 .23176 L
.676 .23176 L
.68 .23176 L
.684 .23176 L
.688 .23176 L
.692 .23176 L
.696 .23176 L
.7 .23176 L
.704 .23176 L
.708 .23176 L
.712 .23176 L
.716 .23176 L
.72 .23176 L
.724 .23176 L
.728 .23176 L
.732 .23176 L
.736 .23176 L
.74 .23176 L
.744 .23176 L
.748 .23176 L
.752 .23176 L
.756 .23176 L
.76 .23176 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35315 L
.364 .35315 L
.368 .35313 L
.372 .3531 L
.376 .35305 L
.38 .35296 L
.384 .35281 L
.388 .35255 L
.392 .35214 L
.396 .35148 L
.4 .35047 L
Mistroke
.404 .34894 L
.408 .3467 L
.412 .3435 L
.416 .33906 L
.42 .33305 L
.424 .32518 L
.428 .31515 L
.432 .30277 L
.436 .28798 L
.44 .27092 L
.444 .25198 L
.448 .23183 L
.452 .21146 L
.456 .19209 L
.46 .17517 L
.464 .16222 L
.468 .15474 L
.472 .15404 L
.476 .16107 L
.48 .17633 L
.484 .19975 L
.488 .23063 L
.492 .26773 L
.496 .30929 L
.5 .35316 L
.504 .39704 L
.508 .43859 L
.512 .47569 L
.516 .50658 L
.52 .52999 L
.524 .54525 L
.528 .55229 L
.532 .55158 L
.536 .54411 L
.54 .53116 L
.544 .51423 L
.548 .49486 L
.552 .47449 L
.556 .45435 L
.56 .43541 L
.564 .41835 L
.568 .40356 L
.572 .39118 L
.576 .38115 L
.58 .37327 L
.584 .36727 L
.588 .36282 L
.592 .35962 L
.596 .35738 L
.6 .35586 L
Mistroke
.604 .35484 L
.608 .35418 L
.612 .35377 L
.616 .35352 L
.62 .35336 L
.624 .35327 L
.628 .35322 L
.632 .35319 L
.636 .35318 L
.64 .35317 L
.644 .35317 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23176 L
.276 .23176 L
.28 .23176 L
.284 .23176 L
.288 .23176 L
.292 .23176 L
.296 .23176 L
.3 .23176 L
.304 .23176 L
.308 .23176 L
.312 .23176 L
.316 .23176 L
.32 .23176 L
.324 .23176 L
.328 .23176 L
.332 .23176 L
.336 .23176 L
.34 .23176 L
.344 .23176 L
.348 .23176 L
.352 .23176 L
.356 .23177 L
.36 .23177 L
.364 .23178 L
.368 .23179 L
.372 .23181 L
.376 .23186 L
.38 .23193 L
.384 .23206 L
.388 .23227 L
.392 .23262 L
.396 .23317 L
.4 .23403 L
Mistroke
.404 .23531 L
.408 .23719 L
.412 .23989 L
.416 .24364 L
.42 .24871 L
.424 .25538 L
.428 .26391 L
.432 .27451 L
.436 .28728 L
.44 .3022 L
.444 .31908 L
.448 .33755 L
.452 .35707 L
.456 .37694 L
.46 .39642 L
.464 .41472 L
.468 .43117 L
.472 .44525 L
.476 .45669 L
.48 .46545 L
.484 .47173 L
.488 .47592 L
.492 .47846 L
.496 .47978 L
.5 .48018 L
.504 .47978 L
.508 .47846 L
.512 .47592 L
.516 .47173 L
.52 .46545 L
.524 .45669 L
.528 .44525 L
.532 .43117 L
.536 .41472 L
.54 .39642 L
.544 .37694 L
.548 .35707 L
.552 .33755 L
.556 .31908 L
.56 .3022 L
.564 .28728 L
.568 .27451 L
.572 .26391 L
.576 .25538 L
.58 .24871 L
.584 .24364 L
.588 .23989 L
.592 .23719 L
.596 .23531 L
.6 .23403 L
Mistroke
.604 .23317 L
.608 .23262 L
.612 .23227 L
.616 .23206 L
.62 .23193 L
.624 .23186 L
.628 .23181 L
.632 .23179 L
.636 .23178 L
.64 .23177 L
.644 .23177 L
.648 .23176 L
.652 .23176 L
.656 .23176 L
.66 .23176 L
.664 .23176 L
.668 .23176 L
.672 .23176 L
.676 .23176 L
.68 .23176 L
.684 .23176 L
.688 .23176 L
.692 .23176 L
.696 .23176 L
.7 .23176 L
.704 .23176 L
.708 .23176 L
.712 .23176 L
.716 .23176 L
.72 .23176 L
.724 .23176 L
.728 .23176 L
.732 .23176 L
.736 .23176 L
.74 .23176 L
.744 .23176 L
.748 .23176 L
.752 .23176 L
.756 .23176 L
.76 .23176 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00Woo0P000Woo00D007ooOomoo`0000=oo`05001oogooOol00002Ool20003Ool01@00Oomo
ogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00Woo00<007ooOol02Woo000LOol2000ZOol00`00Oomoo`0=Ool00`00Oomoo`0fOol001ao
o`03001oogoo02Uoo`03001oogoo00eoo`03001oogoo03Ioo`0077oo0P00:Woo00<007ooOol037oo
00<007ooOol0=goo000LOol00`00Oomoo`0ZOol00`00Oomoo`0;Ool00`00Oomoo`0gOol000]oo`80
00Aoo`04001oogooOol50002Ool2000[Ool00`00Oomoo`0;Ool00`00Oomoo`0gOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00<007ooOol0:Woo00<007ooOol02goo00<007ooOol0=goo000:
Ool01000Oomoo`002Goo00<007ooOol00Woo0P00;7oo00<007ooOol02Goo00<007ooOol0>7oo000:
Ool01000Oomoo`002Woo00D007ooOomoo`0002eoo`03001oogoo00Uoo`03001oogoo03Qoo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000/Ool00`00Oomoo`09Ool00`00Oomoo`0hOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0;7oo00<007ooOol01goo00<0
07ooOol0>Goo000;Ool20009Ool30003Ool2000]Ool00`00Oomoo`07Ool00`00Oomoo`0iOol001ao
o`03001oogoo02aoo`03001oogoo00Moo`03001oogoo03Uoo`002goo0P0017oo00<007ooOol00goo
0`000Woo0P00;Goo00<007ooOol01goo00<007ooOol0>Goo000:Ool01000Oomoo`002Woo00D007oo
Oomoo`0002ioo`03001oogoo00Ioo`03001oogoo03Yoo`002Woo00@007ooOol000Moo`D0009oo`80
02eoo`03001oogoo00Ioo`03001oogoo03Yoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool0
0`00Oomoo`0]Ool00`00Oomoo`05Ool00`00Oomoo`0jOol000Yoo`04001oogoo0008Ool00`00Ool0
0003Ool2000^Ool00`00Oomoo`05Ool00`00Oomoo`0jOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`0]Ool00`00Oomoo`05Ool00`00Oomoo`0jOol000]oo`8000]oo`04001oogooOol2000^
Ool00`00Oomoo`05Ool00`00Oomoo`0jOol001aoo`03001oogoo02ioo`03001oogoo00=oo`03001o
ogoo03]oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00;goo00<007ooOol00goo00<007oo
Ool0>goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo02ioo`03001oogoo
00=oo`03001oogoo03]oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000_Ool20003
Ool00`00Oomoo`0lOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0_Ool200000goo0000
000nOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2000aOol3000oOol000Yoo`04001oogoo
0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<0
07ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`00
0goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=o
o`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0
Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3001hOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P00Lgoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`@000=oo`8007=oo`002Woo00@007oo
Ool000Moo`03001oogoo00Aoo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oogoo00=o
o`8007=oo`002goo0P002Woo0P000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00;goo00<007ooOol0@Goo000:Ool01000
Oomoo`002Woo00D007ooOomoo`0002moo`8004=oo`000goo1@000Woo00@007ooOol000Moo`D0009o
o`03001oogoo02eoo`8004=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool2000^Ool00`00
Ool00012Ool000Yoo`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`0/Ool01000Oomoo`00
@Woo000:Ool01000Oomoo`002Goo0P000goo0P00;Goo00@007ooOol0049oo`002goo0P002goo00D0
07ooOomoo`0002ioo`04001oogoo0012Ool001aoo`8002eoo`05001oogooOol00011Ool001aoo`03
001oogoo02aoo`05001oogooOol00011Ool000]oo`8000Aoo`04001oogooOol50002Ool2000]Ool0
1@00Oomoogoo0000@Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo02]oo`03
001oogoo009oo`03001oogoo03moo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`03
001oogoo02]oo`03001oogoo009oo`03001oogoo03moo`002Woo00@007ooOol000Yoo`04001oogoo
Ool2000>Ool30004Ool20009Ool30004Ool20003Ool30002Ool00`00Oomoo`030003Ool30004Ool2
0005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol037oo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01@00Oomoogoo00000goo00@007oo
Ool0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06
001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00D0
07ooOol007oo0080009oo`03001oo`0000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000]oo`8000Uoo`<000=oo`03001oogoo011oo`04001oogoo0002
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01@00Oomoo`00Ool00P000Woo00<007oo00000goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`00
0Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P00
3Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`05001oogoo001oo`020002Ool00`00Ool0
0003Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007oo
Ool037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`03001oogoo00800007Ool007ooOol0
07oo00000Woo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo
00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P0000Aoo`00Oomoo`80009oo`05001o
ogooOol00003Ool50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool0
01aoo`8002Uoo`8000Moo`03001oogoo03ioo`0077oo00<007ooOol09goo0P0027oo00<007ooOol0
?Woo000LOomY000<Ool001aoo`03001oogoo019oo`03001oogoo019oo`03001oogoo00Moo`03001o
ogoo00Ioo`8001Aoo`03001oogoo019oo`03001oogoo00Yoo`0077oo0P00<Woo00<007ooOol01Goo
00<007ooOol0=Woo000LOol00`00Oomoo`0aOol00`00Oomoo`05Ool00`00Oomoo`0fOol001aoo`80
039oo`03001oogoo00Aoo`03001oogoo03Moo`0077oo00<007ooOol0<Goo00<007ooOol017oo00<0
07ooOol0=goo000LOol00`00Oomoo`0aOol00`00Oomoo`04Ool00`00Oomoo`0gOol000]oo`8000Ao
o`04001oogooOol50002Ool2000cOol00`00Oomoo`03Ool00`00Oomoo`0gOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00<007ooOol0<Woo00<007ooOol00Woo00<007ooOol0>7oo000:Ool0
1000Oomoo`002Goo00<007ooOol00Woo0P00<goo00<007ooOol00Woo00<007ooOol0>7oo000:Ool0
1000Oomoo`002Woo00D007ooOomoo`0003Aoo`03001oogoo009oo`03001oogoo03Qoo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2000cOol00`00Oomoo`02Ool00`00Oomoo`0hOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0<Woo00D007ooOomoo`0003]oo`00
2goo0P002Goo0`000goo00<007ooOol0<Woo00D007ooOomoo`0003]oo`0077oo0P00<goo00D007oo
Oomoo`0003]oo`0077oo00<007ooOol0<goo00@007ooOol003]oo`002goo0P0017oo00<007ooOol0
0goo0`000Woo0P00=7oo00@007ooOol003]oo`002Woo00@007ooOol000Yoo`05001oogooOol0000e
Ool00`00Ool0000lOol000Yoo`04001oogoo0007Ool50002Ool2000dOol00`00Ool0000lOol000Yo
o`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0<goo00<007oo0000?7oo000:Ool01000
Oomoo`0027oo00<007oo00000goo0P00=7oo0`00?7oo000:Ool01000Oomoo`002Goo0P000goo00<0
07ooOol0LWoo000;Ool2000;Ool01@00Oomoogoo0000M7oo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000LOol0
0`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo
00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@0
07ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool0
0003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`04
001oogooOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00@007ooOomoo`D0009oo`80
07=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0=Ool30004Ool20009Ool3
0004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool3
0004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool2000=Ool01@00Oomo
ogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo00@007ooOol0009oo`03001oogoo00Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`@000=o
o`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo
Ool40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
17oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool2000=Ool0
0`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003
Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000
Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool5
0003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`00
17oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2001cOol001aoo`03001oogoo079o
o`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol010000Woo00D007ooOomoo`00
00=oo`05001oogooOol00002Ool30002Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol2
000YOol2000?Ool2000gOol001aoo`03001oogoo02Uoo`03001oogoo00eoo`03001oogoo03Ioo`00
77oo0P00:Woo00<007ooOol037oo00<007ooOol0=goo000LOol00`00Oomoo`0ZOol00`00Oomoo`0;
Ool00`00Oomoo`0gOol000]oo`8000Aoo`04001oogooOol50002Ool2000[Ool00`00Oomoo`0;Ool0
0`00Oomoo`0gOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0:Woo00<007oo
Ool02goo00<007ooOol0=goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00;7oo00<007oo
Ool02Goo00<007ooOol0>7oo000:Ool01000Oomoo`002Woo00D007ooOomoo`0002eoo`03001oogoo
00Uoo`03001oogoo03Qoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000/Ool00`00
Oomoo`09Ool00`00Oomoo`0hOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0;7oo00<007ooOol01goo00<007ooOol0>Goo000;Ool20009Ool30003Ool2000]Ool00`00Oomo
o`07Ool00`00Oomoo`0iOol001aoo`03001oogoo02aoo`03001oogoo00Moo`03001oogoo03Uoo`00
2goo0P0017oo00<007ooOol00goo0`000Woo0P00;Goo00<007ooOol01goo00<007ooOol0>Goo000:
Ool01000Oomoo`002Woo00D007ooOomoo`0002ioo`03001oogoo00Ioo`03001oogoo03Yoo`002Woo
00@007ooOol000Moo`D0009oo`8002eoo`03001oogoo00Ioo`03001oogoo03Yoo`002Woo00@007oo
Ool000Moo`04001oogoo0003Ool00`00Oomoo`0]Ool00`00Oomoo`05Ool00`00Oomoo`0jOol000Yo
o`04001oogoo0008Ool00`00Ool00003Ool2000^Ool00`00Oomoo`05Ool00`00Oomoo`0jOol000Yo
o`04001oogoo0009Ool20003Ool00`00Oomoo`0]Ool00`00Oomoo`05Ool00`00Oomoo`0jOol000]o
o`8000]oo`04001oogooOol2000^Ool00`00Oomoo`05Ool00`00Oomoo`0jOol001aoo`03001oogoo
02ioo`03001oogoo00=oo`03001oogoo03]oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00
;goo00<007ooOol00goo00<007ooOol0>goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo02ioo`03001oogoo00=oo`03001oogoo03]oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2000_Ool00`00Oomoo`02Ool00`00Oomoo`0lOol000Yoo`04001oogoo0007Ool4
0003Ool00`00Oomoo`0_Ool01@00Oomoogoo0000?Woo000:Ool01000Oomoo`001goo00<007ooOol0
17oo0P00<Goo0`00?goo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;
Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo
0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00
Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007oo
Ool0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0
Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(80\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23176 L
.276 .23176 L
.28 .23176 L
.284 .23176 L
.288 .23176 L
.292 .23176 L
.296 .23176 L
.3 .23176 L
.304 .23176 L
.308 .23176 L
.312 .23176 L
.316 .23176 L
.32 .23176 L
.324 .23176 L
.328 .23176 L
.332 .23176 L
.336 .23176 L
.34 .23176 L
.344 .23177 L
.348 .23177 L
.352 .23178 L
.356 .23179 L
.36 .23182 L
.364 .23186 L
.368 .23194 L
.372 .23208 L
.376 .2323 L
.38 .23266 L
.384 .23323 L
.388 .23409 L
.392 .2354 L
.396 .2373 L
.4 .24 L
Mistroke
.404 .24374 L
.408 .24879 L
.412 .25541 L
.416 .26385 L
.42 .27428 L
.424 .28679 L
.428 .30131 L
.432 .3176 L
.436 .33522 L
.44 .3535 L
.444 .37161 L
.448 .38862 L
.452 .40355 L
.456 .4155 L
.46 .42375 L
.464 .42789 L
.468 .42784 L
.472 .42394 L
.476 .41692 L
.48 .4078 L
.484 .39782 L
.488 .38831 L
.492 .38049 L
.496 .37535 L
.5 .37357 L
.504 .37535 L
.508 .38049 L
.512 .38831 L
.516 .39782 L
.52 .4078 L
.524 .41692 L
.528 .42394 L
.532 .42784 L
.536 .42789 L
.54 .42375 L
.544 .4155 L
.548 .40355 L
.552 .38862 L
.556 .37161 L
.56 .3535 L
.564 .33522 L
.568 .3176 L
.572 .30131 L
.576 .28679 L
.58 .27428 L
.584 .26385 L
.588 .25541 L
.592 .24879 L
.596 .24374 L
.6 .24 L
Mistroke
.604 .2373 L
.608 .2354 L
.612 .23409 L
.616 .23323 L
.62 .23266 L
.624 .2323 L
.628 .23208 L
.632 .23194 L
.636 .23186 L
.64 .23182 L
.644 .23179 L
.648 .23178 L
.652 .23177 L
.656 .23177 L
.66 .23176 L
.664 .23176 L
.668 .23176 L
.672 .23176 L
.676 .23176 L
.68 .23176 L
.684 .23176 L
.688 .23176 L
.692 .23176 L
.696 .23176 L
.7 .23176 L
.704 .23176 L
.708 .23176 L
.712 .23176 L
.716 .23176 L
.72 .23176 L
.724 .23176 L
.728 .23176 L
.732 .23176 L
.736 .23176 L
.74 .23176 L
.744 .23176 L
.748 .23176 L
.752 .23176 L
.756 .23176 L
.76 .23176 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35315 L
.352 .35314 L
.356 .35313 L
.36 .3531 L
.364 .35304 L
.368 .35295 L
.372 .35279 L
.376 .35252 L
.38 .35209 L
.384 .35142 L
.388 .35038 L
.392 .34883 L
.396 .34657 L
.4 .34335 L
Mistroke
.404 .33889 L
.408 .33288 L
.412 .32499 L
.416 .31495 L
.42 .30253 L
.424 .28763 L
.428 .27035 L
.432 .25097 L
.436 .23006 L
.44 .20841 L
.444 .18705 L
.448 .16719 L
.452 .15009 L
.456 .13699 L
.46 .12897 L
.464 .12688 L
.468 .1312 L
.472 .14207 L
.476 .15928 L
.48 .18229 L
.484 .21032 L
.488 .24244 L
.492 .27764 L
.496 .31489 L
.5 .35316 L
.504 .39143 L
.508 .42868 L
.512 .46388 L
.516 .49601 L
.52 .52403 L
.524 .54704 L
.528 .56425 L
.532 .57513 L
.536 .57945 L
.54 .57735 L
.544 .56934 L
.548 .55623 L
.552 .53913 L
.556 .51927 L
.56 .49792 L
.564 .47627 L
.568 .45535 L
.572 .43598 L
.576 .41869 L
.58 .4038 L
.584 .39138 L
.588 .38133 L
.592 .37345 L
.596 .36744 L
.6 .36297 L
Mistroke
.604 .35975 L
.608 .35749 L
.612 .35594 L
.616 .3549 L
.62 .35423 L
.624 .3538 L
.628 .35354 L
.632 .35338 L
.636 .35328 L
.64 .35323 L
.644 .3532 L
.648 .35318 L
.652 .35317 L
.656 .35317 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23176 L
.276 .23176 L
.28 .23176 L
.284 .23176 L
.288 .23176 L
.292 .23176 L
.296 .23176 L
.3 .23176 L
.304 .23176 L
.308 .23176 L
.312 .23176 L
.316 .23176 L
.32 .23176 L
.324 .23176 L
.328 .23176 L
.332 .23176 L
.336 .23176 L
.34 .23176 L
.344 .23177 L
.348 .23177 L
.352 .23178 L
.356 .23179 L
.36 .23182 L
.364 .23186 L
.368 .23194 L
.372 .23208 L
.376 .2323 L
.38 .23266 L
.384 .23323 L
.388 .23409 L
.392 .2354 L
.396 .2373 L
.4 .24 L
Mistroke
.404 .24374 L
.408 .24879 L
.412 .25541 L
.416 .26385 L
.42 .27428 L
.424 .28679 L
.428 .30131 L
.432 .3176 L
.436 .33522 L
.44 .3535 L
.444 .37161 L
.448 .38862 L
.452 .40355 L
.456 .4155 L
.46 .42375 L
.464 .42789 L
.468 .42784 L
.472 .42394 L
.476 .41692 L
.48 .4078 L
.484 .39782 L
.488 .38831 L
.492 .38049 L
.496 .37535 L
.5 .37357 L
.504 .37535 L
.508 .38049 L
.512 .38831 L
.516 .39782 L
.52 .4078 L
.524 .41692 L
.528 .42394 L
.532 .42784 L
.536 .42789 L
.54 .42375 L
.544 .4155 L
.548 .40355 L
.552 .38862 L
.556 .37161 L
.56 .3535 L
.564 .33522 L
.568 .3176 L
.572 .30131 L
.576 .28679 L
.58 .27428 L
.584 .26385 L
.588 .25541 L
.592 .24879 L
.596 .24374 L
.6 .24 L
Mistroke
.604 .2373 L
.608 .2354 L
.612 .23409 L
.616 .23323 L
.62 .23266 L
.624 .2323 L
.628 .23208 L
.632 .23194 L
.636 .23186 L
.64 .23182 L
.644 .23179 L
.648 .23178 L
.652 .23177 L
.656 .23177 L
.66 .23176 L
.664 .23176 L
.668 .23176 L
.672 .23176 L
.676 .23176 L
.68 .23176 L
.684 .23176 L
.688 .23176 L
.692 .23176 L
.696 .23176 L
.7 .23176 L
.704 .23176 L
.708 .23176 L
.712 .23176 L
.716 .23176 L
.72 .23176 L
.724 .23176 L
.728 .23176 L
.732 .23176 L
.736 .23176 L
.74 .23176 L
.744 .23176 L
.748 .23176 L
.752 .23176 L
.756 .23176 L
.76 .23176 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00`000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool20002Ool01@00Oomoogoo
000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo
Ool00Woo00<007ooOol02Woo000LOol2000XOol00`00Oomoo`0@Ool2000fOol001aoo`03001oogoo
02Qoo`03001oogoo00moo`03001oogoo03Eoo`0077oo0P00:Goo00<007ooOol03goo00<007ooOol0
=Goo000LOol00`00Oomoo`0YOol00`00Oomoo`0=Ool00`00Oomoo`0fOol000]oo`8000Aoo`04001o
ogooOol50002Ool2000ZOol00`00Oomoo`0=Ool00`00Oomoo`0fOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00<007ooOol0:Goo00<007ooOol037oo00<007ooOol0=goo000:Ool01000Oomo
o`002Goo00<007ooOol00Woo0P00:Woo00<007ooOol037oo00<007ooOol0=goo000:Ool01000Oomo
o`002Woo00D007ooOomoo`0002aoo`03001oogoo00]oo`03001oogoo03Moo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2000[Ool00`00Oomoo`0;Ool00`00Oomoo`0gOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0:Woo00<007ooOol02goo00<007ooOol0=goo
000;Ool20009Ool30003Ool2000[Ool00`00Oomoo`0;Ool00`00Oomoo`0gOol001aoo`03001oogoo
02]oo`03001oogoo00Uoo`03001oogoo03Qoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00
;7oo00<007ooOol02Goo00<007ooOol0>7oo000:Ool01000Oomoo`002Woo00D007ooOomoo`0002eo
o`03001oogoo009oo`8000Eoo`03001oogoo03Qoo`002Woo00@007ooOol000Moo`D0009oo`8002eo
o`07001oogooOol007oo00000goo00<007ooOol0>Goo000:Ool01000Oomoo`001goo00@007ooOol0
00=oo`03001oogoo02aoo`04001oogoo0003Ool01000Oomoo`00>goo000:Ool01000Oomoo`0027oo
00<007oo00000goo0P00;Goo00@007ooOol000=oo`04001oogoo000kOol000Yoo`04001oogoo0009
Ool20003Ool00`00Oomoo`0/Ool00`00Ool00004Ool00`00Ool0000lOol000]oo`8000]oo`04001o
ogooOol2000^Ool20005Ool2000lOol001aoo`03001oogoo02eoo`8000Eoo`8003aoo`002goo0P00
17oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04
001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2
001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`80
00=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001c
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03
001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Mo
o`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`80
07Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3
001hOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P00Lgoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`@000=o
o`8007=oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`03001oogoo079oo`002Woo00@007oo
Ool000Qoo`03001oogoo00=oo`8007=oo`002goo0P002Woo0P000goo00<007ooOol0LWoo000LOol2
000^Ool20013Ool001aoo`03001oogoo02aoo`03001oo`0004=oo`002goo0P0017oo00<007ooOol0
0goo0`000Woo0P00;Goo00<007oo0000@goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0002io
o`03001oo`0004=oo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo02aoo`03001o
o`0004=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool2000]Ool01000Oomoo`00@Woo000:
Ool01000Oomoo`0027oo00<007oo00000goo00<007ooOol0:goo00D007ooOomoo`00049oo`002Woo
00@007ooOol000Uoo`8000=oo`8002aoo`05001oogooOol00012Ool000]oo`8000]oo`05001oogoo
Ool0000]Ool01@00Oomoogoo0000@Woo000LOol2000/Ool01@00Oomoogoo0000@Woo000LOol00`00
Oomoo`0ZOol00`00Oomoo`03Ool00`00Oomoo`0oOol000]oo`8000Aoo`04001oogooOol50002Ool2
000[Ool00`00Oomoo`03Ool00`00Oomoo`0oOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00<007ooOol0:Woo00<007ooOol00goo00<007ooOol0?goo0003Ool50002Ool01000Oomoo`002Goo
00<007ooOol00Woo00<007ooOol0:Woo00<007ooOol00goo00<007ooOol0?goo000:Ool01000Oomo
o`002Woo00@007ooOomoo`8000ioo`<000Aoo`8000Uoo`<000Aoo`800004Ool007ooOol20002Ool0
0`00Oomoo`030003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo00D007ooOomoo`00
009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0200001goo001oogoo001oo`0000=o
o`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol0
0goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04001oogoo0002Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0200001goo001oogoo001oo`0000=oo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Uoo`<000=o
o`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`02
00001goo001oogoo001oo`0000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo
0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool0
0`00Oomoo`0200001goo001oogoo001oo`0000=oo`04001oogooOol40003Ool01000Oomoo`0017oo
00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003
Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P00
17oo00@007ooOol0009oo`06001oogoo001oo`000Woo0P000goo00<007ooOol017oo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo
00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo
0`000goo0P000Woo00D007ooOomoo`0000=oo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0
009oo`D000=oo`8000Ioo`0077oo0P00:7oo00<007ooOol01Woo00<007ooOol0?goo000LOol00`00
Oomoo`0VOol20009Ool00`00Oomoo`0nOol001aoofT000aoo`0077oo00<007ooOol04Woo00<007oo
Ool04Woo00<007ooOol01goo00<007ooOol01goo0P004goo00<007ooOol04Woo00<007ooOol02Woo
000LOol2000bOol00`00Oomoo`06Ool00`00Oomoo`0eOol001aoo`03001oogoo035oo`03001oogoo
00Ioo`03001oogoo03Eoo`0077oo0P00<Woo00<007ooOol01Woo00<007ooOol0=Goo000LOol00`00
Oomoo`0aOol00`00Oomoo`05Ool00`00Oomoo`0fOol001aoo`03001oogoo035oo`03001oogoo00Eo
o`03001oogoo03Ioo`002goo0P0017oo00@007ooOomoo`D0009oo`8003=oo`03001oogoo00Aoo`03
001oogoo03Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0bOol00`00Oomo
o`03Ool00`00Oomoo`0gOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000cOol00`00Oomo
o`03Ool00`00Oomoo`0gOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000=7oo00<007ooOol0
0goo00<007ooOol0=goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8003=oo`03001o
ogoo00=oo`03001oogoo03Moo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`0bOol00`00Oomoo`03Ool00`00Oomoo`0gOol000]oo`8000Uoo`<000=oo`03001oogoo039oo`03
001oogoo00=oo`03001oogoo03Moo`0077oo0P00=7oo00<007ooOol00Woo00<007ooOol0=goo000L
Ool00`00Oomoo`0cOol01@00Oomoogoo0000>Woo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2
000dOol01@00Oomoogoo0000>Woo000:Ool01000Oomoo`002Woo00D007ooOomoo`0003Eoo`05001o
ogooOol0000jOol000Yoo`04001oogoo0007Ool50002Ool2000dOol01@00Oomoogoo0000>Woo000:
Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo03=oo`04001oogoo000kOol000Yoo`04
001oogoo0008Ool00`00Ool00003Ool2000dOol01000Oomoo`00>goo000:Ool01000Oomoo`002Goo
0P000goo00<007ooOol0<goo00@007ooOol003]oo`002goo0P002goo00D007ooOomoo`0003Ioo`80
03aoo`0077oo0P00=Goo0P00?7oo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo
00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000=oo`D0009o
o`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`00
2Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomo
o`1bOol000]oo`8000Aoo`04001oogooOol50002Ool2001cOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`00
17oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000
Oomoo`002Goo00<007ooOol00Woo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`00
0Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`002Woo00D007oo
Oomoo`00019oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo00@007ooOol0009oo`03
001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@0
07ooOol000Eoo`002goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`80
00Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Ao
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo0000
1Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P00
17oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=o
o`8000Ioo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oo`0000<000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo1@000goo
00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00<007ooOol00Woo00<007ooOol02Woo000LOol2000XOol00`00Oomoo`0@Ool2000fOol001aoo`03
001oogoo02Qoo`03001oogoo00moo`03001oogoo03Eoo`0077oo0P00:Goo00<007ooOol03goo00<0
07ooOol0=Goo000LOol00`00Oomoo`0YOol00`00Oomoo`0=Ool00`00Oomoo`0fOol000]oo`8000Ao
o`04001oogooOol50002Ool2000ZOol00`00Oomoo`0=Ool00`00Oomoo`0fOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00<007ooOol0:Goo00<007ooOol03Goo00<007ooOol0=Woo000:Ool0
1000Oomoo`002Goo00<007ooOol00Woo0P00:Woo00<007ooOol037oo00<007ooOol0=goo000:Ool0
1000Oomoo`002Woo00D007ooOomoo`0002aoo`03001oogoo00]oo`03001oogoo03Moo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2000[Ool00`00Oomoo`0;Ool00`00Oomoo`0gOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0:Woo00<007ooOol02goo00<007oo
Ool0=goo000;Ool20009Ool30003Ool2000[Ool00`00Oomoo`0;Ool00`00Oomoo`0gOol001aoo`03
001oogoo02]oo`03001oogoo00Uoo`03001oogoo03Qoo`002goo0P0017oo00<007ooOol00goo0`00
0Woo0P00;7oo00<007ooOol02Goo00<007ooOol0>7oo000:Ool01000Oomoo`002Woo00D007ooOomo
o`0002eoo`03001oogoo009oo`8000Eoo`03001oogoo03Qoo`002Woo00@007ooOol000Moo`D0009o
o`8002aoo`03001oogoo009oo`03001oo`0000Aoo`03001oogoo03Qoo`002Woo00@007ooOol000Mo
o`04001oogoo0003Ool00`00Oomoo`0/Ool01`00Oomoogoo001oo`0000=oo`03001oogoo03Uoo`00
2Woo00@007ooOol000Qoo`03001oo`0000=oo`8002eoo`04001oogoo0003Ool01000Oomoo`00>goo
000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0;7oo00@007ooOol000=oo`03001oo`0003ao
o`002goo0P002goo00@007ooOomoo`8002ioo`8000Aoo`<003aoo`0077oo00<007ooOol0;Goo0P00
1Goo0P00?7oo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo
079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`00
27oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<0
00=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009o
o`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03
001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(120\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23176 L
.276 .23176 L
.28 .23176 L
.284 .23176 L
.288 .23176 L
.292 .23176 L
.296 .23176 L
.3 .23176 L
.304 .23176 L
.308 .23176 L
.312 .23176 L
.316 .23176 L
.32 .23176 L
.324 .23176 L
.328 .23177 L
.332 .23177 L
.336 .23177 L
.34 .23178 L
.344 .2318 L
.348 .23182 L
.352 .23187 L
.356 .23196 L
.36 .2321 L
.364 .23233 L
.368 .2327 L
.372 .23328 L
.376 .23416 L
.38 .23548 L
.384 .2374 L
.388 .24012 L
.392 .24387 L
.396 .24891 L
.4 .25551 L
Mistroke
.404 .2639 L
.408 .27426 L
.412 .28668 L
.416 .3011 L
.42 .31727 L
.424 .33475 L
.428 .35289 L
.432 .37087 L
.436 .38771 L
.44 .40241 L
.444 .41401 L
.448 .42167 L
.452 .42485 L
.456 .42329 L
.46 .41711 L
.464 .40678 L
.468 .39311 L
.472 .37714 L
.476 .36004 L
.48 .34306 L
.484 .32736 L
.488 .31399 L
.492 .30381 L
.496 .29745 L
.5 .29528 L
.504 .29745 L
.508 .30381 L
.512 .31399 L
.516 .32736 L
.52 .34306 L
.524 .36004 L
.528 .37714 L
.532 .39311 L
.536 .40678 L
.54 .41711 L
.544 .42329 L
.548 .42485 L
.552 .42167 L
.556 .41401 L
.56 .40241 L
.564 .38771 L
.568 .37087 L
.572 .35289 L
.576 .33475 L
.58 .31727 L
.584 .3011 L
.588 .28668 L
.592 .27426 L
.596 .2639 L
.6 .25551 L
Mistroke
.604 .24891 L
.608 .24387 L
.612 .24012 L
.616 .2374 L
.62 .23548 L
.624 .23416 L
.628 .23328 L
.632 .2327 L
.636 .23233 L
.64 .2321 L
.644 .23196 L
.648 .23187 L
.652 .23182 L
.656 .2318 L
.66 .23178 L
.664 .23177 L
.668 .23177 L
.672 .23177 L
.676 .23176 L
.68 .23176 L
.684 .23176 L
.688 .23176 L
.692 .23176 L
.696 .23176 L
.7 .23176 L
.704 .23176 L
.708 .23176 L
.712 .23176 L
.716 .23176 L
.72 .23176 L
.724 .23176 L
.728 .23176 L
.732 .23176 L
.736 .23176 L
.74 .23176 L
.744 .23176 L
.748 .23176 L
.752 .23176 L
.756 .23176 L
.76 .23176 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35315 L
.34 .35314 L
.344 .35312 L
.348 .35309 L
.352 .35303 L
.356 .35293 L
.36 .35276 L
.364 .35249 L
.368 .35205 L
.372 .35136 L
.376 .3503 L
.38 .34873 L
.384 .34645 L
.388 .34321 L
.392 .33874 L
.396 .33274 L
.4 .32488 L
Mistroke
.404 .31488 L
.408 .30254 L
.412 .28774 L
.416 .27057 L
.42 .25131 L
.424 .23048 L
.428 .20887 L
.432 .18746 L
.436 .16741 L
.44 .14991 L
.444 .13613 L
.448 .12706 L
.452 .1234 L
.456 .12547 L
.46 .13321 L
.464 .14617 L
.468 .16354 L
.472 .18434 L
.476 .20748 L
.48 .23193 L
.484 .25683 L
.488 .28158 L
.492 .30587 L
.496 .32967 L
.5 .35316 L
.504 .37666 L
.508 .40046 L
.512 .42474 L
.516 .44949 L
.52 .47439 L
.524 .49884 L
.528 .52198 L
.532 .54278 L
.536 .56016 L
.54 .57311 L
.544 .58085 L
.548 .58293 L
.552 .57926 L
.556 .57019 L
.56 .55641 L
.564 .53892 L
.568 .51886 L
.572 .49745 L
.576 .47584 L
.58 .45502 L
.584 .43575 L
.588 .41858 L
.592 .40379 L
.596 .39144 L
.6 .38145 L
Mistroke
.604 .37359 L
.608 .36758 L
.612 .36311 L
.616 .35988 L
.62 .35759 L
.624 .35602 L
.628 .35497 L
.632 .35428 L
.636 .35384 L
.64 .35356 L
.644 .35339 L
.648 .35329 L
.652 .35323 L
.656 .3532 L
.66 .35318 L
.664 .35317 L
.668 .35317 L
.672 .35317 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23176 L
.276 .23176 L
.28 .23176 L
.284 .23176 L
.288 .23176 L
.292 .23176 L
.296 .23176 L
.3 .23176 L
.304 .23176 L
.308 .23176 L
.312 .23176 L
.316 .23176 L
.32 .23176 L
.324 .23176 L
.328 .23177 L
.332 .23177 L
.336 .23177 L
.34 .23178 L
.344 .2318 L
.348 .23182 L
.352 .23187 L
.356 .23196 L
.36 .2321 L
.364 .23233 L
.368 .2327 L
.372 .23328 L
.376 .23416 L
.38 .23548 L
.384 .2374 L
.388 .24012 L
.392 .24387 L
.396 .24891 L
.4 .25551 L
Mistroke
.404 .2639 L
.408 .27426 L
.412 .28668 L
.416 .3011 L
.42 .31727 L
.424 .33475 L
.428 .35289 L
.432 .37087 L
.436 .38771 L
.44 .40241 L
.444 .41401 L
.448 .42167 L
.452 .42485 L
.456 .42329 L
.46 .41711 L
.464 .40678 L
.468 .39311 L
.472 .37714 L
.476 .36004 L
.48 .34306 L
.484 .32736 L
.488 .31399 L
.492 .30381 L
.496 .29745 L
.5 .29528 L
.504 .29745 L
.508 .30381 L
.512 .31399 L
.516 .32736 L
.52 .34306 L
.524 .36004 L
.528 .37714 L
.532 .39311 L
.536 .40678 L
.54 .41711 L
.544 .42329 L
.548 .42485 L
.552 .42167 L
.556 .41401 L
.56 .40241 L
.564 .38771 L
.568 .37087 L
.572 .35289 L
.576 .33475 L
.58 .31727 L
.584 .3011 L
.588 .28668 L
.592 .27426 L
.596 .2639 L
.6 .25551 L
Mistroke
.604 .24891 L
.608 .24387 L
.612 .24012 L
.616 .2374 L
.62 .23548 L
.624 .23416 L
.628 .23328 L
.632 .2327 L
.636 .23233 L
.64 .2321 L
.644 .23196 L
.648 .23187 L
.652 .23182 L
.656 .2318 L
.66 .23178 L
.664 .23177 L
.668 .23177 L
.672 .23177 L
.676 .23176 L
.68 .23176 L
.684 .23176 L
.688 .23176 L
.692 .23176 L
.696 .23176 L
.7 .23176 L
.704 .23176 L
.708 .23176 L
.712 .23176 L
.716 .23176 L
.72 .23176 L
.724 .23176 L
.728 .23176 L
.732 .23176 L
.736 .23176 L
.74 .23176 L
.744 .23176 L
.748 .23176 L
.752 .23176 L
.756 .23176 L
.76 .23176 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00H0
07oo000007oo0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`D000=oo`03001oogoo
009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo
009oo`03001oogoo00Yoo`0077oo0P009goo00<007ooOol04goo00<007ooOol0<goo000LOol00`00
Oomoo`0WOol00`00Oomoo`0AOol00`00Oomoo`0dOol001aoo`8002Qoo`03001oogoo015oo`03001o
ogoo03Aoo`0077oo00<007ooOol09goo00<007ooOol047oo00<007ooOol0=Goo000;Ool20004Ool0
1000Oomoogoo1@000Woo0P00:Goo00<007ooOol03goo00<007ooOol0=Goo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`03001oogoo02Qoo`03001oogoo00Eoo`8000Qoo`03001oogoo03Eoo`00
2Woo00@007ooOol000Uoo`03001oogoo009oo`8002Uoo`03001oogoo00Eoo`03001oo`0000Moo`03
001oogoo03Eoo`002Woo00@007ooOol000Yoo`05001oogooOol0000[Ool00`00Oomoo`04Ool00`00
Ool00006Ool00`00Oomoo`0fOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00:Woo
00<007ooOol00goo00D007ooOomoo`0000Eoo`03001oogoo03Ioo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`0YOol00`00Oomoo`03Ool01@00Oomoogoo00001Goo00<007oo
Ool0=Woo000;Ool20009Ool30003Ool2000ZOol00`00Oomoo`03Ool01@00Oomoogoo00001Goo00<0
07ooOol0=Woo000LOol00`00Oomoo`0YOol00`00Oomoo`03Ool01@00Oomoogoo000017oo00<007oo
Ool0=goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000ZOol00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0gOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000
;7oo00D007ooOomoo`0000Eoo`05001oogooOol0000iOol000Yoo`04001oogoo0007Ool50002Ool2
000[Ool01@00Oomoogoo00001Goo00D007ooOomoo`0003Uoo`002Woo00@007ooOol000Moo`04001o
ogoo0003Ool00`00Oomoo`0ZOol01@00Oomoogoo00001Goo00D007ooOomoo`0003Uoo`002Woo00@0
07ooOol000Qoo`03001oo`0000=oo`8002aoo`03001oo`0000Moo`03001oo`0003Yoo`002Woo00@0
07ooOol000Uoo`8000=oo`03001oogoo02]oo`03001oo`0000Moo`03001oo`0003Yoo`002goo0P00
2goo00@007ooOomoo`8002eoo`03001oogoo00Ioo`8003]oo`0077oo00<007ooOol0LWoo000;Ool2
0004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo
00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Ao
o`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo
0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`80
07=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo
00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`00
5goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo
0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009o
o`<007Qoo`002Woo00@007ooOol000Moo`05001oogooOol0001gOol000=oo`D0009oo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool2001cOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo1000
0goo0P00Lgoo000:Ool01000Oomoo`001goo00<007ooOol017oo00<007ooOol0LWoo000:Ool01000
Oomoo`0027oo00<007ooOol00goo0P00Lgoo000;Ool2000:Ool20003Ool00`00Oomoo`0/Ool00`00
Oomoo`13Ool001aoo`8002aoo`<004Aoo`0077oo00<007ooOol0:goo00<007oo0000A7oo000;Ool2
0004Ool00`00Oomoo`03Ool30002Ool2000/Ool00`00Ool00014Ool000Yoo`04001oogoo000:Ool0
1@00Oomoogoo0000;Goo00@007ooOol004=oo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03
001oogoo02Yoo`05001oogooOol00013Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P00
:goo00D007ooOomoo`0004=oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo02Yo
o`05001oogooOol00013Ool000Yoo`04001oogoo0009Ool20003Ool2000[Ool01@00Oomoogoo0000
@goo000;Ool2000;Ool01@00Oomoogoo0000:goo00<007ooOol00Woo00<007ooOol0@Goo000LOol2
000ZOol00`00Oomoo`02Ool00`00Oomoo`11Ool001aoo`03001oogoo02Uoo`03001oogoo00=oo`03
001oogoo041oo`002goo0P0017oo00@007ooOomoo`D0009oo`8002Yoo`03001oogoo00=oo`03001o
ogoo041oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0YOol00`00Oomoo`03
Ool00`00Oomoo`10Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0Y
Ool00`00Oomoo`03Ool00`00Oomoo`10Ool000Yoo`04001oogoo000:Ool01000Oomoogoo0P003Woo
0`0017oo0P002Goo0`0017oo0`000goo0P0000=oo`00Ool00Woo0`000goo0`0017oo0P001Goo1@00
0goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo
00@007ooOol0009oo`06001oogoo001oo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00
Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P004Goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002
Ool01P00Oomoo`00Ool000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`03Ool000]oo`8000Uoo`<000=oo`03001oogoo011oo`04001oogoo0002Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool0
1000Oomoo`002Goo00<007ooOol00Woo00@007oo0000009oo`06001oogoo001oo`000goo00@007oo
Oomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001o
ogoo00Aoo`04001oogoo0008Ool20004Ool01000Ool000000Woo00H007ooOol007oo0002Ool20003
Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000
Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool5
0003Ool2000:Ool00`00Oomoo`03Ool20004Ool20002Ool01@00Oomoogoo00000goo1@000goo0P00
1Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000WOol00`00Oomoo`07
Ool00`00Oomoo`0oOol001aoo`03001oogoo02Aoo`8000]oo`03001oogoo03ioo`0077ooJ@0037oo
000LOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`07Ool00`00Oomoo`07Ool3000BOol0
0`00Oomoo`0BOol00`00Oomoo`0:Ool001aoo`80039oo`03001oogoo00Qoo`03001oogoo03=oo`00
77oo00<007ooOol0<Goo00<007ooOol01goo00<007ooOol0=7oo000LOol2000cOol00`00Oomoo`06
Ool00`00Oomoo`0dOol001aoo`03001oogoo039oo`03001oogoo00Eoo`03001oogoo03Eoo`0077oo
00<007ooOol0<Woo00<007ooOol01Goo00<007ooOol0=Goo000;Ool20004Ool01000Oomoogoo1@00
0Woo0P00<goo00<007ooOol01Goo00<007ooOol0=Goo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`03001oogoo039oo`03001oogoo00Eoo`03001oogoo03Eoo`002Woo00@007ooOol000Uoo`03
001oogoo009oo`8003Aoo`03001oogoo00Aoo`03001oogoo03Eoo`002Woo00@007ooOol000Yoo`05
001oogooOol0000eOol00`00Oomoo`03Ool00`00Oomoo`0fOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo0P00=7oo00<007ooOol00goo00<007ooOol0=Woo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo03=oo`03001oogoo00=oo`03001oogoo03Ioo`002goo0P00
2Goo0`000goo00<007ooOol0<goo00<007ooOol00goo00<007ooOol0=Woo000LOol2000dOol00`00
Oomoo`03Ool00`00Oomoo`0fOol001aoo`03001oogoo03=oo`03001oogoo009oo`03001oogoo03Mo
o`002goo0P0017oo00<007ooOol00goo0`000Woo0P00=7oo00<007ooOol00Woo00<007ooOol0=goo
000:Ool01000Oomoo`002Woo00D007ooOomoo`0003Ioo`05001oogooOol0000iOol000Yoo`04001o
ogoo0007Ool50002Ool2000eOol01@00Oomoogoo0000>Goo000:Ool01000Oomoo`001goo00@007oo
Ool000=oo`03001oogoo03Aoo`05001oogooOol0000iOol000Yoo`04001oogoo0008Ool00`00Ool0
0003Ool2000eOol01@00Oomoogoo0000>Goo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0
=Goo00<007oo0000>Woo000;Ool2000;Ool01@00Oomoogoo0000=goo00<007oo0000>Woo000LOol2
000fOol2000kOol001aoo`03001oogoo03Ioo`03001oogoo03Uoo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007oo
Ool00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@00
0Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo
0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001o
ogoo079oo`002goo0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool3
0004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04
001oogoo0009Ool00`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00
Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00
Oomoogoo00004Woo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo
00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool0
1000Oomoo`001Goo000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo
0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool0
0006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool2
0004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@00
0goo0P001Woo000LOol2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomo
ogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo100000=oo`00Ool00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool50003
Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`8002Moo`03001oogoo01=oo`03001oogoo03=o
o`0077oo00<007ooOol09goo00<007ooOol04Goo00<007ooOol0=7oo000LOol2000XOol00`00Oomo
o`0AOol00`00Oomoo`0dOol001aoo`03001oogoo02Moo`03001oogoo011oo`03001oogoo03Eoo`00
2goo0P0017oo00@007ooOomoo`D0009oo`8002Uoo`03001oogoo00moo`03001oogoo03Eoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0XOol00`00Oomoo`05Ool20008Ool00`00
Oomoo`0eOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000YOol00`00Oomoo`05Ool00`00
Ool00007Ool00`00Oomoo`0eOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000:goo00<007oo
Ool017oo00<007oo00001Woo00<007ooOol0=Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8002Yoo`03001oogoo00=oo`05001oogooOol00005Ool00`00Oomoo`0fOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0:Goo00<007ooOol00goo00D007ooOomoo`00
00Eoo`03001oogoo03Ioo`002goo0P002Goo0`000goo0P00:Woo00<007ooOol00goo00D007ooOomo
o`0000Eoo`03001oogoo03Ioo`0077oo00<007ooOol0:Goo00<007ooOol00goo00D007ooOomoo`00
00Aoo`03001oogoo03Moo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00:Woo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0=goo000:Ool01000Oomoo`002Woo00D0
07ooOomoo`0002aoo`05001oogooOol00005Ool01@00Oomoogoo0000>Goo000:Ool01000Oomoo`00
1goo1@000Woo0P00:goo00D007ooOomoo`0000Eoo`05001oogooOol0000iOol000Yoo`04001oogoo
0007Ool01000Oomoo`000goo00<007ooOol0:Woo00D007ooOomoo`0000Eoo`05001oogooOol0000i
Ool000Yoo`04001oogoo0008Ool00`00Ool00003Ool2000/Ool01000Oomoo`001Goo00@007ooOol0
03Yoo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo02]oo`03001oo`0000Moo`03001oo`00
03Yoo`002goo0P002goo00@007ooOomoo`8002eoo`8000Moo`8003]oo`0077oo00<007ooOol0LWoo
000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=o
o`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo
0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<0
00=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=o
o`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo
079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Mo
o`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(160\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23176 L
.276 .23176 L
.28 .23176 L
.284 .23176 L
.288 .23176 L
.292 .23176 L
.296 .23176 L
.3 .23176 L
.304 .23176 L
.308 .23176 L
.312 .23176 L
.316 .23177 L
.32 .23177 L
.324 .23177 L
.328 .23178 L
.332 .2318 L
.336 .23183 L
.34 .23188 L
.344 .23197 L
.348 .23212 L
.352 .23236 L
.356 .23274 L
.36 .23333 L
.364 .23423 L
.368 .23557 L
.372 .2375 L
.376 .24023 L
.38 .24399 L
.384 .24902 L
.388 .2556 L
.392 .26395 L
.396 .27425 L
.4 .28658 L
Mistroke
.404 .3009 L
.408 .31696 L
.412 .33434 L
.416 .3524 L
.42 .37033 L
.424 .38716 L
.428 .40191 L
.432 .41359 L
.436 .42138 L
.44 .42468 L
.444 .42322 L
.448 .41706 L
.452 .40661 L
.456 .39259 L
.46 .37593 L
.464 .35769 L
.468 .33896 L
.472 .3207 L
.476 .30378 L
.48 .28882 L
.484 .27626 L
.488 .26638 L
.492 .25929 L
.496 .25503 L
.5 .25362 L
.504 .25503 L
.508 .25929 L
.512 .26638 L
.516 .27626 L
.52 .28882 L
.524 .30378 L
.528 .3207 L
.532 .33896 L
.536 .35769 L
.54 .37593 L
.544 .39259 L
.548 .40661 L
.552 .41706 L
.556 .42322 L
.56 .42468 L
.564 .42138 L
.568 .41359 L
.572 .40191 L
.576 .38716 L
.58 .37033 L
.584 .3524 L
.588 .33434 L
.592 .31696 L
.596 .3009 L
.6 .28658 L
Mistroke
.604 .27425 L
.608 .26395 L
.612 .2556 L
.616 .24902 L
.62 .24399 L
.624 .24023 L
.628 .2375 L
.632 .23557 L
.636 .23423 L
.64 .23333 L
.644 .23274 L
.648 .23236 L
.652 .23212 L
.656 .23197 L
.66 .23188 L
.664 .23183 L
.668 .2318 L
.672 .23178 L
.676 .23177 L
.68 .23177 L
.684 .23177 L
.688 .23176 L
.692 .23176 L
.696 .23176 L
.7 .23176 L
.704 .23176 L
.708 .23176 L
.712 .23176 L
.716 .23176 L
.72 .23176 L
.724 .23176 L
.728 .23176 L
.732 .23176 L
.736 .23176 L
.74 .23176 L
.744 .23176 L
.748 .23176 L
.752 .23176 L
.756 .23176 L
.76 .23176 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35315 L
.328 .35314 L
.332 .35312 L
.336 .35308 L
.34 .35302 L
.344 .35292 L
.348 .35274 L
.352 .35246 L
.356 .352 L
.36 .35129 L
.364 .35022 L
.368 .34863 L
.372 .34632 L
.376 .34307 L
.38 .3386 L
.384 .3326 L
.388 .32477 L
.392 .31482 L
.396 .30255 L
.4 .28786 L
Mistroke
.404 .2708 L
.408 .25167 L
.412 .23097 L
.416 .20945 L
.42 .1881 L
.424 .16805 L
.428 .15049 L
.432 .13658 L
.436 .1273 L
.44 .12337 L
.444 .12512 L
.448 .13247 L
.452 .14493 L
.456 .16166 L
.46 .18156 L
.464 .20339 L
.468 .22591 L
.472 .24801 L
.476 .2688 L
.48 .28767 L
.484 .30434 L
.488 .31883 L
.492 .33144 L
.496 .34267 L
.5 .35316 L
.504 .36366 L
.508 .37488 L
.512 .38749 L
.516 .40198 L
.52 .41866 L
.524 .43753 L
.528 .45831 L
.532 .48041 L
.536 .50293 L
.54 .52476 L
.544 .54466 L
.548 .56139 L
.552 .57386 L
.556 .58121 L
.56 .58295 L
.564 .57902 L
.568 .56975 L
.572 .55584 L
.576 .53828 L
.58 .51822 L
.584 .49687 L
.588 .47536 L
.592 .45466 L
.596 .43552 L
.6 .41847 L
Mistroke
.604 .40377 L
.608 .3915 L
.612 .38156 L
.616 .37373 L
.62 .36773 L
.624 .36325 L
.628 .36 L
.632 .3577 L
.636 .3561 L
.64 .35503 L
.644 .35432 L
.648 .35387 L
.652 .35358 L
.656 .35341 L
.66 .3533 L
.664 .35324 L
.668 .35321 L
.672 .35319 L
.676 .35317 L
.68 .35317 L
.684 .35317 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23176 L
.276 .23176 L
.28 .23176 L
.284 .23176 L
.288 .23176 L
.292 .23176 L
.296 .23176 L
.3 .23176 L
.304 .23176 L
.308 .23176 L
.312 .23176 L
.316 .23177 L
.32 .23177 L
.324 .23177 L
.328 .23178 L
.332 .2318 L
.336 .23183 L
.34 .23188 L
.344 .23197 L
.348 .23212 L
.352 .23236 L
.356 .23274 L
.36 .23333 L
.364 .23423 L
.368 .23557 L
.372 .2375 L
.376 .24023 L
.38 .24399 L
.384 .24902 L
.388 .2556 L
.392 .26395 L
.396 .27425 L
.4 .28658 L
Mistroke
.404 .3009 L
.408 .31696 L
.412 .33434 L
.416 .3524 L
.42 .37033 L
.424 .38716 L
.428 .40191 L
.432 .41359 L
.436 .42138 L
.44 .42468 L
.444 .42322 L
.448 .41706 L
.452 .40661 L
.456 .39259 L
.46 .37593 L
.464 .35769 L
.468 .33896 L
.472 .3207 L
.476 .30378 L
.48 .28882 L
.484 .27626 L
.488 .26638 L
.492 .25929 L
.496 .25503 L
.5 .25362 L
.504 .25503 L
.508 .25929 L
.512 .26638 L
.516 .27626 L
.52 .28882 L
.524 .30378 L
.528 .3207 L
.532 .33896 L
.536 .35769 L
.54 .37593 L
.544 .39259 L
.548 .40661 L
.552 .41706 L
.556 .42322 L
.56 .42468 L
.564 .42138 L
.568 .41359 L
.572 .40191 L
.576 .38716 L
.58 .37033 L
.584 .3524 L
.588 .33434 L
.592 .31696 L
.596 .3009 L
.6 .28658 L
Mistroke
.604 .27425 L
.608 .26395 L
.612 .2556 L
.616 .24902 L
.62 .24399 L
.624 .24023 L
.628 .2375 L
.632 .23557 L
.636 .23423 L
.64 .23333 L
.644 .23274 L
.648 .23236 L
.652 .23212 L
.656 .23197 L
.66 .23188 L
.664 .23183 L
.668 .2318 L
.672 .23178 L
.676 .23177 L
.68 .23177 L
.684 .23177 L
.688 .23176 L
.692 .23176 L
.696 .23176 L
.7 .23176 L
.704 .23176 L
.708 .23176 L
.712 .23176 L
.716 .23176 L
.72 .23176 L
.724 .23176 L
.728 .23176 L
.732 .23176 L
.736 .23176 L
.74 .23176 L
.744 .23176 L
.748 .23176 L
.752 .23176 L
.756 .23176 L
.76 .23176 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo0`00
0Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo0P000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00Woo00<007ooOol02Woo000LOol2000UOol2000GOol00`00Oomoo`0bOol001aoo`03001o
ogoo02Eoo`03001oogoo00Qoo`<000Uoo`03001oogoo03=oo`0077oo0P009goo00<007ooOol01goo
00<007oo00002Goo00<007ooOol0<goo000LOol00`00Oomoo`0VOol00`00Oomoo`06Ool01@00Oomo
ogoo000027oo00<007ooOol0<goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00:7oo00<007oo
Ool01Goo00D007ooOomoo`0000Moo`03001oogoo03Aoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool00`00Oomoo`0WOol00`00Oomoo`05Ool01@00Oomoogoo00001goo00<007ooOol0=7oo000:
Ool01000Oomoo`002Goo00<007ooOol00Woo0P00:7oo00<007ooOol017oo00<007ooOol00Woo00<0
07ooOol01Goo00<007ooOol0=7oo000:Ool01000Oomoo`002Woo00D007ooOomoo`0002Uoo`03001o
ogoo00Aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo03Eoo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2000XOol00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
0`00Oomoo`0eOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0:7oo00<0
07ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol0=Goo000;Ool20009Ool30003
Ool2000YOol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0eOol001ao
o`03001oogoo02Qoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo03Eo
o`002goo0P0017oo00<007ooOol00goo0`000Woo0P00:Goo00<007ooOol00Woo00<007ooOol01Goo
00<007ooOol00Woo00<007ooOol0=Goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0002]oo`05
001oogooOol00007Ool01@00Oomoogoo0000>7oo000:Ool01000Oomoo`001goo1@000Woo0P00:Woo
00D007ooOomoo`0000Moo`05001oogooOol0000hOol000Yoo`04001oogoo0007Ool01000Oomoo`00
0goo00<007ooOol0:Goo00@007ooOol000Qoo`05001oogooOol0000hOol000Yoo`04001oogoo0008
Ool00`00Ool00003Ool2000ZOol01000Oomoo`002Goo00<007oo0000>Goo000:Ool01000Oomoo`00
2Goo0P000goo00<007ooOol0:Woo00<007oo00002Goo00<007oo0000>Goo000;Ool2000;Ool01000
Oomoogoo0P00:goo0P002goo0P00>Goo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo
009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo
10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool0
1000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol0
01aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol0
01Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02
Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03
001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00N7oo000:Ool0
1000Oomoo`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`8007=oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001ao
o`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool40003Ool2001cOol000Yo
o`04001oogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00
Oomoo`03Ool2001cOol000]oo`8000Yoo`8000=oo`03001oogoo02]oo`03001oogoo04Aoo`0077oo
0P00:goo00<007oo0000AGoo000LOol00`00Oomoo`0ZOol00`00Ool00015Ool000]oo`8000Aoo`03
001oogoo00=oo`<0009oo`8002Yoo`04001oogoo0015Ool000Yoo`04001oogoo000:Ool01@00Oomo
ogoo0000:goo00@007ooOol004Eoo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo
02Uoo`04001oogoo0015Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P00:Woo00D007oo
Oomoo`0004Aoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo02Uoo`05001oogoo
Ool00014Ool000Yoo`04001oogoo0009Ool20003Ool2000ZOol01@00Oomoogoo0000A7oo000;Ool2
000;Ool01@00Oomoogoo0000:Woo00<007ooOol00Woo00<007ooOol0@Woo000LOol2000YOol00`00
Oomoo`03Ool00`00Oomoo`11Ool001aoo`03001oogoo02Qoo`03001oogoo00=oo`03001oogoo045o
o`002goo0P0017oo00@007ooOomoo`D0009oo`8002Uoo`03001oogoo00=oo`03001oogoo045oo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0WOol00`00Oomoo`04Ool00`00Oomo
o`11Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomo
o`04Ool00`00Oomoo`11Ool000Yoo`04001oogoo000:Ool01000Oomoogoo0P003Woo0`0017oo0P00
2Goo0`0017oo0P0017oo0`0017oo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@00
0Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00ao
o`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007oo0000009oo`04001o
ogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`00
0Woo00<007ooOol01goo00<007ooOol00Woo00@007oo0000009oo`03001oogoo008000Aoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Uoo`<0
00=oo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Ool0
00000Woo00<007ooOol00P0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0
009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`80
0005Ool007ooOol00002Ool20004Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007oo
Ool000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`800005
Ool007ooOol00002Ool00`00Ool00002Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool0
1000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`02Ool30004Ool2
0002Ool01@00Oomoogoo00000goo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@00
0goo0P001Woo000LOol2000UOol2000:Ool00`00Oomoo`0oOol001aoo`03001oogoo02=oo`8000]o
o`03001oogoo03moo`0077ooJ@0037oo000LOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomo
o`07Ool00`00Oomoo`07Ool01000Ool000004Goo00<007ooOol04Woo00<007ooOol02Woo000LOol2
000cOol00`00Oomoo`08Ool00`00Oomoo`0bOol001aoo`03001oogoo039oo`03001oogoo00Moo`03
001oogoo03=oo`0077oo0P00<goo00<007ooOol01goo00<007ooOol0<goo000LOol00`00Oomoo`0c
Ool00`00Oomoo`06Ool00`00Oomoo`0cOol001aoo`03001oogoo03=oo`03001oogoo00Ioo`03001o
ogoo03=oo`002goo0P0017oo00@007ooOomoo`D0009oo`8003Aoo`03001oogoo00Eoo`03001oogoo
03Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0cOol00`00Oomoo`05Ool0
0`00Oomoo`0dOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000dOol00`00Oomoo`05Ool0
0`00Oomoo`0dOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000=Goo00<007ooOol017oo00<0
07ooOol0=Goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8003Eoo`03001oogoo00=o
o`03001oogoo03Eoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0dOol0
0`00Oomoo`03Ool00`00Oomoo`0eOol000]oo`8000Uoo`<000=oo`03001oogoo03Aoo`03001oogoo
00=oo`03001oogoo03Eoo`0077oo0P00=Goo00<007ooOol00goo00<007ooOol0=Goo000LOol00`00
Oomoo`0eOol00`00Oomoo`02Ool00`00Oomoo`0eOol000]oo`8000Aoo`03001oogoo00=oo`<0009o
o`8003Ioo`03001oogoo009oo`03001oogoo03Eoo`002Woo00@007ooOol000Yoo`05001oogooOol0
000gOol01@00Oomoogoo0000>7oo000:Ool01000Oomoo`001goo1@000Woo0P00=Woo00D007ooOomo
o`0003Qoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0eOol01@00Oomoogoo
0000>7oo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00=Woo00D007ooOomoo`0003Qoo`00
2Woo00@007ooOol000Uoo`8000=oo`03001oogoo03Ioo`03001oo`0003Uoo`002goo0P002goo00D0
07ooOomoo`0003Qoo`03001oo`0003Uoo`0077oo0P00=goo0`00>Goo000LOol00`00Oomoo`0gOol0
0`00Oomoo`0hOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000L
Ool00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007oo
Ool000Yoo`05001oogooOol0001dOol000=oo`D0009oo`04001oogoo0007Ool50002Ool2001cOol0
00Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo
00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2
000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogooOol5
0002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol03Goo0`0017oo
0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo
1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo0P003Goo
00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`04001oogoo0002Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Io
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo0P004Goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0
009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<
Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
1000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Goo0`000goo
0P003Goo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`00
17oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007oo
Ool037oo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`80
00Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`<0009oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`<0009oo`03001oogoo009oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo
00Yoo`0077oo0P009Goo0P005goo00<007ooOol0<Woo000LOol00`00Oomoo`0UOol00`00Oomoo`08
Ool30009Ool00`00Oomoo`0cOol001aoo`8002Moo`03001oogoo00Moo`03001oo`0000Uoo`03001o
ogoo03=oo`0077oo00<007ooOol09Woo00<007ooOol01Woo00D007ooOomoo`0000Qoo`03001oogoo
03=oo`002goo0P0017oo00@007ooOomoo`D0009oo`8002Qoo`03001oogoo00Eoo`05001oogooOol0
0007Ool00`00Oomoo`0dOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol09goo
00<007ooOol01Goo00D007ooOomoo`0000Moo`03001oogoo03Aoo`002Woo00@007ooOol000Uoo`03
001oogoo009oo`8002Qoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo
03Aoo`002Woo00@007ooOol000Yoo`05001oogooOol0000YOol00`00Oomoo`04Ool00`00Oomoo`02
Ool00`00Oomoo`04Ool00`00Oomoo`0eOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
0P00:7oo00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol0=Goo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo02Qoo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo00=oo`03001oogoo03Eoo`002goo0P002Goo0`000goo0P00:Goo00<007ooOol0
0goo00<007ooOol00goo00<007ooOol00goo00<007ooOol0=Goo000LOol00`00Oomoo`0XOol00`00
Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0eOol000]oo`8000Aoo`03001o
ogoo00=oo`<0009oo`8002Uoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`03001o
ogoo03Eoo`002Woo00@007ooOol000Yoo`05001oogooOol0000[Ool01@00Oomoogoo00001goo00D0
07ooOomoo`0003Qoo`002Woo00@007ooOol000Moo`D0009oo`8002Yoo`05001oogooOol00007Ool0
1@00Oomoogoo0000>7oo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo02Uoo`04
001oogoo0008Ool01@00Oomoogoo0000>7oo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00
:Woo00@007ooOol000Qoo`04001oogoo000iOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomo
o`0ZOol00`00Ool00009Ool00`00Ool0000iOol000]oo`8000]oo`04001oogooOol2000[Ool30009
Ool3000iOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00
Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo
000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=o
o`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo
000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<0
07ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(200\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23176 L
.276 .23176 L
.28 .23176 L
.284 .23176 L
.288 .23176 L
.292 .23176 L
.296 .23176 L
.3 .23176 L
.304 .23177 L
.308 .23177 L
.312 .23177 L
.316 .23178 L
.32 .2318 L
.324 .23183 L
.328 .23189 L
.332 .23198 L
.336 .23214 L
.34 .23238 L
.344 .23278 L
.348 .23338 L
.352 .2343 L
.356 .23565 L
.36 .2376 L
.364 .24034 L
.368 .24411 L
.372 .24914 L
.376 .25569 L
.38 .264 L
.384 .27424 L
.388 .28649 L
.392 .30071 L
.396 .31667 L
.4 .33395 L
Mistroke
.404 .35192 L
.408 .36979 L
.412 .38662 L
.416 .40141 L
.42 .41319 L
.424 .42112 L
.428 .4246 L
.432 .42332 L
.436 .41733 L
.44 .40703 L
.444 .39309 L
.448 .37645 L
.452 .35816 L
.456 .33927 L
.46 .32078 L
.464 .30348 L
.468 .28797 L
.472 .2746 L
.476 .26353 L
.48 .25471 L
.484 .24798 L
.488 .2431 L
.492 .23983 L
.496 .23796 L
.5 .23736 L
.504 .23796 L
.508 .23983 L
.512 .2431 L
.516 .24798 L
.52 .25471 L
.524 .26353 L
.528 .2746 L
.532 .28797 L
.536 .30348 L
.54 .32078 L
.544 .33927 L
.548 .35816 L
.552 .37645 L
.556 .39309 L
.56 .40703 L
.564 .41733 L
.568 .42332 L
.572 .4246 L
.576 .42112 L
.58 .41319 L
.584 .40141 L
.588 .38662 L
.592 .36979 L
.596 .35192 L
.6 .33395 L
Mistroke
.604 .31667 L
.608 .30071 L
.612 .28649 L
.616 .27424 L
.62 .264 L
.624 .25569 L
.628 .24914 L
.632 .24411 L
.636 .24034 L
.64 .2376 L
.644 .23565 L
.648 .2343 L
.652 .23338 L
.656 .23278 L
.66 .23238 L
.664 .23214 L
.668 .23198 L
.672 .23189 L
.676 .23183 L
.68 .2318 L
.684 .23178 L
.688 .23177 L
.692 .23177 L
.696 .23177 L
.7 .23176 L
.704 .23176 L
.708 .23176 L
.712 .23176 L
.716 .23176 L
.72 .23176 L
.724 .23176 L
.728 .23176 L
.732 .23176 L
.736 .23176 L
.74 .23176 L
.744 .23176 L
.748 .23176 L
.752 .23176 L
.756 .23176 L
.76 .23176 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35315 L
.316 .35314 L
.32 .35312 L
.324 .35308 L
.328 .35301 L
.332 .3529 L
.336 .35272 L
.34 .35242 L
.344 .35195 L
.348 .35123 L
.352 .35014 L
.356 .34853 L
.36 .34621 L
.364 .34294 L
.368 .33846 L
.372 .33247 L
.376 .32466 L
.38 .31476 L
.384 .30257 L
.388 .28797 L
.392 .27103 L
.396 .25202 L
.4 .23144 L
Mistroke
.404 .21003 L
.408 .18874 L
.412 .16869 L
.416 .15108 L
.42 .13705 L
.424 .12761 L
.428 .12347 L
.432 .12499 L
.436 .13213 L
.44 .14441 L
.444 .16102 L
.448 .18084 L
.452 .20264 L
.456 .22514 L
.46 .24718 L
.464 .2678 L
.468 .2863 L
.472 .30227 L
.476 .31555 L
.48 .32624 L
.484 .33459 L
.488 .34099 L
.492 .34589 L
.496 .34978 L
.5 .35316 L
.504 .35655 L
.508 .36044 L
.512 .36534 L
.516 .37174 L
.52 .38009 L
.524 .39077 L
.528 .40406 L
.532 .42002 L
.536 .43852 L
.54 .45914 L
.544 .48119 L
.548 .50369 L
.552 .52548 L
.556 .54531 L
.56 .56191 L
.564 .5742 L
.568 .58133 L
.572 .58286 L
.576 .57872 L
.58 .56927 L
.584 .55524 L
.588 .53763 L
.592 .51758 L
.596 .4963 L
.6 .47488 L
Mistroke
.604 .4543 L
.608 .4353 L
.612 .41836 L
.616 .40376 L
.62 .39156 L
.624 .38166 L
.628 .37386 L
.632 .36787 L
.636 .36339 L
.64 .36012 L
.644 .3578 L
.648 .35619 L
.652 .35509 L
.656 .35437 L
.66 .3539 L
.664 .35361 L
.668 .35342 L
.672 .35331 L
.676 .35325 L
.68 .35321 L
.684 .35319 L
.688 .35318 L
.692 .35317 L
.696 .35317 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23176 L
.276 .23176 L
.28 .23176 L
.284 .23176 L
.288 .23176 L
.292 .23176 L
.296 .23176 L
.3 .23176 L
.304 .23177 L
.308 .23177 L
.312 .23177 L
.316 .23178 L
.32 .2318 L
.324 .23183 L
.328 .23189 L
.332 .23198 L
.336 .23214 L
.34 .23238 L
.344 .23278 L
.348 .23338 L
.352 .2343 L
.356 .23565 L
.36 .2376 L
.364 .24034 L
.368 .24411 L
.372 .24914 L
.376 .25569 L
.38 .264 L
.384 .27424 L
.388 .28649 L
.392 .30071 L
.396 .31667 L
.4 .33395 L
Mistroke
.404 .35192 L
.408 .36979 L
.412 .38662 L
.416 .40141 L
.42 .41319 L
.424 .42112 L
.428 .4246 L
.432 .42332 L
.436 .41733 L
.44 .40703 L
.444 .39309 L
.448 .37645 L
.452 .35816 L
.456 .33927 L
.46 .32078 L
.464 .30348 L
.468 .28797 L
.472 .2746 L
.476 .26353 L
.48 .25471 L
.484 .24798 L
.488 .2431 L
.492 .23983 L
.496 .23796 L
.5 .23736 L
.504 .23796 L
.508 .23983 L
.512 .2431 L
.516 .24798 L
.52 .25471 L
.524 .26353 L
.528 .2746 L
.532 .28797 L
.536 .30348 L
.54 .32078 L
.544 .33927 L
.548 .35816 L
.552 .37645 L
.556 .39309 L
.56 .40703 L
.564 .41733 L
.568 .42332 L
.572 .4246 L
.576 .42112 L
.58 .41319 L
.584 .40141 L
.588 .38662 L
.592 .36979 L
.596 .35192 L
.6 .33395 L
Mistroke
.604 .31667 L
.608 .30071 L
.612 .28649 L
.616 .27424 L
.62 .264 L
.624 .25569 L
.628 .24914 L
.632 .24411 L
.636 .24034 L
.64 .2376 L
.644 .23565 L
.648 .2343 L
.652 .23338 L
.656 .23278 L
.66 .23238 L
.664 .23214 L
.668 .23198 L
.672 .23189 L
.676 .23183 L
.68 .2318 L
.684 .23178 L
.688 .23177 L
.692 .23177 L
.696 .23177 L
.7 .23176 L
.704 .23176 L
.708 .23176 L
.712 .23176 L
.716 .23176 L
.72 .23176 L
.724 .23176 L
.728 .23176 L
.732 .23176 L
.736 .23176 L
.74 .23176 L
.744 .23176 L
.748 .23176 L
.752 .23176 L
.756 .23176 L
.76 .23176 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo0P00
0goo00D007ooOomoo`0000=oo`D000=oo`05001oogooOol00003Ool20002Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool0
0`00Oomoo`0:Ool001aoo`8002Aoo`8000Yoo`05001oogooOol0000:Ool2000bOol001aoo`03001o
ogoo02Aoo`03001oogoo00Qoo`05001oogooOol0000:Ool00`00Oomoo`0aOol001aoo`8002Eoo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo039oo`0077oo00<007ooOol0
9Goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol0<Woo000;Ool20004
Ool01000Oomoogoo1@000Woo0P009Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Goo
00<007ooOol0<goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo02Ioo`03001o
ogoo00Eoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo03=oo`002Woo00@007ooOol000Uo
o`03001oogoo009oo`8002Moo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001o
ogoo03=oo`002Woo00@007ooOol000Yoo`05001oogooOol0000XOol00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`0cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P009goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0<goo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo02Moo`03001oogoo009oo`03001o
ogoo00Ioo`03001oogoo00=oo`03001oogoo03Aoo`002goo0P002Goo0`000goo0P00:7oo00<007oo
Ool00Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0=7oo000LOol00`00Oomoo`0WOol0
0`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0dOol000]oo`8000Aoo`03
001oogoo00=oo`<0009oo`8002Qoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo009oo`03
001oogoo03Aoo`002Woo00@007ooOol000Yoo`05001oogooOol0000YOol00`00Oomoo`02Ool00`00
Oomoo`07Ool01@00Oomoogoo0000=goo000:Ool01000Oomoo`001goo1@000Woo0P00:Goo00D007oo
Oomoo`0000Uoo`05001oogooOol0000gOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<0
07ooOol0:7oo00@007ooOol000]oo`04001oogoo000gOol000Yoo`04001oogoo0008Ool00`00Ool0
0003Ool2000YOol01000Oomoo`002goo00@007ooOol003Moo`002Woo00@007ooOol000Uoo`8000=o
o`03001oogoo02Uoo`8000eoo`8003Qoo`002goo0P002goo00@007ooOomoo`8002Yoo`8000eoo`80
03Qoo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo
00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:
Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Mo
o`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomo
o`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol000]oo`8000Aoo`03001oogoo009oo`<007Qoo`002Woo00@007ooOol000Moo`05001oogoo
Ool0001gOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool0
1000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000]o
o`8000Uoo`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`80
00Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo10000goo0P00Lgoo000:Ool01000Oomoo`001goo00<007oo
Ool017oo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007ooOol00goo0P00Lgoo000;Ool2
000:Ool20003Ool00`00Oomoo`0YOol20017Ool001aoo`8002Yoo`8004Moo`0077oo00<007ooOol0
:Goo00<007oo0000AWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000YOol01000Oomoo`00
AWoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0002Yoo`04001oogoo0016Ool000=oo`D0009o
o`04001oogoo0007Ool50002Ool00`00Oomoo`0XOol01000Oomoo`00AWoo000:Ool01000Oomoo`00
1goo00@007ooOol000=oo`8002Uoo`05001oogooOol00015Ool000Yoo`04001oogoo0008Ool00`00
Ool00003Ool00`00Oomoo`0WOol00`00Oomoo`02Ool00`00Oomoo`13Ool000Yoo`04001oogoo0009
Ool20003Ool2000XOol00`00Oomoo`02Ool00`00Oomoo`13Ool000]oo`8000]oo`05001oogooOol0
000YOol00`00Oomoo`02Ool00`00Oomoo`13Ool001aoo`8002Qoo`03001oogoo009oo`03001oogoo
04=oo`0077oo00<007ooOol09goo00<007ooOol00Woo00<007ooOol0@goo000;Ool20004Ool01000
Oomoogoo1@000Woo0P00:7oo00<007ooOol00Woo00<007ooOol0@goo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`03001oogoo02Ioo`03001oogoo00Aoo`03001oogoo049oo`000goo1@000Woo
00@007ooOol000Uoo`03001oogoo009oo`03001oogoo02Ioo`03001oogoo00Aoo`03001oogoo049o
o`002Woo00@007ooOol000Yoo`04001oogooOol2000>Ool30004Ool20009Ool30004Ool20004Ool2
0005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo00D007ooOomoo`00009o
o`04001oogoo0009Ool00`00Oomoo`02Ool200001Woo001oogoo001oo`8000Eoo`05001oogooOol0
0003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Uoo`<000=oo`03001oogoo011oo`04001o
ogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`80
00eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool0
1000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<
Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P000goo0P000Woo00@007ooOol0009oo`03001oogoo
009oo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001o
ogoo00aoo`D000=oo`8000Yoo`06001oogooOol007oo0P0017oo0P0000=oo`00Ool00goo00@007oo
Oomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00
97oo0P002Woo00<007ooOol0@7oo000LOol00`00Oomoo`0ROol2000<Ool00`00Oomoo`0oOol001ao
ofT000aoo`0077oo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol027oo00<007ooOol01Woo
00D007ooOomoo`00011oo`03001oogoo019oo`03001oogoo00Yoo`0077oo0P00=7oo00<007ooOol0
27oo00<007ooOol0<Goo000LOol00`00Oomoo`0cOol00`00Oomoo`08Ool00`00Oomoo`0aOol001ao
o`8003Aoo`03001oogoo00Moo`03001oogoo039oo`0077oo00<007ooOol0=7oo00<007ooOol01Woo
00<007ooOol0<Woo000LOol00`00Oomoo`0dOol00`00Oomoo`06Ool00`00Oomoo`0bOol000]oo`80
00Aoo`04001oogooOol50002Ool2000eOol00`00Oomoo`05Ool00`00Oomoo`0cOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00<007ooOol0=7oo00<007ooOol01Goo00<007ooOol0<goo000:
Ool01000Oomoo`002Goo00<007ooOol00Woo0P00=Woo00<007ooOol017oo00<007ooOol0<goo000:
Ool01000Oomoo`002Woo00D007ooOomoo`0003Moo`03001oogoo00Aoo`03001oogoo03=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000fOol00`00Oomoo`04Ool00`00Oomoo`0cOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0=Goo00<007ooOol00goo00<0
07ooOol0=7oo000;Ool20009Ool30003Ool00`00Oomoo`0eOol00`00Oomoo`03Ool00`00Oomoo`0d
Ool001aoo`8003Ioo`03001oogoo00=oo`03001oogoo03Aoo`0077oo00<007ooOol0=Woo00<007oo
Ool00Woo00<007ooOol0=7oo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000gOol00`00Oomo
o`02Ool00`00Oomoo`0dOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000>7oo00D007ooOomo
o`0003Moo`002Woo00@007ooOol000Moo`D0009oo`8003Moo`05001oogooOol0000gOol000Yoo`04
001oogoo0007Ool01000Oomoo`000goo00<007ooOol0=Woo00D007ooOomoo`0003Moo`002Woo00@0
07ooOol000Qoo`03001oo`0000=oo`8003Qoo`04001oogoo000gOol000Yoo`04001oogoo0009Ool2
0003Ool00`00Oomoo`0gOol01000Oomoo`00=goo000;Ool2000;Ool01@00Oomoogoo0000>Goo00<0
07oo0000>7oo000LOol2000iOol2000hOol001aoo`03001oogoo03Qoo`03001oogoo03Moo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
2goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomo
o`0007Aoo`000goo1@000Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Mo
o`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001c
Ool000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2
001cOol001aoo`03001oogoo079oo`002goo0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004
Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006
Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo
00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomo
o`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04
001oogoo000:Ool01@00Oomoogoo00004Woo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000A
Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`@000=oo`04001oogoo
0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool0
1000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007oo
Oomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04
Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomo
o`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:
Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo
0P001Woo0`000Woo1@000goo0P001Woo000LOol2001cOol001aoo`03001oogoo079oo`0077ooJ@00
37oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01P00Oomoogoo001oo`@000=oo`05001oogooOol00003Ool50003Ool01@00Oomoogoo
00000goo0`0000=oo`00Ool00goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol2000TOol2000:Ool200000goo0000
000:Ool2000bOol001aoo`03001oogoo02Aoo`03001oogoo00Qoo`05001oogooOol0000:Ool00`00
Oomoo`0aOol001aoo`8002Eoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001o
ogoo039oo`0077oo00<007ooOol09Goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Woo
00<007ooOol0<Woo000;Ool20004Ool01000Oomoogoo1@000Woo0P009Woo00<007ooOol01Woo00<0
07ooOol00goo00<007ooOol01Goo00<007ooOol0<goo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`03001oogoo02Eoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo
03=oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8002Moo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo03=oo`002Woo00@007ooOol000Yoo`05001oogooOol0000X
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`0cOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P009goo00<007ooOol017oo00<007ooOol01Goo00<007oo
Ool017oo00<007ooOol0<goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo
02Moo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo03Aoo`002goo0P00
2Goo0`000goo0P00:7oo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0
=7oo000LOol00`00Oomoo`0WOol00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00
Oomoo`0dOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8002Qoo`03001oogoo009oo`03001o
ogoo00Moo`03001oogoo009oo`03001oogoo03Aoo`002Woo00@007ooOol000Yoo`05001oogooOol0
000YOol00`00Oomoo`02Ool00`00Oomoo`07Ool01@00Oomoogoo0000=goo000:Ool01000Oomoo`00
1goo1@000Woo0P00:Goo00D007ooOomoo`0000Uoo`05001oogooOol0000gOol000Yoo`04001oogoo
0007Ool01000Oomoo`000goo00<007ooOol0:7oo00@007ooOol000]oo`04001oogoo000gOol000Yo
o`04001oogoo0008Ool00`00Ool00003Ool2000YOol01000Oomoo`002goo00@007ooOol003Moo`00
2Woo00@007ooOol000Uoo`8000=oo`03001oogoo02Uoo`03001oo`0000]oo`03001oo`0003Qoo`00
2goo0P002goo00@007ooOomoo`8002Yoo`8000eoo`8003Qoo`0077oo00<007ooOol0LWoo000;Ool2
0004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo
00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Ao
o`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo
0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`80
07=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo
00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`00
5goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo
0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(240\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23176 L
.276 .23176 L
.28 .23176 L
.284 .23176 L
.288 .23176 L
.292 .23177 L
.296 .23177 L
.3 .23178 L
.304 .23179 L
.308 .23181 L
.312 .23184 L
.316 .2319 L
.32 .232 L
.324 .23216 L
.328 .23241 L
.332 .23282 L
.336 .23344 L
.34 .23437 L
.344 .23574 L
.348 .2377 L
.352 .24046 L
.356 .24422 L
.36 .24925 L
.364 .25578 L
.368 .26405 L
.372 .27423 L
.376 .2864 L
.38 .30053 L
.384 .31638 L
.388 .33355 L
.392 .35145 L
.396 .36926 L
.4 .38608 L
Mistroke
.404 .40091 L
.408 .41278 L
.412 .42085 L
.416 .4245 L
.42 .42341 L
.424 .4176 L
.428 .40744 L
.432 .39361 L
.436 .37702 L
.44 .35871 L
.444 .33977 L
.448 .32117 L
.452 .30375 L
.456 .28811 L
.46 .27461 L
.464 .26342 L
.468 .25446 L
.472 .24755 L
.476 .24242 L
.48 .23874 L
.484 .23621 L
.488 .23454 L
.492 .23352 L
.496 .23297 L
.5 .2328 L
.504 .23297 L
.508 .23352 L
.512 .23454 L
.516 .23621 L
.52 .23874 L
.524 .24242 L
.528 .24755 L
.532 .25446 L
.536 .26342 L
.54 .27461 L
.544 .28811 L
.548 .30375 L
.552 .32117 L
.556 .33977 L
.56 .35871 L
.564 .37702 L
.568 .39361 L
.572 .40744 L
.576 .4176 L
.58 .42341 L
.584 .4245 L
.588 .42085 L
.592 .41278 L
.596 .40091 L
.6 .38608 L
Mistroke
.604 .36926 L
.608 .35145 L
.612 .33355 L
.616 .31638 L
.62 .30053 L
.624 .2864 L
.628 .27423 L
.632 .26405 L
.636 .25578 L
.64 .24925 L
.644 .24422 L
.648 .24046 L
.652 .2377 L
.656 .23574 L
.66 .23437 L
.664 .23344 L
.668 .23282 L
.672 .23241 L
.676 .23216 L
.68 .232 L
.684 .2319 L
.688 .23184 L
.692 .23181 L
.696 .23179 L
.7 .23178 L
.704 .23177 L
.708 .23177 L
.712 .23176 L
.716 .23176 L
.72 .23176 L
.724 .23176 L
.728 .23176 L
.732 .23176 L
.736 .23176 L
.74 .23176 L
.744 .23176 L
.748 .23176 L
.752 .23176 L
.756 .23176 L
.76 .23176 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35315 L
.3 .35315 L
.304 .35313 L
.308 .35311 L
.312 .35307 L
.316 .353 L
.32 .35289 L
.324 .35269 L
.328 .35239 L
.332 .35191 L
.336 .35117 L
.34 .35006 L
.344 .34843 L
.348 .34609 L
.352 .34281 L
.356 .33832 L
.36 .33233 L
.364 .32455 L
.368 .3147 L
.372 .30258 L
.376 .28807 L
.38 .27125 L
.384 .25237 L
.388 .23191 L
.392 .21059 L
.396 .18937 L
.4 .16934 L
Mistroke
.404 .15167 L
.408 .13754 L
.412 .12793 L
.416 .12358 L
.42 .12488 L
.424 .13181 L
.428 .14391 L
.432 .1604 L
.436 .18017 L
.44 .20198 L
.444 .22455 L
.448 .24671 L
.452 .26746 L
.456 .2861 L
.46 .30217 L
.464 .31551 L
.468 .32619 L
.472 .33442 L
.476 .34054 L
.48 .34494 L
.484 .34799 L
.488 .35006 L
.492 .35145 L
.496 .3524 L
.5 .35316 L
.504 .35392 L
.508 .35488 L
.512 .35626 L
.516 .35833 L
.52 .36139 L
.524 .36579 L
.528 .37191 L
.532 .38014 L
.536 .39081 L
.54 .40415 L
.544 .42023 L
.548 .43886 L
.552 .45962 L
.556 .48177 L
.56 .50435 L
.564 .52616 L
.568 .54593 L
.572 .56241 L
.576 .57452 L
.58 .58144 L
.584 .58275 L
.588 .5784 L
.592 .56879 L
.596 .55465 L
.6 .53699 L
Mistroke
.604 .51696 L
.608 .49573 L
.612 .47442 L
.616 .45396 L
.62 .43507 L
.624 .41825 L
.628 .40375 L
.632 .39162 L
.636 .38177 L
.64 .37399 L
.644 .36801 L
.648 .36352 L
.652 .36024 L
.656 .3579 L
.66 .35627 L
.664 .35516 L
.668 .35442 L
.672 .35394 L
.676 .35363 L
.68 .35344 L
.684 .35332 L
.688 .35325 L
.692 .35321 L
.696 .35319 L
.7 .35318 L
.704 .35317 L
.708 .35317 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23176 L
.276 .23176 L
.28 .23176 L
.284 .23176 L
.288 .23176 L
.292 .23177 L
.296 .23177 L
.3 .23178 L
.304 .23179 L
.308 .23181 L
.312 .23184 L
.316 .2319 L
.32 .232 L
.324 .23216 L
.328 .23241 L
.332 .23282 L
.336 .23344 L
.34 .23437 L
.344 .23574 L
.348 .2377 L
.352 .24046 L
.356 .24422 L
.36 .24925 L
.364 .25578 L
.368 .26405 L
.372 .27423 L
.376 .2864 L
.38 .30053 L
.384 .31638 L
.388 .33355 L
.392 .35145 L
.396 .36926 L
.4 .38608 L
Mistroke
.404 .40091 L
.408 .41278 L
.412 .42085 L
.416 .4245 L
.42 .42341 L
.424 .4176 L
.428 .40744 L
.432 .39361 L
.436 .37702 L
.44 .35871 L
.444 .33977 L
.448 .32117 L
.452 .30375 L
.456 .28811 L
.46 .27461 L
.464 .26342 L
.468 .25446 L
.472 .24755 L
.476 .24242 L
.48 .23874 L
.484 .23621 L
.488 .23454 L
.492 .23352 L
.496 .23297 L
.5 .2328 L
.504 .23297 L
.508 .23352 L
.512 .23454 L
.516 .23621 L
.52 .23874 L
.524 .24242 L
.528 .24755 L
.532 .25446 L
.536 .26342 L
.54 .27461 L
.544 .28811 L
.548 .30375 L
.552 .32117 L
.556 .33977 L
.56 .35871 L
.564 .37702 L
.568 .39361 L
.572 .40744 L
.576 .4176 L
.58 .42341 L
.584 .4245 L
.588 .42085 L
.592 .41278 L
.596 .40091 L
.6 .38608 L
Mistroke
.604 .36926 L
.608 .35145 L
.612 .33355 L
.616 .31638 L
.62 .30053 L
.624 .2864 L
.628 .27423 L
.632 .26405 L
.636 .25578 L
.64 .24925 L
.644 .24422 L
.648 .24046 L
.652 .2377 L
.656 .23574 L
.66 .23437 L
.664 .23344 L
.668 .23282 L
.672 .23241 L
.676 .23216 L
.68 .232 L
.684 .2319 L
.688 .23184 L
.692 .23181 L
.696 .23179 L
.7 .23178 L
.704 .23177 L
.708 .23177 L
.712 .23176 L
.716 .23176 L
.72 .23176 L
.724 .23176 L
.728 .23176 L
.732 .23176 L
.736 .23176 L
.74 .23176 L
.744 .23176 L
.748 .23176 L
.752 .23176 L
.756 .23176 L
.76 .23176 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01P00Oomoogoo001oo`<000Ao
o`05001oogooOol00002Ool300000goo00000003Ool01@00Oomoogoo00000goo0`0000=oo`00Ool0
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol0
0Woo00<007ooOol02Woo000LOol2000SOol00`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`08
Ool2000aOol001aoo`03001oogoo02=oo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo00Qo
o`03001oogoo031oo`0077oo0P0097oo00<007ooOol01goo00<007ooOol01Goo00<007ooOol01goo
00<007ooOol0<7oo000LOol00`00Oomoo`0TOol00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomo
o`06Ool00`00Oomoo`0aOol000]oo`8000Aoo`04001oogooOol50002Ool2000UOol00`00Oomoo`05
Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0aOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<0
07ooOol0<Woo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P009Goo00<007ooOol01Goo00<0
07ooOol01goo00<007ooOol017oo00<007ooOol0<Woo000:Ool01000Oomoo`002Woo00D007ooOomo
o`0002Moo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo039oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000VOol00`00Oomoo`04Ool00`00Oomoo`07Ool0
0`00Oomoo`04Ool00`00Oomoo`0bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol09Goo00<007ooOol00goo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol0<goo000;
Ool20009Ool30003Ool2000VOol00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00
Oomoo`0cOol001aoo`03001oogoo02Ioo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo009o
o`03001oogoo03=oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P009goo00<007ooOol00Woo
00<007ooOol02Goo00<007ooOol00Woo00<007ooOol0<goo000:Ool01000Oomoo`002Woo00D007oo
Oomoo`0002Qoo`05001oogooOol0000=Ool01@00Oomoogoo0000=Goo000:Ool01000Oomoo`001goo
1@000Woo0P00:7oo00@007ooOol000eoo`04001oogoo000fOol000Yoo`04001oogoo0007Ool01000
Oomoo`000goo00<007ooOol09goo00@007ooOol000eoo`04001oogoo000fOol000Yoo`04001oogoo
0008Ool00`00Ool00003Ool2000XOol00`00Ool0000>Ool01000Oomoo`00=Woo000:Ool01000Oomo
o`002Goo0P000goo00<007ooOol09goo00<007oo00003goo0P00=goo000;Ool2000;Ool01000Oomo
ogoo0P00:Goo0P003goo0P00=goo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009o
o`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo1000
0goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000
Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001ao
o`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Io
o`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2
001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001o
ogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00N7oo000:Ool01000
Oomoo`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`8007=oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool40003Ool2001cOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Oomo
o`03Ool2001cOol000]oo`8000Yoo`8000=oo`03001oogoo02Qoo`8004Qoo`0077oo0P00:Goo0P00
B7oo000LOol00`00Oomoo`0WOol00`00Ool00018Ool000]oo`8000Aoo`03001oogoo00=oo`<0009o
o`8002Qoo`03001oo`0004Qoo`002Woo00@007ooOol000Yoo`05001oogooOol0000YOol01000Oomo
o`00Agoo0003Ool50002Ool01000Oomoo`001goo1@000Woo00<007ooOol09goo00@007ooOol004Mo
o`002Woo00@007ooOol000Moo`04001oogoo0003Ool2000XOol01000Oomoo`00Agoo000:Ool01000
Oomoo`0027oo00<007oo00000goo00<007ooOol09Woo00D007ooOomoo`0004Moo`002Woo00@007oo
Ool000Uoo`8000=oo`8002Moo`03001oogoo009oo`03001oogoo04Aoo`002goo0P002goo00D007oo
Oomoo`0002Qoo`03001oogoo009oo`03001oogoo04Aoo`0077oo0P009goo00<007ooOol00Woo00<0
07ooOol0A7oo000LOol00`00Oomoo`0UOol00`00Oomoo`03Ool00`00Oomoo`14Ool000]oo`8000Ao
o`04001oogooOol50002Ool2000VOol00`00Oomoo`03Ool00`00Oomoo`14Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00<007ooOol09Goo00<007ooOol017oo00<007ooOol0@goo0003Ool5
0002Ool01000Oomoo`002Goo00<007ooOol00Woo00<007ooOol09Goo00<007ooOol017oo00<007oo
Ool0@goo000:Ool01000Oomoo`002Woo00@007ooOomoo`8000ioo`<000Aoo`8000Uoo`<0009oo`04
001oo`000004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool3
0004Ool20006Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo00D0
07ooOomoo`00009oo`04001oogoo0009Ool01000Oomoogoo0P000Woo00<007ooOol00P0000=oo`00
Ool017oo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo00@007ooOol0009o
o`03001oogoo00Moo`04001oogooOol20002Ool00`00Oomoo`0200000goo001oo`04Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool20009Ool30003
Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00@007ooOomoo`80009oo`03001o
ogoo00800003Ool007oo00Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002
Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool01000Oomoogoo0P000Woo
00D007ooOol007oo008000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`00
1Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P000Woo00<007oo0000
0Woo00D007ooOol007oo008000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`04001oogoo0002Ool20004Ool30005
Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo
000LOol2000SOol00`00Oomoo`09Ool00`00Oomoo`11Ool001aoo`03001oogoo025oo`8000]oo`80
049oo`0077ooJ@0037oo000LOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`09Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool2000>Ool00`00Oomoo`0BOol00`00Oomoo`0:Ool001aoo`8003Eo
o`03001oogoo00Qoo`03001oogoo031oo`0077oo00<007ooOol0=7oo00<007ooOol027oo00<007oo
Ool0<7oo000LOol2000fOol00`00Oomoo`07Ool00`00Oomoo`0`Ool001aoo`03001oogoo03Eoo`03
001oogoo00Ioo`03001oogoo035oo`0077oo00<007ooOol0=Goo00<007ooOol01Woo00<007ooOol0
<Goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00=Woo00<007ooOol01Woo00<007ooOol0<Goo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo03Eoo`03001oogoo00Eoo`03001o
ogoo039oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8003Moo`03001oogoo00Aoo`03001o
ogoo039oo`002Woo00@007ooOol000Yoo`05001oogooOol0000hOol00`00Oomoo`04Ool00`00Oomo
o`0bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00=goo00<007ooOol017oo00<0
07ooOol0<Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo03Ioo`03001o
ogoo00=oo`03001oogoo03=oo`002goo0P002Goo0`000goo00<007ooOol0=goo00<007ooOol00Woo
00<007ooOol0<goo000LOol2000hOol00`00Oomoo`02Ool00`00Oomoo`0cOol001aoo`03001oogoo
03Moo`03001oogoo009oo`03001oogoo03=oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00
>7oo00<007ooOol00Woo00<007ooOol0<goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0003Uo
o`03001oogoo009oo`03001oogoo03=oo`002Woo00@007ooOol000Moo`D0009oo`8003Uoo`05001o
ogooOol0000eOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0>7oo00@007oo
Ool003Ioo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8003Uoo`04001oogoo000fOol000Yo
o`04001oogoo0009Ool20003Ool00`00Oomoo`0hOol01000Oomoo`00=Woo000;Ool2000;Ool01@00
Oomoogoo0000>Woo00<007oo0000=goo000LOol2000jOol2000gOol001aoo`03001oogoo03Yoo`03
001oogoo03Eoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001ao
o`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomo
o`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol000Moo`D0009oo`8007=oo`00
2Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool0
0`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`80
00]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00@007ooOomoo`D0
009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0=Ool30004Ool2
0009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool5
0002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool2000=Ool0
1@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo00@007ooOol0009oo`03001o
ogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D0
07ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`00
0Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00ao
o`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04
001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000
Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool2
000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004
Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002
Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomo
o`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P00
1Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2001cOol001aoo`03001o
ogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01000Oomoogoo1@0017oo00D007ooOomoo`0000=oo`D000=o
o`05001oogooOol00003Ool50004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`8002=oo`03001oogoo00Uoo`03
001oogoo009oo`8000Yoo`80035oo`0077oo00<007ooOol08goo00<007ooOol027oo00<007ooOol0
0goo00<007ooOol027oo00<007ooOol0<7oo000LOol2000TOol00`00Oomoo`07Ool00`00Oomoo`05
Ool00`00Oomoo`07Ool00`00Oomoo`0`Ool001aoo`03001oogoo02Aoo`03001oogoo00Ioo`03001o
ogoo00Eoo`03001oogoo00Ioo`03001oogoo035oo`002goo0P0017oo00@007ooOomoo`D0009oo`80
02Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo035oo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`0aOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000UOol0
0`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`0bOol000Yoo`04001oogoo
000:Ool01@00Oomoogoo00009goo00<007ooOol017oo00<007ooOol01goo00<007ooOol017oo00<0
07ooOol0<Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8002Ioo`03001oogoo00Ao
o`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo039oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`0UOol00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`03Ool0
0`00Oomoo`0cOol000]oo`8000Uoo`<000=oo`8002Ioo`03001oogoo00=oo`03001oogoo00Uoo`03
001oogoo009oo`03001oogoo03=oo`0077oo00<007ooOol09Woo00<007ooOol00Woo00<007ooOol0
2Goo00<007ooOol00Woo00<007ooOol0<goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000W
Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`0cOol000Yoo`04001o
ogoo000:Ool01@00Oomoogoo0000:7oo00D007ooOomoo`0000eoo`05001oogooOol0000eOol000Yo
o`04001oogoo0007Ool50002Ool2000XOol01000Oomoo`003Goo00@007ooOol003Ioo`002Woo00@0
07ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0WOol01000Oomoo`003Goo00@007ooOol003Io
o`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8002Qoo`04001oogoo000=Ool01000Oomoo`00
=Woo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol09goo00<007oo00003Woo00<007oo0000
=goo000;Ool2000;Ool01000Oomoogoo0P00:Goo0P003goo0P00=goo000LOol00`00Oomoo`1bOol0
00]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo
000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007oo
Ool017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2
000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`00
0goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo
000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0
LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo
000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(280\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23176 L
.276 .23176 L
.28 .23177 L
.284 .23177 L
.288 .23178 L
.292 .23179 L
.296 .23181 L
.3 .23185 L
.304 .23191 L
.308 .23201 L
.312 .23218 L
.316 .23244 L
.32 .23285 L
.324 .23349 L
.328 .23443 L
.332 .23582 L
.336 .2378 L
.34 .24056 L
.344 .24434 L
.348 .24936 L
.352 .25587 L
.356 .2641 L
.36 .27422 L
.364 .28632 L
.368 .30034 L
.372 .3161 L
.376 .33317 L
.38 .35098 L
.384 .36874 L
.388 .38555 L
.392 .40041 L
.396 .41237 L
.4 .42058 L
Mistroke
.404 .4244 L
.408 .4235 L
.412 .41786 L
.416 .40785 L
.42 .39413 L
.424 .37758 L
.428 .35927 L
.432 .34027 L
.436 .32157 L
.44 .30403 L
.444 .28827 L
.448 .27466 L
.452 .26337 L
.456 .25435 L
.46 .24741 L
.464 .24226 L
.468 .23858 L
.472 .23605 L
.476 .23437 L
.48 .2333 L
.484 .23265 L
.488 .23227 L
.492 .23206 L
.496 .23195 L
.5 .23192 L
.504 .23195 L
.508 .23206 L
.512 .23227 L
.516 .23265 L
.52 .2333 L
.524 .23437 L
.528 .23605 L
.532 .23858 L
.536 .24226 L
.54 .24741 L
.544 .25435 L
.548 .26337 L
.552 .27466 L
.556 .28827 L
.56 .30403 L
.564 .32157 L
.568 .34027 L
.572 .35927 L
.576 .37758 L
.58 .39413 L
.584 .40785 L
.588 .41786 L
.592 .4235 L
.596 .4244 L
.6 .42058 L
Mistroke
.604 .41237 L
.608 .40041 L
.612 .38555 L
.616 .36874 L
.62 .35098 L
.624 .33317 L
.628 .3161 L
.632 .30034 L
.636 .28632 L
.64 .27422 L
.644 .2641 L
.648 .25587 L
.652 .24936 L
.656 .24434 L
.66 .24056 L
.664 .2378 L
.668 .23582 L
.672 .23443 L
.676 .23349 L
.68 .23285 L
.684 .23244 L
.688 .23218 L
.692 .23201 L
.696 .23191 L
.7 .23185 L
.704 .23181 L
.708 .23179 L
.712 .23178 L
.716 .23177 L
.72 .23177 L
.724 .23176 L
.728 .23176 L
.732 .23176 L
.736 .23176 L
.74 .23176 L
.744 .23176 L
.748 .23176 L
.752 .23176 L
.756 .23176 L
.76 .23176 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35315 L
.288 .35315 L
.292 .35313 L
.296 .35311 L
.3 .35306 L
.304 .35299 L
.308 .35287 L
.312 .35267 L
.316 .35236 L
.32 .35186 L
.324 .35111 L
.328 .34998 L
.332 .34833 L
.336 .34597 L
.34 .34268 L
.344 .33818 L
.348 .3322 L
.352 .32445 L
.356 .31464 L
.36 .30259 L
.364 .28818 L
.368 .27147 L
.372 .2527 L
.376 .23236 L
.38 .21115 L
.384 .18999 L
.388 .16998 L
.392 .15227 L
.396 .13803 L
.4 .12825 L
Mistroke
.404 .1237 L
.408 .12478 L
.412 .1315 L
.416 .14343 L
.42 .15978 L
.424 .17949 L
.428 .20131 L
.432 .22395 L
.436 .24623 L
.44 .26712 L
.444 .28591 L
.448 .30211 L
.452 .31556 L
.456 .32631 L
.46 .33458 L
.464 .34072 L
.468 .3451 L
.472 .34812 L
.476 .35011 L
.48 .35139 L
.484 .35217 L
.488 .35263 L
.492 .3529 L
.496 .35305 L
.5 .35316 L
.504 .35327 L
.508 .35343 L
.512 .35369 L
.516 .35415 L
.52 .35494 L
.524 .35621 L
.528 .35821 L
.532 .36123 L
.536 .36561 L
.54 .37174 L
.544 .38001 L
.548 .39076 L
.552 .40421 L
.556 .42042 L
.56 .4392 L
.564 .4601 L
.568 .48237 L
.572 .50501 L
.576 .52683 L
.58 .54654 L
.584 .5629 L
.588 .57483 L
.592 .58154 L
.596 .58262 L
.6 .57807 L
Mistroke
.604 .5683 L
.608 .55405 L
.612 .53635 L
.616 .51633 L
.62 .49517 L
.624 .47396 L
.628 .45362 L
.632 .43486 L
.636 .41815 L
.64 .40374 L
.644 .39168 L
.648 .38188 L
.652 .37412 L
.656 .36814 L
.66 .36365 L
.664 .36035 L
.668 .35799 L
.672 .35634 L
.676 .35522 L
.68 .35446 L
.684 .35397 L
.688 .35365 L
.692 .35346 L
.696 .35333 L
.7 .35326 L
.704 .35322 L
.708 .35319 L
.712 .35318 L
.716 .35317 L
.72 .35317 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23176 L
.276 .23176 L
.28 .23177 L
.284 .23177 L
.288 .23178 L
.292 .23179 L
.296 .23181 L
.3 .23185 L
.304 .23191 L
.308 .23201 L
.312 .23218 L
.316 .23244 L
.32 .23285 L
.324 .23349 L
.328 .23443 L
.332 .23582 L
.336 .2378 L
.34 .24056 L
.344 .24434 L
.348 .24936 L
.352 .25587 L
.356 .2641 L
.36 .27422 L
.364 .28632 L
.368 .30034 L
.372 .3161 L
.376 .33317 L
.38 .35098 L
.384 .36874 L
.388 .38555 L
.392 .40041 L
.396 .41237 L
.4 .42058 L
Mistroke
.404 .4244 L
.408 .4235 L
.412 .41786 L
.416 .40785 L
.42 .39413 L
.424 .37758 L
.428 .35927 L
.432 .34027 L
.436 .32157 L
.44 .30403 L
.444 .28827 L
.448 .27466 L
.452 .26337 L
.456 .25435 L
.46 .24741 L
.464 .24226 L
.468 .23858 L
.472 .23605 L
.476 .23437 L
.48 .2333 L
.484 .23265 L
.488 .23227 L
.492 .23206 L
.496 .23195 L
.5 .23192 L
.504 .23195 L
.508 .23206 L
.512 .23227 L
.516 .23265 L
.52 .2333 L
.524 .23437 L
.528 .23605 L
.532 .23858 L
.536 .24226 L
.54 .24741 L
.544 .25435 L
.548 .26337 L
.552 .27466 L
.556 .28827 L
.56 .30403 L
.564 .32157 L
.568 .34027 L
.572 .35927 L
.576 .37758 L
.58 .39413 L
.584 .40785 L
.588 .41786 L
.592 .4235 L
.596 .4244 L
.6 .42058 L
Mistroke
.604 .41237 L
.608 .40041 L
.612 .38555 L
.616 .36874 L
.62 .35098 L
.624 .33317 L
.628 .3161 L
.632 .30034 L
.636 .28632 L
.64 .27422 L
.644 .2641 L
.648 .25587 L
.652 .24936 L
.656 .24434 L
.66 .24056 L
.664 .2378 L
.668 .23582 L
.672 .23443 L
.676 .23349 L
.68 .23285 L
.684 .23244 L
.688 .23218 L
.692 .23201 L
.696 .23191 L
.7 .23185 L
.704 .23181 L
.708 .23179 L
.712 .23178 L
.716 .23177 L
.72 .23177 L
.724 .23176 L
.728 .23176 L
.732 .23176 L
.736 .23176 L
.74 .23176 L
.744 .23176 L
.748 .23176 L
.752 .23176 L
.756 .23176 L
.76 .23176 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoogoo0`0000=oo`00
Ool00goo00H007ooOomoo`00Ool30003Ool300000goo001oo`02Ool01P00Oomoogoo001oo`<000Ao
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009o
o`03001oogoo00Yoo`0077oo0P008Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo
00<007ooOol0;Woo000LOol00`00Oomoo`0ROol00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomo
o`08Ool00`00Oomoo`0_Ool001aoo`8002=oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo02moo`0077oo00<007ooOol08Woo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol01Woo00<007ooOol0<7oo000;Ool20004Ool01000Oomoogoo1@000Woo0P0097oo00<007oo
Ool01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol0<7oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`03001oogoo02=oo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eo
o`03001oogoo031oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8002Aoo`03001oogoo00Eo
o`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo031oo`002Woo00@007ooOol000Yoo`05001o
ogooOol0000VOol00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`0aOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P009Goo00<007ooOol00goo00<007ooOol0
2goo00<007ooOol00goo00<007ooOol0<Goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo02Aoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo035o
o`002goo0P002Goo0`000goo0P009Goo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo
00<007ooOol0<Goo000LOol00`00Oomoo`0TOol00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomo
o`02Ool00`00Oomoo`0bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8002Ioo`05001oogoo
Ool0000>Ool00`00Oomoo`02Ool00`00Oomoo`0bOol000Yoo`04001oogoo000:Ool01@00Oomoogoo
00009goo00D007ooOomoo`0000moo`05001oogooOol0000dOol000Yoo`04001oogoo0007Ool50002
Ool2000VOol01@00Oomoogoo00003goo00@007ooOol003Eoo`002Woo00@007ooOol000Moo`04001o
ogoo0003Ool00`00Oomoo`0UOol01@00Oomoogoo00003goo00@007ooOol003Eoo`002Woo00@007oo
Ool000Qoo`03001oo`0000=oo`8002Moo`03001oo`00015oo`03001oo`0003Eoo`002Woo00@007oo
Ool000Uoo`8000=oo`03001oogoo02Ioo`03001oo`00015oo`03001oo`0003Eoo`002goo0P002goo
00@007ooOomoo`8002Qoo`03001oogoo011oo`8003Ioo`0077oo00<007ooOol0LWoo000;Ool20004
Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@0
07ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80
07=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P00
0goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<0
07ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo
00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00
NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<0
07Qoo`002Woo00@007ooOol000Moo`05001oogooOol0001gOol000=oo`D0009oo`04001oogoo0007
Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2001cOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo10000goo
0P00Lgoo000:Ool01000Oomoo`001goo00<007ooOol017oo00<007ooOol0LWoo000:Ool01000Oomo
o`0027oo00<007ooOol00goo0P00Lgoo000;Ool2000:Ool20003Ool00`00Oomoo`0WOol00`00Oomo
o`18Ool001aoo`8002Qoo`8004Uoo`0077oo00<007ooOol09Woo00<007oo0000BGoo000;Ool20004
Ool00`00Oomoo`03Ool30002Ool2000WOol00`00Ool00019Ool000Yoo`04001oogoo000:Ool01@00
Oomoogoo0000:7oo00@007ooOol004Qoo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001o
ogoo02Eoo`05001oogooOol00018Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P009Woo
00D007ooOomoo`0004Qoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo02Eoo`05
001oogooOol00018Ool000Yoo`04001oogoo0009Ool20003Ool2000VOol01@00Oomoogoo0000B7oo
000;Ool2000;Ool01@00Oomoogoo00009Woo00<007ooOol00Woo00<007ooOol0AWoo000LOol2000U
Ool00`00Oomoo`03Ool00`00Oomoo`15Ool001aoo`03001oogoo02Aoo`03001oogoo00=oo`03001o
ogoo04Eoo`002goo0P0017oo00@007ooOomoo`D0009oo`8002Eoo`03001oogoo00=oo`03001oogoo
04Eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0TOol00`00Oomoo`03Ool0
0`00Oomoo`15Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0TOol0
0`00Oomoo`03Ool00`00Oomoo`15Ool000Yoo`04001oogoo000:Ool01000Oomoogoo0P003Woo0`00
17oo0P002Goo0`0000Aoo`00Oomoo`8000=oo`<000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`80
00Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`0<Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`06001oogoo001oo`000Woo
00@007ooOol0009oo`03001oogoo00=oo`05001oogooOol00003Ool01000Oomoo`000Woo00<007oo
Ool00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`80015oo`04001oogoo0002Ool00`00Oomoo`07Ool01P00Oomoo`00Ool0009oo`04001oogoo0002
Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool00goo000;Ool20009Ool30003Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo
00H007ooOol007oo0002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007oo
Ool000Uoo`03001oo`00009oo`04001oogoo0002Ool200000goo001oo`04Ool01000Oomoogoo1000
0goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06
001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo
00@007ooOol000Qoo`800005Ool007ooOol00002Ool00`00Oomoo`0200000goo001oo`03Ool20003
Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000
Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool5
0003Ool2000:Ool00`00Ool00003Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`00
17oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000ROol00`00Oomoo`09Ool00`00
Oomoo`12Ool001aoo`03001oogoo021oo`03001oogoo00Yoo`8004=oo`0077ooJ@0037oo000LOol0
0`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0:Ool20005Ool00`00Oomoo`03Ool2000=Ool0
0`00Oomoo`0BOol00`00Oomoo`0:Ool001aoo`8003Ioo`03001oogoo00Uoo`03001oogoo02ioo`00
77oo00<007ooOol0=Goo00<007ooOol027oo00<007ooOol0;goo000LOol2000gOol00`00Oomoo`07
Ool00`00Oomoo`0_Ool001aoo`03001oogoo03Ioo`03001oogoo00Ioo`03001oogoo031oo`0077oo
00<007ooOol0=Woo00<007ooOol01Woo00<007ooOol0<7oo000;Ool20004Ool01000Oomoogoo1@00
0Woo0P00>7oo00<007ooOol01Goo00<007ooOol0<7oo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`03001oogoo03Moo`03001oogoo00Eoo`03001oogoo031oo`002Woo00@007ooOol000Uoo`03
001oogoo009oo`8003Qoo`03001oogoo00Eoo`03001oogoo031oo`002Woo00@007ooOol000Yoo`05
001oogooOol0000iOol00`00Oomoo`04Ool00`00Oomoo`0aOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo0P00>Goo00<007ooOol00goo00<007ooOol0<Goo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo03Qoo`03001oogoo00=oo`03001oogoo035oo`002goo0P00
2Goo0`000goo00<007ooOol0>7oo00<007ooOol00goo00<007ooOol0<Goo000LOol2000iOol00`00
Oomoo`02Ool00`00Oomoo`0bOol001aoo`03001oogoo03Qoo`03001oogoo009oo`03001oogoo039o
o`002goo0P0017oo00<007ooOol00goo0`000Woo0P00>Goo00<007ooOol00Woo00<007ooOol0<Woo
000:Ool01000Oomoo`002Woo00D007ooOomoo`0003Yoo`03001oogoo009oo`03001oogoo039oo`00
2Woo00@007ooOol000Moo`D0009oo`8003Yoo`05001oogooOol0000dOol000Yoo`04001oogoo0007
Ool01000Oomoo`000goo00<007ooOol0>Goo00@007ooOol003Eoo`002Woo00@007ooOol000Qoo`03
001oo`0000=oo`8003Yoo`04001oogoo000eOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomo
o`0iOol01000Oomoo`00=Goo000;Ool2000;Ool01@00Oomoogoo0000?7oo00<007oo0000=Goo000L
Ool2000kOol2000fOol001aoo`03001oogoo03Yoo`8003Ioo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol0
0goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo
00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009
Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo
079oo`002goo0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004
Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001o
ogoo0009Ool00`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomo
ogoo00004Woo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<0
07ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007oo
Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000
Oomoo`001Goo000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P00
17oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo
00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006
Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004
Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo
0P001Woo000LOol2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo
00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoogoo
0`0000=oo`00Ool00goo00D007ooOomoo`00009oo`<00004Ool000000002Ool01@00Oomoogoo0000
0goo00<007oo00000`000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol2000ROol00`00Oomoo`09Ool00`00Oomo
o`05Ool00`00Oomoo`09Ool00`00Oomoo`0^Ool001aoo`03001oogoo029oo`03001oogoo00Moo`03
001oogoo00Ioo`03001oogoo00Qoo`03001oogoo02moo`0077oo0P008goo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol0;goo000LOol00`00Oomoo`0ROol00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0`Ool000]oo`8000Aoo`04001oogooOol5
0002Ool2000TOol00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0`Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol08goo00<007ooOol01Goo00<007oo
Ool02Goo00<007ooOol01Goo00<007ooOol0<7oo000:Ool01000Oomoo`002Goo00<007ooOol00Woo
0P0097oo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol0<7oo000:Ool0
1000Oomoo`002Woo00D007ooOomoo`0002Ioo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo
00Aoo`03001oogoo035oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000UOol00`00
Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0aOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol097oo00<007ooOol00goo00<007ooOol02goo00<007oo
Ool00goo00<007ooOol0<Goo000;Ool20009Ool30003Ool2000UOol00`00Oomoo`03Ool00`00Oomo
o`0;Ool00`00Oomoo`03Ool00`00Oomoo`0aOol001aoo`03001oogoo02Aoo`03001oogoo00=oo`03
001oogoo00]oo`03001oogoo009oo`03001oogoo039oo`002goo0P0017oo00<007ooOol00goo0`00
0Woo0P009Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol0<Woo000:
Ool01000Oomoo`002Woo00D007ooOomoo`0002Moo`05001oogooOol0000>Ool00`00Oomoo`02Ool0
0`00Oomoo`0bOol000Yoo`04001oogoo0007Ool50002Ool2000VOol01@00Oomoogoo00003goo00@0
07ooOol003Eoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0UOol01@00Oomo
ogoo00003goo00@007ooOol003Eoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8002Moo`04
001oogoo000?Ool01000Oomoo`00=Goo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol09Woo
00<007oo00004Goo00<007oo0000=Goo000;Ool2000;Ool01000Oomoogoo0P00:7oo0P004Goo0P00
=Woo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol0
0goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yo
o`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo
00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo
07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(320\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23177 L
.268 .23177 L
.272 .23177 L
.276 .23178 L
.28 .23179 L
.284 .23181 L
.288 .23185 L
.292 .23192 L
.296 .23202 L
.3 .23219 L
.304 .23247 L
.308 .23289 L
.312 .23354 L
.316 .2345 L
.32 .2359 L
.324 .2379 L
.328 .24067 L
.332 .24445 L
.336 .24946 L
.34 .25595 L
.344 .26415 L
.348 .27421 L
.352 .28623 L
.356 .30017 L
.36 .31582 L
.364 .3328 L
.368 .35052 L
.372 .36822 L
.376 .38501 L
.38 .39991 L
.384 .41196 L
.388 .42029 L
.392 .42428 L
.396 .42356 L
.4 .41811 L
Mistroke
.404 .40826 L
.408 .39464 L
.412 .37815 L
.416 .35983 L
.42 .34077 L
.424 .32198 L
.428 .30432 L
.432 .28844 L
.436 .27472 L
.44 .26333 L
.444 .25425 L
.448 .24727 L
.452 .2421 L
.456 .23843 L
.46 .23592 L
.464 .23426 L
.468 .23322 L
.472 .23259 L
.476 .23222 L
.48 .23202 L
.484 .23191 L
.488 .23186 L
.492 .23183 L
.496 .23182 L
.5 .23182 L
.504 .23182 L
.508 .23183 L
.512 .23186 L
.516 .23191 L
.52 .23202 L
.524 .23222 L
.528 .23259 L
.532 .23322 L
.536 .23426 L
.54 .23592 L
.544 .23843 L
.548 .2421 L
.552 .24727 L
.556 .25425 L
.56 .26333 L
.564 .27472 L
.568 .28844 L
.572 .30432 L
.576 .32198 L
.58 .34077 L
.584 .35983 L
.588 .37815 L
.592 .39464 L
.596 .40826 L
.6 .41811 L
Mistroke
.604 .42356 L
.608 .42428 L
.612 .42029 L
.616 .41196 L
.62 .39991 L
.624 .38501 L
.628 .36822 L
.632 .35052 L
.636 .3328 L
.64 .31582 L
.644 .30017 L
.648 .28623 L
.652 .27421 L
.656 .26415 L
.66 .25595 L
.664 .24946 L
.668 .24445 L
.672 .24067 L
.676 .2379 L
.68 .2359 L
.684 .2345 L
.688 .23354 L
.692 .23289 L
.696 .23247 L
.7 .23219 L
.704 .23202 L
.708 .23192 L
.712 .23185 L
.716 .23181 L
.72 .23179 L
.724 .23178 L
.728 .23177 L
.732 .23177 L
.736 .23177 L
.74 .23176 L
.744 .23176 L
.748 .23176 L
.752 .23176 L
.756 .23176 L
.76 .23176 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35315 L
.276 .35314 L
.28 .35313 L
.284 .3531 L
.288 .35306 L
.292 .35298 L
.296 .35285 L
.3 .35265 L
.304 .35232 L
.308 .35182 L
.312 .35105 L
.316 .3499 L
.32 .34823 L
.324 .34586 L
.328 .34255 L
.332 .33805 L
.336 .33208 L
.34 .32434 L
.344 .31459 L
.348 .3026 L
.352 .28828 L
.356 .27167 L
.36 .25303 L
.364 .23281 L
.368 .2117 L
.372 .19061 L
.376 .17061 L
.38 .15287 L
.384 .13852 L
.388 .12859 L
.392 .12384 L
.396 .1247 L
.4 .1312 L
Mistroke
.404 .14295 L
.408 .15917 L
.412 .17882 L
.416 .20064 L
.42 .22335 L
.424 .24574 L
.428 .26678 L
.432 .2857 L
.436 .30205 L
.44 .31561 L
.444 .32644 L
.448 .33475 L
.452 .3409 L
.456 .34528 L
.46 .34827 L
.464 .35024 L
.468 .35149 L
.472 .35224 L
.476 .35268 L
.48 .35292 L
.484 .35305 L
.488 .35311 L
.492 .35314 L
.496 .35315 L
.5 .35316 L
.504 .35317 L
.508 .35318 L
.512 .35321 L
.516 .35328 L
.52 .35341 L
.524 .35365 L
.528 .35408 L
.532 .35484 L
.536 .35608 L
.54 .35805 L
.544 .36105 L
.548 .36542 L
.552 .37157 L
.556 .37989 L
.56 .39071 L
.564 .40428 L
.568 .42062 L
.572 .43955 L
.576 .46059 L
.58 .48298 L
.584 .50568 L
.588 .52751 L
.592 .54715 L
.596 .56338 L
.6 .57513 L
Mistroke
.604 .58162 L
.608 .58248 L
.612 .57774 L
.616 .5678 L
.62 .55346 L
.624 .53571 L
.628 .51572 L
.632 .49462 L
.636 .47351 L
.64 .45329 L
.644 .43465 L
.648 .41805 L
.652 .40373 L
.656 .39174 L
.66 .38198 L
.664 .37425 L
.668 .36827 L
.672 .36378 L
.676 .36047 L
.68 .35809 L
.684 .35642 L
.688 .35528 L
.692 .35451 L
.696 .354 L
.7 .35368 L
.704 .35347 L
.708 .35334 L
.712 .35327 L
.716 .35322 L
.72 .3532 L
.724 .35318 L
.728 .35317 L
.732 .35317 L
.736 .35317 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23177 L
.268 .23177 L
.272 .23177 L
.276 .23178 L
.28 .23179 L
.284 .23181 L
.288 .23185 L
.292 .23192 L
.296 .23202 L
.3 .23219 L
.304 .23247 L
.308 .23289 L
.312 .23354 L
.316 .2345 L
.32 .2359 L
.324 .2379 L
.328 .24067 L
.332 .24445 L
.336 .24946 L
.34 .25595 L
.344 .26415 L
.348 .27421 L
.352 .28623 L
.356 .30017 L
.36 .31582 L
.364 .3328 L
.368 .35052 L
.372 .36822 L
.376 .38501 L
.38 .39991 L
.384 .41196 L
.388 .42029 L
.392 .42428 L
.396 .42356 L
.4 .41811 L
Mistroke
.404 .40826 L
.408 .39464 L
.412 .37815 L
.416 .35983 L
.42 .34077 L
.424 .32198 L
.428 .30432 L
.432 .28844 L
.436 .27472 L
.44 .26333 L
.444 .25425 L
.448 .24727 L
.452 .2421 L
.456 .23843 L
.46 .23592 L
.464 .23426 L
.468 .23322 L
.472 .23259 L
.476 .23222 L
.48 .23202 L
.484 .23191 L
.488 .23186 L
.492 .23183 L
.496 .23182 L
.5 .23182 L
.504 .23182 L
.508 .23183 L
.512 .23186 L
.516 .23191 L
.52 .23202 L
.524 .23222 L
.528 .23259 L
.532 .23322 L
.536 .23426 L
.54 .23592 L
.544 .23843 L
.548 .2421 L
.552 .24727 L
.556 .25425 L
.56 .26333 L
.564 .27472 L
.568 .28844 L
.572 .30432 L
.576 .32198 L
.58 .34077 L
.584 .35983 L
.588 .37815 L
.592 .39464 L
.596 .40826 L
.6 .41811 L
Mistroke
.604 .42356 L
.608 .42428 L
.612 .42029 L
.616 .41196 L
.62 .39991 L
.624 .38501 L
.628 .36822 L
.632 .35052 L
.636 .3328 L
.64 .31582 L
.644 .30017 L
.648 .28623 L
.652 .27421 L
.656 .26415 L
.66 .25595 L
.664 .24946 L
.668 .24445 L
.672 .24067 L
.676 .2379 L
.68 .2359 L
.684 .2345 L
.688 .23354 L
.692 .23289 L
.696 .23247 L
.7 .23219 L
.704 .23202 L
.708 .23192 L
.712 .23185 L
.716 .23181 L
.72 .23179 L
.724 .23178 L
.728 .23177 L
.732 .23177 L
.736 .23177 L
.74 .23176 L
.744 .23176 L
.748 .23176 L
.752 .23176 L
.756 .23176 L
.76 .23176 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoogoo0P000Woo00<0
07ooOol00Woo00@007ooOomoo`<00003Ool007oo009oo`03001oo`00008000=oo`05001oogooOol0
0003Ool20003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
0`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`80025oo`03001oogoo00Uoo`03001oogoo00Moo`03
001oogoo00Uoo`03001oogoo02eoo`0077oo00<007ooOol087oo00<007ooOol027oo00<007ooOol0
2Goo00<007ooOol01goo00<007ooOol0;Woo000LOol2000ROol00`00Oomoo`07Ool00`00Oomoo`09
Ool00`00Oomoo`07Ool00`00Oomoo`0^Ool001aoo`03001oogoo025oo`03001oogoo00Ioo`03001o
ogoo00]oo`03001oogoo00Ioo`03001oogoo02ioo`002goo0P0017oo00@007ooOomoo`D0009oo`80
02=oo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo02moo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0ROol00`00Oomoo`05Ool00`00Oomoo`0;Ool0
0`00Oomoo`05Ool00`00Oomoo`0_Ool000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000SOol0
0`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0_Ool000Yoo`04001oogoo
000:Ool01@00Oomoogoo000097oo00<007ooOol017oo00<007ooOol037oo00<007ooOol017oo00<0
07ooOol0<7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8002=oo`03001oogoo00Ao
o`03001oogoo00eoo`03001oogoo00=oo`03001oogoo031oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`0SOol00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool0
0`00Oomoo`0`Ool000]oo`8000Uoo`<000=oo`8002Aoo`03001oogoo00=oo`03001oogoo00eoo`03
001oogoo00=oo`03001oogoo031oo`0077oo00<007ooOol08goo00<007ooOol00Woo00<007ooOol0
3goo00<007ooOol00Woo00<007ooOol0<7oo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000U
Ool01@00Oomoogoo00004Goo00D007ooOomoo`0003=oo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0000VOol01@00Oomoogoo00004Goo00D007ooOomoo`0003=oo`002Woo00@007ooOol000Moo`D0
009oo`8002Eoo`05001oogooOol0000AOol01@00Oomoogoo0000<goo000:Ool01000Oomoo`001goo
00@007ooOol000=oo`03001oogoo02Aoo`04001oogoo000BOol01@00Oomoogoo0000<goo000:Ool0
1000Oomoo`0027oo00<007oo00000goo0P009Goo00@007ooOol0019oo`04001oogoo000dOol000Yo
o`04001oogoo0009Ool20003Ool00`00Oomoo`0UOol00`00Ool0000COol00`00Ool0000dOol000]o
o`8000]oo`04001oogooOol2000VOol3000COol2000eOol001aoo`03001oogoo079oo`002goo0P00
17oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04
001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2
001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`80
00=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001c
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03
001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Mo
o`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`80
07Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3
001hOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P00Lgoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`@000=o
o`8007=oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`03001oogoo079oo`002Woo00@007oo
Ool000Qoo`03001oogoo00=oo`8007=oo`002goo0P002Woo0P000goo00<007ooOol09Woo00<007oo
Ool0BGoo000LOol2000VOol00`00Ool0001:Ool001aoo`03001oogoo02Eoo`03001oo`0004Yoo`00
2goo0P0017oo00<007ooOol00goo0`000Woo0P009Goo00@007ooOol004Yoo`002Woo00@007ooOol0
00Yoo`05001oogooOol0000VOol01000Oomoo`00BWoo0003Ool50002Ool01000Oomoo`001goo1@00
0Woo00<007ooOol097oo00@007ooOol004Yoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool2
000UOol01@00Oomoogoo0000BGoo000:Ool01000Oomoo`0027oo00<007oo00000goo00<007ooOol0
97oo00D007ooOomoo`0004Uoo`002Woo00@007ooOol000Uoo`8000=oo`8002Eoo`05001oogooOol0
0019Ool000]oo`8000]oo`05001oogooOol0000UOol00`00Oomoo`02Ool00`00Oomoo`17Ool001ao
o`8002Aoo`03001oogoo00=oo`03001oogoo04Ioo`0077oo00<007ooOol08goo00<007ooOol00goo
00<007ooOol0AWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P0097oo00<007ooOol00goo00<0
07ooOol0AWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo029oo`03001oogoo
00Aoo`03001oogoo04Ioo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo
029oo`03001oogoo00Aoo`03001oogoo04Ioo`002Woo00@007ooOol000Yoo`04001oogooOol2000>
Ool30004Ool20009Ool40003Ool2000017oo001oogoo0P001Goo0`000goo0`0017oo0P001Goo1@00
0goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007oo00000Woo
00<007ooOol00P0000Eoo`00Oomoo`0000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<0
07ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo
0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`80015oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Ool00002Ool01@00Oomoo`00Ool0
0P000Woo00<007ooOol00goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00=oo`002goo0P002Goo0`000goo00<007ooOol047oo00@007ooOol0009oo`03001oogoo
00Moo`03001oo`00009oo`05001oogoo001oo`020002Ool00`00Oomoo`03Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool0
1000Oomoo`002Goo0P000goo00D007ooOol007oo0080009oo`03001oogoo00=oo`04001oogooOol4
0003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04
Ool01000Oomoo`0027oo0`000goo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomo
o`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:
Ool00`00Oomoo`03Ool20003Ool30006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo
0P001Woo0`000Woo1@000goo0P001Woo000LOol2000QOol00`00Oomoo`09Ool00`00Oomoo`13Ool0
01aoo`03001oogoo01ioo`8000aoo`8004Aoo`0077ooJ@0037oo000LOol00`00Oomoo`0BOol00`00
Oomoo`0BOol00`00Oomoo`0;Ool20004Ool00`00Oomoo`04Ool2000<Ool00`00Oomoo`0BOol00`00
Oomoo`0:Ool001aoo`8003Moo`03001oogoo00Uoo`03001oogoo02eoo`0077oo00<007ooOol0=goo
00<007ooOol01goo00<007ooOol0;Woo000LOol2000hOol00`00Oomoo`07Ool00`00Oomoo`0^Ool0
01aoo`03001oogoo03Qoo`03001oogoo00Ioo`03001oogoo02ioo`0077oo00<007ooOol0>7oo00<0
07ooOol01Woo00<007ooOol0;Woo000;Ool20004Ool01000Oomoogoo1@000Woo0P00>Goo00<007oo
Ool01Goo00<007ooOol0;goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo03Qo
o`03001oogoo00Eoo`03001oogoo02moo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8003Uo
o`03001oogoo00Eoo`03001oogoo02moo`002Woo00@007ooOol000Yoo`05001oogooOol0000jOol0
0`00Oomoo`04Ool00`00Oomoo`0`Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00
>Woo00<007ooOol00goo00<007ooOol0<7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo03Uoo`03001oogoo00=oo`03001oogoo031oo`002goo0P002Goo0`000goo00<007oo
Ool0>Goo00<007ooOol00goo00<007ooOol0<7oo000LOol2000jOol00`00Oomoo`03Ool00`00Oomo
o`0`Ool001aoo`03001oogoo03Yoo`03001oogoo009oo`03001oogoo031oo`002goo0P0017oo00<0
07ooOol00goo0`000Woo0P00>goo00<007ooOol00Woo00<007ooOol0<7oo000:Ool01000Oomoo`00
2Woo00D007ooOomoo`0003aoo`05001oogooOol0000cOol000Yoo`04001oogoo0007Ool50002Ool2
000kOol01@00Oomoogoo0000<goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo
03Yoo`05001oogooOol0000cOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2000kOol01@00
Oomoogoo0000<goo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0>Woo00@007ooOol003Ao
o`002goo0P002goo00D007ooOomoo`0003eoo`03001oo`0003Aoo`0077oo0P00?7oo0P00=Goo000L
Ool00`00Oomoo`0lOol00`00Oomoo`0cOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol0
0`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`80
07=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000=oo`D0009oo`04001oogoo0007
Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:
Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<0
07ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`80
00Aoo`04001oogooOol50002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<0
07ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@00
0goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo00<0
07ooOol00Woo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol0
0goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`04
001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo00@007ooOol0009oo`03001oogoo00Moo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo
Ool017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`00
2goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo
0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol0
00Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@0
07ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001o
ogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00`000Woo00<007oo
Ool00Woo00@007ooOomoo`D000=oo`<00003Ool007oo009oo`05001oogooOol00003Ool30002Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool0
0`00Oomoo`0:Ool001aoo`80025oo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Uoo`03
001oogoo02eoo`0077oo00<007ooOol087oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol0
1goo00<007ooOol0;Woo000LOol2000ROol00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`07
Ool00`00Oomoo`0^Ool001aoo`03001oogoo025oo`03001oogoo00Ioo`03001oogoo00]oo`03001o
ogoo00Ioo`03001oogoo02ioo`002goo0P0017oo00@007ooOomoo`D0009oo`8002=oo`03001oogoo
00Eoo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo02moo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool00`00Oomoo`0ROol00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool0
0`00Oomoo`0_Ool000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000SOol00`00Oomoo`04Ool0
0`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0_Ool000Yoo`04001oogoo000:Ool01@00Oomo
ogoo000097oo00<007ooOol017oo00<007ooOol037oo00<007ooOol017oo00<007ooOol0<7oo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8002=oo`03001oogoo00Aoo`03001oogoo00eo
o`03001oogoo00=oo`03001oogoo031oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`0SOol00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`0`Ool0
00]oo`8000Uoo`<000=oo`8002Aoo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00=oo`03
001oogoo031oo`0077oo00<007ooOol08goo00<007ooOol00goo00<007ooOol03Goo00<007ooOol0
0goo00<007ooOol0<7oo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000TOol00`00Oomoo`02
Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0`Ool000Yoo`04001oogoo000:Ool01@00
Oomoogoo00009Woo00D007ooOomoo`00015oo`05001oogooOol0000cOol000Yoo`04001oogoo0007
Ool50002Ool2000UOol01@00Oomoogoo00004Goo00D007ooOomoo`0003=oo`002Woo00@007ooOol0
00Moo`04001oogoo0003Ool00`00Oomoo`0TOol01000Oomoo`004Woo00D007ooOomoo`0003=oo`00
2Woo00@007ooOol000Qoo`03001oo`0000=oo`8002Eoo`04001oogoo000BOol01000Oomoo`00=7oo
000:Ool01000Oomoo`002Goo0P000goo00<007ooOol09Goo00<007oo00004goo00<007oo0000=7oo
000;Ool2000;Ool01000Oomoogoo0P009Woo0`004goo0P00=Goo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:
Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol0
17oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:
Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo
0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000L
Ool00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo
000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000F
Ool2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(360\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23177 L
.256 .23177 L
.26 .23177 L
.264 .23178 L
.268 .23179 L
.272 .23182 L
.276 .23186 L
.28 .23193 L
.284 .23204 L
.288 .23221 L
.292 .2325 L
.296 .23293 L
.3 .23359 L
.304 .23457 L
.308 .23598 L
.312 .23799 L
.316 .24078 L
.32 .24456 L
.324 .24957 L
.328 .25604 L
.332 .2642 L
.336 .2742 L
.34 .28615 L
.344 .3 L
.348 .31555 L
.352 .33243 L
.356 .35006 L
.36 .36771 L
.364 .38448 L
.368 .39941 L
.372 .41154 L
.376 .42 L
.38 .42416 L
.384 .42362 L
.388 .41835 L
.392 .40865 L
.396 .39515 L
.4 .37872 L
Mistroke
.404 .3604 L
.408 .34129 L
.412 .32241 L
.416 .30463 L
.42 .28861 L
.424 .27478 L
.428 .2633 L
.432 .25414 L
.436 .24712 L
.44 .24194 L
.444 .23828 L
.448 .23578 L
.452 .23415 L
.456 .23313 L
.46 .23253 L
.464 .23218 L
.468 .23199 L
.472 .2319 L
.476 .23185 L
.48 .23183 L
.484 .23182 L
.488 .23182 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23182 L
.516 .23182 L
.52 .23183 L
.524 .23185 L
.528 .2319 L
.532 .23199 L
.536 .23218 L
.54 .23253 L
.544 .23313 L
.548 .23415 L
.552 .23578 L
.556 .23828 L
.56 .24194 L
.564 .24712 L
.568 .25414 L
.572 .2633 L
.576 .27478 L
.58 .28861 L
.584 .30463 L
.588 .32241 L
.592 .34129 L
.596 .3604 L
.6 .37872 L
Mistroke
.604 .39515 L
.608 .40865 L
.612 .41835 L
.616 .42362 L
.62 .42416 L
.624 .42 L
.628 .41154 L
.632 .39941 L
.636 .38448 L
.64 .36771 L
.644 .35006 L
.648 .33243 L
.652 .31555 L
.656 .3 L
.66 .28615 L
.664 .2742 L
.668 .2642 L
.672 .25604 L
.676 .24957 L
.68 .24456 L
.684 .24078 L
.688 .23799 L
.692 .23598 L
.696 .23457 L
.7 .23359 L
.704 .23293 L
.708 .2325 L
.712 .23221 L
.716 .23204 L
.72 .23193 L
.724 .23186 L
.728 .23182 L
.732 .23179 L
.736 .23178 L
.74 .23177 L
.744 .23177 L
.748 .23177 L
.752 .23176 L
.756 .23176 L
.76 .23176 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35315 L
.264 .35314 L
.268 .35313 L
.272 .3531 L
.276 .35305 L
.28 .35297 L
.284 .35284 L
.288 .35262 L
.292 .35229 L
.296 .35177 L
.3 .35099 L
.304 .34982 L
.308 .34814 L
.312 .34574 L
.316 .34242 L
.32 .33792 L
.324 .33195 L
.328 .32424 L
.332 .31453 L
.336 .3026 L
.34 .28837 L
.344 .27188 L
.348 .25335 L
.352 .23325 L
.356 .21224 L
.36 .19122 L
.364 .17124 L
.368 .15346 L
.372 .13902 L
.376 .12894 L
.38 .12399 L
.384 .12463 L
.388 .13092 L
.392 .14247 L
.396 .15857 L
.4 .17814 L
Mistroke
.404 .19996 L
.408 .22273 L
.412 .24523 L
.416 .26642 L
.42 .28549 L
.424 .30198 L
.428 .31565 L
.432 .32656 L
.436 .33493 L
.44 .34109 L
.444 .34546 L
.448 .34844 L
.452 .35038 L
.456 .35159 L
.46 .35231 L
.464 .35273 L
.468 .35295 L
.472 .35307 L
.476 .35312 L
.48 .35315 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35317 L
.52 .35318 L
.524 .3532 L
.528 .35326 L
.532 .35337 L
.536 .3536 L
.54 .35401 L
.544 .35474 L
.548 .35595 L
.552 .35789 L
.556 .36086 L
.56 .36523 L
.564 .3714 L
.568 .37976 L
.572 .39067 L
.576 .40435 L
.58 .42083 L
.584 .43991 L
.588 .46109 L
.592 .48359 L
.596 .50636 L
.6 .52818 L
Mistroke
.604 .54776 L
.608 .56385 L
.612 .57541 L
.616 .58169 L
.62 .58233 L
.624 .57739 L
.628 .5673 L
.632 .55286 L
.636 .53508 L
.64 .51511 L
.644 .49408 L
.648 .47308 L
.652 .45297 L
.656 .43445 L
.66 .41795 L
.664 .40372 L
.668 .3918 L
.672 .38208 L
.676 .37437 L
.68 .36841 L
.684 .3639 L
.688 .36058 L
.692 .35819 L
.696 .3565 L
.7 .35534 L
.704 .35455 L
.708 .35404 L
.712 .3537 L
.716 .35349 L
.72 .35336 L
.724 .35328 L
.728 .35323 L
.732 .3532 L
.736 .35318 L
.74 .35317 L
.744 .35317 L
.748 .35317 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23177 L
.256 .23177 L
.26 .23177 L
.264 .23178 L
.268 .23179 L
.272 .23182 L
.276 .23186 L
.28 .23193 L
.284 .23204 L
.288 .23221 L
.292 .2325 L
.296 .23293 L
.3 .23359 L
.304 .23457 L
.308 .23598 L
.312 .23799 L
.316 .24078 L
.32 .24456 L
.324 .24957 L
.328 .25604 L
.332 .2642 L
.336 .2742 L
.34 .28615 L
.344 .3 L
.348 .31555 L
.352 .33243 L
.356 .35006 L
.36 .36771 L
.364 .38448 L
.368 .39941 L
.372 .41154 L
.376 .42 L
.38 .42416 L
.384 .42362 L
.388 .41835 L
.392 .40865 L
.396 .39515 L
.4 .37872 L
Mistroke
.404 .3604 L
.408 .34129 L
.412 .32241 L
.416 .30463 L
.42 .28861 L
.424 .27478 L
.428 .2633 L
.432 .25414 L
.436 .24712 L
.44 .24194 L
.444 .23828 L
.448 .23578 L
.452 .23415 L
.456 .23313 L
.46 .23253 L
.464 .23218 L
.468 .23199 L
.472 .2319 L
.476 .23185 L
.48 .23183 L
.484 .23182 L
.488 .23182 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23182 L
.516 .23182 L
.52 .23183 L
.524 .23185 L
.528 .2319 L
.532 .23199 L
.536 .23218 L
.54 .23253 L
.544 .23313 L
.548 .23415 L
.552 .23578 L
.556 .23828 L
.56 .24194 L
.564 .24712 L
.568 .25414 L
.572 .2633 L
.576 .27478 L
.58 .28861 L
.584 .30463 L
.588 .32241 L
.592 .34129 L
.596 .3604 L
.6 .37872 L
Mistroke
.604 .39515 L
.608 .40865 L
.612 .41835 L
.616 .42362 L
.62 .42416 L
.624 .42 L
.628 .41154 L
.632 .39941 L
.636 .38448 L
.64 .36771 L
.644 .35006 L
.648 .33243 L
.652 .31555 L
.656 .3 L
.66 .28615 L
.664 .2742 L
.668 .2642 L
.672 .25604 L
.676 .24957 L
.68 .24456 L
.684 .24078 L
.688 .23799 L
.692 .23598 L
.696 .23457 L
.7 .23359 L
.704 .23293 L
.708 .2325 L
.712 .23221 L
.716 .23204 L
.72 .23193 L
.724 .23186 L
.728 .23182 L
.732 .23179 L
.736 .23178 L
.74 .23177 L
.744 .23177 L
.748 .23177 L
.752 .23176 L
.756 .23176 L
.76 .23176 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`020003Ool00`00
Oomoo`02Ool01000Oomoogoo0P000Woo00D007ooOomoo`00009oo`8000=oo`05001oogooOol00003
Ool30002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00
Oomoo`02Ool00`00Oomoo`0:Ool001aoo`8001moo`8000Yoo`03001oogoo00]oo`03001oogoo00Qo
o`03001oogoo02aoo`0077oo00<007ooOol07goo00<007ooOol027oo00<007ooOol02goo00<007oo
Ool027oo00<007ooOol0;7oo000LOol2000QOol00`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomo
o`07Ool00`00Oomoo`0]Ool001aoo`03001oogoo021oo`03001oogoo00Ioo`03001oogoo00eoo`03
001oogoo00Ioo`03001oogoo02eoo`002goo0P0017oo00@007ooOomoo`D0009oo`80025oo`03001o
ogoo00Ioo`03001oogoo00eoo`03001oogoo00Eoo`03001oogoo02ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool00`00Oomoo`0QOol00`00Oomoo`05Ool00`00Oomoo`0=Ool00`00Oomoo`05
Ool00`00Oomoo`0^Ool000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000ROol00`00Oomoo`04
Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool00`00Oomoo`0^Ool000Yoo`04001oogoo000:Ool01@00
Oomoogoo00008goo00<007ooOol017oo00<007ooOol03goo00<007ooOol017oo00<007ooOol0;Woo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80029oo`03001oogoo00Aoo`03001oogoo
00moo`03001oogoo00Aoo`03001oogoo02ioo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`0ROol00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`0_
Ool000]oo`8000Uoo`<000=oo`8002=oo`03001oogoo009oo`03001oogoo011oo`03001oogoo00=o
o`03001oogoo02moo`0077oo00<007ooOol08Woo00<007ooOol00Woo00<007ooOol047oo00<007oo
Ool00goo00<007ooOol0;goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000SOol00`00Oomo
o`02Ool00`00Oomoo`0AOol01@00Oomoogoo0000<Woo000:Ool01000Oomoo`002Woo00D007ooOomo
o`0002Aoo`03001oogoo009oo`03001oogoo015oo`05001oogooOol0000bOol000Yoo`04001oogoo
0007Ool50002Ool2000TOol01@00Oomoogoo00004goo00D007ooOomoo`00039oo`002Woo00@007oo
Ool000Moo`04001oogoo0003Ool00`00Oomoo`0SOol01000Oomoo`005Goo00@007ooOol0039oo`00
2Woo00@007ooOol000Qoo`03001oo`0000=oo`8002Aoo`04001oogoo000EOol01000Oomoo`00<Woo
000:Ool01000Oomoo`002Goo0P000goo00<007ooOol097oo00<007oo00005Goo00<007oo0000<goo
000;Ool2000;Ool01000Oomoogoo0P009Goo0P005Woo0`00<goo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:
Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol0
17oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:
Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo
0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000L
Ool00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo
000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000F
Ool2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol0
0Woo0`00N7oo000:Ool01000Oomoo`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007oo
Ool000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002goo0P002Goo0`000goo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00
Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool4
0003Ool2001cOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0008Ool00`00Oomoo`03Ool2001cOol000]oo`8000Yoo`8000=oo`03001oogoo02Aoo`80
04aoo`0077oo0P009Goo0P00C7oo000LOol00`00Oomoo`0TOol00`00Ool0001;Ool000]oo`8000Ao
o`03001oogoo00=oo`<0009oo`8002Aoo`04001oogoo001;Ool000Yoo`04001oogoo000:Ool01@00
Oomoogoo00009Goo00@007ooOol004]oo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001o
ogoo02=oo`04001oogoo001;Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P0097oo00D0
07ooOomoo`0004Yoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo029oo`03001o
ogoo009oo`03001oogoo04Qoo`002Woo00@007ooOol000Uoo`8000=oo`8002=oo`03001oogoo009o
o`03001oogoo04Qoo`002goo0P002goo00D007ooOomoo`0002Aoo`03001oogoo009oo`03001oogoo
04Qoo`0077oo0P008goo00<007ooOol00Woo00<007ooOol0B7oo000LOol00`00Oomoo`0ROol00`00
Oomoo`02Ool00`00Oomoo`18Ool000]oo`8000Aoo`04001oogooOol50002Ool2000SOol00`00Oomo
o`03Ool00`00Oomoo`17Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol08Woo
00<007ooOol00goo00<007ooOol0Agoo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo
00<007ooOol08Goo00<007ooOol017oo00<007ooOol0Agoo000:Ool01000Oomoo`002Woo00@007oo
Oomoo`8000ioo`<000Aoo`8000Uoo`<000Aoo`<000=oo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D0
00=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`0<Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`8000=oo`04001o
ogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00
4Goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00800005Ool007oo
Ool00005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo
000;Ool20009Ool30003Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007oo
Ool00Woo00<007ooOol00P0000Eoo`00Oomoo`0000Eoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool0
0`00Oomoo`02Ool00`00Oomoo`0200001Goo001oogoo00001Goo00@007ooOomoo`@000=oo`04001o
ogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo
001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo
0008Ool20004Ool00`00Oomoo`0200001Goo001oogoo000017oo0P000goo00<007ooOol017oo00@0
07ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogoo
Ool007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P002Goo0P001Goo
0P000Woo00@007oo000000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool3
0002Ool50003Ool20006Ool001aoo`8001moo`8000Yoo`03001oogoo04Eoo`0077oo00<007ooOol0
7Goo0P0037oo0P00AGoo000LOomY000<Ool001aoo`03001oogoo019oo`03001oogoo019oo`03001o
ogoo00eoo`05001oogooOol00007Ool2000;Ool00`00Oomoo`0BOol00`00Oomoo`0:Ool001aoo`80
03Uoo`03001oogoo00Qoo`03001oogoo02aoo`0077oo00<007ooOol0>7oo00<007ooOol027oo00<0
07ooOol0;7oo000LOol2000iOol00`00Oomoo`07Ool00`00Oomoo`0]Ool001aoo`03001oogoo03Uo
o`03001oogoo00Ioo`03001oogoo02eoo`0077oo00<007ooOol0>Goo00<007ooOol01Woo00<007oo
Ool0;Goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00>Woo00<007ooOol01Goo00<007ooOol0
;Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo03Uoo`03001oogoo00Eoo`03
001oogoo02ioo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8003]oo`03001oogoo00Aoo`03
001oogoo02ioo`002Woo00@007ooOol000Yoo`05001oogooOol0000lOol00`00Oomoo`04Ool00`00
Oomoo`0^Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00>goo00<007ooOol017oo
00<007ooOol0;Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo03Yoo`03
001oogoo00=oo`03001oogoo02moo`002goo0P002Goo0`000goo00<007ooOol0>Woo00<007ooOol0
0goo00<007ooOol0;goo000LOol2000kOol00`00Oomoo`03Ool00`00Oomoo`0_Ool001aoo`03001o
ogoo03]oo`03001oogoo009oo`03001oogoo02moo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00?7oo00D007ooOomoo`00039oo`002Woo00@007ooOol000Yoo`05001oogooOol0000mOol01@00
Oomoogoo0000<Woo000:Ool01000Oomoo`001goo1@000Woo0P00?7oo00D007ooOomoo`00039oo`00
2Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0kOol01@00Oomoogoo0000<Woo000:
Ool01000Oomoo`0027oo00<007oo00000goo0P00?Goo00@007ooOol0039oo`002Woo00@007ooOol0
00Uoo`8000=oo`03001oogoo03aoo`04001oogoo000bOol000]oo`8000]oo`05001oogooOol0000n
Ool00`00Ool0000cOol001aoo`8003eoo`03001oo`0003=oo`0077oo00<007ooOol0?Goo00<007oo
Ool0<Woo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:
Ool01@00Oomoogoo0000M7oo0003Ool50002Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool0
1000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001o
o`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo
00@007ooOomoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool01000Oomoogoo1@000Woo
0P00Lgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00eoo`<000Aoo`8000Uo
o`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009o
o`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`8000eoo`05001o
ogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Yoo`05001oogooOol0000BOol01000Oomoo`000Woo00<007ooOol0
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`80015oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool0
0`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo1000
0goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Oomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uoo`<000=oo`8000eo
o`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`80
00=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04
001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00ao
o`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool3
0004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`D000=oo`03001oogoo009oo`04001oogooOol300000goo001oo`02
Ool00`00Ool000020003Ool01@00Oomoogoo00000goo100000=oo`00Ool00Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00<007ooOol02Woo000LOol2000OOol2
000:Ool2000;Ool2000:Ool00`00Oomoo`0/Ool001aoo`03001oogoo01moo`03001oogoo00Qoo`03
001oogoo00]oo`03001oogoo00Qoo`03001oogoo02aoo`0077oo0P008Goo00<007ooOol01Woo00<0
07ooOol037oo00<007ooOol01goo00<007ooOol0;Goo000LOol00`00Oomoo`0POol00`00Oomoo`06
Ool00`00Oomoo`0=Ool00`00Oomoo`06Ool00`00Oomoo`0]Ool000]oo`8000Aoo`04001oogooOol5
0002Ool2000QOol00`00Oomoo`06Ool00`00Oomoo`0=Ool00`00Oomoo`05Ool00`00Oomoo`0^Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol087oo00<007ooOol01Woo00<007oo
Ool03Goo00<007ooOol01Goo00<007ooOol0;Woo000:Ool01000Oomoo`002Goo00<007ooOol00Woo
0P008Woo00<007ooOol017oo00<007ooOol03goo00<007ooOol017oo00<007ooOol0;Woo000:Ool0
1000Oomoo`002Woo00D007ooOomoo`0002=oo`03001oogoo00Aoo`03001oogoo00moo`03001oogoo
00Aoo`03001oogoo02ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000ROol00`00
Oomoo`04Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool00`00Oomoo`0^Ool000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol08Woo00<007ooOol00goo00<007ooOol03goo00<007oo
Ool00goo00<007ooOol0;goo000;Ool20009Ool30003Ool2000SOol00`00Oomoo`02Ool00`00Oomo
o`0@Ool00`00Oomoo`03Ool00`00Oomoo`0_Ool001aoo`03001oogoo029oo`03001oogoo009oo`03
001oogoo011oo`03001oogoo00=oo`03001oogoo02moo`002goo0P0017oo00<007ooOol00goo0`00
0Woo0P008goo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol0;goo000:
Ool01000Oomoo`002Woo00D007ooOomoo`0002Aoo`03001oogoo009oo`03001oogoo015oo`05001o
ogooOol0000bOol000Yoo`04001oogoo0007Ool50002Ool2000TOol01@00Oomoogoo00004goo00D0
07ooOomoo`00039oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0SOol01000
Oomoo`005Goo00@007ooOol0039oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8002Aoo`04
001oogoo000EOol01000Oomoo`00<Woo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol097oo
00<007oo00005Goo00<007oo0000<goo000;Ool2000;Ool01000Oomoogoo0P009Goo0P005Woo0`00
<goo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol0
0goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yo
o`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo
00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo
07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(400\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23177 L
.244 .23177 L
.248 .23177 L
.252 .23178 L
.256 .2318 L
.26 .23182 L
.264 .23186 L
.268 .23193 L
.272 .23205 L
.276 .23223 L
.28 .23252 L
.284 .23297 L
.288 .23364 L
.292 .23463 L
.296 .23606 L
.3 .23808 L
.304 .24088 L
.308 .24467 L
.312 .24967 L
.316 .25612 L
.32 .26424 L
.324 .2742 L
.328 .28607 L
.332 .29983 L
.336 .31528 L
.34 .33206 L
.344 .34962 L
.348 .36721 L
.352 .38396 L
.356 .39891 L
.36 .41111 L
.364 .41971 L
.368 .42402 L
.372 .42367 L
.376 .41858 L
.38 .40904 L
.384 .39565 L
.388 .37929 L
.392 .36098 L
.396 .34181 L
.4 .32284 L
Mistroke
.404 .30494 L
.408 .2888 L
.412 .27484 L
.416 .26326 L
.42 .25404 L
.424 .24697 L
.428 .24178 L
.432 .23812 L
.436 .23564 L
.44 .23404 L
.444 .23305 L
.448 .23246 L
.452 .23214 L
.456 .23197 L
.46 .23188 L
.464 .23184 L
.468 .23182 L
.472 .23182 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23182 L
.532 .23182 L
.536 .23184 L
.54 .23188 L
.544 .23197 L
.548 .23214 L
.552 .23246 L
.556 .23305 L
.56 .23404 L
.564 .23564 L
.568 .23812 L
.572 .24178 L
.576 .24697 L
.58 .25404 L
.584 .26326 L
.588 .27484 L
.592 .2888 L
.596 .30494 L
.6 .32284 L
Mistroke
.604 .34181 L
.608 .36098 L
.612 .37929 L
.616 .39565 L
.62 .40904 L
.624 .41858 L
.628 .42367 L
.632 .42402 L
.636 .41971 L
.64 .41111 L
.644 .39891 L
.648 .38396 L
.652 .36721 L
.656 .34962 L
.66 .33206 L
.664 .31528 L
.668 .29983 L
.672 .28607 L
.676 .2742 L
.68 .26424 L
.684 .25612 L
.688 .24967 L
.692 .24467 L
.696 .24088 L
.7 .23808 L
.704 .23606 L
.708 .23463 L
.712 .23364 L
.716 .23297 L
.72 .23252 L
.724 .23223 L
.728 .23205 L
.732 .23193 L
.736 .23186 L
.74 .23182 L
.744 .2318 L
.748 .23178 L
.752 .23177 L
.756 .23177 L
.76 .23177 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35315 L
.252 .35314 L
.256 .35312 L
.26 .35309 L
.264 .35304 L
.268 .35296 L
.272 .35282 L
.276 .3526 L
.28 .35225 L
.284 .35172 L
.288 .35093 L
.292 .34975 L
.296 .34804 L
.3 .34563 L
.304 .3423 L
.308 .33779 L
.312 .33183 L
.316 .32414 L
.32 .31447 L
.324 .30261 L
.328 .28847 L
.332 .27208 L
.336 .25367 L
.34 .23368 L
.344 .21277 L
.348 .19182 L
.352 .17187 L
.356 .15406 L
.36 .13952 L
.364 .12929 L
.368 .12415 L
.372 .12458 L
.376 .13064 L
.38 .14201 L
.384 .15797 L
.388 .17747 L
.392 .19928 L
.396 .22211 L
.4 .24472 L
Mistroke
.404 .26604 L
.408 .28528 L
.412 .3019 L
.416 .3157 L
.42 .32669 L
.424 .3351 L
.428 .34129 L
.432 .34565 L
.436 .3486 L
.44 .35051 L
.444 .35169 L
.448 .35239 L
.452 .35278 L
.456 .35298 L
.46 .35308 L
.464 .35313 L
.468 .35315 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35317 L
.532 .35317 L
.536 .35319 L
.54 .35324 L
.544 .35334 L
.548 .35355 L
.552 .35394 L
.556 .35463 L
.56 .35581 L
.564 .35772 L
.568 .36067 L
.572 .36503 L
.576 .37122 L
.58 .37964 L
.584 .39063 L
.588 .40442 L
.592 .42105 L
.596 .44028 L
.6 .4616 L
Mistroke
.604 .48421 L
.608 .50704 L
.612 .52886 L
.616 .54836 L
.62 .56431 L
.624 .57568 L
.628 .58175 L
.632 .58217 L
.636 .57703 L
.64 .5668 L
.644 .55227 L
.648 .53445 L
.652 .5145 L
.656 .49355 L
.66 .47264 L
.664 .45265 L
.668 .43425 L
.672 .41786 L
.676 .40371 L
.68 .39186 L
.684 .38218 L
.688 .37449 L
.692 .36853 L
.696 .36403 L
.7 .36069 L
.704 .35828 L
.708 .35658 L
.712 .3554 L
.716 .3546 L
.72 .35407 L
.724 .35372 L
.728 .3535 L
.732 .35337 L
.736 .35328 L
.74 .35323 L
.744 .3532 L
.748 .35318 L
.752 .35317 L
.756 .35317 L
.76 .35317 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23177 L
.244 .23177 L
.248 .23177 L
.252 .23178 L
.256 .2318 L
.26 .23182 L
.264 .23186 L
.268 .23193 L
.272 .23205 L
.276 .23223 L
.28 .23252 L
.284 .23297 L
.288 .23364 L
.292 .23463 L
.296 .23606 L
.3 .23808 L
.304 .24088 L
.308 .24467 L
.312 .24967 L
.316 .25612 L
.32 .26424 L
.324 .2742 L
.328 .28607 L
.332 .29983 L
.336 .31528 L
.34 .33206 L
.344 .34962 L
.348 .36721 L
.352 .38396 L
.356 .39891 L
.36 .41111 L
.364 .41971 L
.368 .42402 L
.372 .42367 L
.376 .41858 L
.38 .40904 L
.384 .39565 L
.388 .37929 L
.392 .36098 L
.396 .34181 L
.4 .32284 L
Mistroke
.404 .30494 L
.408 .2888 L
.412 .27484 L
.416 .26326 L
.42 .25404 L
.424 .24697 L
.428 .24178 L
.432 .23812 L
.436 .23564 L
.44 .23404 L
.444 .23305 L
.448 .23246 L
.452 .23214 L
.456 .23197 L
.46 .23188 L
.464 .23184 L
.468 .23182 L
.472 .23182 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23182 L
.532 .23182 L
.536 .23184 L
.54 .23188 L
.544 .23197 L
.548 .23214 L
.552 .23246 L
.556 .23305 L
.56 .23404 L
.564 .23564 L
.568 .23812 L
.572 .24178 L
.576 .24697 L
.58 .25404 L
.584 .26326 L
.588 .27484 L
.592 .2888 L
.596 .30494 L
.6 .32284 L
Mistroke
.604 .34181 L
.608 .36098 L
.612 .37929 L
.616 .39565 L
.62 .40904 L
.624 .41858 L
.628 .42367 L
.632 .42402 L
.636 .41971 L
.64 .41111 L
.644 .39891 L
.648 .38396 L
.652 .36721 L
.656 .34962 L
.66 .33206 L
.664 .31528 L
.668 .29983 L
.672 .28607 L
.676 .2742 L
.68 .26424 L
.684 .25612 L
.688 .24967 L
.692 .24467 L
.696 .24088 L
.7 .23808 L
.704 .23606 L
.708 .23463 L
.712 .23364 L
.716 .23297 L
.72 .23252 L
.724 .23223 L
.728 .23205 L
.732 .23193 L
.736 .23186 L
.74 .23182 L
.744 .2318 L
.748 .23178 L
.752 .23177 L
.756 .23177 L
.76 .23177 L
.764 .23176 L
.768 .23176 L
.772 .23176 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool50003Ool00`00Oomoo`02Ool0
0`00Ool000020003Ool01@00Oomoogoo00000goo0P000Woo00D007ooOomoo`0000=oo`06001oo`00
001oo`000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00<0
07ooOol02Woo000LOol2000NOol00`00Oomoo`09Ool00`00Oomoo`0=Ool00`00Oomoo`08Ool2000/
Ool001aoo`03001oogoo01ioo`03001oogoo00Qoo`03001oogoo00eoo`03001oogoo00Qoo`03001o
ogoo02]oo`0077oo0P007goo00<007ooOol01goo00<007ooOol03goo00<007ooOol01Woo00<007oo
Ool0;7oo000LOol00`00Oomoo`0OOol00`00Oomoo`06Ool00`00Oomoo`0?Ool00`00Oomoo`06Ool0
0`00Oomoo`0/Ool000]oo`8000Aoo`04001oogooOol50002Ool2000POol00`00Oomoo`05Ool00`00
Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`0/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00<007ooOol087oo00<007ooOol017oo00<007ooOol047oo00<007ooOol01Goo00<007ooOol0
;Goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P008Goo00<007ooOol017oo00<007ooOol0
4Goo00<007ooOol017oo00<007ooOol0;Goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00029o
o`03001oogoo00Aoo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo02eoo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool2000QOol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomo
o`04Ool00`00Oomoo`0]Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
87oo00<007ooOol017oo00<007ooOol04Goo00<007ooOol00goo00<007ooOol0;Woo000;Ool20009
Ool30003Ool2000ROol00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`02Ool00`00Oomoo`0^
Ool001aoo`03001oogoo025oo`03001oogoo009oo`03001oogoo01=oo`03001oogoo009oo`03001o
ogoo02ioo`002goo0P0017oo00<007ooOol00goo0`000Woo0P008Woo00<007ooOol00Woo00<007oo
Ool04goo00<007ooOol00Woo00<007ooOol0;Woo000:Ool01000Oomoo`002Woo00D007ooOomoo`00
02=oo`03001oogoo009oo`03001oogoo01=oo`03001oogoo009oo`03001oogoo02ioo`002Woo00@0
07ooOol000Moo`D0009oo`8002=oo`04001oogoo000FOol01@00Oomoogoo0000<Goo000:Ool01000
Oomoo`001goo00@007ooOol000=oo`03001oogoo029oo`04001oogoo000GOol01000Oomoo`00<Goo
000:Ool01000Oomoo`0027oo00<007oo00000goo0P008goo00@007ooOol001Moo`04001oogoo000a
Ool000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`0ROol00`00Ool0000HOol00`00Ool0000b
Ool000]oo`8000]oo`04001oogooOol2000TOol2000IOol2000bOol001aoo`03001oogoo079oo`00
2goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol0
00Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomo
o`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`80
00Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003
Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol0
01aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1b
Ool001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol0
01Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomo
o`02Ool3001hOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000;Ool20009Ool30003Ool00`00Oomoo`1b
Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2
001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`@000=oo`8007=oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`03001oogoo079oo`002Woo
00@007ooOol000Qoo`03001oogoo00=oo`8007=oo`002goo0P002Woo0P000goo00<007ooOol08goo
0P00CGoo000LOol2000TOol2001=Ool001aoo`03001oogoo029oo`03001oo`0004eoo`002goo0P00
17oo00<007ooOol00goo0`000Woo0P008goo00<007oo0000CGoo000:Ool01000Oomoo`002Woo00D0
07ooOomoo`0002Aoo`04001oogoo001<Ool000=oo`D0009oo`04001oogoo0007Ool50002Ool00`00
Oomoo`0ROol01000Oomoo`00C7oo000:Ool01000Oomoo`001goo00@007ooOol000=oo`8002=oo`04
001oogoo001<Ool000Yoo`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`0QOol01@00Oomo
ogoo0000C7oo000:Ool01000Oomoo`002Goo0P000goo0P008Woo00<007ooOol00Woo00<007ooOol0
BGoo000;Ool2000;Ool01@00Oomoogoo00008goo00<007ooOol00Woo00<007ooOol0BGoo000LOol2
000ROol00`00Oomoo`02Ool00`00Oomoo`19Ool001aoo`03001oogoo021oo`03001oogoo00=oo`03
001oogoo04Uoo`002goo0P0017oo00@007ooOomoo`D0009oo`80025oo`03001oogoo00Aoo`03001o
ogoo04Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0POol00`00Oomoo`04
Ool00`00Oomoo`18Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0P
Ool00`00Oomoo`04Ool00`00Oomoo`18Ool000Yoo`04001oogoo000:Ool01000Oomoogoo0P003Woo
0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo
0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo00aoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007oo0000
009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol0
1000Oomoo`000Woo00<007ooOol01Woo0P0017oo00@007oo0000009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool20009Ool3
0003Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01Woo0P0017oo00@007oo0000009o
o`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04
001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo
00<007ooOol037oo00<007ooOol017oo00@007ooOol000Moo`<000Aoo`04001oogoo0002Ool01000
Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo
00<007ooOol037oo1@000goo0P0027oo00<007oo00001Goo0P0000Aoo`00Oomoo`8000Ioo`04001o
ogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`80
01ioo`03001oogoo00Uoo`03001oogoo04Ioo`0077oo00<007ooOol077oo0P002goo0P00Agoo000L
OomY000<Ool001aoo`03001oogoo019oo`03001oogoo019oo`03001oogoo00ioo`04001oogoo0009
Ool20009Ool00`00Oomoo`0BOol00`00Oomoo`0:Ool001aoo`8003Yoo`03001oogoo00Qoo`03001o
ogoo02]oo`0077oo00<007ooOol0>Goo00<007ooOol027oo00<007ooOol0:goo000LOol2000kOol0
0`00Oomoo`06Ool00`00Oomoo`0/Ool001aoo`03001oogoo03Yoo`03001oogoo00Ioo`03001oogoo
02aoo`0077oo00<007ooOol0>Woo00<007ooOol01Woo00<007ooOol0;7oo000;Ool20004Ool01000
Oomoogoo1@000Woo0P00>goo00<007ooOol01Woo00<007ooOol0;7oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`03001oogoo03Yoo`03001oogoo00Eoo`03001oogoo02eoo`002Woo00@007oo
Ool000Uoo`03001oogoo009oo`8003aoo`03001oogoo00Aoo`03001oogoo02eoo`002Woo00@007oo
Ool000Yoo`05001oogooOol0000mOol00`00Oomoo`04Ool00`00Oomoo`0]Ool000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P00?7oo00<007ooOol017oo00<007ooOol0;Goo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo03]oo`03001oogoo00=oo`03001oogoo02io
o`002goo0P002Goo0`000goo00<007ooOol0?7oo00<007ooOol00Woo00<007ooOol0;Woo000LOol2
000mOol00`00Oomoo`02Ool00`00Oomoo`0^Ool001aoo`03001oogoo03aoo`03001oogoo009oo`03
001oogoo02ioo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00?Goo00<007ooOol00Woo00<0
07ooOol0;Woo000:Ool01000Oomoo`002Woo00D007ooOomoo`0003ioo`03001oogoo009oo`03001o
ogoo02ioo`002Woo00@007ooOol000Moo`D0009oo`8003eoo`03001oogoo009oo`03001oogoo02io
o`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0lOol01@00Oomoogoo0000<Goo
000:Ool01000Oomoo`0027oo00<007oo00000goo0P00?Woo00@007ooOol0035oo`002Woo00@007oo
Ool000Uoo`8000=oo`03001oogoo03eoo`04001oogoo000aOol000]oo`8000]oo`05001oogooOol0
000oOol00`00Ool0000bOol001aoo`8003moo`80039oo`0077oo00<007ooOol0?Woo0P00<Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomo
ogoo0000M7oo0003Ool50002Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`00
1goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`80
07=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00@007ooOomo
o`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P00Lgoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`80
00Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`80
00Ioo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`8000eoo`05001oogooOol00002
Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomo
ogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Yoo`05001oogooOol0000BOol01000Oomoo`000Woo00<007ooOol01goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
015oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo10000goo00@007oo
Ool000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=o
o`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00
Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uoo`<000=oo`8000eoo`03001oogoo
00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001o
ogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004
Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`80
00Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004
Ool20006Ool30002Ool50003Ool20006Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOomY
000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`D000=oo`03001oogoo009oo`03001oo`0000<0009oo`05001oogooOol00002Ool3
0002Ool01@00Oomoogoo00000goo00<007oo00000`000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo000017oo00<007ooOol02Woo000LOol2000NOol00`00Oomoo`09Ool0
0`00Oomoo`0=Ool00`00Oomoo`08Ool2000/Ool001aoo`03001oogoo01ioo`03001oogoo00Qoo`03
001oogoo00eoo`03001oogoo00Qoo`03001oogoo02]oo`0077oo0P007goo00<007ooOol01goo00<0
07ooOol03goo00<007ooOol01Woo00<007ooOol0;7oo000LOol00`00Oomoo`0OOol00`00Oomoo`06
Ool00`00Oomoo`0?Ool00`00Oomoo`06Ool00`00Oomoo`0/Ool000]oo`8000Aoo`04001oogooOol5
0002Ool2000POol00`00Oomoo`05Ool00`00Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`0/Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol087oo00<007ooOol017oo00<007oo
Ool047oo00<007ooOol01Goo00<007ooOol0;Goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo
0P008Goo00<007ooOol017oo00<007ooOol04Goo00<007ooOol017oo00<007ooOol0;Goo000:Ool0
1000Oomoo`002Woo00D007ooOomoo`00029oo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo
00Aoo`03001oogoo02eoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000QOol00`00
Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0]Ool000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol087oo00<007ooOol017oo00<007ooOol04Goo00<007oo
Ool00goo00<007ooOol0;Woo000;Ool20009Ool30003Ool2000QOol00`00Oomoo`03Ool00`00Oomo
o`0COol00`00Oomoo`02Ool00`00Oomoo`0^Ool001aoo`03001oogoo025oo`03001oogoo009oo`03
001oogoo01=oo`03001oogoo009oo`03001oogoo02ioo`002goo0P0017oo00<007ooOol00goo0`00
0Woo0P008Woo00<007ooOol00Woo00<007ooOol04goo00<007ooOol00Woo00<007ooOol0;Woo000:
Ool01000Oomoo`002Woo00D007ooOomoo`0002=oo`03001oogoo009oo`03001oogoo01=oo`03001o
ogoo009oo`03001oogoo02ioo`002Woo00@007ooOol000Moo`D0009oo`8002=oo`04001oogoo000F
Ool01@00Oomoogoo0000<Goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo029o
o`04001oogoo000GOol01000Oomoo`00<Goo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00
8goo00@007ooOol001Moo`04001oogoo000aOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomo
o`0ROol00`00Ool0000HOol00`00Ool0000bOol000]oo`8000]oo`04001oogooOol2000TOol2000I
Ool2000bOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00
Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo
000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=o
o`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo
000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<0
07ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(440\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23177 L
.232 .23177 L
.236 .23177 L
.24 .23178 L
.244 .2318 L
.248 .23183 L
.252 .23187 L
.256 .23194 L
.26 .23206 L
.264 .23226 L
.268 .23255 L
.272 .23301 L
.276 .23369 L
.28 .23469 L
.284 .23614 L
.288 .23817 L
.292 .24098 L
.296 .24477 L
.3 .24977 L
.304 .25621 L
.308 .26429 L
.312 .27419 L
.316 .286 L
.32 .29967 L
.324 .31502 L
.328 .33171 L
.332 .34918 L
.336 .36671 L
.34 .38343 L
.344 .39841 L
.348 .41069 L
.352 .4194 L
.356 .42388 L
.36 .4237 L
.364 .4188 L
.368 .40942 L
.372 .39615 L
.376 .37985 L
.38 .36155 L
.384 .34234 L
.388 .32328 L
.392 .30526 L
.396 .28899 L
.4 .27491 L
Mistroke
.404 .26323 L
.408 .25393 L
.412 .24682 L
.416 .24161 L
.42 .23795 L
.424 .2355 L
.428 .23392 L
.432 .23296 L
.436 .2324 L
.44 .2321 L
.444 .23194 L
.448 .23186 L
.452 .23183 L
.456 .23182 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23182 L
.548 .23183 L
.552 .23186 L
.556 .23194 L
.56 .2321 L
.564 .2324 L
.568 .23296 L
.572 .23392 L
.576 .2355 L
.58 .23795 L
.584 .24161 L
.588 .24682 L
.592 .25393 L
.596 .26323 L
.6 .27491 L
Mistroke
.604 .28899 L
.608 .30526 L
.612 .32328 L
.616 .34234 L
.62 .36155 L
.624 .37985 L
.628 .39615 L
.632 .40942 L
.636 .4188 L
.64 .4237 L
.644 .42388 L
.648 .4194 L
.652 .41069 L
.656 .39841 L
.66 .38343 L
.664 .36671 L
.668 .34918 L
.672 .33171 L
.676 .31502 L
.68 .29967 L
.684 .286 L
.688 .27419 L
.692 .26429 L
.696 .25621 L
.7 .24977 L
.704 .24477 L
.708 .24098 L
.712 .23817 L
.716 .23614 L
.72 .23469 L
.724 .23369 L
.728 .23301 L
.732 .23255 L
.736 .23226 L
.74 .23206 L
.744 .23194 L
.748 .23187 L
.752 .23183 L
.756 .2318 L
.76 .23178 L
.764 .23177 L
.768 .23177 L
.772 .23177 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35315 L
.24 .35314 L
.244 .35312 L
.248 .35309 L
.252 .35303 L
.256 .35295 L
.26 .3528 L
.264 .35258 L
.268 .35222 L
.272 .35168 L
.276 .35087 L
.28 .34967 L
.284 .34795 L
.288 .34552 L
.292 .34218 L
.296 .33766 L
.3 .33171 L
.304 .32404 L
.308 .31441 L
.312 .30262 L
.316 .28856 L
.32 .27227 L
.324 .25398 L
.328 .2341 L
.332 .2133 L
.336 .19242 L
.34 .17249 L
.344 .15465 L
.348 .14003 L
.352 .12965 L
.356 .12432 L
.36 .12454 L
.364 .13039 L
.368 .14156 L
.372 .15737 L
.376 .17679 L
.38 .1986 L
.384 .22148 L
.388 .2442 L
.392 .26566 L
.396 .28505 L
.4 .30182 L
Mistroke
.404 .31573 L
.408 .32682 L
.412 .33528 L
.416 .34149 L
.42 .34585 L
.424 .34877 L
.428 .35065 L
.432 .3518 L
.436 .35246 L
.44 .35283 L
.444 .35301 L
.448 .3531 L
.452 .35314 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35317 L
.548 .35318 L
.552 .35322 L
.556 .35331 L
.56 .3535 L
.564 .35386 L
.568 .35453 L
.572 .35567 L
.576 .35755 L
.58 .36048 L
.584 .36484 L
.588 .37104 L
.592 .37951 L
.596 .39059 L
.6 .40451 L
Mistroke
.604 .42128 L
.608 .44066 L
.612 .46213 L
.616 .48484 L
.62 .50773 L
.624 .52953 L
.628 .54895 L
.632 .56476 L
.636 .57594 L
.64 .58179 L
.644 .582 L
.648 .57667 L
.652 .56629 L
.656 .55167 L
.66 .53383 L
.664 .51391 L
.668 .49303 L
.672 .47222 L
.676 .45234 L
.68 .43405 L
.684 .41777 L
.688 .40371 L
.692 .39191 L
.696 .38228 L
.7 .37461 L
.704 .36866 L
.708 .36415 L
.712 .3608 L
.716 .35837 L
.72 .35665 L
.724 .35546 L
.728 .35465 L
.732 .3541 L
.736 .35375 L
.74 .35352 L
.744 .35338 L
.748 .35329 L
.752 .35324 L
.756 .3532 L
.76 .35319 L
.764 .35318 L
.768 .35317 L
.772 .35317 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23177 L
.232 .23177 L
.236 .23177 L
.24 .23178 L
.244 .2318 L
.248 .23183 L
.252 .23187 L
.256 .23194 L
.26 .23206 L
.264 .23226 L
.268 .23255 L
.272 .23301 L
.276 .23369 L
.28 .23469 L
.284 .23614 L
.288 .23817 L
.292 .24098 L
.296 .24477 L
.3 .24977 L
.304 .25621 L
.308 .26429 L
.312 .27419 L
.316 .286 L
.32 .29967 L
.324 .31502 L
.328 .33171 L
.332 .34918 L
.336 .36671 L
.34 .38343 L
.344 .39841 L
.348 .41069 L
.352 .4194 L
.356 .42388 L
.36 .4237 L
.364 .4188 L
.368 .40942 L
.372 .39615 L
.376 .37985 L
.38 .36155 L
.384 .34234 L
.388 .32328 L
.392 .30526 L
.396 .28899 L
.4 .27491 L
Mistroke
.404 .26323 L
.408 .25393 L
.412 .24682 L
.416 .24161 L
.42 .23795 L
.424 .2355 L
.428 .23392 L
.432 .23296 L
.436 .2324 L
.44 .2321 L
.444 .23194 L
.448 .23186 L
.452 .23183 L
.456 .23182 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23182 L
.548 .23183 L
.552 .23186 L
.556 .23194 L
.56 .2321 L
.564 .2324 L
.568 .23296 L
.572 .23392 L
.576 .2355 L
.58 .23795 L
.584 .24161 L
.588 .24682 L
.592 .25393 L
.596 .26323 L
.6 .27491 L
Mistroke
.604 .28899 L
.608 .30526 L
.612 .32328 L
.616 .34234 L
.62 .36155 L
.624 .37985 L
.628 .39615 L
.632 .40942 L
.636 .4188 L
.64 .4237 L
.644 .42388 L
.648 .4194 L
.652 .41069 L
.656 .39841 L
.66 .38343 L
.664 .36671 L
.668 .34918 L
.672 .33171 L
.676 .31502 L
.68 .29967 L
.684 .286 L
.688 .27419 L
.692 .26429 L
.696 .25621 L
.7 .24977 L
.704 .24477 L
.708 .24098 L
.712 .23817 L
.716 .23614 L
.72 .23469 L
.724 .23369 L
.728 .23301 L
.732 .23255 L
.736 .23226 L
.74 .23206 L
.744 .23194 L
.748 .23187 L
.752 .23183 L
.756 .2318 L
.76 .23178 L
.764 .23177 L
.768 .23177 L
.772 .23177 L
.776 .23176 L
.78 .23176 L
.784 .23176 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool20002Ool01@00Oomoogoo0000
17oo0`0000=oo`00Ool00Woo00D007ooOomoo`0000=oo`03001oo`00008000=oo`05001oogooOol0
0002Ool30003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool0
0`00Oomoo`0:Ool001aoo`8001eoo`03001oogoo00Uoo`03001oogoo00moo`03001oogoo00Uoo`03
001oogoo02Uoo`0077oo00<007ooOol07Goo00<007ooOol01goo00<007ooOol047oo00<007ooOol0
27oo00<007ooOol0:Woo000LOol2000NOol00`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomoo`07
Ool00`00Oomoo`0ZOol001aoo`03001oogoo01eoo`03001oogoo00Moo`03001oogoo015oo`03001o
ogoo00Ioo`03001oogoo02]oo`002goo0P0017oo00@007ooOomoo`D0009oo`8001moo`03001oogoo
00Eoo`03001oogoo01=oo`03001oogoo00Eoo`03001oogoo02]oo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool00`00Oomoo`0NOol00`00Oomoo`05Ool00`00Oomoo`0COol00`00Oomoo`04Ool0
0`00Oomoo`0/Ool000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000OOol00`00Oomoo`05Ool0
0`00Oomoo`0COol00`00Oomoo`04Ool00`00Oomoo`0/Ool000Yoo`04001oogoo000:Ool01@00Oomo
ogoo00008Goo00<007ooOol017oo00<007ooOol04goo00<007ooOol017oo00<007ooOol0;7oo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80021oo`03001oogoo00=oo`03001oogoo01Ao
o`03001oogoo00Aoo`03001oogoo02aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`0OOol00`00Oomoo`03Ool00`00Oomoo`0DOol00`00Oomoo`04Ool00`00Oomoo`0/Ool0
00]oo`8000Uoo`<000=oo`80025oo`03001oogoo009oo`03001oogoo01Eoo`03001oogoo009oo`03
001oogoo02eoo`0077oo00<007ooOol087oo00<007ooOol00Woo00<007ooOol05Goo00<007ooOol0
0Woo00<007ooOol0;Goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000QOol01@00Oomoogoo
000067oo00<007ooOol00Woo00<007ooOol0;Goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00
029oo`05001oogooOol0000HOol00`00Oomoo`02Ool00`00Oomoo`0]Ool000Yoo`04001oogoo0007
Ool50002Ool2000QOol01@00Oomoogoo00006Goo00@007ooOol0031oo`002Woo00@007ooOol000Mo
o`04001oogoo0003Ool00`00Oomoo`0QOol01000Oomoo`006Goo00@007ooOol0031oo`002Woo00@0
07ooOol000Qoo`03001oo`0000=oo`80029oo`04001oogoo000IOol01000Oomoo`00<7oo000:Ool0
1000Oomoo`002Goo0P000goo00<007ooOol08Goo00<007oo00006goo00<007oo0000<7oo000;Ool2
000;Ool01000Oomoogoo0P008goo0P006goo0P00<Goo000LOol00`00Oomoo`1bOol000]oo`8000Ao
o`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000
Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00
Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003
Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00
Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol0
0`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001i
Ool001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00
N7oo000:Ool01000Oomoo`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8007=oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2
001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool40003Ool2
001cOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0008Ool00`00Oomoo`03Ool2001cOol000]oo`8000Yoo`8000=oo`03001oogoo029oo`03001oogoo
04eoo`0077oo0P008goo0P00CWoo000LOol00`00Oomoo`0QOol00`00Ool0001>Ool000]oo`8000Ao
o`03001oogoo00=oo`<0009oo`80029oo`03001oo`0004ioo`002Woo00@007ooOol000Yoo`05001o
ogooOol0000SOol01000Oomoo`00CGoo0003Ool50002Ool01000Oomoo`001goo1@000Woo00<007oo
Ool087oo00D007ooOomoo`0004eoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool2000QOol0
1@00Oomoogoo0000CGoo000:Ool01000Oomoo`0027oo00<007oo00000goo00<007ooOol087oo00D0
07ooOomoo`0004eoo`002Woo00@007ooOol000Uoo`8000=oo`80025oo`05001oogooOol0001=Ool0
00]oo`8000]oo`05001oogooOol0000ROol01@00Oomoogoo0000CGoo000LOol2000QOol00`00Oomo
o`02Ool00`00Oomoo`1:Ool001aoo`03001oogoo01moo`03001oogoo00=oo`03001oogoo04Yoo`00
2goo0P0017oo00@007ooOomoo`D0009oo`80021oo`03001oogoo00=oo`03001oogoo04Yoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0OOol00`00Oomoo`03Ool00`00Oomoo`1:
Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0OOol00`00Oomoo`03
Ool00`00Oomoo`1:Ool000Yoo`04001oogoo000:Ool01000Oomoogoo0P003Woo0`0017oo0P002Goo
0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo
0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`05
001oogooOol00002Ool01000Oomoo`001goo00<007oo000017oo0P0000Eoo`00Oomoo`00009oo`03
001oogoo00=oo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04001oogoo
0002Ool00`00Oomoo`05Ool00`00Ool00004Ool200001Goo001oogoo00000Woo00<007ooOol00goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P00
2Goo0`000goo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oo`0000Aoo`80
0005Ool007ooOol00002Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`001Woo00@007oo
Ool000Aoo`04001oo`000002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@0
00=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0006Ool0
1000Ool0000017oo00@007oo0000009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000
Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomo
o`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool20007Ool01000Oomo
o`001Goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0
009oo`D000=oo`8000Ioo`0077oo0P007Goo00<007ooOol02Goo00<007ooOol0Agoo000LOol00`00
Oomoo`0KOol00`00Oomoo`0:Ool20018Ool001aoofT000aoo`0077oo00<007ooOol04Woo00<007oo
Ool04Woo00<007ooOol03goo0`002Woo0P0027oo00<007ooOol04Woo00<007ooOol02Woo000LOol2
000kOol00`00Oomoo`09Ool00`00Oomoo`0YOol001aoo`03001oogoo03Yoo`03001oogoo00Qoo`03
001oogoo02Yoo`0077oo0P00?7oo00<007ooOol01goo00<007ooOol0:Woo000LOol00`00Oomoo`0k
Ool00`00Oomoo`06Ool00`00Oomoo`0[Ool001aoo`03001oogoo03]oo`03001oogoo00Ioo`03001o
ogoo02]oo`002goo0P0017oo00@007ooOomoo`D0009oo`8003eoo`03001oogoo00Eoo`03001oogoo
02]oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0lOol00`00Oomoo`04Ool0
0`00Oomoo`0/Ool000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000mOol00`00Oomoo`04Ool0
0`00Oomoo`0/Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000?Woo00<007ooOol017oo00<0
07ooOol0;7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8003eoo`03001oogoo00Ao
o`03001oogoo02aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0lOol0
0`00Oomoo`04Ool00`00Oomoo`0/Ool000]oo`8000Uoo`<000=oo`03001oogoo03eoo`03001oogoo
00=oo`03001oogoo02aoo`0077oo0P00?Woo00<007ooOol00Woo00<007ooOol0;Goo000LOol00`00
Oomoo`0mOol00`00Oomoo`02Ool00`00Oomoo`0]Ool000]oo`8000Aoo`03001oogoo00=oo`<0009o
o`8003ioo`03001oogoo009oo`03001oogoo02eoo`002Woo00@007ooOol000Yoo`05001oogooOol0
000oOol00`00Oomoo`02Ool00`00Oomoo`0]Ool000Yoo`04001oogoo0007Ool50002Ool2000oOol0
1@00Oomoogoo0000;goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo03ioo`04
001oogoo000`Ool000Yoo`04001oogoo0008Ool00`00Ool00003Ool2000oOol01000Oomoo`00<7oo
000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0?Woo00@007ooOol0031oo`002goo0P002goo
00D007ooOomoo`00045oo`03001oo`00031oo`0077oo0P00@7oo0P00<Goo000LOol00`00Oomoo`0o
Ool2000aOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol0
00Yoo`05001oogooOol0001dOol000=oo`D0009oo`04001oogoo0007Ool50002Ool2001cOol000Yo
o`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<0
07oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;
Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogooOol50002
Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol03Goo0`0017oo0P00
2Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@00
0Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo0P003Goo00D0
07ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007oo
Ool00goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`04001oogoo0002Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P004Goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool4
0003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000
Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P00
3Goo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo
0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol0
37oo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Io
o`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000Woo0`000Woo00D007ooOomoo`0000Aoo`D000=oo`05001oogooOol0
0003Ool50003Ool01@00Oomoogoo00000Woo10000Woo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo000017oo00<007ooOol02Woo000LOol2000MOol00`00Oomoo`09Ool00`00
Oomoo`0?Ool00`00Oomoo`09Ool00`00Oomoo`0YOol001aoo`03001oogoo01eoo`03001oogoo00Mo
o`03001oogoo011oo`03001oogoo00Qoo`03001oogoo02Yoo`0077oo0P007Woo00<007ooOol01goo
00<007ooOol04Goo00<007ooOol01goo00<007ooOol0:Woo000LOol00`00Oomoo`0MOol00`00Oomo
o`07Ool00`00Oomoo`0AOol00`00Oomoo`06Ool00`00Oomoo`0[Ool000]oo`8000Aoo`04001oogoo
Ool50002Ool2000OOol00`00Oomoo`05Ool00`00Oomoo`0COol00`00Oomoo`05Ool00`00Oomoo`0[
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol07Woo00<007ooOol01Goo00<0
07ooOol04goo00<007ooOol017oo00<007ooOol0;7oo000:Ool01000Oomoo`002Goo00<007ooOol0
0Woo0P007goo00<007ooOol01Goo00<007ooOol04goo00<007ooOol017oo00<007ooOol0;7oo000:
Ool01000Oomoo`002Woo00D007ooOomoo`00025oo`03001oogoo00Aoo`03001oogoo01=oo`03001o
ogoo00Aoo`03001oogoo02aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000POol0
0`00Oomoo`03Ool00`00Oomoo`0DOol00`00Oomoo`04Ool00`00Oomoo`0/Ool000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol07goo00<007ooOol00goo00<007ooOol057oo00<0
07ooOol017oo00<007ooOol0;7oo000;Ool20009Ool30003Ool2000POol00`00Oomoo`03Ool00`00
Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`0/Ool001aoo`03001oogoo021oo`03001oogoo009o
o`03001oogoo01Eoo`03001oogoo009oo`03001oogoo02eoo`002goo0P0017oo00<007ooOol00goo
0`000Woo0P008Goo00D007ooOomoo`0001Qoo`03001oogoo009oo`03001oogoo02eoo`002Woo00@0
07ooOol000Yoo`05001oogooOol0000ROol01@00Oomoogoo000067oo00<007ooOol00Woo00<007oo
Ool0;Goo000:Ool01000Oomoo`001goo1@000Woo0P008Goo00D007ooOomoo`0001Uoo`04001oogoo
000`Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol087oo00D007ooOomoo`00
01Uoo`04001oogoo000`Ool000Yoo`04001oogoo0008Ool00`00Ool00003Ool2000ROol01000Oomo
o`006Goo00@007ooOol0031oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo025oo`03001o
o`0001]oo`03001oo`00031oo`002goo0P002goo00@007ooOomoo`8002=oo`8001]oo`80035oo`00
77oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03
001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Ao
o`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000
Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`80
00Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001o
ogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol0
01Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(480\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23177 L
.22 .23177 L
.224 .23177 L
.228 .23178 L
.232 .2318 L
.236 .23183 L
.24 .23188 L
.244 .23195 L
.248 .23208 L
.252 .23228 L
.256 .23258 L
.26 .23305 L
.264 .23374 L
.268 .23476 L
.272 .23622 L
.276 .23827 L
.28 .24108 L
.284 .24488 L
.288 .24987 L
.292 .25629 L
.296 .26434 L
.3 .27419 L
.304 .28592 L
.308 .29951 L
.312 .31477 L
.316 .33136 L
.32 .34874 L
.324 .36621 L
.328 .38291 L
.332 .39791 L
.336 .41026 L
.34 .41909 L
.344 .42372 L
.348 .42373 L
.352 .419 L
.356 .40978 L
.36 .39664 L
.364 .38042 L
.368 .36213 L
.372 .34288 L
.376 .32372 L
.38 .30559 L
.384 .28919 L
.388 .27499 L
.392 .2632 L
.396 .25382 L
.4 .24667 L
Mistroke
.404 .24144 L
.408 .23779 L
.412 .23535 L
.416 .2338 L
.42 .23287 L
.424 .23234 L
.428 .23205 L
.432 .23191 L
.436 .23185 L
.44 .23182 L
.444 .23182 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23182 L
.56 .23182 L
.564 .23185 L
.568 .23191 L
.572 .23205 L
.576 .23234 L
.58 .23287 L
.584 .2338 L
.588 .23535 L
.592 .23779 L
.596 .24144 L
.6 .24667 L
Mistroke
.604 .25382 L
.608 .2632 L
.612 .27499 L
.616 .28919 L
.62 .30559 L
.624 .32372 L
.628 .34288 L
.632 .36213 L
.636 .38042 L
.64 .39664 L
.644 .40978 L
.648 .419 L
.652 .42373 L
.656 .42372 L
.66 .41909 L
.664 .41026 L
.668 .39791 L
.672 .38291 L
.676 .36621 L
.68 .34874 L
.684 .33136 L
.688 .31477 L
.692 .29951 L
.696 .28592 L
.7 .27419 L
.704 .26434 L
.708 .25629 L
.712 .24987 L
.716 .24488 L
.72 .24108 L
.724 .23827 L
.728 .23622 L
.732 .23476 L
.736 .23374 L
.74 .23305 L
.744 .23258 L
.748 .23228 L
.752 .23208 L
.756 .23195 L
.76 .23188 L
.764 .23183 L
.768 .2318 L
.772 .23178 L
.776 .23177 L
.78 .23177 L
.784 .23177 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35315 L
.224 .35315 L
.228 .35314 L
.232 .35312 L
.236 .35308 L
.24 .35303 L
.244 .35293 L
.248 .35279 L
.252 .35255 L
.256 .35219 L
.26 .35163 L
.264 .35081 L
.268 .34959 L
.272 .34786 L
.276 .34542 L
.28 .34206 L
.284 .33754 L
.288 .33159 L
.292 .32395 L
.296 .31436 L
.3 .30262 L
.304 .28865 L
.308 .27246 L
.312 .25428 L
.316 .23452 L
.32 .21381 L
.324 .19301 L
.328 .17311 L
.332 .15525 L
.336 .14054 L
.34 .13002 L
.344 .12451 L
.348 .12451 L
.352 .13014 L
.356 .14113 L
.36 .15678 L
.364 .17612 L
.368 .19791 L
.372 .22084 L
.376 .24366 L
.38 .26527 L
.384 .28481 L
.388 .30173 L
.392 .31577 L
.396 .32694 L
.4 .33547 L
Mistroke
.404 .34169 L
.408 .34604 L
.412 .34895 L
.416 .35079 L
.42 .35191 L
.424 .35254 L
.428 .35288 L
.432 .35304 L
.436 .35312 L
.44 .35315 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35317 L
.564 .3532 L
.568 .35328 L
.572 .35345 L
.576 .35379 L
.58 .35442 L
.584 .35553 L
.588 .35738 L
.592 .36028 L
.596 .36463 L
.6 .37086 L
Mistroke
.604 .37938 L
.608 .39056 L
.612 .4046 L
.616 .42152 L
.62 .44106 L
.624 .46266 L
.628 .48548 L
.632 .50842 L
.636 .53021 L
.64 .54954 L
.644 .5652 L
.648 .57618 L
.652 .58182 L
.656 .58182 L
.66 .5763 L
.664 .56578 L
.668 .55108 L
.672 .53321 L
.676 .51332 L
.68 .49251 L
.684 .4718 L
.688 .45204 L
.692 .43386 L
.696 .41768 L
.7 .4037 L
.704 .39197 L
.708 .38238 L
.712 .37473 L
.716 .36879 L
.72 .36427 L
.724 .36091 L
.728 .35847 L
.732 .35673 L
.736 .35552 L
.74 .35469 L
.744 .35414 L
.748 .35377 L
.752 .35354 L
.756 .35339 L
.76 .3533 L
.764 .35324 L
.768 .35321 L
.772 .35319 L
.776 .35318 L
.78 .35317 L
.784 .35317 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23177 L
.22 .23177 L
.224 .23177 L
.228 .23178 L
.232 .2318 L
.236 .23183 L
.24 .23188 L
.244 .23195 L
.248 .23208 L
.252 .23228 L
.256 .23258 L
.26 .23305 L
.264 .23374 L
.268 .23476 L
.272 .23622 L
.276 .23827 L
.28 .24108 L
.284 .24488 L
.288 .24987 L
.292 .25629 L
.296 .26434 L
.3 .27419 L
.304 .28592 L
.308 .29951 L
.312 .31477 L
.316 .33136 L
.32 .34874 L
.324 .36621 L
.328 .38291 L
.332 .39791 L
.336 .41026 L
.34 .41909 L
.344 .42372 L
.348 .42373 L
.352 .419 L
.356 .40978 L
.36 .39664 L
.364 .38042 L
.368 .36213 L
.372 .34288 L
.376 .32372 L
.38 .30559 L
.384 .28919 L
.388 .27499 L
.392 .2632 L
.396 .25382 L
.4 .24667 L
Mistroke
.404 .24144 L
.408 .23779 L
.412 .23535 L
.416 .2338 L
.42 .23287 L
.424 .23234 L
.428 .23205 L
.432 .23191 L
.436 .23185 L
.44 .23182 L
.444 .23182 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23182 L
.56 .23182 L
.564 .23185 L
.568 .23191 L
.572 .23205 L
.576 .23234 L
.58 .23287 L
.584 .2338 L
.588 .23535 L
.592 .23779 L
.596 .24144 L
.6 .24667 L
Mistroke
.604 .25382 L
.608 .2632 L
.612 .27499 L
.616 .28919 L
.62 .30559 L
.624 .32372 L
.628 .34288 L
.632 .36213 L
.636 .38042 L
.64 .39664 L
.644 .40978 L
.648 .419 L
.652 .42373 L
.656 .42372 L
.66 .41909 L
.664 .41026 L
.668 .39791 L
.672 .38291 L
.676 .36621 L
.68 .34874 L
.684 .33136 L
.688 .31477 L
.692 .29951 L
.696 .28592 L
.7 .27419 L
.704 .26434 L
.708 .25629 L
.712 .24987 L
.716 .24488 L
.72 .24108 L
.724 .23827 L
.728 .23622 L
.732 .23476 L
.736 .23374 L
.74 .23305 L
.744 .23258 L
.748 .23228 L
.752 .23208 L
.756 .23195 L
.76 .23188 L
.764 .23183 L
.768 .2318 L
.772 .23178 L
.776 .23177 L
.78 .23177 L
.784 .23177 L
.788 .23176 L
.792 .23176 L
.796 .23176 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00002Ool20003Ool01@00Oomoogoo0000
17oo0P000Woo00D007ooOomoo`0000=oo`05001oogooOol00002Ool20003Ool01@00Oomoogoo0000
17oo0P000Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00<0
07ooOol02Woo000LOol2000LOol00`00Oomoo`09Ool00`00Oomoo`0AOol00`00Oomoo`09Ool00`00
Oomoo`0XOol001aoo`03001oogoo01]oo`03001oogoo00Qoo`03001oogoo01=oo`03001oogoo00Mo
o`03001oogoo02Uoo`0077oo0P007Goo00<007ooOol01goo00<007ooOol04goo00<007ooOol01goo
00<007ooOol0:Goo000LOol00`00Oomoo`0LOol00`00Oomoo`06Ool00`00Oomoo`0DOol00`00Oomo
o`07Ool00`00Oomoo`0YOol000]oo`8000Aoo`04001oogooOol50002Ool2000NOol00`00Oomoo`05
Ool00`00Oomoo`0EOol00`00Oomoo`05Ool00`00Oomoo`0ZOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00<007ooOol07Goo00<007ooOol01Goo00<007ooOol05Goo00<007ooOol01Goo00<0
07ooOol0:Woo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P007Woo00<007ooOol017oo00<0
07ooOol05Woo00<007ooOol01Goo00<007ooOol0:Woo000:Ool01000Oomoo`002Woo00D007ooOomo
o`0001moo`03001oogoo00Aoo`03001oogoo01Ioo`03001oogoo00Aoo`03001oogoo02]oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000NOol00`00Oomoo`04Ool00`00Oomoo`0GOol0
0`00Oomoo`03Ool00`00Oomoo`0[Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol07Woo00<007ooOol00goo00<007ooOol05goo00<007ooOol00goo00<007ooOol0:goo000;
Ool20009Ool30003Ool2000OOol00`00Oomoo`03Ool00`00Oomoo`0GOol00`00Oomoo`02Ool00`00
Oomoo`0/Ool001aoo`03001oogoo01ioo`03001oogoo00=oo`03001oogoo01Moo`03001oogoo009o
o`03001oogoo02aoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P0087oo00D007ooOomoo`00
01]oo`05001oogooOol0000^Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00008Goo00D007oo
Oomoo`0001]oo`05001oogooOol0000^Ool000Yoo`04001oogoo0007Ool50002Ool2000POol01@00
Oomoogoo00006goo00D007ooOomoo`0002ioo`002Woo00@007ooOol000Moo`04001oogoo0003Ool0
0`00Oomoo`0POol00`00Ool0000LOol01000Oomoo`00;goo000:Ool01000Oomoo`0027oo00<007oo
00000goo0P008Goo00<007oo000077oo00@007ooOol002moo`002Woo00@007ooOol000Uoo`8000=o
o`03001oogoo021oo`03001oo`0001eoo`03001oo`0002moo`002goo0P002goo00@007ooOomoo`80
025oo`<001eoo`80031oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003
Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol0
00Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00
Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003
Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo
000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1g
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<007Qoo`002Woo00@007ooOol0
00Moo`05001oogooOol0001gOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo
0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool2001cOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo10000goo0P00Lgoo000:Ool01000Oomo
o`001goo00<007ooOol017oo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007ooOol00goo
0P00Lgoo000;Ool2000:Ool20003Ool00`00Oomoo`0QOol00`00Oomoo`1>Ool001aoo`80025oo`03
001oo`0004moo`0077oo00<007ooOol087oo00<007oo0000Cgoo000;Ool20004Ool00`00Oomoo`03
Ool30002Ool2000QOol00`00Ool0001?Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00008Woo
00<007oo0000Cgoo0003Ool50002Ool01000Oomoo`001goo1@000Woo00<007ooOol07goo00@007oo
Ool004moo`002Woo00@007ooOol000Moo`04001oogoo0003Ool2000POol01@00Oomoogoo0000CWoo
000:Ool01000Oomoo`0027oo00<007oo00000goo00<007ooOol07goo00D007ooOomoo`0004ioo`00
2Woo00@007ooOol000Uoo`8000=oo`80021oo`05001oogooOol0001>Ool000]oo`8000]oo`05001o
ogooOol0000POol00`00Oomoo`02Ool00`00Oomoo`1<Ool001aoo`8001moo`03001oogoo00=oo`03
001oogoo04]oo`0077oo00<007ooOol07Woo00<007ooOol00goo00<007ooOol0Bgoo000;Ool20004
Ool01000Oomoogoo1@000Woo0P007goo00<007ooOol00goo00<007ooOol0Bgoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`03001oogoo01ioo`03001oogoo00=oo`03001oogoo04]oo`000goo
1@000Woo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo01eoo`03001oogoo00Aoo`03001o
ogoo04]oo`002Woo00@007ooOol000Yoo`04001oogooOol2000>Ool30004Ool20007Ool00`00Ool0
00020002Ool01000Ool0000017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P00
1Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo00aoo`05001oogooOol00002Ool01000Oomoo`001Woo00@007ooOol000=oo`80009oo`04001o
ogoo0002Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=o
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@0
07ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000A
Ool01000Oomoo`000Woo00<007ooOol017oo00@007ooOol000Aoo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`00
2goo0P002Goo0`000goo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Aoo`04001oogoo
0004Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Ao
o`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0005Ool01@00
Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol0
07oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol0
00Eoo`03001oogoo008000Aoo`800005Ool007ooOol00002Ool00`00Oomoo`02Ool20003Ool00`00
Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
17oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2
0005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P00
1Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000LOol00`00Oomoo`09
Ool00`00Oomoo`18Ool001aoo`03001oogoo01Uoo`8000aoo`8004Uoo`0077ooJ@0037oo000LOol0
0`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0@Ool2000<Ool00`00Oomoo`05Ool00`00Oomo
o`0BOol00`00Oomoo`0:Ool001aoo`8003aoo`03001oogoo00Uoo`03001oogoo02Qoo`0077oo00<0
07ooOol0?7oo00<007ooOol01goo00<007ooOol0:Goo000LOol2000mOol00`00Oomoo`07Ool00`00
Oomoo`0YOol001aoo`03001oogoo03aoo`03001oogoo00Moo`03001oogoo02Uoo`0077oo00<007oo
Ool0?7oo00<007ooOol01goo00<007ooOol0:Goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00
?Woo00<007ooOol01Goo00<007ooOol0:Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03
001oogoo03eoo`03001oogoo00Eoo`03001oogoo02Yoo`002Woo00@007ooOol000Uoo`03001oogoo
009oo`8003ioo`03001oogoo00Eoo`03001oogoo02Yoo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0000oOol00`00Oomoo`04Ool00`00Oomoo`0[Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00?goo00<007ooOol00goo00<007ooOol0:goo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo02]oo`002goo0P002Goo0`00
0goo00<007ooOol0?Woo00<007ooOol00goo00<007ooOol0:goo000LOol2000oOol00`00Oomoo`02
Ool00`00Oomoo`0/Ool001aoo`03001oogoo03ioo`03001oogoo009oo`03001oogoo02aoo`002goo
0P0017oo00<007ooOol00goo0`000Woo0P00@7oo00D007ooOomoo`0002ioo`002Woo00@007ooOol0
00Yoo`05001oogooOol00011Ool01@00Oomoogoo0000;Woo000:Ool01000Oomoo`001goo1@000Woo
0P00@7oo00D007ooOomoo`0002ioo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomo
o`0oOol01@00Oomoogoo0000;Woo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00@7oo00@0
07ooOol002moo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo03moo`04001oogoo000_Ool0
00]oo`8000]oo`05001oogooOol00012Ool00`00Ool0000_Ool001aoo`80045oo`80031oo`0077oo
00<007ooOol0@Goo00<007ooOol0;Woo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001c
Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo0003Ool50002Ool01000Oomoo`001goo
1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo
00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001o
ogoo079oo`002goo0P002goo00@007ooOomoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004
Ool01000Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001o
ogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=o
o`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Uoo`03001o
ogoo009oo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=o
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@0
07ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Yoo`05001oogooOol0000BOol01000
Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol037oo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]o
o`8000Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00@007ooOomoo`D000=oo`05001oogooOol00004Ool300000goo
001oo`02Ool01@00Oomoogoo00000goo00<007oo00000P000goo00D007ooOomoo`0000Aoo`D000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000L
Ool2000LOol00`00Oomoo`09Ool00`00Oomoo`0AOol00`00Oomoo`09Ool00`00Oomoo`0XOol001ao
o`03001oogoo01]oo`03001oogoo00Qoo`03001oogoo01=oo`03001oogoo00Moo`03001oogoo02Uo
o`0077oo0P007Goo00<007ooOol01goo00<007ooOol04goo00<007ooOol01goo00<007ooOol0:Goo
000LOol00`00Oomoo`0LOol00`00Oomoo`06Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomo
o`0YOol000]oo`8000Aoo`04001oogooOol50002Ool2000NOol00`00Oomoo`05Ool00`00Oomoo`0E
Ool00`00Oomoo`05Ool00`00Oomoo`0ZOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<0
07ooOol07Goo00<007ooOol01Goo00<007ooOol05Goo00<007ooOol01Goo00<007ooOol0:Woo000:
Ool01000Oomoo`002Goo00<007ooOol00Woo0P007Woo00<007ooOol017oo00<007ooOol05Woo00<0
07ooOol01Goo00<007ooOol0:Woo000:Ool01000Oomoo`002Woo00D007ooOomoo`0001moo`03001o
ogoo00Aoo`03001oogoo01Ioo`03001oogoo00Aoo`03001oogoo02]oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2000NOol00`00Oomoo`04Ool00`00Oomoo`0GOol00`00Oomoo`03Ool0
0`00Oomoo`0[Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol07Woo00<0
07ooOol00goo00<007ooOol05goo00<007ooOol00goo00<007ooOol0:goo000;Ool20009Ool30003
Ool2000OOol00`00Oomoo`03Ool00`00Oomoo`0GOol00`00Oomoo`03Ool00`00Oomoo`0[Ool001ao
o`03001oogoo01ioo`03001oogoo00=oo`03001oogoo01Moo`03001oogoo009oo`03001oogoo02ao
o`002goo0P0017oo00<007ooOol00goo0`000Woo0P0087oo00D007ooOomoo`0001]oo`05001oogoo
Ool0000^Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00008Goo00D007ooOomoo`0001]oo`05
001oogooOol0000^Ool000Yoo`04001oogoo0007Ool50002Ool2000POol01@00Oomoogoo00006goo
00D007ooOomoo`0002ioo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0OOol0
1000Oomoo`0077oo00D007ooOomoo`0002ioo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`80
025oo`03001oo`0001aoo`04001oogoo000_Ool000Yoo`04001oogoo0009Ool20003Ool00`00Oomo
o`0POol00`00Ool0000MOol00`00Ool0000_Ool000]oo`8000]oo`04001oogooOol2000QOol3000M
Ool2000`Ool001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00
Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo
000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=o
o`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo
000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<0
07ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(520\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23178 L
.216 .23179 L
.22 .2318 L
.224 .23183 L
.228 .23188 L
.232 .23196 L
.236 .23209 L
.24 .2323 L
.244 .23261 L
.248 .23308 L
.252 .23379 L
.256 .23482 L
.26 .23629 L
.264 .23835 L
.268 .24118 L
.272 .24498 L
.276 .24997 L
.28 .25637 L
.284 .26439 L
.288 .27419 L
.292 .28585 L
.296 .29935 L
.3 .31452 L
.304 .33102 L
.308 .34832 L
.312 .36572 L
.316 .3824 L
.32 .39741 L
.324 .40983 L
.328 .41877 L
.332 .42356 L
.336 .42374 L
.34 .4192 L
.344 .41014 L
.348 .39713 L
.352 .38098 L
.356 .36271 L
.36 .34342 L
.364 .32418 L
.368 .30593 L
.372 .2894 L
.376 .27507 L
.38 .26317 L
.384 .25372 L
.388 .24651 L
.392 .24127 L
.396 .23762 L
.4 .2352 L
Mistroke
.404 .23368 L
.408 .23278 L
.412 .23227 L
.416 .23201 L
.42 .23189 L
.424 .23184 L
.428 .23182 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23182 L
.576 .23184 L
.58 .23189 L
.584 .23201 L
.588 .23227 L
.592 .23278 L
.596 .23368 L
.6 .2352 L
Mistroke
.604 .23762 L
.608 .24127 L
.612 .24651 L
.616 .25372 L
.62 .26317 L
.624 .27507 L
.628 .2894 L
.632 .30593 L
.636 .32418 L
.64 .34342 L
.644 .36271 L
.648 .38098 L
.652 .39713 L
.656 .41014 L
.66 .4192 L
.664 .42374 L
.668 .42356 L
.672 .41877 L
.676 .40983 L
.68 .39741 L
.684 .3824 L
.688 .36572 L
.692 .34832 L
.696 .33102 L
.7 .31452 L
.704 .29935 L
.708 .28585 L
.712 .27419 L
.716 .26439 L
.72 .25637 L
.724 .24997 L
.728 .24498 L
.732 .24118 L
.736 .23835 L
.74 .23629 L
.744 .23482 L
.748 .23379 L
.752 .23308 L
.756 .23261 L
.76 .2323 L
.764 .23209 L
.768 .23196 L
.772 .23188 L
.776 .23183 L
.78 .2318 L
.784 .23179 L
.788 .23178 L
.792 .23177 L
.796 .23177 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35315 L
.212 .35315 L
.216 .35313 L
.22 .35311 L
.224 .35308 L
.228 .35302 L
.232 .35292 L
.236 .35277 L
.24 .35253 L
.244 .35215 L
.248 .35159 L
.252 .35075 L
.256 .34952 L
.26 .34777 L
.264 .34531 L
.268 .34194 L
.272 .33742 L
.276 .33148 L
.28 .32385 L
.284 .3143 L
.288 .30263 L
.292 .28873 L
.296 .27265 L
.3 .25458 L
.304 .23493 L
.308 .21432 L
.312 .19359 L
.316 .17373 L
.32 .15584 L
.324 .14106 L
.328 .1304 L
.332 .1247 L
.336 .12449 L
.34 .12991 L
.344 .1407 L
.348 .1562 L
.352 .17545 L
.356 .19721 L
.36 .22019 L
.364 .24312 L
.368 .26486 L
.372 .28456 L
.376 .30163 L
.38 .3158 L
.384 .32707 L
.388 .33565 L
.392 .3419 L
.396 .34625 L
.4 .34913 L
Mistroke
.404 .35094 L
.408 .35201 L
.412 .35261 L
.416 .35293 L
.42 .35307 L
.424 .35314 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35317 L
.576 .35319 L
.58 .35325 L
.584 .3534 L
.588 .35371 L
.592 .35431 L
.596 .35539 L
.6 .3572 L
Mistroke
.604 .36008 L
.608 .36443 L
.612 .37068 L
.616 .37926 L
.62 .39052 L
.624 .40469 L
.628 .42176 L
.632 .44146 L
.636 .46321 L
.64 .48613 L
.644 .50911 L
.648 .53088 L
.652 .55012 L
.656 .56563 L
.66 .57642 L
.664 .58183 L
.668 .58162 L
.672 .57592 L
.676 .56527 L
.68 .55048 L
.684 .5326 L
.688 .51274 L
.692 .492 L
.696 .47139 L
.7 .45175 L
.704 .43368 L
.708 .41759 L
.712 .4037 L
.716 .39202 L
.72 .38247 L
.724 .37485 L
.728 .36891 L
.732 .36438 L
.736 .36101 L
.74 .35856 L
.744 .3568 L
.748 .35558 L
.752 .35474 L
.756 .35417 L
.76 .3538 L
.764 .35356 L
.768 .3534 L
.772 .35331 L
.776 .35325 L
.78 .35321 L
.784 .35319 L
.788 .35318 L
.792 .35317 L
.796 .35317 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23178 L
.216 .23179 L
.22 .2318 L
.224 .23183 L
.228 .23188 L
.232 .23196 L
.236 .23209 L
.24 .2323 L
.244 .23261 L
.248 .23308 L
.252 .23379 L
.256 .23482 L
.26 .23629 L
.264 .23835 L
.268 .24118 L
.272 .24498 L
.276 .24997 L
.28 .25637 L
.284 .26439 L
.288 .27419 L
.292 .28585 L
.296 .29935 L
.3 .31452 L
.304 .33102 L
.308 .34832 L
.312 .36572 L
.316 .3824 L
.32 .39741 L
.324 .40983 L
.328 .41877 L
.332 .42356 L
.336 .42374 L
.34 .4192 L
.344 .41014 L
.348 .39713 L
.352 .38098 L
.356 .36271 L
.36 .34342 L
.364 .32418 L
.368 .30593 L
.372 .2894 L
.376 .27507 L
.38 .26317 L
.384 .25372 L
.388 .24651 L
.392 .24127 L
.396 .23762 L
.4 .2352 L
Mistroke
.404 .23368 L
.408 .23278 L
.412 .23227 L
.416 .23201 L
.42 .23189 L
.424 .23184 L
.428 .23182 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23182 L
.576 .23184 L
.58 .23189 L
.584 .23201 L
.588 .23227 L
.592 .23278 L
.596 .23368 L
.6 .2352 L
Mistroke
.604 .23762 L
.608 .24127 L
.612 .24651 L
.616 .25372 L
.62 .26317 L
.624 .27507 L
.628 .2894 L
.632 .30593 L
.636 .32418 L
.64 .34342 L
.644 .36271 L
.648 .38098 L
.652 .39713 L
.656 .41014 L
.66 .4192 L
.664 .42374 L
.668 .42356 L
.672 .41877 L
.676 .40983 L
.68 .39741 L
.684 .3824 L
.688 .36572 L
.692 .34832 L
.696 .33102 L
.7 .31452 L
.704 .29935 L
.708 .28585 L
.712 .27419 L
.716 .26439 L
.72 .25637 L
.724 .24997 L
.728 .24498 L
.732 .24118 L
.736 .23835 L
.74 .23629 L
.744 .23482 L
.748 .23379 L
.752 .23308 L
.756 .23261 L
.76 .2323 L
.764 .23209 L
.768 .23196 L
.772 .23188 L
.776 .23183 L
.78 .2318 L
.784 .23179 L
.788 .23178 L
.792 .23177 L
.796 .23177 L
.8 .23176 L
Mistroke
.804 .23176 L
.808 .23176 L
.812 .23176 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`06001oogooOol007oo0`000goo00D007ooOomoo`0000=o
o`8000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo0P000Woo00D007ooOomoo`0000Ao
o`<00003Ool007oo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo
00<007ooOol02Woo000LOol2000JOol2000:Ool00`00Oomoo`0DOol00`00Oomoo`09Ool00`00Oomo
o`0WOol001aoo`03001oogoo01Yoo`03001oogoo00Qoo`03001oogoo01Eoo`03001oogoo00Qoo`03
001oogoo02Moo`0077oo0P0077oo00<007ooOol01Woo00<007ooOol05Woo00<007ooOol01goo00<0
07ooOol0:7oo000LOol00`00Oomoo`0KOol00`00Oomoo`06Ool00`00Oomoo`0GOol00`00Oomoo`06
Ool00`00Oomoo`0XOol000]oo`8000Aoo`04001oogooOol50002Ool2000LOol00`00Oomoo`06Ool0
0`00Oomoo`0GOol00`00Oomoo`05Ool00`00Oomoo`0YOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00<007ooOol077oo00<007ooOol01Goo00<007ooOol05goo00<007ooOol01Goo00<007oo
Ool0:Goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P007Goo00<007ooOol017oo00<007oo
Ool06Goo00<007ooOol017oo00<007ooOol0:Goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00
01ioo`03001oogoo00Aoo`03001oogoo01Uoo`03001oogoo00Aoo`03001oogoo02Uoo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2000MOol00`00Oomoo`04Ool00`00Oomoo`0IOol00`00
Oomoo`04Ool00`00Oomoo`0YOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool07Goo00<007ooOol00goo00<007ooOol06Goo00<007ooOol00goo00<007ooOol0:Woo000;Ool2
0009Ool30003Ool2000NOol00`00Oomoo`02Ool00`00Oomoo`0JOol00`00Oomoo`03Ool00`00Oomo
o`0ZOol001aoo`03001oogoo01eoo`03001oogoo009oo`03001oogoo01Yoo`03001oogoo00=oo`03
001oogoo02Yoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P007Woo00<007ooOol00Woo00<0
07ooOol06goo00D007ooOomoo`0002eoo`002Woo00@007ooOol000Yoo`05001oogooOol0000OOol0
0`00Oomoo`02Ool00`00Oomoo`0KOol01@00Oomoogoo0000;Goo000:Ool01000Oomoo`001goo1@00
0Woo0P007goo00D007ooOomoo`0001eoo`05001oogooOol0000]Ool000Yoo`04001oogoo0007Ool0
1000Oomoo`000goo00<007ooOol07Woo00@007ooOol001moo`03001oo`0002ioo`002Woo00@007oo
Ool000Qoo`03001oo`0000=oo`8001moo`04001oogoo000OOol00`00Ool0000^Ool000Yoo`04001o
ogoo0009Ool20003Ool00`00Oomoo`0OOol00`00Ool0000OOol00`00Ool0000^Ool000]oo`8000]o
o`04001oogooOol2000POol2000POol3000^Ool001aoo`03001oogoo079oo`002goo0P0017oo00<0
07ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo
0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol0
00Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`80
07=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo
079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001o
ogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`00
5goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3001hOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P00Lgoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`@000=oo`8007=o
o`002Woo00@007ooOol000Moo`03001oogoo00Aoo`03001oogoo079oo`002Woo00@007ooOol000Qo
o`03001oogoo00=oo`8007=oo`002goo0P002Woo0P000goo00<007ooOol087oo00<007ooOol0Cgoo
000LOol2000POol2001AOol001aoo`03001oogoo01moo`03001oo`00051oo`002goo0P0017oo00<0
07ooOol00goo0`000Woo0P0087oo00<007oo0000D7oo000:Ool01000Oomoo`002Woo00D007ooOomo
o`00021oo`04001oogoo001@Ool000=oo`D0009oo`04001oogoo0007Ool50002Ool00`00Oomoo`0N
Ool01000Oomoo`00D7oo000:Ool01000Oomoo`001goo00@007ooOol000=oo`8001moo`05001oogoo
Ool0001?Ool000Yoo`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`0MOol00`00Oomoo`02
Ool00`00Oomoo`1=Ool000Yoo`04001oogoo0009Ool20003Ool2000NOol00`00Oomoo`02Ool00`00
Oomoo`1=Ool000]oo`8000]oo`05001oogooOol0000OOol00`00Oomoo`02Ool00`00Oomoo`1=Ool0
01aoo`8001ioo`03001oogoo009oo`03001oogoo04eoo`0077oo00<007ooOol07Goo00<007ooOol0
0Woo00<007ooOol0CGoo000;Ool20004Ool01000Oomoogoo1@000Woo0P007Woo00<007ooOol00goo
00<007ooOol0C7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo01eoo`03001o
ogoo00=oo`03001oogoo04aoo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`03001o
ogoo01aoo`03001oogoo00Aoo`03001oogoo04aoo`002Woo00@007ooOol000Yoo`04001oogooOol2
000>Ool30004Ool20006Ool00`00Oomoo`03000017oo001oogoo0P0017oo0P001Goo0`000goo0`00
17oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo00aoo`05001oogooOol00002Ool01000Oomoo`001Goo
00D007ooOomoo`00009oo`03001oo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool01@00Oomo
ogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol00Woo
00<007ooOol00Woo00@007ooOomoo`80009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool20009Ool30003
Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOomo
o`80009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`0017oo00<0
07ooOol00Woo00@007ooOomoo`80009oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoogoo
10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Ao
o`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol0
17oo00@007ooOol000Aoo`04001oogooOol20003Ool20002Ool01000Oomoo`000Woo00<007ooOol0
0Woo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007oo
Ool037oo1@000goo0P0017oo00<007ooOol00goo00<007ooOol00Woo0`0017oo0P001Woo00@007oo
Oomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00
6Woo0P002Woo00<007ooOol0BWoo000LOol00`00Oomoo`0HOol2000<Ool2001:Ool001aoofT000ao
o`0077oo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Goo0P0037oo00<007ooOol017oo
00<007ooOol04Woo00<007ooOol02Woo000LOol2000mOol00`00Oomoo`09Ool00`00Oomoo`0WOol0
01aoo`03001oogoo03eoo`03001oogoo00Qoo`03001oogoo02Moo`0077oo0P00?Woo00<007ooOol0
1goo00<007ooOol0:7oo000LOol00`00Oomoo`0nOol00`00Oomoo`06Ool00`00Oomoo`0XOol001ao
o`03001oogoo03ioo`03001oogoo00Ioo`03001oogoo02Qoo`002goo0P0017oo00@007ooOomoo`D0
009oo`8003moo`03001oogoo00Eoo`03001oogoo02Uoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool00`00Oomoo`0nOol00`00Oomoo`05Ool00`00Oomoo`0YOol000Yoo`04001oogoo0009Ool0
0`00Oomoo`02Ool20010Ool00`00Oomoo`04Ool00`00Oomoo`0YOol000Yoo`04001oogoo000:Ool0
1@00Oomoogoo0000@Goo00<007ooOol017oo00<007ooOol0:Goo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`80041oo`03001oogoo00Aoo`03001oogoo02Uoo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`0oOol00`00Oomoo`03Ool00`00Oomoo`0ZOol000]oo`80
00Uoo`<000=oo`03001oogoo03moo`03001oogoo00=oo`03001oogoo02Yoo`0077oo0P00@7oo00<0
07ooOol00goo00<007ooOol0:Woo000LOol00`00Oomoo`0oOol00`00Oomoo`03Ool00`00Oomoo`0Z
Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`80045oo`05001oogooOol0000]Ool000Yoo`04
001oogoo000:Ool01@00Oomoogoo0000@Woo00D007ooOomoo`0002eoo`002Woo00@007ooOol000Mo
o`D0009oo`80045oo`05001oogooOol0000]Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo
00<007ooOol0@7oo00D007ooOomoo`0002eoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`80
049oo`03001oo`0002ioo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo045oo`03001oo`00
02ioo`002goo0P002goo00D007ooOomoo`0004=oo`03001oo`0002ioo`0077oo0P00@Woo00<007oo
0000;Woo000LOol00`00Oomoo`12Ool00`00Oomoo`0]Ool001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=o
o`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000=oo`D0009oo`04
001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo
0P000goo00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1b
Ool000]oo`8000Aoo`04001oogooOol50002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo
0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomo
o`002Goo00<007ooOol00Woo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo
00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol0
07oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`002Woo00D007ooOomo
o`00019oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo00@007ooOol0009oo`03001o
ogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007oo
Ool000Eoo`002goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`8000Ao
o`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo
00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P0017oo
0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`80
00Ioo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomoo`00
00=oo`03001oogoo009oo`05001oogooOol00003Ool01000Oomoogoo1@000goo00D007ooOomoo`00
00=oo`<0009oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo0`000Woo00D007ooOomoo`00
00Aoo`D000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007oo
Ool02Woo000LOol2000JOol2000:Ool00`00Oomoo`0DOol00`00Oomoo`09Ool00`00Oomoo`0WOol0
01aoo`03001oogoo01Yoo`03001oogoo00Qoo`03001oogoo01Eoo`03001oogoo00Qoo`03001oogoo
02Moo`0077oo0P0077oo00<007ooOol01Woo00<007ooOol05Woo00<007ooOol01goo00<007ooOol0
:7oo000LOol00`00Oomoo`0KOol00`00Oomoo`06Ool00`00Oomoo`0GOol00`00Oomoo`06Ool00`00
Oomoo`0XOol000]oo`8000Aoo`04001oogooOol50002Ool2000LOol00`00Oomoo`06Ool00`00Oomo
o`0GOol00`00Oomoo`05Ool00`00Oomoo`0YOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00<007ooOol077oo00<007ooOol01Goo00<007ooOol05goo00<007ooOol01Goo00<007ooOol0:Goo
000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P007Goo00<007ooOol017oo00<007ooOol06Goo
00<007ooOol017oo00<007ooOol0:Goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0001ioo`03
001oogoo00Aoo`03001oogoo01Uoo`03001oogoo00Aoo`03001oogoo02Uoo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2000MOol00`00Oomoo`04Ool00`00Oomoo`0IOol00`00Oomoo`04
Ool00`00Oomoo`0YOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol07Goo
00<007ooOol00goo00<007ooOol06Goo00<007ooOol00goo00<007ooOol0:Woo000;Ool20009Ool3
0003Ool2000NOol00`00Oomoo`02Ool00`00Oomoo`0JOol00`00Oomoo`03Ool00`00Oomoo`0ZOol0
01aoo`03001oogoo01eoo`03001oogoo009oo`03001oogoo01Yoo`03001oogoo00=oo`03001oogoo
02Yoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P007Woo00<007ooOol00Woo00<007ooOol0
6goo00D007ooOomoo`0002eoo`002Woo00@007ooOol000Yoo`05001oogooOol0000OOol00`00Oomo
o`02Ool00`00Oomoo`0KOol01@00Oomoogoo0000;Goo000:Ool01000Oomoo`001goo1@000Woo0P00
7goo00D007ooOomoo`0001eoo`05001oogooOol0000]Ool000Yoo`04001oogoo0007Ool01000Oomo
o`000goo00<007ooOol07Woo00D007ooOomoo`0001eoo`05001oogooOol0000]Ool000Yoo`04001o
ogoo0008Ool00`00Ool00003Ool2000OOol01000Oomoo`007goo00<007oo0000;Woo000:Ool01000
Oomoo`002Goo0P000goo00<007ooOol07goo00<007oo00007goo00<007oo0000;Woo000;Ool2000;
Ool01000Oomoogoo0P0087oo0P0087oo0`00;Woo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03
001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo
000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2
001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomo
o`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00
Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol0
01Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(560\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23178 L
Mistroke
.204 .23179 L
.208 .23181 L
.212 .23184 L
.216 .23189 L
.22 .23197 L
.224 .23211 L
.228 .23232 L
.232 .23264 L
.236 .23312 L
.24 .23384 L
.244 .23488 L
.248 .23637 L
.252 .23844 L
.256 .24128 L
.26 .24508 L
.264 .25006 L
.268 .25645 L
.272 .26443 L
.276 .27418 L
.28 .28578 L
.284 .2992 L
.288 .31428 L
.292 .33068 L
.296 .34789 L
.3 .36524 L
.304 .38189 L
.308 .39692 L
.312 .40939 L
.316 .41845 L
.32 .42339 L
.324 .42374 L
.328 .41938 L
.332 .41049 L
.336 .39761 L
.34 .38154 L
.344 .3633 L
.348 .34397 L
.352 .32465 L
.356 .30628 L
.36 .28961 L
.364 .27516 L
.368 .26315 L
.372 .25361 L
.376 .24636 L
.38 .24109 L
.384 .23744 L
.388 .23505 L
.392 .23356 L
.396 .23268 L
.4 .23221 L
Mistroke
.404 .23197 L
.408 .23186 L
.412 .23182 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23182 L
.592 .23186 L
.596 .23197 L
.6 .23221 L
Mistroke
.604 .23268 L
.608 .23356 L
.612 .23505 L
.616 .23744 L
.62 .24109 L
.624 .24636 L
.628 .25361 L
.632 .26315 L
.636 .27516 L
.64 .28961 L
.644 .30628 L
.648 .32465 L
.652 .34397 L
.656 .3633 L
.66 .38154 L
.664 .39761 L
.668 .41049 L
.672 .41938 L
.676 .42374 L
.68 .42339 L
.684 .41845 L
.688 .40939 L
.692 .39692 L
.696 .38189 L
.7 .36524 L
.704 .34789 L
.708 .33068 L
.712 .31428 L
.716 .2992 L
.72 .28578 L
.724 .27418 L
.728 .26443 L
.732 .25645 L
.736 .25006 L
.74 .24508 L
.744 .24128 L
.748 .23844 L
.752 .23637 L
.756 .23488 L
.76 .23384 L
.764 .23312 L
.768 .23264 L
.772 .23232 L
.776 .23211 L
.78 .23197 L
.784 .23189 L
.788 .23184 L
.792 .23181 L
.796 .23179 L
.8 .23178 L
Mistroke
.804 .23177 L
.808 .23177 L
.812 .23177 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35315 L
.2 .35315 L
Mistroke
.204 .35313 L
.208 .35311 L
.212 .35307 L
.216 .35301 L
.22 .35291 L
.224 .35275 L
.228 .3525 L
.232 .35212 L
.236 .35154 L
.24 .35069 L
.244 .34945 L
.248 .34768 L
.252 .34521 L
.256 .34182 L
.26 .3373 L
.264 .33136 L
.268 .32376 L
.272 .31424 L
.276 .30263 L
.28 .28882 L
.284 .27283 L
.288 .25487 L
.292 .23533 L
.296 .21482 L
.3 .19416 L
.304 .17433 L
.308 .15643 L
.312 .14157 L
.316 .13079 L
.32 .12491 L
.324 .12449 L
.328 .12969 L
.332 .14028 L
.336 .15563 L
.34 .17478 L
.344 .19652 L
.348 .21954 L
.352 .24256 L
.356 .26445 L
.36 .2843 L
.364 .30153 L
.368 .31583 L
.372 .32719 L
.376 .33584 L
.38 .34211 L
.384 .34645 L
.388 .34931 L
.392 .35109 L
.396 .35213 L
.4 .35269 L
Mistroke
.404 .35298 L
.408 .3531 L
.412 .35315 L
.416 .35317 L
.42 .35317 L
.424 .35317 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35317 L
.592 .35322 L
.596 .35335 L
.6 .35363 L
Mistroke
.604 .3542 L
.608 .35524 L
.612 .35701 L
.616 .35987 L
.62 .36421 L
.624 .37049 L
.628 .37913 L
.632 .3905 L
.636 .4048 L
.64 .42202 L
.644 .44188 L
.648 .46376 L
.652 .48678 L
.656 .50981 L
.66 .53155 L
.664 .55069 L
.668 .56604 L
.672 .57664 L
.676 .58184 L
.68 .58141 L
.684 .57554 L
.688 .56475 L
.692 .54989 L
.696 .53199 L
.7 .51216 L
.704 .4915 L
.708 .47099 L
.712 .45146 L
.716 .4335 L
.72 .41751 L
.724 .40369 L
.728 .39208 L
.732 .38257 L
.736 .37496 L
.74 .36903 L
.744 .3645 L
.748 .36112 L
.752 .35865 L
.756 .35688 L
.76 .35564 L
.764 .35478 L
.768 .3542 L
.772 .35382 L
.776 .35357 L
.78 .35341 L
.784 .35331 L
.788 .35325 L
.792 .35321 L
.796 .35319 L
.8 .35318 L
Mistroke
.804 .35317 L
.808 .35317 L
.812 .35317 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23178 L
Mistroke
.204 .23179 L
.208 .23181 L
.212 .23184 L
.216 .23189 L
.22 .23197 L
.224 .23211 L
.228 .23232 L
.232 .23264 L
.236 .23312 L
.24 .23384 L
.244 .23488 L
.248 .23637 L
.252 .23844 L
.256 .24128 L
.26 .24508 L
.264 .25006 L
.268 .25645 L
.272 .26443 L
.276 .27418 L
.28 .28578 L
.284 .2992 L
.288 .31428 L
.292 .33068 L
.296 .34789 L
.3 .36524 L
.304 .38189 L
.308 .39692 L
.312 .40939 L
.316 .41845 L
.32 .42339 L
.324 .42374 L
.328 .41938 L
.332 .41049 L
.336 .39761 L
.34 .38154 L
.344 .3633 L
.348 .34397 L
.352 .32465 L
.356 .30628 L
.36 .28961 L
.364 .27516 L
.368 .26315 L
.372 .25361 L
.376 .24636 L
.38 .24109 L
.384 .23744 L
.388 .23505 L
.392 .23356 L
.396 .23268 L
.4 .23221 L
Mistroke
.404 .23197 L
.408 .23186 L
.412 .23182 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23182 L
.592 .23186 L
.596 .23197 L
.6 .23221 L
Mistroke
.604 .23268 L
.608 .23356 L
.612 .23505 L
.616 .23744 L
.62 .24109 L
.624 .24636 L
.628 .25361 L
.632 .26315 L
.636 .27516 L
.64 .28961 L
.644 .30628 L
.648 .32465 L
.652 .34397 L
.656 .3633 L
.66 .38154 L
.664 .39761 L
.668 .41049 L
.672 .41938 L
.676 .42374 L
.68 .42339 L
.684 .41845 L
.688 .40939 L
.692 .39692 L
.696 .38189 L
.7 .36524 L
.704 .34789 L
.708 .33068 L
.712 .31428 L
.716 .2992 L
.72 .28578 L
.724 .27418 L
.728 .26443 L
.732 .25645 L
.736 .25006 L
.74 .24508 L
.744 .24128 L
.748 .23844 L
.752 .23637 L
.756 .23488 L
.76 .23384 L
.764 .23312 L
.768 .23264 L
.772 .23232 L
.776 .23211 L
.78 .23197 L
.784 .23189 L
.788 .23184 L
.792 .23181 L
.796 .23179 L
.8 .23178 L
Mistroke
.804 .23177 L
.808 .23177 L
.812 .23177 L
.816 .23176 L
.82 .23176 L
.824 .23176 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`04001oogooOol300000goo001oo`02Ool01P00Oomoogoo
001oo`800003Ool007oo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo0`0000=oo`00
Ool00Woo00<007ooOol00Woo00<007oo00000P000goo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`8001Uoo`8000Yoo`03001oogoo01Moo`03
001oogoo00Qoo`8002Moo`0077oo00<007ooOol06Goo00<007ooOol027oo00<007ooOol05goo00<0
07ooOol027oo00<007ooOol09Woo000LOol2000JOol00`00Oomoo`07Ool00`00Oomoo`0IOol00`00
Oomoo`06Ool00`00Oomoo`0WOol001aoo`03001oogoo01Yoo`03001oogoo00Ioo`03001oogoo01Uo
o`03001oogoo00Ioo`03001oogoo02Moo`002goo0P0017oo00@007ooOomoo`D0009oo`8001]oo`03
001oogoo00Eoo`03001oogoo01Yoo`03001oogoo00Ioo`03001oogoo02Moo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool00`00Oomoo`0KOol00`00Oomoo`04Ool00`00Oomoo`0JOol00`00Oomo
o`05Ool00`00Oomoo`0XOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000LOol00`00Oomo
o`04Ool00`00Oomoo`0KOol00`00Oomoo`04Ool00`00Oomoo`0XOol000Yoo`04001oogoo000:Ool0
1@00Oomoogoo00007Goo00<007ooOol017oo00<007ooOol06goo00<007ooOol017oo00<007ooOol0
:7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8001aoo`03001oogoo00Aoo`03001o
ogoo01]oo`03001oogoo00=oo`03001oogoo02Uoo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`0KOol00`00Oomoo`04Ool00`00Oomoo`0KOol00`00Oomoo`03Ool00`00Oomo
o`0YOol000]oo`8000Uoo`<000=oo`8001eoo`03001oogoo009oo`03001oogoo01eoo`03001oogoo
009oo`03001oogoo02Uoo`0077oo00<007ooOol077oo00<007ooOol00Woo00<007ooOol07Goo00<0
07ooOol00Woo00<007ooOol0:Goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000MOol00`00
Oomoo`02Ool00`00Oomoo`0MOol00`00Oomoo`02Ool00`00Oomoo`0YOol000Yoo`04001oogoo000:
Ool01@00Oomoogoo00007Woo00<007ooOol00Woo00<007ooOol07Goo00<007ooOol00Woo00<007oo
Ool0:Goo000:Ool01000Oomoo`001goo1@000Woo0P007Woo00@007ooOol0021oo`05001oogooOol0
000/Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol07Goo00@007ooOol0025o
o`04001oogoo000/Ool000Yoo`04001oogoo0008Ool00`00Ool00003Ool2000NOol01000Oomoo`00
8Goo00@007ooOol002aoo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo01eoo`04001oogoo
000QOol00`00Ool0000]Ool000]oo`8000]oo`04001oogooOol2000OOol2000SOol2000]Ool001ao
o`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00
Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool0
0`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007oo
Ool000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2
001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009
Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomo
o`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000G
Ool00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;
Ool20004Ool00`00Oomoo`02Ool3001hOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000Mgoo
0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol0
00Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000;Ool20009Ool3
0003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00
Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`@000=oo`8007=oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`03
001oogoo079oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`8007=oo`002goo0P002Woo0P00
0goo00<007ooOol07Woo0P00DWoo000LOol2000OOol2001BOol001aoo`03001oogoo01eoo`04001o
ogoo001AOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8001ioo`04001oogoo001AOol000Yo
o`04001oogoo000:Ool01@00Oomoogoo00007goo00@007ooOol0055oo`000goo1@000Woo00@007oo
Ool000Moo`D0009oo`03001oogoo01eoo`04001oogoo001AOol000Yoo`04001oogoo0007Ool01000
Oomoo`000goo0P007Woo00@007ooOol0055oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`03
001oogoo01aoo`03001oogoo009oo`03001oogoo04ioo`002Woo00@007ooOol000Uoo`8000=oo`80
01eoo`03001oogoo009oo`03001oogoo04ioo`002goo0P002goo00D007ooOomoo`0001ioo`03001o
ogoo009oo`03001oogoo04ioo`0077oo0P007Goo00<007ooOol00Woo00<007ooOol0CWoo000LOol0
0`00Oomoo`0LOol00`00Oomoo`02Ool00`00Oomoo`1>Ool000]oo`8000Aoo`04001oogooOol50002
Ool2000LOol00`00Oomoo`04Ool00`00Oomoo`1=Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00<007ooOol06goo00<007ooOol017oo00<007ooOol0CGoo0003Ool50002Ool01000Oomoo`00
2Goo00<007ooOol00Woo00<007ooOol06goo00<007ooOol017oo00<007ooOol0CGoo000:Ool01000
Oomoo`002Woo00@007ooOomoo`8000ioo`<000Aoo`8000Eoo`04001oogooOol40003Ool20004Ool2
0005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo00D007ooOomoo`00009o
o`04001oogoo0004Ool00`00Oomoo`02Ool00`00Ool00002Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007oo
Ool00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04001oogoo0002Ool0
1@00Oomoogoo00001Goo00<007oo00000Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool20009Ool30003
Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00D007ooOomoo`0000Eoo`03001oo`00009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0
009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000=oo`03001oogoo00=oo`06
001oogoo001oo`000Woo00@007ooOol0009oo`03001oogoo00=oo`04001oogooOol40003Ool01000
Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomo
o`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomo
o`000Woo00<007ooOol00goo0P000Woo00<007oo00000Woo00@007ooOol0009oo`03001oogoo009o
o`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo
00aoo`D000=oo`8000=oo`03001oogoo00Aoo`06001oogooOol007oo0P0017oo0P001Woo00@007oo
Oomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00
6Goo0P002Woo00<007ooOol0Bgoo000LOol00`00Oomoo`0GOol2000;Ool2001<Ool001aoofT000ao
o`0077oo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Goo00<007oo000037oo0P0017oo
00<007ooOol04Woo00<007ooOol02Woo000LOol2000oOol00`00Oomoo`08Ool2000WOol001aoo`03
001oogoo03ioo`03001oogoo00Qoo`03001oogoo02Ioo`0077oo0P00@7oo00<007ooOol01Woo00<0
07ooOol09goo000LOol00`00Oomoo`0oOol00`00Oomoo`06Ool00`00Oomoo`0WOol001aoo`03001o
ogoo03moo`03001oogoo00Ioo`03001oogoo02Moo`002goo0P0017oo00@007ooOomoo`D0009oo`80
041oo`03001oogoo00Ioo`03001oogoo02Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0oOol00`00Oomoo`05Ool00`00Oomoo`0XOol000Yoo`04001oogoo0009Ool00`00Oomo
o`02Ool20011Ool00`00Oomoo`04Ool00`00Oomoo`0XOol000Yoo`04001oogoo000:Ool01@00Oomo
ogoo0000@Woo00<007ooOol017oo00<007ooOol0:7oo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`80045oo`03001oogoo00Aoo`03001oogoo02Qoo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`10Ool00`00Oomoo`03Ool00`00Oomoo`0YOol000]oo`8000Uoo`<0
00=oo`03001oogoo045oo`03001oogoo009oo`03001oogoo02Uoo`0077oo0P00@Woo00<007ooOol0
0Woo00<007ooOol0:Goo000LOol00`00Oomoo`11Ool00`00Oomoo`02Ool00`00Oomoo`0YOol000]o
o`8000Aoo`03001oogoo00=oo`<0009oo`80049oo`03001oogoo009oo`03001oogoo02Uoo`002Woo
00@007ooOol000Yoo`05001oogooOol00013Ool00`00Oomoo`02Ool00`00Oomoo`0YOol000Yoo`04
001oogoo0007Ool50002Ool20012Ool01@00Oomoogoo0000;7oo000:Ool01000Oomoo`001goo00@0
07ooOol000=oo`03001oogoo045oo`05001oogooOol0000/Ool000Yoo`04001oogoo0008Ool00`00
Ool00003Ool20013Ool01000Oomoo`00;7oo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0
@Woo00@007ooOol002aoo`002goo0P002goo00D007ooOomoo`0004Aoo`03001oo`0002eoo`0077oo
0P00A7oo0P00;Goo000LOol00`00Oomoo`13Ool00`00Oomoo`0/Ool001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001o
ogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000=oo`D0
009oo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo
00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomo
o`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00
Oomoo`1bOol000]oo`8000Aoo`04001oogooOol50002Ool2001cOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo
0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool0
1000Oomoo`002Goo00<007ooOol00Woo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomo
o`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`002Woo00D0
07ooOomoo`00019oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo00@007ooOol0009o
o`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`002Goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo
00@007ooOol000Eoo`002goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Qo
o`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo
00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo
0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D0
00=oo`8000Ioo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007oo
Oomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0400000goo001oo`02
Ool01P00Oomoogoo001oo`@000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo0`0000=o
o`00Ool00Woo00<007ooOol00Woo00<007oo00000`000Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`8001Uoo`8000Yoo`03001oogoo01Mo
o`03001oogoo00Qoo`8002Moo`0077oo00<007ooOol06Goo00<007ooOol027oo00<007ooOol05goo
00<007ooOol027oo00<007ooOol09Woo000LOol2000JOol00`00Oomoo`07Ool00`00Oomoo`0IOol0
0`00Oomoo`06Ool00`00Oomoo`0WOol001aoo`03001oogoo01Yoo`03001oogoo00Ioo`03001oogoo
01Uoo`03001oogoo00Ioo`03001oogoo02Moo`002goo0P0017oo00@007ooOomoo`D0009oo`8001]o
o`03001oogoo00Eoo`03001oogoo01Yoo`03001oogoo00Ioo`03001oogoo02Moo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool00`00Oomoo`0KOol00`00Oomoo`04Ool00`00Oomoo`0JOol00`00
Oomoo`05Ool00`00Oomoo`0XOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000LOol00`00
Oomoo`04Ool00`00Oomoo`0KOol00`00Oomoo`04Ool00`00Oomoo`0XOol000Yoo`04001oogoo000:
Ool01@00Oomoogoo00007Goo00<007ooOol017oo00<007ooOol06goo00<007ooOol017oo00<007oo
Ool0:7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8001aoo`03001oogoo00Aoo`03
001oogoo01]oo`03001oogoo00Aoo`03001oogoo02Qoo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`0KOol00`00Oomoo`04Ool00`00Oomoo`0KOol00`00Oomoo`03Ool00`00
Oomoo`0YOol000]oo`8000Uoo`<000=oo`8001eoo`03001oogoo009oo`03001oogoo01eoo`03001o
ogoo009oo`03001oogoo02Uoo`0077oo00<007ooOol077oo00<007ooOol00Woo00<007ooOol07Goo
00<007ooOol00Woo00<007ooOol0:Goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000MOol0
0`00Oomoo`02Ool00`00Oomoo`0MOol00`00Oomoo`02Ool00`00Oomoo`0YOol000Yoo`04001oogoo
000:Ool01@00Oomoogoo00007Woo00<007ooOol00Woo00<007ooOol07Goo00<007ooOol00Woo00<0
07ooOol0:Goo000:Ool01000Oomoo`001goo1@000Woo0P007Woo00@007ooOol0021oo`05001oogoo
Ool0000/Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol07Goo00@007ooOol0
021oo`05001oogooOol0000/Ool000Yoo`04001oogoo0008Ool00`00Ool00003Ool2000NOol01000
Oomoo`008Goo00@007ooOol002aoo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo01eoo`04
001oogoo000QOol00`00Ool0000]Ool000]oo`8000]oo`04001oogooOol2000OOol2000SOol2000]
Ool001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03
Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool2
0004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo
00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;
Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol0
0`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0
Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(600\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23178 L
.192 .23179 L
.196 .23181 L
.2 .23184 L
Mistroke
.204 .2319 L
.208 .23198 L
.212 .23212 L
.216 .23234 L
.22 .23267 L
.224 .23316 L
.228 .23389 L
.232 .23494 L
.236 .23644 L
.24 .23853 L
.244 .24138 L
.248 .24518 L
.252 .25016 L
.256 .25652 L
.26 .26448 L
.264 .27418 L
.268 .28571 L
.272 .29905 L
.276 .31404 L
.28 .33035 L
.284 .34748 L
.288 .36476 L
.292 .38138 L
.296 .39642 L
.3 .40896 L
.304 .41812 L
.308 .4232 L
.312 .42374 L
.316 .41955 L
.32 .41083 L
.324 .39809 L
.328 .3821 L
.332 .36388 L
.336 .34453 L
.34 .32512 L
.344 .30664 L
.348 .28984 L
.352 .27525 L
.356 .26313 L
.36 .25351 L
.364 .2462 L
.368 .24091 L
.372 .23727 L
.376 .23489 L
.38 .23343 L
.384 .23259 L
.388 .23214 L
.392 .23193 L
.396 .23184 L
.4 .23181 L
Mistroke
.404 .2318 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .2318 L
.6 .23181 L
Mistroke
.604 .23184 L
.608 .23193 L
.612 .23214 L
.616 .23259 L
.62 .23343 L
.624 .23489 L
.628 .23727 L
.632 .24091 L
.636 .2462 L
.64 .25351 L
.644 .26313 L
.648 .27525 L
.652 .28984 L
.656 .30664 L
.66 .32512 L
.664 .34453 L
.668 .36388 L
.672 .3821 L
.676 .39809 L
.68 .41083 L
.684 .41955 L
.688 .42374 L
.692 .4232 L
.696 .41812 L
.7 .40896 L
.704 .39642 L
.708 .38138 L
.712 .36476 L
.716 .34748 L
.72 .33035 L
.724 .31404 L
.728 .29905 L
.732 .28571 L
.736 .27418 L
.74 .26448 L
.744 .25652 L
.748 .25016 L
.752 .24518 L
.756 .24138 L
.76 .23853 L
.764 .23644 L
.768 .23494 L
.772 .23389 L
.776 .23316 L
.78 .23267 L
.784 .23234 L
.788 .23212 L
.792 .23198 L
.796 .2319 L
.8 .23184 L
Mistroke
.804 .23181 L
.808 .23179 L
.812 .23178 L
.816 .23177 L
.82 .23177 L
.824 .23177 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35315 L
.188 .35314 L
.192 .35313 L
.196 .35311 L
.2 .35307 L
Mistroke
.204 .353 L
.208 .3529 L
.212 .35273 L
.216 .35248 L
.22 .35209 L
.224 .3515 L
.228 .35063 L
.232 .34937 L
.236 .34759 L
.24 .3451 L
.244 .34171 L
.248 .33718 L
.252 .33125 L
.256 .32367 L
.26 .31419 L
.264 .30263 L
.268 .2889 L
.272 .27301 L
.276 .25515 L
.28 .23573 L
.284 .21532 L
.288 .19473 L
.292 .17494 L
.296 .15702 L
.3 .14209 L
.304 .13118 L
.308 .12513 L
.312 .1245 L
.316 .12948 L
.32 .13987 L
.324 .15506 L
.328 .17411 L
.332 .19582 L
.336 .21888 L
.34 .242 L
.344 .26402 L
.348 .28403 L
.352 .30141 L
.356 .31585 L
.36 .32732 L
.364 .33602 L
.368 .34233 L
.372 .34667 L
.376 .3495 L
.38 .35124 L
.384 .35224 L
.388 .35277 L
.392 .35303 L
.396 .35313 L
.4 .35317 L
Mistroke
.404 .35317 L
.408 .35317 L
.412 .35317 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35315 L
.596 .35315 L
.6 .35316 L
Mistroke
.604 .35319 L
.608 .3533 L
.612 .35355 L
.616 .35408 L
.62 .35509 L
.624 .35683 L
.628 .35966 L
.632 .364 L
.636 .3703 L
.64 .37901 L
.644 .39048 L
.648 .40491 L
.652 .42229 L
.656 .4423 L
.66 .46433 L
.664 .48745 L
.668 .51051 L
.672 .53222 L
.676 .55126 L
.68 .56645 L
.684 .57684 L
.688 .58183 L
.692 .5812 L
.696 .57515 L
.7 .56423 L
.704 .5493 L
.708 .53139 L
.712 .51159 L
.716 .49101 L
.72 .4706 L
.724 .45117 L
.728 .43332 L
.732 .41743 L
.736 .40369 L
.74 .39213 L
.744 .38266 L
.748 .37508 L
.752 .36915 L
.756 .36461 L
.76 .36122 L
.764 .35874 L
.768 .35695 L
.772 .35569 L
.776 .35483 L
.78 .35424 L
.784 .35385 L
.788 .35359 L
.792 .35343 L
.796 .35332 L
.8 .35326 L
Mistroke
.804 .35322 L
.808 .35319 L
.812 .35318 L
.816 .35317 L
.82 .35317 L
.824 .35317 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23178 L
.192 .23179 L
.196 .23181 L
.2 .23184 L
Mistroke
.204 .2319 L
.208 .23198 L
.212 .23212 L
.216 .23234 L
.22 .23267 L
.224 .23316 L
.228 .23389 L
.232 .23494 L
.236 .23644 L
.24 .23853 L
.244 .24138 L
.248 .24518 L
.252 .25016 L
.256 .25652 L
.26 .26448 L
.264 .27418 L
.268 .28571 L
.272 .29905 L
.276 .31404 L
.28 .33035 L
.284 .34748 L
.288 .36476 L
.292 .38138 L
.296 .39642 L
.3 .40896 L
.304 .41812 L
.308 .4232 L
.312 .42374 L
.316 .41955 L
.32 .41083 L
.324 .39809 L
.328 .3821 L
.332 .36388 L
.336 .34453 L
.34 .32512 L
.344 .30664 L
.348 .28984 L
.352 .27525 L
.356 .26313 L
.36 .25351 L
.364 .2462 L
.368 .24091 L
.372 .23727 L
.376 .23489 L
.38 .23343 L
.384 .23259 L
.388 .23214 L
.392 .23193 L
.396 .23184 L
.4 .23181 L
Mistroke
.404 .2318 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .2318 L
.6 .23181 L
Mistroke
.604 .23184 L
.608 .23193 L
.612 .23214 L
.616 .23259 L
.62 .23343 L
.624 .23489 L
.628 .23727 L
.632 .24091 L
.636 .2462 L
.64 .25351 L
.644 .26313 L
.648 .27525 L
.652 .28984 L
.656 .30664 L
.66 .32512 L
.664 .34453 L
.668 .36388 L
.672 .3821 L
.676 .39809 L
.68 .41083 L
.684 .41955 L
.688 .42374 L
.692 .4232 L
.696 .41812 L
.7 .40896 L
.704 .39642 L
.708 .38138 L
.712 .36476 L
.716 .34748 L
.72 .33035 L
.724 .31404 L
.728 .29905 L
.732 .28571 L
.736 .27418 L
.74 .26448 L
.744 .25652 L
.748 .25016 L
.752 .24518 L
.756 .24138 L
.76 .23853 L
.764 .23644 L
.768 .23494 L
.772 .23389 L
.776 .23316 L
.78 .23267 L
.784 .23234 L
.788 .23212 L
.792 .23198 L
.796 .2319 L
.8 .23184 L
Mistroke
.804 .23181 L
.808 .23179 L
.812 .23178 L
.816 .23177 L
.82 .23177 L
.824 .23177 L
.828 .23176 L
.832 .23176 L
.836 .23176 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo008000=oo`05001oogooOol00003Ool30002
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00002Ool20003Ool00`00
Oomoo`02Ool00`00Oomoo`030002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001o
ogoo009oo`03001oogoo00Yoo`0077oo0P0067oo00<007ooOol02Goo00<007ooOol06Goo00<007oo
Ool02Goo00<007ooOol097oo000LOol00`00Oomoo`0HOol00`00Oomoo`07Ool00`00Oomoo`0JOol0
0`00Oomoo`08Ool00`00Oomoo`0UOol001aoo`8001Uoo`03001oogoo00Moo`03001oogoo01]oo`03
001oogoo00Moo`03001oogoo02Eoo`0077oo00<007ooOol06Goo00<007ooOol01Woo00<007ooOol0
6goo00<007ooOol01Woo00<007ooOol09Woo000;Ool20004Ool01000Oomoogoo1@000Woo0P006Woo
00<007ooOol01Goo00<007ooOol07Goo00<007ooOol01Goo00<007ooOol09Woo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`03001oogoo01Uoo`03001oogoo00Eoo`03001oogoo01eoo`03001o
ogoo00Aoo`03001oogoo02Moo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8001Yoo`03001o
ogoo00Eoo`03001oogoo01eoo`03001oogoo00Aoo`03001oogoo02Moo`002Woo00@007ooOol000Yo
o`05001oogooOol0000LOol00`00Oomoo`04Ool00`00Oomoo`0MOol00`00Oomoo`04Ool00`00Oomo
o`0WOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P006goo00<007ooOol00goo00<0
07ooOol07Woo00<007ooOol017oo00<007ooOol09goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo01Yoo`03001oogoo00=oo`03001oogoo01ioo`03001oogoo00Aoo`03001o
ogoo02Moo`002goo0P002Goo0`000goo0P0077oo00<007ooOol00Woo00<007ooOol07goo00<007oo
Ool00Woo00<007ooOol0:7oo000LOol00`00Oomoo`0KOol00`00Oomoo`02Ool00`00Oomoo`0OOol0
0`00Oomoo`02Ool00`00Oomoo`0XOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8001aoo`03
001oogoo009oo`03001oogoo01moo`03001oogoo009oo`03001oogoo02Qoo`002Woo00@007ooOol0
00Yoo`05001oogooOol0000MOol00`00Oomoo`02Ool00`00Oomoo`0OOol00`00Oomoo`02Ool00`00
Oomoo`0XOol000Yoo`04001oogoo0007Ool50002Ool2000LOol01@00Oomoogoo00008goo00@007oo
Ool002]oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0LOol01000Oomoo`00
8goo00@007ooOol002]oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8001eoo`04001oogoo
000SOol01000Oomoo`00:goo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol077oo00<007oo
000097oo00@007ooOol002]oo`002goo0P002goo00@007ooOomoo`8001ioo`8002Eoo`8002aoo`00
77oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03
001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Ao
o`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000
Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`80
00Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001o
ogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol0
01Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
00]oo`8000Aoo`03001oogoo009oo`<007Qoo`002Woo00@007ooOol000Moo`05001oogooOol0001g
Ool000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000]oo`8000Uo
o`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03
001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo10000goo0P00Lgoo000:Ool01000Oomoo`001goo00<007ooOol017oo
00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007ooOol00goo0P00Lgoo000;Ool2000:Ool2
0003Ool00`00Oomoo`0MOol00`00Oomoo`1BOol001aoo`8001ioo`8005=oo`0077oo00<007ooOol0
77oo00<007oo0000Dgoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000MOol01000Oomoo`00
DWoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0001ioo`04001oogoo001BOol000=oo`D0009o
o`04001oogoo0007Ool50002Ool00`00Oomoo`0KOol01@00Oomoogoo0000DWoo000:Ool01000Oomo
o`001goo00@007ooOol000=oo`8001aoo`05001oogooOol0001BOol000Yoo`04001oogoo0008Ool0
0`00Ool00003Ool00`00Oomoo`0KOol00`00Oomoo`02Ool00`00Oomoo`1?Ool000Yoo`04001oogoo
0009Ool20003Ool2000LOol00`00Oomoo`02Ool00`00Oomoo`1?Ool000]oo`8000]oo`05001oogoo
Ool0000MOol00`00Oomoo`02Ool00`00Oomoo`1?Ool001aoo`8001aoo`03001oogoo009oo`03001o
ogoo04moo`0077oo00<007ooOol06goo00<007ooOol00Woo00<007ooOol0Cgoo000;Ool20004Ool0
1000Oomoogoo1@000Woo0P006goo00<007ooOol00goo00<007ooOol0Cgoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`03001oogoo01Yoo`03001oogoo00=oo`03001oogoo04moo`000goo1@00
0Woo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo01Yoo`03001oogoo00Aoo`03001oogoo
04ioo`002Woo00@007ooOol000Yoo`04001oogooOol2000>Ool30004Ool20004Ool00`00Oomoo`02
Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002
Ool30004Ool20006Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo
00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool20003Ool01000Oomoo`000Woo
00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`00
0Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04001o
ogoo0002Ool01000Oomoo`001Woo0P000goo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool20009Ool30003
Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00@007ooOol000Ioo`8000=oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001o
ogoo00=oo`0077oo0P003Goo10000goo00@007ooOol0009oo`03001oogoo00Aoo`03001oo`00009o
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04
001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`06001oogoo001oo`001Woo0P00
00Eoo`00Oomoo`00009oo`04001oogoo0002Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`04Ool0
1000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007oo
Oomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool20002Ool00`00
Oomoo`05Ool00`00Ool00003Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo
0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000HOol00`00Oomoo`09Ool00`00Oomo
o`1<Ool001aoo`03001oogoo01Ioo`03001oogoo00Yoo`8004eoo`0077ooJ@0037oo000LOol00`00
Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`02000;Ool20003Ool00`00Oomo
o`0BOol00`00Oomoo`0:Ool001aoo`80041oo`03001oogoo00Uoo`03001oogoo02Aoo`0077oo00<0
07ooOol0?goo00<007ooOol027oo00<007ooOol09Goo000LOol20011Ool00`00Oomoo`07Ool00`00
Oomoo`0UOol001aoo`03001oogoo041oo`03001oogoo00Ioo`03001oogoo02Ioo`0077oo00<007oo
Ool0@7oo00<007ooOol01Woo00<007ooOol09Woo000;Ool20004Ool01000Oomoogoo1@000Woo0P00
@Woo00<007ooOol01Goo00<007ooOol09Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03
001oogoo045oo`03001oogoo00Aoo`03001oogoo02Moo`002Woo00@007ooOol000Uoo`03001oogoo
009oo`80049oo`03001oogoo00Aoo`03001oogoo02Moo`002Woo00@007ooOol000Yoo`05001oogoo
Ool00013Ool00`00Oomoo`04Ool00`00Oomoo`0WOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00@Woo00<007ooOol017oo00<007ooOol09goo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo045oo`03001oogoo00Aoo`03001oogoo02Moo`002goo0P002Goo0`00
0goo00<007ooOol0@Woo00<007ooOol00goo00<007ooOol09goo000LOol20013Ool00`00Oomoo`02
Ool00`00Oomoo`0XOol001aoo`03001oogoo049oo`03001oogoo009oo`03001oogoo02Qoo`002goo
0P0017oo00<007ooOol00goo0`000Woo0P00@goo00<007ooOol00Woo00<007ooOol0:7oo000:Ool0
1000Oomoo`002Woo00D007ooOomoo`0004Aoo`03001oogoo009oo`03001oogoo02Qoo`002Woo00@0
07ooOol000Moo`D0009oo`8004Aoo`04001oogoo000[Ool000Yoo`04001oogoo0007Ool01000Oomo
o`000goo00<007ooOol0@goo00@007ooOol002]oo`002Woo00@007ooOol000Qoo`03001oo`0000=o
o`8004Aoo`04001oogoo000[Ool000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`13Ool01000
Oomoo`00:goo000;Ool2000;Ool01@00Oomoogoo0000AGoo00@007ooOol002]oo`0077oo0P00AGoo
0P00;7oo000LOol00`00Oomoo`14Ool00`00Oomoo`0[Ool001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=o
o`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000=oo`D0009oo`04
001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo
0P000goo00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1b
Ool000]oo`8000Aoo`04001oogooOol50002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo
0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomo
o`002Goo00<007ooOol00Woo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo
00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol0
07oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`002Woo00D007ooOomo
o`00019oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo00@007ooOol0009oo`03001o
ogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007oo
Ool000Eoo`002goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`8000Ao
o`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo
00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P0017oo
0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`80
00Ioo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomoo`00
00=oo`03001oogoo009oo`05001oogooOol00003Ool00`00Ool000020003Ool01@00Oomoogoo0000
0goo100000=oo`00Ool00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Ool00002
0003Ool00`00Oomoo`02Ool00`00Oomoo`0400000goo001oo`02Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000Aoo`03001oogoo00Yoo`0077oo0P0067oo00<007ooOol02Goo00<007ooOol06Goo
00<007ooOol02Goo00<007ooOol097oo000LOol00`00Oomoo`0HOol00`00Oomoo`07Ool00`00Oomo
o`0JOol00`00Oomoo`08Ool00`00Oomoo`0UOol001aoo`8001Uoo`03001oogoo00Moo`03001oogoo
01]oo`03001oogoo00Moo`03001oogoo02Eoo`0077oo00<007ooOol06Goo00<007ooOol01Woo00<0
07ooOol06goo00<007ooOol01Woo00<007ooOol09Woo000;Ool20004Ool01000Oomoogoo1@000Woo
0P006Woo00<007ooOol01Goo00<007ooOol07Goo00<007ooOol01Goo00<007ooOol09Woo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`03001oogoo01Uoo`03001oogoo00Eoo`03001oogoo01eo
o`03001oogoo00Aoo`03001oogoo02Moo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8001Yo
o`03001oogoo00Eoo`03001oogoo01eoo`03001oogoo00Aoo`03001oogoo02Moo`002Woo00@007oo
Ool000Yoo`05001oogooOol0000LOol00`00Oomoo`04Ool00`00Oomoo`0MOol00`00Oomoo`04Ool0
0`00Oomoo`0WOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P006goo00<007ooOol0
0goo00<007ooOol07Woo00<007ooOol017oo00<007ooOol09goo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo01Yoo`03001oogoo00=oo`03001oogoo01ioo`03001oogoo00Ao
o`03001oogoo02Moo`002goo0P002Goo0`000goo0P0077oo00<007ooOol00Woo00<007ooOol07goo
00<007ooOol00Woo00<007ooOol0:7oo000LOol00`00Oomoo`0KOol00`00Oomoo`02Ool00`00Oomo
o`0OOol00`00Oomoo`02Ool00`00Oomoo`0XOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`80
01aoo`03001oogoo009oo`03001oogoo01moo`03001oogoo009oo`03001oogoo02Qoo`002Woo00@0
07ooOol000Yoo`05001oogooOol0000MOol00`00Oomoo`02Ool00`00Oomoo`0OOol00`00Oomoo`02
Ool00`00Oomoo`0XOol000Yoo`04001oogoo0007Ool50002Ool2000LOol01@00Oomoogoo00008goo
00@007ooOol002]oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0LOol01000
Oomoo`008goo00@007ooOol002]oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8001eoo`04
001oogoo000SOol01000Oomoo`00:goo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol077oo
00<007oo000097oo00@007ooOol002]oo`002goo0P002goo00@007ooOomoo`8001ioo`8002Eoo`80
02aoo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo
00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:
Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Mo
o`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomo
o`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(640\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23178 L
.18 .23179 L
.184 .23181 L
.188 .23185 L
.192 .2319 L
.196 .23199 L
.2 .23214 L
Mistroke
.204 .23236 L
.208 .23269 L
.212 .2332 L
.216 .23394 L
.22 .235 L
.224 .23652 L
.228 .23861 L
.232 .24147 L
.236 .24528 L
.24 .25025 L
.244 .2566 L
.248 .26452 L
.252 .27418 L
.256 .28564 L
.26 .29891 L
.264 .3138 L
.268 .33002 L
.272 .34707 L
.276 .36429 L
.28 .38088 L
.284 .39593 L
.288 .40852 L
.292 .41779 L
.296 .42301 L
.3 .42372 L
.304 .41972 L
.308 .41117 L
.312 .39855 L
.316 .38266 L
.32 .36447 L
.324 .34509 L
.328 .32561 L
.332 .30701 L
.336 .29007 L
.34 .27535 L
.344 .26312 L
.348 .2534 L
.352 .24604 L
.356 .24073 L
.36 .23708 L
.364 .23473 L
.368 .2333 L
.372 .23249 L
.376 .23207 L
.38 .23189 L
.384 .23181 L
.388 .2318 L
.392 .2318 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .2318 L
.612 .2318 L
.616 .23181 L
.62 .23189 L
.624 .23207 L
.628 .23249 L
.632 .2333 L
.636 .23473 L
.64 .23708 L
.644 .24073 L
.648 .24604 L
.652 .2534 L
.656 .26312 L
.66 .27535 L
.664 .29007 L
.668 .30701 L
.672 .32561 L
.676 .34509 L
.68 .36447 L
.684 .38266 L
.688 .39855 L
.692 .41117 L
.696 .41972 L
.7 .42372 L
.704 .42301 L
.708 .41779 L
.712 .40852 L
.716 .39593 L
.72 .38088 L
.724 .36429 L
.728 .34707 L
.732 .33002 L
.736 .3138 L
.74 .29891 L
.744 .28564 L
.748 .27418 L
.752 .26452 L
.756 .2566 L
.76 .25025 L
.764 .24528 L
.768 .24147 L
.772 .23861 L
.776 .23652 L
.78 .235 L
.784 .23394 L
.788 .2332 L
.792 .23269 L
.796 .23236 L
.8 .23214 L
Mistroke
.804 .23199 L
.808 .2319 L
.812 .23185 L
.816 .23181 L
.82 .23179 L
.824 .23178 L
.828 .23177 L
.832 .23177 L
.836 .23177 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35315 L
.176 .35314 L
.18 .35313 L
.184 .3531 L
.188 .35306 L
.192 .35299 L
.196 .35289 L
.2 .35272 L
Mistroke
.204 .35245 L
.208 .35205 L
.212 .35145 L
.216 .35057 L
.22 .3493 L
.224 .3475 L
.228 .345 L
.232 .3416 L
.236 .33706 L
.24 .33114 L
.244 .32357 L
.248 .31414 L
.252 .30264 L
.256 .28898 L
.26 .27318 L
.264 .25543 L
.268 .23611 L
.272 .2158 L
.276 .19529 L
.28 .17554 L
.284 .15761 L
.288 .14261 L
.292 .13158 L
.296 .12535 L
.3 .12452 L
.304 .12929 L
.308 .13948 L
.312 .15451 L
.316 .17345 L
.32 .19512 L
.324 .21821 L
.328 .24142 L
.332 .26358 L
.336 .28375 L
.34 .30129 L
.344 .31587 L
.348 .32744 L
.352 .33621 L
.356 .34255 L
.36 .34688 L
.364 .34969 L
.368 .3514 L
.372 .35236 L
.376 .35285 L
.38 .35308 L
.384 .35316 L
.388 .35318 L
.392 .35318 L
.396 .35317 L
.4 .35317 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35315 L
.608 .35314 L
.612 .35314 L
.616 .35316 L
.62 .35325 L
.624 .35347 L
.628 .35397 L
.632 .35493 L
.636 .35663 L
.64 .35944 L
.644 .36378 L
.648 .37011 L
.652 .37888 L
.656 .39046 L
.66 .40503 L
.664 .42257 L
.668 .44274 L
.672 .4649 L
.676 .48812 L
.68 .51121 L
.684 .53288 L
.688 .55182 L
.692 .56684 L
.696 .57703 L
.7 .5818 L
.704 .58097 L
.708 .57475 L
.712 .56371 L
.716 .54871 L
.72 .53079 L
.724 .51103 L
.728 .49052 L
.732 .47021 L
.736 .45089 L
.74 .43314 L
.744 .41735 L
.748 .40369 L
.752 .39219 L
.756 .38275 L
.76 .37519 L
.764 .36926 L
.768 .36473 L
.772 .36133 L
.776 .35883 L
.78 .35702 L
.784 .35575 L
.788 .35487 L
.792 .35427 L
.796 .35387 L
.8 .35361 L
Mistroke
.804 .35344 L
.808 .35333 L
.812 .35326 L
.816 .35322 L
.82 .3532 L
.824 .35318 L
.828 .35317 L
.832 .35317 L
.836 .35317 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23178 L
.18 .23179 L
.184 .23181 L
.188 .23185 L
.192 .2319 L
.196 .23199 L
.2 .23214 L
Mistroke
.204 .23236 L
.208 .23269 L
.212 .2332 L
.216 .23394 L
.22 .235 L
.224 .23652 L
.228 .23861 L
.232 .24147 L
.236 .24528 L
.24 .25025 L
.244 .2566 L
.248 .26452 L
.252 .27418 L
.256 .28564 L
.26 .29891 L
.264 .3138 L
.268 .33002 L
.272 .34707 L
.276 .36429 L
.28 .38088 L
.284 .39593 L
.288 .40852 L
.292 .41779 L
.296 .42301 L
.3 .42372 L
.304 .41972 L
.308 .41117 L
.312 .39855 L
.316 .38266 L
.32 .36447 L
.324 .34509 L
.328 .32561 L
.332 .30701 L
.336 .29007 L
.34 .27535 L
.344 .26312 L
.348 .2534 L
.352 .24604 L
.356 .24073 L
.36 .23708 L
.364 .23473 L
.368 .2333 L
.372 .23249 L
.376 .23207 L
.38 .23189 L
.384 .23181 L
.388 .2318 L
.392 .2318 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .2318 L
.612 .2318 L
.616 .23181 L
.62 .23189 L
.624 .23207 L
.628 .23249 L
.632 .2333 L
.636 .23473 L
.64 .23708 L
.644 .24073 L
.648 .24604 L
.652 .2534 L
.656 .26312 L
.66 .27535 L
.664 .29007 L
.668 .30701 L
.672 .32561 L
.676 .34509 L
.68 .36447 L
.684 .38266 L
.688 .39855 L
.692 .41117 L
.696 .41972 L
.7 .42372 L
.704 .42301 L
.708 .41779 L
.712 .40852 L
.716 .39593 L
.72 .38088 L
.724 .36429 L
.728 .34707 L
.732 .33002 L
.736 .3138 L
.74 .29891 L
.744 .28564 L
.748 .27418 L
.752 .26452 L
.756 .2566 L
.76 .25025 L
.764 .24528 L
.768 .24147 L
.772 .23861 L
.776 .23652 L
.78 .235 L
.784 .23394 L
.788 .2332 L
.792 .23269 L
.796 .23236 L
.8 .23214 L
Mistroke
.804 .23199 L
.808 .2319 L
.812 .23185 L
.816 .23181 L
.82 .23179 L
.824 .23178 L
.828 .23177 L
.832 .23177 L
.836 .23177 L
.84 .23176 L
.844 .23176 L
.848 .23176 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`03001oo`00008000=oo`05001oogooOol00003Ool20003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool20002Ool00`00
Oomoo`02Ool01000Oomoogoo0`0000=oo`00Ool00Woo00D007ooOomoo`0000=oo`05001oogooOol0
0004Ool00`00Oomoo`0:Ool001aoo`8001Moo`03001oogoo00Uoo`03001oogoo01]oo`03001oogoo
00Uoo`03001oogoo02=oo`0077oo00<007ooOol05Woo00<007ooOol027oo00<007ooOol07Goo00<0
07ooOol01goo00<007ooOol097oo000LOol2000HOol00`00Oomoo`07Ool00`00Oomoo`0MOol00`00
Oomoo`07Ool00`00Oomoo`0TOol001aoo`03001oogoo01Moo`03001oogoo00Ioo`03001oogoo01io
o`03001oogoo00Moo`03001oogoo02Aoo`002goo0P0017oo00@007ooOomoo`D0009oo`8001Uoo`03
001oogoo00Eoo`03001oogoo01moo`03001oogoo00Eoo`03001oogoo02Eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool00`00Oomoo`0HOol00`00Oomoo`05Ool00`00Oomoo`0OOol00`00Oomo
o`05Ool00`00Oomoo`0UOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000IOol00`00Oomo
o`05Ool00`00Oomoo`0OOol00`00Oomoo`05Ool00`00Oomoo`0UOol000Yoo`04001oogoo000:Ool0
1@00Oomoogoo00006goo00<007ooOol017oo00<007ooOol07goo00<007ooOol017oo00<007ooOol0
9Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8001Yoo`03001oogoo00=oo`03001o
ogoo025oo`03001oogoo00=oo`03001oogoo02Ioo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`0IOol00`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomo
o`0VOol000]oo`8000Uoo`<000=oo`8001Yoo`03001oogoo00=oo`03001oogoo025oo`03001oogoo
009oo`03001oogoo02Moo`0077oo00<007ooOol06Goo00<007ooOol00goo00<007ooOol08Goo00<0
07ooOol00Woo00<007ooOol09goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000KOol01@00
Oomoogoo000097oo00<007ooOol00Woo00<007ooOol09goo000:Ool01000Oomoo`002Woo00D007oo
Oomoo`0001aoo`05001oogooOol0000TOol00`00Oomoo`02Ool00`00Oomoo`0WOol000Yoo`04001o
ogoo0007Ool50002Ool2000KOol01@00Oomoogoo00009Goo00D007ooOomoo`0002Uoo`002Woo00@0
07ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0KOol00`00Ool0000VOol01000Oomoo`00:Woo
000:Ool01000Oomoo`0027oo00<007oo00000goo0P0077oo00<007oo00009Woo00@007ooOol002Yo
o`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo01]oo`03001oo`0002Moo`<002Yoo`002goo
0P002goo00@007ooOomoo`8001eoo`8002Moo`8002]oo`0077oo00<007ooOol0LWoo000;Ool20004
Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@0
07ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80
07=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P00
0goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<0
07ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo
00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00
NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<0
07Qoo`002Woo00@007ooOol000Moo`05001oogooOol0001gOol000=oo`D0009oo`04001oogoo0007
Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2001cOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo10000goo
0P00Lgoo000:Ool01000Oomoo`001goo00<007ooOol017oo00<007ooOol0LWoo000:Ool01000Oomo
o`0027oo00<007ooOol00goo0P00Lgoo000;Ool2000:Ool20003Ool00`00Oomoo`0LOol00`00Oomo
o`1COol001aoo`8001aoo`03001oo`0005Aoo`0077oo00<007ooOol06goo00<007oo0000E7oo000;
Ool20004Ool00`00Oomoo`03Ool30002Ool2000LOol00`00Ool0001DOol000Yoo`04001oogoo000:
Ool01@00Oomoogoo00007Goo00<007oo0000E7oo0003Ool50002Ool01000Oomoo`001goo1@000Woo
00<007ooOol06goo00@007ooOol005=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool2000K
Ool01@00Oomoogoo0000Dgoo000:Ool01000Oomoo`0027oo00<007oo00000goo00<007ooOol06Woo
00D007ooOomoo`0005=oo`002Woo00@007ooOol000Uoo`8000=oo`8001]oo`05001oogooOol0001C
Ool000]oo`8000]oo`05001oogooOol0000LOol01@00Oomoogoo0000Dgoo000LOol2000JOol00`00
Oomoo`03Ool00`00Oomoo`1@Ool001aoo`03001oogoo01Uoo`03001oogoo00=oo`03001oogoo051o
o`002goo0P0017oo00@007ooOomoo`D0009oo`8001Yoo`03001oogoo00=oo`03001oogoo051oo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0IOol00`00Oomoo`03Ool00`00Oomo
o`1@Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomo
o`04Ool00`00Oomoo`1?Ool000Yoo`04001oogoo000:Ool01000Oomoogoo0P003Woo0`0017oo0P00
0goo00<007ooOol00goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P00
17oo0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00aoo`05001oogooOol00002Ool01P00Oomoo`00Ool000Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
0P004Goo00@007ooOol0009oo`03001oo`0000Moo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=o
o`002goo0P002Goo0`000goo00<007ooOol047oo00@007ooOol0009oo`03001oo`0000Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol0
17oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00<007ooOol00P0027oo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol0
07oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00<007ooOol0
0P001goo0`000goo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000
Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomo
o`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool30009Ool20004Ool2
0004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@00
0goo0P001Woo000LOol2000GOol00`00Oomoo`09Ool00`00Oomoo`1=Ool001aoo`03001oogoo01Ao
o`8000aoo`03001oogoo04eoo`0077ooJ@0037oo000LOol00`00Oomoo`0BOol00`00Oomoo`0BOol0
0`00Oomoo`0AOol01000Oomoogoo0P0037oo00@007ooOol001Aoo`03001oogoo00Yoo`0077oo0P00
@Goo00<007ooOol02Goo00<007ooOol08goo000LOol00`00Oomoo`11Ool00`00Oomoo`07Ool00`00
Oomoo`0TOol001aoo`80049oo`03001oogoo00Moo`03001oogoo02Aoo`0077oo00<007ooOol0@Goo
00<007ooOol01goo00<007ooOol097oo000LOol00`00Oomoo`11Ool00`00Oomoo`07Ool00`00Oomo
o`0TOol000]oo`8000Aoo`04001oogooOol50002Ool20013Ool00`00Oomoo`05Ool00`00Oomoo`0U
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0@Woo00<007ooOol01Goo00<0
07ooOol09Goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00@goo00<007ooOol01Goo00<0
07ooOol09Goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0004Aoo`03001oogoo00Aoo`03001o
ogoo02Ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool20014Ool00`00Oomoo`03Ool0
0`00Oomoo`0VOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0@goo00<0
07ooOol00goo00<007ooOol09Woo000;Ool20009Ool30003Ool00`00Oomoo`13Ool00`00Oomoo`03
Ool00`00Oomoo`0VOol001aoo`8004Aoo`03001oogoo009oo`03001oogoo02Moo`0077oo00<007oo
Ool0@goo00<007ooOol00Woo00<007ooOol09goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2
0014Ool00`00Oomoo`02Ool00`00Oomoo`0WOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000
AGoo00<007ooOol00Woo00<007ooOol09goo000:Ool01000Oomoo`001goo1@000Woo0P00AGoo00D0
07ooOomoo`0002Uoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`14Ool01@00
Oomoogoo0000:Goo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00AGoo00@007ooOol002Yo
o`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo04Aoo`04001oogoo000ZOol000]oo`8000]o
o`05001oogooOol00017Ool00`00Ool0000ZOol001aoo`8004Ioo`8002]oo`0077oo00<007ooOol0
AWoo00<007ooOol0:Goo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04
001oogoo000:Ool01@00Oomoogoo0000M7oo0003Ool50002Ool01000Oomoo`001goo1@000Woo0P00
Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`00
2goo0P002goo00@007ooOomoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool01000Oomo
ogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00eoo`<0
00Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`80
00Eoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`80
00eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Yoo`05001oogooOol0000BOol01000Oomoo`000Woo
00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`80015oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool037oo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uoo`<0
00=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03
001oogoo00aoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003
Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00
Oomoogoo00000goo1@000goo00D007ooOomoo`0000=oo`<0009oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`00009oo`<0009oo`03001oogoo009oo`04001oogooOol50003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`03001oogoo00Yoo`0077oo0P005goo00<0
07ooOol02Goo00<007ooOol06goo00<007ooOol02Goo00<007ooOol08goo000LOol00`00Oomoo`0F
Ool00`00Oomoo`08Ool00`00Oomoo`0MOol00`00Oomoo`07Ool00`00Oomoo`0TOol001aoo`8001Qo
o`03001oogoo00Moo`03001oogoo01eoo`03001oogoo00Moo`03001oogoo02Aoo`0077oo00<007oo
Ool05goo00<007ooOol01Woo00<007ooOol07Woo00<007ooOol01goo00<007ooOol097oo000;Ool2
0004Ool01000Oomoogoo1@000Woo0P006Goo00<007ooOol01Goo00<007ooOol07goo00<007ooOol0
1Goo00<007ooOol09Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo01Qoo`03
001oogoo00Eoo`03001oogoo01moo`03001oogoo00Eoo`03001oogoo02Eoo`002Woo00@007ooOol0
00Uoo`03001oogoo009oo`8001Uoo`03001oogoo00Eoo`03001oogoo01moo`03001oogoo00Eoo`03
001oogoo02Eoo`002Woo00@007ooOol000Yoo`05001oogooOol0000KOol00`00Oomoo`04Ool00`00
Oomoo`0OOol00`00Oomoo`04Ool00`00Oomoo`0VOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P006Woo00<007ooOol00goo00<007ooOol08Goo00<007ooOol00goo00<007ooOol09Woo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo01Uoo`03001oogoo00=oo`03
001oogoo025oo`03001oogoo00=oo`03001oogoo02Ioo`002goo0P002Goo0`000goo0P006Woo00<0
07ooOol00goo00<007ooOol08Goo00<007ooOol00Woo00<007ooOol09goo000LOol00`00Oomoo`0I
Ool00`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`02Ool00`00Oomoo`0WOol000]oo`8000Ao
o`03001oogoo00=oo`<0009oo`8001]oo`05001oogooOol0000TOol00`00Oomoo`02Ool00`00Oomo
o`0WOol000Yoo`04001oogoo000:Ool01@00Oomoogoo000077oo00D007ooOomoo`0002Aoo`03001o
ogoo009oo`03001oogoo02Moo`002Woo00@007ooOol000Moo`D0009oo`8001]oo`05001oogooOol0
000UOol01@00Oomoogoo0000:Goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo
01]oo`04001oogoo000UOol01000Oomoo`00:Woo000:Ool01000Oomoo`0027oo00<007oo00000goo
0P0077oo00<007oo00009Woo00@007ooOol002Yoo`002Woo00@007ooOol000Uoo`8000=oo`03001o
ogoo01]oo`03001oo`0002Moo`03001oo`0002Yoo`002goo0P002goo00@007ooOomoo`8001aoo`<0
02Moo`8002]oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001c
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03
001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1b
Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00
Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001c
Ool001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol0
0`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(680\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23178 L
.168 .23179 L
.172 .23182 L
.176 .23185 L
.18 .23191 L
.184 .232 L
.188 .23215 L
.192 .23238 L
.196 .23272 L
.2 .23323 L
Mistroke
.204 .23399 L
.208 .23507 L
.212 .23659 L
.216 .2387 L
.22 .24156 L
.224 .24538 L
.228 .25034 L
.232 .25668 L
.236 .26457 L
.24 .27417 L
.244 .28558 L
.248 .29876 L
.252 .31357 L
.256 .3297 L
.26 .34667 L
.264 .36383 L
.268 .38038 L
.272 .39544 L
.276 .40808 L
.28 .41745 L
.284 .42282 L
.288 .42369 L
.292 .41987 L
.296 .41149 L
.3 .39901 L
.304 .38321 L
.308 .36506 L
.312 .34566 L
.316 .3261 L
.32 .30738 L
.324 .29032 L
.328 .27546 L
.332 .26311 L
.336 .2533 L
.34 .24588 L
.344 .24054 L
.348 .2369 L
.352 .23456 L
.356 .23316 L
.36 .23239 L
.364 .23201 L
.368 .23184 L
.372 .23179 L
.376 .23179 L
.38 .23179 L
.384 .2318 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .2318 L
.62 .23179 L
.624 .23179 L
.628 .23179 L
.632 .23184 L
.636 .23201 L
.64 .23239 L
.644 .23316 L
.648 .23456 L
.652 .2369 L
.656 .24054 L
.66 .24588 L
.664 .2533 L
.668 .26311 L
.672 .27546 L
.676 .29032 L
.68 .30738 L
.684 .3261 L
.688 .34566 L
.692 .36506 L
.696 .38321 L
.7 .39901 L
.704 .41149 L
.708 .41987 L
.712 .42369 L
.716 .42282 L
.72 .41745 L
.724 .40808 L
.728 .39544 L
.732 .38038 L
.736 .36383 L
.74 .34667 L
.744 .3297 L
.748 .31357 L
.752 .29876 L
.756 .28558 L
.76 .27417 L
.764 .26457 L
.768 .25668 L
.772 .25034 L
.776 .24538 L
.78 .24156 L
.784 .2387 L
.788 .23659 L
.792 .23507 L
.796 .23399 L
.8 .23323 L
Mistroke
.804 .23272 L
.808 .23238 L
.812 .23215 L
.816 .232 L
.82 .23191 L
.824 .23185 L
.828 .23182 L
.832 .23179 L
.836 .23178 L
.84 .23177 L
.844 .23177 L
.848 .23177 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35315 L
.164 .35314 L
.168 .35313 L
.172 .3531 L
.176 .35306 L
.18 .35299 L
.184 .35287 L
.188 .3527 L
.192 .35243 L
.196 .35202 L
.2 .35141 L
Mistroke
.204 .35051 L
.208 .34923 L
.212 .34741 L
.216 .3449 L
.22 .34149 L
.224 .33694 L
.228 .33103 L
.232 .32349 L
.236 .31408 L
.24 .30264 L
.244 .28905 L
.248 .27335 L
.252 .25571 L
.256 .23649 L
.26 .21628 L
.264 .19585 L
.268 .17613 L
.272 .1582 L
.276 .14314 L
.28 .13198 L
.284 .12559 L
.288 .12455 L
.292 .12911 L
.296 .1391 L
.3 .15396 L
.304 .17279 L
.308 .19441 L
.312 .21753 L
.316 .24084 L
.32 .26313 L
.324 .28346 L
.328 .30116 L
.332 .31588 L
.336 .32756 L
.34 .33641 L
.344 .34277 L
.348 .34711 L
.352 .34989 L
.356 .35156 L
.36 .35248 L
.364 .35293 L
.368 .35313 L
.372 .35319 L
.376 .3532 L
.38 .35319 L
.384 .35317 L
.388 .35317 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35315 L
.62 .35314 L
.624 .35313 L
.628 .35313 L
.632 .3532 L
.636 .35339 L
.64 .35385 L
.644 .35477 L
.648 .35644 L
.652 .35922 L
.656 .36356 L
.66 .36992 L
.664 .37876 L
.668 .39045 L
.672 .40516 L
.676 .42286 L
.68 .44319 L
.684 .46549 L
.688 .48879 L
.692 .51191 L
.696 .53354 L
.7 .55237 L
.704 .56723 L
.708 .57721 L
.712 .58177 L
.716 .58073 L
.72 .57435 L
.724 .56319 L
.728 .54813 L
.732 .53019 L
.736 .51048 L
.74 .49004 L
.744 .46983 L
.748 .45062 L
.752 .43298 L
.756 .41727 L
.76 .40368 L
.764 .39224 L
.768 .38284 L
.772 .3753 L
.776 .36938 L
.78 .36484 L
.784 .36143 L
.788 .35891 L
.792 .3571 L
.796 .35581 L
.8 .35492 L
Mistroke
.804 .35431 L
.808 .3539 L
.812 .35363 L
.816 .35345 L
.82 .35334 L
.824 .35327 L
.828 .35323 L
.832 .3532 L
.836 .35318 L
.84 .35317 L
.844 .35317 L
.848 .35317 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23178 L
.168 .23179 L
.172 .23182 L
.176 .23185 L
.18 .23191 L
.184 .232 L
.188 .23215 L
.192 .23238 L
.196 .23272 L
.2 .23323 L
Mistroke
.204 .23399 L
.208 .23507 L
.212 .23659 L
.216 .2387 L
.22 .24156 L
.224 .24538 L
.228 .25034 L
.232 .25668 L
.236 .26457 L
.24 .27417 L
.244 .28558 L
.248 .29876 L
.252 .31357 L
.256 .3297 L
.26 .34667 L
.264 .36383 L
.268 .38038 L
.272 .39544 L
.276 .40808 L
.28 .41745 L
.284 .42282 L
.288 .42369 L
.292 .41987 L
.296 .41149 L
.3 .39901 L
.304 .38321 L
.308 .36506 L
.312 .34566 L
.316 .3261 L
.32 .30738 L
.324 .29032 L
.328 .27546 L
.332 .26311 L
.336 .2533 L
.34 .24588 L
.344 .24054 L
.348 .2369 L
.352 .23456 L
.356 .23316 L
.36 .23239 L
.364 .23201 L
.368 .23184 L
.372 .23179 L
.376 .23179 L
.38 .23179 L
.384 .2318 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .2318 L
.62 .23179 L
.624 .23179 L
.628 .23179 L
.632 .23184 L
.636 .23201 L
.64 .23239 L
.644 .23316 L
.648 .23456 L
.652 .2369 L
.656 .24054 L
.66 .24588 L
.664 .2533 L
.668 .26311 L
.672 .27546 L
.676 .29032 L
.68 .30738 L
.684 .3261 L
.688 .34566 L
.692 .36506 L
.696 .38321 L
.7 .39901 L
.704 .41149 L
.708 .41987 L
.712 .42369 L
.716 .42282 L
.72 .41745 L
.724 .40808 L
.728 .39544 L
.732 .38038 L
.736 .36383 L
.74 .34667 L
.744 .3297 L
.748 .31357 L
.752 .29876 L
.756 .28558 L
.76 .27417 L
.764 .26457 L
.768 .25668 L
.772 .25034 L
.776 .24538 L
.78 .24156 L
.784 .2387 L
.788 .23659 L
.792 .23507 L
.796 .23399 L
.8 .23323 L
Mistroke
.804 .23272 L
.808 .23238 L
.812 .23215 L
.816 .232 L
.82 .23191 L
.824 .23185 L
.828 .23182 L
.832 .23179 L
.836 .23178 L
.84 .23177 L
.844 .23177 L
.848 .23177 L
.852 .23176 L
.856 .23176 L
.86 .23176 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`<00003Ool007oo009oo`05001oogooOol00002Ool20004
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool300000goo001o
o`03Ool01P00Oomoogoo001oo`<000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00<0
07ooOol02Woo000LOol2000EOol2000:Ool00`00Oomoo`0NOol2000:Ool00`00Oomoo`0ROol001ao
o`03001oogoo01Eoo`03001oogoo00Qoo`03001oogoo01moo`03001oogoo00Qoo`03001oogoo029o
o`0077oo0P005goo00<007ooOol01goo00<007ooOol07goo00<007ooOol01goo00<007ooOol08goo
000LOol00`00Oomoo`0FOol00`00Oomoo`06Ool00`00Oomoo`0QOol00`00Oomoo`06Ool00`00Oomo
o`0SOol000]oo`8000Aoo`04001oogooOol50002Ool2000GOol00`00Oomoo`06Ool00`00Oomoo`0Q
Ool00`00Oomoo`05Ool00`00Oomoo`0TOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<0
07ooOol05goo00<007ooOol01Goo00<007ooOol08Goo00<007ooOol01Goo00<007ooOol097oo000:
Ool01000Oomoo`002Goo00<007ooOol00Woo0P0067oo00<007ooOol017oo00<007ooOol08Woo00<0
07ooOol01Goo00<007ooOol097oo000:Ool01000Oomoo`002Woo00D007ooOomoo`0001Uoo`03001o
ogoo00Aoo`03001oogoo029oo`03001oogoo00Eoo`03001oogoo02Aoo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2000IOol00`00Oomoo`03Ool00`00Oomoo`0SOol00`00Oomoo`03Ool0
0`00Oomoo`0UOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol067oo00<0
07ooOol00goo00<007ooOol08goo00<007ooOol00goo00<007ooOol09Goo000;Ool20009Ool30003
Ool2000IOol00`00Oomoo`02Ool00`00Oomoo`0TOol00`00Oomoo`03Ool00`00Oomoo`0UOol001ao
o`03001oogoo01Qoo`03001oogoo009oo`03001oogoo02Aoo`03001oogoo00=oo`03001oogoo02Eo
o`002goo0P0017oo00<007ooOol00goo0`000Woo0P006Woo00D007ooOomoo`0002Moo`05001oogoo
Ool0000XOol000Yoo`04001oogoo000:Ool01@00Oomoogoo00006goo00D007ooOomoo`0002Moo`05
001oogooOol0000XOol000Yoo`04001oogoo0007Ool50002Ool2000JOol01@00Oomoogoo00009goo
00D007ooOomoo`0002Qoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0IOol0
1@00Oomoogoo00009goo00@007ooOol002Uoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`80
01]oo`03001oo`0002Uoo`03001oo`0002Uoo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo
01Yoo`03001oo`0002Uoo`03001oo`0002Uoo`002goo0P002goo00@007ooOomoo`8001aoo`03001o
ogoo02Qoo`8002Yoo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2
001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qo
o`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomo
o`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2
001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000G
Ool00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<007Qoo`002Woo00@007ooOol000Mo
o`05001oogooOol0001gOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00
Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2
001cOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1b
Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo10000goo0P00Lgoo000:Ool01000Oomoo`00
1goo00<007ooOol017oo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007ooOol00goo0P00
Lgoo000;Ool2000:Ool20003Ool00`00Oomoo`0KOol00`00Oomoo`1DOol001aoo`8001]oo`8005Io
o`0077oo00<007ooOol06Woo00<007oo0000EGoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2
000KOol00`00Ool0001EOol000Yoo`04001oogoo000:Ool01@00Oomoogoo00006goo00@007ooOol0
05Eoo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo01Uoo`05001oogooOol0001D
Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P006Woo00D007ooOomoo`0005Aoo`002Woo
00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo01Uoo`05001oogooOol0001DOol000Yoo`04
001oogoo0009Ool20003Ool2000JOol01@00Oomoogoo0000E7oo000;Ool2000;Ool01@00Oomoogoo
00006goo00D007ooOomoo`0005Aoo`0077oo0P006Goo00<007ooOol00Woo00<007ooOol0DWoo000L
Ool00`00Oomoo`0HOol00`00Oomoo`02Ool00`00Oomoo`1BOol000]oo`8000Aoo`04001oogooOol5
0002Ool2000IOol00`00Oomoo`03Ool00`00Oomoo`1AOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00<007ooOol067oo00<007ooOol00goo00<007ooOol0DGoo0003Ool50002Ool01000Oomo
o`002Goo00<007ooOol00Woo00<007ooOol05goo00<007ooOol017oo00<007ooOol0DGoo000:Ool0
1000Oomoo`002Woo00@007ooOomoo`8000ioo`<000Aoo`800003Ool007oo00Eoo`@000Aoo`8000Ao
o`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Io
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool01@00Oomoogoo0000
0Woo00<007ooOol00P001Woo00<007oo000017oo00@007ooOol0009oo`04001oogoo0005Ool01@00
Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol0
1Woo0P0017oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool20009Ool30003Ool00`00Oomoo`0@Ool01000
Oomoo`000Woo00<007ooOol01Woo0P0017oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool4
0003Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo
10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Ao
o`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol0
17oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007oo
Ool017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Ao
o`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P00
2Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Ao
o`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P005Goo0P002Woo00<007ooOol0Cgoo000LOol0
0`00Oomoo`0COol2000<Ool00`00Oomoo`1>Ool001aoofT000aoo`0077oo00<007ooOol04Woo00<0
07ooOol04Woo00<007ooOol04Goo00<007ooOol00goo00<007ooOol02Woo00<007oo000057oo00<0
07ooOol02Woo000LOol20012Ool00`00Oomoo`09Ool00`00Oomoo`0ROol001aoo`03001oogoo049o
o`03001oogoo00Qoo`03001oogoo029oo`0077oo0P00@goo00<007ooOol01goo00<007ooOol08goo
000LOol00`00Oomoo`13Ool00`00Oomoo`06Ool00`00Oomoo`0SOol001aoo`03001oogoo04=oo`03
001oogoo00Ioo`03001oogoo02=oo`002goo0P0017oo00@007ooOomoo`D0009oo`8004Aoo`03001o
ogoo00Eoo`03001oogoo02Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`13
Ool00`00Oomoo`05Ool00`00Oomoo`0TOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool20014
Ool00`00Oomoo`05Ool00`00Oomoo`0TOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000AGoo
00<007ooOol01Goo00<007ooOol097oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
04Eoo`03001oogoo00Aoo`03001oogoo02Aoo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`14Ool00`00Oomoo`03Ool00`00Oomoo`0UOol000]oo`8000Uoo`<000=oo`03001o
ogoo04Aoo`03001oogoo00=oo`03001oogoo02Eoo`0077oo0P00AGoo00<007ooOol00goo00<007oo
Ool09Goo000LOol00`00Oomoo`14Ool00`00Oomoo`03Ool00`00Oomoo`0UOol000]oo`8000Aoo`03
001oogoo00=oo`<0009oo`8004Ioo`05001oogooOol0000XOol000Yoo`04001oogoo000:Ool01@00
Oomoogoo0000Agoo00D007ooOomoo`0002Qoo`002Woo00@007ooOol000Moo`D0009oo`8004Ioo`05
001oogooOol0000XOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0AGoo00D0
07ooOomoo`0002Qoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8004Moo`03001oo`0002Uo
o`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo04Ioo`03001oo`0002Uoo`002goo0P002goo
00D007ooOomoo`0004Qoo`03001oo`0002Uoo`0077oo0P00Agoo0`00:Goo000LOol00`00Oomoo`17
Ool00`00Oomoo`0XOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@0
07ooOol000Yoo`05001oogooOol0001dOol000=oo`D0009oo`04001oogoo0007Ool50002Ool2001c
Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
27oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;
Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogoo
Ool50002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol03Goo0`00
17oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P00
1Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo0P00
3Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00<007ooOol00goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`04001oogoo0002Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P004Goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eo
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`0<Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Goo0`00
0goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomo
o`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomo
o`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<0
07ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=o
o`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001o
ogooOol00002Ool400000goo001oo`02Ool01@00Oomoogoo00000Woo0P0017oo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo0`0000=oo`00Ool00goo00H007ooOomo
o`00Ool40002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`03001oogoo00Yoo`0077oo
0P005Goo0P002Woo00<007ooOol07Woo00<007ooOol02Goo00<007ooOol08Woo000LOol00`00Oomo
o`0EOol00`00Oomoo`08Ool00`00Oomoo`0OOol00`00Oomoo`08Ool00`00Oomoo`0ROol001aoo`80
01Moo`03001oogoo00Moo`03001oogoo01moo`03001oogoo00Moo`03001oogoo02=oo`0077oo00<0
07ooOol05Woo00<007ooOol01Woo00<007ooOol08Goo00<007ooOol01Woo00<007ooOol08goo000;
Ool20004Ool01000Oomoogoo1@000Woo0P005goo00<007ooOol01Woo00<007ooOol08Goo00<007oo
Ool01Goo00<007ooOol097oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo01Mo
o`03001oogoo00Eoo`03001oogoo025oo`03001oogoo00Eoo`03001oogoo02Aoo`002Woo00@007oo
Ool000Uoo`03001oogoo009oo`8001Qoo`03001oogoo00Aoo`03001oogoo029oo`03001oogoo00Eo
o`03001oogoo02Aoo`002Woo00@007ooOol000Yoo`05001oogooOol0000IOol00`00Oomoo`04Ool0
0`00Oomoo`0ROol00`00Oomoo`05Ool00`00Oomoo`0TOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P0067oo00<007ooOol017oo00<007ooOol08goo00<007ooOol017oo00<007ooOol0
97oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo01Qoo`03001oogoo00=o
o`03001oogoo02=oo`03001oogoo00=oo`03001oogoo02Eoo`002goo0P002Goo0`000goo0P006Goo
00<007ooOol00Woo00<007ooOol097oo00<007ooOol00goo00<007ooOol09Goo000LOol00`00Oomo
o`0HOol00`00Oomoo`02Ool00`00Oomoo`0TOol00`00Oomoo`03Ool00`00Oomoo`0UOol000]oo`80
00Aoo`03001oogoo00=oo`<0009oo`8001Yoo`05001oogooOol0000WOol01@00Oomoogoo0000:7oo
000:Ool01000Oomoo`002Woo00D007ooOomoo`0001]oo`05001oogooOol0000WOol01@00Oomoogoo
0000:7oo000:Ool01000Oomoo`001goo1@000Woo0P006Woo00D007ooOomoo`0002Moo`05001oogoo
Ool0000XOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol06Goo00D007ooOomo
o`0002Moo`04001oogoo000YOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2000JOol01000
Oomoo`00:Goo00<007oo0000:Goo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol06Woo00<0
07oo0000:Goo00<007oo0000:Goo000;Ool2000;Ool01000Oomoogoo0P006goo0P00:Woo0`00:Goo
000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo
00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P00
17oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04
001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo
0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<0
07ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Mo
o`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(720\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23178 L
.156 .2318 L
.16 .23182 L
.164 .23186 L
.168 .23192 L
.172 .23201 L
.176 .23217 L
.18 .2324 L
.184 .23275 L
.188 .23327 L
.192 .23403 L
.196 .23513 L
.2 .23666 L
Mistroke
.204 .23878 L
.208 .24166 L
.212 .24547 L
.216 .25043 L
.22 .25675 L
.224 .26461 L
.228 .27417 L
.232 .28552 L
.236 .29862 L
.24 .31335 L
.244 .32939 L
.248 .34627 L
.252 .36337 L
.256 .37988 L
.26 .39495 L
.264 .40764 L
.268 .41711 L
.272 .42261 L
.276 .42365 L
.28 .42001 L
.284 .4118 L
.288 .39947 L
.292 .38376 L
.296 .36565 L
.3 .34623 L
.304 .3266 L
.308 .30777 L
.312 .29057 L
.316 .27558 L
.32 .26311 L
.324 .2532 L
.328 .24572 L
.332 .24035 L
.336 .23671 L
.34 .23439 L
.344 .23302 L
.348 .23229 L
.352 .23194 L
.356 .2318 L
.36 .23177 L
.364 .23177 L
.368 .23179 L
.372 .2318 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .2318 L
.632 .23179 L
.636 .23177 L
.64 .23177 L
.644 .2318 L
.648 .23194 L
.652 .23229 L
.656 .23302 L
.66 .23439 L
.664 .23671 L
.668 .24035 L
.672 .24572 L
.676 .2532 L
.68 .26311 L
.684 .27558 L
.688 .29057 L
.692 .30777 L
.696 .3266 L
.7 .34623 L
.704 .36565 L
.708 .38376 L
.712 .39947 L
.716 .4118 L
.72 .42001 L
.724 .42365 L
.728 .42261 L
.732 .41711 L
.736 .40764 L
.74 .39495 L
.744 .37988 L
.748 .36337 L
.752 .34627 L
.756 .32939 L
.76 .31335 L
.764 .29862 L
.768 .28552 L
.772 .27417 L
.776 .26461 L
.78 .25675 L
.784 .25043 L
.788 .24547 L
.792 .24166 L
.796 .23878 L
.8 .23666 L
Mistroke
.804 .23513 L
.808 .23403 L
.812 .23327 L
.816 .23275 L
.82 .2324 L
.824 .23217 L
.828 .23201 L
.832 .23192 L
.836 .23186 L
.84 .23182 L
.844 .2318 L
.848 .23178 L
.852 .23177 L
.856 .23177 L
.86 .23177 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35315 L
.148 .35315 L
.152 .35314 L
.156 .35312 L
.16 .3531 L
.164 .35305 L
.168 .35298 L
.172 .35286 L
.176 .35268 L
.18 .3524 L
.184 .35199 L
.188 .35136 L
.192 .35046 L
.196 .34916 L
.2 .34733 L
Mistroke
.204 .3448 L
.208 .34138 L
.212 .33683 L
.216 .33092 L
.22 .3234 L
.224 .31403 L
.228 .30264 L
.232 .28913 L
.236 .27352 L
.24 .25597 L
.244 .23687 L
.248 .21675 L
.252 .1964 L
.256 .17672 L
.26 .15878 L
.264 .14366 L
.268 .13239 L
.272 .12583 L
.276 .1246 L
.28 .12894 L
.284 .13873 L
.288 .15342 L
.292 .17213 L
.296 .19371 L
.3 .21685 L
.304 .24024 L
.308 .26267 L
.312 .28316 L
.316 .30102 L
.32 .31588 L
.324 .32768 L
.328 .3366 L
.332 .343 L
.336 .34733 L
.34 .35009 L
.344 .35172 L
.348 .3526 L
.352 .35302 L
.356 .35318 L
.36 .35322 L
.364 .35321 L
.368 .35319 L
.372 .35317 L
.376 .35317 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35315 L
.632 .35313 L
.636 .35312 L
.64 .35311 L
.644 .35315 L
.648 .35331 L
.652 .35373 L
.656 .3546 L
.66 .35623 L
.664 .35899 L
.668 .36333 L
.672 .36973 L
.676 .37864 L
.68 .39044 L
.684 .40531 L
.688 .42317 L
.692 .44366 L
.696 .46608 L
.7 .48947 L
.704 .51261 L
.708 .53419 L
.712 .55291 L
.716 .5676 L
.72 .57738 L
.724 .58172 L
.728 .58049 L
.732 .57394 L
.736 .56266 L
.74 .54754 L
.744 .5296 L
.748 .50993 L
.752 .48957 L
.756 .46946 L
.76 .45035 L
.764 .43281 L
.768 .41719 L
.772 .40368 L
.776 .39229 L
.78 .38293 L
.784 .3754 L
.788 .36949 L
.792 .36495 L
.796 .36153 L
.8 .359 L
Mistroke
.804 .35717 L
.808 .35587 L
.812 .35496 L
.816 .35434 L
.82 .35392 L
.824 .35364 L
.828 .35346 L
.832 .35335 L
.836 .35327 L
.84 .35323 L
.844 .3532 L
.848 .35319 L
.852 .35318 L
.856 .35317 L
.86 .35317 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23178 L
.156 .2318 L
.16 .23182 L
.164 .23186 L
.168 .23192 L
.172 .23201 L
.176 .23217 L
.18 .2324 L
.184 .23275 L
.188 .23327 L
.192 .23403 L
.196 .23513 L
.2 .23666 L
Mistroke
.204 .23878 L
.208 .24166 L
.212 .24547 L
.216 .25043 L
.22 .25675 L
.224 .26461 L
.228 .27417 L
.232 .28552 L
.236 .29862 L
.24 .31335 L
.244 .32939 L
.248 .34627 L
.252 .36337 L
.256 .37988 L
.26 .39495 L
.264 .40764 L
.268 .41711 L
.272 .42261 L
.276 .42365 L
.28 .42001 L
.284 .4118 L
.288 .39947 L
.292 .38376 L
.296 .36565 L
.3 .34623 L
.304 .3266 L
.308 .30777 L
.312 .29057 L
.316 .27558 L
.32 .26311 L
.324 .2532 L
.328 .24572 L
.332 .24035 L
.336 .23671 L
.34 .23439 L
.344 .23302 L
.348 .23229 L
.352 .23194 L
.356 .2318 L
.36 .23177 L
.364 .23177 L
.368 .23179 L
.372 .2318 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .2318 L
.632 .23179 L
.636 .23177 L
.64 .23177 L
.644 .2318 L
.648 .23194 L
.652 .23229 L
.656 .23302 L
.66 .23439 L
.664 .23671 L
.668 .24035 L
.672 .24572 L
.676 .2532 L
.68 .26311 L
.684 .27558 L
.688 .29057 L
.692 .30777 L
.696 .3266 L
.7 .34623 L
.704 .36565 L
.708 .38376 L
.712 .39947 L
.716 .4118 L
.72 .42001 L
.724 .42365 L
.728 .42261 L
.732 .41711 L
.736 .40764 L
.74 .39495 L
.744 .37988 L
.748 .36337 L
.752 .34627 L
.756 .32939 L
.76 .31335 L
.764 .29862 L
.768 .28552 L
.772 .27417 L
.776 .26461 L
.78 .25675 L
.784 .25043 L
.788 .24547 L
.792 .24166 L
.796 .23878 L
.8 .23666 L
Mistroke
.804 .23513 L
.808 .23403 L
.812 .23327 L
.816 .23275 L
.82 .2324 L
.824 .23217 L
.828 .23201 L
.832 .23192 L
.836 .23186 L
.84 .23182 L
.844 .2318 L
.848 .23178 L
.852 .23177 L
.856 .23177 L
.86 .23177 L
.864 .23176 L
.868 .23176 L
.872 .23176 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`00009oo`<0009oo`05001oogooOol00003Ool01@00Ool007oo0000
17oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo0000
0P0017oo00D007ooOomoo`00009oo`8000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo
00<007ooOol02Woo000LOol2000DOol2000:Ool00`00Oomoo`0QOol00`00Oomoo`08Ool2000ROol0
01aoo`03001oogoo01Aoo`03001oogoo00Qoo`03001oogoo025oo`03001oogoo00Qoo`03001oogoo
025oo`0077oo0P005Goo00<007ooOol01goo00<007ooOol08Woo00<007ooOol01goo00<007ooOol0
8Woo000LOol00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`0SOol00`00Oomoo`06Ool00`00
Oomoo`0ROol000]oo`8000Aoo`04001oogooOol50002Ool2000FOol00`00Oomoo`05Ool00`00Oomo
o`0TOol00`00Oomoo`06Ool00`00Oomoo`0ROol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00<007ooOol05Woo00<007ooOol017oo00<007ooOol097oo00<007ooOol01Goo00<007ooOol08goo
000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P005goo00<007ooOol017oo00<007ooOol09Goo
00<007ooOol017oo00<007ooOol08goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0001Qoo`03
001oogoo00Aoo`03001oogoo02Eoo`03001oogoo00Aoo`03001oogoo02=oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2000GOol00`00Oomoo`04Ool00`00Oomoo`0UOol00`00Oomoo`03
Ool00`00Oomoo`0TOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol05Woo
00<007ooOol017oo00<007ooOol09Goo00<007ooOol00goo00<007ooOol097oo000;Ool20009Ool3
0003Ool2000HOol00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`02Ool00`00Oomoo`0TOol0
01aoo`03001oogoo01Moo`03001oogoo009oo`03001oogoo02Moo`03001oogoo009oo`03001oogoo
02Aoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P0067oo00<007ooOol00Woo00<007ooOol0
9goo00<007ooOol00Woo00<007ooOol097oo000:Ool01000Oomoo`002Woo00D007ooOomoo`0001Uo
o`03001oogoo009oo`03001oogoo02Moo`03001oogoo009oo`03001oogoo02Aoo`002Woo00@007oo
Ool000Moo`D0009oo`8001Uoo`04001oogoo000ZOol01@00Oomoogoo00009goo000:Ool01000Oomo
o`001goo00@007ooOol000=oo`03001oogoo01Qoo`04001oogoo000ZOol01@00Oomoogoo00009goo
000:Ool01000Oomoo`0027oo00<007oo00000goo0P006Woo00<007oo0000:goo00<007oo0000:7oo
000:Ool01000Oomoo`002Goo0P000goo00<007ooOol06Goo00<007oo0000:goo00<007oo0000:7oo
000;Ool2000;Ool01000Oomoogoo0P006Woo0P00;Goo00<007ooOol09goo000LOol00`00Oomoo`1b
Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00
Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<0
07ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;
Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo
0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00
Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007oo
Ool0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0
Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<0
07ooOol00Woo0`00N7oo000:Ool01000Oomoo`001goo00D007ooOomoo`0007Moo`000goo1@000Woo
00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002goo0P002Goo0`000goo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`00
0goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo
1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool40003Ool2001cOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Oomoo`03Ool2001cOol000]oo`8000Yoo`8000=oo`03001oogoo
01Uoo`8005Moo`0077oo0P006Woo0P00Egoo000LOol00`00Oomoo`0IOol00`00Ool0001FOol000]o
o`8000Aoo`03001oogoo00=oo`<0009oo`8001Yoo`03001oo`0005Ioo`002Woo00@007ooOol000Yo
o`05001oogooOol0000JOol01000Oomoo`00EWoo0003Ool50002Ool01000Oomoo`001goo1@000Woo
00<007ooOol067oo00@007ooOol005Ioo`002Woo00@007ooOol000Moo`04001oogoo0003Ool2000I
Ool01000Oomoo`00EWoo000:Ool01000Oomoo`0027oo00<007oo00000goo00<007ooOol067oo00D0
07ooOomoo`0005Eoo`002Woo00@007ooOol000Uoo`8000=oo`8001Qoo`03001oogoo009oo`03001o
ogoo05=oo`002goo0P002goo00D007ooOomoo`0001Uoo`03001oogoo009oo`03001oogoo05=oo`00
77oo0P0067oo00<007ooOol00Woo00<007ooOol0Dgoo000LOol00`00Oomoo`0GOol00`00Oomoo`02
Ool00`00Oomoo`1COol000]oo`8000Aoo`04001oogooOol50002Ool2000GOol00`00Oomoo`04Ool0
0`00Oomoo`1BOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol05Woo00<007oo
Ool017oo00<007ooOol0DWoo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo00<007oo
Ool05Woo00<007ooOol017oo00<007ooOol0DWoo000:Ool01000Oomoo`002Woo00@007ooOomoo`80
00ioo`<000Aoo`<000Ioo`03001oo`00008000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eo
o`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`0<Ool01@00Oomoogoo00000Woo00@007ooOol000Ioo`04001oogoo
0004Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo
00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol0
07oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`80015oo`05001oogoo001oo`020006Ool01000Oomoo`0017oo00@007ooOol0009oo`04
001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
0goo000;Ool20009Ool30003Ool00`00Oomoo`0@Ool01@00Oomoo`00Ool00P001Woo00@007ooOol0
00Aoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo
00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007oo000000Moo`03001o
o`0000Aoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@0
00=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`800003Ool007oo00Io
o`<000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo
00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P002Goo0P001Goo0P0017oo
0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`80
00Ioo`0077oo0P0057oo0P002Woo00<007ooOol0D7oo000LOol00`00Oomoo`0AOol3000<Ool00`00
Oomoo`1?Ool001aoofT000aoo`0077oo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Goo
00<007ooOol017oo00<007ooOol02Woo0P0057oo00<007ooOol02Woo000LOol20014Ool00`00Oomo
o`08Ool2000ROol001aoo`03001oogoo04=oo`03001oogoo00Qoo`03001oogoo025oo`0077oo0P00
A7oo00<007ooOol01goo00<007ooOol08Woo000LOol00`00Oomoo`14Ool00`00Oomoo`06Ool00`00
Oomoo`0ROol001aoo`03001oogoo04Aoo`03001oogoo00Ioo`03001oogoo029oo`002goo0P0017oo
00@007ooOomoo`D0009oo`8004Eoo`03001oogoo00Ioo`03001oogoo029oo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool00`00Oomoo`14Ool00`00Oomoo`05Ool00`00Oomoo`0SOol000Yoo`04
001oogoo0009Ool00`00Oomoo`02Ool20016Ool00`00Oomoo`04Ool00`00Oomoo`0SOol000Yoo`04
001oogoo000:Ool01@00Oomoogoo0000Agoo00<007ooOol017oo00<007ooOol08goo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`8004Ioo`03001oogoo00Aoo`03001oogoo02=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`15Ool00`00Oomoo`03Ool00`00Oomo
o`0TOol000]oo`8000Uoo`<000=oo`03001oogoo04Eoo`03001oogoo00=oo`03001oogoo02Aoo`00
77oo0P00Agoo00<007ooOol00Woo00<007ooOol097oo000LOol00`00Oomoo`16Ool00`00Oomoo`02
Ool00`00Oomoo`0TOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8004Moo`03001oogoo009o
o`03001oogoo02Aoo`002Woo00@007ooOol000Yoo`05001oogooOol00018Ool00`00Oomoo`02Ool0
0`00Oomoo`0TOol000Yoo`04001oogoo0007Ool50002Ool20017Ool01@00Oomoogoo00009goo000:
Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo04Ioo`05001oogooOol0000WOol000Yo
o`04001oogoo0008Ool00`00Ool00003Ool20017Ool01@00Oomoogoo00009goo000:Ool01000Oomo
o`002Goo0P000goo00<007ooOol0Agoo00@007ooOol002Moo`002goo0P002goo00D007ooOomoo`00
04Uoo`03001oo`0002Qoo`0077oo0P00BGoo0P00:7oo000LOol00`00Oomoo`18Ool00`00Oomoo`0W
Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05
001oogooOol0001dOol000=oo`D0009oo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001o
ogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo0000
0goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01000
Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogooOol50002Ool2001c
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol03Goo0`0017oo0P002Goo0`00
17oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`00
17oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo0P003Goo00D007ooOomo
o`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05
001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo
000:Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`04001oogoo0002Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P004Goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool0
1000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo
10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Ao
o`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P003Goo00<0
07ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo
00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@00
0goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Ao
o`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`06001oogooOol007oo1000
0Woo00D007ooOomoo`0000=oo`03001oo`00008000Aoo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`03001oo`00008000Aoo`05001oogooOol00002Ool400000goo
001oo`02Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol2000DOol2
000:Ool00`00Oomoo`0QOol00`00Oomoo`08Ool2000ROol001aoo`03001oogoo01Aoo`03001oogoo
00Qoo`03001oogoo025oo`03001oogoo00Qoo`03001oogoo025oo`0077oo0P005Goo00<007ooOol0
1goo00<007ooOol08Woo00<007ooOol01goo00<007ooOol08Woo000LOol00`00Oomoo`0EOol00`00
Oomoo`06Ool00`00Oomoo`0SOol00`00Oomoo`06Ool00`00Oomoo`0ROol000]oo`8000Aoo`04001o
ogooOol50002Ool2000FOol00`00Oomoo`06Ool00`00Oomoo`0SOol00`00Oomoo`06Ool00`00Oomo
o`0ROol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol05Woo00<007ooOol017oo
00<007ooOol097oo00<007ooOol01Goo00<007ooOol08goo000:Ool01000Oomoo`002Goo00<007oo
Ool00Woo0P005goo00<007ooOol017oo00<007ooOol09Goo00<007ooOol017oo00<007ooOol08goo
000:Ool01000Oomoo`002Woo00D007ooOomoo`0001Qoo`03001oogoo00Aoo`03001oogoo02Eoo`03
001oogoo00Aoo`03001oogoo02=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000G
Ool00`00Oomoo`04Ool00`00Oomoo`0UOol00`00Oomoo`04Ool00`00Oomoo`0SOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol05Woo00<007ooOol017oo00<007ooOol09Goo
00<007ooOol00goo00<007ooOol097oo000;Ool20009Ool30003Ool2000HOol00`00Oomoo`02Ool0
0`00Oomoo`0WOol00`00Oomoo`02Ool00`00Oomoo`0TOol001aoo`03001oogoo01Moo`03001oogoo
009oo`03001oogoo02Moo`03001oogoo009oo`03001oogoo02Aoo`002goo0P0017oo00<007ooOol0
0goo0`000Woo0P0067oo00<007ooOol00Woo00<007ooOol09goo00<007ooOol00Woo00<007ooOol0
97oo000:Ool01000Oomoo`002Woo00D007ooOomoo`0001Uoo`03001oogoo009oo`03001oogoo02Mo
o`03001oogoo009oo`03001oogoo02Aoo`002Woo00@007ooOol000Moo`D0009oo`8001Uoo`04001o
ogoo000ZOol01@00Oomoogoo00009goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001o
ogoo01Qoo`04001oogoo000ZOol01@00Oomoogoo00009goo000:Ool01000Oomoo`0027oo00<007oo
00000goo0P006Goo00@007ooOol002]oo`04001oogoo000WOol000Yoo`04001oogoo0009Ool20003
Ool00`00Oomoo`0IOol00`00Ool0000[Ool00`00Ool0000XOol000]oo`8000]oo`04001oogooOol2
000JOol2000]Ool2000XOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`00
0goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo
0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<0
07ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`00
0goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=o
o`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0
Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(760\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23178 L
.144 .2318 L
.148 .23182 L
.152 .23186 L
.156 .23193 L
.16 .23203 L
.164 .23218 L
.168 .23242 L
.172 .23278 L
.176 .23331 L
.18 .23408 L
.184 .23518 L
.188 .23673 L
.192 .23887 L
.196 .24175 L
.2 .24556 L
Mistroke
.204 .25052 L
.208 .25682 L
.212 .26466 L
.216 .27417 L
.22 .28545 L
.224 .29849 L
.228 .31313 L
.232 .32908 L
.236 .34588 L
.24 .36291 L
.244 .37939 L
.248 .39446 L
.252 .4072 L
.256 .41676 L
.26 .4224 L
.264 .4236 L
.268 .42014 L
.272 .4121 L
.276 .39991 L
.28 .38431 L
.284 .36624 L
.288 .3468 L
.292 .32711 L
.296 .30817 L
.3 .29084 L
.304 .27571 L
.308 .26311 L
.312 .2531 L
.316 .24555 L
.32 .24015 L
.324 .23651 L
.328 .23422 L
.332 .23288 L
.336 .23218 L
.34 .23187 L
.344 .23176 L
.348 .23174 L
.352 .23176 L
.356 .23179 L
.36 .2318 L
.364 .23181 L
.368 .23182 L
.372 .23182 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23182 L
.632 .23182 L
.636 .23181 L
.64 .2318 L
.644 .23179 L
.648 .23176 L
.652 .23174 L
.656 .23176 L
.66 .23187 L
.664 .23218 L
.668 .23288 L
.672 .23422 L
.676 .23651 L
.68 .24015 L
.684 .24555 L
.688 .2531 L
.692 .26311 L
.696 .27571 L
.7 .29084 L
.704 .30817 L
.708 .32711 L
.712 .3468 L
.716 .36624 L
.72 .38431 L
.724 .39991 L
.728 .4121 L
.732 .42014 L
.736 .4236 L
.74 .4224 L
.744 .41676 L
.748 .4072 L
.752 .39446 L
.756 .37939 L
.76 .36291 L
.764 .34588 L
.768 .32908 L
.772 .31313 L
.776 .29849 L
.78 .28545 L
.784 .27417 L
.788 .26466 L
.792 .25682 L
.796 .25052 L
.8 .24556 L
Mistroke
.804 .24175 L
.808 .23887 L
.812 .23673 L
.816 .23518 L
.82 .23408 L
.824 .23331 L
.828 .23278 L
.832 .23242 L
.836 .23218 L
.84 .23203 L
.844 .23193 L
.848 .23186 L
.852 .23182 L
.856 .2318 L
.86 .23178 L
.864 .23177 L
.868 .23177 L
.872 .23177 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35315 L
.136 .35315 L
.14 .35314 L
.144 .35312 L
.148 .35309 L
.152 .35304 L
.156 .35297 L
.16 .35285 L
.164 .35266 L
.168 .35238 L
.172 .35195 L
.176 .35132 L
.18 .3504 L
.184 .34909 L
.188 .34724 L
.192 .3447 L
.196 .34127 L
.2 .33672 L
Mistroke
.204 .33082 L
.208 .32331 L
.212 .31398 L
.216 .30264 L
.22 .2892 L
.224 .27368 L
.228 .25624 L
.232 .23723 L
.236 .21722 L
.24 .19694 L
.244 .17731 L
.248 .15936 L
.252 .14418 L
.256 .1328 L
.26 .12609 L
.264 .12466 L
.268 .12879 L
.272 .13837 L
.276 .15289 L
.28 .17148 L
.284 .19301 L
.288 .21617 L
.292 .23964 L
.296 .26219 L
.3 .28284 L
.304 .30087 L
.308 .31588 L
.312 .3278 L
.316 .33679 L
.32 .34323 L
.324 .34757 L
.328 .3503 L
.332 .35189 L
.336 .35272 L
.34 .3531 L
.344 .35323 L
.348 .35324 L
.352 .35322 L
.356 .35319 L
.36 .35317 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35315 L
.644 .35313 L
.648 .3531 L
.652 .35308 L
.656 .3531 L
.66 .35322 L
.664 .3536 L
.668 .35444 L
.672 .35602 L
.676 .35876 L
.68 .3631 L
.684 .36953 L
.688 .37853 L
.692 .39044 L
.696 .40546 L
.7 .42348 L
.704 .44413 L
.708 .46669 L
.712 .49016 L
.716 .51332 L
.72 .53484 L
.724 .55344 L
.728 .56796 L
.732 .57754 L
.736 .58167 L
.74 .58024 L
.744 .57352 L
.748 .56214 L
.752 .54696 L
.756 .52902 L
.76 .50939 L
.764 .48911 L
.768 .46909 L
.772 .45009 L
.776 .43265 L
.78 .41712 L
.784 .40368 L
.788 .39235 L
.792 .38301 L
.796 .37551 L
.8 .3696 L
Mistroke
.804 .36506 L
.808 .36162 L
.812 .35908 L
.816 .35724 L
.82 .35592 L
.824 .355 L
.828 .35437 L
.832 .35395 L
.836 .35366 L
.84 .35348 L
.844 .35336 L
.848 .35328 L
.852 .35323 L
.856 .3532 L
.86 .35319 L
.864 .35318 L
.868 .35317 L
.872 .35317 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23178 L
.144 .2318 L
.148 .23182 L
.152 .23186 L
.156 .23193 L
.16 .23203 L
.164 .23218 L
.168 .23242 L
.172 .23278 L
.176 .23331 L
.18 .23408 L
.184 .23518 L
.188 .23673 L
.192 .23887 L
.196 .24175 L
.2 .24556 L
Mistroke
.204 .25052 L
.208 .25682 L
.212 .26466 L
.216 .27417 L
.22 .28545 L
.224 .29849 L
.228 .31313 L
.232 .32908 L
.236 .34588 L
.24 .36291 L
.244 .37939 L
.248 .39446 L
.252 .4072 L
.256 .41676 L
.26 .4224 L
.264 .4236 L
.268 .42014 L
.272 .4121 L
.276 .39991 L
.28 .38431 L
.284 .36624 L
.288 .3468 L
.292 .32711 L
.296 .30817 L
.3 .29084 L
.304 .27571 L
.308 .26311 L
.312 .2531 L
.316 .24555 L
.32 .24015 L
.324 .23651 L
.328 .23422 L
.332 .23288 L
.336 .23218 L
.34 .23187 L
.344 .23176 L
.348 .23174 L
.352 .23176 L
.356 .23179 L
.36 .2318 L
.364 .23181 L
.368 .23182 L
.372 .23182 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23182 L
.632 .23182 L
.636 .23181 L
.64 .2318 L
.644 .23179 L
.648 .23176 L
.652 .23174 L
.656 .23176 L
.66 .23187 L
.664 .23218 L
.668 .23288 L
.672 .23422 L
.676 .23651 L
.68 .24015 L
.684 .24555 L
.688 .2531 L
.692 .26311 L
.696 .27571 L
.7 .29084 L
.704 .30817 L
.708 .32711 L
.712 .3468 L
.716 .36624 L
.72 .38431 L
.724 .39991 L
.728 .4121 L
.732 .42014 L
.736 .4236 L
.74 .4224 L
.744 .41676 L
.748 .4072 L
.752 .39446 L
.756 .37939 L
.76 .36291 L
.764 .34588 L
.768 .32908 L
.772 .31313 L
.776 .29849 L
.78 .28545 L
.784 .27417 L
.788 .26466 L
.792 .25682 L
.796 .25052 L
.8 .24556 L
Mistroke
.804 .24175 L
.808 .23887 L
.812 .23673 L
.816 .23518 L
.82 .23408 L
.824 .23331 L
.828 .23278 L
.832 .23242 L
.836 .23218 L
.84 .23203 L
.844 .23193 L
.848 .23186 L
.852 .23182 L
.856 .2318 L
.86 .23178 L
.864 .23177 L
.868 .23177 L
.872 .23177 L
.876 .23176 L
.88 .23176 L
.884 .23176 L
.888 .23176 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00H007ooOomoo`00Ool30003Ool01@00Oomoogoo00000goo0P000Woo00<007ooOol0
0Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000Aoo`05001oogooOol00003Ool300000goo001oo`02Ool01@00Oomoogoo00000goo00<007oo
Ool00Woo00<007ooOol02Woo000LOol2000COol00`00Oomoo`08Ool2000UOol00`00Oomoo`08Ool2
000QOol001aoo`03001oogoo01=oo`03001oogoo00Moo`03001oogoo02Aoo`03001oogoo00Qoo`03
001oogoo021oo`0077oo0P0057oo00<007ooOol01goo00<007ooOol09Goo00<007ooOol01goo00<0
07ooOol087oo000LOol00`00Oomoo`0DOol00`00Oomoo`06Ool00`00Oomoo`0UOol00`00Oomoo`06
Ool00`00Oomoo`0QOol000]oo`8000Aoo`04001oogooOol50002Ool2000EOol00`00Oomoo`05Ool0
0`00Oomoo`0WOol00`00Oomoo`05Ool00`00Oomoo`0QOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00<007ooOol057oo00<007ooOol01Goo00<007ooOol09goo00<007ooOol017oo00<007oo
Ool08Woo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P005Goo00<007ooOol01Goo00<007oo
Ool09goo00<007ooOol017oo00<007ooOol08Woo000:Ool01000Oomoo`002Woo00D007ooOomoo`00
01Moo`03001oogoo00Aoo`03001oogoo02Moo`03001oogoo00Aoo`03001oogoo029oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2000FOol00`00Oomoo`03Ool00`00Oomoo`0XOol00`00
Oomoo`04Ool00`00Oomoo`0ROol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool05Goo00<007ooOol00goo00<007ooOol0:7oo00<007ooOol017oo00<007ooOol08Woo000;Ool2
0009Ool30003Ool2000GOol00`00Oomoo`02Ool00`00Oomoo`0YOol00`00Oomoo`02Ool00`00Oomo
o`0SOol001aoo`03001oogoo01Ioo`03001oogoo009oo`03001oogoo02Uoo`03001oogoo009oo`03
001oogoo02=oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P005goo00<007ooOol00Woo00<0
07ooOol0:Goo00<007ooOol00Woo00<007ooOol08goo000:Ool01000Oomoo`002Woo00D007ooOomo
o`0001Qoo`03001oogoo009oo`03001oogoo02Uoo`03001oogoo009oo`03001oogoo02=oo`002Woo
00@007ooOol000Moo`D0009oo`8001Moo`05001oogooOol0000]Ool01000Oomoo`009Woo000:Ool0
1000Oomoo`001goo00@007ooOol000=oo`03001oogoo01Moo`04001oogoo000]Ool01000Oomoo`00
9Woo000:Ool01000Oomoo`0027oo00<007oo00000goo0P0067oo00@007ooOol002eoo`04001oogoo
000VOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`0HOol2000^Ool00`00Ool0000WOol0
00]oo`8000]oo`04001oogooOol2000IOol2000_Ool2000WOol001aoo`03001oogoo079oo`002goo
0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yo
o`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04
Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yo
o`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2
001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001ao
o`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol0
01Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Io
o`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02
Ool3001hOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001c
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`@0
00=oo`8007=oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`03001oogoo079oo`002Woo00@0
07ooOol000Qoo`03001oogoo00=oo`8007=oo`002goo0P002Woo0P000goo00<007ooOol067oo0P00
F7oo000LOol2000IOol2001HOol001aoo`03001oogoo01Moo`03001oo`0005Qoo`002goo0P0017oo
00<007ooOol00goo0`000Woo0P0067oo00@007ooOol005Moo`002Woo00@007ooOol000Yoo`05001o
ogooOol0000IOol01000Oomoo`00Egoo0003Ool50002Ool01000Oomoo`001goo1@000Woo00<007oo
Ool05goo00@007ooOol005Moo`002Woo00@007ooOol000Moo`04001oogoo0003Ool2000GOol01@00
Oomoogoo0000Egoo000:Ool01000Oomoo`0027oo00<007oo00000goo00<007ooOol05Woo00<007oo
Ool00Woo00<007ooOol0E7oo000:Ool01000Oomoo`002Goo0P000goo0P005goo00<007ooOol00Woo
00<007ooOol0E7oo000;Ool2000;Ool01@00Oomoogoo000067oo00<007ooOol00Woo00<007ooOol0
E7oo000LOol2000GOol00`00Oomoo`02Ool00`00Oomoo`1DOol001aoo`03001oogoo01Ioo`03001o
ogoo009oo`03001oogoo05Aoo`002goo0P0017oo00@007ooOomoo`D0009oo`8001Ioo`03001oogoo
00=oo`03001oogoo05Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0EOol0
0`00Oomoo`03Ool00`00Oomoo`1DOol000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool0
0`00Oomoo`0EOol00`00Oomoo`04Ool00`00Oomoo`1COol000Yoo`04001oogoo000:Ool01000Oomo
ogoo0P003Woo0`0017oo0P001Woo00<007ooOol00`0017oo0P0017oo0P001Goo0`000goo0`0017oo
0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo00aoo`05001oogooOol00002Ool200000goo001oo`04Ool0
1@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@0
07ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eo
o`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2000AOol00`00Oomoo`0200000goo001oo`04Ool01@00Oomoogoo0000
17oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol00goo000;Ool20009Ool30003Ool00`00Oomoo`0@Ool00`00Oomoo`02
00000goo001oo`04Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=
Ool40003Ool200000goo001oo`05Ool01000Oomoo`0017oo00@007ooOol0009oo`04001oogoo0005
Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol0
37oo00<007ooOol017oo00@007ooOol000Ioo`04001oo`000004Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03
001oogoo00aoo`D0009oo`<000Moo`04001oogoo0005Ool20004Ool20006Ool01000Oomoogoo1@00
0goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000COol00`00
Oomoo`09Ool00`00Oomoo`1AOol001aoo`03001oogoo011oo`8000aoo`80059oo`0077ooJ@0037oo
000LOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`05Ool00`00Oomo
o`0:Ool2000COol00`00Oomoo`0:Ool001aoo`8004Eoo`03001oogoo00Qoo`80025oo`0077oo00<0
07ooOol0A7oo00<007ooOol027oo00<007ooOol087oo000LOol20016Ool00`00Oomoo`07Ool00`00
Oomoo`0POol001aoo`03001oogoo04Eoo`03001oogoo00Ioo`03001oogoo025oo`0077oo00<007oo
Ool0AGoo00<007ooOol01Woo00<007ooOol08Goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00
Agoo00<007ooOol01Goo00<007ooOol08Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03
001oogoo04Ioo`03001oogoo00Aoo`03001oogoo029oo`002Woo00@007ooOol000Uoo`03001oogoo
009oo`8004Moo`03001oogoo00Aoo`03001oogoo029oo`002Woo00@007ooOol000Yoo`05001oogoo
Ool00018Ool00`00Oomoo`04Ool00`00Oomoo`0ROol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00Agoo00<007ooOol017oo00<007ooOol08Woo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo04Ioo`03001oogoo00Aoo`03001oogoo029oo`002goo0P002Goo0`00
0goo00<007ooOol0AWoo00<007ooOol017oo00<007ooOol08Woo000LOol20018Ool00`00Oomoo`02
Ool00`00Oomoo`0SOol001aoo`03001oogoo04Moo`03001oogoo009oo`03001oogoo02=oo`002goo
0P0017oo00<007ooOol00goo0`000Woo0P00B7oo00<007ooOol00Woo00<007ooOol08goo000:Ool0
1000Oomoo`002Woo00D007ooOomoo`0004Uoo`03001oogoo009oo`03001oogoo02=oo`002Woo00@0
07ooOol000Moo`D0009oo`8004Uoo`04001oogoo000VOol000Yoo`04001oogoo0007Ool01000Oomo
o`000goo00<007ooOol0B7oo00@007ooOol002Ioo`002Woo00@007ooOol000Qoo`03001oo`0000=o
o`8004Uoo`04001oogoo000VOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`18Ool01000
Oomoo`009Woo000;Ool2000;Ool01@00Oomoogoo0000BWoo00@007ooOol002Ioo`0077oo0P00BWoo
0P009goo000LOol00`00Oomoo`19Ool00`00Oomoo`0VOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=o
o`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000=oo`D0009oo`04
001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo
0P000goo00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1b
Ool000]oo`8000Aoo`04001oogooOol50002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo
0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomo
o`002Goo00<007ooOol00Woo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo
00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol0
07oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`002Woo00D007ooOomo
o`00019oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo00@007ooOol0009oo`03001o
ogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007oo
Ool000Eoo`002goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`8000Ao
o`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo
00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P0017oo
0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`80
00Ioo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomoo`00
00=oo`03001oogoo009oo`04001oogooOol50003Ool01@00Oomoogoo00000goo0`0000=oo`00Ool0
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol0
0P0017oo00D007ooOomoo`0000=oo`D000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00
Oomoo`0:Ool001aoo`8001=oo`03001oogoo00Uoo`03001oogoo02=oo`03001oogoo00Qoo`80025o
o`0077oo00<007ooOol04goo00<007ooOol01goo00<007ooOol097oo00<007ooOol027oo00<007oo
Ool087oo000LOol2000DOol00`00Oomoo`07Ool00`00Oomoo`0UOol00`00Oomoo`07Ool00`00Oomo
o`0POol001aoo`03001oogoo01Aoo`03001oogoo00Ioo`03001oogoo02Eoo`03001oogoo00Ioo`03
001oogoo025oo`002goo0P0017oo00@007ooOomoo`D0009oo`8001Eoo`03001oogoo00Ioo`03001o
ogoo02Eoo`03001oogoo00Ioo`03001oogoo025oo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool00`00Oomoo`0DOol00`00Oomoo`05Ool00`00Oomoo`0WOol00`00Oomoo`04Ool00`00Oomoo`0R
Ool000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000EOol00`00Oomoo`05Ool00`00Oomoo`0W
Ool00`00Oomoo`04Ool00`00Oomoo`0ROol000Yoo`04001oogoo000:Ool01@00Oomoogoo00005goo
00<007ooOol017oo00<007ooOol09goo00<007ooOol017oo00<007ooOol08Woo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`8001Ioo`03001oogoo00=oo`03001oogoo02Qoo`03001oogoo
00Aoo`03001oogoo029oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0E
Ool00`00Oomoo`03Ool00`00Oomoo`0XOol00`00Oomoo`04Ool00`00Oomoo`0ROol000]oo`8000Uo
o`<000=oo`8001Moo`03001oogoo009oo`03001oogoo02Uoo`03001oogoo009oo`03001oogoo02=o
o`0077oo00<007ooOol05Woo00<007ooOol00Woo00<007ooOol0:Goo00<007ooOol00Woo00<007oo
Ool08goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000GOol00`00Oomoo`02Ool00`00Oomo
o`0YOol00`00Oomoo`02Ool00`00Oomoo`0SOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000
67oo00<007ooOol00Woo00<007ooOol0:Goo00<007ooOol00Woo00<007ooOol08goo000:Ool01000
Oomoo`001goo1@000Woo0P005goo00D007ooOomoo`0002eoo`04001oogoo000VOol000Yoo`04001o
ogoo0007Ool01000Oomoo`000goo00<007ooOol05goo00@007ooOol002eoo`04001oogoo000VOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2000HOol01000Oomoo`00;Goo00@007ooOol002Io
o`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo01Moo`03001oo`0002ioo`04001oogoo000V
Ool000]oo`8000]oo`04001oogooOol2000IOol2000_Ool2000WOol001aoo`03001oogoo079oo`00
2goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol0
00Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomo
o`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`80
00Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003
Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol0
01aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1b
Ool001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol0
01Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(800\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23178 L
.128 .23178 L
.132 .2318 L
.136 .23183 L
.14 .23187 L
.144 .23193 L
.148 .23204 L
.152 .2322 L
.156 .23244 L
.16 .23281 L
.164 .23335 L
.168 .23413 L
.172 .23524 L
.176 .2368 L
.18 .23895 L
.184 .24184 L
.188 .24566 L
.192 .25061 L
.196 .25689 L
.2 .2647 L
Mistroke
.204 .27417 L
.208 .28539 L
.212 .29835 L
.216 .31291 L
.22 .32878 L
.224 .3455 L
.228 .36246 L
.232 .37891 L
.236 .39397 L
.24 .40676 L
.244 .41641 L
.248 .42218 L
.252 .42354 L
.256 .42026 L
.26 .41239 L
.264 .40035 L
.268 .38485 L
.272 .36683 L
.276 .34738 L
.28 .32762 L
.284 .30858 L
.288 .29111 L
.292 .27584 L
.296 .26311 L
.3 .25301 L
.304 .24539 L
.308 .23996 L
.312 .23631 L
.316 .23404 L
.32 .23274 L
.324 .23207 L
.328 .23179 L
.332 .23171 L
.336 .23172 L
.34 .23176 L
.344 .23179 L
.348 .23181 L
.352 .23181 L
.356 .23182 L
.36 .23182 L
.364 .23182 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23182 L
.64 .23182 L
.644 .23182 L
.648 .23181 L
.652 .23181 L
.656 .23179 L
.66 .23176 L
.664 .23172 L
.668 .23171 L
.672 .23179 L
.676 .23207 L
.68 .23274 L
.684 .23404 L
.688 .23631 L
.692 .23996 L
.696 .24539 L
.7 .25301 L
.704 .26311 L
.708 .27584 L
.712 .29111 L
.716 .30858 L
.72 .32762 L
.724 .34738 L
.728 .36683 L
.732 .38485 L
.736 .40035 L
.74 .41239 L
.744 .42026 L
.748 .42354 L
.752 .42218 L
.756 .41641 L
.76 .40676 L
.764 .39397 L
.768 .37891 L
.772 .36246 L
.776 .3455 L
.78 .32878 L
.784 .31291 L
.788 .29835 L
.792 .28539 L
.796 .27417 L
.8 .2647 L
Mistroke
.804 .25689 L
.808 .25061 L
.812 .24566 L
.816 .24184 L
.82 .23895 L
.824 .2368 L
.828 .23524 L
.832 .23413 L
.836 .23335 L
.84 .23281 L
.844 .23244 L
.848 .2322 L
.852 .23204 L
.856 .23193 L
.86 .23187 L
.864 .23183 L
.868 .2318 L
.872 .23178 L
.876 .23178 L
.88 .23177 L
.884 .23177 L
.888 .23177 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35315 L
.124 .35315 L
.128 .35314 L
.132 .35312 L
.136 .35309 L
.14 .35304 L
.144 .35296 L
.148 .35284 L
.152 .35265 L
.156 .35235 L
.16 .35192 L
.164 .35128 L
.168 .35034 L
.172 .34902 L
.176 .34716 L
.18 .3446 L
.184 .34116 L
.188 .33661 L
.192 .33071 L
.196 .32323 L
.2 .31393 L
Mistroke
.204 .30264 L
.208 .28928 L
.212 .27384 L
.216 .2565 L
.22 .2376 L
.224 .21768 L
.228 .19747 L
.232 .17789 L
.236 .15994 L
.24 .14471 L
.244 .13322 L
.248 .12635 L
.252 .12473 L
.256 .12865 L
.26 .13802 L
.264 .15237 L
.268 .17084 L
.272 .1923 L
.276 .21548 L
.28 .23902 L
.284 .26171 L
.288 .28252 L
.292 .30071 L
.296 .31587 L
.3 .32791 L
.304 .33699 L
.308 .34346 L
.312 .3478 L
.316 .35051 L
.32 .35206 L
.324 .35285 L
.328 .35319 L
.332 .35328 L
.336 .35327 L
.34 .35323 L
.344 .3532 L
.348 .35317 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35317 L
.644 .35317 L
.648 .35316 L
.652 .35315 L
.656 .35313 L
.66 .35309 L
.664 .35305 L
.668 .35304 L
.672 .35314 L
.676 .35347 L
.68 .35426 L
.684 .35581 L
.688 .35852 L
.692 .36286 L
.696 .36934 L
.7 .37841 L
.704 .39045 L
.708 .40562 L
.712 .42381 L
.716 .44462 L
.72 .4673 L
.724 .49085 L
.728 .51402 L
.732 .53549 L
.736 .55396 L
.74 .5683 L
.744 .57768 L
.748 .5816 L
.752 .57997 L
.756 .5731 L
.76 .56161 L
.764 .54638 L
.768 .52844 L
.772 .50885 L
.776 .48865 L
.78 .46873 L
.784 .44983 L
.788 .43249 L
.792 .41705 L
.796 .40368 L
.8 .3924 L
Mistroke
.804 .3831 L
.808 .37561 L
.812 .36971 L
.816 .36516 L
.82 .36172 L
.824 .35917 L
.828 .35731 L
.832 .35598 L
.836 .35505 L
.84 .35441 L
.844 .35397 L
.848 .35368 L
.852 .35349 L
.856 .35336 L
.86 .35329 L
.864 .35324 L
.868 .35321 L
.872 .35319 L
.876 .35318 L
.88 .35317 L
.884 .35317 L
.888 .35317 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23178 L
.128 .23178 L
.132 .2318 L
.136 .23183 L
.14 .23187 L
.144 .23193 L
.148 .23204 L
.152 .2322 L
.156 .23244 L
.16 .23281 L
.164 .23335 L
.168 .23413 L
.172 .23524 L
.176 .2368 L
.18 .23895 L
.184 .24184 L
.188 .24566 L
.192 .25061 L
.196 .25689 L
.2 .2647 L
Mistroke
.204 .27417 L
.208 .28539 L
.212 .29835 L
.216 .31291 L
.22 .32878 L
.224 .3455 L
.228 .36246 L
.232 .37891 L
.236 .39397 L
.24 .40676 L
.244 .41641 L
.248 .42218 L
.252 .42354 L
.256 .42026 L
.26 .41239 L
.264 .40035 L
.268 .38485 L
.272 .36683 L
.276 .34738 L
.28 .32762 L
.284 .30858 L
.288 .29111 L
.292 .27584 L
.296 .26311 L
.3 .25301 L
.304 .24539 L
.308 .23996 L
.312 .23631 L
.316 .23404 L
.32 .23274 L
.324 .23207 L
.328 .23179 L
.332 .23171 L
.336 .23172 L
.34 .23176 L
.344 .23179 L
.348 .23181 L
.352 .23181 L
.356 .23182 L
.36 .23182 L
.364 .23182 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23182 L
.64 .23182 L
.644 .23182 L
.648 .23181 L
.652 .23181 L
.656 .23179 L
.66 .23176 L
.664 .23172 L
.668 .23171 L
.672 .23179 L
.676 .23207 L
.68 .23274 L
.684 .23404 L
.688 .23631 L
.692 .23996 L
.696 .24539 L
.7 .25301 L
.704 .26311 L
.708 .27584 L
.712 .29111 L
.716 .30858 L
.72 .32762 L
.724 .34738 L
.728 .36683 L
.732 .38485 L
.736 .40035 L
.74 .41239 L
.744 .42026 L
.748 .42354 L
.752 .42218 L
.756 .41641 L
.76 .40676 L
.764 .39397 L
.768 .37891 L
.772 .36246 L
.776 .3455 L
.78 .32878 L
.784 .31291 L
.788 .29835 L
.792 .28539 L
.796 .27417 L
.8 .2647 L
Mistroke
.804 .25689 L
.808 .25061 L
.812 .24566 L
.816 .24184 L
.82 .23895 L
.824 .2368 L
.828 .23524 L
.832 .23413 L
.836 .23335 L
.84 .23281 L
.844 .23244 L
.848 .2322 L
.852 .23204 L
.856 .23193 L
.86 .23187 L
.864 .23183 L
.868 .2318 L
.872 .23178 L
.876 .23178 L
.88 .23177 L
.884 .23177 L
.888 .23177 L
.892 .23176 L
.896 .23176 L
.9 .23176 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00@007ooOomoo`<00003Ool007oo009oo`05001oogooOol00002Ool20003Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000
Oomoogoo0`000Woo00D007ooOomoo`0000=oo`03001oo`00008000=oo`05001oogooOol00003Ool0
0`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`80019oo`03001oogoo00Qoo`8002Moo`8000Yoo`03
001oogoo01ioo`0077oo00<007ooOol04Goo00<007ooOol027oo00<007ooOol09goo00<007ooOol0
1goo00<007ooOol07goo000LOol2000COol00`00Oomoo`07Ool00`00Oomoo`0WOol00`00Oomoo`07
Ool00`00Oomoo`0OOol001aoo`03001oogoo019oo`03001oogoo00Ioo`03001oogoo02Qoo`03001o
ogoo00Ioo`03001oogoo021oo`002goo0P0017oo00@007ooOomoo`D0009oo`8001Aoo`03001oogoo
00Eoo`03001oogoo02Uoo`03001oogoo00Eoo`03001oogoo021oo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool00`00Oomoo`0COol00`00Oomoo`05Ool00`00Oomoo`0YOol00`00Oomoo`05Ool0
0`00Oomoo`0POol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000DOol00`00Oomoo`05Ool0
0`00Oomoo`0YOol00`00Oomoo`05Ool00`00Oomoo`0POol000Yoo`04001oogoo000:Ool01@00Oomo
ogoo00005Woo00<007ooOol017oo00<007ooOol0:Goo00<007ooOol017oo00<007ooOol08Goo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8001Eoo`03001oogoo00=oo`03001oogoo02]o
o`03001oogoo00=oo`03001oogoo025oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`03Ool00`00Oomoo`0[Ool00`00Oomoo`03Ool00`00Oomoo`0QOol0
00]oo`8000Uoo`<000=oo`8001Eoo`03001oogoo00=oo`03001oogoo02]oo`03001oogoo009oo`03
001oogoo029oo`0077oo00<007ooOol057oo00<007ooOol00goo00<007ooOol0:goo00<007ooOol0
0Woo00<007ooOol08Woo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000FOol01@00Oomoogoo
0000;Woo00<007ooOol00Woo00<007ooOol08Woo000:Ool01000Oomoo`002Woo00D007ooOomoo`00
01Moo`05001oogooOol0000^Ool00`00Oomoo`02Ool00`00Oomoo`0ROol000Yoo`04001oogoo0007
Ool50002Ool2000FOol01@00Oomoogoo0000;goo00D007ooOomoo`0002Aoo`002Woo00@007ooOol0
00Moo`04001oogoo0003Ool00`00Oomoo`0FOol01000Oomoo`00;goo00@007ooOol002Eoo`002Woo
00@007ooOol000Qoo`03001oo`0000=oo`8001Moo`04001oogoo000_Ool01000Oomoo`009Goo000:
Ool01000Oomoo`002Goo0P000goo00<007ooOol05Woo00<007oo0000<Goo0P009Woo000;Ool2000;
Ool01000Oomoogoo0P0067oo0P00<Goo0P009Woo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03
001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo
000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2
001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomo
o`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00
Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol0
01Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00N7oo
000:Ool01000Oomoo`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007ooOol000Moo`05
001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`8007=oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool40003Ool2001c
Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008
Ool00`00Oomoo`03Ool2001cOol000]oo`8000Yoo`8000=oo`03001oogoo01Moo`03001oogoo05Qo
o`0077oo0P005goo00<007oo0000FGoo000LOol00`00Oomoo`0FOol00`00Ool0001IOol000]oo`80
00Aoo`03001oogoo00=oo`<0009oo`8001Moo`04001oogoo001HOol000Yoo`04001oogoo000:Ool0
1@00Oomoogoo000067oo00@007ooOol005Qoo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03
001oogoo01Ioo`04001oogoo001HOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P005Woo
00D007ooOomoo`0005Qoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo01Eoo`05
001oogooOol0001HOol000Yoo`04001oogoo0009Ool20003Ool2000FOol01@00Oomoogoo0000F7oo
000;Ool2000;Ool01@00Oomoogoo00005goo00<007ooOol00Woo00<007ooOol0EGoo000LOol2000E
Ool00`00Oomoo`03Ool00`00Oomoo`1EOol001aoo`03001oogoo01Aoo`03001oogoo00=oo`03001o
ogoo05Eoo`002goo0P0017oo00@007ooOomoo`D0009oo`8001Eoo`03001oogoo00=oo`03001oogoo
05Eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0DOol00`00Oomoo`03Ool0
0`00Oomoo`1EOol000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0DOol0
0`00Oomoo`04Ool00`00Oomoo`1DOol000Yoo`04001oogoo000:Ool01000Oomoogoo0P003Woo0`00
17oo0P001Goo00@007ooOomoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=o
o`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`0<Ool01@00Oomoogoo00000Woo00@007ooOol000Aoo`03001oogoo009oo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00
Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo0P004Goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Goo0`000goo00<007ooOol047oo00@007oo
Ool0009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002
Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo
00=oo`0077oo0P003Goo10000Woo0P000Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo
00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol00goo0P000Woo00<007ooOol00goo
00<007ooOol00P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool0
1000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007oo
Oomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool60002Ool20006Ool01@00
Oomoogoo00001Goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`80
00Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P004Woo00<007ooOol02Goo00<007ooOol0DWoo000L
Ool00`00Oomoo`0?Ool2000<Ool00`00Oomoo`1BOol001aoofT000aoo`0077oo00<007ooOol04Woo
00<007ooOol04Woo00<007ooOol04Goo00<007ooOol01goo00<007ooOol027oo00<007oo00004Woo
00<007ooOol02Woo000LOol20016Ool00`00Oomoo`09Ool00`00Oomoo`0NOol001aoo`03001oogoo
04Ioo`03001oogoo00Moo`03001oogoo01moo`0077oo0P00Agoo00<007ooOol01goo00<007ooOol0
7goo000LOol00`00Oomoo`16Ool00`00Oomoo`06Ool00`00Oomoo`0POol001aoo`03001oogoo04Io
o`03001oogoo00Ioo`03001oogoo021oo`002goo0P0017oo00@007ooOomoo`D0009oo`8004Qoo`03
001oogoo00Eoo`03001oogoo021oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomo
o`17Ool00`00Oomoo`05Ool00`00Oomoo`0POol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2
0018Ool00`00Oomoo`05Ool00`00Oomoo`0POol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000
BGoo00<007ooOol017oo00<007ooOol08Goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`8004Uoo`03001oogoo00=oo`03001oogoo025oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`18Ool00`00Oomoo`03Ool00`00Oomoo`0QOol000]oo`8000Uoo`<000=oo`03
001oogoo04Qoo`03001oogoo00=oo`03001oogoo025oo`0077oo0P00BGoo00<007ooOol00Woo00<0
07ooOol08Woo000LOol00`00Oomoo`18Ool00`00Oomoo`02Ool00`00Oomoo`0ROol000]oo`8000Ao
o`03001oogoo00=oo`<0009oo`8004Uoo`03001oogoo009oo`03001oogoo029oo`002Woo00@007oo
Ool000Yoo`05001oogooOol0001:Ool00`00Oomoo`02Ool00`00Oomoo`0ROol000Yoo`04001oogoo
0007Ool50002Ool20019Ool00`00Oomoo`02Ool00`00Oomoo`0ROol000Yoo`04001oogoo0007Ool0
1000Oomoo`000goo00<007ooOol0BGoo00D007ooOomoo`0002Aoo`002Woo00@007ooOol000Qoo`03
001oo`0000=oo`8004Yoo`04001oogoo000UOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomo
o`19Ool01000Oomoo`009Goo000;Ool2000;Ool01@00Oomoogoo0000C7oo00<007oo00009Goo000L
Ool2001;Ool2000VOol001aoo`03001oogoo04]oo`03001oogoo02Aoo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<0
07ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo
1@000Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001o
ogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03
001oogoo079oo`002goo0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003
Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009o
o`04001oogoo0009Ool00`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool0
1@00Oomoogoo00004Woo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`00
0Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo
00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003
Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`00
27oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomo
o`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00
Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03
Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo
1@000goo0P001Woo000LOol2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00
Oomoogoo00000goo00<007ooOol00Woo00<007ooOol0100000=oo`00Ool00Woo00D007ooOomoo`00
009oo`8000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`04001oogooOol30002Ool01@00Oomoogoo00000goo00<007oo00000P000goo00D0
07ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo0P004Woo00<007ooOol02Goo
00<007ooOol09Goo00<007ooOol02Goo00<007ooOol07Woo000LOol00`00Oomoo`0AOol00`00Oomo
o`08Ool00`00Oomoo`0WOol00`00Oomoo`07Ool00`00Oomoo`0OOol001aoo`8001=oo`03001oogoo
00Moo`03001oogoo02Moo`03001oogoo00Moo`03001oogoo01moo`0077oo00<007ooOol04Woo00<0
07ooOol01Woo00<007ooOol0:7oo00<007ooOol01Woo00<007ooOol087oo000;Ool20004Ool01000
Oomoogoo1@000Woo0P0057oo00<007ooOol01Goo00<007ooOol0:7oo00<007ooOol01Woo00<007oo
Ool087oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo01=oo`03001oogoo00Eo
o`03001oogoo02Uoo`03001oogoo00Eoo`03001oogoo021oo`002Woo00@007ooOol000Uoo`03001o
ogoo009oo`8001Aoo`03001oogoo00Eoo`03001oogoo02Uoo`03001oogoo00Eoo`03001oogoo021o
o`002Woo00@007ooOol000Yoo`05001oogooOol0000FOol00`00Oomoo`04Ool00`00Oomoo`0YOol0
0`00Oomoo`04Ool00`00Oomoo`0QOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00
5Goo00<007ooOol00goo00<007ooOol0:goo00<007ooOol00goo00<007ooOol08Goo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo01Aoo`03001oogoo00=oo`03001oogoo02]o
o`03001oogoo00=oo`03001oogoo025oo`002goo0P002Goo0`000goo0P005Goo00<007ooOol00goo
00<007ooOol0:goo00<007ooOol00Woo00<007ooOol08Woo000LOol00`00Oomoo`0DOol00`00Oomo
o`03Ool00`00Oomoo`0[Ool00`00Oomoo`02Ool00`00Oomoo`0ROol000]oo`8000Aoo`03001oogoo
00=oo`<0009oo`8001Ioo`05001oogooOol0000^Ool00`00Oomoo`02Ool00`00Oomoo`0ROol000Yo
o`04001oogoo000:Ool01@00Oomoogoo00005goo00D007ooOomoo`0002ioo`03001oogoo009oo`03
001oogoo029oo`002Woo00@007ooOol000Moo`D0009oo`8001Ioo`05001oogooOol0000_Ool01@00
Oomoogoo000097oo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo01Ioo`04001o
ogoo000_Ool01000Oomoo`009Goo000:Ool01000Oomoo`0027oo00<007oo00000goo0P005goo00@0
07ooOol002moo`04001oogoo000UOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`0FOol0
0`00Ool0000aOol00`00Ool0000UOol000]oo`8000]oo`04001oogooOol2000GOol3000aOol2000V
Ool001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03
Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool2
0004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo
00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;
Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol0
0`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0
Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(840\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23178 L
.116 .23179 L
.12 .2318 L
.124 .23183 L
.128 .23187 L
.132 .23194 L
.136 .23205 L
.14 .23221 L
.144 .23246 L
.148 .23284 L
.152 .23338 L
.156 .23418 L
.16 .2353 L
.164 .23687 L
.168 .23903 L
.172 .24192 L
.176 .24575 L
.18 .25069 L
.184 .25696 L
.188 .26474 L
.192 .27417 L
.196 .28533 L
.2 .29822 L
Mistroke
.204 .3127 L
.208 .32848 L
.212 .34512 L
.216 .36202 L
.22 .37842 L
.224 .39349 L
.228 .40632 L
.232 .41605 L
.236 .42195 L
.24 .42348 L
.244 .42036 L
.248 .41267 L
.252 .40078 L
.256 .38539 L
.26 .36742 L
.264 .34797 L
.268 .32814 L
.272 .30899 L
.276 .2914 L
.28 .27598 L
.284 .26313 L
.288 .25292 L
.292 .24522 L
.296 .23975 L
.3 .23611 L
.304 .23385 L
.308 .23259 L
.312 .23196 L
.316 .23172 L
.32 .23167 L
.324 .2317 L
.328 .23175 L
.332 .23179 L
.336 .23181 L
.34 .23182 L
.344 .23182 L
.348 .23182 L
.352 .23182 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23182 L
.652 .23182 L
.656 .23182 L
.66 .23182 L
.664 .23181 L
.668 .23179 L
.672 .23175 L
.676 .2317 L
.68 .23167 L
.684 .23172 L
.688 .23196 L
.692 .23259 L
.696 .23385 L
.7 .23611 L
.704 .23975 L
.708 .24522 L
.712 .25292 L
.716 .26313 L
.72 .27598 L
.724 .2914 L
.728 .30899 L
.732 .32814 L
.736 .34797 L
.74 .36742 L
.744 .38539 L
.748 .40078 L
.752 .41267 L
.756 .42036 L
.76 .42348 L
.764 .42195 L
.768 .41605 L
.772 .40632 L
.776 .39349 L
.78 .37842 L
.784 .36202 L
.788 .34512 L
.792 .32848 L
.796 .3127 L
.8 .29822 L
Mistroke
.804 .28533 L
.808 .27417 L
.812 .26474 L
.816 .25696 L
.82 .25069 L
.824 .24575 L
.828 .24192 L
.832 .23903 L
.836 .23687 L
.84 .2353 L
.844 .23418 L
.848 .23338 L
.852 .23284 L
.856 .23246 L
.86 .23221 L
.864 .23205 L
.868 .23194 L
.872 .23187 L
.876 .23183 L
.88 .2318 L
.884 .23179 L
.888 .23178 L
.892 .23177 L
.896 .23177 L
.9 .23177 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35315 L
.112 .35315 L
.116 .35313 L
.12 .35311 L
.124 .35308 L
.128 .35303 L
.132 .35295 L
.136 .35282 L
.14 .35263 L
.144 .35233 L
.148 .35188 L
.152 .35123 L
.156 .35029 L
.16 .34895 L
.164 .34707 L
.168 .34451 L
.172 .34106 L
.176 .3365 L
.18 .33061 L
.184 .32314 L
.188 .31388 L
.192 .30265 L
.196 .28935 L
.2 .27399 L
Mistroke
.204 .25675 L
.208 .23795 L
.212 .21813 L
.216 .198 L
.22 .17846 L
.224 .16052 L
.228 .14524 L
.232 .13364 L
.236 .12662 L
.24 .12481 L
.244 .12852 L
.248 .13769 L
.252 .15186 L
.256 .1702 L
.26 .1916 L
.264 .21478 L
.268 .2384 L
.272 .26121 L
.276 .28218 L
.28 .30054 L
.284 .31586 L
.288 .32802 L
.292 .33719 L
.296 .3437 L
.3 .34805 L
.304 .35073 L
.308 .35224 L
.312 .35298 L
.316 .35327 L
.32 .35333 L
.324 .3533 L
.328 .35324 L
.332 .3532 L
.336 .35317 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35317 L
.656 .35317 L
.66 .35317 L
.664 .35315 L
.668 .35313 L
.672 .35308 L
.676 .35303 L
.68 .35299 L
.684 .35305 L
.688 .35334 L
.692 .35408 L
.696 .35559 L
.7 .35828 L
.704 .36262 L
.708 .36914 L
.712 .3783 L
.716 .39046 L
.72 .40579 L
.724 .42415 L
.728 .44511 L
.732 .46793 L
.736 .49155 L
.74 .51472 L
.744 .53613 L
.748 .55447 L
.752 .56864 L
.756 .57781 L
.76 .58152 L
.764 .5797 L
.768 .57268 L
.772 .56109 L
.776 .54581 L
.78 .52787 L
.784 .50832 L
.788 .4882 L
.792 .46837 L
.796 .44957 L
.8 .43233 L
Mistroke
.804 .41698 L
.808 .40368 L
.812 .39245 L
.816 .38318 L
.82 .37571 L
.824 .36982 L
.828 .36527 L
.832 .36182 L
.836 .35925 L
.84 .35738 L
.844 .35604 L
.848 .35509 L
.852 .35444 L
.856 .35399 L
.86 .3537 L
.864 .3535 L
.868 .35337 L
.872 .35329 L
.876 .35324 L
.88 .35321 L
.884 .35319 L
.888 .35318 L
.892 .35317 L
.896 .35317 L
.9 .35317 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23178 L
.116 .23179 L
.12 .2318 L
.124 .23183 L
.128 .23187 L
.132 .23194 L
.136 .23205 L
.14 .23221 L
.144 .23246 L
.148 .23284 L
.152 .23338 L
.156 .23418 L
.16 .2353 L
.164 .23687 L
.168 .23903 L
.172 .24192 L
.176 .24575 L
.18 .25069 L
.184 .25696 L
.188 .26474 L
.192 .27417 L
.196 .28533 L
.2 .29822 L
Mistroke
.204 .3127 L
.208 .32848 L
.212 .34512 L
.216 .36202 L
.22 .37842 L
.224 .39349 L
.228 .40632 L
.232 .41605 L
.236 .42195 L
.24 .42348 L
.244 .42036 L
.248 .41267 L
.252 .40078 L
.256 .38539 L
.26 .36742 L
.264 .34797 L
.268 .32814 L
.272 .30899 L
.276 .2914 L
.28 .27598 L
.284 .26313 L
.288 .25292 L
.292 .24522 L
.296 .23975 L
.3 .23611 L
.304 .23385 L
.308 .23259 L
.312 .23196 L
.316 .23172 L
.32 .23167 L
.324 .2317 L
.328 .23175 L
.332 .23179 L
.336 .23181 L
.34 .23182 L
.344 .23182 L
.348 .23182 L
.352 .23182 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23182 L
.652 .23182 L
.656 .23182 L
.66 .23182 L
.664 .23181 L
.668 .23179 L
.672 .23175 L
.676 .2317 L
.68 .23167 L
.684 .23172 L
.688 .23196 L
.692 .23259 L
.696 .23385 L
.7 .23611 L
.704 .23975 L
.708 .24522 L
.712 .25292 L
.716 .26313 L
.72 .27598 L
.724 .2914 L
.728 .30899 L
.732 .32814 L
.736 .34797 L
.74 .36742 L
.744 .38539 L
.748 .40078 L
.752 .41267 L
.756 .42036 L
.76 .42348 L
.764 .42195 L
.768 .41605 L
.772 .40632 L
.776 .39349 L
.78 .37842 L
.784 .36202 L
.788 .34512 L
.792 .32848 L
.796 .3127 L
.8 .29822 L
Mistroke
.804 .28533 L
.808 .27417 L
.812 .26474 L
.816 .25696 L
.82 .25069 L
.824 .24575 L
.828 .24192 L
.832 .23903 L
.836 .23687 L
.84 .2353 L
.844 .23418 L
.848 .23338 L
.852 .23284 L
.856 .23246 L
.86 .23221 L
.864 .23205 L
.868 .23194 L
.872 .23187 L
.876 .23183 L
.88 .2318 L
.884 .23179 L
.888 .23178 L
.892 .23177 L
.896 .23177 L
.9 .23177 L
.904 .23176 L
.908 .23176 L
.912 .23176 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00<007ooOol00`000Woo00D007ooOomoo`0000=oo`05001oo`00Ool00003Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000Woo00<007oo00000goo00D007ooOomoo`00009oo`8000=oo`05001oogooOol00003
Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`80011oo`8000Yoo`03001oogoo02Qoo`8000Yo
o`03001oogoo01eoo`0077oo00<007ooOol047oo00<007ooOol027oo00<007ooOol0:Goo00<007oo
Ool027oo00<007ooOol07Goo000LOol2000BOol00`00Oomoo`07Ool00`00Oomoo`0YOol00`00Oomo
o`07Ool00`00Oomoo`0NOol001aoo`03001oogoo015oo`03001oogoo00Ioo`03001oogoo02]oo`03
001oogoo00Ioo`03001oogoo01ioo`002goo0P0017oo00@007ooOomoo`D0009oo`80019oo`03001o
ogoo00Ioo`03001oogoo02]oo`03001oogoo00Eoo`03001oogoo01moo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool00`00Oomoo`0BOol00`00Oomoo`05Ool00`00Oomoo`0[Ool00`00Oomoo`05
Ool00`00Oomoo`0OOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000COol00`00Oomoo`04
Ool00`00Oomoo`0/Ool00`00Oomoo`05Ool00`00Oomoo`0OOol000Yoo`04001oogoo000:Ool01@00
Oomoogoo000057oo00<007ooOol017oo00<007ooOol0;7oo00<007ooOol017oo00<007ooOol087oo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8001Aoo`03001oogoo00=oo`03001oogoo
02eoo`03001oogoo00=oo`03001oogoo021oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`0COol00`00Oomoo`03Ool00`00Oomoo`0]Ool00`00Oomoo`03Ool00`00Oomoo`0P
Ool000]oo`8000Uoo`<000=oo`8001Aoo`03001oogoo00=oo`03001oogoo02eoo`03001oogoo00=o
o`03001oogoo021oo`0077oo00<007ooOol04goo00<007ooOol00goo00<007ooOol0;Goo00<007oo
Ool00goo00<007ooOol087oo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000EOol01@00Oomo
ogoo0000<Goo00D007ooOomoo`0002=oo`002Woo00@007ooOol000Yoo`05001oogooOol0000FOol0
1@00Oomoogoo0000<Goo00D007ooOomoo`0002=oo`002Woo00@007ooOol000Moo`D0009oo`8001Eo
o`05001oogooOol0000aOol01@00Oomoogoo00008goo000:Ool01000Oomoo`001goo00@007ooOol0
00=oo`03001oogoo01Aoo`05001oogooOol0000aOol01000Oomoo`0097oo000:Ool01000Oomoo`00
27oo00<007oo00000goo0P005Woo00<007oo0000<goo00<007oo000097oo000:Ool01000Oomoo`00
2Goo0P000goo00<007ooOol05Goo00<007oo0000<goo00<007oo000097oo000;Ool2000;Ool01000
Oomoogoo0P005goo00<007ooOol0<Woo0P009Goo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03
001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo
000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2
001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomo
o`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00
Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol0
01Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00N7oo
000:Ool01000Oomoo`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007ooOol000Moo`05
001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`8007=oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool40003Ool2001c
Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008
Ool00`00Oomoo`03Ool2001cOol000]oo`8000Yoo`8000=oo`03001oogoo01Ioo`03001oogoo05Uo
o`0077oo0P005Woo0P00Fgoo000LOol00`00Oomoo`0EOol00`00Ool0001JOol000]oo`8000Aoo`03
001oogoo00=oo`<0009oo`8001Ioo`03001oo`0005Yoo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0000FOol01000Oomoo`00FWoo0003Ool50002Ool01000Oomoo`001goo1@000Woo00<007ooOol0
57oo00D007ooOomoo`0005Uoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool2000EOol01@00
Oomoogoo0000FGoo000:Ool01000Oomoo`0027oo00<007oo00000goo00<007ooOol057oo00D007oo
Oomoo`0005Uoo`002Woo00@007ooOol000Uoo`8000=oo`8001Eoo`05001oogooOol0001IOol000]o
o`8000]oo`05001oogooOol0000FOol00`00Oomoo`02Ool00`00Oomoo`1FOol001aoo`8001Aoo`03
001oogoo00=oo`03001oogoo05Ioo`0077oo00<007ooOol04goo00<007ooOol00goo00<007ooOol0
EWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P0057oo00<007ooOol00goo00<007ooOol0EWoo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo01=oo`03001oogoo00=oo`03001o
ogoo05Ioo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo019oo`03001o
ogoo00Aoo`03001oogoo05Ioo`002Woo00@007ooOol000Yoo`04001oogooOol2000>Ool30002Ool0
1000Ool000000goo00<007ooOol00goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo
1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo00aoo`06001oogooOol007oo0P000Woo00D007ooOomoo`0000Eoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00
Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo0P004Goo0P0000Eoo`00Oomoo`0000=oo`03001oogoo00=oo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`002goo0P002Goo0`000goo00<007ooOol047oo0P0000Eoo`00Oomo
o`0000=oo`03001oogoo00=oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`00
0Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P00
3Goo100000Aoo`00Ool0009oo`05001oogooOol00005Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000L
Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Oomoo`02Ool01000Oomoogoo
0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool0
0006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool20005Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P00
1Woo0`000Woo1@000goo0P001Woo000LOol2000@Ool2000:Ool00`00Oomoo`1DOol001aoo`03001o
ogoo00ioo`8000aoo`03001oogoo05=oo`0077ooJ@0037oo000LOol00`00Oomoo`0BOol00`00Oomo
o`0BOol00`00Oomoo`0AOol00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`02000@Ool00`00
Oomoo`0:Ool001aoo`8004Moo`03001oogoo00Uoo`03001oogoo01eoo`0077oo00<007ooOol0Agoo
00<007ooOol027oo00<007ooOol07Goo000LOol20018Ool00`00Oomoo`07Ool00`00Oomoo`0NOol0
01aoo`03001oogoo04Qoo`03001oogoo00Ioo`03001oogoo01ioo`0077oo00<007ooOol0B7oo00<0
07ooOol01Goo00<007ooOol07goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00BGoo00<007oo
Ool01Goo00<007ooOol07goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo04Qo
o`03001oogoo00Eoo`03001oogoo01moo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8004Uo
o`03001oogoo00Eoo`03001oogoo01moo`002Woo00@007ooOol000Yoo`05001oogooOol0001:Ool0
0`00Oomoo`04Ool00`00Oomoo`0POol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00
BWoo00<007ooOol00goo00<007ooOol087oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo021oo`002goo0P002Goo0`000goo00<007oo
Ool0BGoo00<007ooOol00goo00<007ooOol087oo000LOol2001:Ool00`00Oomoo`03Ool00`00Oomo
o`0POol001aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo021oo`002goo0P0017oo00<0
07ooOol00goo0`000Woo0P00Bgoo00D007ooOomoo`0002=oo`002Woo00@007ooOol000Yoo`05001o
ogooOol0001<Ool01@00Oomoogoo00008goo000:Ool01000Oomoo`001goo1@000Woo0P00Bgoo00D0
07ooOomoo`0002=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1:Ool01@00
Oomoogoo00008goo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Bgoo00@007ooOol002Ao
o`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo04]oo`03001oo`0002Aoo`002goo0P002goo
00D007ooOomoo`0004eoo`03001oo`0002Aoo`0077oo0P00C7oo0`0097oo000LOol00`00Oomoo`1<
Ool00`00Oomoo`0SOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@0
07ooOol000Yoo`05001oogooOol0001dOol000=oo`D0009oo`04001oogoo0007Ool50002Ool2001c
Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
27oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;
Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogoo
Ool50002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol03Goo0`00
17oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P00
1Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo0P00
3Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00<007ooOol00goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`04001oogoo0002Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P004Goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eo
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`0<Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Goo0`00
0goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomo
o`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomo
o`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<0
07ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=o
o`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`03001o
o`0000<0009oo`05001oogooOol00003Ool00`00Ool000020003Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01P00Oomoogoo001oo`800003
Ool007oo009oo`05001oogooOol00002Ool400000goo001oo`02Ool01@00Oomoogoo000017oo00<0
07ooOol02Woo000LOol2000@Ool2000:Ool00`00Oomoo`0XOol00`00Oomoo`09Ool2000NOol001ao
o`03001oogoo011oo`03001oogoo00Qoo`03001oogoo02Uoo`03001oogoo00Qoo`03001oogoo01eo
o`0077oo0P004Woo00<007ooOol01goo00<007ooOol0:Goo00<007ooOol01goo00<007ooOol07Woo
000LOol00`00Oomoo`0AOol00`00Oomoo`06Ool00`00Oomoo`0[Ool00`00Oomoo`06Ool00`00Oomo
o`0NOol000]oo`8000Aoo`04001oogooOol50002Ool2000BOol00`00Oomoo`06Ool00`00Oomoo`0[
Ool00`00Oomoo`05Ool00`00Oomoo`0OOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<0
07ooOol04Woo00<007ooOol01Goo00<007ooOol0:goo00<007ooOol01Goo00<007ooOol07goo000:
Ool01000Oomoo`002Goo00<007ooOol00Woo0P004goo00<007ooOol017oo00<007ooOol0;7oo00<0
07ooOol01Goo00<007ooOol07goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0001Aoo`03001o
ogoo00Aoo`03001oogoo02aoo`03001oogoo00Aoo`03001oogoo021oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2000DOol00`00Oomoo`03Ool00`00Oomoo`0]Ool00`00Oomoo`03Ool0
0`00Oomoo`0POol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol04goo00<0
07ooOol00goo00<007ooOol0;Goo00<007ooOol00goo00<007ooOol087oo000;Ool20009Ool30003
Ool2000DOol00`00Oomoo`03Ool00`00Oomoo`0]Ool00`00Oomoo`03Ool00`00Oomoo`0POol001ao
o`03001oogoo01=oo`03001oogoo00=oo`03001oogoo02eoo`03001oogoo00=oo`03001oogoo021o
o`002goo0P0017oo00<007ooOol00goo0`000Woo0P005Goo00D007ooOomoo`00035oo`05001oogoo
Ool0000SOol000Yoo`04001oogoo000:Ool01@00Oomoogoo00005Woo00D007ooOomoo`00035oo`05
001oogooOol0000SOol000Yoo`04001oogoo0007Ool50002Ool2000EOol01@00Oomoogoo0000<Goo
00D007ooOomoo`0002=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0DOol0
1@00Oomoogoo0000<Goo00@007ooOol002Aoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`80
01Ioo`03001oo`0003=oo`03001oo`0002Aoo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo
01Eoo`03001oo`0003=oo`03001oo`0002Aoo`002goo0P002goo00@007ooOomoo`8001Moo`03001o
ogoo039oo`8002Eoo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2
001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qo
o`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomo
o`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2
001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000G
Ool00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(880\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23178 L
.104 .23179 L
.108 .2318 L
.112 .23183 L
.116 .23188 L
.12 .23195 L
.124 .23206 L
.128 .23223 L
.132 .23248 L
.136 .23286 L
.14 .23342 L
.144 .23422 L
.148 .23536 L
.152 .23694 L
.156 .23911 L
.16 .24201 L
.164 .24584 L
.168 .25078 L
.172 .25703 L
.176 .26478 L
.18 .27417 L
.184 .28528 L
.188 .29809 L
.192 .31249 L
.196 .32819 L
.2 .34475 L
Mistroke
.204 .36158 L
.208 .37795 L
.212 .39301 L
.216 .40588 L
.22 .41569 L
.224 .42172 L
.228 .4234 L
.232 .42046 L
.236 .41294 L
.24 .4012 L
.244 .38592 L
.248 .36801 L
.252 .34856 L
.256 .32867 L
.26 .30942 L
.264 .29169 L
.268 .27614 L
.272 .26314 L
.276 .25283 L
.28 .24506 L
.284 .23955 L
.288 .2359 L
.292 .23366 L
.296 .23243 L
.3 .23185 L
.304 .23164 L
.308 .23163 L
.312 .23168 L
.316 .23174 L
.32 .23179 L
.324 .23181 L
.328 .23182 L
.332 .23182 L
.336 .23182 L
.34 .23182 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23182 L
.664 .23182 L
.668 .23182 L
.672 .23182 L
.676 .23181 L
.68 .23179 L
.684 .23174 L
.688 .23168 L
.692 .23163 L
.696 .23164 L
.7 .23185 L
.704 .23243 L
.708 .23366 L
.712 .2359 L
.716 .23955 L
.72 .24506 L
.724 .25283 L
.728 .26314 L
.732 .27614 L
.736 .29169 L
.74 .30942 L
.744 .32867 L
.748 .34856 L
.752 .36801 L
.756 .38592 L
.76 .4012 L
.764 .41294 L
.768 .42046 L
.772 .4234 L
.776 .42172 L
.78 .41569 L
.784 .40588 L
.788 .39301 L
.792 .37795 L
.796 .36158 L
.8 .34475 L
Mistroke
.804 .32819 L
.808 .31249 L
.812 .29809 L
.816 .28528 L
.82 .27417 L
.824 .26478 L
.828 .25703 L
.832 .25078 L
.836 .24584 L
.84 .24201 L
.844 .23911 L
.848 .23694 L
.852 .23536 L
.856 .23422 L
.86 .23342 L
.864 .23286 L
.868 .23248 L
.872 .23223 L
.876 .23206 L
.88 .23195 L
.884 .23188 L
.888 .23183 L
.892 .2318 L
.896 .23179 L
.9 .23178 L
.904 .23177 L
.908 .23177 L
.912 .23177 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35315 L
.1 .35314 L
.104 .35313 L
.108 .35311 L
.112 .35308 L
.116 .35303 L
.12 .35294 L
.124 .35281 L
.128 .35261 L
.132 .3523 L
.136 .35185 L
.14 .35119 L
.144 .35023 L
.148 .34888 L
.152 .34699 L
.156 .34441 L
.16 .34095 L
.164 .3364 L
.168 .33051 L
.172 .32306 L
.176 .31383 L
.18 .30265 L
.184 .28941 L
.188 .27415 L
.192 .257 L
.196 .2383 L
.2 .21857 L
Mistroke
.204 .19852 L
.208 .17903 L
.212 .16109 L
.216 .14576 L
.22 .13407 L
.224 .1269 L
.228 .1249 L
.232 .1284 L
.236 .13737 L
.24 .15135 L
.244 .16956 L
.248 .1909 L
.252 .21408 L
.256 .23777 L
.26 .2607 L
.264 .28183 L
.268 .30036 L
.272 .31584 L
.276 .32813 L
.28 .33738 L
.284 .34394 L
.288 .3483 L
.292 .35096 L
.296 .35243 L
.3 .35312 L
.304 .35336 L
.308 .35338 L
.312 .35332 L
.316 .35325 L
.32 .3532 L
.324 .35317 L
.328 .35316 L
.332 .35315 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35317 L
.668 .35317 L
.672 .35317 L
.676 .35316 L
.68 .35313 L
.684 .35308 L
.688 .353 L
.692 .35294 L
.696 .35296 L
.7 .3532 L
.704 .3539 L
.708 .35536 L
.712 .35803 L
.716 .36238 L
.72 .36894 L
.724 .37819 L
.728 .39049 L
.732 .40597 L
.736 .4245 L
.74 .44562 L
.744 .46856 L
.748 .49225 L
.752 .51542 L
.756 .53676 L
.76 .55497 L
.764 .56896 L
.768 .57792 L
.772 .58143 L
.776 .57943 L
.78 .57225 L
.784 .56056 L
.788 .54524 L
.792 .5273 L
.796 .5078 L
.8 .48775 L
Mistroke
.804 .46802 L
.808 .44933 L
.812 .43218 L
.816 .41691 L
.82 .40368 L
.824 .3925 L
.828 .38327 L
.832 .37582 L
.836 .36993 L
.84 .36537 L
.844 .36191 L
.848 .35933 L
.852 .35745 L
.856 .35609 L
.86 .35514 L
.864 .35447 L
.868 .35402 L
.872 .35372 L
.876 .35351 L
.88 .35338 L
.884 .3533 L
.888 .35325 L
.892 .35321 L
.896 .35319 L
.9 .35318 L
.904 .35317 L
.908 .35317 L
.912 .35317 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23178 L
.104 .23179 L
.108 .2318 L
.112 .23183 L
.116 .23188 L
.12 .23195 L
.124 .23206 L
.128 .23223 L
.132 .23248 L
.136 .23286 L
.14 .23342 L
.144 .23422 L
.148 .23536 L
.152 .23694 L
.156 .23911 L
.16 .24201 L
.164 .24584 L
.168 .25078 L
.172 .25703 L
.176 .26478 L
.18 .27417 L
.184 .28528 L
.188 .29809 L
.192 .31249 L
.196 .32819 L
.2 .34475 L
Mistroke
.204 .36158 L
.208 .37795 L
.212 .39301 L
.216 .40588 L
.22 .41569 L
.224 .42172 L
.228 .4234 L
.232 .42046 L
.236 .41294 L
.24 .4012 L
.244 .38592 L
.248 .36801 L
.252 .34856 L
.256 .32867 L
.26 .30942 L
.264 .29169 L
.268 .27614 L
.272 .26314 L
.276 .25283 L
.28 .24506 L
.284 .23955 L
.288 .2359 L
.292 .23366 L
.296 .23243 L
.3 .23185 L
.304 .23164 L
.308 .23163 L
.312 .23168 L
.316 .23174 L
.32 .23179 L
.324 .23181 L
.328 .23182 L
.332 .23182 L
.336 .23182 L
.34 .23182 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23182 L
.664 .23182 L
.668 .23182 L
.672 .23182 L
.676 .23181 L
.68 .23179 L
.684 .23174 L
.688 .23168 L
.692 .23163 L
.696 .23164 L
.7 .23185 L
.704 .23243 L
.708 .23366 L
.712 .2359 L
.716 .23955 L
.72 .24506 L
.724 .25283 L
.728 .26314 L
.732 .27614 L
.736 .29169 L
.74 .30942 L
.744 .32867 L
.748 .34856 L
.752 .36801 L
.756 .38592 L
.76 .4012 L
.764 .41294 L
.768 .42046 L
.772 .4234 L
.776 .42172 L
.78 .41569 L
.784 .40588 L
.788 .39301 L
.792 .37795 L
.796 .36158 L
.8 .34475 L
Mistroke
.804 .32819 L
.808 .31249 L
.812 .29809 L
.816 .28528 L
.82 .27417 L
.824 .26478 L
.828 .25703 L
.832 .25078 L
.836 .24584 L
.84 .24201 L
.844 .23911 L
.848 .23694 L
.852 .23536 L
.856 .23422 L
.86 .23342 L
.864 .23286 L
.868 .23248 L
.872 .23223 L
.876 .23206 L
.88 .23195 L
.884 .23188 L
.888 .23183 L
.892 .2318 L
.896 .23179 L
.9 .23178 L
.904 .23177 L
.908 .23177 L
.912 .23177 L
.916 .23176 L
.92 .23176 L
.924 .23176 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00<007oo00000P000goo00D007ooOomoo`0000=oo`80009oo`05001oogooOol00004
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo0P000goo00D007ooOomoo`0000=oo`<00003Ool007oo009oo`05001oogooOol00004Ool0
0`00Oomoo`0:Ool001aoo`8000moo`8000Yoo`03001oogoo02]oo`03001oogoo00Qoo`8001eoo`00
77oo00<007ooOol03goo00<007ooOol027oo00<007ooOol0:goo00<007ooOol027oo00<007ooOol0
77oo000LOol2000@Ool00`00Oomoo`07Ool00`00Oomoo`0/Ool00`00Oomoo`07Ool00`00Oomoo`0M
Ool001aoo`03001oogoo011oo`03001oogoo00Ioo`03001oogoo02eoo`03001oogoo00Ioo`03001o
ogoo01eoo`002goo0P0017oo00@007ooOomoo`D0009oo`80015oo`03001oogoo00Ioo`03001oogoo
02eoo`03001oogoo00Ioo`03001oogoo01eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0AOol00`00Oomoo`05Ool00`00Oomoo`0]Ool00`00Oomoo`05Ool00`00Oomoo`0NOol0
00Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000BOol00`00Oomoo`04Ool00`00Oomoo`0_Ool0
0`00Oomoo`04Ool00`00Oomoo`0NOol000Yoo`04001oogoo000:Ool01@00Oomoogoo00004goo00<0
07ooOol017oo00<007ooOol0;goo00<007ooOol017oo00<007ooOol07Woo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`80019oo`03001oogoo00Aoo`03001oogoo02moo`03001oogoo00=o
o`03001oogoo01moo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0AOol0
0`00Oomoo`04Ool00`00Oomoo`0_Ool00`00Oomoo`03Ool00`00Oomoo`0OOol000]oo`8000Uoo`<0
00=oo`8001=oo`03001oogoo009oo`03001oogoo035oo`03001oogoo009oo`03001oogoo01moo`00
77oo00<007ooOol04Woo00<007ooOol00Woo00<007ooOol0<Goo00<007ooOol00Woo00<007ooOol0
7goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000COol00`00Oomoo`02Ool00`00Oomoo`0a
Ool01@00Oomoogoo00008Woo000:Ool01000Oomoo`002Woo00D007ooOomoo`0001Eoo`05001oogoo
Ool0000cOol01@00Oomoogoo00008Woo000:Ool01000Oomoo`001goo1@000Woo0P0057oo00@007oo
Ool003Aoo`05001oogooOol0000ROol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007oo
Ool04goo00@007ooOol003Aoo`05001oogooOol0000ROol000Yoo`04001oogoo0008Ool00`00Ool0
0003Ool2000EOol00`00Ool0000eOol00`00Ool0000SOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`0DOol00`00Ool0000eOol00`00Ool0000SOol000]oo`8000]oo`04001oogooOol2000E
Ool2000gOol00`00Oomoo`0ROol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo
0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool40003
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001o
ogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo
00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo
0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`80
07=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007oo
Ool0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3001hOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00Lgoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`@000=oo`8007=oo`002Woo00@0
07ooOol000Moo`03001oogoo00Aoo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oogoo
00=oo`8007=oo`002goo0P002Woo0P000goo00<007ooOol05Goo00<007ooOol0FWoo000LOol2000E
Ool2001LOol001aoo`03001oogoo01Aoo`03001oo`0005]oo`002goo0P0017oo00<007ooOol00goo
0`000Woo0P005Goo00<007oo0000Fgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0001Eoo`04
001oogoo001KOol000=oo`D0009oo`04001oogoo0007Ool50002Ool00`00Oomoo`0COol01000Oomo
o`00Fgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`8001Aoo`04001oogoo001KOol000Yo
o`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`0COol01@00Oomoogoo0000FWoo000:Ool0
1000Oomoo`002Goo0P000goo0P004goo00<007ooOol00Woo00<007ooOol0F7oo000;Ool2000;Ool0
1@00Oomoogoo000057oo00<007ooOol00Woo00<007ooOol0F7oo000LOol2000COol00`00Oomoo`02
Ool00`00Oomoo`1HOol001aoo`03001oogoo019oo`03001oogoo009oo`03001oogoo05Qoo`002goo
0P0017oo00@007ooOomoo`D0009oo`80019oo`03001oogoo00Aoo`03001oogoo05Moo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`1GOol0
00=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`04Ool0
0`00Oomoo`1GOol000Yoo`04001oogoo000:Ool01000Oomoogoo0P003Woo0`0000Aoo`00Oomoo`80
009oo`03001oogoo00Aoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`80
00Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`0<Ool01000Oomoogoo0P0000Eoo`00Oomoo`00009oo`03001oogoo00Aoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P004Goo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`03Ool000]oo`8000Uoo`<000=oo`03001oogoo011oo`04001oogoo0002Ool01000Oomo
o`001Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool50002Ool01000
Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
1000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo
00@007ooOol000=oo`04001oogoo0002Ool00`00Oomoo`03Ool20004Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001ao
o`03001oogoo00aoo`D000=oo`8000Aoo`03001oogoo00=oo`03001oogoo00=oo`8000Aoo`8000Io
o`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool0
01aoo`8000moo`8000Yoo`03001oogoo05Eoo`0077oo00<007ooOol03Goo0P0037oo00<007ooOol0
E7oo000LOomY000<Ool001aoo`03001oogoo019oo`03001oogoo019oo`03001oogoo015oo`03001o
ogoo00Uoo`03001oogoo00Ioo`04001oogooOol2000?Ool00`00Oomoo`0:Ool001aoo`8004Uoo`03
001oogoo00Qoo`8001eoo`0077oo00<007ooOol0B7oo00<007ooOol027oo00<007ooOol077oo000L
Ool20019Ool00`00Oomoo`07Ool00`00Oomoo`0MOol001aoo`03001oogoo04Uoo`03001oogoo00Io
o`03001oogoo01eoo`0077oo00<007ooOol0BGoo00<007ooOol01Woo00<007ooOol07Goo000;Ool2
0004Ool01000Oomoogoo1@000Woo0P00BWoo00<007ooOol01Woo00<007ooOol07Goo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`03001oogoo04Uoo`03001oogoo00Eoo`03001oogoo01ioo`00
2Woo00@007ooOol000Uoo`03001oogoo009oo`8004]oo`03001oogoo00Aoo`03001oogoo01ioo`00
2Woo00@007ooOol000Yoo`05001oogooOol0001<Ool00`00Oomoo`04Ool00`00Oomoo`0NOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Bgoo00<007ooOol017oo00<007ooOol07Woo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo04Yoo`03001oogoo00=oo`03
001oogoo01moo`002goo0P002Goo0`000goo00<007ooOol0BWoo00<007ooOol00goo00<007ooOol0
7goo000LOol2001<Ool00`00Oomoo`02Ool00`00Oomoo`0OOol001aoo`03001oogoo04]oo`03001o
ogoo009oo`03001oogoo01moo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00C7oo00D007oo
Oomoo`00029oo`002Woo00@007ooOol000Yoo`05001oogooOol0001=Ool01@00Oomoogoo00008Woo
000:Ool01000Oomoo`001goo1@000Woo0P00C7oo00D007ooOomoo`00029oo`002Woo00@007ooOol0
00Moo`04001oogoo0003Ool00`00Oomoo`1;Ool01@00Oomoogoo00008Woo000:Ool01000Oomoo`00
27oo00<007oo00000goo0P00C7oo00D007ooOomoo`00029oo`002Woo00@007ooOol000Uoo`8000=o
o`03001oogoo04aoo`03001oo`0002=oo`002goo0P002goo00D007ooOomoo`0004ioo`03001oo`00
02=oo`0077oo0P00CWoo0P008goo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo
00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000=oo`D0009o
o`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`00
2Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomo
o`1bOol000]oo`8000Aoo`04001oogooOol50002Ool2001cOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`00
17oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000
Oomoo`002Goo00<007ooOol00Woo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`00
0Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`002Woo00D007oo
Oomoo`00019oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo00@007ooOol0009oo`03
001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@0
07ooOol000Eoo`002goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`80
00Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Ao
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo0000
1Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P00
17oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=o
o`8000Ioo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomo
o`0000=oo`03001oogoo009oo`D000=oo`05001oogooOol00003Ool300000goo001oo`02Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000Woo0`000goo00D007ooOomoo`0000=oo`D000=oo`05001oogooOol00004Ool00`00
Oomoo`0:Ool001aoo`8000moo`8000Yoo`03001oogoo02]oo`03001oogoo00Qoo`8001eoo`0077oo
00<007ooOol03goo00<007ooOol027oo00<007ooOol0:goo00<007ooOol027oo00<007ooOol077oo
000LOol2000@Ool00`00Oomoo`07Ool00`00Oomoo`0/Ool00`00Oomoo`07Ool00`00Oomoo`0MOol0
01aoo`03001oogoo011oo`03001oogoo00Ioo`03001oogoo02eoo`03001oogoo00Ioo`03001oogoo
01eoo`002goo0P0017oo00@007ooOomoo`D0009oo`80015oo`03001oogoo00Ioo`03001oogoo02eo
o`03001oogoo00Ioo`03001oogoo01eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00
Oomoo`0AOol00`00Oomoo`05Ool00`00Oomoo`0]Ool00`00Oomoo`05Ool00`00Oomoo`0NOol000Yo
o`04001oogoo0009Ool00`00Oomoo`02Ool2000BOol00`00Oomoo`04Ool00`00Oomoo`0_Ool00`00
Oomoo`04Ool00`00Oomoo`0NOol000Yoo`04001oogoo000:Ool01@00Oomoogoo00004goo00<007oo
Ool017oo00<007ooOol0;goo00<007ooOol017oo00<007ooOol07Woo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`80019oo`03001oogoo00Aoo`03001oogoo02moo`03001oogoo00=oo`03
001oogoo01moo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0AOol00`00
Oomoo`04Ool00`00Oomoo`0_Ool00`00Oomoo`03Ool00`00Oomoo`0OOol000]oo`8000Uoo`<000=o
o`8001=oo`03001oogoo009oo`03001oogoo035oo`03001oogoo009oo`03001oogoo01moo`0077oo
00<007ooOol04Woo00<007ooOol00Woo00<007ooOol0<Goo00<007ooOol00Woo00<007ooOol07goo
000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000COol00`00Oomoo`02Ool00`00Oomoo`0aOol0
1@00Oomoogoo00008Woo000:Ool01000Oomoo`002Woo00D007ooOomoo`0001Aoo`03001oogoo009o
o`03001oogoo035oo`05001oogooOol0000ROol000Yoo`04001oogoo0007Ool50002Ool2000DOol0
1000Oomoo`00=7oo00D007ooOomoo`00029oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool0
0`00Oomoo`0COol01000Oomoo`00=7oo00D007ooOomoo`00029oo`002Woo00@007ooOol000Qoo`03
001oo`0000=oo`8001Eoo`03001oo`0003Eoo`03001oo`0002=oo`002Woo00@007ooOol000Uoo`80
00=oo`03001oogoo01Aoo`03001oo`0003Eoo`03001oo`0002=oo`002goo0P002goo00@007ooOomo
o`8001Eoo`8003Moo`03001oogoo029oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomo
o`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Mo
o`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo
00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo
000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo
000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol0
0Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol0
0`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(920\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23178 L
.092 .23179 L
.096 .23181 L
.1 .23184 L
.104 .23188 L
.108 .23196 L
.112 .23207 L
.116 .23224 L
.12 .2325 L
.124 .23289 L
.128 .23346 L
.132 .23427 L
.136 .23542 L
.14 .23701 L
.144 .23918 L
.148 .2421 L
.152 .24593 L
.156 .25086 L
.16 .2571 L
.164 .26482 L
.168 .27417 L
.172 .28522 L
.176 .29797 L
.18 .31228 L
.184 .3279 L
.188 .34438 L
.192 .36115 L
.196 .37748 L
.2 .39253 L
Mistroke
.204 .40543 L
.208 .41533 L
.212 .42148 L
.216 .42331 L
.22 .42055 L
.224 .4132 L
.228 .40161 L
.232 .38644 L
.236 .3686 L
.24 .34915 L
.244 .32921 L
.248 .30986 L
.252 .292 L
.256 .2763 L
.26 .26317 L
.264 .25274 L
.268 .2449 L
.272 .23935 L
.276 .23568 L
.28 .23347 L
.284 .23227 L
.288 .23173 L
.292 .23157 L
.296 .23158 L
.3 .23166 L
.304 .23173 L
.308 .23179 L
.312 .23181 L
.316 .23182 L
.32 .23182 L
.324 .23182 L
.328 .23182 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23182 L
.676 .23182 L
.68 .23182 L
.684 .23182 L
.688 .23181 L
.692 .23179 L
.696 .23173 L
.7 .23166 L
.704 .23158 L
.708 .23157 L
.712 .23173 L
.716 .23227 L
.72 .23347 L
.724 .23568 L
.728 .23935 L
.732 .2449 L
.736 .25274 L
.74 .26317 L
.744 .2763 L
.748 .292 L
.752 .30986 L
.756 .32921 L
.76 .34915 L
.764 .3686 L
.768 .38644 L
.772 .40161 L
.776 .4132 L
.78 .42055 L
.784 .42331 L
.788 .42148 L
.792 .41533 L
.796 .40543 L
.8 .39253 L
Mistroke
.804 .37748 L
.808 .36115 L
.812 .34438 L
.816 .3279 L
.82 .31228 L
.824 .29797 L
.828 .28522 L
.832 .27417 L
.836 .26482 L
.84 .2571 L
.844 .25086 L
.848 .24593 L
.852 .2421 L
.856 .23918 L
.86 .23701 L
.864 .23542 L
.868 .23427 L
.872 .23346 L
.876 .23289 L
.88 .2325 L
.884 .23224 L
.888 .23207 L
.892 .23196 L
.896 .23188 L
.9 .23184 L
.904 .23181 L
.908 .23179 L
.912 .23178 L
.916 .23177 L
.92 .23177 L
.924 .23177 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35315 L
.088 .35314 L
.092 .35313 L
.096 .35311 L
.1 .35307 L
.104 .35302 L
.108 .35293 L
.112 .3528 L
.116 .35259 L
.12 .35228 L
.124 .35182 L
.128 .35114 L
.132 .35018 L
.136 .34881 L
.14 .34691 L
.144 .34432 L
.148 .34085 L
.152 .33629 L
.156 .33041 L
.16 .32298 L
.164 .31378 L
.168 .30265 L
.172 .28948 L
.176 .2743 L
.18 .25724 L
.184 .23865 L
.188 .21901 L
.192 .19904 L
.196 .17959 L
.2 .16166 L
Mistroke
.204 .14629 L
.208 .1345 L
.212 .12718 L
.216 .125 L
.22 .1283 L
.224 .13706 L
.228 .15086 L
.232 .16894 L
.236 .1902 L
.24 .21338 L
.244 .23713 L
.248 .26018 L
.252 .28147 L
.256 .30017 L
.26 .31581 L
.264 .32823 L
.268 .33758 L
.272 .34419 L
.276 .34855 L
.28 .35119 L
.284 .35262 L
.288 .35326 L
.292 .35346 L
.296 .35344 L
.3 .35335 L
.304 .35326 L
.308 .35319 L
.312 .35316 L
.316 .35315 L
.32 .35315 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35317 L
.68 .35317 L
.684 .35317 L
.688 .35316 L
.692 .35313 L
.696 .35307 L
.7 .35298 L
.704 .35289 L
.708 .35287 L
.712 .35306 L
.716 .35371 L
.72 .35513 L
.724 .35777 L
.728 .36214 L
.732 .36875 L
.736 .37809 L
.74 .39052 L
.744 .40616 L
.748 .42486 L
.752 .44614 L
.756 .4692 L
.76 .49295 L
.764 .51613 L
.768 .53739 L
.772 .55546 L
.776 .56927 L
.78 .57803 L
.784 .58132 L
.788 .57914 L
.792 .57182 L
.796 .56003 L
.8 .54467 L
Mistroke
.804 .52673 L
.808 .50729 L
.812 .48731 L
.816 .46768 L
.82 .44908 L
.824 .43203 L
.828 .41684 L
.832 .40368 L
.836 .39254 L
.84 .38335 L
.844 .37591 L
.848 .37003 L
.852 .36547 L
.856 .362 L
.86 .35941 L
.864 .35752 L
.868 .35615 L
.872 .35518 L
.876 .35451 L
.88 .35405 L
.884 .35373 L
.888 .35353 L
.892 .35339 L
.896 .3533 L
.9 .35325 L
.904 .35322 L
.908 .35319 L
.912 .35318 L
.916 .35317 L
.92 .35317 L
.924 .35317 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23178 L
.092 .23179 L
.096 .23181 L
.1 .23184 L
.104 .23188 L
.108 .23196 L
.112 .23207 L
.116 .23224 L
.12 .2325 L
.124 .23289 L
.128 .23346 L
.132 .23427 L
.136 .23542 L
.14 .23701 L
.144 .23918 L
.148 .2421 L
.152 .24593 L
.156 .25086 L
.16 .2571 L
.164 .26482 L
.168 .27417 L
.172 .28522 L
.176 .29797 L
.18 .31228 L
.184 .3279 L
.188 .34438 L
.192 .36115 L
.196 .37748 L
.2 .39253 L
Mistroke
.204 .40543 L
.208 .41533 L
.212 .42148 L
.216 .42331 L
.22 .42055 L
.224 .4132 L
.228 .40161 L
.232 .38644 L
.236 .3686 L
.24 .34915 L
.244 .32921 L
.248 .30986 L
.252 .292 L
.256 .2763 L
.26 .26317 L
.264 .25274 L
.268 .2449 L
.272 .23935 L
.276 .23568 L
.28 .23347 L
.284 .23227 L
.288 .23173 L
.292 .23157 L
.296 .23158 L
.3 .23166 L
.304 .23173 L
.308 .23179 L
.312 .23181 L
.316 .23182 L
.32 .23182 L
.324 .23182 L
.328 .23182 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23182 L
.676 .23182 L
.68 .23182 L
.684 .23182 L
.688 .23181 L
.692 .23179 L
.696 .23173 L
.7 .23166 L
.704 .23158 L
.708 .23157 L
.712 .23173 L
.716 .23227 L
.72 .23347 L
.724 .23568 L
.728 .23935 L
.732 .2449 L
.736 .25274 L
.74 .26317 L
.744 .2763 L
.748 .292 L
.752 .30986 L
.756 .32921 L
.76 .34915 L
.764 .3686 L
.768 .38644 L
.772 .40161 L
.776 .4132 L
.78 .42055 L
.784 .42331 L
.788 .42148 L
.792 .41533 L
.796 .40543 L
.8 .39253 L
Mistroke
.804 .37748 L
.808 .36115 L
.812 .34438 L
.816 .3279 L
.82 .31228 L
.824 .29797 L
.828 .28522 L
.832 .27417 L
.836 .26482 L
.84 .2571 L
.844 .25086 L
.848 .24593 L
.852 .2421 L
.856 .23918 L
.86 .23701 L
.864 .23542 L
.868 .23427 L
.872 .23346 L
.876 .23289 L
.88 .2325 L
.884 .23224 L
.888 .23207 L
.892 .23196 L
.896 .23188 L
.9 .23184 L
.904 .23181 L
.908 .23179 L
.912 .23178 L
.916 .23177 L
.92 .23177 L
.924 .23177 L
.928 .23176 L
.932 .23176 L
.936 .23176 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo1@000goo00D007ooOomoo`00009oo`8000=oo`05001oogooOol00004Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D0
07ooOomoo`0000=oo`04001oogooOol50003Ool01@00Oomoogoo000017oo00<007ooOol02Woo000L
Ool2000>Ool00`00Oomoo`09Ool00`00Oomoo`0]Ool00`00Oomoo`08Ool2000LOol001aoo`03001o
ogoo00ioo`03001oogoo00Qoo`03001oogoo02eoo`03001oogoo00Qoo`03001oogoo01]oo`0077oo
0P003goo00<007ooOol01goo00<007ooOol0;goo00<007ooOol01goo00<007ooOol06goo000LOol0
0`00Oomoo`0?Ool00`00Oomoo`06Ool00`00Oomoo`0_Ool00`00Oomoo`06Ool00`00Oomoo`0LOol0
00]oo`8000Aoo`04001oogooOol50002Ool2000@Ool00`00Oomoo`05Ool00`00Oomoo`0aOol00`00
Oomoo`05Ool00`00Oomoo`0LOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0
3goo00<007ooOol01Goo00<007ooOol0<Goo00<007ooOol017oo00<007ooOol07Goo000:Ool01000
Oomoo`002Goo00<007ooOol00Woo0P0047oo00<007ooOol01Goo00<007ooOol0<Goo00<007ooOol0
17oo00<007ooOol07Goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`03001oogoo00Ao
o`03001oogoo035oo`03001oogoo00Aoo`03001oogoo01eoo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2000AOol00`00Oomoo`03Ool00`00Oomoo`0bOol00`00Oomoo`04Ool00`00Oomo
o`0MOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol047oo00<007ooOol0
0goo00<007ooOol0<Woo00<007ooOol017oo00<007ooOol07Goo000;Ool20009Ool30003Ool2000B
Ool00`00Oomoo`02Ool00`00Oomoo`0cOol00`00Oomoo`02Ool00`00Oomoo`0NOol001aoo`03001o
ogoo015oo`03001oogoo009oo`03001oogoo03=oo`03001oogoo009oo`03001oogoo01ioo`002goo
0P0017oo00<007ooOol00goo0`000Woo0P004Woo00<007ooOol00Woo00<007ooOol0<goo00<007oo
Ool00Woo00<007ooOol07Woo000:Ool01000Oomoo`002Woo00D007ooOomoo`0001=oo`03001oogoo
009oo`03001oogoo03=oo`05001oogooOol0000QOol000Yoo`04001oogoo0007Ool50002Ool2000B
Ool01@00Oomoogoo0000=goo00@007ooOol0025oo`002Woo00@007ooOol000Moo`04001oogoo0003
Ool00`00Oomoo`0BOol01000Oomoo`00=goo00@007ooOol0025oo`002Woo00@007ooOol000Qoo`03
001oo`0000=oo`8001=oo`04001oogoo000gOol00`00Ool0000ROol000Yoo`04001oogoo0009Ool2
0003Ool00`00Oomoo`0COol2000hOol00`00Ool0000ROol000]oo`8000]oo`04001oogooOol2000D
Ool2000iOol2000ROol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo
0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008
Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007oo
Ool0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo
0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`00
5goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3001hOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
07=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
0P00Lgoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`@000=oo`8007=oo`002Woo00@007ooOol0
00Moo`03001oogoo00Aoo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`80
07=oo`002goo0P002Woo0P000goo00<007ooOol057oo00<007ooOol0Fgoo000LOol2000DOol2001M
Ool001aoo`03001oogoo01=oo`8005eoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P004goo
00@007ooOol005aoo`002Woo00@007ooOol000Yoo`05001oogooOol0000DOol01000Oomoo`00G7oo
0003Ool50002Ool01000Oomoo`001goo1@000Woo00<007ooOol04Woo00@007ooOol005aoo`002Woo
00@007ooOol000Moo`04001oogoo0003Ool2000BOol01@00Oomoogoo0000G7oo000:Ool01000Oomo
o`0027oo00<007oo00000goo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol0FGoo000:Ool0
1000Oomoo`002Goo0P000goo0P004Woo00<007ooOol00Woo00<007ooOol0FGoo000;Ool2000;Ool0
1@00Oomoogoo00004goo00<007ooOol00Woo00<007ooOol0FGoo000LOol2000BOol00`00Oomoo`02
Ool00`00Oomoo`1IOol001aoo`03001oogoo015oo`03001oogoo009oo`03001oogoo05Uoo`002goo
0P0017oo00@007ooOomoo`D0009oo`80015oo`03001oogoo00=oo`03001oogoo05Uoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool00`00Oomoo`1IOol0
00=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool0
0`00Oomoo`1HOol000Yoo`04001oogoo000:Ool01000Oomoogoo0P003Woo10000goo0P0000=oo`00
Ool01Woo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo
1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo
00aoo`03001oogoo0080009oo`03001oogoo008000Qoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P0047oo0P000Woo
00<007ooOol00P0027oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool20009Ool30003
Ool00`00Oomoo`0?Ool20002Ool01P00Oomoo`00Ool000Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03
001oogoo00=oo`0077oo0P003Goo10000goo00H007ooOol007oo0007Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool00`00Ool00004Ool01P00Oomoo`00Ool000Ioo`8000Aoo`04
001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@0
07ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P000goo00<007ooOol017oo00<007ooOol0
0goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009o
o`D000=oo`8000Ioo`0077oo0P003Woo00<007ooOol02Goo00<007ooOol0EWoo000LOol00`00Oomo
o`0;Ool3000;Ool2001GOol001aoofT000aoo`0077oo00<007ooOol04Woo00<007ooOol04Woo00<0
07ooOol04Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol00Woo0P003Woo00<007ooOol0
2Woo000LOol2001:Ool00`00Oomoo`08Ool2000LOol001aoo`03001oogoo04Uoo`03001oogoo00Qo
o`03001oogoo01]oo`0077oo0P00Bgoo00<007ooOol01goo00<007ooOol06goo000LOol00`00Oomo
o`1:Ool00`00Oomoo`06Ool00`00Oomoo`0LOol001aoo`03001oogoo04Yoo`03001oogoo00Ioo`03
001oogoo01aoo`002goo0P0017oo00@007ooOomoo`D0009oo`8004aoo`03001oogoo00Eoo`03001o
ogoo01aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1;Ool00`00Oomoo`04
Ool00`00Oomoo`0MOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001<Ool00`00Oomoo`04
Ool00`00Oomoo`0MOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000CGoo00<007ooOol017oo
00<007ooOol07Goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8004aoo`03001oogoo
00Aoo`03001oogoo01eoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1;
Ool00`00Oomoo`04Ool00`00Oomoo`0MOol000]oo`8000Uoo`<000=oo`03001oogoo04]oo`03001o
ogoo00Aoo`03001oogoo01eoo`0077oo0P00CGoo00<007ooOol00Woo00<007ooOol07Woo000LOol0
0`00Oomoo`1<Ool00`00Oomoo`02Ool00`00Oomoo`0NOol000]oo`8000Aoo`03001oogoo00=oo`<0
009oo`8004eoo`03001oogoo009oo`03001oogoo01ioo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0001>Ool00`00Oomoo`02Ool00`00Oomoo`0NOol000Yoo`04001oogoo0007Ool50002Ool2001=
Ool01@00Oomoogoo00008Goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo04eo
o`04001oogoo000QOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001>Ool01000Oomoo`00
8Goo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0CGoo00<007oo00008Woo000;Ool2000;
Ool01@00Oomoogoo0000Cgoo00<007oo00008Woo000LOol2001?Ool2000ROol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000LOol0
0`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo
00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@0
07ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool0
0003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`04
001oogooOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00@007ooOomoo`D0009oo`80
07=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0=Ool30004Ool20009Ool3
0004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool3
0004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool2000=Ool01@00Oomo
ogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo00@007ooOol0009oo`03001oogoo00Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`@000=o
o`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo
Ool40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
17oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool2000=Ool0
0`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003
Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000
Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool5
0003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`00
17oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2001cOol001aoo`03001oogoo079o
o`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00@007ooOomoo`@00003Ool007oo009oo`05
001oogooOol00002Ool30002Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`8000=oo`05001oogooOol00003
Ool00`00Ool000030002Ool01@00Oomoogoo000017oo00<007ooOol02Woo000LOol2000>Ool00`00
Oomoo`09Ool00`00Oomoo`0]Ool00`00Oomoo`08Ool2000LOol001aoo`03001oogoo00ioo`03001o
ogoo00Qoo`03001oogoo02eoo`03001oogoo00Qoo`03001oogoo01]oo`0077oo0P003goo00<007oo
Ool01goo00<007ooOol0;goo00<007ooOol01goo00<007ooOol06goo000LOol00`00Oomoo`0?Ool0
0`00Oomoo`06Ool00`00Oomoo`0_Ool00`00Oomoo`06Ool00`00Oomoo`0LOol000]oo`8000Aoo`04
001oogooOol50002Ool2000@Ool00`00Oomoo`06Ool00`00Oomoo`0_Ool00`00Oomoo`06Ool00`00
Oomoo`0LOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol03goo00<007ooOol0
1Goo00<007ooOol0<Goo00<007ooOol017oo00<007ooOol07Goo000:Ool01000Oomoo`002Goo00<0
07ooOol00Woo0P0047oo00<007ooOol01Goo00<007ooOol0<Goo00<007ooOol017oo00<007ooOol0
7Goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`03001oogoo00Aoo`03001oogoo035o
o`03001oogoo00Aoo`03001oogoo01eoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2
000AOol00`00Oomoo`04Ool00`00Oomoo`0aOol00`00Oomoo`04Ool00`00Oomoo`0MOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol047oo00<007ooOol00goo00<007ooOol0
<Woo00<007ooOol017oo00<007ooOol07Goo000;Ool20009Ool30003Ool2000BOol00`00Oomoo`02
Ool00`00Oomoo`0bOol00`00Oomoo`03Ool00`00Oomoo`0NOol001aoo`03001oogoo015oo`03001o
ogoo009oo`03001oogoo03=oo`03001oogoo009oo`03001oogoo01ioo`002goo0P0017oo00<007oo
Ool00goo0`000Woo0P004Woo00<007ooOol00Woo00<007ooOol0<goo00<007ooOol00Woo00<007oo
Ool07Woo000:Ool01000Oomoo`002Woo00D007ooOomoo`0001=oo`03001oogoo009oo`03001oogoo
03=oo`03001oogoo009oo`03001oogoo01ioo`002Woo00@007ooOol000Moo`D0009oo`80019oo`05
001oogooOol0000gOol01000Oomoo`008Goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03
001oogoo019oo`04001oogoo000gOol01000Oomoo`008Goo000:Ool01000Oomoo`0027oo00<007oo
00000goo0P004goo00@007ooOol003Moo`03001oo`00029oo`002Woo00@007ooOol000Uoo`8000=o
o`03001oogoo01=oo`8003Qoo`03001oo`00029oo`002goo0P002goo00@007ooOomoo`8001Aoo`80
03Uoo`80029oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001c
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03
001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1b
Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00
Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001c
Ool001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol0
0`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(960\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23178 L
.08 .23179 L
.084 .23181 L
.088 .23184 L
.092 .23189 L
.096 .23196 L
.1 .23208 L
.104 .23226 L
.108 .23252 L
.112 .23292 L
.116 .23349 L
.12 .23432 L
.124 .23547 L
.128 .23708 L
.132 .23926 L
.136 .24218 L
.14 .24601 L
.144 .25094 L
.148 .25717 L
.152 .26486 L
.156 .27417 L
.16 .28517 L
.164 .29785 L
.168 .31208 L
.172 .32761 L
.176 .34402 L
.18 .36072 L
.184 .37701 L
.188 .39205 L
.192 .40499 L
.196 .41497 L
.2 .42123 L
Mistroke
.204 .42322 L
.208 .42063 L
.212 .41345 L
.216 .40202 L
.22 .38696 L
.224 .36918 L
.228 .34974 L
.232 .32975 L
.236 .3103 L
.24 .29231 L
.244 .27647 L
.248 .2632 L
.252 .25266 L
.256 .24473 L
.26 .23914 L
.264 .23547 L
.268 .23327 L
.272 .23211 L
.276 .23161 L
.28 .23149 L
.284 .23154 L
.288 .23164 L
.292 .23173 L
.296 .23179 L
.3 .23182 L
.304 .23183 L
.308 .23183 L
.312 .23182 L
.316 .23182 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23182 L
.688 .23182 L
.692 .23183 L
.696 .23183 L
.7 .23182 L
.704 .23179 L
.708 .23173 L
.712 .23164 L
.716 .23154 L
.72 .23149 L
.724 .23161 L
.728 .23211 L
.732 .23327 L
.736 .23547 L
.74 .23914 L
.744 .24473 L
.748 .25266 L
.752 .2632 L
.756 .27647 L
.76 .29231 L
.764 .3103 L
.768 .32975 L
.772 .34974 L
.776 .36918 L
.78 .38696 L
.784 .40202 L
.788 .41345 L
.792 .42063 L
.796 .42322 L
.8 .42123 L
Mistroke
.804 .41497 L
.808 .40499 L
.812 .39205 L
.816 .37701 L
.82 .36072 L
.824 .34402 L
.828 .32761 L
.832 .31208 L
.836 .29785 L
.84 .28517 L
.844 .27417 L
.848 .26486 L
.852 .25717 L
.856 .25094 L
.86 .24601 L
.864 .24218 L
.868 .23926 L
.872 .23708 L
.876 .23547 L
.88 .23432 L
.884 .23349 L
.888 .23292 L
.892 .23252 L
.896 .23226 L
.9 .23208 L
.904 .23196 L
.908 .23189 L
.912 .23184 L
.916 .23181 L
.92 .23179 L
.924 .23178 L
.928 .23177 L
.932 .23177 L
.936 .23177 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35315 L
.076 .35314 L
.08 .35313 L
.084 .35311 L
.088 .35307 L
.092 .35301 L
.096 .35292 L
.1 .35278 L
.104 .35257 L
.108 .35225 L
.112 .35178 L
.116 .3511 L
.12 .35012 L
.124 .34874 L
.128 .34683 L
.132 .34423 L
.136 .34075 L
.14 .33619 L
.144 .33031 L
.148 .3229 L
.152 .31373 L
.156 .30265 L
.16 .28955 L
.164 .27444 L
.168 .25748 L
.172 .23898 L
.176 .21944 L
.18 .19955 L
.184 .18015 L
.188 .16222 L
.192 .14682 L
.196 .13494 L
.2 .12748 L
Mistroke
.204 .12511 L
.208 .1282 L
.212 .13676 L
.216 .15038 L
.22 .16832 L
.224 .1895 L
.228 .21267 L
.232 .23648 L
.236 .25965 L
.24 .28109 L
.244 .29996 L
.248 .31577 L
.252 .32833 L
.256 .33777 L
.26 .34444 L
.264 .34881 L
.268 .35143 L
.272 .35281 L
.276 .35341 L
.28 .35355 L
.284 .35349 L
.288 .35337 L
.292 .35326 L
.296 .35319 L
.3 .35316 L
.304 .35315 L
.308 .35315 L
.312 .35315 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35317 L
.692 .35318 L
.696 .35318 L
.7 .35317 L
.704 .35313 L
.708 .35306 L
.712 .35295 L
.716 .35283 L
.72 .35277 L
.724 .35292 L
.728 .35351 L
.732 .35489 L
.736 .35751 L
.74 .36189 L
.744 .36855 L
.748 .37799 L
.752 .39056 L
.756 .40636 L
.76 .42523 L
.764 .44667 L
.768 .46984 L
.772 .49366 L
.776 .51682 L
.78 .53801 L
.784 .55594 L
.788 .56957 L
.792 .57812 L
.796 .58121 L
.8 .57885 L
Mistroke
.804 .57139 L
.808 .55951 L
.812 .5441 L
.816 .52618 L
.82 .50678 L
.824 .48688 L
.828 .46734 L
.832 .44884 L
.836 .43188 L
.84 .41678 L
.844 .40368 L
.848 .39259 L
.852 .38343 L
.856 .37601 L
.86 .37014 L
.864 .36557 L
.868 .3621 L
.872 .35949 L
.876 .35758 L
.88 .3562 L
.884 .35522 L
.888 .35454 L
.892 .35407 L
.896 .35375 L
.9 .35354 L
.904 .3534 L
.908 .35331 L
.912 .35325 L
.916 .35322 L
.92 .3532 L
.924 .35318 L
.928 .35317 L
.932 .35317 L
.936 .35317 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23178 L
.08 .23179 L
.084 .23181 L
.088 .23184 L
.092 .23189 L
.096 .23196 L
.1 .23208 L
.104 .23226 L
.108 .23252 L
.112 .23292 L
.116 .23349 L
.12 .23432 L
.124 .23547 L
.128 .23708 L
.132 .23926 L
.136 .24218 L
.14 .24601 L
.144 .25094 L
.148 .25717 L
.152 .26486 L
.156 .27417 L
.16 .28517 L
.164 .29785 L
.168 .31208 L
.172 .32761 L
.176 .34402 L
.18 .36072 L
.184 .37701 L
.188 .39205 L
.192 .40499 L
.196 .41497 L
.2 .42123 L
Mistroke
.204 .42322 L
.208 .42063 L
.212 .41345 L
.216 .40202 L
.22 .38696 L
.224 .36918 L
.228 .34974 L
.232 .32975 L
.236 .3103 L
.24 .29231 L
.244 .27647 L
.248 .2632 L
.252 .25266 L
.256 .24473 L
.26 .23914 L
.264 .23547 L
.268 .23327 L
.272 .23211 L
.276 .23161 L
.28 .23149 L
.284 .23154 L
.288 .23164 L
.292 .23173 L
.296 .23179 L
.3 .23182 L
.304 .23183 L
.308 .23183 L
.312 .23182 L
.316 .23182 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23182 L
.688 .23182 L
.692 .23183 L
.696 .23183 L
.7 .23182 L
.704 .23179 L
.708 .23173 L
.712 .23164 L
.716 .23154 L
.72 .23149 L
.724 .23161 L
.728 .23211 L
.732 .23327 L
.736 .23547 L
.74 .23914 L
.744 .24473 L
.748 .25266 L
.752 .2632 L
.756 .27647 L
.76 .29231 L
.764 .3103 L
.768 .32975 L
.772 .34974 L
.776 .36918 L
.78 .38696 L
.784 .40202 L
.788 .41345 L
.792 .42063 L
.796 .42322 L
.8 .42123 L
Mistroke
.804 .41497 L
.808 .40499 L
.812 .39205 L
.816 .37701 L
.82 .36072 L
.824 .34402 L
.828 .32761 L
.832 .31208 L
.836 .29785 L
.84 .28517 L
.844 .27417 L
.848 .26486 L
.852 .25717 L
.856 .25094 L
.86 .24601 L
.864 .24218 L
.868 .23926 L
.872 .23708 L
.876 .23547 L
.88 .23432 L
.884 .23349 L
.888 .23292 L
.892 .23252 L
.896 .23226 L
.9 .23208 L
.904 .23196 L
.908 .23189 L
.912 .23184 L
.916 .23181 L
.92 .23179 L
.924 .23178 L
.928 .23177 L
.932 .23177 L
.936 .23177 L
.94 .23176 L
.944 .23176 L
.948 .23176 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo0P000Woo00D007ooOomoo`0000=oo`03001oo`00008000=oo`05001oogooOol00004
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
000017oo0`0000=oo`00Ool00Woo00D007ooOomoo`00009oo`8000=oo`05001oogooOol00004Ool0
0`00Oomoo`0:Ool001aoo`8000eoo`03001oogoo00Qoo`80035oo`8000Yoo`03001oogoo01Uoo`00
77oo00<007ooOol03Goo00<007ooOol01goo00<007ooOol0<Goo00<007ooOol01goo00<007ooOol0
6Woo000LOol2000>Ool00`00Oomoo`07Ool00`00Oomoo`0aOol00`00Oomoo`07Ool00`00Oomoo`0J
Ool001aoo`03001oogoo00eoo`03001oogoo00Ioo`03001oogoo039oo`03001oogoo00Ioo`03001o
ogoo01]oo`002goo0P0017oo00@007ooOomoo`D0009oo`8000moo`03001oogoo00Eoo`03001oogoo
039oo`03001oogoo00Ioo`03001oogoo01]oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0>Ool00`00Oomoo`05Ool00`00Oomoo`0cOol00`00Oomoo`05Ool00`00Oomoo`0KOol0
00Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000?Ool00`00Oomoo`05Ool00`00Oomoo`0cOol0
0`00Oomoo`05Ool00`00Oomoo`0KOol000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Goo00<0
07ooOol017oo00<007ooOol0<goo00<007ooOol017oo00<007ooOol077oo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`80011oo`03001oogoo00=oo`03001oogoo03Eoo`03001oogoo00=o
o`03001oogoo01aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0?Ool0
0`00Oomoo`03Ool00`00Oomoo`0eOol00`00Oomoo`03Ool00`00Oomoo`0LOol000]oo`8000Uoo`<0
00=oo`80011oo`03001oogoo00=oo`03001oogoo03Eoo`03001oogoo009oo`03001oogoo01eoo`00
77oo00<007ooOol03goo00<007ooOol00goo00<007ooOol0=Goo00<007ooOol00Woo00<007ooOol0
7Goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000AOol01@00Oomoogoo0000>7oo00<007oo
Ool00Woo00<007ooOol07Goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`05001oogoo
Ool0000hOol00`00Oomoo`02Ool00`00Oomoo`0MOol000Yoo`04001oogoo0007Ool50002Ool2000A
Ool01@00Oomoogoo0000>Goo00D007ooOomoo`0001moo`002Woo00@007ooOol000Moo`04001oogoo
0003Ool00`00Oomoo`0AOol01000Oomoo`00>Goo00@007ooOol0021oo`002Woo00@007ooOol000Qo
o`03001oo`0000=oo`80019oo`04001oogoo000iOol01000Oomoo`0087oo000:Ool01000Oomoo`00
2Goo0P000goo00<007ooOol04Goo00<007oo0000>goo0P008Goo000;Ool2000;Ool01000Oomoogoo
0P004goo0P00>goo0P008Goo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<0
00=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomo
o`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03
001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<0
00=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001c
Ool001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo
07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00N7oo000:Ool01000Oomo
o`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002
Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8007=oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool40003Ool2001cOol000Yoo`04001o
ogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Oomoo`03
Ool2001cOol000]oo`8000Yoo`8000=oo`03001oogoo019oo`03001oogoo05eoo`0077oo0P004Woo
0`00GWoo000LOol00`00Oomoo`0AOol00`00Ool0001NOol000]oo`8000Aoo`03001oogoo00=oo`<0
009oo`80019oo`04001oogoo001MOol000Yoo`04001oogoo000:Ool01@00Oomoogoo00004goo00@0
07ooOol005eoo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo015oo`04001oogoo
001MOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P004Goo00D007ooOomoo`0005eoo`00
2Woo00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo011oo`05001oogooOol0001MOol000Yo
o`04001oogoo0009Ool20003Ool2000AOol01@00Oomoogoo0000GGoo000;Ool2000;Ool01@00Oomo
ogoo00004Woo00<007ooOol00Woo00<007ooOol0FWoo000LOol2000@Ool00`00Oomoo`03Ool00`00
Oomoo`1JOol001aoo`03001oogoo00moo`03001oogoo00=oo`03001oogoo05Yoo`002goo0P0017oo
00@007ooOomoo`D0009oo`80011oo`03001oogoo00=oo`03001oogoo05Yoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`1JOol000=oo`D0
009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool00`00Oomo
o`1IOol000Yoo`04001oogoo000:Ool01000Oomoogoo0P003Woo0`0017oo0`0027oo0`0017oo0P00
17oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P00
1Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`05001oo`00Ool0
0002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00
Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2000?Ool00`00Ool00002Ool01000Oomoo`00
2Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool20009Ool30003Ool00`00Oomoo`0>
Ool00`00Ool00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo
000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomo
o`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<0
07ooOol037oo0P001Goo00<007ooOol00P001goo0P0017oo00@007ooOol0009oo`04001oogoo0004
Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002
Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomo
o`0<Ool50003Ool200000goo001oo`07Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo
1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000=Ool0
0`00Oomoo`09Ool00`00Oomoo`1GOol001aoo`03001oogoo00Yoo`8000aoo`8005Qoo`0077ooJ@00
37oo000LOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0<Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool001aoo`8004aoo`03001o
ogoo00Qoo`03001oogoo01Uoo`0077oo00<007ooOol0Bgoo00<007ooOol01goo00<007ooOol06Woo
000LOol2001<Ool00`00Oomoo`07Ool00`00Oomoo`0JOol001aoo`03001oogoo04]oo`03001oogoo
00Ioo`03001oogoo01]oo`0077oo00<007ooOol0Bgoo00<007ooOol01Woo00<007ooOol06goo000;
Ool20004Ool01000Oomoogoo1@000Woo0P00CGoo00<007ooOol01Goo00<007ooOol06goo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`03001oogoo04aoo`03001oogoo00Eoo`03001oogoo01]o
o`002Woo00@007ooOol000Uoo`03001oogoo009oo`8004eoo`03001oogoo00Eoo`03001oogoo01]o
o`002Woo00@007ooOol000Yoo`05001oogooOol0001>Ool00`00Oomoo`04Ool00`00Oomoo`0LOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00CGoo00<007ooOol017oo00<007ooOol0
77oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo04eoo`03001oogoo00=o
o`03001oogoo01aoo`002goo0P002Goo0`000goo00<007ooOol0CGoo00<007ooOol00goo00<007oo
Ool077oo000LOol2001>Ool00`00Oomoo`02Ool00`00Oomoo`0MOol001aoo`03001oogoo04eoo`03
001oogoo009oo`03001oogoo01eoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00CWoo00<0
07ooOol00Woo00<007ooOol07Goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0004moo`03001o
ogoo009oo`03001oogoo01eoo`002Woo00@007ooOol000Moo`D0009oo`8004ioo`03001oogoo009o
o`03001oogoo01eoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1>Ool01@00
Oomoogoo00007goo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Cgoo00@007ooOol0021o
o`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo04ioo`04001oogoo000POol000]oo`8000]o
o`05001oogooOol0001AOol2000QOol001aoo`80051oo`80025oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomo
ogoo0000M7oo0003Ool50002Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`00
1goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`80
07=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00@007ooOomo
o`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P00Lgoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`80
00Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`80
00Ioo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`8000eoo`05001oogooOol00002
Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomo
ogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Yoo`05001oogooOol0000BOol01000Oomoo`000Woo00<007ooOol01goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
015oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo10000goo00@007oo
Ool000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=o
o`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00
Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uoo`<000=oo`8000eoo`03001oogoo
00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001o
ogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004
Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`80
00Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004
Ool20006Ool30002Ool50003Ool20006Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOomY
000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`040002Ool01@00Oomoogoo00000goo00<0
07oo00000P000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00004Ool300000goo001oo`02Ool01@00Oomoogoo0000
0Woo100000=oo`00Ool00Woo00<007ooOol00Woo00<007ooOol02Woo000LOol2000<Ool2000;Ool0
0`00Oomoo`0_Ool00`00Oomoo`09Ool2000JOol001aoo`03001oogoo00eoo`03001oogoo00Moo`03
001oogoo035oo`03001oogoo00Moo`03001oogoo01Yoo`0077oo0P003Woo00<007ooOol01goo00<0
07ooOol0<Goo00<007ooOol01goo00<007ooOol06Woo000LOol00`00Oomoo`0=Ool00`00Oomoo`06
Ool00`00Oomoo`0bOol00`00Oomoo`06Ool00`00Oomoo`0KOol000]oo`8000Aoo`04001oogooOol5
0002Ool2000?Ool00`00Oomoo`05Ool00`00Oomoo`0bOol00`00Oomoo`06Ool00`00Oomoo`0KOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol03Woo00<007ooOol01Goo00<007oo
Ool0<goo00<007ooOol01Goo00<007ooOol06goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo
0P003goo00<007ooOol01Goo00<007ooOol0<goo00<007ooOol01Goo00<007ooOol06goo000:Ool0
1000Oomoo`002Woo00D007ooOomoo`00015oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo
00Aoo`03001oogoo01aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000@Ool00`00
Oomoo`04Ool00`00Oomoo`0cOol00`00Oomoo`04Ool00`00Oomoo`0LOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol03goo00<007ooOol00goo00<007ooOol0=Goo00<007oo
Ool00goo00<007ooOol077oo000;Ool20009Ool30003Ool2000@Ool00`00Oomoo`03Ool00`00Oomo
o`0eOol00`00Oomoo`02Ool00`00Oomoo`0MOol001aoo`03001oogoo00moo`03001oogoo00=oo`03
001oogoo03Eoo`03001oogoo009oo`03001oogoo01eoo`002goo0P0017oo00<007ooOol00goo0`00
0Woo0P004Goo00<007ooOol00Woo00<007ooOol0=Goo00<007ooOol00Woo00<007ooOol07Goo000:
Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`05001oogooOol0000hOol00`00Oomoo`02Ool0
0`00Oomoo`0MOol000Yoo`04001oogoo0007Ool50002Ool2000AOol01@00Oomoogoo0000>Goo00D0
07ooOomoo`0001moo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0AOol01000
Oomoo`00>Goo00@007ooOol0021oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`80019oo`04
001oogoo000iOol01000Oomoo`0087oo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol04Goo
00<007oo0000>goo0P008Goo000;Ool2000;Ool01000Oomoogoo0P004goo0P00>goo0P008Goo000L
Ool00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<0
07ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo
00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001o
ogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P00
2Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007oo
Ool00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`00
5goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1000\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23178 L
.068 .23179 L
.072 .23181 L
.076 .23184 L
.08 .23189 L
.084 .23197 L
.088 .23209 L
.092 .23227 L
.096 .23255 L
.1 .23295 L
.104 .23353 L
.108 .23436 L
.112 .23553 L
.116 .23715 L
.12 .23934 L
.124 .24226 L
.128 .2461 L
.132 .25102 L
.136 .25724 L
.14 .2649 L
.144 .27417 L
.148 .28511 L
.152 .29772 L
.156 .31188 L
.16 .32733 L
.164 .34366 L
.168 .3603 L
.172 .37654 L
.176 .39158 L
.18 .40455 L
.184 .4146 L
.188 .42098 L
.192 .42312 L
.196 .42069 L
.2 .41369 L
Mistroke
.204 .40241 L
.208 .38748 L
.212 .36977 L
.216 .35033 L
.22 .3303 L
.224 .31076 L
.228 .29263 L
.232 .27665 L
.236 .26324 L
.24 .25258 L
.244 .24457 L
.248 .23893 L
.252 .23524 L
.256 .23306 L
.26 .23194 L
.264 .23148 L
.268 .2314 L
.272 .23149 L
.276 .23162 L
.28 .23173 L
.284 .23179 L
.288 .23183 L
.292 .23183 L
.296 .23183 L
.3 .23182 L
.304 .23182 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23182 L
.7 .23182 L
.704 .23183 L
.708 .23183 L
.712 .23183 L
.716 .23179 L
.72 .23173 L
.724 .23162 L
.728 .23149 L
.732 .2314 L
.736 .23148 L
.74 .23194 L
.744 .23306 L
.748 .23524 L
.752 .23893 L
.756 .24457 L
.76 .25258 L
.764 .26324 L
.768 .27665 L
.772 .29263 L
.776 .31076 L
.78 .3303 L
.784 .35033 L
.788 .36977 L
.792 .38748 L
.796 .40241 L
.8 .41369 L
Mistroke
.804 .42069 L
.808 .42312 L
.812 .42098 L
.816 .4146 L
.82 .40455 L
.824 .39158 L
.828 .37654 L
.832 .3603 L
.836 .34366 L
.84 .32733 L
.844 .31188 L
.848 .29772 L
.852 .28511 L
.856 .27417 L
.86 .2649 L
.864 .25724 L
.868 .25102 L
.872 .2461 L
.876 .24226 L
.88 .23934 L
.884 .23715 L
.888 .23553 L
.892 .23436 L
.896 .23353 L
.9 .23295 L
.904 .23255 L
.908 .23227 L
.912 .23209 L
.916 .23197 L
.92 .23189 L
.924 .23184 L
.928 .23181 L
.932 .23179 L
.936 .23178 L
.94 .23177 L
.944 .23177 L
.948 .23177 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35315 L
.064 .35314 L
.068 .35313 L
.072 .3531 L
.076 .35307 L
.08 .35301 L
.084 .35291 L
.088 .35277 L
.092 .35255 L
.096 .35223 L
.1 .35175 L
.104 .35106 L
.108 .35007 L
.112 .34867 L
.116 .34675 L
.12 .34414 L
.124 .34065 L
.128 .33609 L
.132 .33022 L
.136 .32282 L
.14 .31368 L
.144 .30265 L
.148 .28961 L
.152 .27459 L
.156 .25772 L
.16 .23932 L
.164 .21987 L
.168 .20005 L
.172 .1807 L
.176 .16279 L
.18 .14734 L
.184 .13537 L
.188 .12778 L
.192 .12523 L
.196 .12812 L
.2 .13647 L
Mistroke
.204 .14991 L
.208 .1677 L
.212 .18881 L
.216 .21196 L
.22 .23583 L
.224 .25911 L
.228 .2807 L
.232 .29975 L
.236 .31572 L
.24 .32842 L
.244 .33797 L
.248 .34469 L
.252 .34908 L
.256 .35167 L
.26 .35301 L
.264 .35355 L
.268 .35365 L
.272 .35355 L
.276 .35339 L
.28 .35327 L
.284 .35319 L
.288 .35315 L
.292 .35314 L
.296 .35315 L
.3 .35315 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35317 L
.704 .35318 L
.708 .35318 L
.712 .35318 L
.716 .35314 L
.72 .35306 L
.724 .35293 L
.728 .35278 L
.732 .35268 L
.736 .35277 L
.74 .35331 L
.744 .35465 L
.748 .35725 L
.752 .36164 L
.756 .36836 L
.76 .3779 L
.764 .39061 L
.768 .40658 L
.772 .42562 L
.776 .44721 L
.78 .4705 L
.784 .49436 L
.788 .51752 L
.792 .53862 L
.796 .55641 L
.8 .56985 L
Mistroke
.804 .5782 L
.808 .58109 L
.812 .57855 L
.816 .57095 L
.82 .55898 L
.824 .54354 L
.828 .52563 L
.832 .50628 L
.836 .48646 L
.84 .46701 L
.844 .44861 L
.848 .43174 L
.852 .41671 L
.856 .40368 L
.86 .39264 L
.864 .38351 L
.868 .37611 L
.872 .37024 L
.876 .36567 L
.88 .36219 L
.884 .35957 L
.888 .35765 L
.892 .35626 L
.896 .35527 L
.9 .35457 L
.904 .3541 L
.908 .35377 L
.912 .35355 L
.916 .35341 L
.92 .35332 L
.924 .35326 L
.928 .35322 L
.932 .3532 L
.936 .35318 L
.94 .35317 L
.944 .35317 L
.948 .35317 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23178 L
.068 .23179 L
.072 .23181 L
.076 .23184 L
.08 .23189 L
.084 .23197 L
.088 .23209 L
.092 .23227 L
.096 .23255 L
.1 .23295 L
.104 .23353 L
.108 .23436 L
.112 .23553 L
.116 .23715 L
.12 .23934 L
.124 .24226 L
.128 .2461 L
.132 .25102 L
.136 .25724 L
.14 .2649 L
.144 .27417 L
.148 .28511 L
.152 .29772 L
.156 .31188 L
.16 .32733 L
.164 .34366 L
.168 .3603 L
.172 .37654 L
.176 .39158 L
.18 .40455 L
.184 .4146 L
.188 .42098 L
.192 .42312 L
.196 .42069 L
.2 .41369 L
Mistroke
.204 .40241 L
.208 .38748 L
.212 .36977 L
.216 .35033 L
.22 .3303 L
.224 .31076 L
.228 .29263 L
.232 .27665 L
.236 .26324 L
.24 .25258 L
.244 .24457 L
.248 .23893 L
.252 .23524 L
.256 .23306 L
.26 .23194 L
.264 .23148 L
.268 .2314 L
.272 .23149 L
.276 .23162 L
.28 .23173 L
.284 .23179 L
.288 .23183 L
.292 .23183 L
.296 .23183 L
.3 .23182 L
.304 .23182 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23182 L
.7 .23182 L
.704 .23183 L
.708 .23183 L
.712 .23183 L
.716 .23179 L
.72 .23173 L
.724 .23162 L
.728 .23149 L
.732 .2314 L
.736 .23148 L
.74 .23194 L
.744 .23306 L
.748 .23524 L
.752 .23893 L
.756 .24457 L
.76 .25258 L
.764 .26324 L
.768 .27665 L
.772 .29263 L
.776 .31076 L
.78 .3303 L
.784 .35033 L
.788 .36977 L
.792 .38748 L
.796 .40241 L
.8 .41369 L
Mistroke
.804 .42069 L
.808 .42312 L
.812 .42098 L
.816 .4146 L
.82 .40455 L
.824 .39158 L
.828 .37654 L
.832 .3603 L
.836 .34366 L
.84 .32733 L
.844 .31188 L
.848 .29772 L
.852 .28511 L
.856 .27417 L
.86 .2649 L
.864 .25724 L
.868 .25102 L
.872 .2461 L
.876 .24226 L
.88 .23934 L
.884 .23715 L
.888 .23553 L
.892 .23436 L
.896 .23353 L
.9 .23295 L
.904 .23255 L
.908 .23227 L
.912 .23209 L
.916 .23197 L
.92 .23189 L
.924 .23184 L
.928 .23181 L
.932 .23179 L
.936 .23178 L
.94 .23177 L
.944 .23177 L
.948 .23177 L
.952 .23176 L
.956 .23176 L
.96 .23176 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00`000goo00D007ooOomoo`0000=oo`80009oo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
000017oo00<007ooOol00P000goo00D007ooOomoo`0000=oo`80009oo`05001oogooOol00004Ool0
0`00Oomoo`0:Ool001aoo`8000]oo`8000Yoo`03001oogoo039oo`8000Yoo`03001oogoo01Qoo`00
77oo00<007ooOol02goo00<007ooOol027oo00<007ooOol0<goo00<007ooOol027oo00<007ooOol0
67oo000LOol2000=Ool00`00Oomoo`07Ool00`00Oomoo`0cOol00`00Oomoo`07Ool00`00Oomoo`0I
Ool001aoo`03001oogoo00aoo`03001oogoo00Ioo`03001oogoo03Eoo`03001oogoo00Ioo`03001o
ogoo01Uoo`002goo0P0017oo00@007ooOomoo`D0009oo`8000ioo`03001oogoo00Eoo`03001oogoo
03Eoo`03001oogoo00Eoo`03001oogoo01Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool00`00Oomoo`05Ool00`00Oomoo`0eOol00`00Oomoo`05Ool00`00Oomoo`0JOol0
00Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000>Ool00`00Oomoo`04Ool00`00Oomoo`0fOol0
0`00Oomoo`05Ool00`00Oomoo`0JOol000Yoo`04001oogoo000:Ool01@00Oomoogoo00003goo00<0
07ooOol017oo00<007ooOol0=Woo00<007ooOol017oo00<007ooOol06goo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8000moo`03001oogoo00=oo`03001oogoo03Moo`03001oogoo00=o
o`03001oogoo01]oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0>Ool0
0`00Oomoo`03Ool00`00Oomoo`0gOol00`00Oomoo`03Ool00`00Oomoo`0KOol000]oo`8000Uoo`<0
00=oo`8000moo`03001oogoo00=oo`03001oogoo03Moo`03001oogoo00=oo`03001oogoo01]oo`00
77oo00<007ooOol03Woo00<007ooOol00goo00<007ooOol0=goo00<007ooOol00goo00<007ooOol0
6goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000@Ool00`00Oomoo`02Ool00`00Oomoo`0g
Ool00`00Oomoo`02Ool00`00Oomoo`0LOol000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Goo
00D007ooOomoo`0003]oo`05001oogooOol0000NOol000Yoo`04001oogoo0007Ool50002Ool2000@
Ool01@00Oomoogoo0000>goo00D007ooOomoo`0001ioo`002Woo00@007ooOol000Moo`04001oogoo
0003Ool00`00Oomoo`0?Ool01@00Oomoogoo0000>goo00@007ooOol001moo`002Woo00@007ooOol0
00Qoo`03001oo`0000=oo`80015oo`03001oo`0003aoo`04001oogoo000OOol000Yoo`04001oogoo
0009Ool20003Ool00`00Oomoo`0@Ool00`00Ool0000mOol00`00Ool0000OOol000]oo`8000]oo`04
001oogooOol2000BOol00`00Oomoo`0lOol2000POol001aoo`03001oogoo079oo`002goo0P0017oo
00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001o
ogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001c
Ool000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=o
o`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001o
ogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03
001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uo
o`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3001h
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo0P00Lgoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`@000=oo`80
07=oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`03001oogoo079oo`002Woo00@007ooOol0
00Qoo`03001oogoo00=oo`8007=oo`002goo0P002Woo0P000goo00<007ooOol04Goo00<007ooOol0
GWoo000LOol2000AOol2001POol001aoo`03001oogoo011oo`03001oo`0005moo`002goo0P0017oo
00<007ooOol00goo0`000Woo0P004Goo00<007oo0000Ggoo000:Ool01000Oomoo`002Woo00D007oo
Oomoo`00015oo`04001oogoo001OOol000=oo`D0009oo`04001oogoo0007Ool50002Ool00`00Oomo
o`0?Ool01@00Oomoogoo0000GWoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`80011oo`05
001oogooOol0001NOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`0?Ool01@00
Oomoogoo0000GWoo000:Ool01000Oomoo`002Goo0P000goo0P0047oo00D007ooOomoo`0005ioo`00
2goo0P002goo00D007ooOomoo`00015oo`03001oogoo009oo`03001oogoo05]oo`0077oo0P003goo
00<007ooOol00goo00<007ooOol0Fgoo000LOol00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomo
o`1KOol000]oo`8000Aoo`04001oogooOol50002Ool2000?Ool00`00Oomoo`03Ool00`00Oomoo`1K
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol03Woo00<007ooOol00goo00<0
07ooOol0Fgoo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo00<007ooOol03Goo00<0
07ooOol017oo00<007ooOol0Fgoo000:Ool01000Oomoo`002Woo00@007ooOomoo`8000ioo`<000Ao
o`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eo
o`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`0<Ool20002Ool01@00Oomoo`00Ool00P002Goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000>Ool01000Oomoo`00
0Woo00@007oo000000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Goo0`00
0goo00<007ooOol03Goo00@007ooOol0009oo`04001oo`000009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002
Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oo`000009Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0;Ool60003Ool30009Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2000;Ool2000:Ool00`00Oomoo`1IOol001aoo`03001oogoo00Uoo`8000aoo`03001oogoo05Qo
o`0077ooJ@0037oo000LOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomo
o`0=Ool00`00Oomoo`02Ool00`00Oomoo`05Ool2000;Ool00`00Oomoo`0:Ool001aoo`8004eoo`03
001oogoo00Qoo`03001oogoo01Qoo`0077oo00<007ooOol0C7oo00<007ooOol027oo00<007ooOol0
67oo000LOol2001=Ool00`00Oomoo`07Ool00`00Oomoo`0IOol001aoo`03001oogoo04eoo`03001o
ogoo00Ioo`03001oogoo01Uoo`0077oo00<007ooOol0CGoo00<007ooOol01Goo00<007ooOol06Woo
000;Ool20004Ool01000Oomoogoo1@000Woo0P00CWoo00<007ooOol01Goo00<007ooOol06Woo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo04eoo`03001oogoo00Eoo`03001oogoo
01Yoo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8004ioo`03001oogoo00Eoo`03001oogoo
01Yoo`002Woo00@007ooOol000Yoo`05001oogooOol0001?Ool00`00Oomoo`04Ool00`00Oomoo`0K
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00CWoo00<007ooOol017oo00<007oo
Ool06goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo04ioo`03001oogoo
00=oo`03001oogoo01]oo`002goo0P002Goo0`000goo00<007ooOol0CWoo00<007ooOol00goo00<0
07ooOol06goo000LOol2001?Ool00`00Oomoo`03Ool00`00Oomoo`0KOol001aoo`03001oogoo04io
o`03001oogoo00=oo`03001oogoo01]oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00D7oo
00D007ooOomoo`0001ioo`002Woo00@007ooOol000Yoo`05001oogooOol0001AOol01@00Oomoogoo
00007Woo000:Ool01000Oomoo`001goo1@000Woo0P00D7oo00D007ooOomoo`0001ioo`002Woo00@0
07ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1?Ool01@00Oomoogoo00007Woo000:Ool01000
Oomoo`0027oo00<007oo00000goo0P00D7oo00@007ooOol001moo`002Woo00@007ooOol000Uoo`80
00=oo`03001oogoo04moo`04001oogoo000OOol000]oo`8000]oo`05001oogooOol0001BOol00`00
Ool0000OOol001aoo`80055oo`80021oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00
Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo0003Ool5
0002Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=o
o`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007oo
Ool000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00@007ooOomoo`8007=oo`0077oo00<0
07ooOol0LWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=o
o`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo
00@007ooOol000Uoo`03001oogoo009oo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007oo
Ool0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06
001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Yoo`05
001oogooOol0000BOol01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04001oogoo0002
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo10000goo00@007ooOol000Uoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=o
o`04001oogoo0005Ool000]oo`8000Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008
Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo
0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001o
o`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`03001oogoo00=o
o`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool5
0003Ool20006Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001o
ogooOol00003Ool00`00Ool000030003Ool01@00Oomoogoo00000goo0`0000=oo`00Ool00Woo00D0
07ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00004Ool00`00Ool000020003Ool01@00Oomoogoo00000goo1@000goo00<007oo
Ool00Woo00<007ooOol02Woo000LOol2000;Ool2000:Ool00`00Oomoo`0bOol00`00Oomoo`09Ool2
000IOol001aoo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo03=oo`03001oogoo00Qoo`03
001oogoo01Qoo`0077oo0P003Goo00<007ooOol01goo00<007ooOol0<goo00<007ooOol01goo00<0
07ooOol06Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`0eOol00`00Oomoo`06
Ool00`00Oomoo`0IOol000]oo`8000Aoo`04001oogooOol50002Ool2000>Ool00`00Oomoo`05Ool0
0`00Oomoo`0eOol00`00Oomoo`05Ool00`00Oomoo`0JOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00<007ooOol03Goo00<007ooOol01Goo00<007ooOol0=Goo00<007ooOol01Goo00<007oo
Ool06Woo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P003Woo00<007ooOol01Goo00<007oo
Ool0=Goo00<007ooOol01Goo00<007ooOol06Woo000:Ool01000Oomoo`002Woo00D007ooOomoo`00
00moo`03001oogoo00Aoo`03001oogoo03Ioo`03001oogoo00Aoo`03001oogoo01]oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2000?Ool00`00Oomoo`03Ool00`00Oomoo`0fOol00`00
Oomoo`04Ool00`00Oomoo`0KOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool03Woo00<007ooOol00goo00<007ooOol0=goo00<007ooOol00goo00<007ooOol06goo000;Ool2
0009Ool30003Ool2000?Ool00`00Oomoo`03Ool00`00Oomoo`0gOol00`00Oomoo`03Ool00`00Oomo
o`0KOol001aoo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo03Moo`03001oogoo00=oo`03
001oogoo01]oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P0047oo00<007ooOol00Woo00<0
07ooOol0=goo00<007ooOol00Woo00<007ooOol077oo000:Ool01000Oomoo`002Woo00D007ooOomo
o`00015oo`05001oogooOol0000kOol01@00Oomoogoo00007Woo000:Ool01000Oomoo`001goo1@00
0Woo0P0047oo00D007ooOomoo`0003]oo`05001oogooOol0000NOol000Yoo`04001oogoo0007Ool0
1000Oomoo`000goo00<007ooOol03goo00D007ooOomoo`0003]oo`04001oogoo000OOol000Yoo`04
001oogoo0008Ool00`00Ool00003Ool2000AOol00`00Ool0000lOol01000Oomoo`007goo000:Ool0
1000Oomoo`002Goo0P000goo00<007ooOol047oo00<007oo0000?Goo00<007oo00007goo000;Ool2
000;Ool01000Oomoogoo0P004Woo00<007ooOol0?7oo0P0087oo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:
Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol0
17oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:
Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo
0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000L
Ool00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo
000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000F
Ool2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1040\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23178 L
.056 .23179 L
.06 .23181 L
.064 .23185 L
.068 .2319 L
.072 .23198 L
.076 .2321 L
.08 .23229 L
.084 .23257 L
.088 .23298 L
.092 .23357 L
.096 .23441 L
.1 .23559 L
.104 .23721 L
.108 .23941 L
.112 .24235 L
.116 .24618 L
.12 .2511 L
.124 .2573 L
.128 .26494 L
.132 .27417 L
.136 .28506 L
.14 .2976 L
.144 .31169 L
.148 .32706 L
.152 .34331 L
.156 .35988 L
.16 .37609 L
.164 .39111 L
.168 .40411 L
.172 .41423 L
.176 .42072 L
.18 .42301 L
.184 .42075 L
.188 .41392 L
.192 .4028 L
.196 .38799 L
.2 .37035 L
Mistroke
.204 .35093 L
.208 .33086 L
.212 .31122 L
.216 .29297 L
.22 .27684 L
.224 .26329 L
.228 .25251 L
.232 .24441 L
.236 .23871 L
.24 .23502 L
.244 .23285 L
.248 .23176 L
.252 .23136 L
.256 .23132 L
.26 .23144 L
.264 .2316 L
.268 .23172 L
.272 .2318 L
.276 .23183 L
.28 .23184 L
.284 .23183 L
.288 .23182 L
.292 .23182 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23182 L
.712 .23182 L
.716 .23183 L
.72 .23184 L
.724 .23183 L
.728 .2318 L
.732 .23172 L
.736 .2316 L
.74 .23144 L
.744 .23132 L
.748 .23136 L
.752 .23176 L
.756 .23285 L
.76 .23502 L
.764 .23871 L
.768 .24441 L
.772 .25251 L
.776 .26329 L
.78 .27684 L
.784 .29297 L
.788 .31122 L
.792 .33086 L
.796 .35093 L
.8 .37035 L
Mistroke
.804 .38799 L
.808 .4028 L
.812 .41392 L
.816 .42075 L
.82 .42301 L
.824 .42072 L
.828 .41423 L
.832 .40411 L
.836 .39111 L
.84 .37609 L
.844 .35988 L
.848 .34331 L
.852 .32706 L
.856 .31169 L
.86 .2976 L
.864 .28506 L
.868 .27417 L
.872 .26494 L
.876 .2573 L
.88 .2511 L
.884 .24618 L
.888 .24235 L
.892 .23941 L
.896 .23721 L
.9 .23559 L
.904 .23441 L
.908 .23357 L
.912 .23298 L
.916 .23257 L
.92 .23229 L
.924 .2321 L
.928 .23198 L
.932 .2319 L
.936 .23185 L
.94 .23181 L
.944 .23179 L
.948 .23178 L
.952 .23177 L
.956 .23177 L
.96 .23177 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35315 L
.048 .35315 L
.052 .35314 L
.056 .35312 L
.06 .3531 L
.064 .35306 L
.068 .353 L
.072 .3529 L
.076 .35276 L
.08 .35254 L
.084 .3522 L
.088 .35172 L
.092 .35101 L
.096 .35001 L
.1 .34861 L
.104 .34667 L
.108 .34405 L
.112 .34055 L
.116 .33599 L
.12 .33012 L
.124 .32274 L
.128 .31364 L
.132 .30265 L
.136 .28967 L
.14 .27473 L
.144 .25795 L
.148 .23964 L
.152 .22029 L
.156 .20055 L
.16 .18125 L
.164 .16335 L
.168 .14787 L
.172 .13581 L
.176 .12808 L
.18 .12536 L
.184 .12805 L
.188 .1362 L
.192 .14945 L
.196 .1671 L
.2 .18811 L
Mistroke
.204 .21125 L
.208 .23516 L
.212 .25856 L
.216 .2803 L
.22 .29952 L
.224 .31566 L
.228 .32851 L
.232 .33816 L
.236 .34494 L
.24 .34935 L
.244 .35193 L
.248 .35322 L
.252 .35371 L
.256 .35375 L
.26 .3536 L
.264 .35342 L
.268 .35327 L
.272 .35318 L
.276 .35314 L
.28 .35313 L
.284 .35314 L
.288 .35315 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35317 L
.716 .35318 L
.72 .35319 L
.724 .35318 L
.728 .35315 L
.732 .35306 L
.736 .35291 L
.74 .35272 L
.744 .35257 L
.748 .35262 L
.752 .3531 L
.756 .3544 L
.76 .35698 L
.764 .36138 L
.768 .36816 L
.772 .37781 L
.776 .39066 L
.78 .4068 L
.784 .42602 L
.788 .44776 L
.792 .47116 L
.796 .49508 L
.8 .51821 L
Mistroke
.804 .53922 L
.808 .55687 L
.812 .57013 L
.816 .57827 L
.82 .58096 L
.824 .57824 L
.828 .57051 L
.832 .55846 L
.836 .54298 L
.84 .52508 L
.844 .50578 L
.848 .48604 L
.852 .46668 L
.856 .44837 L
.86 .4316 L
.864 .41665 L
.868 .40368 L
.872 .39269 L
.876 .38358 L
.88 .3762 L
.884 .37034 L
.888 .36577 L
.892 .36228 L
.896 .35965 L
.9 .35772 L
.904 .35631 L
.908 .35531 L
.912 .35461 L
.916 .35412 L
.92 .35379 L
.924 .35357 L
.928 .35342 L
.932 .35332 L
.936 .35326 L
.94 .35322 L
.944 .3532 L
.948 .35318 L
.952 .35318 L
.956 .35317 L
.96 .35317 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23178 L
.056 .23179 L
.06 .23181 L
.064 .23185 L
.068 .2319 L
.072 .23198 L
.076 .2321 L
.08 .23229 L
.084 .23257 L
.088 .23298 L
.092 .23357 L
.096 .23441 L
.1 .23559 L
.104 .23721 L
.108 .23941 L
.112 .24235 L
.116 .24618 L
.12 .2511 L
.124 .2573 L
.128 .26494 L
.132 .27417 L
.136 .28506 L
.14 .2976 L
.144 .31169 L
.148 .32706 L
.152 .34331 L
.156 .35988 L
.16 .37609 L
.164 .39111 L
.168 .40411 L
.172 .41423 L
.176 .42072 L
.18 .42301 L
.184 .42075 L
.188 .41392 L
.192 .4028 L
.196 .38799 L
.2 .37035 L
Mistroke
.204 .35093 L
.208 .33086 L
.212 .31122 L
.216 .29297 L
.22 .27684 L
.224 .26329 L
.228 .25251 L
.232 .24441 L
.236 .23871 L
.24 .23502 L
.244 .23285 L
.248 .23176 L
.252 .23136 L
.256 .23132 L
.26 .23144 L
.264 .2316 L
.268 .23172 L
.272 .2318 L
.276 .23183 L
.28 .23184 L
.284 .23183 L
.288 .23182 L
.292 .23182 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23182 L
.712 .23182 L
.716 .23183 L
.72 .23184 L
.724 .23183 L
.728 .2318 L
.732 .23172 L
.736 .2316 L
.74 .23144 L
.744 .23132 L
.748 .23136 L
.752 .23176 L
.756 .23285 L
.76 .23502 L
.764 .23871 L
.768 .24441 L
.772 .25251 L
.776 .26329 L
.78 .27684 L
.784 .29297 L
.788 .31122 L
.792 .33086 L
.796 .35093 L
.8 .37035 L
Mistroke
.804 .38799 L
.808 .4028 L
.812 .41392 L
.816 .42075 L
.82 .42301 L
.824 .42072 L
.828 .41423 L
.832 .40411 L
.836 .39111 L
.84 .37609 L
.844 .35988 L
.848 .34331 L
.852 .32706 L
.856 .31169 L
.86 .2976 L
.864 .28506 L
.868 .27417 L
.872 .26494 L
.876 .2573 L
.88 .2511 L
.884 .24618 L
.888 .24235 L
.892 .23941 L
.896 .23721 L
.9 .23559 L
.904 .23441 L
.908 .23357 L
.912 .23298 L
.916 .23257 L
.92 .23229 L
.924 .2321 L
.928 .23198 L
.932 .2319 L
.936 .23185 L
.94 .23181 L
.944 .23179 L
.948 .23178 L
.952 .23177 L
.956 .23177 L
.96 .23177 L
.964 .23176 L
.968 .23176 L
.972 .23176 L
.976 .23176 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07oo00000`000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo1@000goo00<007ooOol00Woo00<007oo
Ool02Woo000LOol2000:Ool2000:Ool00`00Oomoo`0eOol00`00Oomoo`08Ool2000HOol001aoo`03
001oogoo00Yoo`03001oogoo00Qoo`03001oogoo03Eoo`03001oogoo00Qoo`03001oogoo01Moo`00
77oo0P002goo00<007ooOol01goo00<007ooOol0=Woo00<007ooOol01goo00<007ooOol067oo000L
Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0gOol00`00Oomoo`06Ool00`00Oomoo`0H
Ool000]oo`8000Aoo`04001oogooOol50002Ool2000<Ool00`00Oomoo`06Ool00`00Oomoo`0gOol0
0`00Oomoo`06Ool00`00Oomoo`0HOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007oo
Ool037oo00<007ooOol01Goo00<007ooOol0=goo00<007ooOol01Goo00<007ooOol06Goo000:Ool0
1000Oomoo`002Goo00<007ooOol00Woo0P003Goo00<007ooOol017oo00<007ooOol0>Goo00<007oo
Ool017oo00<007ooOol06Goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0000ioo`03001oogoo
00Aoo`03001oogoo03Uoo`03001oogoo00Aoo`03001oogoo01Uoo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool2000>Ool00`00Oomoo`03Ool00`00Oomoo`0iOol00`00Oomoo`03Ool00`00
Oomoo`0JOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol03Goo00<007oo
Ool00goo00<007ooOol0>Goo00<007ooOol00goo00<007ooOol06Woo000;Ool20009Ool30003Ool2
000>Ool00`00Oomoo`03Ool00`00Oomoo`0iOol00`00Oomoo`03Ool00`00Oomoo`0JOol001aoo`03
001oogoo00eoo`03001oogoo009oo`03001oogoo03Yoo`03001oogoo00=oo`03001oogoo01Yoo`00
2goo0P0017oo00<007ooOol00goo0`000Woo0P003Woo00<007ooOol00Woo00<007ooOol0>Woo00<0
07ooOol00Woo00<007ooOol06goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00011oo`05001o
ogooOol0000mOol01@00Oomoogoo00007Goo000:Ool01000Oomoo`001goo1@000Woo0P003goo00@0
07ooOol003ioo`05001oogooOol0000MOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<0
07ooOol03Woo00@007ooOol003ioo`05001oogooOol0000MOol000Yoo`04001oogoo0008Ool00`00
Ool00003Ool2000@Ool00`00Ool0000oOol00`00Ool0000NOol000Yoo`04001oogoo0009Ool20003
Ool00`00Oomoo`0?Ool00`00Ool0000oOol00`00Ool0000NOol000]oo`8000]oo`04001oogooOol2
000@Ool20011Ool00`00Oomoo`0MOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol0
0Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool4
0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04
001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`00
77oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`00
5Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009o
o`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<0
07ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3001hOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P00Lgoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`@000=oo`8007=oo`002Woo
00@007ooOol000Moo`03001oogoo00Aoo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001o
ogoo00=oo`8007=oo`002goo0P002Woo0P000goo00<007ooOol047oo00<007ooOol0Ggoo000LOol2
000@Ool3001POol001aoo`03001oogoo00moo`03001oo`00061oo`002goo0P0017oo00<007ooOol0
0goo0`000Woo0P0047oo00<007oo0000H7oo000:Ool01000Oomoo`002Woo00D007ooOomoo`00011o
o`04001oogoo001POol000=oo`D0009oo`04001oogoo0007Ool50002Ool00`00Oomoo`0>Ool01000
Oomoo`00H7oo000:Ool01000Oomoo`001goo00@007ooOol000=oo`8000moo`04001oogoo001POol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`0>Ool01@00Oomoogoo0000Ggoo000:
Ool01000Oomoo`002Goo0P000goo0P003Woo00<007ooOol00Woo00<007ooOol0GGoo000;Ool2000;
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0GGoo000LOol2000>Ool00`00Oomo
o`02Ool00`00Oomoo`1MOol001aoo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo05aoo`00
2goo0P0017oo00@007ooOomoo`D0009oo`8000ioo`03001oogoo00=oo`03001oogoo05aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`1L
Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`04
Ool00`00Oomoo`1LOol000Yoo`04001oogoo000:Ool01000Oomoogoo0P003Goo10000goo0`002Goo
0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo
0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`05
001oogooOol00002Ool200000goo001oo`08Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8000aoo`03001oogoo009o
o`03001oogoo00800003Ool007oo00Qoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo
0P002Goo0`000goo00<007ooOol02goo00<007ooOol00Woo00<007ooOol00P0000=oo`00Ool027oo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000<Ool50003Ool200000goo001o
o`08Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool0
1000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007oo
Oomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0:Ool00`00Ool00006Ool20000
0goo001oo`07Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Ao
o`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00
Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00Yoo`03001oo`0000@000=o
o`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool2
0004Ool20006Ool30002Ool50003Ool20006Ool001aoo`8000Yoo`8000Yoo`03001oogoo05Yoo`00
77oo00<007ooOol027oo0P0037oo00<007ooOol0FGoo000LOomY000<Ool001aoo`03001oogoo019o
o`03001oogoo019oo`03001oogoo015oo`03001oogoo00ioo`80009oo`03001oogoo00Ioo`8000Yo
o`03001oogoo00Yoo`0077oo0P00CWoo00<007ooOol027oo0P0067oo000LOol00`00Oomoo`1=Ool0
0`00Oomoo`08Ool00`00Oomoo`0GOol001aoo`8004ioo`03001oogoo00Moo`03001oogoo01Qoo`00
77oo00<007ooOol0CWoo00<007ooOol01Woo00<007ooOol067oo000LOol00`00Oomoo`1>Ool00`00
Oomoo`06Ool00`00Oomoo`0HOol000]oo`8000Aoo`04001oogooOol50002Ool2001?Ool00`00Oomo
o`06Ool00`00Oomoo`0HOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0CWoo
00<007ooOol01Goo00<007ooOol06Goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00D7oo
00<007ooOol017oo00<007ooOol06Goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00055oo`03
001oogoo00Aoo`03001oogoo01Uoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001@
Ool00`00Oomoo`04Ool00`00Oomoo`0IOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0Cgoo00<007ooOol00goo00<007ooOol06Woo000;Ool20009Ool30003Ool00`00Oomo
o`1?Ool00`00Oomoo`03Ool00`00Oomoo`0JOol001aoo`80051oo`03001oogoo00=oo`03001oogoo
01Yoo`0077oo00<007ooOol0Cgoo00<007ooOol00goo00<007ooOol06Woo000;Ool20004Ool00`00
Oomoo`03Ool30002Ool2001@Ool00`00Oomoo`02Ool00`00Oomoo`0KOol000Yoo`04001oogoo000:
Ool01@00Oomoogoo0000DWoo00D007ooOomoo`0001eoo`002Woo00@007ooOol000Moo`D0009oo`80
055oo`05001oogooOol0000MOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0
D7oo00D007ooOomoo`0001eoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`80055oo`05001o
ogooOol0000MOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1AOol00`00Ool0000NOol0
00]oo`8000]oo`05001oogooOol0001COol00`00Ool0000NOol001aoo`8005=oo`03001oogoo01eo
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yo
o`04001oogoo000:Ool01@00Oomoogoo0000M7oo0003Ool50002Ool01000Oomoo`001goo1@000Woo
0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079o
o`002goo0P002goo00@007ooOomoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool01000
Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00eo
o`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Ao
o`8000Eoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009o
o`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001o
ogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0
009oo`03001oogoo00=oo`002Woo00@007ooOol000Yoo`05001oogooOol0000BOol01000Oomoo`00
0Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`80015oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol037oo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uo
o`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001ao
o`03001oogoo00aoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool400000goo001oo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00<007oo
Ool00P000goo00D007ooOomoo`0000=oo`D000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo
0P002Woo0P002Woo00<007ooOol0=Goo00<007ooOol027oo0P0067oo000LOol00`00Oomoo`0:Ool0
0`00Oomoo`08Ool00`00Oomoo`0eOol00`00Oomoo`08Ool00`00Oomoo`0GOol001aoo`8000]oo`03
001oogoo00Moo`03001oogoo03Ioo`03001oogoo00Moo`03001oogoo01Qoo`0077oo00<007ooOol0
2goo00<007ooOol01Woo00<007ooOol0=goo00<007ooOol01Woo00<007ooOol067oo000;Ool20004
Ool01000Oomoogoo1@000Woo0P0037oo00<007ooOol01Woo00<007ooOol0=goo00<007ooOol01Woo
00<007ooOol067oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00aoo`03001o
ogoo00Eoo`03001oogoo03Moo`03001oogoo00Eoo`03001oogoo01Uoo`002Woo00@007ooOol000Uo
o`03001oogoo009oo`8000eoo`03001oogoo00Eoo`03001oogoo03Moo`03001oogoo00Eoo`03001o
ogoo01Uoo`002Woo00@007ooOol000Yoo`05001oogooOol0000>Ool00`00Oomoo`04Ool00`00Oomo
o`0iOol00`00Oomoo`04Ool00`00Oomoo`0IOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P003Woo00<007ooOol00goo00<007ooOol0>Goo00<007ooOol00goo00<007ooOol06Woo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00eoo`03001oogoo00=oo`03001o
ogoo03Uoo`03001oogoo00=oo`03001oogoo01Yoo`002goo0P002Goo0`000goo0P003Woo00<007oo
Ool00goo00<007ooOol0>Goo00<007ooOol00goo00<007ooOol06Woo000LOol00`00Oomoo`0=Ool0
0`00Oomoo`02Ool00`00Oomoo`0jOol00`00Oomoo`03Ool00`00Oomoo`0JOol000]oo`8000Aoo`03
001oogoo00=oo`<0009oo`8000ioo`03001oogoo009oo`03001oogoo03Yoo`03001oogoo009oo`03
001oogoo01]oo`002Woo00@007ooOol000Yoo`05001oogooOol0000@Ool01@00Oomoogoo0000?Goo
00D007ooOomoo`0001eoo`002Woo00@007ooOol000Moo`D0009oo`8000moo`05001oogooOol0000m
Ool01@00Oomoogoo00007Goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo00io
o`04001oogoo000nOol01@00Oomoogoo00007Goo000:Ool01000Oomoo`0027oo00<007oo00000goo
0P0047oo00<007oo0000?goo00<007oo00007Woo000:Ool01000Oomoo`002Goo0P000goo00<007oo
Ool03goo00<007oo0000?goo00<007oo00007Woo000;Ool2000;Ool01000Oomoogoo0P0047oo0P00
@Goo00<007ooOol07Goo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=o
o`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`00
27oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001o
ogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=o
o`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol0
01Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Mo
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1080\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23178 L
.044 .2318 L
.048 .23182 L
.052 .23185 L
.056 .2319 L
.06 .23199 L
.064 .23211 L
.068 .2323 L
.072 .23259 L
.076 .233 L
.08 .2336 L
.084 .23445 L
.088 .23564 L
.092 .23728 L
.096 .23949 L
.1 .24243 L
.104 .24626 L
.108 .25118 L
.112 .25736 L
.116 .26498 L
.12 .27417 L
.124 .28501 L
.128 .29749 L
.132 .3115 L
.136 .32679 L
.14 .34296 L
.144 .35947 L
.148 .37563 L
.152 .39065 L
.156 .40367 L
.16 .41386 L
.164 .42046 L
.168 .42289 L
.172 .4208 L
.176 .41414 L
.18 .40317 L
.184 .38849 L
.188 .37093 L
.192 .35153 L
.196 .33142 L
.2 .31169 L
Mistroke
.204 .29331 L
.208 .27704 L
.212 .26335 L
.216 .25244 L
.22 .24425 L
.224 .2385 L
.228 .23479 L
.232 .23264 L
.236 .23158 L
.24 .23122 L
.244 .23123 L
.248 .2314 L
.252 .23158 L
.256 .23172 L
.26 .23181 L
.264 .23184 L
.268 .23185 L
.272 .23184 L
.276 .23182 L
.28 .23182 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23182 L
.724 .23182 L
.728 .23184 L
.732 .23185 L
.736 .23184 L
.74 .23181 L
.744 .23172 L
.748 .23158 L
.752 .2314 L
.756 .23123 L
.76 .23122 L
.764 .23158 L
.768 .23264 L
.772 .23479 L
.776 .2385 L
.78 .24425 L
.784 .25244 L
.788 .26335 L
.792 .27704 L
.796 .29331 L
.8 .31169 L
Mistroke
.804 .33142 L
.808 .35153 L
.812 .37093 L
.816 .38849 L
.82 .40317 L
.824 .41414 L
.828 .4208 L
.832 .42289 L
.836 .42046 L
.84 .41386 L
.844 .40367 L
.848 .39065 L
.852 .37563 L
.856 .35947 L
.86 .34296 L
.864 .32679 L
.868 .3115 L
.872 .29749 L
.876 .28501 L
.88 .27417 L
.884 .26498 L
.888 .25736 L
.892 .25118 L
.896 .24626 L
.9 .24243 L
.904 .23949 L
.908 .23728 L
.912 .23564 L
.916 .23445 L
.92 .2336 L
.924 .233 L
.928 .23259 L
.932 .2323 L
.936 .23211 L
.94 .23199 L
.944 .2319 L
.948 .23185 L
.952 .23182 L
.956 .2318 L
.96 .23178 L
.964 .23177 L
.968 .23177 L
.972 .23177 L
.976 .23177 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35315 L
.036 .35315 L
.04 .35314 L
.044 .35312 L
.048 .3531 L
.052 .35306 L
.056 .35299 L
.06 .35289 L
.064 .35274 L
.068 .35252 L
.072 .35218 L
.076 .35168 L
.08 .35097 L
.084 .34996 L
.088 .34854 L
.092 .34659 L
.096 .34396 L
.1 .34046 L
.104 .33589 L
.108 .33003 L
.112 .32266 L
.116 .31359 L
.12 .30265 L
.124 .28974 L
.128 .27487 L
.132 .25818 L
.136 .23997 L
.14 .2207 L
.144 .20104 L
.148 .18179 L
.152 .1639 L
.156 .14839 L
.16 .13626 L
.164 .12839 L
.168 .1255 L
.172 .128 L
.176 .13594 L
.18 .149 L
.184 .1665 L
.188 .18742 L
.192 .21054 L
.196 .2345 L
.2 .258 L
Mistroke
.204 .27989 L
.208 .29928 L
.212 .31559 L
.216 .32859 L
.22 .33835 L
.224 .3452 L
.228 .34962 L
.232 .35218 L
.236 .35344 L
.24 .35387 L
.244 .35385 L
.248 .35366 L
.252 .35344 L
.256 .35327 L
.26 .35317 L
.264 .35313 L
.268 .35312 L
.272 .35314 L
.276 .35315 L
.28 .35316 L
.284 .35316 L
.288 .35317 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35317 L
.728 .35319 L
.732 .3532 L
.736 .35319 L
.74 .35315 L
.744 .35305 L
.748 .35288 L
.752 .35267 L
.756 .35247 L
.76 .35246 L
.764 .35289 L
.768 .35414 L
.772 .3567 L
.776 .36113 L
.78 .36797 L
.784 .37773 L
.788 .39073 L
.792 .40704 L
.796 .42643 L
.8 .44833 L
Mistroke
.804 .47183 L
.808 .49579 L
.812 .5189 L
.816 .53982 L
.82 .55732 L
.824 .57039 L
.828 .57833 L
.832 .58082 L
.836 .57793 L
.84 .57007 L
.844 .55793 L
.848 .54242 L
.852 .52454 L
.856 .50529 L
.86 .48562 L
.864 .46636 L
.868 .44815 L
.872 .43146 L
.876 .41659 L
.88 .40368 L
.884 .39273 L
.888 .38366 L
.892 .3763 L
.896 .37044 L
.9 .36587 L
.904 .36237 L
.908 .35973 L
.912 .35778 L
.916 .35637 L
.92 .35535 L
.924 .35464 L
.928 .35415 L
.932 .35381 L
.936 .35358 L
.94 .35343 L
.944 .35333 L
.948 .35327 L
.952 .35323 L
.956 .3532 L
.96 .35319 L
.964 .35318 L
.968 .35317 L
.972 .35317 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23178 L
.044 .2318 L
.048 .23182 L
.052 .23185 L
.056 .2319 L
.06 .23199 L
.064 .23211 L
.068 .2323 L
.072 .23259 L
.076 .233 L
.08 .2336 L
.084 .23445 L
.088 .23564 L
.092 .23728 L
.096 .23949 L
.1 .24243 L
.104 .24626 L
.108 .25118 L
.112 .25736 L
.116 .26498 L
.12 .27417 L
.124 .28501 L
.128 .29749 L
.132 .3115 L
.136 .32679 L
.14 .34296 L
.144 .35947 L
.148 .37563 L
.152 .39065 L
.156 .40367 L
.16 .41386 L
.164 .42046 L
.168 .42289 L
.172 .4208 L
.176 .41414 L
.18 .40317 L
.184 .38849 L
.188 .37093 L
.192 .35153 L
.196 .33142 L
.2 .31169 L
Mistroke
.204 .29331 L
.208 .27704 L
.212 .26335 L
.216 .25244 L
.22 .24425 L
.224 .2385 L
.228 .23479 L
.232 .23264 L
.236 .23158 L
.24 .23122 L
.244 .23123 L
.248 .2314 L
.252 .23158 L
.256 .23172 L
.26 .23181 L
.264 .23184 L
.268 .23185 L
.272 .23184 L
.276 .23182 L
.28 .23182 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23182 L
.724 .23182 L
.728 .23184 L
.732 .23185 L
.736 .23184 L
.74 .23181 L
.744 .23172 L
.748 .23158 L
.752 .2314 L
.756 .23123 L
.76 .23122 L
.764 .23158 L
.768 .23264 L
.772 .23479 L
.776 .2385 L
.78 .24425 L
.784 .25244 L
.788 .26335 L
.792 .27704 L
.796 .29331 L
.8 .31169 L
Mistroke
.804 .33142 L
.808 .35153 L
.812 .37093 L
.816 .38849 L
.82 .40317 L
.824 .41414 L
.828 .4208 L
.832 .42289 L
.836 .42046 L
.84 .41386 L
.844 .40367 L
.848 .39065 L
.852 .37563 L
.856 .35947 L
.86 .34296 L
.864 .32679 L
.868 .3115 L
.872 .29749 L
.876 .28501 L
.88 .27417 L
.884 .26498 L
.888 .25736 L
.892 .25118 L
.896 .24626 L
.9 .24243 L
.904 .23949 L
.908 .23728 L
.912 .23564 L
.916 .23445 L
.92 .2336 L
.924 .233 L
.928 .23259 L
.932 .2323 L
.936 .23211 L
.94 .23199 L
.944 .2319 L
.948 .23185 L
.952 .23182 L
.956 .2318 L
.96 .23178 L
.964 .23177 L
.968 .23177 L
.972 .23177 L
.976 .23177 L
.98 .23176 L
.984 .23176 L
.988 .23176 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo1000
00=oo`00Ool00Woo00H007ooOomoo`00Ool30003Ool01@00Oomoogoo00000goo00<007ooOol00Woo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00Aoo`04001oogooOol20002Ool01@00Oomoogoo00000goo00<007oo00000P000goo00<007ooOol0
0Woo00<007ooOol02Woo000LOol20009Ool00`00Oomoo`09Ool00`00Oomoo`0gOol00`00Oomoo`08
Ool2000GOol001aoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo03Moo`03001oogoo00Qo
o`03001oogoo01Ioo`0077oo0P002Woo00<007ooOol01goo00<007ooOol0>Goo00<007ooOol01goo
00<007ooOol05Woo000LOol00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`0iOol00`00Oomo
o`06Ool00`00Oomoo`0GOol000]oo`8000Aoo`04001oogooOol50002Ool2000;Ool00`00Oomoo`06
Ool00`00Oomoo`0iOol00`00Oomoo`06Ool00`00Oomoo`0GOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol0>Woo00<007ooOol01Goo00<0
07ooOol067oo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P002goo00<007ooOol01Goo00<0
07ooOol0>Woo00<007ooOol01Goo00<007ooOol067oo000:Ool01000Oomoo`002Woo00D007ooOomo
o`0000eoo`03001oogoo00Aoo`03001oogoo03]oo`03001oogoo00Aoo`03001oogoo01Qoo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000<Ool00`00Oomoo`04Ool00`00Oomoo`0kOol0
0`00Oomoo`04Ool00`00Oomoo`0HOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol02goo00<007ooOol00goo00<007ooOol0?7oo00<007ooOol017oo00<007ooOol067oo000;
Ool20009Ool30003Ool2000=Ool00`00Oomoo`02Ool00`00Oomoo`0lOol00`00Oomoo`03Ool00`00
Oomoo`0IOol001aoo`03001oogoo00aoo`03001oogoo009oo`03001oogoo03eoo`03001oogoo009o
o`03001oogoo01Uoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P003Goo00<007ooOol00Woo
00<007ooOol0?Goo00<007ooOol00Woo00<007ooOol06Goo000:Ool01000Oomoo`002Woo00D007oo
Oomoo`0000moo`05001oogooOol0000oOol01@00Oomoogoo000077oo000:Ool01000Oomoo`001goo
1@000Woo0P003Woo00@007ooOol0045oo`04001oogoo000LOol000Yoo`04001oogoo0007Ool01000
Oomoo`000goo00<007ooOol03Goo00@007ooOol0045oo`04001oogoo000LOol000Yoo`04001oogoo
0008Ool00`00Ool00003Ool2000>Ool01000Oomoo`00@Goo00<007oo00007Goo000:Ool01000Oomo
o`002Goo0P000goo00<007ooOol03Woo0P00@Woo00<007oo00007Goo000;Ool2000;Ool01000Oomo
ogoo0P003goo0P00@goo0P007Goo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009o
o`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo1000
0goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000
Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001ao
o`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Io
o`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2
001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001o
ogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00N7oo000:Ool01000
Oomoo`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`8007=oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool40003Ool2001cOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Oomo
o`03Ool2001cOol000]oo`8000Yoo`8000=oo`03001oogoo00moo`03001oogoo061oo`0077oo0P00
3goo0P00HWoo000LOol00`00Oomoo`0>Ool2001ROol000]oo`8000Aoo`03001oogoo00=oo`<0009o
o`8000ioo`04001oogoo001QOol000Yoo`04001oogoo000:Ool01@00Oomoogoo00003goo00@007oo
Ool0065oo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo00eoo`04001oogoo001Q
Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P003Woo00@007ooOol0065oo`002Woo00@0
07ooOol000Qoo`03001oo`0000=oo`03001oogoo00eoo`05001oogooOol0001POol000Yoo`04001o
ogoo0009Ool20003Ool2000=Ool00`00Oomoo`02Ool00`00Oomoo`1NOol000]oo`8000]oo`05001o
ogooOol0000>Ool00`00Oomoo`02Ool00`00Oomoo`1NOol001aoo`8000eoo`03001oogoo009oo`03
001oogoo05ioo`0077oo00<007ooOol037oo00<007ooOol00Woo00<007ooOol0GWoo000;Ool20004
Ool01000Oomoogoo1@000Woo0P0037oo00<007ooOol00goo00<007ooOol0GWoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo05ioo`000goo
1@000Woo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo00Aoo`03001o
ogoo05eoo`002Woo00@007ooOol000Yoo`04001oogooOol2000<Ool00`00Ool000020002Ool01000
Ool000002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P00
1Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo00Yoo`03001oo`0000=oo`04001oo`000002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol0
0goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
00]oo`03001oogoo00=oo`04001oo`000002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`03Ool000]oo`8000Uoo`<000=oo`03001oogoo00Yoo`03001oogoo00=oo`04001oogoo
0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000]o
o`03001oo`0000<000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00
Oomoo`09Ool01000Oomoo`001Woo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomo
o`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomo
o`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<0
07ooOol02Goo00<007ooOol01@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007oo
Oomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00
2Goo00<007ooOol02Goo00<007ooOol0Fgoo000LOol00`00Oomoo`06Ool3000;Ool00`00Oomoo`1K
Ool001aoofT000aoo`0077oo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Goo00<007oo
Ool03goo0P0000=oo`00Ool027oo0P002Goo00<007ooOol02Woo000LOol2001?Ool00`00Oomoo`08
Ool2000GOol001aoo`03001oogoo04ioo`03001oogoo00Qoo`03001oogoo01Ioo`0077oo0P00D7oo
00<007ooOol01goo00<007ooOol05Woo000LOol00`00Oomoo`1?Ool00`00Oomoo`06Ool00`00Oomo
o`0GOol001aoo`03001oogoo04moo`03001oogoo00Ioo`03001oogoo01Moo`002goo0P0017oo00@0
07ooOomoo`D0009oo`80051oo`03001oogoo00Ioo`03001oogoo01Moo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool00`00Oomoo`1?Ool00`00Oomoo`05Ool00`00Oomoo`0HOol000Yoo`04001o
ogoo0009Ool00`00Oomoo`02Ool2001AOol00`00Oomoo`04Ool00`00Oomoo`0HOol000Yoo`04001o
ogoo000:Ool01@00Oomoogoo0000DWoo00<007ooOol017oo00<007ooOol067oo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`80055oo`03001oogoo00Aoo`03001oogoo01Qoo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1@Ool00`00Oomoo`04Ool00`00Oomoo`0H
Ool000]oo`8000Uoo`<000=oo`03001oogoo051oo`03001oogoo00Aoo`03001oogoo01Qoo`0077oo
0P00DWoo00<007ooOol00Woo00<007ooOol06Goo000LOol00`00Oomoo`1AOol00`00Oomoo`02Ool0
0`00Oomoo`0IOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`80059oo`03001oogoo009oo`03
001oogoo01Uoo`002Woo00@007ooOol000Yoo`05001oogooOol0001COol00`00Oomoo`02Ool00`00
Oomoo`0IOol000Yoo`04001oogoo0007Ool50002Ool2001BOol01@00Oomoogoo000077oo000:Ool0
1000Oomoo`001goo00@007ooOol000=oo`03001oogoo059oo`04001oogoo000LOol000Yoo`04001o
ogoo0008Ool00`00Ool00003Ool2001COol01000Oomoo`0077oo000:Ool01000Oomoo`002Goo0P00
0goo00<007ooOol0DWoo00<007oo00007Goo000;Ool2000;Ool01@00Oomoogoo0000E7oo00<007oo
00007Goo000LOol2001DOol2000MOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007oo
Ool00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@00
0Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo
0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001o
ogoo079oo`002goo0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool3
0004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04
001oogoo0009Ool00`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00
Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00
Oomoogoo00004Woo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo
00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool0
1000Oomoo`001Goo000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo
0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool0
0006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool2
0004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@00
0goo0P001Woo000LOol2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomo
ogoo00000Woo10000Woo00D007ooOomoo`0000=oo`03001oo`00008000=oo`05001oogooOol00003
Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo000017oo00@007ooOomoo`80009oo`05001oogooOol00003Ool00`00Oomoo`04
00000goo001oo`03Ool00`00Oomoo`0:Ool001aoo`8000Uoo`03001oogoo00Uoo`03001oogoo03Mo
o`03001oogoo00Qoo`8001Moo`0077oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0=goo
00<007ooOol027oo00<007ooOol05Woo000LOol2000:Ool00`00Oomoo`07Ool00`00Oomoo`0iOol0
0`00Oomoo`07Ool00`00Oomoo`0FOol001aoo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo
03Uoo`03001oogoo00Ioo`03001oogoo01Moo`002goo0P0017oo00@007ooOomoo`D0009oo`8000]o
o`03001oogoo00Ioo`03001oogoo03Uoo`03001oogoo00Ioo`03001oogoo01Moo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0jOol00`00
Oomoo`05Ool00`00Oomoo`0HOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000;Ool00`00
Oomoo`05Ool00`00Oomoo`0jOol00`00Oomoo`05Ool00`00Oomoo`0HOol000Yoo`04001oogoo000:
Ool01@00Oomoogoo00003Goo00<007ooOol017oo00<007ooOol0>goo00<007ooOol017oo00<007oo
Ool067oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8000aoo`03001oogoo00Aoo`03
001oogoo03]oo`03001oogoo00Aoo`03001oogoo01Qoo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0lOol00`00Oomoo`04Ool00`00
Oomoo`0HOol000]oo`8000Uoo`<000=oo`8000eoo`03001oogoo009oo`03001oogoo03aoo`03001o
ogoo00=oo`03001oogoo01Uoo`0077oo00<007ooOol037oo00<007ooOol00Woo00<007ooOol0?Goo
00<007ooOol00Woo00<007ooOol06Goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000=Ool0
0`00Oomoo`02Ool00`00Oomoo`0mOol00`00Oomoo`02Ool00`00Oomoo`0IOol000Yoo`04001oogoo
000:Ool01@00Oomoogoo00003goo00D007ooOomoo`0003moo`05001oogooOol0000LOol000Yoo`04
001oogoo0007Ool50002Ool2000>Ool01@00Oomoogoo0000?goo00D007ooOomoo`0001aoo`002Woo
00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0=Ool01000Oomoo`00@Goo00@007ooOol0
01aoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8000ioo`04001oogoo0011Ool00`00Ool0
000MOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`0>Ool20012Ool00`00Ool0000MOol0
00]oo`8000]oo`04001oogooOol2000?Ool20013Ool2000MOol001aoo`03001oogoo079oo`002goo
0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yo
o`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04
Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yo
o`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2
001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001ao
o`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol0
01Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Io
o`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1120\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23178 L
.028 .23178 L
.032 .2318 L
.036 .23182 L
.04 .23185 L
.044 .23191 L
.048 .232 L
.052 .23213 L
.056 .23232 L
.06 .23261 L
.064 .23303 L
.068 .23364 L
.072 .2345 L
.076 .2357 L
.08 .23734 L
.084 .23956 L
.088 .24251 L
.092 .24635 L
.096 .25126 L
.1 .25743 L
.104 .26502 L
.108 .27417 L
.112 .28496 L
.116 .29737 L
.12 .31131 L
.124 .32652 L
.128 .34262 L
.132 .35906 L
.136 .37518 L
.14 .39018 L
.144 .40323 L
.148 .41349 L
.152 .4202 L
.156 .42277 L
.16 .42084 L
.164 .41435 L
.168 .40354 L
.172 .38898 L
.176 .3715 L
.18 .35213 L
.184 .33198 L
.188 .31217 L
.192 .29367 L
.196 .27725 L
.2 .26341 L
Mistroke
.204 .25238 L
.208 .24409 L
.212 .23828 L
.216 .23455 L
.22 .23241 L
.224 .2314 L
.228 .23108 L
.232 .23114 L
.236 .23135 L
.24 .23156 L
.244 .23172 L
.248 .23181 L
.252 .23185 L
.256 .23185 L
.26 .23184 L
.264 .23183 L
.268 .23182 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23182 L
.736 .23183 L
.74 .23184 L
.744 .23185 L
.748 .23185 L
.752 .23181 L
.756 .23172 L
.76 .23156 L
.764 .23135 L
.768 .23114 L
.772 .23108 L
.776 .2314 L
.78 .23241 L
.784 .23455 L
.788 .23828 L
.792 .24409 L
.796 .25238 L
.8 .26341 L
Mistroke
.804 .27725 L
.808 .29367 L
.812 .31217 L
.816 .33198 L
.82 .35213 L
.824 .3715 L
.828 .38898 L
.832 .40354 L
.836 .41435 L
.84 .42084 L
.844 .42277 L
.848 .4202 L
.852 .41349 L
.856 .40323 L
.86 .39018 L
.864 .37518 L
.868 .35906 L
.872 .34262 L
.876 .32652 L
.88 .31131 L
.884 .29737 L
.888 .28496 L
.892 .27417 L
.896 .26502 L
.9 .25743 L
.904 .25126 L
.908 .24635 L
.912 .24251 L
.916 .23956 L
.92 .23734 L
.924 .2357 L
.928 .2345 L
.932 .23364 L
.936 .23303 L
.94 .23261 L
.944 .23232 L
.948 .23213 L
.952 .232 L
.956 .23191 L
.96 .23185 L
.964 .23182 L
.968 .2318 L
.972 .23178 L
.976 .23178 L
.98 .23177 L
.984 .23177 L
.988 .23177 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35315 L
.024 .35315 L
.028 .35314 L
.032 .35312 L
.036 .35309 L
.04 .35305 L
.044 .35299 L
.048 .35289 L
.052 .35273 L
.056 .3525 L
.06 .35215 L
.064 .35165 L
.068 .35093 L
.072 .3499 L
.076 .34848 L
.08 .34652 L
.084 .34387 L
.088 .34036 L
.092 .33579 L
.096 .32994 L
.1 .32259 L
.104 .31355 L
.108 .30265 L
.112 .2898 L
.116 .27501 L
.12 .2584 L
.124 .24028 L
.128 .22111 L
.132 .20152 L
.136 .18232 L
.14 .16445 L
.144 .14891 L
.148 .1367 L
.152 .12871 L
.156 .12565 L
.16 .12795 L
.164 .13569 L
.168 .14857 L
.172 .16591 L
.176 .18674 L
.18 .20982 L
.184 .23382 L
.188 .25743 L
.192 .27947 L
.196 .29903 L
.2 .31552 L
Mistroke
.204 .32867 L
.208 .33854 L
.212 .34546 L
.216 .3499 L
.22 .35245 L
.224 .35366 L
.228 .35403 L
.232 .35396 L
.236 .35372 L
.24 .35346 L
.244 .35327 L
.248 .35316 L
.252 .35312 L
.256 .35312 L
.26 .35313 L
.264 .35315 L
.268 .35316 L
.272 .35317 L
.276 .35317 L
.28 .35317 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35318 L
.74 .35319 L
.744 .35321 L
.748 .35321 L
.752 .35316 L
.756 .35305 L
.76 .35286 L
.764 .35261 L
.768 .35236 L
.772 .35229 L
.776 .35267 L
.78 .35388 L
.784 .35642 L
.788 .36087 L
.792 .36778 L
.796 .37766 L
.8 .39081 L
Mistroke
.804 .40729 L
.808 .42685 L
.812 .4489 L
.816 .4725 L
.82 .4965 L
.824 .51959 L
.828 .54041 L
.832 .55776 L
.836 .57064 L
.84 .57837 L
.844 .58067 L
.848 .57761 L
.852 .56963 L
.856 .55741 L
.86 .54187 L
.864 .524 L
.868 .5048 L
.872 .48522 L
.876 .46604 L
.88 .44792 L
.884 .43132 L
.888 .41653 L
.892 .40368 L
.896 .39278 L
.9 .38374 L
.904 .37639 L
.908 .37054 L
.912 .36596 L
.916 .36245 L
.92 .35981 L
.924 .35785 L
.928 .35642 L
.932 .3554 L
.936 .35467 L
.94 .35417 L
.944 .35383 L
.948 .35359 L
.952 .35344 L
.956 .35334 L
.96 .35327 L
.964 .35323 L
.968 .3532 L
.972 .35319 L
.976 .35318 L
.98 .35317 L
.984 .35317 L
.988 .35317 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23177 L
.02 .23177 L
.024 .23178 L
.028 .23178 L
.032 .2318 L
.036 .23182 L
.04 .23185 L
.044 .23191 L
.048 .232 L
.052 .23213 L
.056 .23232 L
.06 .23261 L
.064 .23303 L
.068 .23364 L
.072 .2345 L
.076 .2357 L
.08 .23734 L
.084 .23956 L
.088 .24251 L
.092 .24635 L
.096 .25126 L
.1 .25743 L
.104 .26502 L
.108 .27417 L
.112 .28496 L
.116 .29737 L
.12 .31131 L
.124 .32652 L
.128 .34262 L
.132 .35906 L
.136 .37518 L
.14 .39018 L
.144 .40323 L
.148 .41349 L
.152 .4202 L
.156 .42277 L
.16 .42084 L
.164 .41435 L
.168 .40354 L
.172 .38898 L
.176 .3715 L
.18 .35213 L
.184 .33198 L
.188 .31217 L
.192 .29367 L
.196 .27725 L
.2 .26341 L
Mistroke
.204 .25238 L
.208 .24409 L
.212 .23828 L
.216 .23455 L
.22 .23241 L
.224 .2314 L
.228 .23108 L
.232 .23114 L
.236 .23135 L
.24 .23156 L
.244 .23172 L
.248 .23181 L
.252 .23185 L
.256 .23185 L
.26 .23184 L
.264 .23183 L
.268 .23182 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23182 L
.736 .23183 L
.74 .23184 L
.744 .23185 L
.748 .23185 L
.752 .23181 L
.756 .23172 L
.76 .23156 L
.764 .23135 L
.768 .23114 L
.772 .23108 L
.776 .2314 L
.78 .23241 L
.784 .23455 L
.788 .23828 L
.792 .24409 L
.796 .25238 L
.8 .26341 L
Mistroke
.804 .27725 L
.808 .29367 L
.812 .31217 L
.816 .33198 L
.82 .35213 L
.824 .3715 L
.828 .38898 L
.832 .40354 L
.836 .41435 L
.84 .42084 L
.844 .42277 L
.848 .4202 L
.852 .41349 L
.856 .40323 L
.86 .39018 L
.864 .37518 L
.868 .35906 L
.872 .34262 L
.876 .32652 L
.88 .31131 L
.884 .29737 L
.888 .28496 L
.892 .27417 L
.896 .26502 L
.9 .25743 L
.904 .25126 L
.908 .24635 L
.912 .24251 L
.916 .23956 L
.92 .23734 L
.924 .2357 L
.928 .2345 L
.932 .23364 L
.936 .23303 L
.94 .23261 L
.944 .23232 L
.948 .23213 L
.952 .232 L
.956 .23191 L
.96 .23185 L
.964 .23182 L
.968 .2318 L
.972 .23178 L
.976 .23178 L
.98 .23177 L
.984 .23177 L
.988 .23177 L
.992 .23176 L
.996 .23176 L
1 .23176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo0P00
0goo00D007ooOomoo`0000=oo`<00003Ool007oo009oo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
000017oo00H007ooOomoo`00Ool30003Ool01@00Oomoogoo00000Woo0`000Woo00<007ooOol00Woo
00<007ooOol02Woo000LOol20008Ool00`00Oomoo`08Ool2000kOol00`00Oomoo`09Ool00`00Oomo
o`0DOol001aoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo03Yoo`03001oogoo00Qoo`03
001oogoo01Eoo`0077oo0P002Goo00<007ooOol01goo00<007ooOol0>goo00<007ooOol01goo00<0
07ooOol05Goo000LOol00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`0lOol00`00Oomoo`06
Ool00`00Oomoo`0FOol000]oo`8000Aoo`04001oogooOol50002Ool2000:Ool00`00Oomoo`05Ool0
0`00Oomoo`0lOol00`00Oomoo`06Ool00`00Oomoo`0FOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol0?Goo00<007ooOol01Goo00<007oo
Ool05Woo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P002goo00<007ooOol017oo00<007oo
Ool0?Goo00<007ooOol017oo00<007ooOol05goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00
00aoo`03001oogoo00Aoo`03001oogoo03eoo`03001oogoo00Aoo`03001oogoo01Moo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2000;Ool00`00Oomoo`04Ool00`00Oomoo`0mOol00`00
Oomoo`04Ool00`00Oomoo`0GOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool02Woo00<007ooOol00goo00<007ooOol0?goo00<007ooOol00goo00<007ooOol05goo000;Ool2
0009Ool30003Ool2000;Ool00`00Oomoo`03Ool00`00Oomoo`0oOol00`00Oomoo`02Ool00`00Oomo
o`0HOol001aoo`03001oogoo00]oo`03001oogoo009oo`03001oogoo03moo`03001oogoo009oo`03
001oogoo01Qoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P0037oo00<007ooOol00Woo00<0
07ooOol0?goo00<007ooOol00Woo00<007ooOol067oo000:Ool01000Oomoo`002Woo00D007ooOomo
o`0000eoo`05001oogooOol00012Ool00`00Oomoo`02Ool00`00Oomoo`0HOol000Yoo`04001oogoo
0007Ool50002Ool2000<Ool01@00Oomoogoo0000@Woo00<007ooOol00Woo00<007ooOol067oo000:
Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo00aoo`04001oogoo0013Ool01000Oomo
o`006goo000:Ool01000Oomoo`0027oo00<007oo00000goo0P003Goo00@007ooOol004=oo`04001o
ogoo000KOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`0=Ool20015Ool2000LOol000]o
o`8000]oo`04001oogooOol2000>Ool20015Ool2000LOol001aoo`03001oogoo079oo`002goo0P00
17oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04
001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2
001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`80
00=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001c
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03
001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Mo
o`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`80
07Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3
001hOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P00Lgoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`@000=o
o`8007=oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`03001oogoo079oo`002Woo00@007oo
Ool000Qoo`03001oogoo00=oo`8007=oo`002goo0P002Woo0P000goo00<007ooOol03Goo00<007oo
Ool0HWoo000LOol2000>Ool2001SOol001aoo`03001oogoo00eoo`8006=oo`002goo0P0017oo00<0
07ooOol00goo0`000Woo0P003Goo00@007ooOol0069oo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0000>Ool01000Oomoo`00HWoo0003Ool50002Ool01000Oomoo`001goo1@000Woo00<007ooOol0
37oo00@007ooOol0069oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool2000<Ool01@00Oomo
ogoo0000HWoo000:Ool01000Oomoo`0027oo00<007oo00000goo00<007ooOol02goo00D007ooOomo
o`00069oo`002Woo00@007ooOol000Uoo`8000=oo`8000aoo`05001oogooOol0001ROol000]oo`80
00]oo`05001oogooOol0000=Ool00`00Oomoo`02Ool00`00Oomoo`1OOol001aoo`8000]oo`03001o
ogoo00=oo`03001oogoo05moo`0077oo00<007ooOol02Woo00<007ooOol00goo00<007ooOol0Ggoo
000;Ool20004Ool01000Oomoogoo1@000Woo0P002goo00<007ooOol00goo00<007ooOol0Ggoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo
05moo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo
00Aoo`03001oogoo05ioo`002Woo00@007ooOol000Yoo`04001oogooOol2000;Ool00`00Oomoo`03
000017oo001oogoo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo
0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo00Uoo`04001oogoo0003Ool200001Goo001oogoo00002Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001o
ogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`00
0goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool2000:Ool00`00Oomoo`04Ool200001Goo001oogoo00002Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00goo000;Ool20009Ool30003Ool00`00Oomoo`09Ool00`00Oomoo`04Ool200001Goo001o
ogoo00002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol20009Ool01000Oomo
ogoo100000Aoo`00Ool0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03
001oogoo00Qoo`05001oogooOol00005Ool20002Ool00`00Oomoo`06Ool20004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool001aoo`03001oogoo00Qoo`04001oogooOol500000goo001oo`02000:Ool00`00Oomoo`03Ool2
0004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@00
0goo0P001Woo000LOol20008Ool00`00Oomoo`09Ool00`00Oomoo`1LOol001aoo`03001oogoo00Eo
o`8000aoo`03001oogoo05aoo`0077ooJ@0037oo000LOol00`00Oomoo`0BOol00`00Oomoo`0BOol0
0`00Oomoo`0AOol00`00Oomoo`0AOol2000:Ool20008Ool00`00Oomoo`0:Ool001aoo`80051oo`03
001oogoo00Uoo`03001oogoo01Aoo`0077oo00<007ooOol0Cgoo00<007ooOol027oo00<007ooOol0
5Goo000LOol2001AOol00`00Oomoo`07Ool00`00Oomoo`0EOol001aoo`03001oogoo051oo`03001o
ogoo00Ioo`03001oogoo01Ioo`0077oo00<007ooOol0D7oo00<007ooOol01Woo00<007ooOol05Woo
000;Ool20004Ool01000Oomoogoo1@000Woo0P00DWoo00<007ooOol01Goo00<007ooOol05Woo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo055oo`03001oogoo00Eoo`03001oogoo
01Ioo`002Woo00@007ooOol000Uoo`03001oogoo009oo`80059oo`03001oogoo00Eoo`03001oogoo
01Ioo`002Woo00@007ooOol000Yoo`05001oogooOol0001COol00`00Oomoo`04Ool00`00Oomoo`0G
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00DWoo00<007ooOol017oo00<007oo
Ool05goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo059oo`03001oogoo
00=oo`03001oogoo01Moo`002goo0P002Goo0`000goo00<007ooOol0DWoo00<007ooOol00goo00<0
07ooOol05goo000LOol2001COol00`00Oomoo`02Ool00`00Oomoo`0HOol001aoo`03001oogoo059o
o`03001oogoo009oo`03001oogoo01Qoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00Dgoo
00<007ooOol00Woo00<007ooOol067oo000:Ool01000Oomoo`002Woo00D007ooOomoo`0005Aoo`03
001oogoo009oo`03001oogoo01Qoo`002Woo00@007ooOol000Moo`D0009oo`8005=oo`03001oogoo
009oo`03001oogoo01Qoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1COol0
1000Oomoo`006goo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00E7oo00@007ooOol001]o
o`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo05=oo`04001oogoo000KOol000]oo`8000]o
o`05001oogooOol0001FOol2000LOol001aoo`8005Eoo`8001aoo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomo
ogoo0000M7oo0003Ool50002Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`00
1goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`80
07=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00@007ooOomo
o`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P00Lgoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`80
00Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`80
00Ioo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`8000eoo`05001oogooOol00002
Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomo
ogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Yoo`05001oogooOol0000BOol01000Oomoo`000Woo00<007ooOol01goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
015oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo10000goo00@007oo
Ool000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=o
o`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00
Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uoo`<000=oo`8000eoo`03001oogoo
00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001o
ogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004
Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`80
00Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004
Ool20006Ool30002Ool50003Ool20006Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOomY
000<Ool001aoo`06001oogooOol007oo10000goo00D007ooOomoo`0000=oo`<00003Ool007oo009o
o`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo000017oo00H007ooOomoo`00Ool30003Ool01@00Oomo
ogoo00000goo1@0017oo00<007ooOol02Woo000LOol20007Ool2000;Ool00`00Oomoo`0iOol00`00
Oomoo`09Ool00`00Oomoo`0DOol001aoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo03Yo
o`03001oogoo00Qoo`03001oogoo01Eoo`0077oo0P002Goo00<007ooOol01goo00<007ooOol0>goo
00<007ooOol01goo00<007ooOol05Goo000LOol00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomo
o`0lOol00`00Oomoo`06Ool00`00Oomoo`0FOol000]oo`8000Aoo`04001oogooOol50002Ool2000:
Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`00Oomoo`06Ool00`00Oomoo`0FOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol0?Goo00<0
07ooOol01Goo00<007ooOol05Woo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P002Woo00<0
07ooOol01Goo00<007ooOol0?Goo00<007ooOol01Goo00<007ooOol05Woo000:Ool01000Oomoo`00
2Woo00D007ooOomoo`0000aoo`03001oogoo00Aoo`03001oogoo03eoo`03001oogoo00Aoo`03001o
ogoo01Moo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000;Ool00`00Oomoo`04Ool0
0`00Oomoo`0mOol00`00Oomoo`04Ool00`00Oomoo`0GOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol02Woo00<007ooOol00goo00<007ooOol0?goo00<007ooOol00goo00<0
07ooOol05goo000;Ool20009Ool30003Ool2000;Ool00`00Oomoo`03Ool00`00Oomoo`0oOol00`00
Oomoo`02Ool00`00Oomoo`0HOol001aoo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo03mo
o`03001oogoo009oo`03001oogoo01Qoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P0037oo
00<007ooOol00Woo00<007ooOol0?goo00<007ooOol00Woo00<007ooOol067oo000:Ool01000Oomo
o`002Woo00D007ooOomoo`0000eoo`05001oogooOol00012Ool00`00Oomoo`02Ool00`00Oomoo`0H
Ool000Yoo`04001oogoo0007Ool50002Ool2000<Ool01@00Oomoogoo0000@Woo00<007ooOol00Woo
00<007ooOol067oo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo00aoo`04001o
ogoo0013Ool01000Oomoo`006goo000:Ool01000Oomoo`0027oo00<007oo00000goo0P003Goo00@0
07ooOol004=oo`04001oogoo000KOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`0=Ool2
0015Ool2000LOol000]oo`8000]oo`04001oogooOol2000>Ool20015Ool2000LOol001aoo`03001o
ogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1b
Ool000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomo
o`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qo
o`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003
Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool0
0`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00
Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1160\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23178 L
.016 .23178 L
.02 .2318 L
.024 .23182 L
.028 .23186 L
.032 .23192 L
.036 .232 L
.04 .23214 L
.044 .23234 L
.048 .23263 L
.052 .23306 L
.056 .23367 L
.06 .23454 L
.064 .23575 L
.068 .23741 L
.072 .23964 L
.076 .24259 L
.08 .24643 L
.084 .25134 L
.088 .25749 L
.092 .26506 L
.096 .27417 L
.1 .28491 L
.104 .29726 L
.108 .31113 L
.112 .32626 L
.116 .34228 L
.12 .35866 L
.124 .37473 L
.128 .38972 L
.132 .40279 L
.136 .41311 L
.14 .41993 L
.144 .42263 L
.148 .42087 L
.152 .41455 L
.156 .4039 L
.16 .38947 L
.164 .37207 L
.168 .35273 L
.172 .33256 L
.176 .31266 L
.18 .29404 L
.184 .27747 L
.188 .26349 L
.192 .25232 L
.196 .24393 L
.2 .23807 L
Mistroke
.204 .23431 L
.208 .23219 L
.212 .23121 L
.216 .23094 L
.22 .23105 L
.224 .2313 L
.228 .23154 L
.232 .23172 L
.236 .23183 L
.24 .23186 L
.244 .23186 L
.248 .23185 L
.252 .23183 L
.256 .23182 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23182 L
.748 .23183 L
.752 .23185 L
.756 .23186 L
.76 .23186 L
.764 .23183 L
.768 .23172 L
.772 .23154 L
.776 .2313 L
.78 .23105 L
.784 .23094 L
.788 .23121 L
.792 .23219 L
.796 .23431 L
.8 .23807 L
Mistroke
.804 .24393 L
.808 .25232 L
.812 .26349 L
.816 .27747 L
.82 .29404 L
.824 .31266 L
.828 .33256 L
.832 .35273 L
.836 .37207 L
.84 .38947 L
.844 .4039 L
.848 .41455 L
.852 .42087 L
.856 .42263 L
.86 .41993 L
.864 .41311 L
.868 .40279 L
.872 .38972 L
.876 .37473 L
.88 .35866 L
.884 .34228 L
.888 .32626 L
.892 .31113 L
.896 .29726 L
.9 .28491 L
.904 .27417 L
.908 .26506 L
.912 .25749 L
.916 .25134 L
.92 .24643 L
.924 .24259 L
.928 .23964 L
.932 .23741 L
.936 .23575 L
.94 .23454 L
.944 .23367 L
.948 .23306 L
.952 .23263 L
.956 .23234 L
.96 .23214 L
.964 .232 L
.968 .23192 L
.972 .23186 L
.976 .23182 L
.98 .2318 L
.984 .23178 L
.988 .23178 L
.992 .23177 L
.996 .23177 L
1 .23177 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35315 m
.008 .35315 L
.012 .35314 L
.016 .35313 L
.02 .35312 L
.024 .35309 L
.028 .35305 L
.032 .35298 L
.036 .35288 L
.04 .35272 L
.044 .35248 L
.048 .35213 L
.052 .35162 L
.056 .35088 L
.06 .34985 L
.064 .34841 L
.068 .34644 L
.072 .34378 L
.076 .34027 L
.08 .33569 L
.084 .32985 L
.088 .32252 L
.092 .3135 L
.096 .30265 L
.1 .28986 L
.104 .27514 L
.108 .25862 L
.112 .2406 L
.116 .22151 L
.12 .202 L
.124 .18285 L
.128 .165 L
.132 .14944 L
.136 .13715 L
.14 .12903 L
.144 .12581 L
.148 .12791 L
.152 .13545 L
.156 .14814 L
.16 .16533 L
.164 .18606 L
.168 .20911 L
.172 .23314 L
.176 .25685 L
.18 .27903 L
.184 .29877 L
.188 .31543 L
.192 .32873 L
.196 .33873 L
.2 .34571 L
Mistroke
.204 .35019 L
.208 .35272 L
.212 .35389 L
.216 .3542 L
.22 .35407 L
.224 .35378 L
.228 .35348 L
.232 .35327 L
.236 .35315 L
.24 .3531 L
.244 .3531 L
.248 .35312 L
.252 .35315 L
.256 .35316 L
.26 .35317 L
.264 .35317 L
.268 .35317 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35318 L
.752 .3532 L
.756 .35322 L
.76 .35322 L
.764 .35318 L
.768 .35306 L
.772 .35284 L
.776 .35255 L
.78 .35225 L
.784 .35212 L
.788 .35244 L
.792 .35361 L
.796 .35614 L
.8 .36061 L
Mistroke
.804 .3676 L
.808 .37759 L
.812 .3909 L
.816 .40756 L
.82 .42729 L
.824 .44948 L
.828 .47318 L
.832 .49722 L
.836 .52027 L
.84 .54099 L
.844 .55819 L
.848 .57087 L
.852 .57841 L
.856 .58052 L
.86 .57729 L
.864 .56918 L
.868 .55689 L
.872 .54132 L
.876 .52347 L
.88 .50433 L
.884 .48481 L
.888 .46573 L
.892 .4477 L
.896 .43118 L
.9 .41647 L
.904 .40368 L
.908 .39282 L
.912 .38381 L
.916 .37648 L
.92 .37063 L
.924 .36606 L
.928 .36254 L
.932 .35989 L
.936 .35791 L
.94 .35647 L
.944 .35544 L
.948 .35471 L
.952 .3542 L
.956 .35385 L
.96 .35361 L
.964 .35345 L
.968 .35334 L
.972 .35328 L
.976 .35323 L
.98 .35321 L
.984 .35319 L
.988 .35318 L
.992 .35317 L
.996 .35317 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23177 L
.012 .23177 L
.016 .23178 L
.02 .2318 L
.024 .23182 L
.028 .23186 L
.032 .23192 L
.036 .232 L
.04 .23214 L
.044 .23234 L
.048 .23263 L
.052 .23306 L
.056 .23367 L
.06 .23454 L
.064 .23575 L
.068 .23741 L
.072 .23964 L
.076 .24259 L
.08 .24643 L
.084 .25134 L
.088 .25749 L
.092 .26506 L
.096 .27417 L
.1 .28491 L
.104 .29726 L
.108 .31113 L
.112 .32626 L
.116 .34228 L
.12 .35866 L
.124 .37473 L
.128 .38972 L
.132 .40279 L
.136 .41311 L
.14 .41993 L
.144 .42263 L
.148 .42087 L
.152 .41455 L
.156 .4039 L
.16 .38947 L
.164 .37207 L
.168 .35273 L
.172 .33256 L
.176 .31266 L
.18 .29404 L
.184 .27747 L
.188 .26349 L
.192 .25232 L
.196 .24393 L
.2 .23807 L
Mistroke
.204 .23431 L
.208 .23219 L
.212 .23121 L
.216 .23094 L
.22 .23105 L
.224 .2313 L
.228 .23154 L
.232 .23172 L
.236 .23183 L
.24 .23186 L
.244 .23186 L
.248 .23185 L
.252 .23183 L
.256 .23182 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23182 L
.748 .23183 L
.752 .23185 L
.756 .23186 L
.76 .23186 L
.764 .23183 L
.768 .23172 L
.772 .23154 L
.776 .2313 L
.78 .23105 L
.784 .23094 L
.788 .23121 L
.792 .23219 L
.796 .23431 L
.8 .23807 L
Mistroke
.804 .24393 L
.808 .25232 L
.812 .26349 L
.816 .27747 L
.82 .29404 L
.824 .31266 L
.828 .33256 L
.832 .35273 L
.836 .37207 L
.84 .38947 L
.844 .4039 L
.848 .41455 L
.852 .42087 L
.856 .42263 L
.86 .41993 L
.864 .41311 L
.868 .40279 L
.872 .38972 L
.876 .37473 L
.88 .35866 L
.884 .34228 L
.888 .32626 L
.892 .31113 L
.896 .29726 L
.9 .28491 L
.904 .27417 L
.908 .26506 L
.912 .25749 L
.916 .25134 L
.92 .24643 L
.924 .24259 L
.928 .23964 L
.932 .23741 L
.936 .23575 L
.94 .23454 L
.944 .23367 L
.948 .23306 L
.952 .23263 L
.956 .23234 L
.96 .23214 L
.964 .232 L
.968 .23192 L
.972 .23186 L
.976 .23182 L
.98 .2318 L
.984 .23179 L
.988 .23178 L
.992 .23177 L
.996 .23177 L
1 .23177 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01P00Oomoogoo001oo`<000Ao
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0004Ool01@00Oomoogoo00000Woo0P000goo00D007ooOomoo`0000=oo`<00003Ool007oo00=oo`03
001oogoo00Yoo`0077oo0P001Woo0P002Woo00<007ooOol0?7oo0P002Woo00<007ooOol04goo000L
Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0mOol00`00Oomoo`07Ool00`00Oomoo`0D
Ool001aoo`8000Qoo`03001oogoo00Moo`03001oogoo03eoo`03001oogoo00Moo`03001oogoo01Ao
o`0077oo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0?goo00<007ooOol01Woo00<007oo
Ool057oo000;Ool20004Ool01000Oomoogoo1@000Woo0P002Goo00<007ooOol01Goo00<007ooOol0
?goo00<007ooOol01Goo00<007ooOol05Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03
001oogoo00Qoo`03001oogoo00Eoo`03001oogoo03moo`03001oogoo00Eoo`03001oogoo01Eoo`00
2Woo00@007ooOol000Uoo`03001oogoo009oo`8000Uoo`03001oogoo00Eoo`03001oogoo03moo`03
001oogoo00Aoo`03001oogoo01Ioo`002Woo00@007ooOol000Yoo`05001oogooOol0000:Ool00`00
Oomoo`04Ool00`00Oomoo`10Ool00`00Oomoo`04Ool00`00Oomoo`0FOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo0P002Woo00<007ooOol00goo00<007ooOol0@7oo00<007ooOol017oo
00<007ooOol05Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00Uoo`03
001oogoo00=oo`03001oogoo045oo`03001oogoo00=oo`03001oogoo01Ioo`002goo0P002Goo0`00
0goo0P002Woo00<007ooOol00goo00<007ooOol0@Goo00<007ooOol00goo00<007ooOol05Woo000L
Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`11Ool00`00Oomoo`02Ool00`00Oomoo`0G
Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8000]oo`03001oogoo009oo`03001oogoo045o
o`03001oogoo009oo`03001oogoo01Moo`002Woo00@007ooOol000Yoo`05001oogooOol0000<Ool0
1@00Oomoogoo0000AGoo00D007ooOomoo`0001Uoo`002Woo00@007ooOol000Moo`D0009oo`8000]o
o`05001oogooOol00015Ool01@00Oomoogoo00006Goo000:Ool01000Oomoo`001goo00@007ooOol0
00=oo`03001oogoo00Yoo`05001oogooOol00015Ool01000Oomoo`006Woo000:Ool01000Oomoo`00
27oo00<007oo00000goo0P0037oo00<007oo0000AWoo00@007ooOol001Yoo`002Woo00@007ooOol0
00Uoo`8000=oo`03001oogoo00]oo`03001oo`0004Moo`03001oo`0001Yoo`002goo0P002goo00@0
07ooOomoo`8000eoo`8004Moo`8001]oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomo
o`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Mo
o`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo
00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo
000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo
000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol0
0Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol0
0`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<007Qoo`002Woo
00@007ooOol000Moo`05001oogooOol0001gOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2001cOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000L
Ool00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo10000goo0P00Lgoo000:
Ool01000Oomoo`001goo00<007ooOol017oo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<0
07ooOol00goo0P00Lgoo000;Ool2000:Ool20003Ool00`00Oomoo`0<Ool00`00Oomoo`1SOol001ao
o`8000eoo`8006Aoo`0077oo00<007ooOol02goo00<007oo0000I7oo000;Ool20004Ool00`00Oomo
o`03Ool30002Ool2000<Ool00`00Ool0001TOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000
37oo00D007ooOomoo`0006=oo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo00Yo
o`05001oogooOol0001SOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P002goo00D007oo
Oomoo`0006=oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo00Yoo`05001oogoo
Ool0001SOol000Yoo`04001oogoo0009Ool20003Ool2000;Ool01@00Oomoogoo0000Hgoo000;Ool2
000;Ool01@00Oomoogoo000037oo00<007ooOol00Woo00<007ooOol0H7oo000LOol2000:Ool00`00
Oomoo`03Ool00`00Oomoo`1POol001aoo`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo061o
o`002goo0P0017oo00@007ooOomoo`D0009oo`8000Yoo`03001oogoo00=oo`03001oogoo061oo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomo
o`1POol000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomo
o`04Ool00`00Oomoo`1POol000Yoo`04001oogoo000:Ool01000Oomoogoo0P002Goo00<007ooOol0
0Woo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P00
17oo0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00Qoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol01goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009o
o`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo
001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool20009Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol00goo000;Ool20009Ool30003Ool00`00Oomoo`08Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo
000LOol20008Ool00`00Oomoo`02Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol0
00Eoo`0077oo00<007ooOol01goo00<007ooOol00Woo00<007ooOol00Woo00<007oo00000Woo00<0
07ooOol01Woo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool0
1000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007oo
Oomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`06Ool00`00Oomoo`03Ool60002
Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo
0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol20006Ool00`00Oomoo`09Ool00`00Oomo
o`1NOol001aoo`03001oogoo00Aoo`8000aoo`03001oogoo05eoo`0077ooJ@0037oo000LOol00`00
Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0:Ool20006
Ool00`00Oomoo`0:Ool001aoo`80059oo`03001oogoo00Qoo`03001oogoo01=oo`0077oo00<007oo
Ool0DGoo00<007ooOol01goo00<007ooOol057oo000LOol2001BOol00`00Oomoo`07Ool00`00Oomo
o`0DOol001aoo`03001oogoo055oo`03001oogoo00Moo`03001oogoo01Aoo`0077oo00<007ooOol0
DWoo00<007ooOol01Goo00<007ooOol05Goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00Dgoo
00<007ooOol01Goo00<007ooOol05Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001o
ogoo059oo`03001oogoo00Eoo`03001oogoo01Eoo`002Woo00@007ooOol000Uoo`03001oogoo009o
o`8005=oo`03001oogoo00Eoo`03001oogoo01Eoo`002Woo00@007ooOol000Yoo`05001oogooOol0
001DOol00`00Oomoo`04Ool00`00Oomoo`0FOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P00Dgoo00<007ooOol017oo00<007ooOol05Woo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo05=oo`03001oogoo00=oo`03001oogoo01Ioo`002goo0P002Goo0`000goo
00<007ooOol0Dgoo00<007ooOol00goo00<007ooOol05Woo000LOol2001DOol00`00Oomoo`03Ool0
0`00Oomoo`0FOol001aoo`03001oogoo05=oo`03001oogoo00=oo`03001oogoo01Ioo`002goo0P00
17oo00<007ooOol00goo0`000Woo0P00E7oo00<007ooOol00Woo00<007ooOol05goo000:Ool01000
Oomoo`002Woo00D007ooOomoo`0005Ioo`05001oogooOol0000IOol000Yoo`04001oogoo0007Ool5
0002Ool2001EOol01@00Oomoogoo00006Goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03
001oogoo05Aoo`04001oogoo000JOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001EOol0
1000Oomoo`006Woo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0E7oo00@007ooOol001Yo
o`002goo0P002goo00D007ooOomoo`0005Moo`03001oo`0001Yoo`0077oo0P00EWoo0P006goo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@0
07ooOol000Yoo`05001oogooOol0001dOol000=oo`D0009oo`04001oogoo0007Ool50002Ool2001c
Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
27oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;
Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogoo
Ool50002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol03Goo0`00
17oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P00
1Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo0P00
3Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00<007ooOol00goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`04001oogoo0002Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P004Goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eo
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`0<Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Goo0`00
0goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomo
o`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomo
o`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<0
07ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=o
o`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoofT000aoo`0077oo00@007ooOomoo`D000Aoo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo0000
0Woo0P000goo00D007ooOomoo`0000=oo`D000Aoo`03001oogoo00Yoo`0077oo0P001Woo0P002Woo
00<007ooOol0?7oo00<007ooOol02Goo0P0057oo000LOol00`00Oomoo`06Ool00`00Oomoo`08Ool0
0`00Oomoo`0mOol00`00Oomoo`07Ool00`00Oomoo`0DOol001aoo`8000Qoo`03001oogoo00Moo`03
001oogoo03eoo`03001oogoo00Moo`03001oogoo01Aoo`0077oo00<007ooOol01goo00<007ooOol0
1Woo00<007ooOol0?goo00<007ooOol01Woo00<007ooOol057oo000;Ool20004Ool01000Oomoogoo
1@000Woo0P002Goo00<007ooOol01Goo00<007ooOol0?goo00<007ooOol01Goo00<007ooOol05Goo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00Qoo`03001oogoo00Eoo`03001o
ogoo03moo`03001oogoo00Eoo`03001oogoo01Eoo`002Woo00@007ooOol000Uoo`03001oogoo009o
o`8000Uoo`03001oogoo00Eoo`03001oogoo03moo`03001oogoo00Eoo`03001oogoo01Eoo`002Woo
00@007ooOol000Yoo`05001oogooOol0000:Ool00`00Oomoo`04Ool00`00Oomoo`10Ool00`00Oomo
o`04Ool00`00Oomoo`0FOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P002Woo00<0
07ooOol00goo00<007ooOol0@7oo00<007ooOol017oo00<007ooOol05Woo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo045oo`03001o
ogoo00=oo`03001oogoo01Ioo`002goo0P002Goo0`000goo0P002Woo00<007ooOol00goo00<007oo
Ool0@Goo00<007ooOol00goo00<007ooOol05Woo000LOol00`00Oomoo`09Ool00`00Oomoo`03Ool0
0`00Oomoo`11Ool00`00Oomoo`03Ool00`00Oomoo`0FOol000]oo`8000Aoo`03001oogoo00=oo`<0
009oo`8000]oo`03001oogoo009oo`03001oogoo045oo`03001oogoo009oo`03001oogoo01Moo`00
2Woo00@007ooOol000Yoo`05001oogooOol0000<Ool01@00Oomoogoo0000AGoo00D007ooOomoo`00
01Uoo`002Woo00@007ooOol000Moo`D0009oo`8000]oo`05001oogooOol00015Ool01@00Oomoogoo
00006Goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo00Yoo`05001oogooOol0
0015Ool01000Oomoo`006Woo000:Ool01000Oomoo`0027oo00<007oo00000goo0P0037oo00<007oo
0000AWoo00@007ooOol001Yoo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo00]oo`03001o
o`0004Moo`03001oo`0001Yoo`002goo0P002goo00@007ooOomoo`8000eoo`8004Moo`8001]oo`00
77oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03
001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Ao
o`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000
Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`80
00Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001o
ogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol0
01Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1200\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23178 m
.008 .2318 L
.012 .23182 L
.016 .23186 L
.02 .23192 L
.024 .23201 L
.028 .23215 L
.032 .23235 L
.036 .23265 L
.04 .23309 L
.044 .23371 L
.048 .23459 L
.052 .23581 L
.056 .23747 L
.06 .23971 L
.064 .24266 L
.068 .24651 L
.072 .25141 L
.076 .25755 L
.08 .26509 L
.084 .27417 L
.088 .28486 L
.092 .29715 L
.096 .31094 L
.1 .326 L
.104 .34195 L
.108 .35827 L
.112 .37429 L
.116 .38927 L
.12 .40236 L
.124 .41274 L
.128 .41965 L
.132 .4225 L
.136 .42089 L
.14 .41474 L
.144 .40425 L
.148 .38995 L
.152 .37264 L
.156 .35333 L
.16 .33313 L
.164 .31316 L
.168 .29441 L
.172 .2777 L
.176 .26357 L
.18 .25227 L
.184 .24378 L
.188 .23785 L
.192 .23407 L
.196 .23195 L
.2 .23101 L
Mistroke
.204 .23079 L
.208 .23095 L
.212 .23124 L
.216 .23153 L
.22 .23173 L
.224 .23184 L
.228 .23188 L
.232 .23187 L
.236 .23185 L
.24 .23183 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23183 L
.764 .23185 L
.768 .23187 L
.772 .23188 L
.776 .23184 L
.78 .23173 L
.784 .23153 L
.788 .23124 L
.792 .23095 L
.796 .23079 L
.8 .23101 L
Mistroke
.804 .23195 L
.808 .23407 L
.812 .23785 L
.816 .24378 L
.82 .25227 L
.824 .26357 L
.828 .2777 L
.832 .29441 L
.836 .31316 L
.84 .33313 L
.844 .35333 L
.848 .37264 L
.852 .38995 L
.856 .40425 L
.86 .41474 L
.864 .42089 L
.868 .4225 L
.872 .41965 L
.876 .41274 L
.88 .40236 L
.884 .38927 L
.888 .37429 L
.892 .35827 L
.896 .34195 L
.9 .326 L
.904 .31094 L
.908 .29715 L
.912 .28486 L
.916 .27417 L
.92 .26509 L
.924 .25755 L
.928 .25141 L
.932 .24651 L
.936 .24266 L
.94 .23971 L
.944 .23747 L
.948 .23581 L
.952 .23459 L
.956 .23371 L
.96 .23309 L
.964 .23265 L
.968 .23235 L
.972 .23215 L
.976 .23201 L
.98 .23192 L
.984 .23186 L
.988 .23183 L
.992 .2318 L
.996 .23179 L
1 .23178 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35311 m
.008 .3531 L
.012 .35308 L
.016 .35304 L
.02 .35297 L
.024 .35286 L
.028 .3527 L
.032 .35246 L
.036 .3521 L
.04 .35158 L
.044 .35084 L
.048 .3498 L
.052 .34835 L
.056 .34636 L
.06 .3437 L
.064 .34018 L
.068 .3356 L
.072 .32976 L
.076 .32244 L
.08 .31346 L
.084 .30265 L
.088 .28992 L
.092 .27527 L
.096 .25884 L
.1 .2409 L
.104 .22191 L
.108 .20247 L
.112 .18338 L
.116 .16555 L
.12 .14996 L
.124 .13759 L
.128 .12936 L
.132 .12597 L
.136 .12789 L
.14 .13522 L
.144 .14772 L
.148 .16476 L
.152 .18538 L
.156 .20839 L
.16 .23246 L
.164 .25626 L
.168 .27859 L
.172 .29849 L
.176 .31533 L
.18 .32879 L
.184 .33891 L
.188 .34597 L
.192 .35048 L
.196 .353 L
.2 .35412 L
Mistroke
.204 .35438 L
.208 .35419 L
.212 .35384 L
.216 .35351 L
.22 .35327 L
.224 .35313 L
.228 .35309 L
.232 .35309 L
.236 .35312 L
.24 .35314 L
.244 .35316 L
.248 .35317 L
.252 .35317 L
.256 .35317 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35318 L
.764 .35321 L
.768 .35323 L
.772 .35324 L
.776 .35319 L
.78 .35306 L
.784 .35282 L
.788 .35248 L
.792 .35214 L
.796 .35194 L
.8 .3522 L
Mistroke
.804 .35333 L
.808 .35585 L
.812 .36035 L
.816 .36742 L
.82 .37753 L
.824 .391 L
.828 .40783 L
.832 .42774 L
.836 .45007 L
.84 .47387 L
.844 .49793 L
.848 .52094 L
.852 .54156 L
.856 .5586 L
.86 .5711 L
.864 .57843 L
.868 .58035 L
.872 .57696 L
.876 .56873 L
.88 .55637 L
.884 .54078 L
.888 .52294 L
.892 .50385 L
.896 .48442 L
.9 .46542 L
.904 .44748 L
.908 .43105 L
.912 .41641 L
.916 .40368 L
.92 .39287 L
.924 .38388 L
.928 .37657 L
.932 .37073 L
.936 .36615 L
.94 .36263 L
.944 .35996 L
.948 .35798 L
.952 .35653 L
.956 .35548 L
.96 .35474 L
.964 .35422 L
.968 .35386 L
.972 .35362 L
.976 .35346 L
.98 .35335 L
.984 .35328 L
.988 .35323 L
.992 .3532 L
.996 .35318 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23179 L
.012 .23182 L
.016 .23186 L
.02 .23192 L
.024 .23201 L
.028 .23215 L
.032 .23235 L
.036 .23265 L
.04 .23309 L
.044 .23371 L
.048 .23459 L
.052 .23581 L
.056 .23747 L
.06 .23971 L
.064 .24266 L
.068 .24651 L
.072 .25141 L
.076 .25755 L
.08 .26509 L
.084 .27417 L
.088 .28486 L
.092 .29715 L
.096 .31094 L
.1 .326 L
.104 .34195 L
.108 .35827 L
.112 .37429 L
.116 .38927 L
.12 .40236 L
.124 .41274 L
.128 .41965 L
.132 .4225 L
.136 .42089 L
.14 .41474 L
.144 .40425 L
.148 .38995 L
.152 .37264 L
.156 .35333 L
.16 .33313 L
.164 .31316 L
.168 .29441 L
.172 .2777 L
.176 .26357 L
.18 .25227 L
.184 .24378 L
.188 .23785 L
.192 .23407 L
.196 .23195 L
.2 .23101 L
Mistroke
.204 .23079 L
.208 .23095 L
.212 .23124 L
.216 .23153 L
.22 .23173 L
.224 .23184 L
.228 .23188 L
.232 .23187 L
.236 .23185 L
.24 .23183 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23183 L
.764 .23185 L
.768 .23187 L
.772 .23188 L
.776 .23184 L
.78 .23173 L
.784 .23153 L
.788 .23124 L
.792 .23095 L
.796 .23079 L
.8 .23101 L
Mistroke
.804 .23195 L
.808 .23407 L
.812 .23785 L
.816 .24378 L
.82 .25227 L
.824 .26357 L
.828 .2777 L
.832 .29441 L
.836 .31316 L
.84 .33313 L
.844 .35333 L
.848 .37264 L
.852 .38995 L
.856 .40425 L
.86 .41474 L
.864 .42089 L
.868 .4225 L
.872 .41965 L
.876 .41274 L
.88 .40236 L
.884 .38927 L
.888 .37429 L
.892 .35827 L
.896 .34195 L
.9 .326 L
.904 .31094 L
.908 .29715 L
.912 .28486 L
.916 .27417 L
.92 .26509 L
.924 .25755 L
.928 .25141 L
.932 .24651 L
.936 .24266 L
.94 .23971 L
.944 .23747 L
.948 .23581 L
.952 .23459 L
.956 .23371 L
.96 .23309 L
.964 .23265 L
.968 .23235 L
.972 .23215 L
.976 .23201 L
.98 .23192 L
.984 .23186 L
.988 .23183 L
.992 .23181 L
.996 .23179 L
1 .23179 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01000Oomoogoo1@0017oo00D0
07ooOomoo`00009oo`8000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001o
ogooOol00003Ool20002Ool01@00Oomoogoo00000goo00<007oo00000P0017oo00<007ooOol02Woo
000LOol20005Ool2000:Ool00`00Oomoo`0oOol00`00Oomoo`08Ool2000COol001aoo`03001oogoo
00Eoo`03001oogoo00Qoo`03001oogoo03moo`03001oogoo00Qoo`03001oogoo019oo`0077oo0P00
1Woo00<007ooOol01goo00<007ooOol0@7oo00<007ooOol01goo00<007ooOol04goo000LOol00`00
Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`11Ool00`00Oomoo`06Ool00`00Oomoo`0COol000]o
o`8000Aoo`04001oogooOol50002Ool20007Ool00`00Oomoo`06Ool00`00Oomoo`11Ool00`00Oomo
o`05Ool00`00Oomoo`0DOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol01Goo00<007ooOol0@Goo00<007ooOol01Goo00<007ooOol057oo000:Ool01000Oomo
o`002Goo00<007ooOol00Woo0P0027oo00<007ooOol01Goo00<007ooOol0@Goo00<007ooOol01Goo
00<007ooOol057oo000:Ool01000Oomoo`002Woo00D007ooOomoo`0000Uoo`03001oogoo00Aoo`03
001oogoo04=oo`03001oogoo00Aoo`03001oogoo01Aoo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool20009Ool00`00Oomoo`03Ool00`00Oomoo`13Ool00`00Oomoo`03Ool00`00Oomoo`0E
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol027oo00<007ooOol00goo
00<007ooOol0@goo00<007ooOol00goo00<007ooOol05Goo000;Ool20009Ool30003Ool20009Ool0
0`00Oomoo`03Ool00`00Oomoo`13Ool00`00Oomoo`03Ool00`00Oomoo`0EOol001aoo`03001oogoo
00Qoo`03001oogoo009oo`03001oogoo04Aoo`03001oogoo009oo`03001oogoo01Ioo`002goo0P00
17oo00<007ooOol00goo0`000Woo0P002Goo00<007ooOol00Woo00<007ooOol0A7oo00<007ooOol0
0Woo00<007ooOol05Woo000:Ool01000Oomoo`002Woo00D007ooOomoo`0000]oo`05001oogooOol0
0017Ool01@00Oomoogoo000067oo000:Ool01000Oomoo`001goo1@000Woo0P002Woo00D007ooOomo
o`0004Moo`05001oogooOol0000HOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007oo
Ool02Goo00D007ooOomoo`0004Moo`05001oogooOol0000HOol000Yoo`04001oogoo0008Ool00`00
Ool00003Ool2000;Ool00`00Ool00019Ool00`00Ool0000IOol000Yoo`04001oogoo0009Ool20003
Ool00`00Oomoo`0:Ool00`00Ool00019Ool00`00Ool0000IOol000]oo`8000]oo`04001oogooOol2
000;Ool2001;Ool00`00Oomoo`0HOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol0
0Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool4
0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04
001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`00
77oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`00
5Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009o
o`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<0
07ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3001hOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P00Lgoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`@000=oo`8007=oo`002Woo
00@007ooOol000Moo`03001oogoo00Aoo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001o
ogoo00=oo`8007=oo`002goo0P002Woo0P000goo00<007ooOol02goo00<007ooOol0I7oo000LOol2
000;Ool3001UOol001aoo`03001oogoo00Yoo`03001oo`0006Eoo`002goo0P0017oo00<007ooOol0
0goo0`000Woo0P002goo00<007oo0000IGoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0000ao
o`04001oogoo001TOol000=oo`D0009oo`04001oogoo0007Ool50002Ool00`00Oomoo`09Ool01@00
Oomoogoo0000I7oo000:Ool01000Oomoo`001goo00@007ooOol000=oo`8000Yoo`05001oogooOol0
001TOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`09Ool01@00Oomoogoo0000
I7oo000:Ool01000Oomoo`002Goo0P000goo0P002Goo00<007ooOol00Woo00<007ooOol0HWoo000;
Ool2000;Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol0HWoo000LOol20009Ool0
0`00Oomoo`02Ool00`00Oomoo`1ROol001aoo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo
065oo`002goo0P0017oo00@007ooOomoo`D0009oo`8000Uoo`03001oogoo00=oo`03001oogoo065o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00
Oomoo`1QOol000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00
Oomoo`04Ool00`00Oomoo`1QOol000Yoo`04001oogoo000:Ool01000Oomoogoo0P0027oo00<007oo
Ool00goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo
0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0080009oo`04001oogoo0009Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`00
0Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`8000Moo`03001oogoo00Ioo`80009oo`04001oogoo0009Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`03Ool000]oo`8000Uoo`<000=oo`03001oogoo00Ioo`03001oogoo00Ioo`80
009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000Mo
o`03001oogoo00=oo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol0
0`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000goo00@007ooOol000Qoo`8000Aoo`04001o
ogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007oo
Ool000Eoo`0077oo00<007ooOol01Goo00<007ooOol017oo1@000goo0P002Woo00<007ooOol00goo
0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D0
00=oo`8000Ioo`0077oo0P001Goo00<007ooOol02Goo00<007ooOol0Ggoo000LOol00`00Oomoo`03
Ool2000<Ool00`00Oomoo`1NOol001aoofT000aoo`0077oo00<007ooOol04Woo00<007ooOol04Woo
00<007ooOol04Goo00<007ooOol04Woo0`002goo0P001Goo00<007ooOol02Woo000LOol2001COol0
0`00Oomoo`08Ool2000COol001aoo`03001oogoo059oo`03001oogoo00Qoo`03001oogoo019oo`00
77oo0P00Dgoo00<007ooOol01goo00<007ooOol04goo000LOol00`00Oomoo`1BOol00`00Oomoo`07
Ool00`00Oomoo`0COol001aoo`03001oogoo05=oo`03001oogoo00Eoo`03001oogoo01Aoo`002goo
0P0017oo00@007ooOomoo`D0009oo`8005Aoo`03001oogoo00Eoo`03001oogoo01Aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1COol00`00Oomoo`05Ool00`00Oomoo`0DOol0
00Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001DOol00`00Oomoo`05Ool00`00Oomoo`0DOol0
00Yoo`04001oogoo000:Ool01@00Oomoogoo0000EWoo00<007ooOol017oo00<007ooOol057oo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8005Eoo`03001oogoo00Aoo`03001oogoo01Ao
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1DOol00`00Oomoo`03Ool0
0`00Oomoo`0EOol000]oo`8000Uoo`<000=oo`03001oogoo05Aoo`03001oogoo00=oo`03001oogoo
01Eoo`0077oo0P00EGoo00<007ooOol00goo00<007ooOol05Goo000LOol00`00Oomoo`1DOol00`00
Oomoo`02Ool00`00Oomoo`0FOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8005Eoo`03001o
ogoo009oo`03001oogoo01Ioo`002Woo00@007ooOol000Yoo`05001oogooOol0001GOol01@00Oomo
ogoo000067oo000:Ool01000Oomoo`001goo1@000Woo0P00EWoo00D007ooOomoo`0001Qoo`002Woo
00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1EOol01@00Oomoogoo000067oo000:Ool0
1000Oomoo`0027oo00<007oo00000goo0P00EWoo00D007ooOomoo`0001Qoo`002Woo00@007ooOol0
00Uoo`8000=oo`03001oogoo05Ioo`03001oo`0001Uoo`002goo0P002goo00D007ooOomoo`0005Qo
o`03001oo`0001Uoo`0077oo0P00F7oo00<007ooOol067oo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0
001dOol000=oo`D0009oo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool0
1000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo
000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00
Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogooOol50002Ool2001cOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo
0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo
0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo0P003Goo00D007ooOomoo`00009oo`04
001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol0
0003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`002Woo00D007ooOomoo`00019oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`00
2Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@0
07ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogoo
Ool007oo10000goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P003Goo00<007ooOol017oo
00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol0
17oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07
001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo
00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`80
00Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoofT000ao
o`0077oo00@007ooOomoo`<00003Ool007oo00=oo`05001oogooOol00002Ool20003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo0P000Woo00D007ooOomo
o`0000=oo`03001oo`0000<000=oo`03001oogoo00Yoo`0077oo0P001Goo0P002Woo00<007ooOol0
?goo00<007ooOol027oo0P004goo000LOol00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`0o
Ool00`00Oomoo`08Ool00`00Oomoo`0BOol001aoo`8000Ioo`03001oogoo00Moo`03001oogoo041o
o`03001oogoo00Moo`03001oogoo01=oo`0077oo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool0@Goo00<007ooOol01Woo00<007ooOol04goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00
1goo00<007ooOol01Woo00<007ooOol0@Goo00<007ooOol01Goo00<007ooOol057oo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo045oo`03
001oogoo00Eoo`03001oogoo01Aoo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8000Qoo`03
001oogoo00Eoo`03001oogoo045oo`03001oogoo00Eoo`03001oogoo01Aoo`002Woo00@007ooOol0
00Yoo`05001oogooOol00009Ool00`00Oomoo`04Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00
Oomoo`0DOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P002Goo00<007ooOol00goo
00<007ooOol0@goo00<007ooOol00goo00<007ooOol05Goo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo04=oo`03001oogoo00=oo`03
001oogoo01Eoo`002goo0P002Goo0`000goo0P002Goo00<007ooOol00goo00<007ooOol0@goo00<0
07ooOol00goo00<007ooOol05Goo000LOol00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`14
Ool00`00Oomoo`03Ool00`00Oomoo`0EOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8000Uo
o`03001oogoo009oo`03001oogoo04Aoo`03001oogoo009oo`03001oogoo01Ioo`002Woo00@007oo
Ool000Yoo`05001oogooOol0000;Ool01@00Oomoogoo0000Agoo00D007ooOomoo`0001Qoo`002Woo
00@007ooOol000Moo`D0009oo`8000Yoo`05001oogooOol00017Ool01@00Oomoogoo000067oo000:
Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo00Uoo`05001oogooOol00017Ool01@00
Oomoogoo000067oo000:Ool01000Oomoo`0027oo00<007oo00000goo0P002goo00<007oo0000BGoo
00<007oo00006Goo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol02Woo00<007oo0000BGoo
00<007oo00006Goo000;Ool2000;Ool01000Oomoogoo0P002goo0P00Bgoo00<007ooOol067oo000L
Ool00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<0
07ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo
00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001o
ogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P00
2Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007oo
Ool00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`00
5goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1240\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23183 m
.008 .23191 L
.012 .23201 L
.016 .23215 L
.02 .23236 L
.024 .23267 L
.028 .23311 L
.032 .23374 L
.036 .23463 L
.04 .23586 L
.044 .23753 L
.048 .23978 L
.052 .24274 L
.056 .24659 L
.06 .25148 L
.064 .25761 L
.068 .26513 L
.072 .27417 L
.076 .28481 L
.08 .29704 L
.084 .31076 L
.088 .32575 L
.092 .34162 L
.096 .35787 L
.1 .37386 L
.104 .38881 L
.108 .40192 L
.112 .41236 L
.116 .41937 L
.12 .42235 L
.124 .4209 L
.128 .41492 L
.132 .40459 L
.136 .39042 L
.14 .37321 L
.144 .35393 L
.148 .33371 L
.152 .31366 L
.156 .2948 L
.16 .27794 L
.164 .26366 L
.168 .25223 L
.172 .24363 L
.176 .23763 L
.18 .23382 L
.184 .23171 L
.188 .2308 L
.192 .23064 L
.196 .23085 L
.2 .23119 L
Mistroke
.204 .23151 L
.208 .23173 L
.212 .23185 L
.216 .23189 L
.22 .23188 L
.224 .23186 L
.228 .23183 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23183 L
.776 .23186 L
.78 .23188 L
.784 .23189 L
.788 .23185 L
.792 .23173 L
.796 .23151 L
.8 .23119 L
Mistroke
.804 .23085 L
.808 .23064 L
.812 .2308 L
.816 .23171 L
.82 .23382 L
.824 .23763 L
.828 .24363 L
.832 .25223 L
.836 .26366 L
.84 .27794 L
.844 .2948 L
.848 .31366 L
.852 .33371 L
.856 .35393 L
.86 .37321 L
.864 .39042 L
.868 .40459 L
.872 .41492 L
.876 .4209 L
.88 .42235 L
.884 .41937 L
.888 .41236 L
.892 .40192 L
.896 .38881 L
.9 .37386 L
.904 .35787 L
.908 .34162 L
.912 .32575 L
.916 .31076 L
.92 .29704 L
.924 .28481 L
.928 .27417 L
.932 .26513 L
.936 .25761 L
.94 .25148 L
.944 .24659 L
.948 .24274 L
.952 .23978 L
.956 .23753 L
.96 .23586 L
.964 .23463 L
.968 .23375 L
.972 .23312 L
.976 .23267 L
.98 .23237 L
.984 .23216 L
.988 .23203 L
.992 .23194 L
.996 .23188 L
1 .23185 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35292 m
.008 .35289 L
.012 .35281 L
.016 .35266 L
.02 .35242 L
.024 .35207 L
.028 .35155 L
.032 .3508 L
.036 .34974 L
.04 .34828 L
.044 .34629 L
.048 .34361 L
.052 .34008 L
.056 .3355 L
.06 .32967 L
.064 .32237 L
.068 .31341 L
.072 .30264 L
.076 .28997 L
.08 .2754 L
.084 .25905 L
.088 .24121 L
.092 .2223 L
.096 .20294 L
.1 .1839 L
.104 .16609 L
.108 .15047 L
.112 .13804 L
.116 .12969 L
.12 .12615 L
.124 .12787 L
.128 .13501 L
.132 .14732 L
.136 .1642 L
.14 .18471 L
.144 .20768 L
.148 .23177 L
.152 .25566 L
.156 .27813 L
.16 .29821 L
.164 .31522 L
.168 .32885 L
.172 .33909 L
.176 .34624 L
.18 .35077 L
.184 .35328 L
.188 .35436 L
.192 .35456 L
.196 .35431 L
.2 .3539 L
Mistroke
.204 .35353 L
.208 .35326 L
.212 .35312 L
.216 .35307 L
.22 .35308 L
.224 .35311 L
.228 .35314 L
.232 .35316 L
.236 .35317 L
.24 .35317 L
.244 .35317 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35315 L
.764 .35315 L
.768 .35316 L
.772 .35318 L
.776 .35322 L
.78 .35325 L
.784 .35326 L
.788 .35321 L
.792 .35306 L
.796 .3528 L
.8 .35242 L
Mistroke
.804 .35201 L
.808 .35176 L
.812 .35196 L
.816 .35304 L
.82 .35555 L
.824 .36009 L
.828 .36724 L
.832 .37748 L
.836 .3911 L
.84 .40812 L
.844 .4282 L
.848 .45067 L
.852 .47456 L
.856 .49865 L
.86 .52161 L
.864 .54213 L
.868 .55901 L
.872 .57132 L
.876 .57845 L
.88 .58018 L
.884 .57663 L
.888 .56828 L
.892 .55585 L
.896 .54024 L
.9 .52242 L
.904 .50339 L
.908 .48403 L
.912 .46512 L
.916 .44727 L
.92 .43092 L
.924 .41635 L
.928 .40368 L
.932 .39291 L
.936 .38395 L
.94 .37665 L
.944 .37082 L
.948 .36624 L
.952 .36271 L
.956 .36004 L
.96 .35804 L
.964 .35658 L
.968 .35552 L
.972 .35477 L
.976 .35424 L
.98 .35388 L
.984 .35363 L
.988 .35345 L
.992 .35333 L
.996 .35324 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23187 L
.012 .23198 L
.016 .23214 L
.02 .23235 L
.024 .23266 L
.028 .23311 L
.032 .23374 L
.036 .23463 L
.04 .23586 L
.044 .23753 L
.048 .23978 L
.052 .24274 L
.056 .24659 L
.06 .25148 L
.064 .25761 L
.068 .26513 L
.072 .27417 L
.076 .28481 L
.08 .29704 L
.084 .31076 L
.088 .32575 L
.092 .34162 L
.096 .35787 L
.1 .37386 L
.104 .38881 L
.108 .40192 L
.112 .41236 L
.116 .41937 L
.12 .42235 L
.124 .4209 L
.128 .41492 L
.132 .40459 L
.136 .39042 L
.14 .37321 L
.144 .35393 L
.148 .33371 L
.152 .31366 L
.156 .2948 L
.16 .27794 L
.164 .26366 L
.168 .25223 L
.172 .24363 L
.176 .23763 L
.18 .23382 L
.184 .23171 L
.188 .2308 L
.192 .23064 L
.196 .23085 L
.2 .23119 L
Mistroke
.204 .23151 L
.208 .23173 L
.212 .23185 L
.216 .23189 L
.22 .23188 L
.224 .23186 L
.228 .23183 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23183 L
.776 .23186 L
.78 .23188 L
.784 .23189 L
.788 .23185 L
.792 .23173 L
.796 .23151 L
.8 .23119 L
Mistroke
.804 .23085 L
.808 .23064 L
.812 .2308 L
.816 .23171 L
.82 .23382 L
.824 .23763 L
.828 .24363 L
.832 .25223 L
.836 .26366 L
.84 .27794 L
.844 .2948 L
.848 .31366 L
.852 .33371 L
.856 .35393 L
.86 .37321 L
.864 .39042 L
.868 .40459 L
.872 .41492 L
.876 .4209 L
.88 .42235 L
.884 .41937 L
.888 .41236 L
.892 .40192 L
.896 .38881 L
.9 .37386 L
.904 .35787 L
.908 .34162 L
.912 .32575 L
.916 .31076 L
.92 .29704 L
.924 .28481 L
.928 .27417 L
.932 .26513 L
.936 .25761 L
.94 .25148 L
.944 .24659 L
.948 .24274 L
.952 .23978 L
.956 .23753 L
.96 .23586 L
.964 .23463 L
.968 .23375 L
.972 .23312 L
.976 .23268 L
.98 .23237 L
.984 .23217 L
.988 .23203 L
.992 .23195 L
.996 .23191 L
1 .23189 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01000Oomoogoo0`0000=oo`00
Ool00goo00@007ooOomoo`80009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo
Ool00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000Aoo`05001oogooOol00003Ool00`00Ool000020003Ool01@00Oomoogoo00000Woo0`00
0goo00<007ooOol02Woo000LOol20004Ool00`00Oomoo`09Ool00`00Oomoo`11Ool00`00Oomoo`08
Ool2000BOol001aoo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo045oo`03001oogoo00Qo
o`03001oogoo015oo`0077oo0P001Goo00<007ooOol01goo00<007ooOol0@goo00<007ooOol01goo
00<007ooOol04Goo000LOol00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`13Ool00`00Oomo
o`06Ool00`00Oomoo`0BOol000]oo`8000Aoo`04001oogooOol50002Ool20006Ool00`00Oomoo`06
Ool00`00Oomoo`13Ool00`00Oomoo`06Ool00`00Oomoo`0BOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0A7oo00<007ooOol01Goo00<0
07ooOol04goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P001goo00<007ooOol017oo00<0
07ooOol0A7oo00<007ooOol01Goo00<007ooOol04goo000:Ool01000Oomoo`002Woo00D007ooOomo
o`0000Qoo`03001oogoo00Aoo`03001oogoo04Eoo`03001oogoo00Aoo`03001oogoo01=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool20007Ool00`00Oomoo`04Ool00`00Oomoo`15Ool0
0`00Oomoo`03Ool00`00Oomoo`0DOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol01Woo00<007ooOol017oo00<007ooOol0AGoo00<007ooOol00goo00<007ooOol057oo000;
Ool20009Ool30003Ool20008Ool00`00Oomoo`03Ool00`00Oomoo`15Ool00`00Oomoo`03Ool00`00
Oomoo`0DOol001aoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo04Moo`03001oogoo009o
o`03001oogoo01Aoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P0027oo00<007ooOol00Woo
00<007ooOol0Agoo00<007ooOol00Woo00<007ooOol057oo000:Ool01000Oomoo`002Woo00D007oo
Oomoo`0000Yoo`05001oogooOol00019Ool01@00Oomoogoo00005goo000:Ool01000Oomoo`001goo
1@000Woo0P002Goo00D007ooOomoo`0004Uoo`05001oogooOol0000GOol000Yoo`04001oogoo0007
Ool01000Oomoo`000goo00<007ooOol027oo00@007ooOol004]oo`04001oogoo000GOol000Yoo`04
001oogoo0008Ool00`00Ool00003Ool20009Ool01000Oomoo`00Bgoo00<007oo000067oo000:Ool0
1000Oomoo`002Goo0P000goo00<007ooOol02Goo0P00C7oo00<007oo000067oo000;Ool2000;Ool0
1000Oomoogoo0P002Woo0P00CGoo0P0067oo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`00
1goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:
Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001c
Ool001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1b
Ool001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomo
o`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Mo
o`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00N7oo000:
Ool01000Oomoo`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`8007=oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool40003Ool2001cOol0
00Yoo`04001oogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool0
0`00Oomoo`03Ool2001cOol000]oo`8000Yoo`8000=oo`03001oogoo00Yoo`03001oogoo06Eoo`00
77oo0P002Woo0P00Igoo000LOol00`00Oomoo`09Ool2001WOol000]oo`8000Aoo`03001oogoo00=o
o`<0009oo`8000Uoo`04001oogoo001VOol000Yoo`04001oogoo000:Ool01@00Oomoogoo00002Woo
00@007ooOol006Ioo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo00Qoo`04001o
ogoo001VOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P002Goo00D007ooOomoo`0006Eo
o`002Woo00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo00Qoo`05001oogooOol0001UOol0
00Yoo`04001oogoo0009Ool20003Ool20008Ool00`00Oomoo`02Ool00`00Oomoo`1SOol000]oo`80
00]oo`05001oogooOol00009Ool00`00Oomoo`02Ool00`00Oomoo`1SOol001aoo`8000Qoo`03001o
ogoo009oo`03001oogoo06=oo`0077oo00<007ooOol01goo00<007ooOol00goo00<007ooOol0HWoo
000;Ool20004Ool01000Oomoogoo1@000Woo0P001goo00<007ooOol017oo00<007ooOol0HWoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo
069oo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo
00Aoo`03001oogoo069oo`002Woo00@007ooOol000Yoo`04001oogooOol20007Ool00`00Oomoo`04
Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004
Ool20005Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol01Goo00<007ooOol017oo0P000Woo00@007ooOol0009oo`03001oogoo00Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P001Woo00<007ooOol01Goo00@007ooOol0009oo`04001oogoo0009Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Uoo`<000=oo`03001oogoo00Eoo`03001oogoo
00Ioo`03001oo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03
Ool001aoo`8000Ioo`03001oogoo00Aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomo
o`001Goo000LOol00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Ool00004Ool01000Oomoo`0027oo
0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool0
0006Ool01000Oomoo`001Goo000LOol00`00Oomoo`03Ool20007Ool50003Ool2000:Ool00`00Oomo
o`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`00
0Woo1@000goo0P001Woo000LOol20004Ool00`00Oomoo`09Ool00`00Oomoo`1POol001aoo`04001o
ogooOol3000;Ool00`00Oomoo`1POol001aoofT000aoo`0077oo00<007ooOol04Woo00<007ooOol0
4Woo00<007ooOol04Goo00<007ooOol04Woo00@007oo000000]oo`8000Aoo`03001oogoo00Yoo`00
77oo0P00E7oo00<007ooOol027oo0P004Woo000LOol00`00Oomoo`1COol00`00Oomoo`08Ool00`00
Oomoo`0AOol001aoo`8005Eoo`03001oogoo00Moo`03001oogoo015oo`0077oo00<007ooOol0E7oo
00<007ooOol01Woo00<007ooOol04Woo000LOol00`00Oomoo`1DOol00`00Oomoo`06Ool00`00Oomo
o`0BOol000]oo`8000Aoo`04001oogooOol50002Ool2001EOol00`00Oomoo`06Ool00`00Oomoo`0B
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0E7oo00<007ooOol01Goo00<0
07ooOol04goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00EGoo00<007ooOol01Goo00<0
07ooOol04goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0005Moo`03001oogoo00Aoo`03001o
ogoo01=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001FOol00`00Oomoo`03Ool0
0`00Oomoo`0DOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0EGoo00<0
07ooOol00goo00<007ooOol057oo000;Ool20009Ool30003Ool00`00Oomoo`1EOol00`00Oomoo`03
Ool00`00Oomoo`0DOol001aoo`8005Moo`03001oogoo009oo`03001oogoo01Aoo`0077oo00<007oo
Ool0EWoo00<007ooOol00Woo00<007ooOol057oo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2
001GOol00`00Oomoo`02Ool00`00Oomoo`0DOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000
F7oo00D007ooOomoo`0001Moo`002Woo00@007ooOol000Moo`D0009oo`8005Moo`05001oogooOol0
000GOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0Egoo00@007ooOol001Mo
o`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8005Qoo`04001oogoo000GOol000Yoo`04001o
ogoo0009Ool20003Ool00`00Oomoo`1GOol00`00Ool0000HOol000]oo`8000]oo`05001oogooOol0
001IOol00`00Ool0000HOol001aoo`8005Uoo`8001Qoo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool2
0004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000
M7oo0003Ool50002Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@0
07ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`00
2Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00@007ooOomoo`8007=o
o`0077oo00<007ooOol0LWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P00Lgoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`80
00Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`00
0goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`8000eoo`05001oogooOol00002Ool01000
Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo0000
0goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Yoo`05001oogooOol0000BOol01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
17oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04
001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo10000goo00@007ooOol000Uo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001o
ogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo
001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04
001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Ao
o`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00
Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`03
001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006
Ool30002Ool50003Ool20006Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOomY000<Ool0
01aoo`03001oo`0000<0009oo`03001oogoo009oo`04001oogooOol300000goo001oo`02Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007oo001oo`00
00=oo`05001oogooOol00003Ool30002Ool00`00Oomoo`0:Ool001aoo`8000Aoo`03001oogoo00Uo
o`03001oogoo045oo`03001oogoo00Qoo`80019oo`0077oo00<007ooOol017oo00<007ooOol027oo
00<007ooOol0@Goo00<007ooOol027oo00<007ooOol04Goo000LOol20005Ool00`00Oomoo`07Ool0
0`00Oomoo`13Ool00`00Oomoo`07Ool00`00Oomoo`0AOol001aoo`03001oogoo00Eoo`03001oogoo
00Ioo`03001oogoo04=oo`03001oogoo00Ioo`03001oogoo019oo`002goo0P0017oo00@007ooOomo
o`D0009oo`8000Ioo`03001oogoo00Ioo`03001oogoo04=oo`03001oogoo00Ioo`03001oogoo019o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`14Ool00`00Oomoo`05Ool00`00Oomoo`0COol000Yoo`04001oogoo0009Ool00`00Oomoo`02
Ool20006Ool00`00Oomoo`05Ool00`00Oomoo`14Ool00`00Oomoo`05Ool00`00Oomoo`0COol000Yo
o`04001oogoo000:Ool01@00Oomoogoo000027oo00<007ooOol017oo00<007ooOol0AGoo00<007oo
Ool017oo00<007ooOol04goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8000Moo`03
001oogoo00Aoo`03001oogoo04Eoo`03001oogoo00=oo`03001oogoo01Aoo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`15Ool00`00
Oomoo`03Ool00`00Oomoo`0DOol000]oo`8000Uoo`<000=oo`8000Qoo`03001oogoo00=oo`03001o
ogoo04Eoo`03001oogoo00=oo`03001oogoo01Aoo`0077oo00<007ooOol01goo00<007ooOol00Woo
00<007ooOol0Agoo00<007ooOol00Woo00<007ooOol057oo000;Ool20004Ool00`00Oomoo`03Ool3
0002Ool20008Ool00`00Oomoo`02Ool00`00Oomoo`17Ool00`00Oomoo`02Ool00`00Oomoo`0DOol0
00Yoo`04001oogoo000:Ool01@00Oomoogoo00002Woo00D007ooOomoo`0004Uoo`05001oogooOol0
000GOol000Yoo`04001oogoo0007Ool50002Ool20009Ool01@00Oomoogoo0000BGoo00D007ooOomo
o`0001Moo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`08Ool01000Oomoo`00
Bgoo00@007ooOol001Moo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8000Uoo`04001oogoo
001;Ool00`00Ool0000HOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`09Ool2001<Ool0
0`00Ool0000HOol000]oo`8000]oo`04001oogooOol2000:Ool2001=Ool2000HOol001aoo`03001o
ogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1b
Ool000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomo
o`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qo
o`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003
Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool0
0`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00
Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1280\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23203 m
.008 .2323 L
.012 .23264 L
.016 .23311 L
.02 .23376 L
.024 .23466 L
.028 .2359 L
.032 .23759 L
.036 .23985 L
.04 .24282 L
.044 .24666 L
.048 .25156 L
.052 .25767 L
.056 .26517 L
.06 .27417 L
.064 .28476 L
.068 .29693 L
.072 .31059 L
.076 .3255 L
.08 .3413 L
.084 .35749 L
.088 .37342 L
.092 .38836 L
.096 .40149 L
.1 .41198 L
.104 .41909 L
.108 .4222 L
.112 .42091 L
.116 .41509 L
.12 .40492 L
.124 .39089 L
.128 .37377 L
.132 .35453 L
.136 .33429 L
.14 .31417 L
.144 .29519 L
.148 .2782 L
.152 .26376 L
.156 .25219 L
.16 .24348 L
.164 .23741 L
.168 .23357 L
.172 .23147 L
.176 .23059 L
.18 .23048 L
.184 .23075 L
.188 .23113 L
.192 .23149 L
.196 .23173 L
.2 .23187 L
Mistroke
.204 .23191 L
.208 .2319 L
.212 .23187 L
.216 .23183 L
.22 .23181 L
.224 .2318 L
.228 .2318 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23182 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23182 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .2318 L
.776 .2318 L
.78 .23181 L
.784 .23183 L
.788 .23187 L
.792 .2319 L
.796 .23191 L
.8 .23187 L
Mistroke
.804 .23173 L
.808 .23149 L
.812 .23113 L
.816 .23075 L
.82 .23048 L
.824 .23059 L
.828 .23147 L
.832 .23357 L
.836 .23741 L
.84 .24348 L
.844 .25219 L
.848 .26376 L
.852 .2782 L
.856 .29519 L
.86 .31417 L
.864 .33429 L
.868 .35453 L
.872 .37377 L
.876 .39089 L
.88 .40492 L
.884 .41509 L
.888 .42091 L
.892 .4222 L
.896 .41909 L
.9 .41198 L
.904 .40149 L
.908 .38836 L
.912 .37342 L
.916 .35749 L
.92 .3413 L
.924 .3255 L
.928 .31059 L
.932 .29693 L
.936 .28476 L
.94 .27417 L
.944 .26517 L
.948 .25767 L
.952 .25156 L
.956 .24666 L
.96 .24282 L
.964 .23985 L
.968 .2376 L
.972 .23592 L
.976 .23468 L
.98 .23379 L
.984 .23316 L
.988 .23272 L
.992 .23242 L
.996 .23223 L
1 .23211 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35221 m
.008 .35211 L
.012 .35186 L
.016 .35139 L
.02 .35068 L
.024 .34964 L
.028 .34819 L
.032 .3462 L
.036 .34352 L
.04 .33999 L
.044 .33541 L
.048 .32958 L
.052 .3223 L
.056 .31337 L
.06 .30264 L
.064 .29003 L
.068 .27553 L
.072 .25926 L
.076 .24151 L
.08 .22268 L
.084 .2034 L
.088 .18442 L
.092 .16662 L
.096 .15099 L
.1 .13849 L
.104 .13003 L
.108 .12633 L
.112 .12787 L
.116 .13481 L
.12 .14692 L
.124 .16364 L
.128 .18404 L
.132 .20696 L
.136 .23107 L
.14 .25505 L
.144 .27766 L
.148 .29791 L
.152 .3151 L
.156 .32889 L
.16 .33926 L
.164 .3465 L
.168 .35107 L
.172 .35357 L
.176 .35461 L
.18 .35475 L
.184 .35444 L
.188 .35397 L
.192 .35355 L
.196 .35326 L
.2 .3531 L
Mistroke
.204 .35305 L
.208 .35306 L
.212 .3531 L
.216 .35314 L
.22 .35316 L
.224 .35317 L
.228 .35317 L
.232 .35317 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35315 L
.776 .35315 L
.78 .35316 L
.784 .35319 L
.788 .35322 L
.792 .35326 L
.796 .35328 L
.8 .35323 L
Mistroke
.804 .35307 L
.808 .35277 L
.812 .35235 L
.816 .35189 L
.82 .35157 L
.824 .35171 L
.828 .35275 L
.832 .35526 L
.836 .35983 L
.84 .36706 L
.844 .37744 L
.848 .39123 L
.852 .40842 L
.856 .42867 L
.86 .45128 L
.864 .47525 L
.868 .49936 L
.872 .52228 L
.876 .54268 L
.88 .5594 L
.884 .57152 L
.888 .57845 L
.892 .58 L
.896 .57629 L
.9 .56783 L
.904 .55533 L
.908 .5397 L
.912 .52191 L
.916 .50293 L
.92 .48364 L
.924 .46482 L
.928 .44706 L
.932 .4308 L
.936 .41629 L
.94 .40368 L
.944 .39295 L
.948 .38402 L
.952 .37674 L
.956 .37091 L
.96 .36633 L
.964 .36279 L
.968 .3601 L
.972 .3581 L
.976 .35661 L
.98 .35554 L
.984 .35476 L
.988 .35419 L
.992 .35377 L
.996 .35345 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23213 L
.012 .23252 L
.016 .23304 L
.02 .23371 L
.024 .23464 L
.028 .23589 L
.032 .23758 L
.036 .23984 L
.04 .24281 L
.044 .24666 L
.048 .25155 L
.052 .25767 L
.056 .26517 L
.06 .27417 L
.064 .28476 L
.068 .29693 L
.072 .31059 L
.076 .3255 L
.08 .3413 L
.084 .35749 L
.088 .37342 L
.092 .38836 L
.096 .40149 L
.1 .41198 L
.104 .41909 L
.108 .4222 L
.112 .42091 L
.116 .41509 L
.12 .40492 L
.124 .39089 L
.128 .37377 L
.132 .35453 L
.136 .33429 L
.14 .31417 L
.144 .29519 L
.148 .2782 L
.152 .26376 L
.156 .25219 L
.16 .24348 L
.164 .23741 L
.168 .23357 L
.172 .23147 L
.176 .23059 L
.18 .23048 L
.184 .23075 L
.188 .23113 L
.192 .23149 L
.196 .23173 L
.2 .23187 L
Mistroke
.204 .23191 L
.208 .2319 L
.212 .23187 L
.216 .23183 L
.22 .23181 L
.224 .2318 L
.228 .2318 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23182 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23182 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .2318 L
.776 .2318 L
.78 .23181 L
.784 .23183 L
.788 .23187 L
.792 .2319 L
.796 .23191 L
.8 .23187 L
Mistroke
.804 .23173 L
.808 .23149 L
.812 .23113 L
.816 .23075 L
.82 .23048 L
.824 .23059 L
.828 .23147 L
.832 .23357 L
.836 .23741 L
.84 .24348 L
.844 .25219 L
.848 .26376 L
.852 .2782 L
.856 .29519 L
.86 .31417 L
.864 .33429 L
.868 .35453 L
.872 .37377 L
.876 .39089 L
.88 .40492 L
.884 .41509 L
.888 .42091 L
.892 .4222 L
.896 .41909 L
.9 .41198 L
.904 .40149 L
.908 .38836 L
.912 .37342 L
.916 .35749 L
.92 .3413 L
.924 .3255 L
.928 .31059 L
.932 .29693 L
.936 .28476 L
.94 .27417 L
.944 .26517 L
.948 .25767 L
.952 .25156 L
.956 .24666 L
.96 .24282 L
.964 .23985 L
.968 .2376 L
.972 .23592 L
.976 .23469 L
.98 .23381 L
.984 .23318 L
.988 .23276 L
.992 .23249 L
.996 .23234 L
1 .23228 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol00`00Oomoo`020003Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
0`000Woo00<007ooOol02Woo000LOol20003Ool00`00Oomoo`08Ool00`00Oomoo`14Ool00`00Oomo
o`09Ool00`00Oomoo`0?Ool001aoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo04Aoo`03
001oogoo00Qoo`03001oogoo011oo`0077oo0P0017oo00<007ooOol01goo00<007ooOol0AGoo00<0
07ooOol01goo00<007ooOol047oo000LOol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`15
Ool00`00Oomoo`06Ool00`00Oomoo`0AOol000]oo`8000Aoo`04001oogooOol50002Ool20005Ool0
0`00Oomoo`06Ool00`00Oomoo`15Ool00`00Oomoo`06Ool00`00Oomoo`0AOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0Agoo00<007oo
Ool01Goo00<007ooOol04Goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P001Woo00<007oo
Ool017oo00<007ooOol0Agoo00<007ooOol017oo00<007ooOol04Woo000:Ool01000Oomoo`002Woo
00D007ooOomoo`0000Moo`03001oogoo00Aoo`03001oogoo04Moo`03001oogoo00Aoo`03001oogoo
019oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool20006Ool00`00Oomoo`04Ool00`00
Oomoo`17Ool00`00Oomoo`04Ool00`00Oomoo`0BOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol01Goo00<007ooOol00goo00<007ooOol0BGoo00<007ooOol00goo00<007oo
Ool04Woo000;Ool20009Ool30003Ool20006Ool00`00Oomoo`03Ool00`00Oomoo`19Ool00`00Oomo
o`02Ool00`00Oomoo`0COol001aoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo04Uoo`03
001oogoo009oo`03001oogoo01=oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P001goo00<0
07ooOol00Woo00<007ooOol0BGoo00<007ooOol00Woo00<007ooOol04goo000:Ool01000Oomoo`00
2Woo00D007ooOomoo`0000Qoo`05001oogooOol0001<Ool01@00Oomoogoo00005Woo000:Ool01000
Oomoo`001goo1@000Woo0P0027oo00@007ooOol004aoo`05001oogooOol0000FOol000Yoo`04001o
ogoo0007Ool01000Oomoo`000goo00<007ooOol01goo00@007ooOol004eoo`04001oogoo000FOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool20008Ool01000Oomoo`00CGoo00@007ooOol001Io
o`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo00Qoo`8004moo`8001Moo`002goo0P002goo
00@007ooOomoo`8000Uoo`8004moo`8001Moo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00
Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol0
00Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`00
2Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00
Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0
LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007oo
Ool00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000G
Ool00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<007Qoo`00
2Woo00@007ooOol000Moo`05001oogooOol0001gOol000=oo`D0009oo`04001oogoo0007Ool01@00
Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool2001cOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo10000goo0P00Lgoo
000:Ool01000Oomoo`001goo00<007ooOol017oo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo
00<007ooOol00goo0P00Lgoo000;Ool2000:Ool20003Ool00`00Oomoo`08Ool00`00Oomoo`1WOol0
01aoo`8000Uoo`8006Qoo`0077oo00<007ooOol027oo0P00J7oo000;Ool20004Ool00`00Oomoo`03
Ool30002Ool20008Ool01000Oomoo`00Igoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0000Uo
o`04001oogoo001WOol000=oo`D0009oo`04001oogoo0007Ool50002Ool00`00Oomoo`07Ool01000
Oomoo`00Igoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`8000Moo`05001oogooOol0001W
Ool000Yoo`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`06Ool01@00Oomoogoo0000Igoo
000:Ool01000Oomoo`002Goo0P000goo0P001goo00<007ooOol00Woo00<007ooOol0I7oo000;Ool2
000;Ool01@00Oomoogoo000027oo00<007ooOol00Woo00<007ooOol0I7oo000LOol20006Ool00`00
Oomoo`03Ool00`00Oomoo`1TOol001aoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo06Ao
o`002goo0P0017oo00@007ooOomoo`D0009oo`8000Ioo`03001oogoo00=oo`03001oogoo06Aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`1SOol000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`1SOol000Yoo`04001oogoo000:Ool01000Oomoogoo0P001Woo00<007ooOol0
17oo100017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P00
17oo0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00Aoo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009o
o`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo
001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool20005Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Goo0`000goo00<007ooOol017oo00<007oo
Ool01Woo00@007ooOol0009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`8000Aoo`03001oogoo00Ioo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007oo
Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000
Oomoo`001Goo000LOol00`00Oomoo`03Ool00`00Oomoo`06Ool20005Ool01000Oomoo`0027oo0P00
17oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo
00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006
Ool01000Oomoo`001Goo000LOol00`00Oomoo`02Ool20008Ool50003Ool2000:Ool00`00Oomoo`03
Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo
1@000goo0P001Woo000LOol20003Ool00`00Oomoo`09Ool00`00Oomoo`1QOol001aoo`03001oogoo
008000aoo`03001oogoo065oo`0077ooJ@0037oo000LOol00`00Oomoo`0BOol00`00Oomoo`0BOol0
0`00Oomoo`0AOol00`00Oomoo`0BOol01@00Oomoogoo00002goo0P000goo00<007ooOol02Woo000L
Ool2001EOol00`00Oomoo`09Ool00`00Oomoo`0?Ool001aoo`03001oogoo05Aoo`03001oogoo00Qo
o`03001oogoo011oo`0077oo0P00EWoo00<007ooOol01goo00<007ooOol047oo000LOol00`00Oomo
o`1EOol00`00Oomoo`06Ool00`00Oomoo`0AOol001aoo`03001oogoo05Eoo`03001oogoo00Ioo`03
001oogoo015oo`002goo0P0017oo00@007ooOomoo`D0009oo`8005Ioo`03001oogoo00Ioo`03001o
ogoo015oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1FOol00`00Oomoo`05
Ool00`00Oomoo`0AOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001GOol00`00Oomoo`05
Ool00`00Oomoo`0AOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000F7oo00<007ooOol017oo
00<007ooOol04Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8005Moo`03001oogoo
00Aoo`03001oogoo019oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1G
Ool00`00Oomoo`03Ool00`00Oomoo`0BOol000]oo`8000Uoo`<000=oo`03001oogoo05Moo`03001o
ogoo009oo`03001oogoo01=oo`0077oo0P00F7oo00<007ooOol00Woo00<007ooOol04goo000LOol0
0`00Oomoo`1GOol00`00Oomoo`02Ool00`00Oomoo`0COol000]oo`8000Aoo`03001oogoo00=oo`<0
009oo`8005Qoo`03001oogoo009oo`03001oogoo01=oo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0001IOol01@00Oomoogoo00005Woo000:Ool01000Oomoo`001goo1@000Woo0P00F7oo00D007oo
Oomoo`0001Ioo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1HOol01000Oomo
o`005Woo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00FGoo00@007ooOol001Ioo`002Woo
00@007ooOol000Uoo`8000=oo`03001oogoo05Qoo`04001oogoo000FOol000]oo`8000]oo`05001o
ogooOol0001KOol2000GOol001aoo`8005Yoo`8001Moo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool2
0004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000
M7oo0003Ool50002Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@0
07ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`00
2Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00@007ooOomoo`8007=o
o`0077oo00<007ooOol0LWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P00Lgoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`80
00Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`00
0goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`8000eoo`05001oogooOol00002Ool01000
Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo0000
0goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Yoo`05001oogooOol0000BOol01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
17oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04
001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo10000goo00@007ooOol000Uo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001o
ogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo
001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04
001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Ao
o`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00
Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`03
001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006
Ool30002Ool50003Ool20006Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOomY000<Ool0
01aoo`D000=oo`03001oogoo009oo`04001oogooOol20002Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00<007ooOol00P000goo00D0
07ooOomoo`0000=oo`H000aoo`0077oo0P000Woo0P002goo00<007ooOol0@goo00<007ooOol02Goo
00<007ooOol03goo000LOol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`14Ool00`00Oomo
o`08Ool00`00Oomoo`0@Ool001aoo`8000Aoo`03001oogoo00Moo`03001oogoo04Eoo`03001oogoo
00Moo`03001oogoo011oo`0077oo00<007ooOol00goo00<007ooOol01goo00<007ooOol0AGoo00<0
07ooOol01Woo00<007ooOol04Goo000;Ool20004Ool01000Oomoogoo1@000Woo0P001Goo00<007oo
Ool01Woo00<007ooOol0AGoo00<007ooOol01Woo00<007ooOol04Goo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo04Moo`03001oogoo00Eo
o`03001oogoo015oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8000Eoo`03001oogoo00Eo
o`03001oogoo04Moo`03001oogoo00Eoo`03001oogoo015oo`002Woo00@007ooOol000Yoo`05001o
ogooOol00007Ool00`00Oomoo`04Ool00`00Oomoo`17Ool00`00Oomoo`04Ool00`00Oomoo`0BOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P001Woo00<007ooOol017oo00<007ooOol0
Agoo00<007ooOol017oo00<007ooOol04Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo019o
o`002goo0P002Goo0`000goo0P001Woo00<007ooOol00goo00<007ooOol0BGoo00<007ooOol00Woo
00<007ooOol04goo000LOol00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`19Ool00`00Oomo
o`02Ool00`00Oomoo`0COol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8000Moo`03001oogoo
009oo`03001oogoo04Uoo`03001oogoo009oo`03001oogoo01=oo`002Woo00@007ooOol000Yoo`05
001oogooOol00008Ool01@00Oomoogoo0000C7oo00D007ooOomoo`0001Ioo`002Woo00@007ooOol0
00Moo`D0009oo`8000Moo`05001oogooOol0001<Ool01@00Oomoogoo00005Woo000:Ool01000Oomo
o`001goo00@007ooOol000=oo`03001oogoo00Moo`04001oogoo001=Ool01000Oomoo`005Woo000:
Ool01000Oomoo`0027oo00<007oo00000goo0P0027oo00@007ooOol004eoo`04001oogoo000FOol0
00Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`08Ool2001?Ool2000GOol000]oo`8000]oo`04
001oogooOol20009Ool2001?Ool2000GOol001aoo`03001oogoo079oo`002goo0P0017oo00<007oo
Ool00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007
Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yo
o`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=o
o`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079o
o`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo
009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo
00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1320\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23269 m
.008 .23351 L
.012 .2345 L
.016 .23583 L
.02 .23757 L
.024 .23986 L
.028 .24286 L
.032 .24672 L
.036 .25161 L
.04 .25772 L
.044 .2652 L
.048 .27417 L
.052 .28471 L
.056 .29683 L
.06 .31041 L
.064 .32525 L
.068 .34098 L
.072 .3571 L
.076 .373 L
.08 .38791 L
.084 .40105 L
.088 .4116 L
.092 .4188 L
.096 .42204 L
.1 .4209 L
.104 .41525 L
.108 .40524 L
.112 .39135 L
.116 .37432 L
.12 .35513 L
.124 .33488 L
.128 .31469 L
.132 .2956 L
.136 .27846 L
.14 .26387 L
.144 .25216 L
.148 .24334 L
.152 .23719 L
.156 .23332 L
.16 .23122 L
.164 .23038 L
.168 .23031 L
.172 .23064 L
.176 .23108 L
.18 .23147 L
.184 .23174 L
.188 .23188 L
.192 .23193 L
.196 .23191 L
.2 .23187 L
Mistroke
.204 .23184 L
.208 .23181 L
.212 .2318 L
.216 .2318 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23182 L
.236 .23182 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23182 L
.768 .23182 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .2318 L
.788 .2318 L
.792 .23181 L
.796 .23184 L
.8 .23187 L
Mistroke
.804 .23191 L
.808 .23193 L
.812 .23188 L
.816 .23174 L
.82 .23147 L
.824 .23108 L
.828 .23064 L
.832 .23031 L
.836 .23038 L
.84 .23122 L
.844 .23332 L
.848 .23719 L
.852 .24334 L
.856 .25216 L
.86 .26387 L
.864 .27846 L
.868 .2956 L
.872 .31469 L
.876 .33488 L
.88 .35513 L
.884 .37432 L
.888 .39135 L
.892 .40524 L
.896 .41525 L
.9 .4209 L
.904 .42204 L
.908 .4188 L
.912 .4116 L
.916 .40105 L
.92 .38791 L
.924 .373 L
.928 .35711 L
.932 .34098 L
.936 .32525 L
.94 .31041 L
.944 .29683 L
.948 .28471 L
.952 .27417 L
.956 .2652 L
.96 .25773 L
.964 .25163 L
.968 .24675 L
.972 .24291 L
.976 .23994 L
.98 .2377 L
.984 .23602 L
.988 .23481 L
.992 .23395 L
.996 .23339 L
1 .23303 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .34985 m
.008 .34958 L
.012 .3489 L
.016 .34766 L
.02 .34582 L
.024 .34324 L
.028 .33977 L
.032 .33524 L
.036 .32945 L
.04 .3222 L
.044 .31331 L
.048 .30263 L
.052 .29008 L
.056 .27565 L
.06 .25947 L
.064 .2418 L
.068 .22306 L
.072 .20385 L
.076 .18493 L
.08 .16716 L
.084 .15151 L
.088 .13895 L
.092 .13037 L
.096 .12652 L
.1 .12788 L
.104 .13461 L
.108 .14654 L
.112 .1631 L
.116 .18338 L
.12 .20625 L
.124 .23038 L
.128 .25443 L
.132 .27718 L
.136 .29759 L
.14 .31497 L
.144 .32892 L
.148 .33943 L
.152 .34676 L
.156 .35137 L
.16 .35387 L
.164 .35487 L
.168 .35495 L
.172 .35457 L
.176 .35404 L
.18 .35357 L
.184 .35325 L
.188 .35308 L
.192 .35303 L
.196 .35304 L
.2 .35309 L
Mistroke
.204 .35313 L
.208 .35316 L
.212 .35318 L
.216 .35318 L
.22 .35317 L
.224 .35317 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35315 L
.784 .35315 L
.788 .35315 L
.792 .35316 L
.796 .35319 L
.8 .35323 L
Mistroke
.804 .35328 L
.808 .3533 L
.812 .35325 L
.816 .35307 L
.82 .35275 L
.824 .35228 L
.828 .35176 L
.832 .35137 L
.836 .35145 L
.84 .35246 L
.844 .35495 L
.848 .35957 L
.852 .36689 L
.856 .3774 L
.86 .39136 L
.864 .40873 L
.868 .42915 L
.872 .45189 L
.876 .47595 L
.88 .50008 L
.884 .52294 L
.888 .54323 L
.892 .55978 L
.896 .57171 L
.9 .57845 L
.904 .57981 L
.908 .57595 L
.912 .56738 L
.916 .55482 L
.92 .53917 L
.924 .5214 L
.928 .50247 L
.932 .48326 L
.936 .46452 L
.94 .44685 L
.944 .43067 L
.948 .41624 L
.952 .40368 L
.956 .39299 L
.96 .38408 L
.964 .37681 L
.968 .37097 L
.972 .36637 L
.976 .3628 L
.98 .36006 L
.984 .35796 L
.988 .35637 L
.992 .35511 L
.996 .3541 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23289 L
.012 .23409 L
.016 .23556 L
.02 .23739 L
.024 .23975 L
.028 .24278 L
.032 .24667 L
.036 .25158 L
.04 .2577 L
.044 .26519 L
.048 .27416 L
.052 .28471 L
.056 .29682 L
.06 .31041 L
.064 .32525 L
.068 .34098 L
.072 .3571 L
.076 .373 L
.08 .38791 L
.084 .40105 L
.088 .4116 L
.092 .4188 L
.096 .42204 L
.1 .4209 L
.104 .41525 L
.108 .40524 L
.112 .39135 L
.116 .37432 L
.12 .35513 L
.124 .33488 L
.128 .31469 L
.132 .2956 L
.136 .27846 L
.14 .26387 L
.144 .25216 L
.148 .24334 L
.152 .23719 L
.156 .23332 L
.16 .23122 L
.164 .23038 L
.168 .23031 L
.172 .23064 L
.176 .23108 L
.18 .23147 L
.184 .23174 L
.188 .23188 L
.192 .23193 L
.196 .23191 L
.2 .23187 L
Mistroke
.204 .23184 L
.208 .23181 L
.212 .2318 L
.216 .2318 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23182 L
.236 .23182 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23182 L
.768 .23182 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .2318 L
.788 .2318 L
.792 .23181 L
.796 .23184 L
.8 .23187 L
Mistroke
.804 .23191 L
.808 .23193 L
.812 .23188 L
.816 .23174 L
.82 .23147 L
.824 .23108 L
.828 .23064 L
.832 .23031 L
.836 .23038 L
.84 .23122 L
.844 .23332 L
.848 .23719 L
.852 .24334 L
.856 .25216 L
.86 .26387 L
.864 .27846 L
.868 .2956 L
.872 .31469 L
.876 .33488 L
.88 .35513 L
.884 .37432 L
.888 .39135 L
.892 .40524 L
.896 .41525 L
.9 .4209 L
.904 .42204 L
.908 .4188 L
.912 .4116 L
.916 .40105 L
.92 .38791 L
.924 .373 L
.928 .35711 L
.932 .34098 L
.936 .32525 L
.94 .31041 L
.944 .29683 L
.948 .28472 L
.952 .27417 L
.956 .26521 L
.96 .25774 L
.964 .25164 L
.968 .24677 L
.972 .24294 L
.976 .23999 L
.98 .23777 L
.984 .23614 L
.988 .23499 L
.992 .23422 L
.996 .23381 L
1 .23364 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol50003Ool00`00Oomoo`02Ool0
0`00Oomoo`020003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004
Ool01@00Oomoogoo00000goo00@007ooOomoo`80009oo`05001oogooOol00003Ool01P00Ool00000
Ool000aoo`0077oo0P000Woo00<007ooOol027oo00<007ooOol0Agoo00<007ooOol027oo00<007oo
Ool03Woo000LOol01@00Oomoogoo00002Woo00<007ooOol0Agoo00<007ooOol01goo00<007ooOol0
3goo000LOol20003Ool00`00Oomoo`07Ool00`00Oomoo`17Ool00`00Oomoo`07Ool00`00Oomoo`0?
Ool001aoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo04Uoo`03001oogoo00Ioo`03001o
ogoo00moo`002goo0P0017oo00@007ooOomoo`D0009oo`8000Aoo`03001oogoo00Eoo`03001oogoo
04Uoo`03001oogoo00Eoo`03001oogoo011oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`19Ool00`00Oomoo`05Ool00`00Oomoo`0@Ool0
00Yoo`04001oogoo0009Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`05Ool00`00Oomoo`19Ool0
0`00Oomoo`04Ool00`00Oomoo`0AOol000Yoo`04001oogoo000:Ool01@00Oomoogoo00001Goo00<0
07ooOol017oo00<007ooOol0BWoo00<007ooOol017oo00<007ooOol04Goo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8000Eoo`03001oogoo00=oo`03001oogoo04Yoo`03001oogoo00Ao
o`03001oogoo015oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`1;Ool00`00Oomoo`03Ool00`00Oomoo`0AOol000]oo`8000Uoo`<0
00=oo`8000Eoo`03001oogoo00=oo`03001oogoo04]oo`03001oogoo00=oo`03001oogoo015oo`00
77oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol0
4Woo000;Ool20004Ool00`00Oomoo`03Ool30002Ool20006Ool00`00Oomoo`02Ool00`00Oomoo`1;
Ool00`00Oomoo`02Ool00`00Oomoo`0BOol000Yoo`04001oogoo000:Ool01@00Oomoogoo00001goo
00D007ooOomoo`0004moo`05001oogooOol0000DOol000Yoo`04001oogoo0007Ool50002Ool20006
Ool01@00Oomoogoo0000Cgoo00@007ooOol001Eoo`002Woo00@007ooOol000Moo`04001oogoo0003
Ool00`00Oomoo`05Ool01@00Oomoogoo0000Cgoo00@007ooOol001Eoo`002Woo00@007ooOol000Qo
o`03001oo`0000=oo`8000Moo`03001oo`00051oo`04001oogoo000EOol000Yoo`04001oogoo0009
Ool20003Ool00`00Oomoo`06Ool00`00Ool0001AOol2000FOol000]oo`8000]oo`04001oogooOol2
0008Ool2001AOol2000FOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`00
0goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo
0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<0
07ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`00
0goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=o
o`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0
Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3001hOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P00Lgoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`@000=oo`8007=oo`002Woo00@007oo
Ool000Moo`03001oogoo00Aoo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oogoo00=o
o`8007=oo`002goo0P002Woo0P000goo00<007ooOol01goo00<007ooOol0J7oo000LOol20008Ool2
001YOol001aoo`03001oogoo00Ioo`03001oo`0006Uoo`002goo0P0017oo00<007ooOol00goo0`00
0Woo0P001goo00<007oo0000JGoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0000Qoo`04001o
ogoo001XOol000=oo`D0009oo`04001oogoo0007Ool50002Ool00`00Oomoo`05Ool01@00Oomoogoo
0000J7oo000:Ool01000Oomoo`001goo00@007ooOol000=oo`8000Ioo`05001oogooOol0001XOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`05Ool01@00Oomoogoo0000J7oo000:
Ool01000Oomoo`002Goo0P000goo0P001Woo00<007ooOol00Woo00<007ooOol0IGoo000;Ool2000;
Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007ooOol0IGoo000LOol20005Ool00`00Oomo
o`03Ool00`00Oomoo`1UOol001aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo06Eoo`00
2goo0P0017oo00@007ooOomoo`D0009oo`8000Eoo`03001oogoo00=oo`03001oogoo06Eoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`1U
Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool00`00Oomoo`1UOol000Yoo`04001oogoo000:Ool01000Oomoogoo0P0017oo00<007ooOol017oo
00<007ooOol00`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@00
0goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00=oo`03001oogoo00Eoo`8000=oo`04001oogoo0002Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000
Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo
00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`8000Aoo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Uoo`<000=oo`03
001oogoo00=oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001o
ogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000=oo`03001oogoo00Ioo`D000=o
o`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo
Ool40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
17oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`02Ool00`00Oomo
o`07Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004
Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002
Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol01@00Oomo
ogoo00002Woo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=o
o`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P000Woo00<007oo
Ool02Goo00<007ooOol0HWoo000LOol4000<Ool00`00Oomoo`1ROol001aoofT000aoo`0077oo00<0
07ooOol04Woo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol00Woo00<0
07ooOol02Woo00@007ooOol000aoo`0077oo0P00Egoo00<007ooOol027oo00<007ooOol03Woo000L
Ool00`00Oomoo`1FOol00`00Oomoo`07Ool00`00Oomoo`0?Ool001aoo`8005Moo`03001oogoo00Mo
o`03001oogoo00moo`0077oo00<007ooOol0EWoo00<007ooOol01goo00<007ooOol03goo000LOol0
0`00Oomoo`1GOol00`00Oomoo`05Ool00`00Oomoo`0@Ool000]oo`8000Aoo`04001oogooOol50002
Ool2001HOol00`00Oomoo`05Ool00`00Oomoo`0@Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00<007ooOol0Egoo00<007ooOol01Goo00<007ooOol047oo000:Ool01000Oomoo`002Goo00<0
07ooOol00Woo0P00F7oo00<007ooOol01Goo00<007ooOol047oo000:Ool01000Oomoo`002Woo00D0
07ooOomoo`0005Uoo`03001oogoo00Aoo`03001oogoo015oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2001HOol00`00Oomoo`04Ool00`00Oomoo`0AOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0F7oo00<007ooOol00goo00<007ooOol04Goo000;Ool20009
Ool30003Ool00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`0AOol001aoo`8005Uoo`03001o
ogoo00=oo`03001oogoo015oo`0077oo00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol04Woo
000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001IOol00`00Oomoo`02Ool00`00Oomoo`0BOol0
00Yoo`04001oogoo000:Ool01@00Oomoogoo0000Fgoo00D007ooOomoo`0001Aoo`002Woo00@007oo
Ool000Moo`D0009oo`8005Yoo`05001oogooOol0000DOol000Yoo`04001oogoo0007Ool01000Oomo
o`000goo00<007ooOol0FGoo00@007ooOol001Eoo`002Woo00@007ooOol000Qoo`03001oo`0000=o
o`8005Yoo`04001oogoo000EOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1IOol01000
Oomoo`005Goo000;Ool2000;Ool01@00Oomoogoo0000G7oo0P005Woo000LOol2001KOol2000FOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool0
1000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol000Moo`D0009oo`80
07=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol0
00]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00@007oo
Oomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0=Ool3
0004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool2
0005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool2
000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo00@007ooOol0009o
o`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
1Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000
Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002
Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool20009Ool3
0003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001o
ogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol0
0`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@00
0goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2001cOol001ao
o`03001oogoo079oo`0077ooJ@0037oo000LOol50003Ool00`00Oomoo`02Ool00`00Oomoo`020003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo
00000goo00@007ooOomoo`80009oo`05001oogooOol00003Ool00`00Ool00003000<Ool001aoo`80
0003Ool0000000]oo`03001oogoo04Eoo`03001oogoo00Uoo`8000moo`0077oo00D007ooOomoo`00
00Yoo`03001oogoo04Moo`03001oogoo00Moo`80011oo`0077oo0P000goo00<007ooOol01goo00<0
07ooOol0Agoo00<007ooOol01goo00<007ooOol03goo000LOol00`00Oomoo`02Ool00`00Oomoo`06
Ool00`00Oomoo`19Ool00`00Oomoo`06Ool00`00Oomoo`0?Ool000]oo`8000Aoo`04001oogooOol5
0002Ool20004Ool00`00Oomoo`05Ool00`00Oomoo`19Ool00`00Oomoo`05Ool00`00Oomoo`0@Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol01Goo00<007oo
Ool0BGoo00<007ooOol01Goo00<007ooOol047oo000:Ool01000Oomoo`002Goo00<007ooOol00Woo
0P0017oo00<007ooOol01Goo00<007ooOol0BGoo00<007ooOol01Goo00<007ooOol047oo000:Ool0
1000Oomoo`002Woo00D007ooOomoo`0000Eoo`03001oogoo00Aoo`03001oogoo04Yoo`03001oogoo
00Aoo`03001oogoo015oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool20005Ool00`00
Oomoo`03Ool00`00Oomoo`1:Ool00`00Oomoo`04Ool00`00Oomoo`0AOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol017oo00<007ooOol00goo00<007ooOol0Bgoo00<007oo
Ool00goo00<007ooOol04Goo000;Ool20009Ool30003Ool20005Ool00`00Oomoo`03Ool00`00Oomo
o`1;Ool00`00Oomoo`03Ool00`00Oomoo`0AOol001aoo`03001oogoo00Eoo`03001oogoo009oo`03
001oogoo04]oo`03001oogoo009oo`03001oogoo019oo`002goo0P0017oo00<007ooOol00goo0`00
0Woo0P001Woo00<007ooOol00Woo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol04Woo000:
Ool01000Oomoo`002Woo00D007ooOomoo`0000Moo`05001oogooOol0001?Ool01@00Oomoogoo0000
57oo000:Ool01000Oomoo`001goo1@000Woo0P001Woo00D007ooOomoo`0004moo`05001oogooOol0
000DOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol01Goo00D007ooOomoo`00
04moo`04001oogoo000EOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool20007Ool00`00Ool0
001@Ool01000Oomoo`005Goo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol01Woo00<007oo
0000DGoo0P005Woo000;Ool2000;Ool01000Oomoogoo0P0027oo0P00DGoo0P005Woo000LOol00`00
Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0
LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007oo
Ool00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008
Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`00
0goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo
00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<0
07ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1360\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23458 m
.008 .23674 L
.012 .23929 L
.016 .2425 L
.02 .24649 L
.024 .25149 L
.028 .25764 L
.032 .26514 L
.036 .27411 L
.04 .28463 L
.044 .2967 L
.048 .31023 L
.052 .325 L
.056 .34066 L
.06 .35672 L
.064 .37257 L
.068 .38747 L
.072 .40062 L
.076 .41122 L
.08 .41851 L
.084 .42187 L
.088 .42089 L
.092 .4154 L
.096 .40555 L
.1 .3918 L
.104 .37487 L
.108 .35573 L
.112 .33547 L
.116 .31521 L
.12 .29601 L
.124 .27873 L
.128 .264 L
.132 .25214 L
.136 .2432 L
.14 .23697 L
.144 .23306 L
.148 .23097 L
.152 .23016 L
.156 .23014 L
.16 .23052 L
.164 .23102 L
.168 .23145 L
.172 .23175 L
.176 .2319 L
.18 .23195 L
.184 .23193 L
.188 .23188 L
.192 .23184 L
.196 .23181 L
.2 .2318 L
Mistroke
.204 .2318 L
.208 .2318 L
.212 .23181 L
.216 .23181 L
.22 .23182 L
.224 .23182 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23182 L
.78 .23182 L
.784 .23181 L
.788 .23181 L
.792 .2318 L
.796 .2318 L
.8 .2318 L
Mistroke
.804 .23181 L
.808 .23184 L
.812 .23188 L
.816 .23193 L
.82 .23195 L
.824 .2319 L
.828 .23175 L
.832 .23145 L
.836 .23102 L
.84 .23052 L
.844 .23014 L
.848 .23016 L
.852 .23097 L
.856 .23306 L
.86 .23697 L
.864 .2432 L
.868 .25214 L
.872 .264 L
.876 .27873 L
.88 .29601 L
.884 .31521 L
.888 .33547 L
.892 .35573 L
.896 .37487 L
.9 .3918 L
.904 .40555 L
.908 .4154 L
.912 .42089 L
.916 .42187 L
.92 .41851 L
.924 .41122 L
.928 .40062 L
.932 .38747 L
.936 .37257 L
.94 .35673 L
.944 .34067 L
.948 .32501 L
.952 .31025 L
.956 .29673 L
.96 .28468 L
.964 .2742 L
.968 .26527 L
.972 .25785 L
.976 .25179 L
.98 .24696 L
.984 .24318 L
.988 .24031 L
.992 .23819 L
.996 .23672 L
1 .23575 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .34311 m
.008 .3425 L
.012 .34092 L
.016 .33811 L
.02 .3341 L
.024 .32864 L
.028 .32166 L
.032 .31295 L
.036 .30243 L
.04 .29 L
.044 .27569 L
.048 .25962 L
.052 .24206 L
.056 .22342 L
.06 .20429 L
.064 .18542 L
.068 .16768 L
.072 .15202 L
.076 .1394 L
.08 .13072 L
.084 .12671 L
.088 .12789 L
.092 .13443 L
.096 .14617 L
.1 .16256 L
.104 .18273 L
.108 .20554 L
.112 .22968 L
.116 .25381 L
.12 .27668 L
.124 .29727 L
.128 .31482 L
.132 .32895 L
.136 .3396 L
.14 .34702 L
.144 .35168 L
.148 .35417 L
.152 .35514 L
.156 .35516 L
.16 .3547 L
.164 .35411 L
.168 .3536 L
.172 .35324 L
.176 .35306 L
.18 .353 L
.184 .35302 L
.188 .35308 L
.192 .35313 L
.196 .35316 L
.2 .35318 L
Mistroke
.204 .35318 L
.208 .35317 L
.212 .35317 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35315 L
.796 .35314 L
.8 .35315 L
Mistroke
.804 .35316 L
.808 .35319 L
.812 .35325 L
.816 .3533 L
.82 .35332 L
.824 .35327 L
.828 .35308 L
.832 .35273 L
.836 .35221 L
.84 .35162 L
.844 .35117 L
.848 .35119 L
.852 .35215 L
.856 .35465 L
.86 .35931 L
.864 .36672 L
.868 .37737 L
.872 .3915 L
.876 .40906 L
.88 .42964 L
.884 .45252 L
.888 .47665 L
.892 .50079 L
.896 .5236 L
.9 .54377 L
.904 .56016 L
.908 .57189 L
.912 .57843 L
.916 .57961 L
.92 .57561 L
.924 .56693 L
.928 .5543 L
.932 .53864 L
.936 .52089 L
.94 .50202 L
.944 .48288 L
.948 .46422 L
.952 .44663 L
.956 .43051 L
.96 .41613 L
.964 .4036 L
.968 .3929 L
.972 .38395 L
.976 .37658 L
.98 .37059 L
.984 .36574 L
.988 .36183 L
.992 .35855 L
.996 .3558 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23477 L
.012 .23791 L
.016 .24156 L
.02 .24585 L
.024 .25106 L
.028 .25736 L
.032 .26496 L
.036 .27399 L
.04 .28455 L
.044 .29665 L
.048 .3102 L
.052 .32498 L
.056 .34065 L
.06 .35672 L
.064 .37257 L
.068 .38747 L
.072 .40062 L
.076 .41122 L
.08 .41851 L
.084 .42187 L
.088 .42089 L
.092 .4154 L
.096 .40555 L
.1 .3918 L
.104 .37487 L
.108 .35573 L
.112 .33547 L
.116 .31521 L
.12 .29601 L
.124 .27873 L
.128 .264 L
.132 .25214 L
.136 .2432 L
.14 .23697 L
.144 .23306 L
.148 .23097 L
.152 .23016 L
.156 .23014 L
.16 .23052 L
.164 .23102 L
.168 .23145 L
.172 .23175 L
.176 .2319 L
.18 .23195 L
.184 .23193 L
.188 .23188 L
.192 .23184 L
.196 .23181 L
.2 .2318 L
Mistroke
.204 .2318 L
.208 .2318 L
.212 .23181 L
.216 .23181 L
.22 .23182 L
.224 .23182 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23182 L
.78 .23182 L
.784 .23181 L
.788 .23181 L
.792 .2318 L
.796 .2318 L
.8 .2318 L
Mistroke
.804 .23181 L
.808 .23184 L
.812 .23188 L
.816 .23193 L
.82 .23195 L
.824 .2319 L
.828 .23175 L
.832 .23145 L
.836 .23102 L
.84 .23052 L
.844 .23014 L
.848 .23016 L
.852 .23097 L
.856 .23306 L
.86 .23697 L
.864 .2432 L
.868 .25214 L
.872 .264 L
.876 .27873 L
.88 .29601 L
.884 .31521 L
.888 .33547 L
.892 .35573 L
.896 .37487 L
.9 .3918 L
.904 .40555 L
.908 .4154 L
.912 .42089 L
.916 .42187 L
.92 .41851 L
.924 .41122 L
.928 .40062 L
.932 .38747 L
.936 .37257 L
.94 .35673 L
.944 .34067 L
.948 .32502 L
.952 .31026 L
.956 .29675 L
.96 .28471 L
.964 .27424 L
.968 .26535 L
.972 .25797 L
.976 .25197 L
.98 .24724 L
.984 .2436 L
.988 .24096 L
.992 .23912 L
.996 .2381 L
1 .23771 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol300000goo001oo`02Ool00`00
Oomoo`02Ool300000goo001oo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001o
ogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00004Ool01@00Oomoogoo00000goo00H007ooOomoo`00Ool30003Ool01@00Oomoogoo0000
0Woo0`0037oo000LOol4000:Ool00`00Oomoo`19Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool001ao
o`04001oogoo000:Ool00`00Oomoo`19Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool001aoo`80009o
o`03001oogoo00Ioo`03001oogoo04Yoo`03001oogoo00Moo`03001oogoo00ioo`0077oo00D007oo
Oomoo`0000Qoo`03001oogoo04]oo`03001oogoo00Ioo`03001oogoo00ioo`002goo0P0017oo00@0
07ooOomoo`D0009oo`80009oo`03001oogoo00Ioo`03001oogoo04]oo`03001oogoo00Eoo`03001o
ogoo00moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`05
Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool000Yoo`04001oogoo0009Ool00`00
Oomoo`02Ool20003Ool00`00Oomoo`05Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool00`00Oomoo`0?
Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol0CGoo
00<007ooOol017oo00<007ooOol03goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
00Aoo`03001oogoo00=oo`03001oogoo04eoo`03001oogoo00=oo`03001oogoo011oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`1=
Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool000]oo`8000Uoo`<000=oo`8000Aoo`03001oogoo00=o
o`03001oogoo04eoo`03001oogoo00=oo`03001oogoo011oo`0077oo00<007ooOol00goo00<007oo
Ool00Woo00<007ooOol0CWoo00<007ooOol00Woo00<007ooOol04Goo000;Ool20004Ool00`00Oomo
o`03Ool30002Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1>Ool00`00Oomoo`02Ool00`00Oomo
o`0AOol000Yoo`04001oogoo000:Ool01@00Oomoogoo00001Woo00D007ooOomoo`00055oo`05001o
ogooOol0000COol000Yoo`04001oogoo0007Ool50002Ool20005Ool01@00Oomoogoo0000DGoo00D0
07ooOomoo`0001=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`04Ool01@00
Oomoogoo0000DGoo00D007ooOomoo`0001=oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`80
00Ioo`03001oo`0005=oo`03001oo`0001Aoo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo
00Eoo`03001oo`0005=oo`03001oo`0001Aoo`002goo0P002goo00@007ooOomoo`8000Ioo`8005Ao
o`8001Eoo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001o
ogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol0
00]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo
000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol0
01Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00
Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<007Qoo`002Woo00@007ooOol000Moo`05001o
ogooOol0001gOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:
Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol0
00]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo10000goo0P00Lgoo000:Ool01000Oomoo`001goo00<0
07ooOol017oo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007ooOol00goo0P00Lgoo000;
Ool2000:Ool20003Ool00`00Oomoo`1bOol001aoo`8000Ioo`<006Yoo`0077oo00<007ooOol01Goo
00<007oo0000JWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool20006Ool00`00Ool0001ZOol0
00Yoo`04001oogoo000:Ool01@00Oomoogoo00001goo00@007ooOol006Uoo`000goo1@000Woo00@0
07ooOol000Moo`D0009oo`03001oogoo00Aoo`05001oogooOol0001YOol000Yoo`04001oogoo0007
Ool01000Oomoo`000goo0P001Goo00D007ooOomoo`0006Uoo`002Woo00@007ooOol000Qoo`03001o
o`0000=oo`03001oogoo00Aoo`05001oogooOol0001YOol000Yoo`04001oogoo0009Ool20003Ool2
0005Ool01@00Oomoogoo0000JGoo000;Ool2000;Ool01@00Oomoogoo00001Goo00<007ooOol00Woo
00<007ooOol0Igoo000LOol20004Ool00`00Oomoo`02Ool00`00Oomoo`1WOol001aoo`03001oogoo
00=oo`03001oogoo00=oo`03001oogoo06Ioo`002goo0P0017oo00@007ooOomoo`D0009oo`8000Ao
o`03001oogoo00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`1VOol000=oo`D0009oo`04001oogoo0009Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000Yoo`04001oogoo000:
Ool01000Oomoogoo0P000goo00<007ooOol017oo00@007ooOomoo`<000Aoo`8000Uoo`<000Aoo`80
00Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`80
00Ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`05
Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool20002Ool0
0`00Oomoo`06Ool00`00Oomoo`03Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
17oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00goo000;Ool20009Ool30003Ool01@00Oomoogoo000027oo00<007ooOol0
0goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool0
1000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=o
o`0077oo0P000Woo00<007ooOol01Woo00<007oo00000`000goo00@007ooOol000Uoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=o
o`04001oogoo0005Ool001aoo`05001oogooOol00008Ool00`00Ool00006Ool01000Oomoo`0027oo
0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool0
0006Ool01000Oomoo`001Goo000LOol01000Oomoo`002Woo1P000goo0P002Woo00<007ooOol00goo
0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D0
00=oo`8000Ioo`0077oo0`002goo00<007ooOol0I7oo000LOol2000<Ool2001UOol001aoofT000ao
o`0077oo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007oo
Ool00goo0P002goo00<007oo000037oo000LOol2001HOol00`00Oomoo`08Ool00`00Oomoo`0=Ool0
01aoo`03001oogoo05Moo`03001oogoo00Qoo`03001oogoo00eoo`0077oo0P00F7oo00<007ooOol0
1goo00<007ooOol03Woo000LOol00`00Oomoo`1GOol00`00Oomoo`07Ool00`00Oomoo`0>Ool001ao
o`03001oogoo05Qoo`03001oogoo00Eoo`03001oogoo00moo`002goo0P0017oo00@007ooOomoo`D0
009oo`8005Uoo`03001oogoo00Eoo`03001oogoo00moo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool00`00Oomoo`1HOol00`00Oomoo`05Ool00`00Oomoo`0?Ool000Yoo`04001oogoo0009Ool0
0`00Oomoo`02Ool2001IOol00`00Oomoo`05Ool00`00Oomoo`0?Ool000Yoo`04001oogoo000:Ool0
1@00Oomoogoo0000Fgoo00<007ooOol017oo00<007ooOol03goo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`8005Yoo`03001oogoo00=oo`03001oogoo011oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1IOol00`00Oomoo`03Ool00`00Oomoo`0@Ool000]oo`80
00Uoo`<000=oo`03001oogoo05Uoo`03001oogoo00=oo`03001oogoo011oo`0077oo0P00FWoo00<0
07ooOol00goo00<007ooOol047oo000LOol00`00Oomoo`1IOol00`00Oomoo`02Ool00`00Oomoo`0A
Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8005Yoo`03001oogoo009oo`03001oogoo015o
o`002Woo00@007ooOol000Yoo`05001oogooOol0001LOol01@00Oomoogoo00004goo000:Ool01000
Oomoo`001goo1@000Woo0P00Fgoo00D007ooOomoo`0001=oo`002Woo00@007ooOol000Moo`04001o
ogoo0003Ool00`00Oomoo`1JOol01@00Oomoogoo00004goo000:Ool01000Oomoo`0027oo00<007oo
00000goo0P00Fgoo00D007ooOomoo`0001=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo
05]oo`03001oo`0001Aoo`002goo0P002goo00D007ooOomoo`0005eoo`03001oo`0001Aoo`0077oo
0P00G7oo0P005Goo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009o
o`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000=oo`D0009oo`04001oogoo
0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo
000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo
00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`04001oogooOol50002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo
1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo
00<007ooOol00Woo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007oo
Ool00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00019o
o`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo00@007ooOol0009oo`03001oogoo00Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eo
o`002goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001o
ogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007oo
Ool000Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo
00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo0`0000=oo`00Ool00Woo00<0
07ooOol00Woo00D007oo001oo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000Aoo`05001oogooOol00003Ool02@00Oomoogoo001oo`00Ool00003Ool01@00Oomo
ogoo00000Woo0`0037oo000LOol4000:Ool00`00Oomoo`19Ool00`00Oomoo`08Ool2000>Ool001ao
o`04001oogoo000:Ool00`00Oomoo`19Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool001aoo`80009o
o`03001oogoo00Ioo`03001oogoo04Yoo`03001oogoo00Moo`03001oogoo00ioo`0077oo00D007oo
Oomoo`0000Qoo`03001oogoo04]oo`03001oogoo00Ioo`03001oogoo00ioo`002goo0P0017oo00@0
07ooOomoo`D0009oo`80009oo`03001oogoo00Ioo`03001oogoo04]oo`03001oogoo00Eoo`03001o
ogoo00moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`05
Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool000Yoo`04001oogoo0009Ool00`00
Oomoo`02Ool20003Ool00`00Oomoo`05Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool00`00Oomoo`0?
Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol0CGoo
00<007ooOol017oo00<007ooOol03goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
00Aoo`03001oogoo00=oo`03001oogoo04eoo`03001oogoo00=oo`03001oogoo011oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`1=
Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool000]oo`8000Uoo`<000=oo`8000Aoo`03001oogoo00=o
o`03001oogoo04eoo`03001oogoo00=oo`03001oogoo011oo`0077oo00<007ooOol00goo00<007oo
Ool00Woo00<007ooOol0CWoo00<007ooOol00Woo00<007ooOol04Goo000;Ool20004Ool00`00Oomo
o`03Ool30002Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1>Ool00`00Oomoo`02Ool00`00Oomo
o`0AOol000Yoo`04001oogoo000:Ool01@00Oomoogoo00001Woo00D007ooOomoo`00055oo`05001o
ogooOol0000COol000Yoo`04001oogoo0007Ool50002Ool20005Ool01@00Oomoogoo0000DGoo00D0
07ooOomoo`0001=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`04Ool01@00
Oomoogoo0000DGoo00D007ooOomoo`0001=oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`80
00Ioo`03001oo`0005=oo`03001oo`0001Aoo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo
00Eoo`03001oo`0005=oo`03001oo`0001Aoo`002goo0P002goo00@007ooOomoo`8000Ioo`8005Ao
o`8001Eoo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001o
ogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol0
00]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo
000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol0
01Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00
Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1400\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23926 m
.008 .24416 L
.012 .24975 L
.016 .25643 L
.02 .26425 L
.024 .27348 L
.028 .28413 L
.032 .2963 L
.036 .30985 L
.04 .32462 L
.044 .34026 L
.048 .35629 L
.052 .37211 L
.056 .387 L
.06 .40018 L
.064 .41083 L
.068 .41821 L
.072 .4217 L
.076 .42087 L
.08 .41554 L
.084 .40586 L
.088 .39224 L
.092 .37541 L
.096 .35632 L
.1 .33606 L
.104 .31574 L
.108 .29643 L
.112 .27901 L
.116 .26413 L
.12 .25212 L
.124 .24306 L
.128 .23675 L
.132 .2328 L
.136 .23071 L
.14 .22993 L
.144 .22996 L
.148 .2304 L
.152 .23095 L
.156 .23143 L
.16 .23176 L
.164 .23193 L
.168 .23197 L
.172 .23195 L
.176 .2319 L
.18 .23184 L
.184 .23181 L
.188 .2318 L
.192 .2318 L
.196 .2318 L
.2 .23181 L
Mistroke
.204 .23181 L
.208 .23182 L
.212 .23182 L
.216 .23182 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23182 L
.788 .23182 L
.792 .23182 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .2318 L
.808 .2318 L
.812 .2318 L
.816 .23181 L
.82 .23184 L
.824 .2319 L
.828 .23195 L
.832 .23197 L
.836 .23193 L
.84 .23176 L
.844 .23143 L
.848 .23095 L
.852 .2304 L
.856 .22996 L
.86 .22993 L
.864 .23071 L
.868 .2328 L
.872 .23675 L
.876 .24306 L
.88 .25212 L
.884 .26413 L
.888 .27901 L
.892 .29643 L
.896 .31574 L
.9 .33606 L
.904 .35632 L
.908 .37541 L
.912 .39224 L
.916 .40586 L
.92 .41554 L
.924 .42087 L
.928 .42171 L
.932 .41822 L
.936 .41084 L
.94 .4002 L
.944 .38704 L
.948 .37217 L
.952 .35638 L
.956 .34039 L
.96 .32483 L
.964 .31017 L
.968 .29677 L
.972 .28485 L
.976 .2745 L
.98 .26576 L
.984 .25854 L
.988 .25279 L
.992 .24831 L
.996 .24505 L
1 .2428 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32641 m
.008 .32527 L
.012 .32225 L
.016 .31698 L
.02 .30967 L
.024 .30013 L
.028 .28848 L
.032 .27473 L
.036 .2591 L
.04 .24185 L
.044 .22347 L
.048 .20453 L
.052 .18579 L
.056 .16812 L
.06 .15248 L
.064 .13982 L
.068 .13104 L
.072 .1269 L
.076 .12791 L
.08 .13426 L
.084 .14581 L
.088 .16203 L
.092 .18208 L
.096 .20483 L
.1 .22897 L
.104 .25318 L
.108 .27618 L
.112 .29693 L
.116 .31467 L
.12 .32897 L
.124 .33976 L
.128 .34728 L
.132 .35198 L
.136 .35448 L
.14 .35541 L
.144 .35537 L
.148 .35484 L
.152 .35419 L
.156 .35362 L
.16 .35323 L
.164 .35303 L
.168 .35297 L
.172 .353 L
.176 .35307 L
.18 .35313 L
.184 .35317 L
.188 .35318 L
.192 .35318 L
.196 .35318 L
.2 .35317 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35317 L
.792 .35317 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35315 L
.808 .35314 L
.812 .35314 L
.816 .35316 L
.82 .3532 L
.824 .35326 L
.828 .35332 L
.832 .35335 L
.836 .3533 L
.84 .35309 L
.844 .3527 L
.848 .35213 L
.852 .35148 L
.856 .35096 L
.86 .35091 L
.864 .35184 L
.868 .35434 L
.872 .35905 L
.876 .36656 L
.88 .37736 L
.884 .39166 L
.888 .40939 L
.892 .43014 L
.896 .45315 L
.9 .47735 L
.904 .5015 L
.908 .52424 L
.912 .54429 L
.916 .56052 L
.92 .57206 L
.924 .57841 L
.928 .5794 L
.932 .57525 L
.936 .56646 L
.94 .55377 L
.944 .53808 L
.948 .52034 L
.952 .50149 L
.956 .48238 L
.96 .46373 L
.964 .44611 L
.968 .4299 L
.972 .41535 L
.976 .40251 L
.98 .39137 L
.984 .38171 L
.988 .37342 L
.992 .36606 L
.996 .35952 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23868 L
.012 .24576 L
.016 .25359 L
.02 .26224 L
.024 .27208 L
.028 .28317 L
.032 .29565 L
.036 .30941 L
.04 .32433 L
.044 .34007 L
.048 .35617 L
.052 .37203 L
.056 .38695 L
.06 .40015 L
.064 .41081 L
.068 .4182 L
.072 .42169 L
.076 .42086 L
.08 .41554 L
.084 .40585 L
.088 .39224 L
.092 .37541 L
.096 .35632 L
.1 .33606 L
.104 .31574 L
.108 .29643 L
.112 .27901 L
.116 .26413 L
.12 .25212 L
.124 .24306 L
.128 .23675 L
.132 .2328 L
.136 .23071 L
.14 .22993 L
.144 .22996 L
.148 .2304 L
.152 .23095 L
.156 .23143 L
.16 .23176 L
.164 .23193 L
.168 .23197 L
.172 .23195 L
.176 .2319 L
.18 .23184 L
.184 .23181 L
.188 .2318 L
.192 .2318 L
.196 .2318 L
.2 .23181 L
Mistroke
.204 .23181 L
.208 .23182 L
.212 .23182 L
.216 .23182 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23182 L
.788 .23182 L
.792 .23182 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .2318 L
.808 .2318 L
.812 .2318 L
.816 .23181 L
.82 .23184 L
.824 .2319 L
.828 .23195 L
.832 .23197 L
.836 .23193 L
.84 .23176 L
.844 .23143 L
.848 .23095 L
.852 .2304 L
.856 .22996 L
.86 .22993 L
.864 .23071 L
.868 .2328 L
.872 .23675 L
.876 .24306 L
.88 .25212 L
.884 .26413 L
.888 .27901 L
.892 .29643 L
.896 .31574 L
.9 .33606 L
.904 .35632 L
.908 .37541 L
.912 .39224 L
.916 .40586 L
.92 .41555 L
.924 .42087 L
.928 .42171 L
.932 .41823 L
.936 .41085 L
.94 .40021 L
.944 .38706 L
.948 .3722 L
.952 .35643 L
.956 .34047 L
.96 .32495 L
.964 .31036 L
.968 .29706 L
.972 .28528 L
.976 .27515 L
.98 .26672 L
.984 .25993 L
.988 .2548 L
.992 .25114 L
.996 .24905 L
1 .24826 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol20002Ool01@00Oomoogoo0000
17oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol0
0Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000Woo0P000goo00D007ooOomoo`0000Ao
o`03001oogoo00Yoo`0077oo0P002goo00<007ooOol0Bgoo00<007ooOol027oo0P003Goo000LOol0
0`00Ool0000:Ool00`00Oomoo`1;Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool001aoo`<000Uoo`03
001oogoo04eoo`03001oogoo00Ioo`03001oogoo00eoo`0077oo00@007ooOol000Qoo`03001oogoo
04eoo`03001oogoo00Ioo`03001oogoo00eoo`002goo0P0017oo00@007ooOomoo`D0009oo`800003
Ool007oo00Moo`03001oogoo04eoo`03001oogoo00Ioo`03001oogoo00eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01@00Oomoogoo00001Woo00<007ooOol0CWoo00<007ooOol01Goo00<0
07ooOol03Woo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P000Woo00<007ooOol017oo00<0
07ooOol0CWoo00<007ooOol01Goo00<007ooOol03Woo000:Ool01000Oomoo`002Woo00D007ooOomo
o`0000=oo`03001oogoo00Aoo`03001oogoo04moo`03001oogoo00Aoo`03001oogoo00ioo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool20002Ool00`00Oomoo`04Ool00`00Oomoo`1?Ool0
0`00Oomoo`03Ool00`00Oomoo`0?Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol0Cgoo00<007ooOol00goo00<007ooOol03goo000;
Ool20009Ool30003Ool20003Ool00`00Oomoo`03Ool00`00Oomoo`1?Ool00`00Oomoo`03Ool00`00
Oomoo`0?Ool001aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo055oo`03001oogoo009o
o`03001oogoo00moo`002goo0P0017oo00<007ooOol00goo0`000Woo0P000goo00<007ooOol00Woo
00<007ooOol0DGoo00<007ooOol00Woo00<007ooOol03goo000:Ool01000Oomoo`002Woo00D007oo
Oomoo`0000Eoo`05001oogooOol0001COol01@00Oomoogoo00004Woo000:Ool01000Oomoo`001goo
1@000Woo0P0017oo00D007ooOomoo`0005=oo`05001oogooOol0000BOol000Yoo`04001oogoo0007
Ool01000Oomoo`000goo00<007ooOol00goo00@007ooOol005Aoo`05001oogooOol0000BOol000Yo
o`04001oogoo0008Ool00`00Ool00003Ool20004Ool01000Oomoo`00EGoo00<007oo00004goo000:
Ool01000Oomoo`002Goo0P000goo00<007ooOol017oo0P00EWoo00<007oo00004goo000;Ool2000;
Ool01000Oomoogoo0P001Goo0P00Egoo0P004goo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03
001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo
000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2
001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomo
o`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00
Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol0
01Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00N7oo
000:Ool01000Oomoo`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007ooOol000Moo`05
001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`8007=oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool40003Ool2001c
Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008
Ool00`00Oomoo`03Ool2001cOol000]oo`8000Yoo`8000=oo`03001oogoo079oo`0077oo0P001Goo
0P00K7oo000LOol00`00Oomoo`04Ool00`00Ool0001[Ool000]oo`8000Aoo`03001oogoo00=oo`<0
009oo`8000Aoo`04001oogoo001[Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00001Goo00@0
07ooOol006]oo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo00=oo`04001oogoo
001[Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P0017oo00D007ooOomoo`0006Yoo`00
2Woo00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo00=oo`05001oogooOol0001ZOol000Yo
o`04001oogoo0009Ool20003Ool20004Ool01@00Oomoogoo0000JWoo000;Ool2000;Ool01@00Oomo
ogoo000017oo00<007ooOol00Woo00<007ooOol0J7oo000LOol20003Ool00`00Oomoo`02Ool00`00
Oomoo`1XOol001aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo06Moo`002goo0P0017oo
00@007ooOomoo`D0009oo`80009oo`03001oogoo00Aoo`03001oogoo06Moo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01@00Oomoogoo00001Woo00<007ooOol0Igoo0003Ool50002Ool01000
Oomoo`002Goo00<007ooOol00Woo00D007ooOomoo`0000Ioo`03001oogoo06Moo`002Woo00@007oo
Ool000Yoo`04001oogooOol20002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool30004Ool20009Ool3
0004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool3
0004Ool20006Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000Io
o`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=o
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@0
07ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool20000
0goo001oo`06Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
17oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00goo000;Ool20009Ool30003Ool01000Oomoo`0027oo00<007ooOol017oo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00
77oo0`002Goo00<007ooOol010000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool0
01aoo`03001oo`0000Uoo`04001oogoo0006Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009o
o`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo
000LOol2000;Ool00`00Ool000040003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000
Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2
000;Ool00`00Oomoo`1UOol001aoo`03001oogoo00Yoo`03001oogoo06Eoo`0077ooJ@0037oo000L
Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`04
Ool2000;Ool2000<Ool001aoo`8005Uoo`03001oogoo00Qoo`03001oogoo00aoo`0077oo00<007oo
Ool0F7oo00<007ooOol027oo00<007ooOol037oo000LOol2001JOol00`00Oomoo`06Ool00`00Oomo
o`0=Ool001aoo`03001oogoo05Uoo`03001oogoo00Ioo`03001oogoo00eoo`0077oo00<007ooOol0
FGoo00<007ooOol01Woo00<007ooOol03Goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00FWoo
00<007ooOol01Woo00<007ooOol03Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001o
ogoo05Uoo`03001oogoo00Eoo`03001oogoo00ioo`002Woo00@007ooOol000Uoo`03001oogoo009o
o`8005Yoo`03001oogoo00Eoo`03001oogoo00ioo`002Woo00@007ooOol000Yoo`05001oogooOol0
001LOol00`00Oomoo`04Ool00`00Oomoo`0>Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P00Fgoo00<007ooOol00goo00<007ooOol03goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo05Yoo`03001oogoo00=oo`03001oogoo00moo`002goo0P002Goo0`000goo
00<007ooOol0FWoo00<007ooOol00goo00<007ooOol03goo000LOol2001KOol00`00Oomoo`03Ool0
0`00Oomoo`0?Ool001aoo`03001oogoo05]oo`03001oogoo009oo`03001oogoo00moo`002goo0P00
17oo00<007ooOol00goo0`000Woo0P00G7oo00<007ooOol00Woo00<007ooOol03goo000:Ool01000
Oomoo`002Woo00D007ooOomoo`0005eoo`05001oogooOol0000BOol000Yoo`04001oogoo0007Ool5
0002Ool2001LOol01@00Oomoogoo00004Woo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03
001oogoo05]oo`05001oogooOol0000BOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001L
Ool01@00Oomoogoo00004Woo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0G7oo00<007oo
00004goo000;Ool2000;Ool01@00Oomoogoo0000GWoo00<007oo00004goo000LOol2001MOol3000C
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo
079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2
001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:
Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol000Moo`D0009o
o`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1b
Ool000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00@0
07ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0=
Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004
Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02
Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo00@007ooOol0
009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool20009
Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04
001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000L
Ool00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo
1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2001cOol0
01aoo`03001oogoo079oo`0077ooJ@0037oo000LOol20002Ool01@00Oomoogoo000017oo0P000Woo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogoo
Ool00003Ool01@00Oomoogoo00000Woo0P000goo00D007ooOomoo`0000Aoo`03001oogoo00Yoo`00
77oo0P002goo00<007ooOol0Bgoo00<007ooOol02Goo0P0037oo000LOol00`00Ool0000:Ool00`00
Oomoo`1;Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool001aoo`<000Uoo`03001oogoo04eoo`03001o
ogoo00Ioo`03001oogoo00eoo`0077oo00@007ooOol000Qoo`03001oogoo04eoo`03001oogoo00Io
o`03001oogoo00eoo`002goo0P0017oo00@007ooOomoo`D0009oo`800003Ool007oo00Moo`03001o
ogoo04eoo`03001oogoo00Ioo`03001oogoo00eoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01@00Oomoogoo00001Woo00<007ooOol0CWoo00<007ooOol01Goo00<007ooOol03Woo000:Ool0
1000Oomoo`002Goo00<007ooOol00Woo0P000Woo00<007ooOol017oo00<007ooOol0CWoo00<007oo
Ool01Goo00<007ooOol03Woo000:Ool01000Oomoo`002Woo00D007ooOomoo`0000=oo`03001oogoo
00Aoo`03001oogoo04moo`03001oogoo00Aoo`03001oogoo00ioo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool20002Ool00`00Oomoo`04Ool00`00Oomoo`1?Ool00`00Oomoo`03Ool00`00
Oomoo`0?Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000Ioo`03
001oogoo04moo`03001oogoo00=oo`03001oogoo00moo`002goo0P002Goo0`000goo0P000goo00<0
07ooOol00goo00<007ooOol0Cgoo00<007ooOol00goo00<007ooOol03goo000LOol00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`1AOol00`00Oomoo`02Ool00`00Oomoo`0?Ool000]oo`8000Ao
o`03001oogoo00=oo`<0009oo`8000=oo`03001oogoo009oo`03001oogoo055oo`03001oogoo009o
o`03001oogoo00moo`002Woo00@007ooOol000Yoo`05001oogooOol00005Ool01@00Oomoogoo0000
Dgoo00D007ooOomoo`00019oo`002Woo00@007ooOol000Moo`D0009oo`8000Aoo`05001oogooOol0
001COol01@00Oomoogoo00004Woo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo
00=oo`04001oogoo001DOol01@00Oomoogoo00004Woo000:Ool01000Oomoo`0027oo00<007oo0000
0goo0P0017oo00@007ooOol005Eoo`03001oo`0001=oo`002Woo00@007ooOol000Uoo`8000=oo`03
001oogoo00Aoo`8005Ioo`03001oo`0001=oo`002goo0P002goo00@007ooOomoo`8000Eoo`8005Mo
o`8001=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001o
ogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol0
00]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo
000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol0
01Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00
Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1440\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .24917 m
.008 .25865 L
.012 .26909 L
.016 .28082 L
.02 .29373 L
.024 .3079 L
.028 .32308 L
.032 .33903 L
.036 .35527 L
.04 .37125 L
.044 .38625 L
.048 .39954 L
.052 .41031 L
.056 .41782 L
.06 .42146 L
.064 .4208 L
.068 .41565 L
.072 .40613 L
.076 .39266 L
.08 .37595 L
.084 .35691 L
.088 .33665 L
.092 .31628 L
.096 .29686 L
.1 .27931 L
.104 .26427 L
.108 .25212 L
.112 .24293 L
.116 .23654 L
.12 .23254 L
.124 .23044 L
.128 .22969 L
.132 .22978 L
.136 .23028 L
.14 .23088 L
.144 .23141 L
.148 .23176 L
.152 .23195 L
.156 .232 L
.16 .23197 L
.164 .23191 L
.168 .23185 L
.172 .23181 L
.176 .23179 L
.18 .23179 L
.184 .2318 L
.188 .23181 L
.192 .23181 L
.196 .23182 L
.2 .23182 L
Mistroke
.204 .23182 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23182 L
.8 .23182 L
Mistroke
.804 .23182 L
.808 .23181 L
.812 .23181 L
.816 .2318 L
.82 .23179 L
.824 .23179 L
.828 .23181 L
.832 .23185 L
.836 .23191 L
.84 .23197 L
.844 .232 L
.848 .23195 L
.852 .23176 L
.856 .23141 L
.86 .23088 L
.864 .23028 L
.868 .22978 L
.872 .22969 L
.876 .23044 L
.88 .23254 L
.884 .23654 L
.888 .24293 L
.892 .25212 L
.896 .26427 L
.9 .27931 L
.904 .29686 L
.908 .31628 L
.912 .33665 L
.916 .35692 L
.92 .37595 L
.924 .39268 L
.928 .40616 L
.932 .41569 L
.936 .42086 L
.94 .42156 L
.944 .41796 L
.948 .41052 L
.952 .39986 L
.956 .38674 L
.96 .37196 L
.964 .35632 L
.968 .34054 L
.972 .32525 L
.976 .31093 L
.98 .29798 L
.984 .28659 L
.988 .27696 L
.992 .26907 L
.996 .26297 L
1 .25851 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29098 m
.008 .2893 L
.012 .28464 L
.016 .27675 L
.02 .26614 L
.024 .25286 L
.028 .23752 L
.032 .22052 L
.036 .20265 L
.04 .18467 L
.044 .16754 L
.048 .15224 L
.052 .13977 L
.056 .13107 L
.06 .1269 L
.064 .1278 L
.068 .13401 L
.072 .1454 L
.076 .16148 L
.08 .18142 L
.084 .2041 L
.088 .22826 L
.092 .25253 L
.096 .27566 L
.1 .29658 L
.104 .3145 L
.108 .32897 L
.112 .33991 L
.116 .34753 L
.12 .35229 L
.124 .3548 L
.128 .35569 L
.132 .35559 L
.136 .35499 L
.14 .35427 L
.144 .35365 L
.148 .35322 L
.152 .353 L
.156 .35294 L
.16 .35298 L
.164 .35305 L
.168 .35312 L
.172 .35317 L
.176 .35319 L
.18 .35319 L
.184 .35318 L
.188 .35317 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35317 L
Mistroke
.804 .35317 L
.808 .35316 L
.812 .35316 L
.816 .35315 L
.82 .35314 L
.824 .35314 L
.828 .35316 L
.832 .3532 L
.836 .35327 L
.84 .35335 L
.844 .35338 L
.848 .35332 L
.852 .3531 L
.856 .35268 L
.86 .35205 L
.864 .35133 L
.868 .35074 L
.872 .35063 L
.876 .35153 L
.88 .35403 L
.884 .35879 L
.888 .36641 L
.892 .37735 L
.896 .39182 L
.9 .40974 L
.904 .43066 L
.908 .45379 L
.912 .47806 L
.916 .5022 L
.92 .52488 L
.924 .5448 L
.928 .56084 L
.932 .57218 L
.936 .57832 L
.94 .57911 L
.944 .57476 L
.948 .56579 L
.952 .55293 L
.956 .53706 L
.96 .51909 L
.964 .49995 L
.968 .48039 L
.972 .46113 L
.976 .44259 L
.98 .42517 L
.984 .40886 L
.988 .39381 L
.992 .37961 L
.996 .3663 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .24532 L
.012 .25899 L
.016 .27331 L
.02 .28818 L
.024 .30389 L
.028 .32019 L
.032 .337 L
.036 .35384 L
.04 .37027 L
.044 .38559 L
.048 .39909 L
.052 .41001 L
.056 .41763 L
.06 .42134 L
.064 .42072 L
.068 .4156 L
.072 .4061 L
.076 .39264 L
.08 .37593 L
.084 .35691 L
.088 .33664 L
.092 .31627 L
.096 .29686 L
.1 .2793 L
.104 .26427 L
.108 .25212 L
.112 .24293 L
.116 .23654 L
.12 .23254 L
.124 .23044 L
.128 .22969 L
.132 .22978 L
.136 .23028 L
.14 .23088 L
.144 .23141 L
.148 .23176 L
.152 .23195 L
.156 .232 L
.16 .23197 L
.164 .23191 L
.168 .23185 L
.172 .23181 L
.176 .23179 L
.18 .23179 L
.184 .2318 L
.188 .23181 L
.192 .23181 L
.196 .23182 L
.2 .23182 L
Mistroke
.204 .23182 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23182 L
.8 .23182 L
Mistroke
.804 .23182 L
.808 .23181 L
.812 .23181 L
.816 .2318 L
.82 .23179 L
.824 .23179 L
.828 .23181 L
.832 .23185 L
.836 .23191 L
.84 .23197 L
.844 .232 L
.848 .23195 L
.852 .23176 L
.856 .23141 L
.86 .23088 L
.864 .23028 L
.868 .22978 L
.872 .22969 L
.876 .23044 L
.88 .23254 L
.884 .23654 L
.888 .24293 L
.892 .25212 L
.896 .26427 L
.9 .27931 L
.904 .29686 L
.908 .31628 L
.912 .33665 L
.916 .35692 L
.92 .37596 L
.924 .39269 L
.928 .40617 L
.932 .41571 L
.936 .42089 L
.94 .42161 L
.944 .41805 L
.948 .41065 L
.952 .40006 L
.956 .38704 L
.96 .37241 L
.964 .35699 L
.968 .34151 L
.972 .32667 L
.976 .31296 L
.98 .30086 L
.984 .29059 L
.988 .28252 L
.992 .27657 L
.996 .27309 L
1 .27182 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00@0
07ooOomoo`8000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Ao
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`80009oo`05001oogooOol00004Ool0
0`00Oomoo`0:Ool001aoo`8000Uoo`03001oogoo04ioo`03001oogoo01Ioo`0077oo0P002Goo00<0
07ooOol0CWoo00<007ooOol027oo0P0037oo000LOol20009Ool00`00Oomoo`1?Ool00`00Oomoo`07
Ool00`00Oomoo`0;Ool001aoo`03001oo`0000Qoo`03001oogoo04moo`03001oogoo00Ioo`03001o
ogoo00aoo`002goo0P0017oo00@007ooOomoo`D0009oo`<000Qoo`03001oogoo04moo`03001oogoo
00Ioo`03001oogoo00aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Ool00007Ool0
0`00Oomoo`1AOol00`00Oomoo`04Ool00`00Oomoo`0=Ool000Yoo`04001oogoo0009Ool00`00Oomo
o`02Ool200000goo001oo`05Ool00`00Oomoo`1AOol00`00Oomoo`04Ool00`00Oomoo`0=Ool000Yo
o`04001oogoo000:Ool01@00Oomoogoo00000Woo00<007ooOol017oo00<007ooOol0DGoo00<007oo
Ool017oo00<007ooOol03Goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`800003Ool0
07oo00Eoo`03001oogoo055oo`03001oogoo00Aoo`03001oogoo00eoo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool01@00Oomoogoo000017oo00<007ooOol0DWoo00<007ooOol017oo00<0
07ooOol03Goo000;Ool20009Ool30003Ool20002Ool00`00Oomoo`02Ool00`00Oomoo`1BOol00`00
Oomoo`03Ool00`00Oomoo`0>Ool001aoo`05001oogooOol00004Ool00`00Oomoo`1COol00`00Oomo
o`02Ool00`00Oomoo`0>Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`80009oo`03001oogoo
009oo`03001oogoo05=oo`03001oogoo009oo`03001oogoo00ioo`002Woo00@007ooOol000Yoo`05
001oogooOol00003Ool01@00Oomoogoo0000EWoo00D007ooOomoo`00015oo`002Woo00@007ooOol0
00Moo`D0009oo`8000=oo`04001oogoo001FOol01@00Oomoogoo00004Goo000:Ool01000Oomoo`00
1goo00@007ooOol000=oo`03001oogoo009oo`04001oogoo001GOol01000Oomoo`004Goo000:Ool0
1000Oomoo`0027oo00<007oo00000goo0P000goo00@007ooOol005Moo`04001oogoo000AOol000Yo
o`04001oogoo0009Ool20003Ool00`00Oomoo`03Ool2001IOol2000BOol000]oo`8000]oo`04001o
ogooOol20004Ool2001IOol2000BOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol0
0Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool4
0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04
001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`00
77oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`00
5Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009o
o`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<0
07ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3001hOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P00Lgoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`@000=oo`8007=oo`002Woo
00@007ooOol000Moo`03001oogoo00Aoo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001o
ogoo00=oo`8007=oo`002goo0P002Woo0P000goo00<007ooOol0LWoo000LOol20004Ool2001]Ool0
01aoo`03001oogoo00=oo`03001oo`0006aoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00
0goo00@007ooOol006aoo`002Woo00@007ooOol000Yoo`05001oogooOol00004Ool01000Oomoo`00
K7oo0003Ool50002Ool01000Oomoo`001goo1@000Woo00<007ooOol00Woo00@007ooOol006aoo`00
2Woo00@007ooOol000Moo`04001oogoo0003Ool20002Ool01@00Oomoogoo0000K7oo000:Ool01000
Oomoo`0027oo00<007oo00000goo00D007ooOomoo`0000=oo`03001oogoo06Yoo`002Woo00@007oo
Ool000Uoo`8000=oo`80009oo`03001oogoo009oo`03001oogoo06Uoo`002goo0P002goo00D007oo
Oomoo`0000=oo`03001oogoo009oo`03001oogoo06Uoo`0077oo0P000Woo00<007ooOol00Woo00<0
07ooOol0JGoo000LOol01@00Oomoogoo000017oo00<007ooOol0JGoo000;Ool20004Ool01000Oomo
ogoo1@000Woo0P0000=oo`00Ool017oo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`04001oogoo0006Ool00`00Oomoo`1XOol000=oo`D0009oo`04001oogoo0009Ool00`00
Oomoo`02Ool01000Oomoo`001Woo00<007ooOol0J7oo000:Ool01000Oomoo`002Woo00@007ooOomo
o`<000Moo`03001oogoo00=oo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Ao
o`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Ool00007Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@0
07ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`00
00=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P0027oo00<007ooOol01Woo00@007ooOol0009oo`03001o
ogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Goo0`000goo00<007oo
Ool027oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0
009oo`03001oogoo00=oo`0077oo0P002Goo00@007ooOomoo`@000=oo`04001oogoo0009Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool4
0003Ool01000Oomoo`001Goo000LOol00`00Oomoo`08Ool01@00Oomoogoo00001Woo00@007ooOol0
00Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol0
07oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol027oo00@007ooOomoo`D000=oo`8000Yo
o`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool2
0006Ool30002Ool50003Ool20006Ool001aoo`8000Uoo`03001oogoo06Moo`0077oo00<007ooOol0
2Goo00<007ooOol0IWoo000LOomY000<Ool001aoo`03001oogoo019oo`03001oogoo019oo`03001o
ogoo015oo`03001oogoo019oo`03001oogoo00Ioo`03001oogoo00Qoo`8000aoo`0077oo0P00FWoo
00<007ooOol027oo00<007ooOol02goo000LOol00`00Oomoo`1IOol00`00Oomoo`08Ool00`00Oomo
o`0;Ool001aoo`8005]oo`03001oogoo00Ioo`03001oogoo00aoo`0077oo00<007ooOol0FWoo00<0
07ooOol01Woo00<007ooOol037oo000LOol00`00Oomoo`1JOol00`00Oomoo`06Ool00`00Oomoo`0<
Ool000]oo`8000Aoo`04001oogooOol50002Ool2001KOol00`00Oomoo`05Ool00`00Oomoo`0=Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0Fgoo00<007ooOol017oo00<007oo
Ool03Goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00G7oo00<007ooOol017oo00<007oo
Ool03Goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0005eoo`03001oogoo00Aoo`03001oogoo
00eoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001LOol00`00Oomoo`04Ool00`00
Oomoo`0=Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0Fgoo00<007oo
Ool017oo00<007ooOol03Goo000;Ool20009Ool30003Ool00`00Oomoo`1KOol00`00Oomoo`03Ool0
0`00Oomoo`0>Ool001aoo`8005aoo`03001oogoo00=oo`03001oogoo00ioo`0077oo00<007ooOol0
G7oo00<007ooOol00Woo00<007ooOol03Woo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001M
Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000GWoo
00D007ooOomoo`00015oo`002Woo00@007ooOol000Moo`D0009oo`8005eoo`05001oogooOol0000A
Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0G7oo00D007ooOomoo`00015o
o`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8005ioo`04001oogoo000AOol000Yoo`04001o
ogoo0009Ool20003Ool00`00Oomoo`1MOol01000Oomoo`004Goo000;Ool2000;Ool01@00Oomoogoo
0000Ggoo00<007oo00004Woo000LOol2001OOol2000BOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`00
07Aoo`000goo1@000Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04
001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol0
00Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001c
Ool001aoo`03001oogoo079oo`002goo0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool2
0005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool0
00=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@0
07ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`00
00=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001o
ogoo000:Ool01@00Oomoogoo00004Woo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol0
1000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001o
ogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000
Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomo
o`00Ool40003Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool0
1000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04
Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L0
07ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool0
0`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P00
1Woo0`000Woo1@000goo0P001Woo000LOol2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo
000LOol20002Ool01@00Oomoogoo00000goo0P000goo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo0P00
0Woo00D007ooOomoo`0000Aoo`03001oogoo00Yoo`0077oo0P002Woo00<007ooOol0CGoo00<007oo
Ool05Woo000LOol20009Ool00`00Oomoo`1>Ool00`00Oomoo`0FOol001aoo`8000Uoo`03001oogoo
04moo`03001oogoo01Eoo`0077oo00<007oo000027oo00<007ooOol0Cgoo00<007ooOol01goo0P00
37oo000;Ool20004Ool01000Oomoogoo1@000Woo0`0027oo00<007ooOol0Cgoo00<007ooOol01Woo
00<007ooOol037oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oo`0000Moo`03001o
ogoo055oo`03001oogoo00Eoo`03001oogoo00aoo`002Woo00@007ooOol000Uoo`03001oogoo009o
o`800003Ool007oo00Eoo`03001oogoo055oo`03001oogoo00Aoo`03001oogoo00eoo`002Woo00@0
07ooOol000Yoo`05001oogooOol00002Ool00`00Oomoo`04Ool00`00Oomoo`1AOol00`00Oomoo`04
Ool00`00Oomoo`0=Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P0000=oo`00Ool0
1Goo00<007ooOol0DGoo00<007ooOol017oo00<007ooOol03Goo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`05001oogooOol00004Ool00`00Oomoo`1BOol00`00Oomoo`04Ool00`00Oomo
o`0=Ool000]oo`8000Uoo`<000=oo`80009oo`03001oogoo009oo`03001oogoo059oo`03001oogoo
00=oo`03001oogoo00ioo`0077oo00D007ooOomoo`0000Aoo`03001oogoo05=oo`03001oogoo009o
o`03001oogoo00ioo`002goo0P0017oo00<007ooOol00goo0`000Woo0P000Woo00<007ooOol00Woo
00<007ooOol0Dgoo00<007ooOol00Woo00<007ooOol03Woo000:Ool01000Oomoo`002Woo00D007oo
Oomoo`0000=oo`05001oogooOol0001FOol01@00Oomoogoo00004Goo000:Ool01000Oomoo`001goo
1@000Woo0P000goo00@007ooOol005Ioo`05001oogooOol0000AOol000Yoo`04001oogoo0007Ool0
1000Oomoo`000goo00<007ooOol00Woo00@007ooOol005Moo`04001oogoo000AOol000Yoo`04001o
ogoo0008Ool00`00Ool00003Ool20003Ool01000Oomoo`00Egoo00@007ooOol0015oo`002Woo00@0
07ooOol000Uoo`8000=oo`03001oogoo00=oo`8005Uoo`80019oo`002goo0P002goo00@007ooOomo
o`8000Aoo`8005Uoo`80019oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool3
0003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007oo
Ool000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol0
0`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol3
0003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00
Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomo
o`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1480\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .26695 m
.008 .28228 L
.012 .29855 L
.016 .31559 L
.02 .33302 L
.024 .35055 L
.028 .36752 L
.032 .38337 L
.036 .39729 L
.04 .40862 L
.044 .41658 L
.048 .42062 L
.052 .4203 L
.056 .41546 L
.06 .4062 L
.064 .39295 L
.068 .37638 L
.072 .35744 L
.076 .3372 L
.08 .31679 L
.084 .29729 L
.088 .2796 L
.092 .26441 L
.096 .25211 L
.1 .24281 L
.104 .23632 L
.108 .23228 L
.112 .23017 L
.116 .22945 L
.12 .22959 L
.124 .23015 L
.128 .23081 L
.132 .23138 L
.136 .23177 L
.14 .23197 L
.144 .23203 L
.148 .23199 L
.152 .23192 L
.156 .23185 L
.16 .23181 L
.164 .23179 L
.168 .23179 L
.172 .2318 L
.176 .23181 L
.18 .23181 L
.184 .23182 L
.188 .23182 L
.192 .23182 L
.196 .23181 L
.2 .23181 L
Mistroke
.204 .23181 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23182 L
.812 .23182 L
.816 .23182 L
.82 .23181 L
.824 .23181 L
.828 .2318 L
.832 .23179 L
.836 .23179 L
.84 .23181 L
.844 .23185 L
.848 .23192 L
.852 .23199 L
.856 .23203 L
.86 .23197 L
.864 .23177 L
.868 .23138 L
.872 .23081 L
.876 .23015 L
.88 .22959 L
.884 .22945 L
.888 .23017 L
.892 .23228 L
.896 .23632 L
.9 .24281 L
.904 .25212 L
.908 .26442 L
.912 .27961 L
.916 .29731 L
.92 .31683 L
.924 .33726 L
.928 .35754 L
.932 .37653 L
.936 .39317 L
.94 .40654 L
.944 .41596 L
.948 .42104 L
.952 .42169 L
.956 .41813 L
.96 .4108 L
.964 .40038 L
.968 .38762 L
.972 .37337 L
.976 .35842 L
.98 .34355 L
.984 .32938 L
.988 .31646 L
.992 .30514 L
.996 .29573 L
1 .28832 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .22739 m
.008 .22562 L
.012 .22032 L
.016 .21175 L
.02 .20062 L
.024 .18746 L
.028 .17339 L
.032 .15924 L
.036 .1463 L
.04 .13554 L
.044 .12809 L
.048 .12475 L
.052 .12621 L
.056 .13273 L
.06 .1443 L
.064 .16046 L
.068 .18044 L
.072 .20318 L
.076 .22741 L
.08 .25179 L
.084 .27508 L
.088 .29618 L
.092 .3143 L
.096 .32896 L
.1 .34005 L
.104 .34779 L
.108 .3526 L
.112 .35512 L
.116 .35598 L
.12 .35581 L
.124 .35515 L
.128 .35435 L
.132 .35367 L
.136 .35321 L
.14 .35297 L
.144 .35291 L
.148 .35295 L
.152 .35303 L
.156 .35311 L
.16 .35317 L
.164 .35319 L
.168 .35319 L
.172 .35318 L
.176 .35317 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35317 L
.812 .35317 L
.816 .35317 L
.82 .35316 L
.824 .35315 L
.828 .35314 L
.832 .35313 L
.836 .35313 L
.84 .35316 L
.844 .35321 L
.848 .35329 L
.852 .35337 L
.856 .35342 L
.86 .35335 L
.864 .35311 L
.868 .35265 L
.872 .35197 L
.876 .35118 L
.88 .35051 L
.884 .35035 L
.888 .35121 L
.892 .35372 L
.896 .35853 L
.9 .36626 L
.904 .37735 L
.908 .392 L
.912 .41009 L
.916 .43116 L
.92 .4544 L
.924 .47871 L
.928 .50281 L
.932 .52537 L
.936 .54508 L
.94 .56085 L
.944 .57182 L
.948 .57751 L
.952 .57776 L
.956 .57277 L
.96 .56297 L
.964 .54909 L
.968 .53185 L
.972 .51216 L
.976 .49069 L
.98 .46827 L
.984 .44522 L
.988 .42215 L
.992 .399 L
.996 .37608 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .25402 L
.012 .27618 L
.016 .29817 L
.02 .31962 L
.024 .34042 L
.028 .35993 L
.032 .37779 L
.036 .39323 L
.04 .40571 L
.044 .41452 L
.048 .41918 L
.052 .4193 L
.056 .41478 L
.06 .40574 L
.064 .39264 L
.068 .37618 L
.072 .35731 L
.076 .33712 L
.08 .31674 L
.084 .29725 L
.088 .27958 L
.092 .2644 L
.096 .25211 L
.1 .2428 L
.104 .23632 L
.108 .23228 L
.112 .23017 L
.116 .22945 L
.12 .22959 L
.124 .23015 L
.128 .23081 L
.132 .23138 L
.136 .23177 L
.14 .23197 L
.144 .23203 L
.148 .23199 L
.152 .23192 L
.156 .23185 L
.16 .23181 L
.164 .23179 L
.168 .23179 L
.172 .2318 L
.176 .23181 L
.18 .23181 L
.184 .23182 L
.188 .23182 L
.192 .23182 L
.196 .23181 L
.2 .23181 L
Mistroke
.204 .23181 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23182 L
.812 .23182 L
.816 .23182 L
.82 .23181 L
.824 .23181 L
.828 .2318 L
.832 .23179 L
.836 .23179 L
.84 .23181 L
.844 .23185 L
.848 .23192 L
.852 .23199 L
.856 .23203 L
.86 .23197 L
.864 .23177 L
.868 .23138 L
.872 .23081 L
.876 .23015 L
.88 .22959 L
.884 .22945 L
.888 .23017 L
.892 .23228 L
.896 .23632 L
.9 .24281 L
.904 .25212 L
.908 .26442 L
.912 .27962 L
.916 .29732 L
.92 .31685 L
.924 .3373 L
.928 .35759 L
.932 .37661 L
.936 .3933 L
.94 .40674 L
.944 .41626 L
.948 .4215 L
.952 .42237 L
.956 .41913 L
.96 .41224 L
.964 .40245 L
.968 .39052 L
.972 .37744 L
.976 .36399 L
.98 .35114 L
.984 .33949 L
.988 .32987 L
.992 .32255 L
.996 .31811 L
1 .31657 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00H0
07ooOol007oo0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Ool007oo00000goo00<007oo
Ool00Woo00<007ooOol02Woo000LOol20008Ool00`00Oomoo`1AOol00`00Oomoo`0DOol001aoo`03
001oogoo00Moo`03001oogoo055oo`03001oogoo01Aoo`0077oo0P0027oo00<007ooOol0DGoo00<0
07ooOol057oo000LOol20007Ool00`00Oomoo`1BOol00`00Oomoo`0DOol000]oo`8000Aoo`04001o
ogooOol50002Ool20007Ool00`00Oomoo`1BOol00`00Oomoo`07Ool00`00Oomoo`0:Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo0P001goo00<007ooOol0Dgoo00<007ooOol01Goo00<007oo
Ool02goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P001goo00<007ooOol0Dgoo00<007oo
Ool01Goo00<007ooOol02goo000:Ool01000Oomoo`002Woo00L007ooOomoo`00Ool00005Ool00`00
Oomoo`1DOol00`00Oomoo`04Ool00`00Oomoo`0<Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0`001Goo00<007ooOol0E7oo00<007ooOol017oo00<007ooOol037oo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oo`0000Eoo`03001oogoo05Eoo`03001oogoo00=oo`03
001oogoo00aoo`002goo0P002Goo0`000goo0`001Goo00<007ooOol0EGoo00<007ooOol00Woo00<0
07ooOol03Goo000LOol01000Oomoo`0017oo00<007ooOol0EGoo00<007ooOol00Woo00<007ooOol0
3Goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool200000goo001oo`03Ool00`00Oomoo`1EOol0
0`00Oomoo`02Ool00`00Oomoo`0=Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00000Woo00D0
07ooOomoo`0005Uoo`05001oogooOol0000?Ool000Yoo`04001oogoo0007Ool50002Ool20002Ool0
1000Oomoo`00FGoo00@007ooOol0011oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool01@00
Oomoogoo00000Woo00<007ooOol0Egoo00@007ooOol0011oo`002Woo00@007ooOol000Qoo`03001o
o`0000=oo`80009oo`03001oo`0005Yoo`04001oogoo000@Ool000Yoo`04001oogoo0009Ool20003
Ool01000Oomoogoo0`00Fgoo0P004Goo000;Ool2000;Ool01000Oomoogoo0P000goo0P00Fgoo0P00
4Goo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol0
0goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yo
o`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo
00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo
07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`002goo0P0017oo00<007ooOol00Woo0`00N7oo000:Ool01000Oomoo`001goo00D007ooOomo
o`0007Moo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04
001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002goo
0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P00
17oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool40003Ool2001cOol000Yoo`04001oogoo0007Ool00`00Oomo
o`04Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool2001cOol000]oo`80
00Yoo`8000=oo`03001oogoo009oo`8006ioo`0077oo0P000Woo0`00KWoo000LOol01`00Oomoogoo
001oo`0006ioo`002goo0P0017oo00<007ooOol00goo0`000Woo0P000Woo00<007oo0000KWoo000:
Ool01000Oomoo`002Woo00D007ooOomoo`0000=oo`04001oogoo001]Ool000=oo`D0009oo`04001o
ogoo0007Ool50002Ool01000Oomoo`000goo00<007ooOol0Jgoo000:Ool01000Oomoo`001goo00@0
07ooOol000=oo`800003Ool007oo009oo`03001oogoo06]oo`002Woo00@007ooOol000Qoo`03001o
o`0000=oo`04001oogoo0003Ool00`00Oomoo`1[Ool000Yoo`04001oogoo0009Ool20003Ool30005
Ool00`00Oomoo`1ZOol000]oo`8000]oo`07001oogooOol007oo00001Goo00<007ooOol0JWoo000L
Ool20006Ool00`00Oomoo`1ZOol001aoo`8000Ioo`03001oogoo06Yoo`002goo0P0017oo00@007oo
Oomoo`D0009oo`8000Ioo`03001oogoo06Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`1ZOol000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool0
0`00Oomoo`05Ool00`00Oomoo`1ZOol000Yoo`04001oogoo000:Ool01000Oomoogoo0P001goo00<0
07ooOol017oo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@00
0goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00Ioo`03001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007oo
Ool0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06
001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool20007Ool00`00Oomoo`07Ool01000Oomoo`000Woo00<007ooOol01goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool20009Ool30003Ool00`00Oomoo`06Ool00`00
Oomoo`07Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00
009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007oo
Ool00goo000LOol20007Ool00`00Oomoo`03Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@0
07ooOol000Eoo`0077oo00<007ooOol01goo00<007ooOol00Woo00<007ooOol017oo00@007ooOol0
00Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol0
07oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol01goo00<007ooOol00Woo1@000goo0P00
2Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Ao
o`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P0027oo00<007ooOol0J7oo000LOol00`00Oomo
o`08Ool00`00Oomoo`1WOol001aoofT000aoo`0077oo00<007ooOol04Woo00<007ooOol04Woo00<0
07ooOol04Goo00<007ooOol04Woo00<007ooOol01goo00<007ooOol027oo00<007ooOol02Woo000L
Ool2001LOol00`00Oomoo`06Ool00`00Oomoo`0;Ool001aoo`03001oogoo05]oo`03001oogoo00Io
o`03001oogoo00]oo`0077oo0P00G7oo00<007ooOol01Woo00<007ooOol02goo000LOol00`00Oomo
o`1KOol00`00Oomoo`06Ool00`00Oomoo`0;Ool001aoo`03001oogoo05]oo`03001oogoo00Ioo`03
001oogoo00]oo`002goo0P0017oo00@007ooOomoo`D0009oo`8005aoo`03001oogoo00Eoo`03001o
ogoo00aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1LOol00`00Oomoo`04
Ool00`00Oomoo`0<Ool000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001MOol00`00Oomoo`04
Ool00`00Oomoo`0<Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000GWoo00<007ooOol017oo
00<007ooOol037oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8005eoo`03001oogoo
00=oo`03001oogoo00eoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1M
Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool000]oo`8000Uoo`<000=oo`03001oogoo05eoo`03001o
ogoo009oo`03001oogoo00eoo`0077oo0P00GWoo00<007ooOol00Woo00<007ooOol03Goo000LOol0
0`00Oomoo`1MOol00`00Oomoo`02Ool00`00Oomoo`0=Ool000]oo`8000Aoo`03001oogoo00=oo`<0
009oo`8005ioo`03001oogoo009oo`03001oogoo00eoo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0001POol01@00Oomoogoo00003goo000:Ool01000Oomoo`001goo1@000Woo0P00Ggoo00@007oo
Ool0011oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1NOol01000Oomoo`00
47oo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Ggoo00@007ooOol0011oo`002Woo00@0
07ooOol000Uoo`8000=oo`03001oogoo05ioo`04001oogoo000@Ool000]oo`8000]oo`05001oogoo
Ool0001QOol2000AOol001aoo`80061oo`80015oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004
Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo
0003Ool50002Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007oo
Ool000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo
00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00@007ooOomoo`8007=oo`00
77oo00<007ooOol0LWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eo
o`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`000goo
1@000Woo00@007ooOol000Uoo`03001oogoo009oo`8000eoo`05001oogooOol00002Ool01000Oomo
o`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol0
00Yoo`05001oogooOol0000BOol01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04001o
ogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo10000goo00@007ooOol000Uoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo
0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001o
o`@000=oo`04001oogoo0005Ool000]oo`8000Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04001o
ogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomo
ogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`03001o
ogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool3
0002Ool50003Ool20006Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001ao
o`80009oo`05001oogooOol00002Ool00`00Ool00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool3
00000goo001oo`02Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`8000Uoo`03001oogoo04mo
o`03001oogoo01Eoo`0077oo0P0027oo00<007ooOol0DGoo00<007ooOol057oo000LOol20008Ool0
0`00Oomoo`1AOol00`00Oomoo`0DOol001aoo`8000Moo`03001oogoo059oo`03001oogoo01Aoo`00
2goo0P0017oo00@007ooOomoo`D0009oo`8000Moo`03001oogoo059oo`03001oogoo01Aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool00`00Ool00006Ool00`00Oomoo`1COol00`00Oomoo`0C
Ool000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool30006Ool00`00Oomoo`1COol00`00Oomoo`0C
Ool000Yoo`04001oogoo000:Ool01`00Oomoogoo001oo`0000Eoo`03001oogoo05Aoo`03001oogoo
00Eoo`8000aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool30005Ool00`00Oomoo`1D
Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007oo00001Goo00<007ooOol0EGoo00<007ooOol00goo00<007ooOol037oo000;Ool20009Ool3
0003Ool200000goo001oo`03Ool00`00Oomoo`1EOol00`00Oomoo`03Ool00`00Oomoo`0<Ool001ao
o`04001oogoo0004Ool00`00Oomoo`1EOol00`00Oomoo`02Ool00`00Oomoo`0=Ool000]oo`8000Ao
o`03001oogoo00=oo`<0009oo`800003Ool007oo00=oo`03001oogoo05Eoo`03001oogoo009oo`03
001oogoo00eoo`002Woo00@007ooOol000Yoo`05001oogooOol00002Ool01@00Oomoogoo0000FGoo
00D007ooOomoo`0000moo`002Woo00@007ooOol000Moo`D0009oo`80009oo`04001oogoo001IOol0
1@00Oomoogoo00003goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`05001oogooOol00002
Ool00`00Oomoo`1GOol01000Oomoo`0047oo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00
0Woo00<007oo0000FWoo00@007ooOol0011oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo
009oo`8005Yoo`03001oo`00015oo`002goo0P002goo00@007ooOomoo`8000=oo`8005]oo`80015o
o`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=o
o`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`80
00Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool0
1000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]o
o`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03
001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1g
Ool001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1520\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29336 m
.008 .31343 L
.012 .33375 L
.016 .35332 L
.02 .37159 L
.024 .38772 L
.028 .40095 L
.032 .41061 L
.036 .41605 L
.04 .41695 L
.044 .41309 L
.048 .40466 L
.052 .39203 L
.056 .37596 L
.06 .35736 L
.064 .33733 L
.068 .31701 L
.072 .29751 L
.076 .27976 L
.08 .26447 L
.084 .25206 L
.088 .24265 L
.092 .23608 L
.096 .232 L
.1 .22989 L
.104 .22919 L
.108 .22939 L
.112 .23001 L
.116 .23074 L
.12 .23136 L
.124 .23178 L
.128 .232 L
.132 .23206 L
.136 .23202 L
.14 .23194 L
.144 .23186 L
.148 .23181 L
.152 .23178 L
.156 .23178 L
.16 .23179 L
.164 .23181 L
.168 .23181 L
.172 .23182 L
.176 .23182 L
.18 .23182 L
.184 .23181 L
.188 .23181 L
.192 .23181 L
.196 .23181 L
.2 .23181 L
Mistroke
.204 .23181 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23182 L
.824 .23182 L
.828 .23182 L
.832 .23181 L
.836 .23181 L
.84 .23179 L
.844 .23178 L
.848 .23178 L
.852 .23181 L
.856 .23186 L
.86 .23194 L
.864 .23202 L
.868 .23206 L
.872 .232 L
.876 .23178 L
.88 .23136 L
.884 .23074 L
.888 .23001 L
.892 .22939 L
.896 .2292 L
.9 .2299 L
.904 .23202 L
.908 .23612 L
.912 .24271 L
.916 .25216 L
.92 .26462 L
.924 .27999 L
.928 .29786 L
.932 .31753 L
.936 .33808 L
.94 .35845 L
.944 .37752 L
.948 .39426 L
.952 .40776 L
.956 .4174 L
.96 .42282 L
.964 .42399 L
.968 .42115 L
.972 .41481 L
.976 .40564 L
.98 .39448 L
.984 .38212 L
.988 .36939 L
.992 .35704 L
.996 .34557 L
1 .33557 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13294 m
.008 .13217 L
.012 .12903 L
.016 .12458 L
.02 .11925 L
.024 .11403 L
.028 .11001 L
.032 .10809 L
.036 .10936 L
.04 .11439 L
.044 .12376 L
.048 .13745 L
.052 .15524 L
.056 .17643 L
.06 .20009 L
.064 .22502 L
.068 .25 L
.072 .27377 L
.076 .29529 L
.08 .31376 L
.084 .32872 L
.088 .34005 L
.092 .34794 L
.096 .35286 L
.1 .3554 L
.104 .35625 L
.108 .35603 L
.112 .3553 L
.116 .35444 L
.12 .3537 L
.124 .3532 L
.128 .35294 L
.132 .35287 L
.136 .35292 L
.14 .35302 L
.144 .35311 L
.148 .35317 L
.152 .3532 L
.156 .3532 L
.16 .35319 L
.164 .35317 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35317 L
.824 .35317 L
.828 .35317 L
.832 .35316 L
.836 .35315 L
.84 .35314 L
.844 .35313 L
.848 .35313 L
.852 .35315 L
.856 .35322 L
.86 .35331 L
.864 .35341 L
.868 .35345 L
.872 .35339 L
.876 .35312 L
.88 .35262 L
.884 .35188 L
.888 .35101 L
.892 .35027 L
.896 .35004 L
.9 .35087 L
.904 .35338 L
.908 .35824 L
.912 .36606 L
.916 .37726 L
.92 .39204 L
.924 .41023 L
.928 .43134 L
.932 .45452 L
.936 .47864 L
.94 .50237 L
.944 .52433 L
.948 .54319 L
.952 .55778 L
.956 .56724 L
.96 .57094 L
.964 .56871 L
.968 .56054 L
.972 .54691 L
.976 .52823 L
.98 .50536 L
.984 .4789 L
.988 .44976 L
.992 .41862 L
.996 .38609 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .26146 L
.012 .29068 L
.016 .31816 L
.02 .34332 L
.024 .36534 L
.028 .38347 L
.032 .39717 L
.036 .40585 L
.04 .40933 L
.044 .40746 L
.048 .40056 L
.052 .38908 L
.056 .37387 L
.06 .35589 L
.064 .33632 L
.068 .31632 L
.072 .29704 L
.076 .27945 L
.08 .26427 L
.084 .25193 L
.088 .24256 L
.092 .23603 L
.096 .23196 L
.1 .22987 L
.104 .22918 L
.108 .22938 L
.112 .23001 L
.116 .23073 L
.12 .23136 L
.124 .23178 L
.128 .232 L
.132 .23206 L
.136 .23202 L
.14 .23194 L
.144 .23186 L
.148 .23181 L
.152 .23178 L
.156 .23178 L
.16 .23179 L
.164 .23181 L
.168 .23181 L
.172 .23182 L
.176 .23182 L
.18 .23182 L
.184 .23181 L
.188 .23181 L
.192 .23181 L
.196 .23181 L
.2 .23181 L
Mistroke
.204 .23181 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23182 L
.824 .23182 L
.828 .23182 L
.832 .23181 L
.836 .23181 L
.84 .23179 L
.844 .23178 L
.848 .23178 L
.852 .23181 L
.856 .23186 L
.86 .23194 L
.864 .23202 L
.868 .23206 L
.872 .232 L
.876 .23178 L
.88 .23136 L
.884 .23074 L
.888 .23002 L
.892 .2294 L
.896 .22921 L
.9 .22991 L
.904 .23204 L
.908 .23614 L
.912 .24274 L
.916 .25221 L
.92 .26471 L
.924 .28013 L
.928 .29806 L
.932 .31784 L
.936 .33855 L
.94 .35914 L
.944 .37854 L
.948 .39573 L
.952 .40985 L
.956 .42035 L
.96 .42691 L
.964 .42962 L
.968 .42876 L
.972 .42501 L
.976 .41906 L
.98 .41195 L
.984 .40449 L
.988 .39767 L
.992 .39221 L
.996 .38864 L
1 .38758 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo0`00
0Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol0
0Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00P000goo00<007oo
Ool00Woo00<007ooOol02Woo000LOol20007Ool00`00Oomoo`1COol00`00Oomoo`0COol001aoo`03
001oogoo00Ioo`03001oogoo05=oo`03001oogoo01=oo`0077oo0P001Woo00<007ooOol0E7oo00<0
07ooOol04goo000LOol00`00Oomoo`05Ool00`00Oomoo`1EOol00`00Oomoo`0BOol000]oo`8000Ao
o`04001oogooOol50002Ool20006Ool00`00Oomoo`1EOol00`00Oomoo`0BOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo0P001Woo00<007ooOol0EGoo00<007ooOol04Woo000:Ool01000Oomo
o`002Goo00<007ooOol00Woo0P001Woo00<007ooOol0EGoo00<007ooOol04Woo000:Ool01000Oomo
o`002Woo00@007ooOomoo`8000Eoo`03001oogoo05Moo`03001oogoo015oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool20005Ool00`00Oomoo`1GOol00`00Oomoo`0AOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P001Goo00<007ooOol0Egoo00<007ooOol017oo00<007oo
Ool02Woo000;Ool20009Ool30003Ool20005Ool00`00Oomoo`1GOol00`00Oomoo`03Ool00`00Oomo
o`0;Ool001aoo`03001oo`0000=oo`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo00]oo`00
2goo0P0017oo00<007ooOol00goo0`000Woo0`000goo00<007ooOol0F7oo00<007ooOol00Woo00<0
07ooOol037oo000:Ool01000Oomoo`002Woo00L007ooOomoo`00Ool00003Ool00`00Oomoo`1IOol0
1@00Oomoogoo00003Woo000:Ool01000Oomoo`001goo1@000Woo0P0000Eoo`00Oomoo`0005]oo`05
001oogooOol0000>Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo00@007ooOol0009oo`03
001oogoo05Uoo`04001oogoo000?Ool000Yoo`04001oogoo0008Ool00`00Ool00003Ool2000017oo
001oo`00GGoo00<007oo00003goo000:Ool01000Oomoo`002Goo0P000goo00@007ooOomoo`8005eo
o`03001oo`0000moo`002goo0P002goo00@007ooOomoo`80065oo`80011oo`0077oo00<007ooOol0
LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
07=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03
001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`00
2goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009o
o`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`00
0goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`80
07=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001o
ogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo
07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03
001oogoo009oo`<007Qoo`002Woo00@007ooOol000Moo`05001oogooOol0001gOol000=oo`D0009o
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000]oo`8000Uoo`<000=oo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<0
00=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=o
o`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo10000goo0P00Lgoo000:Ool01000Oomoo`001goo00<007ooOol017oo00<007ooOol0LWoo
000:Ool01000Oomoo`0027oo00<007ooOol00goo0P0000=oo`000000L7oo000;Ool2000:Ool20003
Ool00`00Ool00002Ool00`00Oomoo`1]Ool001aoo`8000=oo`03001oogoo06eoo`0077oo00<007oo
Ool00Woo00<007ooOol0KGoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool20004Ool00`00Oomo
o`1/Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00001Goo00<007ooOol0K7oo0003Ool50002
Ool01000Oomoo`001goo1@000Woo00<007ooOol00goo00<007ooOol0K7oo000:Ool01000Oomoo`00
1goo00@007ooOol000=oo`8000Aoo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`03001oo`00
00=oo`03001oogoo00=oo`03001oogoo06aoo`002Woo00@007ooOol000Uoo`8000=oo`8000Aoo`03
001oogoo06aoo`002goo0P002goo00D007ooOomoo`0000Eoo`03001oogoo06aoo`0077oo0P001Goo
00<007ooOol0Jgoo000LOol00`00Oomoo`04Ool00`00Oomoo`1[Ool000]oo`8000Aoo`04001oogoo
Ool50002Ool20005Ool00`00Oomoo`1[Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<0
07ooOol017oo00<007ooOol0Jgoo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo00<0
07ooOol017oo00<007ooOol0Jgoo000:Ool01000Oomoo`002Woo00@007ooOomoo`8000Ioo`03001o
ogoo00Eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=o
o`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00
Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo0P001Woo00<007ooOol027oo00@007ooOol0009oo`03001oogoo00Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Goo0`000goo00<007ooOol01Goo00<007oo
Ool027oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002
Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo
00=oo`0077oo0P001Woo00<007ooOol017oo10000goo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001o
ogoo0005Ool001aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0008
Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo
0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001o
o`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00Ioo`03001oogoo00=oo`D000=oo`8000Yo
o`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool2
0006Ool30002Ool50003Ool20006Ool001aoo`8000Moo`03001oogoo06Uoo`0077oo00<007ooOol0
1Woo0P00JWoo000LOomY000<Ool001aoo`03001oogoo019oo`03001oogoo019oo`03001oogoo015o
o`03001oogoo019oo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Yoo`0077oo0P00GGoo
00<007ooOol01Goo00<007ooOol02goo000LOol00`00Oomoo`1LOol00`00Oomoo`05Ool00`00Oomo
o`0;Ool001aoo`8005eoo`03001oogoo00Eoo`03001oogoo00]oo`0077oo00<007ooOol0G7oo00<0
07ooOol01Goo00<007ooOol02goo000LOol00`00Oomoo`1MOol00`00Oomoo`04Ool00`00Oomoo`0;
Ool000]oo`8000Aoo`04001oogooOol50002Ool2001NOol00`00Oomoo`04Ool00`00Oomoo`0;Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0GGoo00<007ooOol017oo00<007oo
Ool02goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00GWoo00<007ooOol00goo00<007oo
Ool037oo000:Ool01000Oomoo`002Woo00D007ooOomoo`00061oo`03001oogoo009oo`03001oogoo
00aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001OOol00`00Oomoo`02Ool00`00
Oomoo`0<Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0GWoo00<007oo
Ool00Woo00<007ooOol037oo000;Ool20009Ool30003Ool00`00Oomoo`1NOol00`00Oomoo`02Ool0
0`00Oomoo`0<Ool001aoo`8005moo`03001oogoo009oo`03001oogoo00aoo`0077oo00<007ooOol0
GWoo00D007ooOomoo`0000moo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00Ggoo00D007oo
Oomoo`0000moo`002Woo00@007ooOol000Yoo`05001oogooOol0001QOol01000Oomoo`003goo000:
Ool01000Oomoo`001goo1@000Woo0P00H7oo00@007ooOol000moo`002Woo00@007ooOol000Moo`04
001oogoo0003Ool00`00Oomoo`1OOol01000Oomoo`003goo000:Ool01000Oomoo`0027oo00<007oo
00000goo0P00H7oo00@007ooOol000moo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo061o
o`80011oo`002goo0P002goo00D007ooOomoo`00069oo`80011oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol0
00Yoo`05001oogooOol0001dOol000=oo`D0009oo`04001oogoo0007Ool50002Ool2001cOol000Yo
o`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<0
07oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;
Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogooOol50002
Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol03Goo0`0017oo0P00
2Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@00
0Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo0P003Goo00D0
07ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007oo
Ool00goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`04001oogoo0002Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P004Goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool4
0003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000
Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P00
3Goo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo
0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol0
37oo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Io
o`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoofT000aoo`0077oo0P000Woo00L007ooOomoo`00Ool00002Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool00`00Oomoo`020003Ool00`00Oomoo`02Ool00`00Oomoo`0:
Ool001aoo`8000Moo`03001oogoo059oo`03001oogoo01Aoo`0077oo0P001goo00<007ooOol0Dgoo
00<007ooOol04goo000LOol20006Ool00`00Oomoo`1DOol00`00Oomoo`0COol001aoo`8000Ioo`03
001oogoo05Eoo`03001oogoo019oo`002goo0P0017oo00@007ooOomoo`D0009oo`8000Ioo`03001o
ogoo05Eoo`03001oogoo019oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20006Ool00`00
Oomoo`1EOol00`00Oomoo`0BOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool20006Ool00`00
Oomoo`1EOol00`00Oomoo`0BOol000Yoo`04001oogoo000:Ool01`00Oomoogoo001oo`0000Aoo`03
001oogoo05Moo`03001oogoo015oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool30004
Ool00`00Oomoo`1GOol00`00Oomoo`0AOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007oo000017oo00<007ooOol0Egoo00<007ooOol04Goo000;Ool20009Ool30003Ool30004Ool0
0`00Oomoo`1GOol00`00Oomoo`0AOol001aoo`03001oo`0000=oo`03001oogoo05Qoo`03001oogoo
015oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P0000Eoo`00Oomoo`0005Yoo`03001oogoo
015oo`002Woo00@007ooOol000Yoo`05001oogooOol00002Ool01000Oomoo`00FWoo00<007ooOol0
4Goo000:Ool01000Oomoo`001goo1@000Woo0P0000Eoo`00Oomoo`0005]oo`03001oogoo011oo`00
2Woo00@007ooOol000Moo`04001oogoo0003Ool01000Oomoo`000Woo00<007ooOol0FGoo00<007oo
Ool00Woo0P0037oo000:Ool01000Oomoo`0027oo00<007oo00000goo0P000Woo0P00G7oo00D007oo
Oomoo`0000ioo`002Woo00@007ooOol000Uoo`8000=oo`04001oogooOol2001MOol00`00Ool0000?
Ool000]oo`8000]oo`04001oogooOol2001QOol00`00Ool0000?Ool001aoo`03001oogoo061oo`80
011oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2
001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
0`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol0
00]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02
Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<0
00=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2
001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00
Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomo
o`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1560\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32436 m
.008 .34409 L
.012 .36274 L
.016 .37853 L
.02 .39114 L
.024 .39945 L
.028 .40315 L
.032 .40189 L
.036 .39576 L
.04 .38517 L
.044 .37078 L
.048 .35356 L
.052 .33459 L
.056 .31508 L
.06 .29613 L
.064 .27875 L
.068 .26368 L
.072 .2514 L
.076 .24206 L
.08 .23554 L
.084 .23151 L
.088 .22946 L
.092 .22884 L
.096 .22912 L
.1 .22983 L
.104 .23063 L
.108 .23131 L
.112 .23178 L
.116 .23202 L
.12 .23209 L
.124 .23204 L
.128 .23195 L
.132 .23187 L
.136 .23181 L
.14 .23178 L
.144 .23178 L
.148 .23179 L
.152 .2318 L
.156 .23181 L
.16 .23182 L
.164 .23182 L
.168 .23182 L
.172 .23181 L
.176 .23181 L
.18 .23181 L
.184 .23181 L
.188 .23181 L
.192 .23181 L
.196 .23181 L
.2 .23181 L
Mistroke
.204 .23181 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23182 L
.836 .23182 L
.84 .23182 L
.844 .23181 L
.848 .2318 L
.852 .23179 L
.856 .23178 L
.86 .23178 L
.864 .23181 L
.868 .23187 L
.872 .23196 L
.876 .23205 L
.88 .23209 L
.884 .23203 L
.888 .2318 L
.892 .23134 L
.896 .23067 L
.9 .22989 L
.904 .22922 L
.908 .22899 L
.912 .22969 L
.916 .23186 L
.92 .23606 L
.924 .24282 L
.928 .25251 L
.932 .26527 L
.936 .281 L
.94 .29928 L
.944 .31942 L
.948 .34052 L
.952 .36153 L
.956 .38139 L
.96 .39906 L
.964 .41373 L
.968 .42479 L
.972 .43193 L
.976 .43511 L
.98 .43458 L
.984 .43083 L
.988 .42437 L
.992 .41604 L
.996 .40628 L
1 .39603 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .02206 m
.008 .02355 L
.012 .02629 L
.016 .03193 L
.02 .03982 L
.024 .05096 L
.028 .06531 L
.032 .08317 L
.036 .10444 L
.04 .12872 L
.044 .15547 L
.048 .18369 L
.052 .21242 L
.056 .24043 L
.06 .26667 L
.064 .29012 L
.068 .31013 L
.072 .32627 L
.076 .33849 L
.08 .34702 L
.084 .35238 L
.088 .3552 L
.092 .3562 L
.096 .35604 L
.1 .35531 L
.104 .35443 L
.108 .35367 L
.112 .35315 L
.116 .35288 L
.12 .35281 L
.124 .35288 L
.128 .35299 L
.132 .3531 L
.136 .35317 L
.14 .3532 L
.144 .35321 L
.148 .35319 L
.152 .35317 L
.156 .35316 L
.16 .35316 L
.164 .35315 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35317 L
.836 .35317 L
.84 .35317 L
.844 .35316 L
.848 .35315 L
.852 .35313 L
.856 .35312 L
.86 .35312 L
.864 .35315 L
.868 .35322 L
.872 .35333 L
.876 .35344 L
.88 .35349 L
.884 .35341 L
.888 .35312 L
.892 .35256 L
.896 .35175 L
.9 .35078 L
.904 .34993 L
.908 .34959 L
.912 .3503 L
.916 .3527 L
.92 .35745 L
.924 .36513 L
.928 .37612 L
.932 .39055 L
.936 .40819 L
.94 .42847 L
.944 .4504 L
.948 .47279 L
.952 .49416 L
.956 .51306 L
.96 .52798 L
.964 .53777 L
.968 .54134 L
.972 .53819 L
.976 .52802 L
.98 .51104 L
.984 .48784 L
.988 .45909 L
.992 .42633 L
.996 .39016 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .26179 L
.012 .29106 L
.016 .31703 L
.02 .33932 L
.024 .35643 L
.028 .36801 L
.032 .37362 L
.036 .37335 L
.04 .36767 L
.044 .35729 L
.048 .34333 L
.052 .32691 L
.056 .30941 L
.06 .29199 L
.064 .27577 L
.068 .26156 L
.072 .24991 L
.076 .24102 L
.08 .23483 L
.084 .23103 L
.088 .22914 L
.092 .22863 L
.096 .22898 L
.1 .22974 L
.104 .23057 L
.108 .23128 L
.112 .23176 L
.116 .23201 L
.12 .23208 L
.124 .23204 L
.128 .23195 L
.132 .23186 L
.136 .2318 L
.14 .23178 L
.144 .23178 L
.148 .23179 L
.152 .2318 L
.156 .23181 L
.16 .23182 L
.164 .23182 L
.168 .23182 L
.172 .23181 L
.176 .23181 L
.18 .23181 L
.184 .23181 L
.188 .23181 L
.192 .23181 L
.196 .23181 L
.2 .23181 L
Mistroke
.204 .23181 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23182 L
.836 .23182 L
.84 .23182 L
.844 .23181 L
.848 .2318 L
.852 .23179 L
.856 .23178 L
.86 .23178 L
.864 .23181 L
.868 .23187 L
.872 .23196 L
.876 .23205 L
.88 .2321 L
.884 .23204 L
.888 .23181 L
.892 .23135 L
.896 .23069 L
.9 .22993 L
.904 .22927 L
.908 .22908 L
.912 .22983 L
.916 .23207 L
.92 .23638 L
.924 .2433 L
.928 .25322 L
.932 .26631 L
.936 .28248 L
.94 .3014 L
.944 .32239 L
.948 .34466 L
.952 .36719 L
.956 .38906 L
.96 .40929 L
.964 .42722 L
.968 .44228 L
.972 .45434 L
.976 .46337 L
.98 .46972 L
.984 .47386 L
.988 .47619 L
.992 .4776 L
.996 .47793 L
1 .47844 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOomoo`80009o
o`03001oogoo009oo`03001oogoo00Yoo`0077oo0P001Woo00<007ooOol0EGoo00<007ooOol04Woo
000LOol00`00Oomoo`05Ool00`00Oomoo`1EOol00`00Oomoo`0BOol001aoo`8000Eoo`03001oogoo
05Moo`03001oogoo015oo`0077oo00<007ooOol017oo00<007ooOol0Egoo00<007ooOol04Goo000;
Ool20004Ool01000Oomoogoo1@000Woo0P001Goo00<007ooOol0Egoo00<007ooOol04Goo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo05Qoo`03001oogoo015o
o`002Woo00@007ooOol000Uoo`03001oogoo009oo`8000Aoo`03001oogoo05Qoo`03001oogoo015o
o`002Woo00@007ooOol000Yoo`05001oogooOol00005Ool00`00Oomoo`1IOol00`00Oomoo`0@Ool0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P0017oo00<007ooOol0FGoo00<007ooOol0
47oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8000Aoo`03001oogoo05Uoo`03001o
ogoo011oo`002goo0P002Goo0`000goo0P0017oo00<007ooOol0FGoo00<007ooOol047oo000LOol2
0003Ool00`00Oomoo`1JOol00`00Oomoo`0@Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`80
00=oo`03001oogoo05]oo`03001oogoo00moo`002Woo00@007ooOol000Yoo`07001oogooOol007oo
00000Woo00<007ooOol0Fgoo00<007ooOol03goo000:Ool01000Oomoo`001goo1@000Woo0`0000=o
o`00Ool0GGoo00<007ooOol03goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`05001oo`00
Ool0001NOol00`00Oomoo`02Ool00`00Oomoo`0:Ool000Yoo`04001oogoo0008Ool00`00Ool00003
Ool200000goo0000001NOol01@00Oomoogoo00003Goo000:Ool01000Oomoo`002Goo0P000goo00<0
07ooOol0HGoo00@007ooOol000eoo`002goo0P002goo00@007ooOomoo`80069oo`03001oo`0000io
o`0077oo00<007ooOol0HWoo0P003Woo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001o
ogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol0
00]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo
000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol0
01Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00
Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<007Qoo`002Woo00@007ooOol000Moo`05001o
ogooOol0001gOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:
Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol0
00]oo`8000Uoo`<000=oo`03001oo`00079oo`0077oo0`00LWoo000LOol01000Oomoo`00LGoo000;
Ool20004Ool00`00Oomoo`02Ool30003Ool200000goo001oo`1`Ool000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00@007ooOol0075oo`000goo1@000Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool01@00Oomoogoo0000L7oo000:Ool01000Oomoo`001goo10000goo0P000Woo00<007oo
Ool0KWoo000:Ool01000Oomoo`001goo00<007ooOol017oo00D007ooOomoo`00071oo`002Woo00@0
07ooOol000Qoo`03001oogoo00=oo`80009oo`03001oogoo06ioo`002goo0P002Woo0P000goo00D0
07ooOomoo`00071oo`0077oo0P000Woo00<007ooOol0KWoo000LOol01@00Oomoogoo0000L7oo000;
Ool20004Ool00`00Oomoo`03Ool30002Ool20003Ool00`00Oomoo`1]Ool000Yoo`04001oogoo000:
Ool01@00Oomoogoo000017oo00<007ooOol0KGoo0003Ool50002Ool01000Oomoo`001goo1@000Woo
00<007ooOol00Woo00<007ooOol0KGoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`8000=o
o`03001oogoo06eoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo009oo`03001o
ogoo06eoo`002Woo00@007ooOol000Uoo`8000=oo`8000Aoo`03001oogoo06aoo`002goo0P002goo
00D007ooOomoo`0000Eoo`03001oogoo06aoo`0077oo0P0017oo00<007ooOol0K7oo000LOol00`00
Oomoo`03Ool00`00Oomoo`1/Ool000]oo`8000Aoo`04001oogooOol50002Ool20004Ool00`00Oomo
o`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol0K7oo
0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0K7oo
000:Ool01000Oomoo`002Woo00@007ooOomoo`8000Aoo`03001oogoo00Moo`<000Aoo`8000Uoo`<0
00Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<0
00Aoo`8000Ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`03Ool00`00
Oomoo`06Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P001Goo00<0
07ooOol02Goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`002goo0P002Goo0`000goo00<007ooOol017oo00<007ooOol02Goo00@007ooOol0009oo`03
001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P001Goo00<007oo
Ool01Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo
00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0
01aoo`03001oogoo00Eoo`03001oogoo00Aoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`80
00Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006
Ool001aoo`8000Ioo`03001oogoo06Yoo`0077oo00<007ooOol01Goo00<007ooOol0JWoo000LOomY
000<Ool001aoo`03001oogoo019oo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03
001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Yoo`0077oo0P00GWoo00<007ooOol01Goo00<0
07ooOol02Woo000LOol00`00Oomoo`1MOol00`00Oomoo`04Ool00`00Oomoo`0;Ool001aoo`8005mo
o`03001oogoo00=oo`03001oogoo00]oo`0077oo00<007ooOol0GWoo00<007ooOol00goo00<007oo
Ool02goo000LOol00`00Oomoo`1NOol00`00Oomoo`03Ool00`00Oomoo`0;Ool000]oo`8000Aoo`04
001oogooOol50002Ool2001OOol00`00Oomoo`03Ool00`00Oomoo`0;Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00<007ooOol0GWoo00<007ooOol00goo00<007ooOol02goo000:Ool01000
Oomoo`002Goo00<007ooOol00Woo0P00Ggoo00<007ooOol00goo00<007ooOol02goo000:Ool01000
Oomoo`002Woo00D007ooOomoo`00065oo`05001oogooOol0000>Ool000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P00H7oo00D007ooOomoo`0000ioo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`1OOol01@00Oomoogoo00003Woo000;Ool20009Ool30003Ool00`00
Oomoo`1OOol01@00Oomoogoo00003Woo000LOol2001QOol01000Oomoo`003Woo000LOol00`00Oomo
o`1POol01000Oomoo`003Woo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001QOol00`00Ool0
000?Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000HWoo00<007oo00003goo000:Ool01000
Oomoo`001goo1@000Woo0P00HGoo00<007oo00003goo000:Ool01000Oomoo`001goo00@007ooOol0
00=oo`03001oogoo065oo`8000moo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`00
2Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00D007ooOomoo`0007Ao
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009o
o`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000=oo`D0009oo`04001oogoo
0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo
000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo
00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`04001oogooOol50002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo
1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo
00<007ooOol00Woo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007oo
Ool00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00019o
o`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo00@007ooOol0009oo`03001oogoo00Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eo
o`002goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001o
ogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007oo
Ool000Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo
00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo0P000Woo00D007ooOomoo`00
00Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo
009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00
Oomoo`02Ool00`00Oomoo`0:Ool001aoo`8000Ioo`03001oogoo05Eoo`03001oogoo019oo`0077oo
0P001Woo00<007ooOol0EGoo00<007ooOol04Woo000LOol20005Ool00`00Oomoo`1GOol00`00Oomo
o`0AOol001aoo`8000Eoo`03001oogoo05Moo`03001oogoo015oo`002goo0P0017oo00@007ooOomo
o`D0009oo`8000Eoo`03001oogoo05Moo`03001oogoo015oo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool20004Ool00`00Oomoo`1HOol00`00Oomoo`0AOol000Yoo`04001oogoo0009Ool00`00
Oomoo`02Ool20004Ool00`00Oomoo`1HOol00`00Oomoo`0AOol000Yoo`04001oogoo000:Ool01`00
Oomoogoo001oo`0000=oo`03001oogoo05Qoo`03001oogoo015oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool30003Ool00`00Oomoo`1IOol00`00Oomoo`0@Ool000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007oo00000goo00<007ooOol0FGoo00<007ooOol047oo000;Ool2
0009Ool30003Ool30002Ool00`00Oomoo`1JOol00`00Oomoo`0@Ool001aoo`06001oogoo001oo`00
G7oo00<007ooOol047oo000;Ool20004Ool00`00Oomoo`03Ool30002Ool200000goo0000001NOol0
0`00Oomoo`0?Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00000Woo0P00GWoo00<007ooOol0
3goo000:Ool01000Oomoo`001goo1@000Woo0P00HGoo00<007ooOol03goo000:Ool01000Oomoo`00
1goo00@007ooOol000=oo`03001oogoo061oo`03001oogoo00moo`002Woo00@007ooOol000Qoo`03
001oo`0000=oo`80065oo`03001oogoo00moo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo
061oo`03001oogoo00moo`002goo0P002goo00@007ooOomoo`80065oo`03001oogoo00moo`0077oo
00<007ooOol0HGoo00<007ooOol03Woo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001ROol0
0`00Oomoo`0>Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0HWoo00<0
07ooOol03Goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8006=oo`03001oogoo00eo
o`002Woo00@007ooOol000Moo`@000=oo`03001oogoo069oo`8000ioo`002Woo00@007ooOol000Mo
o`03001oogoo00Aoo`8006Aoo`<000aoo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001o
ogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03
001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
07=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uo
o`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo
009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Mo
o`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1600\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .34995 m
.008 .3611 L
.012 .36979 L
.016 .37439 L
.02 .37522 L
.024 .37144 L
.028 .36371 L
.032 .35217 L
.036 .33781 L
.04 .32148 L
.044 .30434 L
.048 .28745 L
.052 .2718 L
.056 .25816 L
.06 .24702 L
.064 .23861 L
.068 .23282 L
.072 .22939 L
.076 .22782 L
.08 .22761 L
.084 .22821 L
.088 .2292 L
.092 .23021 L
.096 .23106 L
.1 .23164 L
.104 .23195 L
.108 .23206 L
.112 .23203 L
.116 .23194 L
.12 .23186 L
.124 .23179 L
.128 .23177 L
.132 .23177 L
.136 .23178 L
.14 .2318 L
.144 .23181 L
.148 .23182 L
.152 .23182 L
.156 .23182 L
.16 .23182 L
.164 .23181 L
.168 .23181 L
.172 .23181 L
.176 .23181 L
.18 .23181 L
.184 .23181 L
.188 .23181 L
.192 .23181 L
.196 .23181 L
.2 .23181 L
Mistroke
.204 .23181 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23182 L
.844 .23182 L
.848 .23182 L
.852 .23182 L
.856 .23181 L
.86 .2318 L
.864 .23178 L
.868 .23177 L
.872 .23178 L
.876 .23181 L
.88 .23188 L
.884 .23199 L
.888 .2321 L
.892 .23216 L
.896 .23211 L
.9 .23188 L
.904 .23142 L
.908 .23074 L
.912 .22997 L
.916 .22934 L
.92 .22922 L
.924 .2301 L
.928 .23256 L
.932 .23721 L
.936 .24457 L
.94 .25505 L
.944 .2688 L
.948 .28574 L
.952 .30545 L
.956 .32726 L
.96 .35026 L
.964 .3734 L
.968 .3956 L
.972 .41578 L
.976 .43309 L
.98 .44673 L
.984 .4564 L
.988 .46168 L
.992 .4629 L
.996 .45993 L
1 .45358 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02177 0 m
.024 .01649 L
.028 .04991 L
.032 .08655 L
.036 .12456 L
.04 .16269 L
.044 .1994 L
.048 .23342 L
.052 .26372 L
.056 .28952 L
.06 .31052 L
.064 .32665 L
.068 .33832 L
.072 .34608 L
.076 .35072 L
.08 .35304 L
.084 .35384 L
.088 .35377 L
.092 .35334 L
.096 .35289 L
.1 .35258 L
.104 .35247 L
.108 .35253 L
.112 .35268 L
.116 .35286 L
.12 .35302 L
.124 .35313 L
.128 .35318 L
.132 .3532 L
.136 .35319 L
.14 .35317 L
.144 .35316 L
.148 .35315 L
.152 .35315 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
Mistroke
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
Mistroke
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
Mistroke
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
Mistroke
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35317 L
.848 .35317 L
.852 .35317 L
.856 .35316 L
.86 .35314 L
.864 .35312 L
.868 .3531 L
.872 .3531 L
.876 .35314 L
.88 .35321 L
.884 .35331 L
.888 .35341 L
.892 .35343 L
.896 .35329 L
.9 .35289 L
.904 .35216 L
.908 .3511 L
.912 .34979 L
.916 .34849 L
.92 .34755 L
.924 .3475 L
.928 .34892 L
.932 .35239 L
.936 .35838 L
.94 .36721 L
.944 .37881 L
.948 .39288 L
.952 .40863 L
.956 .42506 L
.96 .44081 L
.964 .45449 L
.968 .46466 L
.972 .47002 L
.976 .46977 L
.98 .46312 L
.984 .45049 L
.988 .43165 L
.992 .40859 L
.996 .38131 L
1 .35316 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .24998 L
.012 .2676 L
.016 .28194 L
.02 .29325 L
.024 .29989 L
.028 .3024 L
.032 .30042 L
.036 .29486 L
.04 .28637 L
.044 .27607 L
.048 .26503 L
.052 .25426 L
.056 .24464 L
.06 .23673 L
.064 .23089 L
.068 .22711 L
.072 .22521 L
.076 .22481 L
.08 .22546 L
.084 .2267 L
.088 .22814 L
.092 .22949 L
.096 .23057 L
.1 .23131 L
.104 .23173 L
.108 .23191 L
.112 .23194 L
.116 .23188 L
.12 .23182 L
.124 .23177 L
.128 .23175 L
.132 .23176 L
.136 .23178 L
.14 .2318 L
.144 .23181 L
.148 .23182 L
.152 .23182 L
.156 .23182 L
.16 .23182 L
.164 .23181 L
.168 .23181 L
.172 .23181 L
.176 .23181 L
.18 .23181 L
.184 .23181 L
.188 .23181 L
.192 .23181 L
.196 .23181 L
.2 .23181 L
Mistroke
.204 .23181 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23182 L
.844 .23182 L
.848 .23182 L
.852 .23182 L
.856 .23181 L
.86 .2318 L
.864 .23179 L
.868 .23178 L
.872 .23178 L
.876 .23182 L
.88 .2319 L
.884 .23201 L
.888 .23213 L
.892 .23222 L
.896 .2322 L
.9 .23202 L
.904 .23163 L
.908 .23107 L
.912 .23046 L
.916 .23006 L
.92 .23027 L
.924 .23161 L
.928 .23471 L
.932 .24022 L
.936 .24874 L
.94 .26076 L
.944 .27651 L
.948 .29603 L
.952 .31896 L
.956 .3448 L
.96 .37268 L
.964 .40168 L
.968 .43072 L
.972 .45873 L
.976 .48486 L
.98 .50804 L
.984 .528 L
.988 .54364 L
.992 .55545 L
.996 .56208 L
1 .56483 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000Woo0P00
17oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol0
0Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00T007ooOomoo`00Ool007oo0000
17oo00<007ooOol02Woo000LOol20004Ool00`00Oomoo`1HOol00`00Oomoo`0AOol001aoo`03001o
ogoo00=oo`03001oogoo05Qoo`03001oogoo015oo`0077oo0P0017oo00<007ooOol0FGoo00<007oo
Ool047oo000LOol00`00Oomoo`03Ool00`00Oomoo`1IOol00`00Oomoo`0@Ool000]oo`8000Aoo`04
001oogooOol50002Ool20003Ool00`00Oomoo`1JOol00`00Oomoo`0@Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol0FWoo00<007ooOol047oo000:Ool01000
Oomoo`002Goo00<007ooOol00Woo0P000goo00<007ooOol0Fgoo00<007ooOol03goo000:Ool01000
Oomoo`002Woo00D007ooOomoo`0000Aoo`03001oogoo05]oo`03001oogoo00moo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool20002Ool00`00Oomoo`1LOol00`00Oomoo`0?Ool000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00D007ooOomoo`0005ioo`03001oogoo00moo`002goo
0P002Goo0`000goo0P000Woo00<007ooOol0G7oo00<007ooOol03goo000LOol20002Ool00`00Oomo
o`1LOol00`00Oomoo`0?Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`800003Ool007oo05io
o`03001oogoo00moo`002Woo00@007ooOol000Yoo`04001oogooOol4001POol00`00Oomoo`0>Ool0
00Yoo`04001oogoo0007Ool50002Ool2001ROol00`00Oomoo`0>Ool000Yoo`04001oogoo0007Ool0
1000Oomoo`000goo00<007ooOol0HGoo00<007ooOol03Woo000:Ool01000Oomoo`0027oo00<007oo
00000goo0P00HWoo00<007ooOol03Woo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0HWoo
00<007ooOol03Goo000;Ool2000;Ool01000Oomoogoo0P00Hgoo00<007ooOol03Goo000LOol00`00
Oomoo`1ROol00`00Oomoo`0=Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`8006=oo`03001o
ogoo00eoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1SOol00`00Ool0
000<Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00I7oo0P003Goo000:Ool01000
Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00
Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003
Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00
Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol0
0`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001i
Ool001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00
N7oo000:Ool01000Oomoo`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007ooOol000Mo
o`05001oogooOol00002Ool3001bOol000Yoo`04001oogoo0008Ool30003Ool00`00Ool0001bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00@007ooOol0075oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool200000goo001oo`1`Ool000]oo`8000Uoo`<000=oo`04001oogoo
001aOol001aoo`800003Ool007oo071oo`0077oo00@007ooOol0075oo`002goo0P0017oo00<007oo
Ool00Woo0`000goo0P0000=oo`00Ool0L7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`05001oogooOol0001`Ool000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo00D0
07ooOomoo`00071oo`002Woo00@007ooOol000Moo`@000=oo`80009oo`03001oogoo06ioo`002Woo
00@007ooOol000Moo`03001oogoo00Aoo`05001oogooOol0001`Ool000Yoo`04001oogoo0008Ool0
0`00Oomoo`03Ool20002Ool00`00Oomoo`1^Ool000]oo`8000Yoo`8000=oo`05001oogooOol0001`
Ool001aoo`80009oo`03001oogoo06ioo`0077oo00D007ooOomoo`00071oo`002goo0P0017oo00<0
07ooOol00goo0`000Woo0P000Woo00<007ooOol0KWoo000:Ool01000Oomoo`002Woo00D007ooOomo
o`0000=oo`03001oogoo06ioo`000goo1@000Woo00@007ooOol000Moo`D0009oo`05001oogooOol0
001`Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P000Woo00<007ooOol0KWoo000:Ool0
1000Oomoo`0027oo00<007oo00000goo00<007ooOol00Woo00<007ooOol0KGoo000:Ool01000Oomo
o`002Goo0P000goo0P000goo00<007ooOol0KGoo000;Ool2000;Ool01@00Oomoogoo000017oo00<0
07ooOol0KGoo000LOol20003Ool00`00Oomoo`1]Ool001aoo`03001oogoo009oo`03001oogoo06eo
o`002goo0P0017oo00@007ooOomoo`D0009oo`8000=oo`03001oogoo06eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`1]Ool000=oo`D0009oo`04001oogoo
0009Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`1/Ool000Yoo`04001oogoo000:Ool0
1000Oomoogoo0P0017oo00<007ooOol01goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`00
0goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00=oo`03001oogoo00Ioo`05001oogooOol0
0002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00
Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool20004Ool00`00Oomoo`0:Ool01000Oomoo`00
0Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool20009Ool30003
Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol20004Ool00`00Oomoo`06Ool40003Ool01000Oomo
o`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo
00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001o
ogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol00goo00<007ooOol01Woo00<0
07ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo
00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol017oo00<0
07ooOol01Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=o
o`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P001Goo00<007oo
Ool0Jgoo000LOol00`00Oomoo`05Ool00`00Oomoo`1DOol2000DOol001aoofT000aoo`0077oo00<0
07ooOol04Woo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol02goo00<0
07ooOol017oo00<007ooOol02Woo000LOol2001OOol00`00Oomoo`03Ool00`00Oomoo`0;Ool001ao
o`03001oogoo05moo`03001oogoo009oo`03001oogoo00]oo`0077oo0P00H7oo00<007ooOol00Woo
00<007ooOol02goo000LOol00`00Oomoo`1OOol00`00Oomoo`02Ool00`00Oomoo`0;Ool001aoo`03
001oogoo061oo`05001oogooOol0000=Ool000]oo`8000Aoo`04001oogooOol50002Ool2001QOol0
1@00Oomoogoo00003Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo061oo`04
001oogoo000>Ool000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001QOol01000Oomoo`003Woo
000:Ool01000Oomoo`002Woo00D007ooOomoo`0006=oo`03001oo`0000ioo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2001ROol2000?Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol0HWoo00<007ooOol03Goo000;Ool20009Ool30003Ool00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001c
Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo
0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079o
o`002goo0P002goo00D007ooOomoo`0007Aoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
00]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0001dOol000=oo`D0009oo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007
Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00
Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo
0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogooOol50002Ool2001cOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P00
17oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P00
1Woo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo0P003Goo00D007ooOomoo`00009o
o`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogoo
Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool0
1000Oomoo`002Woo00D007ooOomoo`00019oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00
4Goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool0
1000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000Oomo
o`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo
00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001o
ogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P003Goo00<007ooOol0
17oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007oo
Ool017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Ao
o`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P00
2Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Ao
o`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoofT0
00aoo`0077oo0P000Woo00D007oo001oo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`80009oo`<00003Ool007oo00=oo`03001oogoo00Yoo`0077oo0P0017oo00<007ooOol0
F7oo00<007ooOol04Goo000LOol20004Ool00`00Oomoo`1HOol00`00Oomoo`0AOol001aoo`8000=o
o`03001oogoo05Uoo`03001oogoo015oo`0077oo0P000goo00<007ooOol0FWoo00<007ooOol047oo
000;Ool20004Ool01000Oomoogoo1@000Woo0`0000=oo`00Ool0G7oo00<007ooOol047oo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`03001oo`00008005eoo`03001oogoo011oo`002Woo00@0
07ooOol000Uoo`03001oogoo009oo`800003Ool0000005eoo`03001oogoo011oo`002Woo00@007oo
Ool000Yoo`05001oogooOol0001ROol00`00Oomoo`0?Ool000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P00HGoo00<007ooOol03goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo061oo`03001oogoo00moo`002goo0P002Goo0`000goo0P00HGoo00<007ooOol03goo
000LOol00`00Oomoo`1POol00`00Oomoo`0?Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`80
065oo`03001oogoo00moo`002Woo00@007ooOol000Yoo`05001oogooOol0001ROol00`00Oomoo`0?
Ool000Yoo`04001oogoo0007Ool50002Ool2001QOol00`00Oomoo`0?Ool000Yoo`04001oogoo0007
Ool01000Oomoo`000goo00<007ooOol0HGoo00<007ooOol03Woo000:Ool01000Oomoo`0027oo00<0
07oo00000goo0P00HWoo00<007ooOol03Woo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0
HGoo00<007ooOol03Woo000;Ool2000;Ool01000Oomoogoo0P00HWoo00<007ooOol03Woo000LOol0
0`00Oomoo`1QOol00`00Oomoo`0>Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`80069oo`03
001oogoo00ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1ROol00`00
Oomoo`0=Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Hgoo00<007ooOol03Goo
000:Ool01000Oomoo`001goo10000goo00<007ooOol0HWoo00<007ooOol03Goo000:Ool01000Oomo
o`001goo00<007ooOol017oo0P00Hgoo00<007ooOol03Goo000:Ool01000Oomoo`0027oo00<007oo
Ool00goo00<007ooOol0HWoo00<007ooOol03Goo000;Ool2000:Ool20003Ool2001SOol00`00Oomo
o`0=Ool001aoo`03001oogoo069oo`03001oogoo00eoo`002goo0P0017oo00<007ooOol00Woo0`00
0goo0P00Hgoo00<007ooOol03Goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo06=oo`03001oogoo00aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001TOol0
0`00Oomoo`0<Ool000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1SOol00`00Oomoo`0<Ool0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00IGoo00<007ooOol02goo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo06Aoo`8000aoo`002goo0P002Goo0`000goo
0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<0
07ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007oo
Ool0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1640\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35763 m
.008 .35321 L
.012 .34596 L
.016 .33567 L
.02 .32328 L
.024 .30882 L
.028 .29365 L
.032 .27813 L
.036 .26353 L
.04 .25033 L
.044 .23933 L
.048 .23077 L
.052 .22484 L
.056 .22135 L
.06 .21998 L
.064 .22026 L
.068 .22162 L
.072 .22358 L
.076 .22568 L
.08 .2276 L
.084 .22916 L
.088 .23028 L
.092 .231 L
.096 .2314 L
.1 .23157 L
.104 .23163 L
.108 .23163 L
.112 .23164 L
.116 .23165 L
.12 .23169 L
.124 .23173 L
.128 .23177 L
.132 .23179 L
.136 .23181 L
.14 .23181 L
.144 .23181 L
.148 .23181 L
.152 .23181 L
.156 .23181 L
.16 .23181 L
.164 .23181 L
.168 .23181 L
.172 .23181 L
.176 .23181 L
.18 .23181 L
.184 .23181 L
.188 .23181 L
.192 .23181 L
.196 .23181 L
.2 .23181 L
Mistroke
.204 .23181 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23182 L
.856 .23182 L
.86 .23183 L
.864 .23183 L
.868 .23182 L
.872 .23181 L
.876 .2318 L
.88 .23179 L
.884 .23182 L
.888 .23188 L
.892 .232 L
.896 .23217 L
.9 .23236 L
.904 .23254 L
.908 .23264 L
.912 .23259 L
.916 .23237 L
.92 .23202 L
.924 .23169 L
.928 .23165 L
.932 .23232 L
.936 .23423 L
.94 .23801 L
.944 .24429 L
.948 .25361 L
.952 .26636 L
.956 .28266 L
.96 .30236 L
.964 .32493 L
.968 .34961 L
.972 .37523 L
.976 .40071 L
.98 .42453 L
.984 .44567 L
.988 .46275 L
.992 .47518 L
.996 .48212 L
1 .4835 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02206 0 m
.024 .0186 L
.028 .06001 L
.032 .10325 L
.036 .14546 L
.04 .18539 L
.044 .22121 L
.048 .25224 L
.052 .27789 L
.056 .29827 L
.06 .31376 L
.064 .32504 L
.068 .33296 L
.072 .33833 L
.076 .34195 L
.08 .34444 L
.084 .34626 L
.088 .34771 L
.092 .34893 L
.096 .34999 L
.1 .35089 L
.104 .35162 L
.108 .35218 L
.112 .35257 L
.116 .35281 L
.12 .35296 L
.124 .35303 L
.128 .35307 L
.132 .35309 L
.136 .35311 L
.14 .35312 L
.144 .35314 L
.148 .35315 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
Mistroke
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
Mistroke
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
Mistroke
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
Mistroke
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35315 L
.868 .35313 L
.872 .3531 L
.876 .35305 L
.88 .35299 L
.884 .35293 L
.888 .35289 L
.892 .35284 L
.896 .35277 L
.9 .35262 L
.904 .35226 L
.908 .35158 L
.912 .35041 L
.916 .34862 L
.92 .34613 L
.924 .34295 L
.928 .33922 L
.932 .33524 L
.936 .33139 L
.94 .3282 L
.944 .32612 L
.948 .32563 L
.952 .32695 L
.956 .33016 L
.96 .33506 L
.964 .34111 L
.968 .34782 L
.972 .35412 L
.976 .35971 L
.98 .36327 L
.984 .36524 L
.988 .36441 L
.992 .36222 L
.996 .35781 L
1 .35316 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .22724 L
.012 .2228 L
.016 .21761 L
.02 .21256 L
.024 .20682 L
.028 .20154 L
.032 .19633 L
.036 .19222 L
.04 .18913 L
.044 .18771 L
.048 .18788 L
.052 .18976 L
.056 .19308 L
.06 .19753 L
.064 .20268 L
.068 .20805 L
.072 .21325 L
.076 .21791 L
.08 .22185 L
.084 .22494 L
.088 .22724 L
.092 .22882 L
.096 .22986 L
.1 .2305 L
.104 .23089 L
.108 .23113 L
.112 .2313 L
.116 .23143 L
.12 .23154 L
.124 .23163 L
.128 .2317 L
.132 .23175 L
.136 .23178 L
.14 .2318 L
.144 .23181 L
.148 .23181 L
.152 .23181 L
.156 .23181 L
.16 .23181 L
.164 .23181 L
.168 .23181 L
.172 .23181 L
.176 .23181 L
.18 .23181 L
.184 .23181 L
.188 .23181 L
.192 .23181 L
.196 .23181 L
.2 .23181 L
Mistroke
.204 .23181 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23182 L
.852 .23182 L
.856 .23183 L
.86 .23183 L
.864 .23184 L
.868 .23184 L
.872 .23184 L
.876 .23184 L
.88 .23186 L
.884 .23191 L
.888 .23203 L
.892 .23222 L
.896 .2325 L
.9 .23287 L
.904 .23328 L
.908 .2337 L
.912 .23412 L
.916 .23455 L
.92 .23507 L
.924 .2359 L
.928 .2374 L
.932 .24008 L
.936 .24455 L
.94 .25158 L
.944 .26185 L
.948 .27606 L
.952 .29462 L
.956 .31774 L
.96 .34526 L
.964 .37656 L
.968 .41083 L
.972 .44655 L
.976 .48256 L
.98 .51663 L
.984 .54777 L
.988 .57346 L
.992 .59335 L
.996 .60526 L
1 .60955 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2001cOol001aoo`03001oogoo00=oo`<006aoo`0077ooJ@0037oo000LOol01000Oomoogoo0P00
0Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00T007ooOomo
o`00Ool007oo000017oo00<007ooOol02Woo000LOol20002Ool00`00Oomoo`1KOol00`00Oomoo`0@
Ool001aoo`05001oogooOol0001MOol00`00Oomoo`0@Ool001aoo`80009oo`03001oogoo05aoo`03
001oogoo00moo`0077oo00D007ooOomoo`0005ioo`03001oogoo00moo`002goo0P0017oo00@007oo
Oomoo`D0009oo`80009oo`03001oogoo05aoo`03001oogoo00moo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`00Ggoo00<007ooOol03goo000:Ool01000Oomoo`002Goo00<007oo
Ool00Woo0P0000=oo`00Ool0GWoo00<007ooOol03goo000:Ool01000Oomoo`002Woo00D007ooOomo
o`00009oo`03001oogoo05eoo`03001oogoo00moo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool3001QOol00`00Oomoo`0>Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07oo0000HGoo00<007ooOol03Woo000;Ool20009Ool30003Ool2001ROol00`00Oomoo`0>Ool001ao
o`80069oo`03001oogoo00ioo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00Hgoo00<007oo
Ool03Goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0006Aoo`03001oogoo00eoo`002Woo00@0
07ooOol000Moo`D0009oo`8006=oo`03001oogoo00eoo`002Woo00@007ooOol000Moo`04001oogoo
0003Ool00`00Oomoo`1ROol00`00Oomoo`0=Ool000Yoo`04001oogoo0008Ool00`00Ool00003Ool2
001SOol00`00Oomoo`0=Ool000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1ROol00`00Oomo
o`0=Ool000]oo`8000]oo`04001oogooOol2001SOol00`00Oomoo`0=Ool001aoo`03001oogoo069o
o`03001oogoo00eoo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00I7oo00<007ooOol037oo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo06=oo`03001oogoo00aoo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2001TOol00`00Oomoo`0<Ool000Yoo`04001o
ogoo0007Ool40003Ool00`00Oomoo`1TOol00`00Oomoo`0;Ool000Yoo`04001oogoo0007Ool00`00
Oomoo`04Ool2001UOol2000<Ool000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1b
Ool000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomo
o`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qo
o`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003
Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool0
0`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00
Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004
Ool00`00Oomoo`02Ool3001hOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000Mgoo0003Ool5
0002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`800003Ool007oo071oo`002Woo00@007oo
Ool000Qoo`<000=oo`04001oogoo001aOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00@007ooOol0075oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool200000goo001oo`1`
Ool000]oo`8000Uoo`<000=oo`04001oogoo001aOol001aoo`800003Ool007oo071oo`0077oo00@0
07ooOol0075oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P0000=oo`00Ool0L7oo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`04001oogoo001aOol000=oo`D0009oo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00@007ooOol0075oo`002Woo00@007ooOol000Moo`@000=oo`80
009oo`03001oogoo06ioo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`05001oogooOol0001`
Ool000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool20002Ool00`00Oomoo`1^Ool000]oo`8000Yo
o`8000=oo`05001oogooOol0001`Ool001aoo`80009oo`03001oogoo06ioo`0077oo00D007ooOomo
o`00071oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P000Woo00<007ooOol0KWoo000:Ool0
1000Oomoo`002Woo00D007ooOomoo`0000=oo`03001oogoo06ioo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`05001oogooOol0001`Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P00
0Woo00<007ooOol0KWoo000:Ool01000Oomoo`0027oo00<007oo00000goo00D007ooOomoo`00071o
o`002Woo00@007ooOol000Uoo`8000=oo`80009oo`03001oogoo06ioo`002goo0P002goo00D007oo
Oomoo`0000Aoo`03001oogoo06eoo`0077oo0P000goo00<007ooOol0KGoo000LOol00`00Oomoo`02
Ool00`00Oomoo`1]Ool000]oo`8000Aoo`04001oogooOol50002Ool20003Ool00`00Oomoo`1]Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol0KGoo0003Ool5
0002Ool01000Oomoo`002Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0KGoo000:Ool0
1000Oomoo`002Woo00@007ooOomoo`8000Aoo`03001oogoo00Moo`<000Aoo`8000Uoo`<000Aoo`80
00Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`80
00Ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`03Ool00`00Oomoo`06
Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P0017oo00<007ooOol0
2Woo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`00
2goo0P002Goo0`000goo00<007ooOol00goo00<007ooOol02Woo00@007ooOol0009oo`03001oogoo
00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P0017oo00<007ooOol01Woo
10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00=oo`03
001oogoo00Ioo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03
001oogoo00Aoo`03001oogoo00Eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04
001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool400000goo000000030003Ool20006
Ool001aoo`8000Eoo`8005Moo`800003Ool007oo011oo`0077oo00<007ooOol01Goo0`00E7oo0P00
0goo00<007ooOol03Woo000LOomY000<Ool001aoo`03001oogoo019oo`03001oogoo019oo`03001o
ogoo015oo`03001oogoo019oo`03001oogoo00moo`@000aoo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000]oo`8000Ao
o`04001oogooOol50002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007oo
Ool0LWoo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo
00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool0
0`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03
Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomo
o`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079o
o`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=o
o`03001oogoo079oo`002goo0P002goo00D007ooOomoo`0007Aoo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol0
00Yoo`05001oogooOol0001dOol000=oo`D0009oo`04001oogoo0007Ool50002Ool2001cOol000Yo
o`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<0
07oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;
Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogooOol50002
Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol03Goo0`0017oo0P00
2Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@00
0Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo0P003Goo00D0
07ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007oo
Ool00goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`04001oogoo0002Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P004Goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool4
0003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000
Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P00
0Woo0`0027oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomo
o`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomo
o`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<0
07ooOol00P0000=oo`0000001goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@0
07ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo
10000goo00<007ooOol0Jgoo000LOol00`00Ool00005Ool00`00Oomoo`1ZOol001aoofT000aoo`00
77oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`L00003Ool007oo00=oo`03001oogoo00Yoo`0077oo0P00Ggoo00<007ooOol04Goo000L
Ool00`00Oomoo`1NOol00`00Oomoo`0AOol001aoo`80061oo`03001oogoo011oo`0077oo00<007oo
Ool0Ggoo00<007ooOol047oo000;Ool20004Ool01000Oomoogoo1@000Woo0P00H7oo00<007ooOol0
47oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo061oo`03001oogoo00moo`00
2Woo00@007ooOol000Uoo`03001oogoo009oo`80065oo`03001oogoo00moo`002Woo00@007ooOol0
00Yoo`05001oogooOol0001ROol00`00Oomoo`0?Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00HGoo00<007ooOol03goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo061oo`03001oogoo00moo`002goo0P002Goo0`000goo0P00HGoo00<007ooOol03goo000L
Ool00`00Oomoo`1POol00`00Oomoo`0?Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`80069o
o`03001oogoo00ioo`002Woo00@007ooOol000Yoo`05001oogooOol0001SOol00`00Oomoo`0>Ool0
00Yoo`04001oogoo0007Ool50002Ool2001ROol00`00Oomoo`0>Ool000Yoo`04001oogoo0007Ool0
1000Oomoo`000goo00<007ooOol0HGoo00<007ooOol03Woo000:Ool01000Oomoo`0027oo00<007oo
00000goo0P00HWoo00<007ooOol03Woo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0HGoo
00<007ooOol03Woo000;Ool2000;Ool01000Oomoogoo0P00HWoo00<007ooOol03Woo000LOol00`00
Oomoo`1QOol00`00Oomoo`0>Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`8006=oo`03001o
ogoo00eoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1ROol00`00Oomo
o`0=Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Hgoo00<007ooOol03Goo000:
Ool01000Oomoo`001goo10000goo00<007ooOol0HWoo00<007ooOol03Goo000:Ool01000Oomoo`00
1goo00<007ooOol017oo0P00Hgoo00<007ooOol03Goo000:Ool01000Oomoo`0027oo00<007ooOol0
0goo00<007ooOol0HWoo00<007ooOol03Goo000;Ool2000:Ool20003Ool2001SOol00`00Oomoo`0=
Ool001aoo`03001oogoo069oo`03001oogoo00eoo`002goo0P0017oo00<007ooOol00Woo0`000goo
0P00Hgoo00<007ooOol03Goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo
069oo`03001oogoo00eoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001TOol00`00
Oomoo`0<Ool000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1SOol00`00Oomoo`0<Ool000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00I7oo00<007ooOol037oo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo06=oo`03001oogoo00aoo`002goo0P002Goo0`00
0goo0P00I7oo00<007ooOol037oo000LOol00`00Oomoo`1SOol00`00Oomoo`0<Ool001Ioo`<000=o
o`8006Eoo`03001oogoo00]oo`005goo00<007ooOol00Woo00<007ooOol0I7oo0P0037oo000GOol0
0`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001i
Ool001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1680\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .34053 m
.008 .32053 L
.012 .29887 L
.016 .27731 L
.02 .25673 L
.024 .2381 L
.028 .22247 L
.032 .21006 L
.036 .20149 L
.04 .19634 L
.044 .19457 L
.048 .19538 L
.052 .19827 L
.056 .20238 L
.06 .20713 L
.064 .21188 L
.068 .21626 L
.072 .22 L
.076 .22301 L
.08 .22532 L
.084 .22701 L
.088 .22823 L
.092 .22911 L
.096 .22976 L
.1 .23026 L
.104 .23065 L
.108 .23097 L
.112 .23122 L
.116 .23142 L
.12 .23155 L
.124 .23165 L
.128 .23171 L
.132 .23174 L
.136 .23177 L
.14 .23178 L
.144 .23179 L
.148 .2318 L
.152 .2318 L
.156 .23181 L
.16 .23181 L
.164 .23181 L
.168 .23181 L
.172 .23181 L
.176 .23181 L
.18 .23181 L
.184 .23181 L
.188 .23181 L
.192 .23181 L
.196 .23181 L
.2 .23181 L
Mistroke
.204 .23181 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23182 L
.844 .23182 L
.848 .23182 L
.852 .23182 L
.856 .23182 L
.86 .23183 L
.864 .23184 L
.868 .23185 L
.872 .23188 L
.876 .2319 L
.88 .23193 L
.884 .23197 L
.888 .23203 L
.892 .23213 L
.896 .23231 L
.9 .23259 L
.904 .233 L
.908 .23357 L
.912 .23428 L
.916 .23512 L
.92 .23605 L
.924 .23703 L
.928 .23806 L
.932 .23921 L
.936 .24065 L
.94 .24267 L
.944 .24567 L
.948 .25016 L
.952 .25669 L
.956 .26576 L
.96 .27782 L
.964 .29296 L
.968 .31122 L
.972 .33203 L
.976 .35482 L
.98 .37839 L
.984 .40169 L
.988 .42328 L
.992 .44194 L
.996 .45663 L
1 .46626 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.01614 0 m
.02 .02376 L
.024 .05271 L
.028 .08377 L
.032 .11595 L
.036 .14706 L
.04 .17663 L
.044 .2033 L
.048 .22715 L
.052 .24774 L
.056 .26548 L
.06 .28055 L
.064 .29339 L
.068 .30433 L
.072 .31369 L
.076 .32168 L
.08 .32845 L
.084 .33414 L
.088 .3388 L
.092 .34254 L
.096 .34545 L
.1 .34766 L
.104 .34928 L
.108 .35044 L
.112 .35126 L
.116 .35184 L
.12 .35224 L
.124 .35253 L
.128 .35274 L
.132 .35288 L
.136 .35298 L
.14 .35305 L
.144 .35309 L
.148 .35312 L
.152 .35313 L
.156 .35314 L
.16 .35315 L
.164 .35315 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
.204 .35316 L
.208 .35316 L
.212 .35316 L
Mistroke
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
.404 .35316 L
.408 .35316 L
.412 .35316 L
Mistroke
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
.604 .35316 L
.608 .35316 L
.612 .35316 L
Mistroke
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
.804 .35316 L
.808 .35316 L
.812 .35316 L
Mistroke
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35315 L
.852 .35314 L
.856 .35313 L
.86 .35311 L
.864 .35309 L
.868 .35306 L
.872 .353 L
.876 .3529 L
.88 .35275 L
.884 .35252 L
.888 .35219 L
.892 .35175 L
.896 .35115 L
.9 .35036 L
.904 .34931 L
.908 .3479 L
.912 .34595 L
.916 .34326 L
.92 .33957 L
.924 .33462 L
.928 .32815 L
.932 .32 L
.936 .31014 L
.94 .29874 L
.944 .28616 L
.948 .273 L
.952 .26009 L
.956 .24823 L
.96 .23859 L
.964 .2318 L
.968 .22904 L
.972 .23034 L
.976 .23668 L
.98 .24727 L
.984 .26268 L
.988 .28156 L
.992 .30375 L
.996 .32809 L
1 .35316 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .2034 L
.012 .17591 L
.016 .15146 L
.02 .13095 L
.024 .11506 L
.028 .10475 L
.032 .09955 L
.036 .09983 L
.04 .10444 L
.044 .11304 L
.048 .12423 L
.052 .13724 L
.056 .15085 L
.06 .1643 L
.064 .17683 L
.068 .18799 L
.072 .19753 L
.076 .2054 L
.08 .21171 L
.084 .21663 L
.088 .22042 L
.092 .22331 L
.096 .22551 L
.1 .22718 L
.104 .22845 L
.108 .22941 L
.112 .23014 L
.116 .23066 L
.12 .23104 L
.124 .2313 L
.128 .23148 L
.132 .23159 L
.136 .23167 L
.14 .23172 L
.144 .23175 L
.148 .23177 L
.152 .23179 L
.156 .2318 L
.16 .2318 L
.164 .23181 L
.168 .23181 L
.172 .23181 L
.176 .23181 L
.18 .23181 L
.184 .23181 L
.188 .23181 L
.192 .23181 L
.196 .23181 L
.2 .23181 L
Mistroke
.204 .23181 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23182 L
.836 .23182 L
.84 .23182 L
.844 .23182 L
.848 .23182 L
.852 .23183 L
.856 .23184 L
.86 .23185 L
.864 .23188 L
.868 .23192 L
.872 .23197 L
.876 .23205 L
.88 .23216 L
.884 .23232 L
.888 .23254 L
.892 .23289 L
.896 .2334 L
.9 .23415 L
.904 .23521 L
.908 .23665 L
.912 .23853 L
.916 .24092 L
.92 .24385 L
.924 .2474 L
.928 .25166 L
.932 .25682 L
.936 .26312 L
.94 .27094 L
.944 .28073 L
.948 .29298 L
.952 .30824 L
.956 .3268 L
.96 .349 L
.964 .3745 L
.968 .40317 L
.972 .4337 L
.976 .46541 L
.98 .49611 L
.984 .5248 L
.988 .54906 L
.992 .56783 L
.996 .57963 L
1 .58335 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool20003Ool00`00Oomoo`07Ool00`00Oomoo`04Ool01000Oomoo`0027oo
0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool0
0006Ool01000Oomoo`001Goo000LOol01000Oomoogoo0`0027oo1@000goo0P002Woo00<007ooOol0
0goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009o
o`D000=oo`8000Ioo`0077oo0P000Woo00@007oo000006eoo`0077oo00@007ooOol000=oo`8006ao
o`0077ooJ@0037oo000LOol00`00Oomoo`020003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool00`00Oomoo`0400000goo001oo`03Ool00`00Oomoo`0:Ool001ao
o`800003Ool007oo05eoo`03001oogoo011oo`0077oo00<007oo0000H7oo00<007ooOol03goo000L
Ool3001POol00`00Oomoo`0?Ool001aoo`03001oo`00061oo`03001oogoo00moo`002goo0P0017oo
00@007ooOomoo`D0009oo`<0061oo`03001oogoo00moo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool2001ROol00`00Oomoo`0>Ool000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001ROol0
0`00Oomoo`0>Ool000Yoo`04001oogoo000:Ool01000Oomoogoo0P00HWoo00<007ooOol03Woo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8006=oo`03001oogoo00eoo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool2001SOol00`00Oomoo`0=Ool000]oo`8000Uoo`<000=oo`80
06=oo`03001oogoo00eoo`0077oo00<007ooOol0HWoo00<007ooOol03Goo000;Ool20004Ool00`00
Oomoo`03Ool30002Ool2001SOol00`00Oomoo`0=Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo
0000I7oo00<007ooOol03Goo000:Ool01000Oomoo`001goo1@000Woo0P00Hgoo00<007ooOol03Goo
000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo06=oo`03001oogoo00aoo`002Woo
00@007ooOol000Qoo`03001oo`0000=oo`8006Aoo`03001oogoo00aoo`002Woo00@007ooOol000Uo
o`8000=oo`03001oogoo06=oo`03001oogoo00aoo`002goo0P002goo00@007ooOomoo`8006Aoo`03
001oogoo00aoo`0077oo00<007ooOol0Hgoo00<007ooOol037oo000;Ool20004Ool00`00Oomoo`02
Ool30003Ool2001UOol00`00Oomoo`0;Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0I7oo00<007ooOol02goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
06Eoo`8000aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo
079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`00
27oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<0
00=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009o
o`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03
001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`80
00Aoo`03001oogoo009oo`<007Qoo`002Woo00@007ooOol000Moo`05001oogooOol0001gOol000=o
o`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo0`00LWoo000:Ool01000Oomoo`0027oo
0`000goo00<007oo0000LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oo`00
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool3001bOol000]oo`8000Uoo`<000=o
o`03001oo`00079oo`0077oo0P0000=oo`00Ool0L7oo000LOol01000Oomoo`00LGoo000;Ool20004
Ool00`00Oomoo`02Ool30003Ool200000goo001oo`1`Ool000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00@007ooOol0075oo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002
Ool01000Oomoo`00LGoo000:Ool01000Oomoo`001goo10000goo0P0000=oo`00Ool0L7oo000:Ool0
1000Oomoo`001goo00<007ooOol017oo00D007ooOomoo`00071oo`002Woo00@007ooOol000Qoo`03
001oogoo00=oo`80009oo`03001oogoo06ioo`002goo0P002Woo0P000goo00D007ooOomoo`00071o
o`0077oo0P000Woo00<007ooOol0KWoo000LOol01@00Oomoogoo0000L7oo000;Ool20004Ool00`00
Oomoo`03Ool30002Ool20002Ool00`00Oomoo`1^Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo
00000goo00<007ooOol0KWoo0003Ool50002Ool01000Oomoo`001goo1@000Woo00D007ooOomoo`00
071oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool20002Ool00`00Oomoo`1^Ool000Yoo`04
001oogoo0008Ool00`00Ool00003Ool01@00Oomoogoo0000L7oo000:Ool01000Oomoo`002Goo0P00
0goo0P000goo00<007ooOol0KGoo000;Ool2000;Ool01@00Oomoogoo000017oo00<007ooOol0KGoo
000LOol20003Ool00`00Oomoo`1]Ool001aoo`03001oogoo009oo`03001oogoo05aoo`8000moo`00
2goo0P0017oo00@007ooOomoo`D0009oo`8000=oo`03001oogoo05]oo`03001oo`0000moo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`1JOol00`00Ool0000?
Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`1J
Ool00`00Ool0000?Ool000Yoo`04001oogoo000:Ool01000Oomoogoo0P0017oo00<007ooOol01goo
0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo
0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo00=oo`03001oogoo00Ioo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03
001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oo`00001o
o`020002Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`8000Aoo`03001oogoo00Yoo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`8000=oo`04001oogoo0002
Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool00`00Oomoo`04Ool00`00Oomoo`09Ool01000
Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo
0002Ool00`00Oomoo`04Ool20003Ool01000Oomoo`000Woo00@007ooOol000Eoo`0077oo0P001Goo
00<007ooOol01Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo0004Ool01P00Ool007oo001oo`@000=oo`04001oogoo0005Ool001aoo`03
001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomo
o`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`04001oogoo0004Ool02@00Ool007oo001oo`00Ool00004Ool01000
Oomoo`001Goo000LOol00`00Oomoo`05Ool00`00Oomoo`04Ool50003Ool2000:Ool00`00Oomoo`03
Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo
1@000goo0P001Woo000LOol20007Ool00`00Oomoo`1COol20006Ool00`00Oomoo`0;Ool001aoo`03
001oogoo00Moo`80059oo`8000Qoo`03001oogoo00Yoo`0077ooJ@0037oo000LOol00`00Oomoo`0B
Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0:
Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo00<007ooOol0LWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`03001oogoo079oo`002Woo00@007ooOol000Uoo`03001oogoo009o
o`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo079oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D0
07ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Mo
o`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001c
Ool000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`05001oogooOol0
001dOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool3
0002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo0003Ool50002Ool01000
Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo
079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`80
00=oo`03001oogoo0080071oo`002goo0P002goo00@007ooOomoo`800004Ool007oo001_Ool001ao
o`06001oogoo001oo`00Kgoo000;Ool20004Ool01000Oomoogoo1@000Woo0`000Woo00<007ooOol0
KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oo`0000=oo`03001oogoo00Moo`<0
00Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`80
00Eoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`<0
00=oo`03001oogoo00Ioo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo
00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo
00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Yoo`07001oogooOol007oo0000
0goo00<007ooOol02Woo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool20004Ool00`00Oomoo`0:
Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8000Eoo`03001oogoo00Eoo`@000=oo`04
001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol4
0003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool20005Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo
0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol20006
Ool00`00Oomoo`04Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo
1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol20006Ool0
0`00Oomoo`1ZOol001aoo`8000Moo`03001oogoo06Uoo`0077ooJ@0037oo000LOol01@00Oomoogoo
00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo1@000goo
00<007ooOol00Woo00<007ooOol02Woo000LOol2001MOol2000DOol001aoo`03001oogoo05eoo`80
01=oo`0077oo0P00Ggoo00<007ooOol04Goo000LOol00`00Oomoo`1NOol00`00Oomoo`0AOol000]o
o`8000Aoo`04001oogooOol50002Ool2001POol00`00Oomoo`0@Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00<007ooOol0Ggoo00<007ooOol047oo000:Ool01000Oomoo`002Goo00<007oo
Ool00Woo0P00HGoo00<007ooOol03goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00069oo`03
001oogoo00moo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001QOol00`00Oomoo`0?
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0H7oo00<007ooOol03goo
000;Ool20009Ool30003Ool2001QOol00`00Oomoo`0?Ool001aoo`03001oogoo061oo`03001oogoo
00moo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00HGoo00<007ooOol03goo000:Ool01000
Oomoo`002Woo00D007ooOomoo`0006=oo`03001oogoo00ioo`002Woo00@007ooOol000Moo`D0009o
o`80069oo`03001oogoo00ioo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1Q
Ool00`00Oomoo`0>Ool000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001ROol00`00Oomoo`0>
Ool000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1QOol00`00Oomoo`0>Ool000]oo`8000]o
o`04001oogooOol2001SOol00`00Oomoo`0=Ool001aoo`03001oogoo069oo`03001oogoo00eoo`00
2goo0P0017oo00<007ooOol00Woo0`000goo0P00Hgoo00<007ooOol03Goo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo069oo`03001oogoo00eoo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2001SOol00`00Oomoo`0=Ool000Yoo`04001oogoo0007Ool40003Ool0
0`00Oomoo`1ROol00`00Oomoo`0=Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001SOol0
0`00Oomoo`0=Ool000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1ROol00`00Oomo
o`0=Ool000]oo`8000Yoo`8000=oo`8006=oo`03001oogoo00eoo`0077oo00<007ooOol0HWoo00<0
07ooOol03Goo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001TOol00`00Oomoo`0<Ool000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0Hgoo00<007ooOol037oo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`8006Aoo`03001oogoo00aoo`002Woo00@007ooOol0
00Qoo`<000=oo`03001oogoo06=oo`03001oogoo00aoo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool2001TOol00`00Oomoo`0<Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0I7oo00<007ooOol02goo000;Ool20009Ool30003Ool2001UOol00`00Oomoo`0;Ool0
01aoo`03001oogoo06Eoo`03001oogoo00Yoo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02
Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol0
0`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
0001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1720\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30432 m
.008 .27732 L
.012 .25075 L
.016 .2272 L
.02 .20677 L
.024 .19082 L
.028 .17929 L
.032 .17225 L
.036 .16932 L
.04 .16971 L
.044 .17282 L
.048 .1776 L
.052 .18349 L
.056 .18965 L
.06 .19576 L
.064 .20139 L
.068 .20647 L
.072 .21087 L
.076 .21467 L
.08 .21791 L
.084 .22066 L
.088 .22298 L
.092 .22492 L
.096 .22653 L
.1 .22783 L
.104 .22886 L
.108 .22966 L
.112 .23026 L
.116 .23071 L
.12 .23103 L
.124 .23126 L
.128 .23143 L
.132 .23155 L
.136 .23163 L
.14 .23169 L
.144 .23173 L
.148 .23176 L
.152 .23178 L
.156 .23179 L
.16 .2318 L
.164 .23181 L
.168 .23181 L
.172 .23181 L
.176 .23181 L
.18 .23181 L
.184 .23181 L
.188 .23181 L
.192 .23181 L
.196 .23181 L
.2 .23181 L
Mistroke
.204 .23181 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23182 L
.836 .23182 L
.84 .23182 L
.844 .23182 L
.848 .23183 L
.852 .23184 L
.856 .23185 L
.86 .23186 L
.864 .23189 L
.868 .23193 L
.872 .23199 L
.876 .23208 L
.88 .23221 L
.884 .23238 L
.888 .23262 L
.892 .23294 L
.896 .23336 L
.9 .23392 L
.904 .23468 L
.908 .2357 L
.912 .23703 L
.916 .23875 L
.92 .24088 L
.924 .24344 L
.928 .24639 L
.932 .24967 L
.936 .25321 L
.94 .25689 L
.944 .26072 L
.948 .26467 L
.952 .26891 L
.956 .2736 L
.96 .27911 L
.964 .2857 L
.968 .29379 L
.972 .30353 L
.976 .31511 L
.98 .32842 L
.984 .34312 L
.988 .35884 L
.992 .37463 L
.996 .39013 L
1 .40393 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .09418 m
.008 .09405 L
.012 .09639 L
.016 .09891 L
.02 .10342 L
.024 .10889 L
.028 .11602 L
.032 .12478 L
.036 .13508 L
.04 .1473 L
.044 .16092 L
.048 .17624 L
.052 .19252 L
.056 .20974 L
.06 .22712 L
.064 .24437 L
.068 .26085 L
.072 .27623 L
.076 .29013 L
.08 .30237 L
.084 .31286 L
.088 .32163 L
.092 .32883 L
.096 .3346 L
.1 .33918 L
.104 .34274 L
.108 .34549 L
.112 .34758 L
.116 .34915 L
.12 .35032 L
.124 .35118 L
.128 .35179 L
.132 .35223 L
.136 .35253 L
.14 .35274 L
.144 .35288 L
.148 .35298 L
.152 .35304 L
.156 .35309 L
.16 .35311 L
.164 .35313 L
.168 .35314 L
.172 .35315 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35315 L
.836 .35315 L
.84 .35314 L
.844 .35313 L
.848 .35311 L
.852 .35309 L
.856 .35304 L
.86 .35298 L
.864 .35288 L
.868 .35273 L
.872 .35253 L
.876 .35223 L
.88 .3518 L
.884 .3512 L
.888 .35034 L
.892 .34917 L
.896 .34756 L
.9 .34543 L
.904 .34263 L
.908 .33905 L
.912 .33452 L
.916 .32887 L
.92 .3219 L
.924 .31341 L
.928 .30317 L
.932 .29099 L
.936 .27678 L
.94 .26055 L
.944 .24259 L
.948 .22333 L
.952 .20375 L
.956 .18475 L
.96 .16807 L
.964 .15486 L
.968 .14722 L
.972 .14609 L
.976 .15312 L
.98 .16858 L
.984 .19267 L
.988 .22498 L
.992 .2635 L
.996 .30768 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .19154 L
.012 .15239 L
.016 .1183 L
.02 .08942 L
.024 .06782 L
.028 .05351 L
.032 .04657 L
.036 .04655 L
.04 .05218 L
.044 .06263 L
.048 .07617 L
.052 .09188 L
.056 .10832 L
.06 .12482 L
.064 .1405 L
.068 .15504 L
.072 .16811 L
.076 .17965 L
.08 .18964 L
.084 .19816 L
.088 .20533 L
.092 .21127 L
.096 .2161 L
.1 .21997 L
.104 .22302 L
.108 .22537 L
.112 .22715 L
.116 .22847 L
.12 .22945 L
.124 .23015 L
.128 .23066 L
.132 .23102 L
.136 .23128 L
.14 .23146 L
.144 .23158 L
.148 .23166 L
.152 .23171 L
.156 .23175 L
.16 .23177 L
.164 .23179 L
.168 .2318 L
.172 .2318 L
.176 .23181 L
.18 .23181 L
.184 .23181 L
.188 .23181 L
.192 .23181 L
.196 .23181 L
.2 .23181 L
Mistroke
.204 .23181 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23182 L
.824 .23182 L
.828 .23182 L
.832 .23182 L
.836 .23182 L
.84 .23183 L
.844 .23184 L
.848 .23186 L
.852 .23188 L
.856 .23191 L
.86 .23197 L
.864 .23205 L
.868 .23217 L
.872 .23235 L
.876 .23261 L
.88 .23297 L
.884 .23349 L
.888 .2342 L
.892 .23517 L
.896 .23647 L
.9 .23821 L
.904 .24052 L
.908 .24355 L
.912 .24745 L
.916 .2524 L
.92 .25852 L
.924 .26593 L
.928 .27466 L
.932 .2847 L
.936 .29598 L
.94 .30833 L
.944 .32163 L
.948 .33562 L
.952 .35028 L
.956 .36522 L
.96 .3806 L
.964 .39591 L
.968 .41137 L
.972 .42632 L
.976 .44085 L
.98 .45423 L
.984 .46613 L
.988 .47624 L
.992 .48348 L
.996 .48858 L
1 .48958 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool20002Ool2000=Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`05001oogoo001oo`020008Ool40003Ool01000Oomoo`002Goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo
00@007ooOol000Eoo`002goo0P002Goo0`000goo0P0000Eoo`00Oomoo`0000Qoo`03001oogoo00Ao
o`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo
00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool0
1`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`04001oogoo0002Ool20007Ool50003
Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo
0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol30004Ool2001/Ool001aoo`03001oo`00
00Eoo`8006]oo`0077ooJ@0037oo000LOol01@00Ool007oo00000goo00<007ooOol00Woo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00`000Woo00<007ooOol00Woo00<0
07ooOol02Woo000LOol2001NOol2000COol001aoo`8005moo`80019oo`0077oo0P00H7oo0P004Goo
000LOol2001QOol00`00Oomoo`0?Ool000]oo`8000Aoo`04001oogooOol50002Ool2001ROol00`00
Oomoo`0>Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P00HWoo00<007ooOol03Woo000:
Ool01000Oomoo`002Goo00<007ooOol00Woo0P00Hgoo00<007ooOol03Goo000:Ool01000Oomoo`00
2Woo00D007ooOomoo`0006Aoo`03001oogoo00eoo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2001SOol00`00Oomoo`0=Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0HWoo00<007ooOol03Goo000;Ool20009Ool30003Ool2001TOol00`00Oomoo`0<Ool001ao
o`03001oogoo06=oo`03001oogoo00aoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00I7oo
00<007ooOol037oo000:Ool01000Oomoo`002Woo00D007ooOomoo`0006Ioo`03001oogoo00]oo`00
2Woo00@007ooOol000Moo`D0009oo`8006Eoo`03001oogoo00]oo`002Woo00@007ooOol000Moo`04
001oogoo0003Ool00`00Oomoo`1TOol00`00Oomoo`0;Ool000Yoo`04001oogoo0008Ool00`00Ool0
0003Ool2001VOol00`00Oomoo`0:Ool000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol0
00]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007oo
Ool00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007
Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yo
o`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=o
o`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079o
o`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo
009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo
00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3001hOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo0P00Lgoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`@000=oo`8007=oo`00
2Woo00@007ooOol000Moo`03001oogoo00Aoo`03001oo`00079oo`002Woo00@007ooOol000Qoo`03
001oogoo00=oo`800003Ool007oo071oo`002goo0P002Woo0P000goo00D007ooOomoo`00071oo`00
77oo0P000Woo00<007ooOol0KWoo000LOol01@00Oomoogoo0000L7oo000;Ool20004Ool00`00Oomo
o`03Ool30002Ool20002Ool00`00Oomoo`1MOol2000?Ool000Yoo`04001oogoo000:Ool01@00Oomo
ogoo000017oo00<007ooOol0G7oo0P003goo0003Ool50002Ool01000Oomoo`001goo1@000Woo00<0
07ooOol00Woo00<007ooOol0Fgoo00<007oo00003goo000:Ool01000Oomoo`001goo00@007ooOol0
00=oo`8000=oo`03001oogoo05]oo`03001oo`0000moo`002Woo00@007ooOol000Qoo`03001oo`00
00=oo`03001oogoo00=oo`03001oogoo05Yoo`04001oogoo000>Ool000Yoo`04001oogoo0009Ool2
0003Ool20004Ool00`00Oomoo`1JOol01000Oomoo`003Woo000;Ool2000;Ool01@00Oomoogoo0000
1Goo00<007ooOol0FWoo00@007ooOol000ioo`0077oo0P0017oo00<007ooOol0FGoo00D007ooOomo
o`0000ioo`0077oo00<007ooOol00goo00<007ooOol0FGoo00D007ooOomoo`0000ioo`002goo0P00
17oo00@007ooOomoo`D0009oo`8000Aoo`03001oogoo05Uoo`05001oogooOol0000>Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol0F7oo00D007ooOomoo`00
00ioo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
05Moo`03001oogoo00=oo`03001oogoo00]oo`002Woo00@007ooOol000Yoo`04001oogooOol20005
Ool00`00Oomoo`06Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005
Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol01Goo00<007ooOol017oo00D007ooOomoo`00009oo`04001oogoo
0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool0
1000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
1Goo0P0000Qoo`00Ool007oo001oo`000Woo00@007ooOol000Eoo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool20006Ool00`00Oomoo`08Ool01000Oomoo`000Woo00<007ooOol01goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`03
Ool00`00Ool00002Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool00`00Oomoo`05Ool00`00
Oomoo`08Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00
009oo`04001oogoo0002Ool00`00Oomoo`04Ool20004Ool00`00Ool00002Ool01000Oomoo`001Goo
000LOol20006Ool00`00Oomoo`04Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`80009oo`03001oo`0000<000=oo`04001oogoo
0005Ool001aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0008Ool2
0004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool20002Ool01@00Ool007oo
000017oo00@007ooOol000Eoo`0077oo00<007ooOol01Woo0P0017oo1@000goo0P002Woo00<007oo
Ool00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Eoo`@0
009oo`D000=oo`8000Ioo`0077oo0P0027oo0P00DWoo00<007ooOol01goo00<007ooOol02Woo000L
Ool00`00Oomoo`08Ool2001?Ool30009Ool00`00Oomoo`0:Ool001aoofT000aoo`0077oo00<007oo
Ool04Woo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Woo00<007oo
Ool02Woo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`03001oogoo079oo`002goo0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0009Ool00`00Oomo
o`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yo
o`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo
0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo
0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01@00Oomo
ogoo0000M7oo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`05001oogooOol0001`Ool000]oo`8000Aoo`03001o
ogoo00=oo`<0009oo`800003Ool00000071oo`002Woo00@007ooOol000Yoo`05001oogooOol00002
Ool00`00Ool0001_Ool000=oo`D0009oo`04001oogoo0007Ool50002Ool2000017oo001oo`00Kgoo
000:Ool01000Oomoo`001goo00@007ooOol000=oo`06001oogoo001oo`00Kgoo000:Ool01000Oomo
o`0027oo00<007oo00000goo0`000goo00<007ooOol0K7oo000:Ool01000Oomoo`002Goo0P000goo
00<007oo00000goo00<007ooOol0K7oo000;Ool2000;Ool01000Oomoogoo0`000goo00<007ooOol0
K7oo000LOol00`00Ool00003Ool00`00Oomoo`1/Ool000]oo`8000Aoo`04001oogooOol50002Ool3
0003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P001Goo00<007oo
Ool01Woo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo
0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo00<007oo
Ool00Woo0P001Goo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo
00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol0
07oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`002Woo00@007ooOomo
o`8000Eoo`03001oogoo00Uoo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P001Woo00<007oo
Ool027oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002
Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool20006Ool00`00Oomoo`04Ool40003
Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomo
ogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0
00Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P001Woo
00<007ooOol017oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000
Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo
0P001goo00<007ooOol00goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007oo
Oomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00
1goo0P00JWoo000LOol20008Ool2001YOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03
001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03
001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`H000=oo`03001oogoo
009oo`03001oogoo00Yoo`0077oo0P00G7oo00<007ooOol057oo000LOol00`00Oomoo`1LOol00`00
Oomoo`0COol001aoo`8005ioo`03001oogoo019oo`0077oo00<007ooOol0GGoo00<007ooOol04Woo
000;Ool20004Ool01000Oomoogoo1@000Woo0P00Ggoo00<007ooOol04Goo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`03001oogoo05ioo`03001oogoo015oo`002Woo00@007ooOol000Uoo`03
001oogoo009oo`8005moo`03001oogoo015oo`002Woo00@007ooOol000Yoo`05001oogooOol0001P
Ool00`00Oomoo`0AOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00H7oo00<007oo
Ool047oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo05moo`03001oogoo
011oo`002goo0P002Goo0`000goo0P00H7oo00<007ooOol047oo000LOol00`00Oomoo`1POol00`00
Oomoo`0?Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`80065oo`03001oogoo00moo`002Woo
00@007ooOol000Yoo`05001oogooOol0001ROol00`00Oomoo`0?Ool000Yoo`04001oogoo0007Ool5
0002Ool2001QOol00`00Oomoo`0?Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007oo
Ool0HGoo00<007ooOol03Woo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00HWoo00<007oo
Ool03Woo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0HGoo00<007ooOol03Woo000;Ool2
000;Ool01000Oomoogoo0P00HWoo00<007ooOol03Woo000LOol00`00Oomoo`1ROol00`00Oomoo`0=
Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`8006=oo`03001oogoo00eoo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1ROol00`00Oomoo`0=Ool000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P00Hgoo00<007ooOol03Goo000:Ool01000Oomoo`001goo1000
0goo00<007ooOol0Hgoo00<007ooOol037oo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00
I7oo0P003Goo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0I7oo0P0037oo000;
Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo
0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00
Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007oo
Ool0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0
Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1760\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .26518 m
.008 .24297 L
.012 .22263 L
.016 .20575 L
.02 .19157 L
.024 .18112 L
.028 .17344 L
.032 .16884 L
.036 .16649 L
.04 .16619 L
.044 .16745 L
.048 .16987 L
.052 .17326 L
.056 .17724 L
.06 .18178 L
.064 .18656 L
.068 .19157 L
.072 .19655 L
.076 .20145 L
.08 .20609 L
.084 .21039 L
.088 .21425 L
.092 .21765 L
.096 .22055 L
.1 .22298 L
.104 .22497 L
.108 .22658 L
.112 .22786 L
.116 .22886 L
.12 .22964 L
.124 .23023 L
.128 .23068 L
.132 .23101 L
.136 .23125 L
.14 .23142 L
.144 .23155 L
.148 .23163 L
.152 .23169 L
.156 .23173 L
.16 .23176 L
.164 .23178 L
.168 .23179 L
.172 .2318 L
.176 .2318 L
.18 .23181 L
.184 .23181 L
.188 .23181 L
.192 .23181 L
.196 .23181 L
.2 .23181 L
Mistroke
.204 .23181 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23182 L
.82 .23182 L
.824 .23182 L
.828 .23182 L
.832 .23182 L
.836 .23183 L
.84 .23184 L
.844 .23185 L
.848 .23187 L
.852 .2319 L
.856 .23194 L
.86 .232 L
.864 .23208 L
.868 .23221 L
.872 .23238 L
.876 .23262 L
.88 .23295 L
.884 .2334 L
.888 .23399 L
.892 .23478 L
.896 .23579 L
.9 .23707 L
.904 .23867 L
.908 .24063 L
.912 .24302 L
.916 .24587 L
.92 .24925 L
.924 .25315 L
.928 .25757 L
.932 .26241 L
.936 .26757 L
.94 .27279 L
.944 .27783 L
.948 .28233 L
.952 .28607 L
.956 .28874 L
.96 .29031 L
.964 .29078 L
.968 .29042 L
.972 .28971 L
.976 .28915 L
.98 .28959 L
.984 .29144 L
.988 .29567 L
.992 .3022 L
.996 .31169 L
1 .32346 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23396 m
.008 .23081 L
.012 .22333 L
.016 .21043 L
.02 .1955 L
.024 .17842 L
.028 .16245 L
.032 .1482 L
.036 .13777 L
.04 .13177 L
.044 .1308 L
.048 .13496 L
.052 .14362 L
.056 .15634 L
.06 .17187 L
.064 .18949 L
.068 .20797 L
.072 .22663 L
.076 .24463 L
.08 .26154 L
.084 .27695 L
.088 .29069 L
.092 .30268 L
.096 .31294 L
.1 .32156 L
.104 .32866 L
.108 .33443 L
.112 .33903 L
.116 .34264 L
.12 .34542 L
.124 .34754 L
.128 .34912 L
.132 .35029 L
.136 .35115 L
.14 .35176 L
.144 .3522 L
.148 .35251 L
.152 .35273 L
.156 .35287 L
.16 .35297 L
.164 .35304 L
.168 .35308 L
.172 .35311 L
.176 .35313 L
.18 .35314 L
.184 .35315 L
.188 .35315 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35315 L
.824 .35315 L
.828 .35314 L
.832 .35313 L
.836 .35311 L
.84 .35308 L
.844 .35304 L
.848 .35297 L
.852 .35287 L
.856 .35273 L
.86 .35251 L
.864 .3522 L
.868 .35176 L
.872 .35115 L
.876 .35029 L
.88 .34911 L
.884 .34753 L
.888 .34542 L
.892 .34265 L
.896 .33905 L
.9 .33446 L
.904 .32868 L
.908 .32153 L
.912 .31286 L
.916 .30255 L
.92 .29055 L
.924 .27685 L
.928 .2616 L
.932 .24494 L
.936 .22726 L
.94 .20886 L
.944 .19045 L
.948 .17249 L
.952 .15604 L
.956 .14173 L
.96 .13092 L
.964 .1244 L
.968 .12346 L
.972 .12896 L
.976 .14148 L
.98 .16181 L
.984 .189 L
.988 .22373 L
.992 .26312 L
.996 .30769 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .19738 L
.012 .16349 L
.016 .13299 L
.02 .10524 L
.024 .08256 L
.028 .06421 L
.032 .05137 L
.036 .04343 L
.04 .04044 L
.044 .04193 L
.048 .04727 L
.052 .05603 L
.056 .0673 L
.06 .08065 L
.064 .09519 L
.068 .11048 L
.072 .12578 L
.076 .14071 L
.08 .15476 L
.084 .16769 L
.088 .17925 L
.092 .18938 L
.096 .19804 L
.1 .2053 L
.104 .21128 L
.108 .21611 L
.112 .21996 L
.116 .22298 L
.12 .22531 L
.124 .22708 L
.128 .22842 L
.132 .2294 L
.136 .23012 L
.14 .23064 L
.144 .23101 L
.148 .23127 L
.152 .23145 L
.156 .23157 L
.16 .23165 L
.164 .23171 L
.168 .23175 L
.172 .23177 L
.176 .23179 L
.18 .2318 L
.184 .2318 L
.188 .23181 L
.192 .23181 L
.196 .23181 L
.2 .23181 L
Mistroke
.204 .23181 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23182 L
.812 .23182 L
.816 .23182 L
.82 .23182 L
.824 .23182 L
.828 .23183 L
.832 .23184 L
.836 .23186 L
.84 .23188 L
.844 .23192 L
.848 .23197 L
.852 .23206 L
.856 .23218 L
.86 .23236 L
.864 .23262 L
.868 .23299 L
.872 .2335 L
.876 .23422 L
.88 .23521 L
.884 .23654 L
.888 .23832 L
.892 .24066 L
.896 .24368 L
.9 .24754 L
.904 .25236 L
.908 .25831 L
.912 .26553 L
.916 .27414 L
.92 .28425 L
.924 .29585 L
.928 .30891 L
.932 .32317 L
.936 .33837 L
.94 .35389 L
.944 .36924 L
.948 .38348 L
.952 .39607 L
.956 .406 L
.96 .41296 L
.964 .41632 L
.968 .4162 L
.972 .4128 L
.976 .40661 L
.98 .39887 L
.984 .38995 L
.988 .38207 L
.992 .37486 L
.996 .37094 L
1 .36895 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00000goo
00<007ooOol037oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool200000goo00000002000<Ool0
1000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001o
ogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`06Ool40003
Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomo
ogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0
00Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0`0017oo
00<007ooOol01Goo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000
Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo
00<007oo00001Goo00<007ooOol017oo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo
00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`00
77oo0`001Goo0P00Jgoo000LOol20008Ool2001YOol001aoofT000aoo`0077oo0P000Woo00D007oo
Oomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03
001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`D000=oo`03001oogoo
009oo`03001oogoo00Yoo`0077oo0P00GGoo0P0057oo000LOol2001NOol2000COol001aoo`8005mo
o`03001oogoo015oo`0077oo00<007ooOol0GWoo0P004Woo000;Ool20004Ool01000Oomoogoo1@00
0Woo0P00HGoo10003Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo06=oo`03
001oogoo00aoo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8006Eoo`03001oogoo00]oo`00
2Woo00@007ooOol000Yoo`05001oogooOol0001VOol00`00Oomoo`0;Ool000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo0P00IWoo00<007ooOol02Woo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1b
Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001o
ogooOol0001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool0
1000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo
000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00
Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol0
0goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yo
o`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo
00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo
07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`002goo0P0017oo00<007ooOol00Woo0`00N7oo000:Ool01000Oomoo`001goo00D007ooOomo
o`0007Moo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04
001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002goo
0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P00
17oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool40003Ool2001cOol000Yoo`04001oogoo0007Ool00`00Oomo
o`04Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool2001cOol000]oo`80
00Yoo`8000=oo`03001oogoo065oo`03001oogoo00ioo`0077oo0P000Woo0P00GGoo00<007oo0000
3goo000LOol01`00Oomoogoo001oo`0005aoo`03001oo`0000moo`002goo0P0017oo00<007ooOol0
0goo0`000Woo0P000Woo00<007oo0000G7oo00<007oo00003goo000:Ool01000Oomoo`002Woo00D0
07ooOomoo`00009oo`04001oogoo001LOol00`00Ool0000?Ool000=oo`D0009oo`04001oogoo0007
Ool50002Ool01000Oomoo`000Woo00<007ooOol0FGoo00@007ooOol000moo`002Woo00@007ooOol0
00Moo`04001oogoo0003Ool200001Goo001oogoo0000Fgoo00D007ooOomoo`0000ioo`002Woo00@0
07ooOol000Qoo`03001oo`0000=oo`04001oogoo0003Ool00`00Oomoo`1HOol01@00Oomoogoo0000
3Woo000:Ool01000Oomoo`002Goo0P000goo0`0017oo00<007ooOol0F7oo00D007ooOomoo`0000io
o`002goo0P002goo00L007ooOomoo`00Ool00004Ool00`00Oomoo`1GOol00`00Oomoo`02Ool00`00
Oomoo`0<Ool001aoo`8000Eoo`03001oogoo05Moo`03001oogoo009oo`03001oogoo00aoo`0077oo
0P001Woo00<007ooOol0EWoo00<007ooOol00Woo00<007ooOol037oo000;Ool20004Ool01000Oomo
ogoo1@000Woo0P001Woo00<007ooOol0EWoo00<007ooOol00Woo00<007ooOol037oo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo05Ioo`03001oogoo009oo`03
001oogoo00aoo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo00Eoo`03
001oogoo05Eoo`03001oogoo00Aoo`03001oogoo00]oo`002Woo00@007ooOol000Yoo`04001oogoo
Ool20006Ool00`00Oomoo`05Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004
Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol01Woo00<007ooOol00goo00D007ooOomoo`00009oo`04
001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol0
0003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`001Goo00X007ooOol007oo001oo`00Ool0009oo`04001oogoo0005Ool000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P001goo00<007ooOol01goo00@007ooOol0009oo`03001oogoo
00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo00<0
07oo00001Goo00<007oo00000Woo00@007ooOol000Eoo`002goo0P002Goo0`000goo00<007ooOol0
1Woo00<007ooOol01goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oo`00009o
o`04001oogoo0005Ool001aoo`8000Qoo`03001oogoo009oo`@000=oo`04001oogoo0009Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool4
0003Ool01000Oomoo`001Goo000LOol00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`04Ool0
1000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04
Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo0P00
0goo00D007oo001oo`0000Aoo`04001oogoo0005Ool001aoo`03001oogoo00Qoo`04001oogooOol5
0003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`00
17oo0P0017oo0P0017oo00<007oo00000P000Woo1@000goo0P001Woo000LOol20009Ool2001@Ool0
0`00Oomoo`08Ool00`00Oomoo`0:Ool001aoo`03001oogoo00Uoo`8004eoo`8000]oo`03001oogoo
00Yoo`0077ooJ@0037oo000LOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00
Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0:Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000;Ool20004Ool01000
Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo079o
o`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001o
ogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`00
0Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Mo
o`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00
Oomoo`1bOol000]oo`8000]oo`05001oogooOol0001dOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00@007oo
Oomoo`8006moo`002goo0P0017oo00<007ooOol00goo0`000Woo0P000Woo00<007oo0000KWoo000:
Ool01000Oomoo`002Woo00D007ooOomoo`00009oo`04001oogoo001^Ool000=oo`D0009oo`04001o
ogoo0007Ool50002Ool200001Goo001oogoo0000KWoo000:Ool01000Oomoo`001goo00@007ooOol0
00=oo`04001oogoo0002Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool00`00Ool00003Ool2
00000goo001oo`02Ool00`00Oomoo`1[Ool000Yoo`04001oogoo0009Ool20003Ool00`00Ool00004
Ool00`00Oomoo`1[Ool000]oo`8000]oo`04001oogooOol30004Ool00`00Oomoo`1[Ool001aoo`03
001oo`0000Aoo`03001oogoo06]oo`002goo0P0017oo00@007ooOomoo`D0009oo`<000Eoo`03001o
ogoo06Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Ool00005Ool00`00Oomoo`05
Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004
Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02
Ool20006Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool0
00=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01000Oomoogoo0P00
1Woo00<007ooOol027oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool20007Ool00`00Oomoo`07
Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8000Moo`03001oogoo00=oo`@000=oo`04
001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol4
0003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool20008Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo
0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol20008
Ool00`00Oomoo`02Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo
1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol20009Ool0
0`00Oomoo`1WOol001aoo`8000Uoo`8006Qoo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo
00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01P00Oomoogoo001oo`@0009oo`05001oogoo
Ool00004Ool00`00Oomoo`0:Ool001aoo`8005]oo`03001oogoo01Eoo`0077oo00<007ooOol0Fgoo
00<007ooOol057oo000LOol2001LOol00`00Oomoo`0DOol001aoo`03001oogoo05aoo`03001oogoo
01=oo`002goo0P0017oo00@007ooOomoo`D0009oo`8005eoo`03001oogoo01=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool00`00Oomoo`1MOol00`00Oomoo`0BOol000Yoo`04001oogoo0009
Ool00`00Oomoo`02Ool2001NOol00`00Oomoo`0BOol000Yoo`04001oogoo000:Ool01@00Oomoogoo
0000Ggoo00<007ooOol04Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8005moo`03
001oogoo015oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1NOol00`00
Oomoo`0AOol000]oo`8000Uoo`<000=oo`8005moo`03001oogoo015oo`0077oo00<007ooOol0GWoo
00<007ooOol04Goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001OOol00`00Oomoo`0AOol0
00Yoo`04001oogoo000:Ool01@00Oomoogoo0000HGoo00<007ooOol00Woo0P0037oo000:Ool01000
Oomoo`001goo1@000Woo0P00H7oo00D007ooOomoo`0000ioo`002Woo00@007ooOol000Moo`04001o
ogoo0003Ool00`00Oomoo`1POol01000Oomoo`003Woo000:Ool01000Oomoo`0027oo00<007oo0000
0goo0P00HGoo00<007oo00003goo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0H7oo00<0
07oo00003goo000;Ool2000;Ool01000Oomoogoo0P00HWoo00<007ooOol03Woo000LOol00`00Oomo
o`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo
000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol0
0Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool3
0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo
0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<0
07ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007oo
Ool0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1800\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23864 m
.008 .22777 L
.012 .21869 L
.016 .21106 L
.02 .20413 L
.024 .19809 L
.028 .1921 L
.032 .18675 L
.036 .18152 L
.04 .17711 L
.044 .17336 L
.048 .17079 L
.052 .16942 L
.056 .16942 L
.06 .17078 L
.064 .17332 L
.068 .17695 L
.072 .18131 L
.076 .18623 L
.08 .19136 L
.084 .19654 L
.088 .20153 L
.092 .20623 L
.096 .21051 L
.1 .21433 L
.104 .21768 L
.108 .22054 L
.112 .22295 L
.116 .22493 L
.12 .22655 L
.124 .22783 L
.128 .22884 L
.132 .22962 L
.136 .23022 L
.14 .23067 L
.144 .231 L
.148 .23124 L
.152 .23141 L
.156 .23154 L
.16 .23163 L
.164 .23169 L
.168 .23173 L
.172 .23176 L
.176 .23178 L
.18 .23179 L
.184 .2318 L
.188 .2318 L
.192 .23181 L
.196 .23181 L
.2 .23181 L
Mistroke
.204 .23181 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23182 L
.808 .23182 L
.812 .23182 L
.816 .23182 L
.82 .23182 L
.824 .23183 L
.828 .23184 L
.832 .23185 L
.836 .23187 L
.84 .2319 L
.844 .23194 L
.848 .232 L
.852 .23209 L
.856 .23221 L
.86 .23239 L
.864 .23263 L
.868 .23297 L
.872 .23341 L
.876 .23401 L
.88 .23479 L
.884 .2358 L
.888 .23708 L
.892 .23869 L
.896 .24068 L
.9 .24309 L
.904 .24597 L
.908 .24931 L
.912 .25314 L
.916 .2574 L
.92 .26205 L
.924 .26699 L
.928 .27211 L
.932 .27722 L
.936 .28218 L
.94 .28669 L
.944 .29054 L
.948 .2934 L
.952 .295 L
.956 .29506 L
.96 .29339 L
.964 .28998 L
.968 .28483 L
.972 .27846 L
.976 .27118 L
.98 .26404 L
.984 .25763 L
.988 .25325 L
.992 .25154 L
.996 .25344 L
1 .25938 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32857 m
.008 .32511 L
.012 .3146 L
.016 .29768 L
.02 .27646 L
.024 .25149 L
.028 .2259 L
.032 .20022 L
.036 .17726 L
.04 .15745 L
.044 .14249 L
.048 .13254 L
.052 .12804 L
.056 .12881 L
.06 .13435 L
.064 .14418 L
.068 .15732 L
.072 .1731 L
.076 .19047 L
.08 .20875 L
.084 .22707 L
.088 .24488 L
.092 .26161 L
.096 .27695 L
.1 .29066 L
.104 .30264 L
.108 .3129 L
.112 .32151 L
.116 .32861 L
.12 .33437 L
.124 .33896 L
.128 .34256 L
.132 .34535 L
.136 .34747 L
.14 .34907 L
.144 .35025 L
.148 .35112 L
.152 .35174 L
.156 .35218 L
.16 .3525 L
.164 .35272 L
.168 .35286 L
.172 .35297 L
.176 .35303 L
.18 .35308 L
.184 .35311 L
.188 .35313 L
.192 .35314 L
.196 .35315 L
.2 .35315 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35315 L
.812 .35315 L
.816 .35314 L
.82 .35313 L
.824 .35311 L
.828 .35308 L
.832 .35303 L
.836 .35297 L
.84 .35286 L
.844 .35272 L
.848 .3525 L
.852 .35218 L
.856 .35174 L
.86 .35112 L
.864 .35025 L
.868 .34907 L
.872 .34748 L
.876 .34535 L
.88 .34256 L
.884 .33896 L
.888 .33436 L
.892 .32861 L
.896 .32151 L
.9 .31291 L
.904 .30266 L
.908 .29069 L
.912 .27699 L
.916 .26163 L
.92 .24485 L
.924 .22698 L
.928 .20861 L
.932 .19031 L
.936 .173 L
.94 .15738 L
.944 .14453 L
.948 .13505 L
.952 .12981 L
.956 .12911 L
.96 .13323 L
.964 .14219 L
.968 .15543 L
.972 .17297 L
.976 .19337 L
.98 .21705 L
.984 .242 L
.988 .26911 L
.992 .29641 L
.996 .32482 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .214 L
.012 .19593 L
.016 .17752 L
.02 .15807 L
.024 .13871 L
.028 .11882 L
.032 .10015 L
.036 .08256 L
.04 .06768 L
.044 .05573 L
.048 .04769 L
.052 .04374 L
.056 .04403 L
.06 .0484 L
.064 .05632 L
.068 .0673 L
.072 .08044 L
.076 .09513 L
.08 .11049 L
.084 .12596 L
.088 .14092 L
.092 .155 L
.096 .16786 L
.1 .17936 L
.104 .18941 L
.108 .19801 L
.112 .20524 L
.116 .2112 L
.12 .21604 L
.124 .21989 L
.128 .22292 L
.132 .22526 L
.136 .22704 L
.14 .22838 L
.144 .22937 L
.148 .2301 L
.152 .23062 L
.156 .23099 L
.16 .23126 L
.164 .23144 L
.168 .23156 L
.172 .23165 L
.176 .23171 L
.18 .23174 L
.184 .23177 L
.188 .23179 L
.192 .2318 L
.196 .2318 L
.2 .23181 L
Mistroke
.204 .23181 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23182 L
.8 .23182 L
Mistroke
.804 .23182 L
.808 .23182 L
.812 .23182 L
.816 .23183 L
.82 .23184 L
.824 .23186 L
.828 .23188 L
.832 .23192 L
.836 .23198 L
.84 .23206 L
.844 .23219 L
.848 .23237 L
.852 .23263 L
.856 .23301 L
.86 .23353 L
.864 .23426 L
.868 .23525 L
.872 .23659 L
.876 .23837 L
.88 .24071 L
.884 .24373 L
.888 .24759 L
.892 .25242 L
.896 .25839 L
.9 .26562 L
.904 .27423 L
.908 .28429 L
.912 .29579 L
.916 .30864 L
.92 .32268 L
.924 .33759 L
.928 .35301 L
.932 .36835 L
.936 .38309 L
.94 .39638 L
.944 .4076 L
.948 .4158 L
.952 .42043 L
.956 .42077 L
.96 .41651 L
.964 .40764 L
.968 .39424 L
.972 .37746 L
.976 .35772 L
.98 .33738 L
.984 .31695 L
.988 .29939 L
.992 .28504 L
.996 .27627 L
1 .27318 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool20003Ool3000;Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`05001oogooOol00002Ool20006Ool40003Ool01000Oomoo`002Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Ao
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo1000
0goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P0000=oo`0000000goo00<007ooOol017oo
00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P00
0goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00@007oo000000Eo
o`03001oogoo00=oo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`<000Moo`80
06Uoo`0077oo0P002Goo0P00J7oo000LOomY000<Ool001aoo`80009oo`05001oogooOol00004Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
17oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool300000goo001oo`02Ool00`00Oomoo`02
Ool00`00Oomoo`0:Ool001aoo`8005aoo`03001oogoo00Eoo`8000eoo`0077oo00<007ooOol0G7oo
00<007ooOol017oo0`0037oo000LOol2001NOol00`00Oomoo`02Ool00`00Oomoo`0=Ool001aoo`03
001oogoo05ioo`05001oogooOol0000?Ool000]oo`8000Aoo`04001oogooOol50002Ool2001OOol2
00000goo001oo`0?Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0Ggoo0P00
4Goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D0
07ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001c
Ool001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool0
1000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`D0009oo`8007=oo`00
2Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool0
0`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`80
00]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo
0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool40003
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001o
ogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo
00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo
0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`80
07=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007oo
Ool0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3001hOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00Lgoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`@000=oo`8007=oo`002Woo00@0
07ooOol000Moo`03001oogoo00Aoo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oogoo
00=oo`8007=oo`002goo0P002Woo0P000goo00<007ooOol0LWoo000LOol20003Ool2001KOol2000A
Ool001aoo`03001oogoo009oo`03001oo`0005Yoo`03001oo`00011oo`002goo0P0017oo00<007oo
Ool00goo0`000Woo0P000goo00<007oo0000FWoo00<007oo000047oo000:Ool01000Oomoo`002Woo
00D007ooOomoo`0000=oo`04001oogoo001IOol01000Oomoo`0047oo0003Ool50002Ool01000Oomo
o`001goo1@000Woo00D007ooOomoo`0000=oo`03001oogoo05Ioo`05001oogooOol0000?Ool000Yo
o`04001oogoo0007Ool01000Oomoo`000goo0P000Woo00D007ooOomoo`0005Qoo`05001oogooOol0
000?Ool000Yoo`04001oogoo0008Ool00`00Ool00003Ool01@00Oomoogoo00000goo00<007ooOol0
EWoo00D007ooOomoo`0000moo`002Woo00@007ooOol000Uoo`8000=oo`80009oo`05001oogooOol0
001HOol01@00Oomoogoo00003goo000;Ool2000;Ool01@00Oomoogoo00000goo00D007ooOomoo`00
05Moo`03001oogoo009oo`03001oogoo00eoo`0077oo0P0000=oo`00Ool00goo00<007ooOol0EGoo
00<007ooOol00Woo00<007ooOol03Goo000LOol01000Oomoo`001Goo00<007ooOol0E7oo00<007oo
Ool00Woo00<007ooOol03Goo000;Ool20004Ool01000Oomoogoo1@000Woo0P0000=oo`00Ool017oo
00<007ooOol0E7oo00<007ooOol00goo00<007ooOol037oo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`1COol00`00Oomoo`04Ool00`00Oomoo`0<Ool000=o
o`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`001Woo00<007ooOol0DWoo00<0
07ooOol017oo00<007ooOol037oo000:Ool01000Oomoo`002Woo00@007ooOomoo`<000Moo`03001o
ogoo00=oo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=o
o`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Ool00007Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00
Ool00002Ool01000Ool000000Woo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool30008Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000
Oomoo`001Goo00<007oo00000Woo00@007ooOol000Eoo`002goo0P002Goo0`000goo00<007oo0000
27oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oo`00
009oo`04001oogoo0005Ool001aoo`<000Qoo`04001oogooOol40003Ool01000Oomoo`002Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`8000=oo`03001oo`00
00<000=oo`04001oogoo0005Ool001aoo`8000Uoo`05001oogooOol00006Ool01000Oomoo`0027oo
0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007oo00000goo00D0
07oo001oo`0000Aoo`04001oogoo0005Ool001aoo`8000Yoo`03001oogoo00D000=oo`8000Yoo`03
001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20002
Ool20002Ool30002Ool50003Ool20006Ool001aoo`8000]oo`03001oogoo04aoo`03001oogoo00Qo
o`03001oogoo00]oo`0077oo00<007ooOol02Woo0`00BWoo0P0037oo00<007ooOol02Woo000LOomY
000<Ool001aoo`03001oogoo019oo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03
001oogoo019oo`03001oogoo00Yoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogooOol50002
Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0LWoo000:Ool01000
Oomoo`002Goo00<007ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Ao
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol0
00Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo0P00
Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`00
2goo0P002goo00D007ooOomoo`0007Aoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`02Ool2001^
Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8000=oo`<006eoo`002Woo00@007ooOol000Yo
o`05001oogooOol00003Ool01000Oomoo`00KGoo0003Ool50002Ool01000Oomoo`001goo1@000Woo
0P000Woo00@007ooOol006eoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool01@00Oomoogoo
00000goo00<007ooOol0JWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P000Woo00D007oo
Oomoo`0006aoo`002Woo00@007ooOol000Uoo`8000=oo`05001oogooOol00003Ool00`00Oomoo`1Z
Ool000]oo`8000]oo`04001oogooOol20002Ool01@00Oomoogoo0000K7oo000LOol01000Oomoo`00
17oo00<007ooOol0JWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P0000=oo`00Ool017oo00<0
07ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`04Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool2
0004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomo
o`02Ool200000goo001oo`04Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00@007ooOol000Uo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool0
1`00Oomoogoo001oo`0000Moo`03001oogoo00Ioo`04001oogoo0002Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
0`001goo00<007ooOol01Woo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0
009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Ool00008
Ool01000Oomoogoo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`80
00Uoo`<000=oo`<000Qoo`05001oogooOol00006Ool01000Oomoo`0027oo0P0017oo00@007ooOol0
009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`00
1Goo000LOol20009Ool01000Oomoogoo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo
00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`00
77oo0P002Woo00<007ooOol0IWoo000LOol2000;Ool00`00Oomoo`1UOol001aoofT000aoo`0077oo
00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00@007ooOomoo`D0
00=oo`05001oogooOol00004Ool00`00Oomoo`0:Ool001aoo`8005Yoo`03001oogoo01Ioo`0077oo
00<007ooOol0FGoo0P005goo000LOol2001KOol00`00Oomoo`0EOol001aoo`03001oogoo05]oo`03
001oogoo00Ioo`8000aoo`002goo0P0017oo00@007ooOomoo`D0009oo`8005aoo`03001oogoo00Io
o`03001oogoo00]oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1KOol00`00
Oomoo`05Ool00`00Oomoo`0<Ool000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001MOol00`00
Oomoo`04Ool00`00Oomoo`0<Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000GWoo00<007oo
Ool017oo00<007ooOol037oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8005eoo`03
001oogoo00Aoo`03001oogoo00aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1MOol00`00Oomoo`02Ool00`00Oomoo`0=Ool000]oo`8000Uoo`<000=oo`8005ioo`03001o
ogoo009oo`03001oogoo00eoo`0077oo00<007ooOol0GGoo00<007ooOol00Woo00<007ooOol03Goo
000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001NOol00`00Oomoo`02Ool00`00Oomoo`0=Ool0
00Yoo`04001oogoo000:Ool01@00Oomoogoo0000H7oo00D007ooOomoo`0000moo`002Woo00@007oo
Ool000Moo`D0009oo`8005moo`05001oogooOol0000?Ool000Yoo`04001oogoo0007Ool01000Oomo
o`000goo00<007ooOol0GWoo00@007ooOol0011oo`002Woo00@007ooOol000Qoo`03001oo`0000=o
o`8005moo`04001oogoo000@Ool000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1OOol00`00
Ool0000@Ool000]oo`8000]oo`04001oogooOol2001QOol00`00Oomoo`0?Ool001aoo`03001oogoo
079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2
001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
0`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol0
00]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02
Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<0
00=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2
001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00
Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomo
o`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1840\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .22902 m
.008 .22746 L
.012 .22665 L
.016 .22521 L
.02 .22302 L
.024 .21959 L
.028 .21482 L
.032 .20908 L
.036 .20235 L
.04 .19547 L
.044 .18851 L
.048 .18229 L
.052 .17689 L
.056 .17282 L
.06 .17011 L
.064 .16891 L
.068 .16916 L
.072 .17073 L
.076 .17349 L
.08 .17716 L
.084 .18157 L
.088 .18642 L
.092 .19152 L
.096 .19663 L
.1 .20159 L
.104 .20625 L
.108 .21052 L
.112 .21434 L
.116 .21768 L
.12 .22053 L
.124 .22293 L
.128 .22492 L
.132 .22653 L
.136 .22781 L
.14 .22882 L
.144 .22961 L
.148 .2302 L
.152 .23065 L
.156 .23099 L
.16 .23123 L
.164 .23141 L
.168 .23153 L
.172 .23162 L
.176 .23168 L
.18 .23173 L
.184 .23176 L
.188 .23178 L
.192 .23179 L
.196 .2318 L
.2 .2318 L
Mistroke
.204 .23181 L
.208 .23181 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23182 L
.796 .23182 L
.8 .23182 L
Mistroke
.804 .23182 L
.808 .23182 L
.812 .23183 L
.816 .23184 L
.82 .23185 L
.824 .23187 L
.828 .2319 L
.832 .23194 L
.836 .23201 L
.84 .2321 L
.844 .23222 L
.848 .2324 L
.852 .23264 L
.856 .23298 L
.86 .23343 L
.864 .23403 L
.868 .23481 L
.872 .23582 L
.876 .23711 L
.88 .23871 L
.884 .2407 L
.888 .2431 L
.892 .24595 L
.896 .24928 L
.9 .25309 L
.904 .25736 L
.908 .26202 L
.912 .26698 L
.916 .2721 L
.92 .2772 L
.924 .28205 L
.928 .28643 L
.932 .29007 L
.936 .29276 L
.94 .29429 L
.944 .29452 L
.948 .29339 L
.952 .29085 L
.956 .28705 L
.96 .282 L
.964 .27602 L
.968 .26916 L
.972 .26188 L
.976 .2543 L
.98 .24696 L
.984 .24017 L
.988 .23446 L
.992 .23043 L
.996 .22844 L
1 .2293 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .36285 m
.008 .36118 L
.012 .35471 L
.016 .34472 L
.02 .33065 L
.024 .31309 L
.028 .29269 L
.032 .26965 L
.036 .24562 L
.04 .22083 L
.044 .19731 L
.048 .17553 L
.052 .15718 L
.056 .14278 L
.06 .13326 L
.064 .1288 L
.068 .12944 L
.072 .13492 L
.076 .14457 L
.08 .15773 L
.084 .17343 L
.088 .19086 L
.092 .20908 L
.096 .22741 L
.1 .24513 L
.104 .26181 L
.108 .27707 L
.112 .29072 L
.116 .30264 L
.12 .31286 L
.124 .32145 L
.128 .32854 L
.132 .33429 L
.136 .33888 L
.14 .34249 L
.144 .34528 L
.148 .34742 L
.152 .34902 L
.156 .35021 L
.16 .35108 L
.164 .35171 L
.168 .35217 L
.172 .35248 L
.176 .3527 L
.18 .35286 L
.184 .35296 L
.188 .35303 L
.192 .35308 L
.196 .35311 L
.2 .35313 L
Mistroke
.204 .35314 L
.208 .35315 L
.212 .35315 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35315 L
.8 .35315 L
Mistroke
.804 .35314 L
.808 .35313 L
.812 .35311 L
.816 .35308 L
.82 .35303 L
.824 .35296 L
.828 .35286 L
.832 .3527 L
.836 .35248 L
.84 .35217 L
.844 .35171 L
.848 .35108 L
.852 .35021 L
.856 .34902 L
.86 .34742 L
.864 .34528 L
.868 .34249 L
.872 .33888 L
.876 .33429 L
.88 .32854 L
.884 .32145 L
.888 .31286 L
.892 .30264 L
.896 .29072 L
.9 .27707 L
.904 .26181 L
.908 .24513 L
.912 .22742 L
.916 .20911 L
.92 .1909 L
.924 .17346 L
.928 .15775 L
.932 .14454 L
.936 .13483 L
.94 .12928 L
.944 .12861 L
.948 .13314 L
.952 .14286 L
.956 .15759 L
.96 .17629 L
.964 .19843 L
.968 .22198 L
.972 .24639 L
.976 .26931 L
.98 .29056 L
.984 .30849 L
.988 .32339 L
.992 .33527 L
.996 .34456 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .22856 L
.012 .22476 L
.016 .21834 L
.02 .20918 L
.024 .19673 L
.028 .18094 L
.032 .16278 L
.036 .14249 L
.04 .12188 L
.044 .10147 L
.048 .08305 L
.052 .06719 L
.056 .05506 L
.06 .04698 L
.064 .04329 L
.068 .04393 L
.072 .04855 L
.076 .05675 L
.08 .06776 L
.084 .08098 L
.088 .09556 L
.092 .11088 L
.096 .12623 L
.1 .14112 L
.104 .15512 L
.108 .16794 L
.112 .17939 L
.116 .18941 L
.12 .19798 L
.124 .20519 L
.128 .21114 L
.132 .21597 L
.136 .21983 L
.14 .22285 L
.144 .2252 L
.148 .22699 L
.152 .22834 L
.156 .22934 L
.16 .23007 L
.164 .2306 L
.168 .23098 L
.172 .23124 L
.176 .23143 L
.18 .23156 L
.184 .23164 L
.188 .2317 L
.192 .23174 L
.196 .23177 L
.2 .23178 L
Mistroke
.204 .2318 L
.208 .2318 L
.212 .23181 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23182 L
.788 .23182 L
.792 .23182 L
.796 .23182 L
.8 .23183 L
Mistroke
.804 .23183 L
.808 .23184 L
.812 .23186 L
.816 .23189 L
.82 .23192 L
.824 .23198 L
.828 .23207 L
.832 .2322 L
.836 .23238 L
.84 .23265 L
.844 .23303 L
.848 .23356 L
.852 .23429 L
.856 .23529 L
.86 .23664 L
.864 .23843 L
.868 .24077 L
.872 .2438 L
.876 .24766 L
.88 .25248 L
.884 .25844 L
.888 .26564 L
.892 .27422 L
.896 .28423 L
.9 .29568 L
.904 .3085 L
.908 .3225 L
.912 .3374 L
.916 .35276 L
.92 .36809 L
.924 .38267 L
.928 .39587 L
.932 .40684 L
.936 .41498 L
.94 .41955 L
.944 .42018 L
.948 .41655 L
.952 .40862 L
.956 .39677 L
.96 .38121 L
.964 .36309 L
.968 .34271 L
.972 .32178 L
.976 .30056 L
.98 .28089 L
.984 .26304 L
.988 .24835 L
.992 .23736 L
.996 .23035 L
1 .22834 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool20004Ool3000:Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo009oo`800003Ool0000000Eoo`@000=oo`04001oogoo0009Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomo
o`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00
Ool40003Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool20003Ool01000Oomoogoo0P0017oo
00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P00
0goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00D007ooOomoo`00
00Eoo`8000=oo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003
Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`80009oo`03001o
ogoo00Aoo`8006Qoo`0077oo00@007oo000000Qoo`8006Moo`0077ooJ@0037oo000LOol01@00Oomo
ogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000Woo0`00
0Woo00D007ooOomoo`00009oo`03001oo`0000aoo`0077oo0P00FWoo0P001goo00<007ooOol03Goo
000LOol00`00Oomoo`1KOol00`00Oomoo`04Ool00`00Oomoo`0=Ool001aoo`8005aoo`8000Aoo`03
001oogoo00ioo`0077oo00<007ooOol0G7oo0P000Woo0P0047oo000;Ool20004Ool01000Oomoogoo
1@000Woo0P00GWoo0P0000=oo`00Ool047oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03
001oogoo05ioo`80019oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@0
07ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P00
2Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009o
o`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool5
0002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007oo
Ool0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Ao
o`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000
Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00
Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003
Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00
Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol0
0`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001i
Ool001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00
N7oo000:Ool01000Oomoo`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8007=oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2
001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool40003Ool2
001cOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0008Ool00`00Oomoo`03Ool2001cOol000]oo`8000Yoo`8000=oo`03001oogoo079oo`0077oo0P00
17oo0`00F7oo0P004Woo000LOol00`00Oomoo`03Ool00`00Ool0001HOol00`00Ool0000AOol000]o
o`8000Aoo`03001oogoo00=oo`<0009oo`8000Aoo`03001oo`0005Qoo`03001oo`00015oo`002Woo
00@007ooOol000Yoo`05001oogooOol00005Ool00`00Ool0001GOol01000Oomoo`004Goo0003Ool5
0002Ool01000Oomoo`001goo1@000Woo00<007ooOol00goo00@007ooOol005Ioo`04001oogoo000A
Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P000goo00D007ooOomoo`0005Ioo`04001o
ogoo000AOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`02Ool01@00Oomoogoo
0000EGoo00D007ooOomoo`00015oo`002Woo00@007ooOol000Uoo`8000=oo`8000=oo`05001oogoo
Ool0001EOol00`00Oomoo`02Ool00`00Oomoo`0>Ool000]oo`8000]oo`05001oogooOol00004Ool0
0`00Oomoo`02Ool00`00Oomoo`1BOol00`00Oomoo`02Ool00`00Oomoo`0>Ool001aoo`80009oo`03
001oogoo00=oo`03001oogoo059oo`03001oogoo009oo`03001oogoo00ioo`0077oo00D007ooOomo
o`0000Eoo`03001oogoo055oo`03001oogoo00=oo`03001oogoo00ioo`002goo0P0017oo00@007oo
Oomoo`D0009oo`80009oo`03001oogoo00=oo`03001oogoo055oo`03001oogoo00Aoo`03001oogoo
00eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoogoo00001Woo00<007ooOol0
D7oo00<007ooOol017oo00<007ooOol03Goo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol0
0Woo00D007ooOomoo`0000Ioo`03001oogoo051oo`03001oogoo00Aoo`03001oogoo00eoo`002Woo
00@007ooOol000Yoo`04001oogooOol20002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool30004Ool2
0009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20004Ool6
00000goo000000020004Ool20006Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00D0
07ooOomoo`0000Ioo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol01goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009o
o`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`800003Ool007oo00Moo`03001oogoo00Aoo`04001oogoo0002Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0009o
o`05001oogooOol00003Ool01@00Oomoogoo00000Woo00@007ooOol000Eoo`002goo0P002Goo0`00
0goo00@007ooOol000Qoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01000Oomoo`00
0goo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P0000=oo`00Ool01goo00<007ooOol01000
0goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Oomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`06001oogoo
001oo`000Woo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol01000Oomoo`002Goo
00<007oo00001Woo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P00
0goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00H0
07ooOol007oo0002Ool01P00Oomoogoo001oo`8000Eoo`04001oogoo0005Ool001aoo`04001oogoo
0009Ool00`00Ool000040003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo
1@000goo0P001Woo0`0017oo0P0017oo0P0000=oo`0000000goo0`000Woo1@000goo0P001Woo000L
Ool3000;Ool00`00Oomoo`19Ool2000;Ool00`00Oomoo`0;Ool001aoo`03001oo`0000aoo`8004Qo
o`8000aoo`03001oogoo00]oo`0077ooJ@0037oo000LOol2000COol00`00Oomoo`0BOol00`00Oomo
o`0AOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0:Ool001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000;Ool2
0004Ool01000Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03
001oogoo079oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol0
00Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`00
0goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007oo
Ool00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@0
07ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool2
0003Ool00`00Oomoo`1bOol000]oo`8000]oo`05001oogooOol0001dOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol00goo0P00KGoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool20004Ool00`00
Ool0001/Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00001Goo00<007oo0000K7oo0003Ool5
0002Ool01000Oomoo`001goo1@000Woo0P0017oo00<007oo0000K7oo000:Ool01000Oomoo`001goo
00@007ooOol000=oo`03001oogoo009oo`05001oogooOol0001[Ool000Yoo`04001oogoo0008Ool0
0`00Ool00003Ool20003Ool01@00Oomoogoo0000Jgoo000:Ool01000Oomoo`002Goo0P000goo00<0
07ooOol00Woo00D007ooOomoo`0006]oo`002goo0P002goo00@007ooOomoo`8000=oo`03001oogoo
009oo`03001oogoo06Qoo`0077oo00D007ooOomoo`0000Eoo`03001oogoo06Qoo`002goo0P0017oo
00@007ooOomoo`D0009oo`80009oo`03001oogoo00=oo`03001oogoo06Qoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01@00Oomoogoo00001Woo00<007ooOol00Woo0`0017oo0P002Goo0`00
17oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`00
17oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo0P000Woo00<007ooOol0
17oo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol0
0goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0000=oo`03
001oogoo00Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P000Woo00<0
07ooOol017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eo
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool01000Oomo
o`0027oo00<007ooOol010000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]o
o`8000Uoo`<000=oo`800003Ool007oo00Moo`04001oogoo0006Ool01000Oomoo`0027oo0P0017oo
00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool0
1000Oomoo`001Goo000LOol01000Oomoo`002Goo00<007oo000010000goo0P002Woo00<007ooOol0
0goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009o
o`D000=oo`8000Ioo`0077oo0`002Woo00<007ooOol0IGoo000LOol00`00Ool0000;Ool00`00Oomo
o`1TOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomo
ogoo00000goo00@007ooOomoo`D000=oo`05001oogooOol00003Ool2000<Ool001aoo`8005Qoo`80
00Yoo`03001oogoo00aoo`0077oo00<007ooOol0F7oo0P002Goo00<007ooOol037oo000LOol2001J
Ool00`00Oomoo`07Ool00`00Oomoo`0<Ool001aoo`03001oogoo05Uoo`03001oogoo00Moo`03001o
ogoo00aoo`002goo0P0017oo00@007ooOomoo`D0009oo`8005]oo`03001oogoo00Eoo`03001oogoo
00eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1JOol00`00Oomoo`05Ool0
0`00Oomoo`0=Ool000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001LOol00`00Oomoo`04Ool0
0`00Oomoo`0=Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000GGoo00<007ooOol017oo00<0
07ooOol03Goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8005aoo`03001oogoo00Ao
o`03001oogoo00eoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1KOol0
0`00Oomoo`04Ool00`00Oomoo`0=Ool000]oo`8000Uoo`<000=oo`8005aoo`03001oogoo00=oo`03
001oogoo00ioo`0077oo00<007ooOol0G7oo00<007ooOol00Woo00<007ooOol03Woo000;Ool20004
Ool00`00Oomoo`03Ool30002Ool2001MOol00`00Oomoo`02Ool00`00Oomoo`0>Ool000Yoo`04001o
ogoo000:Ool01@00Oomoogoo0000GWoo00<007ooOol00Woo00<007ooOol03Woo000:Ool01000Oomo
o`001goo1@000Woo0P00GWoo00@007ooOol0015oo`002Woo00@007ooOol000Moo`04001oogoo0003
Ool00`00Oomoo`1MOol01000Oomoo`004Goo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00
GWoo00@007ooOol0015oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo05ioo`03001oo`00
015oo`002goo0P002goo00@007ooOomoo`8005moo`80019oo`0077oo00<007ooOol0LWoo000;Ool2
0004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo
00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Ao
o`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo
0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`80
07=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo
00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`00
5goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo
0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1880\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .2296 m
.008 .23121 L
.012 .23273 L
.016 .23322 L
.02 .23304 L
.024 .2315 L
.028 .22897 L
.032 .22519 L
.036 .22038 L
.04 .21472 L
.044 .20827 L
.048 .20155 L
.052 .19459 L
.056 .18801 L
.06 .18192 L
.064 .17683 L
.068 .17283 L
.072 .17023 L
.076 .16904 L
.08 .16927 L
.084 .17085 L
.088 .17358 L
.092 .17728 L
.096 .18167 L
.1 .18654 L
.104 .19162 L
.108 .19673 L
.112 .20166 L
.116 .2063 L
.12 .21055 L
.124 .21435 L
.128 .21767 L
.132 .22052 L
.136 .22292 L
.14 .2249 L
.144 .22651 L
.148 .22779 L
.152 .2288 L
.156 .22959 L
.16 .23019 L
.164 .23064 L
.168 .23097 L
.172 .23122 L
.176 .2314 L
.18 .23153 L
.184 .23162 L
.188 .23168 L
.192 .23173 L
.196 .23176 L
.2 .23178 L
Mistroke
.204 .23179 L
.208 .2318 L
.212 .2318 L
.216 .23181 L
.22 .23181 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23182 L
.784 .23182 L
.788 .23182 L
.792 .23182 L
.796 .23182 L
.8 .23183 L
Mistroke
.804 .23184 L
.808 .23185 L
.812 .23187 L
.816 .2319 L
.82 .23195 L
.824 .23201 L
.828 .2321 L
.832 .23223 L
.836 .23241 L
.84 .23266 L
.844 .23299 L
.848 .23344 L
.852 .23404 L
.856 .23483 L
.86 .23584 L
.864 .23713 L
.868 .23873 L
.872 .24071 L
.876 .24311 L
.88 .24595 L
.884 .24927 L
.888 .25307 L
.892 .25731 L
.896 .26195 L
.9 .26688 L
.904 .27197 L
.908 .27705 L
.912 .2819 L
.916 .2863 L
.92 .29 L
.924 .29274 L
.928 .29433 L
.932 .29459 L
.936 .29341 L
.94 .29078 L
.944 .28676 L
.948 .28159 L
.952 .27546 L
.956 .26884 L
.96 .26199 L
.964 .2554 L
.968 .24928 L
.972 .24393 L
.976 .23942 L
.98 .23568 L
.984 .23275 L
.988 .23027 L
.992 .22838 L
.996 .22677 L
1 .22582 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .36083 m
.008 .36086 L
.012 .35985 L
.016 .35845 L
.02 .35485 L
.024 .34928 L
.028 .34031 L
.032 .3279 L
.036 .3118 L
.04 .29213 L
.044 .26988 L
.048 .24559 L
.052 .22101 L
.056 .19696 L
.06 .17525 L
.064 .15668 L
.068 .14246 L
.072 .13304 L
.076 .1288 L
.08 .12967 L
.084 .13527 L
.088 .14507 L
.092 .15822 L
.096 .17395 L
.1 .1913 L
.104 .20949 L
.108 .22771 L
.112 .24538 L
.116 .26198 L
.12 .27718 L
.124 .29076 L
.128 .30265 L
.132 .31283 L
.136 .32139 L
.14 .32847 L
.144 .33421 L
.148 .33881 L
.152 .34242 L
.156 .34522 L
.16 .34736 L
.164 .34897 L
.168 .35017 L
.172 .35105 L
.176 .35169 L
.18 .35215 L
.184 .35247 L
.188 .35269 L
.192 .35285 L
.196 .35295 L
.2 .35303 L
Mistroke
.204 .35307 L
.208 .35311 L
.212 .35313 L
.216 .35314 L
.22 .35315 L
.224 .35315 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35315 L
.788 .35315 L
.792 .35314 L
.796 .35313 L
.8 .35311 L
Mistroke
.804 .35307 L
.808 .35303 L
.812 .35295 L
.816 .35285 L
.82 .35269 L
.824 .35247 L
.828 .35215 L
.832 .35169 L
.836 .35105 L
.84 .35017 L
.844 .34897 L
.848 .34736 L
.852 .34522 L
.856 .34242 L
.86 .33881 L
.864 .33421 L
.868 .32847 L
.872 .32139 L
.876 .31283 L
.88 .30265 L
.884 .29076 L
.888 .27718 L
.892 .26198 L
.896 .24538 L
.9 .22772 L
.904 .20949 L
.908 .1913 L
.912 .17395 L
.916 .15821 L
.92 .14507 L
.924 .13528 L
.928 .1297 L
.932 .12885 L
.936 .13308 L
.94 .14248 L
.944 .15664 L
.948 .17514 L
.952 .19676 L
.956 .22081 L
.96 .24545 L
.964 .26999 L
.968 .29256 L
.972 .31267 L
.976 .32911 L
.98 .34158 L
.984 .35012 L
.988 .3545 L
.992 .35619 L
.996 .35493 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23405 L
.012 .23605 L
.016 .23606 L
.02 .23439 L
.024 .22967 L
.028 .22216 L
.032 .21131 L
.036 .19731 L
.04 .18063 L
.044 .16157 L
.048 .14136 L
.052 .12054 L
.056 .10064 L
.06 .08234 L
.064 .06692 L
.068 .05493 L
.072 .04706 L
.076 .04348 L
.08 .04418 L
.084 .0489 L
.088 .05709 L
.092 .06817 L
.096 .08135 L
.1 .09594 L
.104 .11119 L
.108 .12651 L
.112 .14133 L
.116 .15527 L
.12 .16803 L
.124 .17943 L
.128 .18941 L
.132 .19795 L
.136 .20514 L
.14 .21108 L
.144 .21591 L
.148 .21976 L
.152 .22279 L
.156 .22515 L
.16 .22694 L
.164 .2283 L
.168 .2293 L
.172 .23004 L
.176 .23058 L
.18 .23096 L
.184 .23123 L
.188 .23142 L
.192 .23155 L
.196 .23164 L
.2 .2317 L
Mistroke
.204 .23174 L
.208 .23177 L
.212 .23178 L
.216 .23179 L
.22 .2318 L
.224 .23181 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23182 L
.776 .23182 L
.78 .23182 L
.784 .23182 L
.788 .23183 L
.792 .23183 L
.796 .23184 L
.8 .23186 L
Mistroke
.804 .23189 L
.808 .23193 L
.812 .23199 L
.816 .23208 L
.82 .23221 L
.824 .2324 L
.828 .23267 L
.832 .23305 L
.836 .23359 L
.84 .23432 L
.844 .23533 L
.848 .23668 L
.852 .23848 L
.856 .24083 L
.86 .24387 L
.864 .24772 L
.868 .25254 L
.872 .25848 L
.876 .26567 L
.88 .27422 L
.884 .28419 L
.888 .2956 L
.892 .30836 L
.896 .3223 L
.9 .33712 L
.904 .35243 L
.908 .36768 L
.912 .38227 L
.916 .39545 L
.92 .40654 L
.924 .41473 L
.928 .41947 L
.932 .42018 L
.936 .4166 L
.94 .40871 L
.944 .39667 L
.948 .38119 L
.952 .36281 L
.956 .34291 L
.96 .32215 L
.964 .30214 L
.968 .28336 L
.972 .26704 L
.976 .25334 L
.98 .24254 L
.984 .23466 L
.988 .22894 L
.992 .22567 L
.996 .22346 L
1 .22311 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool20005Ool30009Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo00=oo`80009oo`03001oogoo009oo`@000=oo`04001oogoo0009
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000
Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomo
o`00Ool40003Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool20004Ool00`00Oomoo`02Ool0
1@00Oomoogoo00001Woo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo
0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol0
0Woo00<007ooOol00goo0P000Woo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@0
07ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo
0P000goo00<007ooOol017oo0P00Igoo000LOol01@00Oomoogoo000027oo0P00IWoo000LOomY000<
Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`04001o
ogooOol50003Ool01`00Oomoogoo001oo`00009oo`03001oogoo00Yoo`0077oo0P00FGoo0P001goo
0P003goo000LOol00`00Oomoo`1IOol20005Ool2000@Ool001aoo`8005]oo`8000Aoo`03001oogoo
00moo`0077oo00<007ooOol0Fgoo00@007ooOomoo`80015oo`002goo0P0017oo00@007ooOomoo`D0
009oo`8005eoo`04001oo`00000BOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007oo
Ool0GGoo0P004goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00Lgoo000:Ool01000Oomo
o`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001c
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool3
0003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00
Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`D0009o
o`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1b
Ool000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<0
07ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo
0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol0
00Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`80
07=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo
079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001o
ogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`00
5goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3001hOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P00Lgoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`@000=oo`8007=o
o`002Woo00@007ooOol000Moo`03001oogoo00Aoo`03001oogoo079oo`002Woo00@007ooOol000Qo
o`03001oogoo00=oo`8007=oo`002goo0P002Woo0P000goo00<007ooOol0LWoo000LOol20006Ool2
001FOol2000COol001aoo`03001oogoo00Aoo`03001oo`0005Eoo`03001oo`0001=oo`002goo0P00
17oo00<007ooOol00goo0`000Woo0P001Goo00<007oo0000EGoo00<007oo00004goo000:Ool01000
Oomoo`002Woo00D007ooOomoo`0000Ioo`04001oogoo001DOol01000Oomoo`004Woo0003Ool50002
Ool01000Oomoo`001goo1@000Woo00<007ooOol017oo00@007ooOol005=oo`05001oogooOol0000B
Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P0017oo00D007ooOomoo`0005=oo`05001o
ogooOol0000BOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`1@Ool01@00Oomoogoo00004Woo000:Ool01000Oomoo`002Goo0P000goo0P00
17oo00<007ooOol00Woo00<007ooOol0D7oo00<007ooOol00Woo00<007ooOol03goo000;Ool2000;
Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol0D7oo00<007ooOol00Woo00<007oo
Ool03goo000LOol20004Ool00`00Oomoo`02Ool00`00Oomoo`1@Ool00`00Oomoo`02Ool00`00Oomo
o`0?Ool001aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo04moo`03001oogoo00=oo`03
001oogoo00moo`002goo0P0017oo00@007ooOomoo`D0009oo`8000=oo`03001oogoo00=oo`03001o
ogoo04moo`03001oogoo00=oo`03001oogoo00moo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`1>Ool00`00Oomoo`03Ool00`00Oomoo`0?
Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Oomoo`1=Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool000Yoo`04001oogoo000:Ool01000
Oomoogoo0P000goo00<007ooOol017oo00@007ooOomoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`80
00Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`80009oo`03001oogoo00H00004Ool00000
0004Ool20006Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00<0
07ooOol01Goo00<007oo00000goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`06001oogoo001oo`000goo00<007ooOol00`00
0goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool20002Ool00`00Oomoo`06Ool00`00Oomoo`03Ool01000Oomoo`000Woo00<007ooOol01goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`06001oogoo001oo`0017oo00@007oo
Ool000Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Uoo`<000=oo`05001oogooOol0
0008Ool00`00Oomoo`03Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D0
07ooOomoo`00009oo`04001oogoo0002Ool00`00Ool00005Ool00`00Ool00004Ool01000Oomoo`00
0Woo00<007ooOol00goo000LOol20002Ool00`00Oomoo`06Ool00`00Ool000030003Ool01000Oomo
o`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo
00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00P000goo00@0
07ooOomoo`H000=oo`04001oogoo0005Ool001aoo`05001oogooOol00009Ool20006Ool01000Oomo
o`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000
Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`020003Ool01`00Oomo
ogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`05001oogooOol00009Ool60003Ool2000:Ool0
0`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0`00
1Goo0`000Woo1@000goo0P001Woo000LOol20002Ool00`00Oomoo`08Ool20018Ool2000:Ool00`00
Oomoo`0=Ool001aoo`04001oogoo000<Ool20015Ool3000;Ool00`00Oomoo`0=Ool001aoofT000ao
o`0077oo0P004goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Woo
00<007ooOol02Woo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`002goo0P0017oo00@007ooOomoo`D0009oo`8007=oo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0009Ool0
0`00Oomoo`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000L
Ool00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007oo
Ool000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04
001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo
00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool0
1@00Oomoogoo0000M7oo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo00Eoo`03001oogoo06Yoo`00
2goo0P0017oo00<007ooOol00goo0`000Woo0P001Goo00<007oo0000Jgoo000:Ool01000Oomoo`00
2Woo00D007ooOomoo`0000Ioo`03001oo`0006]oo`000goo1@000Woo00@007ooOol000Moo`D0009o
o`8000Eoo`04001oogoo001ZOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0
0goo00D007ooOomoo`0006Yoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8000Aoo`03001o
ogoo009oo`03001oogoo06Moo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo06Moo`002goo0P002goo00@007ooOomoo`8000Aoo`03001oogoo009oo`03
001oogoo06Moo`0077oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0Igoo000;Ool20004
Ool01000Oomoogoo1@000Woo0P0017oo00<007ooOol00Woo00<007ooOol0Igoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`03001oogoo009oo`03001oogoo00Aoo`04001oogooOol30004Ool2
0009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool5
0002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool20003Ool0
0`00Oomoo`04Ool01000Oomoo`000goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool0
00=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000
17oo00<007ooOol017oo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool20003
Ool00`00Oomoo`05Ool00`00Oomoo`03Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`05
001oogooOol00008Ool00`00Ool000030003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol0
00Eoo`002goo0P002Goo0`000goo0P000Woo00<007ooOol01Woo00<007oo00001Woo00@007ooOol0
00Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol0
07oo00001Woo00@007ooOol000Eoo`0077oo00D007ooOomoo`0000Uoo`H000=oo`8000Yoo`03001o
ogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool3
0002Ool50003Ool20006Ool001aoo`80009oo`03001oogoo00Moo`8006Eoo`0077oo00@007ooOol0
00]oo`8006Aoo`0077ooJ@0037oo000LOol300000goo001oo`02Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D0
07ooOomoo`0000=oo`03001oo`0000@00003Ool007oo009oo`05001oogooOol00002Ool00`00Ool0
000<Ool001aoo`8005Moo`8000Yoo`03001oogoo00eoo`0077oo00<007ooOol0Egoo00<007ooOol0
27oo00<007ooOol03Goo000LOol2001IOol00`00Oomoo`07Ool00`00Oomoo`0=Ool001aoo`03001o
ogoo05Qoo`03001oogoo00Moo`03001oogoo00eoo`002goo0P0017oo00@007ooOomoo`D0009oo`80
05Yoo`03001oogoo00Eoo`03001oogoo00ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`1IOol00`00Oomoo`05Ool00`00Oomoo`0>Ool000Yoo`04001oogoo0009Ool00`00Oomo
o`02Ool2001JOol00`00Oomoo`05Ool00`00Oomoo`0>Ool000Yoo`04001oogoo000:Ool01@00Oomo
ogoo0000Fgoo00<007ooOol01Goo00<007ooOol03Woo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`8005]oo`03001oogoo00=oo`03001oogoo00moo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`1JOol00`00Oomoo`03Ool00`00Oomoo`0?Ool000]oo`8000Uoo`<0
00=oo`8005]oo`03001oogoo00=oo`03001oogoo00moo`0077oo00<007ooOol0Fgoo00<007ooOol0
0Woo00<007ooOol03goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001LOol00`00Oomoo`02
Ool00`00Oomoo`0?Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000GGoo00<007ooOol00Woo
00<007ooOol03goo000:Ool01000Oomoo`001goo1@000Woo0P00G7oo00D007ooOomoo`00019oo`00
2Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1LOol01000Oomoo`004Woo000:Ool0
1000Oomoo`0027oo00<007oo00000goo0P00GGoo00@007ooOol0019oo`002Woo00@007ooOol000Uo
o`8000=oo`03001oogoo05aoo`<001=oo`002goo0P002goo00@007ooOomoo`8005ioo`8001=oo`00
77oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03
001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Ao
o`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000
Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`80
00Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001o
ogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol0
01Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1920\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .2318 m
.008 .2326 L
.012 .23319 L
.016 .23351 L
.02 .2338 L
.024 .23368 L
.028 .23341 L
.032 .23242 L
.036 .23086 L
.04 .22828 L
.044 .22473 L
.048 .22014 L
.052 .21455 L
.056 .20827 L
.06 .20143 L
.064 .19455 L
.068 .18784 L
.072 .18181 L
.076 .17667 L
.08 .17276 L
.084 .17019 L
.088 .16906 L
.092 .16935 L
.096 .17096 L
.1 .17372 L
.104 .17741 L
.108 .18182 L
.112 .18666 L
.116 .19173 L
.12 .19681 L
.124 .20173 L
.128 .20635 L
.132 .21058 L
.136 .21436 L
.14 .21767 L
.144 .22051 L
.148 .2229 L
.152 .22488 L
.156 .22648 L
.16 .22777 L
.164 .22878 L
.168 .22957 L
.172 .23017 L
.176 .23063 L
.18 .23096 L
.184 .23121 L
.188 .23139 L
.192 .23152 L
.196 .23161 L
.2 .23168 L
Mistroke
.204 .23172 L
.208 .23175 L
.212 .23177 L
.216 .23179 L
.22 .2318 L
.224 .2318 L
.228 .23181 L
.232 .23181 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23182 L
.772 .23182 L
.776 .23182 L
.78 .23182 L
.784 .23182 L
.788 .23183 L
.792 .23184 L
.796 .23185 L
.8 .23187 L
Mistroke
.804 .2319 L
.808 .23195 L
.812 .23201 L
.816 .23211 L
.82 .23224 L
.824 .23242 L
.828 .23267 L
.832 .23301 L
.836 .23346 L
.84 .23406 L
.844 .23485 L
.848 .23586 L
.852 .23715 L
.856 .23875 L
.86 .24073 L
.864 .24312 L
.868 .24595 L
.872 .24926 L
.876 .25304 L
.88 .25726 L
.884 .26188 L
.888 .26679 L
.892 .27187 L
.896 .27693 L
.9 .28177 L
.904 .28617 L
.908 .28987 L
.912 .29263 L
.916 .29424 L
.92 .29453 L
.924 .29341 L
.928 .29084 L
.932 .28694 L
.936 .28182 L
.94 .27581 L
.944 .26913 L
.948 .26222 L
.952 .25537 L
.956 .249 L
.96 .24335 L
.964 .23867 L
.968 .2351 L
.972 .2326 L
.976 .23122 L
.98 .23059 L
.984 .23066 L
.988 .23091 L
.992 .2312 L
.996 .23116 L
1 .23067 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35308 m
.008 .35351 L
.012 .3547 L
.016 .35657 L
.02 .35811 L
.024 .35929 L
.028 .35863 L
.032 .35607 L
.036 .35029 L
.04 .34122 L
.044 .3283 L
.048 .31165 L
.052 .29173 L
.056 .26903 L
.06 .24485 L
.064 .22007 L
.068 .19633 L
.072 .17462 L
.076 .15634 L
.08 .14224 L
.084 .13303 L
.088 .12894 L
.092 .12993 L
.096 .13566 L
.1 .14549 L
.104 .15871 L
.108 .17441 L
.112 .19175 L
.116 .20987 L
.12 .22804 L
.124 .24562 L
.128 .26215 L
.132 .27728 L
.136 .29081 L
.14 .30265 L
.144 .31279 L
.148 .32134 L
.152 .3284 L
.156 .33414 L
.16 .33873 L
.164 .34235 L
.168 .34515 L
.172 .3473 L
.176 .34893 L
.18 .35013 L
.184 .35102 L
.188 .35166 L
.192 .35213 L
.196 .35245 L
.2 .35268 L
Mistroke
.204 .35284 L
.208 .35295 L
.212 .35302 L
.216 .35307 L
.22 .3531 L
.224 .35312 L
.228 .35314 L
.232 .35315 L
.236 .35315 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35315 L
.776 .35315 L
.78 .35314 L
.784 .35312 L
.788 .3531 L
.792 .35307 L
.796 .35302 L
.8 .35295 L
Mistroke
.804 .35284 L
.808 .35268 L
.812 .35245 L
.816 .35213 L
.82 .35166 L
.824 .35102 L
.828 .35013 L
.832 .34893 L
.836 .3473 L
.84 .34516 L
.844 .34235 L
.848 .33873 L
.852 .33414 L
.856 .3284 L
.86 .32134 L
.864 .3128 L
.868 .30265 L
.872 .29081 L
.876 .27728 L
.88 .26215 L
.884 .24562 L
.888 .22804 L
.892 .20987 L
.896 .19176 L
.9 .17441 L
.904 .15872 L
.908 .1455 L
.912 .13566 L
.916 .12993 L
.92 .12894 L
.924 .13302 L
.928 .14223 L
.932 .15635 L
.936 .17463 L
.94 .19637 L
.944 .22011 L
.948 .2449 L
.952 .26903 L
.956 .29168 L
.96 .3115 L
.964 .32808 L
.968 .34098 L
.972 .35014 L
.976 .35619 L
.98 .35912 L
.984 .36027 L
.988 .35942 L
.992 .35797 L
.996 .35559 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23313 L
.012 .23455 L
.016 .23573 L
.02 .23689 L
.024 .23712 L
.028 .23652 L
.032 .23389 L
.036 .22918 L
.04 .22149 L
.044 .21077 L
.048 .19692 L
.052 .18016 L
.056 .16126 L
.06 .14082 L
.064 .12014 L
.068 .10007 L
.072 .08194 L
.076 .06652 L
.08 .05473 L
.084 .04699 L
.088 .04356 L
.092 .04441 L
.096 .0492 L
.1 .05748 L
.104 .06856 L
.108 .08176 L
.112 .0963 L
.116 .11152 L
.12 .12677 L
.124 .14154 L
.128 .15541 L
.132 .16811 L
.136 .17947 L
.14 .18941 L
.144 .19793 L
.148 .2051 L
.152 .21102 L
.156 .21584 L
.16 .2197 L
.164 .22273 L
.168 .22509 L
.172 .2269 L
.176 .22826 L
.18 .22927 L
.184 .23002 L
.188 .23056 L
.192 .23094 L
.196 .23122 L
.2 .23141 L
Mistroke
.204 .23154 L
.208 .23163 L
.212 .2317 L
.216 .23174 L
.22 .23176 L
.224 .23178 L
.228 .23179 L
.232 .2318 L
.236 .23181 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23182 L
.764 .23182 L
.768 .23182 L
.772 .23182 L
.776 .23183 L
.78 .23183 L
.784 .23185 L
.788 .23186 L
.792 .23189 L
.796 .23193 L
.8 .23199 L
Mistroke
.804 .23208 L
.808 .23222 L
.812 .23241 L
.816 .23268 L
.82 .23307 L
.824 .23361 L
.828 .23436 L
.832 .23537 L
.836 .23673 L
.84 .23854 L
.844 .24089 L
.848 .24393 L
.852 .24778 L
.856 .2526 L
.86 .25853 L
.864 .2657 L
.868 .27422 L
.872 .28416 L
.876 .29551 L
.88 .30822 L
.884 .32209 L
.888 .33686 L
.892 .3521 L
.896 .36732 L
.9 .38186 L
.904 .39507 L
.908 .40614 L
.912 .41442 L
.916 .41921 L
.92 .42006 L
.924 .41663 L
.928 .40889 L
.932 .3971 L
.936 .38169 L
.94 .36359 L
.944 .34351 L
.948 .32285 L
.952 .30236 L
.956 .28342 L
.96 .26658 L
.964 .25267 L
.968 .24194 L
.972 .23433 L
.976 .22984 L
.98 .22752 L
.984 .22733 L
.988 .22784 L
.992 .22907 L
.996 .22983 L
1 .2302 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool20006Ool40007Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo00Eoo`04001oogoo0003Ool40003Ool01000Oomoo`002Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo
10000goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P001Goo00<007ooOol00Woo00@007oo
Ool000Ioo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03
001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00=oo`03001o
ogoo00Aoo`03001oo`0000@000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogoo
Ool50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`8000Ao
o`03001oogoo00Aoo`8006Ioo`0077oo00<007ooOol00Woo00<007ooOol01goo0P00I7oo000LOomY
000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`04
001oogooOol50003Ool01000Oomoogoo0P000goo00<007ooOol02Woo000LOol2001HOol20007Ool0
0`00Oomoo`0?Ool001aoo`03001oogoo05Qoo`8000Eoo`80015oo`0077oo0P00FWoo00<007ooOol0
0goo00<007ooOol047oo000LOol00`00Oomoo`1JOol01@00Oomoogoo00004goo000;Ool20004Ool0
1000Oomoogoo1@000Woo0P00G7oo00@007oo000001=oo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool00`00Oomoo`1KOol3000DOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001cOol0
00Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03
Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomo
o`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079o
o`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=o
o`03001oogoo079oo`002goo0P002goo00@007ooOomoo`8007=oo`0077oo00<007ooOol0LWoo000;
Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`00
2Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo
00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P00
2Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=o
o`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`00
77oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079o
o`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`00
5Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo
009oo`<007Qoo`002Woo00@007ooOol000Moo`05001oogooOol0001gOol000=oo`D0009oo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2001cOol000]oo`8000Uoo`<000=oo`03001oogoo079o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`80
07=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009o
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
10000goo0P00Lgoo000:Ool01000Oomoo`001goo00<007ooOol017oo00<007ooOol0LWoo000:Ool0
1000Oomoo`0027oo00<007ooOol00goo0P00Lgoo000;Ool2000:Ool20003Ool00`00Oomoo`1bOol0
01aoo`8000Moo`8005=oo`<001Aoo`0077oo00<007ooOol01Goo00@007ooOol0059oo`03001oo`00
01Aoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P001Woo00@007ooOol0059oo`03001oo`00
01Aoo`002Woo00@007ooOol000Yoo`05001oogooOol00007Ool01000Oomoo`00DWoo00@007ooOol0
01=oo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo00Eoo`04001oogoo001AOol0
1@00Oomoogoo00004goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`8000Ioo`04001oogoo
001AOol01@00Oomoogoo00004goo000:Ool01000Oomoo`0027oo00<007oo00000goo00<007ooOol0
17oo00<007ooOol00Woo00<007ooOol0CWoo00D007ooOomoo`0001=oo`002Woo00@007ooOol000Uo
o`8000=oo`8000Eoo`03001oogoo009oo`03001oogoo04ioo`05001oogooOol0000COol000]oo`80
00]oo`05001oogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`1=Ool00`00Oomoo`02Ool00`00
Oomoo`0AOol001aoo`8000Eoo`03001oogoo009oo`03001oogoo04eoo`03001oogoo00=oo`03001o
ogoo011oo`0077oo00<007ooOol017oo00<007ooOol00goo00<007ooOol0C7oo00<007ooOol00goo
00<007ooOol047oo000;Ool20004Ool01000Oomoogoo1@000Woo0P0017oo00<007ooOol017oo00<0
07ooOol0C7oo00<007ooOol00goo00<007ooOol047oo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo04aoo`03001oogoo00=oo`03001oogoo
011oo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
00Aoo`03001oogoo04]oo`03001oogoo00Aoo`03001oogoo011oo`002Woo00@007ooOol000Yoo`04
001oogooOol20004Ool00`00Oomoo`04Ool00`00Oomoo`030004Ool20009Ool30004Ool20004Ool2
0005Ool30003Ool30004Ool20005Ool50003Ool20004Ool200000goo001oo`02Ool50002Ool30004
Ool20006Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol00goo00<007oo
Ool01Goo0P000goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000
Oomoo`000Woo00@007ooOol0009oo`03001oogoo008000Aoo`06001oogoo001oo`000goo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool20004Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
17oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Ool00005Ool01000Oomo
o`000Woo00<007ooOol00goo000;Ool20009Ool30003Ool00`00Oomoo`03Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool20005Ool01000Oomoo`000Woo00<007ooOol0
0goo000LOol20004Ool00`00Oomoo`06Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007oo
Ool000Eoo`0077oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol017oo00@007ooOol000Qo
o`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo
00001Woo00@007ooOol000Eoo`0077oo00<007ooOol00Woo00<007ooOol01goo1@000goo0P002Woo
00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`80
00Ioo`<00003Ool0000000@000=oo`8000Ioo`0077oo0P000goo00<007ooOol027oo0P00AWoo00<0
07ooOol02Goo00<007ooOol03Woo000LOol01@00Oomoogoo000037oo0P00@goo0P0037oo00<007oo
Ool03Woo000LOomY000<Ool001aoo`04001oogoo000AOol00`00Oomoo`0BOol00`00Oomoo`0AOol0
0`00Oomoo`0BOol00`00Oomoo`0?Ool200000goo001oo`0;Ool001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000;Ool20004
Ool01000Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001o
ogoo079oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol000Yo
o`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol0
0goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007oo
Ool000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003
Ool00`00Oomoo`1bOol000]oo`8000]oo`05001oogooOol0001dOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol01Woo0P00JWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool20006Ool01000Ool0
0000JGoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0000Moo`04001oogoo001YOol000=oo`D0
009oo`04001oogoo0007Ool50002Ool20006Ool01000Oomoo`00JGoo000:Ool01000Oomoo`001goo
00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo001YOol000Yoo`04001oogoo0008Ool00`00
Ool00003Ool20006Ool01@00Oomoogoo0000J7oo000:Ool01000Oomoo`002Goo0P000goo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol0IWoo000;Ool2000;Ool01000Oomoogoo0P001Goo00<0
07ooOol00Woo00<007ooOol0IWoo000LOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool000]oo`8000Aoo`04001oogooOol50002Ool20005Ool00`00Oomoo`03Ool00`00Oomoo`1UOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00<007oo
Ool00`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P00
17oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol0
0Woo0P0017oo00<007ooOol017oo00<007oo00000goo00@007ooOol0009oo`03001oogoo00Moo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00
Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00
Oomoogoo00001Goo00<007ooOol017oo00<007ooOol00goo00@007ooOol0009oo`03001oogoo00Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool20004Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00=oo`03001oogoo00Eoo`D000=oo`04001oogoo0009Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool0
1000Oomoo`001Goo000;Ool20009Ool30003Ool20004Ool00`00Oomoo`06Ool00`00Oomoo`04Ool0
1000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04
Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L0
07ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`02Ool00`00Oomoo`07Ool5
0003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`00
17oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol20003Ool00`00Oomoo`08Ool00`00
Oomoo`1ROol001aoo`05001oogooOol0000;Ool2001SOol001aoofT000aoo`0077oo1@000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000Aoo`05001oogooOol00003Ool50003Ool01@00Oomoogoo00000goo00<007oo0000
0Woo00<007ooOol02Woo000LOol2001FOol00`00Oomoo`09Ool00`00Oomoo`0>Ool001aoo`03001o
ogoo05Ioo`03001oogoo00Qoo`03001oogoo00ioo`0077oo0P00F7oo00<007ooOol01Woo00<007oo
Ool03goo000LOol00`00Oomoo`1GOol00`00Oomoo`06Ool00`00Oomoo`0?Ool000]oo`8000Aoo`04
001oogooOol50002Ool2001HOol00`00Oomoo`06Ool00`00Oomoo`0?Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00<007ooOol0F7oo00<007ooOol01Goo00<007ooOol03goo000:Ool01000
Oomoo`002Goo00<007ooOol00Woo0P00FGoo00<007ooOol01Goo00<007ooOol03goo000:Ool01000
Oomoo`002Woo00D007ooOomoo`0005Yoo`03001oogoo00Eoo`03001oogoo00moo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool2001JOol00`00Oomoo`03Ool00`00Oomoo`0@Ool000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0FGoo00<007ooOol00goo00<007ooOol0
47oo000;Ool20009Ool30003Ool2001JOol00`00Oomoo`03Ool00`00Oomoo`0@Ool001aoo`03001o
ogoo05Uoo`03001oogoo00=oo`03001oogoo011oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Fgoo00D007ooOomoo`0001=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001LOol01@00
Oomoogoo00004goo000:Ool01000Oomoo`001goo1@000Woo0P00Fgoo00D007ooOomoo`0001=oo`00
2Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1KOol01000Oomoo`004goo000:Ool0
1000Oomoo`0027oo00<007oo00000goo0P00G7oo00@007ooOol001=oo`002Woo00@007ooOol000Uo
o`8000=oo`03001oogoo05]oo`03001oo`0001Aoo`002goo0P002goo00@007ooOomoo`8005eoo`80
01Aoo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo
00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:
Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Mo
o`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomo
o`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(1960\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23221 m
.008 .23201 L
.012 .23178 L
.016 .23179 L
.02 .23198 L
.024 .23235 L
.028 .2329 L
.032 .23333 L
.036 .23366 L
.04 .23344 L
.044 .2327 L
.048 .23102 L
.052 .22843 L
.056 .22476 L
.06 .22004 L
.064 .21442 L
.068 .20803 L
.072 .20125 L
.076 .1943 L
.08 .18768 L
.084 .18164 L
.088 .17658 L
.092 .17269 L
.096 .17018 L
.1 .16909 L
.104 .16942 L
.108 .17106 L
.112 .17384 L
.116 .17755 L
.12 .18194 L
.124 .18679 L
.128 .19184 L
.132 .1969 L
.136 .20179 L
.14 .2064 L
.144 .21061 L
.148 .21438 L
.152 .21768 L
.156 .2205 L
.16 .22289 L
.164 .22486 L
.168 .22646 L
.172 .22775 L
.176 .22876 L
.18 .22955 L
.184 .23016 L
.188 .23061 L
.192 .23095 L
.196 .2312 L
.2 .23139 L
Mistroke
.204 .23152 L
.208 .23161 L
.212 .23168 L
.216 .23172 L
.22 .23175 L
.224 .23177 L
.228 .23179 L
.232 .2318 L
.236 .2318 L
.24 .23181 L
.244 .23181 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23182 L
.76 .23182 L
.764 .23182 L
.768 .23182 L
.772 .23182 L
.776 .23183 L
.78 .23184 L
.784 .23185 L
.788 .23188 L
.792 .23191 L
.796 .23195 L
.8 .23202 L
Mistroke
.804 .23211 L
.808 .23224 L
.812 .23243 L
.816 .23268 L
.82 .23302 L
.824 .23348 L
.828 .23408 L
.832 .23487 L
.836 .23588 L
.84 .23717 L
.844 .23877 L
.848 .24074 L
.852 .24312 L
.856 .24595 L
.86 .24925 L
.864 .25301 L
.868 .25722 L
.872 .26181 L
.876 .26671 L
.88 .27176 L
.884 .27681 L
.888 .28164 L
.892 .28603 L
.896 .28974 L
.9 .29252 L
.904 .29416 L
.908 .2945 L
.912 .29342 L
.916 .29092 L
.92 .28704 L
.924 .28198 L
.928 .27594 L
.932 .26931 L
.936 .26238 L
.94 .25557 L
.944 .2492 L
.948 .24356 L
.952 .23887 L
.956 .23519 L
.96 .23259 L
.964 .23089 L
.968 .23005 L
.972 .22978 L
.976 .23001 L
.98 .23046 L
.984 .23108 L
.988 .23172 L
.992 .23227 L
.996 .23269 L
1 .23281 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35163 m
.008 .35171 L
.012 .35227 L
.016 .35309 L
.02 .35433 L
.024 .35595 L
.028 .35757 L
.032 .35916 L
.036 .35974 L
.04 .35914 L
.044 .35611 L
.048 .35038 L
.052 .34109 L
.056 .32809 L
.06 .31136 L
.064 .29121 L
.068 .26852 L
.072 .24412 L
.076 .21945 L
.08 .19562 L
.084 .17411 L
.088 .15591 L
.092 .14202 L
.096 .13298 L
.1 .12906 L
.104 .13021 L
.108 .13603 L
.112 .14595 L
.116 .15918 L
.12 .17489 L
.124 .19218 L
.128 .21025 L
.132 .22834 L
.136 .24586 L
.14 .26232 L
.144 .27738 L
.148 .29085 L
.152 .30265 L
.156 .31276 L
.16 .32128 L
.164 .32833 L
.168 .33406 L
.172 .33865 L
.176 .34228 L
.18 .34509 L
.184 .34725 L
.188 .34888 L
.192 .35009 L
.196 .35099 L
.2 .35164 L
Mistroke
.204 .35211 L
.208 .35244 L
.212 .35267 L
.216 .35283 L
.22 .35294 L
.224 .35302 L
.228 .35307 L
.232 .3531 L
.236 .35312 L
.24 .35314 L
.244 .35315 L
.248 .35315 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35315 L
.764 .35315 L
.768 .35314 L
.772 .35312 L
.776 .3531 L
.78 .35307 L
.784 .35302 L
.788 .35294 L
.792 .35283 L
.796 .35267 L
.8 .35244 L
Mistroke
.804 .35211 L
.808 .35164 L
.812 .35099 L
.816 .35009 L
.82 .34888 L
.824 .34725 L
.828 .34509 L
.832 .34228 L
.836 .33865 L
.84 .33406 L
.844 .32833 L
.848 .32128 L
.852 .31276 L
.856 .30265 L
.86 .29086 L
.864 .27738 L
.868 .26232 L
.872 .24586 L
.876 .22835 L
.88 .21026 L
.884 .19219 L
.888 .17489 L
.892 .15918 L
.896 .14596 L
.9 .13603 L
.904 .13021 L
.908 .12907 L
.912 .13298 L
.916 .14203 L
.92 .15592 L
.924 .17412 L
.928 .19562 L
.932 .21945 L
.936 .2441 L
.94 .26851 L
.944 .2912 L
.948 .31137 L
.952 .32812 L
.956 .34114 L
.96 .35044 L
.964 .35612 L
.968 .35908 L
.972 .35957 L
.976 .35892 L
.98 .3573 L
.984 .35581 L
.988 .35446 L
.992 .35365 L
.996 .35334 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23153 L
.012 .23139 L
.016 .23175 L
.02 .23256 L
.024 .23377 L
.028 .23531 L
.032 .23655 L
.036 .23735 L
.04 .23671 L
.044 .23437 L
.048 .22943 L
.052 .22168 L
.056 .21073 L
.06 .19664 L
.064 .17978 L
.068 .16065 L
.072 .14027 L
.076 .11948 L
.08 .09957 L
.084 .08145 L
.088 .06622 L
.092 .05454 L
.096 .04696 L
.1 .04367 L
.104 .04463 L
.108 .04953 L
.112 .05785 L
.116 .06897 L
.12 .08215 L
.124 .09668 L
.128 .11184 L
.132 .12703 L
.136 .14173 L
.14 .15555 L
.144 .1682 L
.148 .17951 L
.152 .18941 L
.156 .1979 L
.16 .20505 L
.164 .21097 L
.168 .21578 L
.172 .21963 L
.176 .22268 L
.18 .22504 L
.184 .22685 L
.188 .22822 L
.192 .22924 L
.196 .22999 L
.2 .23054 L
Mistroke
.204 .23093 L
.208 .23121 L
.212 .2314 L
.216 .23154 L
.22 .23163 L
.224 .23169 L
.228 .23173 L
.232 .23176 L
.236 .23178 L
.24 .23179 L
.244 .2318 L
.248 .23181 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23182 L
.752 .23182 L
.756 .23182 L
.76 .23182 L
.764 .23183 L
.768 .23183 L
.772 .23185 L
.776 .23186 L
.78 .23189 L
.784 .23194 L
.788 .232 L
.792 .23209 L
.796 .23223 L
.8 .23242 L
Mistroke
.804 .2327 L
.808 .23309 L
.812 .23364 L
.816 .23439 L
.82 .23541 L
.824 .23678 L
.828 .23859 L
.832 .24095 L
.836 .24399 L
.84 .24785 L
.844 .25266 L
.848 .25858 L
.852 .26573 L
.856 .27422 L
.86 .28412 L
.864 .29543 L
.868 .30808 L
.872 .32189 L
.876 .33659 L
.88 .35179 L
.884 .36695 L
.888 .38148 L
.892 .39465 L
.896 .40577 L
.9 .41409 L
.904 .419 L
.908 .41995 L
.912 .41667 L
.916 .40909 L
.92 .39741 L
.924 .38218 L
.928 .36405 L
.932 .34414 L
.936 .32334 L
.94 .30297 L
.944 .28384 L
.948 .26701 L
.952 .25293 L
.956 .24199 L
.96 .23424 L
.964 .22925 L
.968 .22687 L
.972 .22613 L
.976 .22688 L
.98 .22809 L
.984 .22974 L
.988 .23118 L
.992 .23235 L
.996 .23313 L
1 .23332 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool20008Ool30006Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo00Ioo`03001oogoo00800003Ool00000008000=oo`04001oogoo
0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool0
1000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007oo
Oomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool20006Ool00`00Oomoo`02
Ool00`00Ool00006Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool2
0003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool0
1000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`05
Ool00`00Oomoo`03Ool60003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo
1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol20005Ool0
0`00Oomoo`05Ool2001TOol001aoo`03001oogoo00=oo`03001oogoo00Moo`8006=oo`0077ooJ@00
37oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool00`00
Oomoo`030002Ool01@00Oomoogoo00000Woo0P0017oo00<007ooOol02Woo000LOol2001GOol20007
Ool00`00Oomoo`0@Ool001aoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo015oo`0077oo
0P00FGoo00<007ooOol00goo00<007ooOol04Goo000LOol00`00Oomoo`1IOol01@00Oomoogoo0000
57oo000;Ool20004Ool01000Oomoogoo1@000Woo0P00FWoo0P0000=oo`00Ool057oo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`03001oogoo05Yoo`8001Ioo`002Woo00@007ooOol000Uoo`03
001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0
001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomo
o`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool0
1000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000L
Ool00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<0
07ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo
00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001o
ogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P00
2Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007oo
Ool00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`00
5goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
2goo0P0017oo00<007ooOol00Woo0`00N7oo000:Ool01000Oomoo`001goo00D007ooOomoo`0007Mo
o`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo
0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002goo0P002Goo
0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<0
07ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo079oo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool40003Ool2001cOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool2001cOol000]oo`8000Yoo`80
00=oo`03001oogoo079oo`0077oo0P0027oo0P00DGoo0P005Woo000LOol00`00Oomoo`07Ool00`00
Ool0001@Ool00`00Ool0000EOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8000Qoo`03001o
o`00051oo`03001oo`0001Eoo`002Woo00@007ooOol000Yoo`05001oogooOol00008Ool01000Oomo
o`00Cgoo00@007ooOol001Eoo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo00Io
o`05001oogooOol0001>Ool01@00Oomoogoo000057oo000:Ool01000Oomoo`001goo00@007ooOol0
00=oo`8000Moo`05001oogooOol0001>Ool01@00Oomoogoo000057oo000:Ool01000Oomoo`0027oo
00<007oo00000goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0C7oo00D007ooOomoo`00
01Aoo`002Woo00@007ooOol000Uoo`8000=oo`8000Ioo`03001oogoo009oo`03001oogoo04aoo`05
001oogooOol0000DOol000]oo`8000]oo`05001oogooOol00007Ool00`00Oomoo`02Ool00`00Oomo
o`1;Ool00`00Oomoo`02Ool00`00Oomoo`0BOol001aoo`8000Ioo`03001oogoo009oo`03001oogoo
04]oo`03001oogoo00=oo`03001oogoo015oo`0077oo00<007ooOol01Goo00<007ooOol00goo00<0
07ooOol0BWoo00<007ooOol00goo00<007ooOol04Goo000;Ool20004Ool01000Oomoogoo1@000Woo
0P001Woo00<007ooOol00goo00<007ooOol0BWoo00<007ooOol00goo00<007ooOol04Goo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo04Uo
o`03001oogoo00Aoo`03001oogoo015oo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009o
o`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo04Uoo`03001oogoo00Aoo`03001oogoo015o
o`002Woo00@007ooOol000Yoo`04001oogooOol20005Ool00`00Oomoo`05Ool40004Ool20009Ool3
0004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool30004Ool50002Ool3
0004Ool20006Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol017oo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo0P0000Aoo`00Ool000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P001Goo00<0
07ooOol01Woo00@007ooOol0009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007oo000000Ioo`8000Ioo`04001oogoo0002Ool00`00Oomoo`03Ool0
00]oo`8000Uoo`<000=oo`03001oogoo00Aoo`03001oogoo00Ioo`04001oogoo0002Ool01000Oomo
o`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`05001oogoo001oo`020007Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol20005Ool00`00Oomoo`05Ool40003
Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomo
ogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo0000
00Aoo`03001oogoo00800003Ool00000008000=oo`04001oogoo0005Ool001aoo`03001oogoo00=o
o`03001oogoo00Ioo`8000Eoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol0
00Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`800003Ool007oo00=oo`03001oogoo00800003Ool007oo00Eoo`04001oogoo0005Ool001ao
o`03001oogoo00=oo`03001oogoo00Ioo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Io
o`04001oogooOol50003Ool20006Ool30004Ool20003Ool30006Ool400000goo000000030003Ool2
0006Ool001aoo`8000Aoo`03001oogoo00Uoo`03001oogoo049oo`03001oogoo00Uoo`03001oogoo
00moo`0077oo00<007ooOol00goo00<007ooOol02Goo0`00@7oo0P0037oo00<007ooOol03goo000L
OomY000<Ool001aoo`05001oogooOol0000@Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomo
o`0BOol00`00Oomoo`0>Ool20002Ool00`00Oomoo`0:Ool001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000;Ool20004Ool0
1000Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo
079oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05
001oogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo
0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`05001oogooOol0001dOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol01goo0P00JGoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool20008Ool3001XOol000Yo
o`04001oogoo000:Ool01@00Oomoogoo000027oo00@007ooOol006Qoo`000goo1@000Woo00@007oo
Ool000Moo`D0009oo`8000Moo`04001oogoo001XOol000Yoo`04001oogoo0007Ool01000Oomoo`00
0goo00<007ooOol01Woo00D007ooOomoo`0006Moo`002Woo00@007ooOol000Qoo`03001oo`0000=o
o`8000Moo`05001oogooOol0001WOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool00`00Oomoo`1UOol000]oo`8000]oo`04001oogooOol20006Ool00`00Oomoo`02
Ool00`00Oomoo`1UOol001aoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo06Eoo`002goo
0P0017oo00@007ooOomoo`D0009oo`8000Ioo`03001oogoo00=oo`03001oogoo06Aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Ool000020004
Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005
Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool20006
Ool00`00Oomoo`03Ool20003Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo
00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo
00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Yoo`05001oogooOol00006Ool0
0`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool20005Ool00`00Oomoo`05
Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002
Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
1000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Goo0`000goo
0P001Goo00<007ooOol01Goo0P001Goo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000
Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo
00<007ooOol00goo00<007ooOol01Woo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo
00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`00
77oo0P0017oo00<007ooOol027oo00<007ooOol0HGoo000LOol00`00Oomoo`03Ool00`00Oomoo`09
Ool00`00Oomoo`1POol001aoofT000aoo`0077oo00<007oo00000`000Woo00<007ooOol00Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Ao
o`05001oogooOol00002Ool60003Ool01@00Oomoogoo00000goo00@007ooOomoo`8000aoo`0077oo
0P00EGoo00<007ooOol02Goo00<007ooOol03goo000LOol00`00Oomoo`1DOol2000:Ool00`00Oomo
o`0?Ool001aoo`8005Ioo`03001oogoo00Moo`03001oogoo011oo`0077oo00<007ooOol0EWoo00<0
07ooOol01Woo00<007ooOol047oo000;Ool20004Ool01000Oomoogoo1@000Woo0P00Egoo00<007oo
Ool01Woo00<007ooOol047oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo05Mo
o`03001oogoo00Eoo`03001oogoo011oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8005Qo
o`03001oogoo00Aoo`03001oogoo015oo`002Woo00@007ooOol000Yoo`05001oogooOol0001IOol0
0`00Oomoo`04Ool00`00Oomoo`0AOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00
F7oo00<007ooOol017oo00<007ooOol04Goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo015oo`002goo0P002Goo0`000goo0P00FGoo
00<007ooOol00goo00<007ooOol04Goo000LOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomo
o`0AOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8005Yoo`05001oogooOol0000DOol000Yo
o`04001oogoo000:Ool01@00Oomoogoo0000Fgoo00D007ooOomoo`0001Aoo`002Woo00@007ooOol0
00Moo`D0009oo`8005Yoo`05001oogooOol0000DOol000Yoo`04001oogoo0007Ool01000Oomoo`00
0goo00<007ooOol0FGoo00D007ooOomoo`0001Aoo`002Woo00@007ooOol000Qoo`03001oo`0000=o
o`8005]oo`03001oo`0001Eoo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo05Yoo`03001o
o`0001Eoo`002goo0P002goo00@007ooOomoo`8005aoo`03001oogoo01Aoo`0077oo00<007ooOol0
LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
07=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03
001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`00
2goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009o
o`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`00
0goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`80
07=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001o
ogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo
07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2000\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23179 m
.008 .23159 L
.012 .23145 L
.016 .23141 L
.02 .23141 L
.024 .23156 L
.028 .23177 L
.032 .23213 L
.036 .2326 L
.04 .23307 L
.044 .23355 L
.048 .23373 L
.052 .23357 L
.056 .2327 L
.06 .23107 L
.064 .22841 L
.068 .22471 L
.072 .21997 L
.076 .21427 L
.08 .20788 L
.084 .20103 L
.088 .19413 L
.092 .18748 L
.096 .1815 L
.1 .17646 L
.104 .17264 L
.108 .17017 L
.112 .16913 L
.116 .1695 L
.12 .17117 L
.124 .17397 L
.128 .17768 L
.132 .18208 L
.136 .1869 L
.14 .19194 L
.144 .19698 L
.148 .20186 L
.152 .20644 L
.156 .21064 L
.16 .21439 L
.164 .21768 L
.168 .2205 L
.172 .22287 L
.176 .22484 L
.18 .22644 L
.184 .22773 L
.188 .22874 L
.192 .22953 L
.196 .23014 L
.2 .2306 L
Mistroke
.204 .23094 L
.208 .23119 L
.212 .23138 L
.216 .23151 L
.22 .23161 L
.224 .23167 L
.228 .23172 L
.232 .23175 L
.236 .23177 L
.24 .23179 L
.244 .2318 L
.248 .2318 L
.252 .23181 L
.256 .23181 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23182 L
.748 .23182 L
.752 .23182 L
.756 .23182 L
.76 .23183 L
.764 .23183 L
.768 .23184 L
.772 .23186 L
.776 .23188 L
.78 .23191 L
.784 .23196 L
.788 .23202 L
.792 .23212 L
.796 .23225 L
.8 .23243 L
Mistroke
.804 .23269 L
.808 .23303 L
.812 .23349 L
.816 .2341 L
.82 .23489 L
.824 .2359 L
.828 .23719 L
.832 .23879 L
.836 .24076 L
.84 .24313 L
.844 .24595 L
.848 .24923 L
.852 .25298 L
.856 .25717 L
.86 .26175 L
.864 .26662 L
.868 .27166 L
.872 .27669 L
.876 .28151 L
.88 .2859 L
.884 .28962 L
.888 .29242 L
.892 .29409 L
.896 .29446 L
.9 .29343 L
.904 .29097 L
.908 .28715 L
.912 .28212 L
.916 .27614 L
.92 .2695 L
.924 .26259 L
.928 .25574 L
.932 .24934 L
.936 .24364 L
.94 .23887 L
.944 .23516 L
.948 .23249 L
.952 .23084 L
.956 .23 L
.96 .22984 L
.964 .23006 L
.968 .23053 L
.972 .23103 L
.976 .23145 L
.98 .23174 L
.984 .23187 L
.988 .23193 L
.992 .23194 L
.996 .232 L
1 .23213 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3531 m
.008 .353 L
.012 .35279 L
.016 .35245 L
.02 .35235 L
.024 .35246 L
.028 .35311 L
.032 .35427 L
.036 .35585 L
.04 .35774 L
.044 .3593 L
.048 .3602 L
.052 .35943 L
.056 .35654 L
.06 .35056 L
.064 .34116 L
.068 .32795 L
.072 .31099 L
.076 .29074 L
.08 .26784 L
.084 .24347 L
.088 .21871 L
.092 .19501 L
.096 .17355 L
.1 .15554 L
.104 .1418 L
.108 .13295 L
.112 .1292 L
.116 .13047 L
.12 .13641 L
.124 .14639 L
.128 .15966 L
.132 .17535 L
.136 .19262 L
.14 .21063 L
.144 .22866 L
.148 .24609 L
.152 .26248 L
.156 .27748 L
.16 .2909 L
.164 .30265 L
.168 .31273 L
.172 .32122 L
.176 .32826 L
.18 .33399 L
.184 .33858 L
.188 .34221 L
.192 .34503 L
.196 .34719 L
.2 .34883 L
Mistroke
.204 .35005 L
.208 .35096 L
.212 .35161 L
.216 .35209 L
.22 .35242 L
.224 .35266 L
.228 .35282 L
.232 .35294 L
.236 .35301 L
.24 .35306 L
.244 .3531 L
.248 .35312 L
.252 .35314 L
.256 .35315 L
.26 .35315 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35315 L
.752 .35315 L
.756 .35314 L
.76 .35312 L
.764 .3531 L
.768 .35306 L
.772 .35301 L
.776 .35294 L
.78 .35282 L
.784 .35266 L
.788 .35242 L
.792 .35209 L
.796 .35161 L
.8 .35096 L
Mistroke
.804 .35005 L
.808 .34883 L
.812 .34719 L
.816 .34503 L
.82 .34221 L
.824 .33858 L
.828 .33399 L
.832 .32826 L
.836 .32123 L
.84 .31273 L
.844 .30265 L
.848 .2909 L
.852 .27748 L
.856 .26248 L
.86 .2461 L
.864 .22866 L
.868 .21063 L
.872 .19262 L
.876 .17536 L
.88 .15967 L
.884 .14639 L
.888 .13642 L
.892 .13048 L
.896 .1292 L
.9 .13295 L
.904 .1418 L
.908 .15555 L
.912 .17355 L
.916 .19502 L
.92 .2187 L
.924 .24347 L
.928 .26784 L
.932 .29075 L
.936 .31099 L
.94 .32795 L
.944 .34116 L
.948 .35055 L
.952 .35653 L
.956 .35942 L
.96 .36023 L
.964 .35933 L
.968 .35781 L
.972 .3559 L
.976 .35428 L
.98 .35303 L
.984 .35227 L
.988 .35207 L
.992 .35216 L
.996 .35264 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23144 L
.012 .23111 L
.016 .23095 L
.02 .23087 L
.024 .23115 L
.028 .23174 L
.032 .23274 L
.036 .23412 L
.04 .23559 L
.044 .23699 L
.048 .23759 L
.052 .23707 L
.056 .23453 L
.06 .22961 L
.064 .22168 L
.068 .2106 L
.072 .19639 L
.076 .17934 L
.08 .16018 L
.084 .13965 L
.088 .11893 L
.092 .09899 L
.096 .08102 L
.1 .06588 L
.104 .05436 L
.108 .04693 L
.112 .04378 L
.116 .04486 L
.12 .04984 L
.124 .05823 L
.128 .06936 L
.132 .08255 L
.136 .09704 L
.14 .11216 L
.144 .12729 L
.148 .14193 L
.152 .15569 L
.156 .16828 L
.16 .17955 L
.164 .18941 L
.168 .19787 L
.172 .205 L
.176 .21091 L
.18 .21572 L
.184 .21957 L
.188 .22262 L
.192 .22498 L
.196 .2268 L
.2 .22818 L
Mistroke
.204 .2292 L
.208 .22996 L
.212 .23051 L
.216 .23091 L
.22 .23119 L
.224 .23139 L
.228 .23153 L
.232 .23162 L
.236 .23169 L
.24 .23173 L
.244 .23176 L
.248 .23178 L
.252 .23179 L
.256 .2318 L
.26 .23181 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23182 L
.74 .23182 L
.744 .23182 L
.748 .23182 L
.752 .23183 L
.756 .23184 L
.76 .23185 L
.764 .23187 L
.768 .2319 L
.772 .23194 L
.776 .232 L
.78 .2321 L
.784 .23224 L
.788 .23243 L
.792 .23272 L
.796 .23311 L
.8 .23367 L
Mistroke
.804 .23442 L
.808 .23545 L
.812 .23683 L
.816 .23864 L
.82 .24101 L
.824 .24405 L
.828 .24791 L
.832 .25272 L
.836 .25862 L
.84 .26576 L
.844 .27422 L
.848 .28408 L
.852 .29534 L
.856 .30794 L
.86 .32169 L
.864 .33634 L
.868 .35147 L
.872 .36659 L
.876 .38108 L
.88 .39426 L
.884 .40539 L
.888 .41378 L
.892 .41876 L
.896 .41984 L
.9 .4167 L
.904 .40926 L
.908 .39775 L
.912 .3826 L
.916 .36463 L
.92 .34469 L
.924 .32398 L
.928 .30345 L
.932 .28429 L
.936 .26724 L
.94 .25303 L
.944 .24194 L
.948 .23401 L
.952 .22909 L
.956 .22655 L
.96 .22606 L
.964 .22667 L
.968 .22809 L
.972 .22955 L
.976 .23089 L
.98 .23182 L
.984 .23231 L
.988 .23252 L
.992 .23244 L
.996 .23239 L
1 .23233 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool20009Ool30005Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo00Moo`800003Ool0000000@000=oo`04001oogoo0009Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool4
0003Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool20007Ool20003Ool20006Ool01000Oomo
o`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000
Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomo
o`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`06Ool00`00Oomoo`03Ool50003Ool2
000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P00
17oo0P001Woo0`000Woo1@000goo0P001Woo000LOol20006Ool00`00Oomoo`05Ool2001SOol001ao
o`03001oogoo00Eoo`03001oogoo00Ioo`80069oo`0077ooJ@0037oo000LOol01@00Oomoogoo0000
0goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool00`00Ool000020003Ool01P00Oomoogoo
001oo`<000Aoo`03001oogoo00Yoo`0077oo0P00EGoo0P0027oo00<007ooOol04Goo000LOol00`00
Oomoo`1FOol00`00Oomoo`04Ool00`00Oomoo`0BOol001aoo`8005Qoo`03001oogoo009oo`03001o
ogoo01=oo`0077oo00<007ooOol0Egoo0P000Woo0P005Goo000;Ool20004Ool01000Oomoogoo1@00
0Woo0P00FGoo0P0000=oo`00Ool05Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001o
ogoo05Uoo`8001Moo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@007oo
Ool000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00
Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo
0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`80
07=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool50002
Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000
Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0
LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03
001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo
000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2
001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomo
o`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00
Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol0
01Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00N7oo
000:Ool01000Oomoo`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007ooOol000Moo`05
001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`8007=oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool40003Ool2001c
Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008
Ool00`00Oomoo`03Ool2001cOol000]oo`8000Yoo`8000=oo`03001oogoo079oo`0077oo0P002Goo
0P00Cgoo0P005goo000LOol00`00Oomoo`08Ool00`00Ool0001>Ool00`00Ool0000FOol000]oo`80
00Aoo`03001oogoo00=oo`<0009oo`8000Uoo`03001oo`0004ioo`03001oo`0001Ioo`002Woo00@0
07ooOol000Yoo`05001oogooOol0000:Ool00`00Ool0001=Ool01000Oomoo`005Woo0003Ool50002
Ool01000Oomoo`001goo1@000Woo00<007ooOol01goo00@007ooOol004eoo`04001oogoo000FOol0
00Yoo`04001oogoo0007Ool01000Oomoo`000goo0P0027oo00D007ooOomoo`0004aoo`04001oogoo
000FOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`07Ool01@00Oomoogoo0000
Bgoo00<007ooOol00Woo00<007ooOol04goo000:Ool01000Oomoo`002Goo0P000goo0P0027oo00D0
07ooOomoo`0004]oo`03001oogoo009oo`03001oogoo01=oo`002goo0P002goo00D007ooOomoo`00
00Uoo`03001oogoo009oo`03001oogoo04Qoo`03001oogoo009oo`03001oogoo01=oo`0077oo0P00
1goo00<007ooOol00goo00<007ooOol0B7oo00<007ooOol00Woo00<007ooOol04goo000LOol00`00
Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`18Ool00`00Oomoo`02Ool00`00Oomoo`0COol000]o
o`8000Aoo`04001oogooOol50002Ool20007Ool00`00Oomoo`03Ool00`00Oomoo`18Ool00`00Oomo
o`03Ool00`00Oomoo`0BOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol01Woo
00<007ooOol017oo00<007ooOol0AWoo00<007ooOol017oo00<007ooOol04Woo0003Ool50002Ool0
1000Oomoo`002Goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol0AWoo
00<007ooOol017oo00<007ooOol04Woo000:Ool01000Oomoo`002Woo00@007ooOomoo`8000Ioo`03
001oogoo00Eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D0
00=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool20002Ool01000Oomoo`000Woo00<007ooOol0
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@0
07ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo0P0000=oo`00Ool0
17oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8000Ioo`03001oogoo00Ioo`03001oo`00009oo`04001oogoo0009
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo0P0000=oo`00Ool01Goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Goo0`000goo00<007ooOol0
1Goo00<007ooOol01Woo00<007oo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001o
ogooOol00002Ool00`00Oomoo`0200000goo001oo`05Ool20006Ool01000Oomoo`000Woo00<007oo
Ool00goo000LOol20006Ool00`00Oomoo`04Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oo`00Ool007oo10000goo00@0
07ooOol000Eoo`0077oo00<007ooOol01Goo00<007ooOol017oo00@007ooOol000=oo`04001oogoo
0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001o
ogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Ool007oo
001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00Aoo`03001oogoo00Eoo`D000=oo`80
00Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20002
Ool40006Ool30002Ool50003Ool20006Ool001aoo`8000Eoo`03001oogoo00Uoo`03001oogoo03mo
o`8000Yoo`03001oogoo015oo`0077oo00<007ooOol017oo00<007ooOol02Woo0P00?Woo0P0037oo
00<007ooOol047oo000LOomY000<Ool001aoo`03001oogoo009oo`8000ioo`03001oogoo019oo`03
001oogoo015oo`03001oogoo019oo`03001oogoo00eoo`8000=oo`03001oogoo00Yoo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol000]oo`8000Aoo`04001oogooOol50002Ool2001cOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00Lgoo000:
Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;
Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool2
0004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000
M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol0
00=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@0
07ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00D007ooOomoo`0007Aoo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`08Ool2001XOol000]oo`8000Aoo`03001oogoo00=oo`<0009o
o`8000Uoo`03001oo`0006Moo`002Woo00@007ooOol000Yoo`05001oogooOol0000:Ool00`00Ool0
001WOol000=oo`D0009oo`04001oogoo0007Ool50002Ool20009Ool00`00Ool0001WOol000Yoo`04
001oogoo0007Ool01000Oomoo`000goo00<007ooOol01goo00D007ooOomoo`0006Ioo`002Woo00@0
07ooOol000Qoo`03001oo`0000=oo`8000Qoo`05001oogooOol0001VOol000Yoo`04001oogoo0009
Ool20003Ool00`00Oomoo`07Ool01@00Oomoogoo0000IWoo000;Ool2000;Ool01000Oomoogoo0P00
27oo00<007ooOol00Woo00<007ooOol0Hgoo000LOol00`00Oomoo`06Ool00`00Oomoo`03Ool00`00
Oomoo`1SOol000]oo`8000Aoo`04001oogooOol50002Ool20007Ool00`00Oomoo`03Ool00`00Oomo
o`1SOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol01Woo00<007ooOol017oo
0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo
0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo
0P001goo00<007ooOol00goo0P000Woo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool0
00=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000
1goo00<007ooOol01Goo00@007ooOol0009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P001Woo00<007ooOol0
1Goo00@007ooOol0009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol01Goo00<007ooOol017oo
10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uoo`<000=oo`80
00Ioo`03001oogoo00Aoo`03001oo`0000Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo
00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0
01aoo`03001oogoo00Eoo`03001oogoo00Aoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`80
00Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006
Ool001aoo`8000Eoo`03001oogoo00Qoo`03001oogoo061oo`0077oo00<007ooOol017oo00<007oo
Ool02Goo00<007ooOol0Ggoo000LOomY000<Ool001aoo`04001oogooOol300000goo001oo`03Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
17oo00H007ooOomoo`00Ool500000goo001oo`02Ool01@00Oomoogoo00000Woo0P000Woo0`0037oo
000LOol2001COol2000;Ool00`00Oomoo`0@Ool001aoo`03001oogoo05=oo`8000Uoo`03001oogoo
015oo`0077oo0P00EGoo00<007ooOol01goo00<007ooOol04Goo000LOol00`00Oomoo`1DOol00`00
Oomoo`07Ool00`00Oomoo`0AOol000]oo`8000Aoo`04001oogooOol50002Ool2001FOol00`00Oomo
o`06Ool00`00Oomoo`0AOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0EGoo
00<007ooOol01Woo00<007ooOol04Goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00Egoo
00<007ooOol017oo00<007ooOol04Woo000:Ool01000Oomoo`002Woo00D007ooOomoo`0005Qoo`03
001oogoo00Aoo`03001oogoo019oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001G
Ool00`00Oomoo`04Ool00`00Oomoo`0BOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0Egoo00<007ooOol00goo00<007ooOol04Woo000;Ool20009Ool30003Ool2001HOol0
0`00Oomoo`02Ool00`00Oomoo`0COol001aoo`03001oogoo05Moo`03001oogoo009oo`03001oogoo
01=oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00F7oo00<007ooOol00Woo00<007ooOol0
4goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0005Uoo`03001oogoo009oo`03001oogoo01=o
o`002Woo00@007ooOol000Moo`D0009oo`8005Uoo`04001oogoo000FOol000Yoo`04001oogoo0007
Ool01000Oomoo`000goo00<007ooOol0F7oo00@007ooOol001Ioo`002Woo00@007ooOol000Qoo`03
001oo`0000=oo`8005Yoo`03001oo`0001Ioo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo
05Uoo`03001oo`0001Ioo`002goo0P002goo00@007ooOomoo`8005Yoo`8001Moo`0077oo00<007oo
Ool0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079o
o`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo
009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo
0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=o
o`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03
001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001o
ogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2040\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23168 m
.008 .23173 L
.012 .23178 L
.016 .23177 L
.02 .23172 L
.024 .23164 L
.028 .23153 L
.032 .2315 L
.036 .23155 L
.04 .23176 L
.044 .23211 L
.048 .23259 L
.052 .23315 L
.056 .23361 L
.06 .23388 L
.064 .23365 L
.068 .23282 L
.072 .23111 L
.076 .22843 L
.08 .22467 L
.084 .21986 L
.088 .21414 L
.092 .20769 L
.096 .20085 L
.1 .19392 L
.104 .18732 L
.108 .18135 L
.112 .17636 L
.116 .17258 L
.12 .17016 L
.124 .16917 L
.128 .16958 L
.132 .17128 L
.136 .17409 L
.14 .17782 L
.144 .1822 L
.148 .18703 L
.152 .19205 L
.156 .19707 L
.16 .20193 L
.164 .20649 L
.168 .21067 L
.172 .2144 L
.176 .21768 L
.18 .22049 L
.184 .22286 L
.188 .22482 L
.192 .22642 L
.196 .22771 L
.2 .22872 L
Mistroke
.204 .22952 L
.208 .23012 L
.212 .23059 L
.216 .23093 L
.22 .23119 L
.224 .23137 L
.228 .23151 L
.232 .2316 L
.236 .23167 L
.24 .23172 L
.244 .23175 L
.248 .23177 L
.252 .23179 L
.256 .2318 L
.26 .2318 L
.264 .23181 L
.268 .23181 L
.272 .23181 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23182 L
.736 .23182 L
.74 .23182 L
.744 .23182 L
.748 .23183 L
.752 .23183 L
.756 .23184 L
.76 .23186 L
.764 .23188 L
.768 .23191 L
.772 .23196 L
.776 .23203 L
.78 .23212 L
.784 .23226 L
.788 .23244 L
.792 .2327 L
.796 .23304 L
.8 .23351 L
Mistroke
.804 .23412 L
.808 .23491 L
.812 .23592 L
.816 .23721 L
.82 .23881 L
.824 .24077 L
.828 .24314 L
.832 .24595 L
.836 .24922 L
.84 .25295 L
.844 .25713 L
.848 .26168 L
.852 .26653 L
.856 .27155 L
.86 .27657 L
.864 .28138 L
.868 .28577 L
.872 .28949 L
.876 .29231 L
.88 .29401 L
.884 .29442 L
.888 .29343 L
.892 .29103 L
.896 .28725 L
.9 .28227 L
.904 .27631 L
.908 .2697 L
.912 .26278 L
.916 .25592 L
.92 .24947 L
.924 .24374 L
.928 .23892 L
.932 .23515 L
.936 .23246 L
.94 .23075 L
.944 .22991 L
.948 .22969 L
.952 .22994 L
.956 .23041 L
.96 .23096 L
.964 .23146 L
.968 .23182 L
.972 .23206 L
.976 .23213 L
.98 .23211 L
.984 .232 L
.988 .23187 L
.992 .23173 L
.996 .23162 L
1 .23159 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3535 m
.008 .35347 L
.012 .35332 L
.016 .35311 L
.02 .35282 L
.024 .35247 L
.028 .35223 L
.032 .35212 L
.036 .35242 L
.04 .35313 L
.044 .35439 L
.048 .35611 L
.052 .35798 L
.056 .35971 L
.06 .3605 L
.064 .35985 L
.068 .35678 L
.072 .35078 L
.076 .34118 L
.08 .32779 L
.084 .31067 L
.088 .29021 L
.092 .26724 L
.096 .24274 L
.1 .21803 L
.104 .19435 L
.108 .17304 L
.112 .15516 L
.116 .1416 L
.12 .13292 L
.124 .12933 L
.128 .13075 L
.132 .13679 L
.136 .14684 L
.14 .16013 L
.144 .17582 L
.148 .19305 L
.152 .211 L
.156 .22896 L
.16 .24633 L
.164 .26264 L
.168 .27758 L
.172 .29094 L
.176 .30265 L
.18 .3127 L
.184 .32117 L
.188 .32819 L
.192 .33391 L
.196 .33851 L
.2 .34214 L
Mistroke
.204 .34496 L
.208 .34714 L
.212 .34878 L
.216 .35002 L
.22 .35093 L
.224 .35159 L
.228 .35207 L
.232 .35241 L
.236 .35265 L
.24 .35282 L
.244 .35293 L
.248 .35301 L
.252 .35306 L
.256 .3531 L
.26 .35312 L
.264 .35314 L
.268 .35315 L
.272 .35315 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35315 L
.74 .35315 L
.744 .35314 L
.748 .35312 L
.752 .3531 L
.756 .35306 L
.76 .35301 L
.764 .35293 L
.768 .35282 L
.772 .35265 L
.776 .35241 L
.78 .35207 L
.784 .35159 L
.788 .35093 L
.792 .35002 L
.796 .34878 L
.8 .34714 L
Mistroke
.804 .34496 L
.808 .34214 L
.812 .33851 L
.816 .33392 L
.82 .32819 L
.824 .32117 L
.828 .3127 L
.832 .30265 L
.836 .29094 L
.84 .27758 L
.844 .26265 L
.848 .24633 L
.852 .22896 L
.856 .211 L
.86 .19305 L
.864 .17582 L
.868 .16013 L
.872 .14685 L
.876 .13679 L
.88 .13076 L
.884 .12934 L
.888 .13292 L
.892 .14161 L
.896 .15516 L
.9 .17304 L
.904 .19435 L
.908 .21804 L
.912 .24274 L
.916 .26725 L
.92 .29021 L
.924 .31067 L
.928 .32779 L
.932 .34118 L
.936 .35078 L
.94 .35678 L
.944 .35986 L
.948 .3605 L
.952 .35971 L
.956 .35796 L
.96 .3561 L
.964 .35437 L
.968 .35313 L
.972 .35244 L
.976 .35217 L
.98 .35231 L
.984 .35252 L
.988 .35282 L
.992 .35301 L
.996 .3531 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23182 L
.012 .23184 L
.016 .23174 L
.02 .23153 L
.024 .23128 L
.028 .231 L
.032 .23094 L
.036 .23111 L
.04 .23173 L
.044 .23278 L
.048 .2342 L
.052 .23584 L
.056 .23721 L
.06 .23797 L
.064 .23734 L
.068 .23483 L
.072 .22974 L
.076 .22171 L
.08 .21047 L
.084 .19608 L
.088 .17894 L
.092 .15962 L
.096 .1391 L
.1 .11832 L
.104 .09847 L
.108 .08056 L
.112 .06557 L
.116 .05419 L
.12 .0469 L
.124 .0439 L
.128 .04509 L
.132 .05017 L
.136 .0586 L
.14 .06976 L
.144 .08293 L
.148 .0974 L
.152 .11247 L
.156 .12755 L
.16 .14213 L
.164 .15583 L
.168 .16836 L
.172 .17958 L
.176 .18941 L
.18 .19784 L
.184 .20496 L
.188 .21085 L
.192 .21566 L
.196 .21951 L
.2 .22256 L
Mistroke
.204 .22493 L
.208 .22676 L
.212 .22814 L
.216 .22917 L
.22 .22994 L
.224 .23049 L
.228 .23089 L
.232 .23118 L
.236 .23138 L
.24 .23152 L
.244 .23162 L
.248 .23168 L
.252 .23173 L
.256 .23176 L
.26 .23178 L
.264 .23179 L
.268 .2318 L
.272 .2318 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23182 L
.728 .23182 L
.732 .23182 L
.736 .23182 L
.74 .23183 L
.744 .23184 L
.748 .23185 L
.752 .23187 L
.756 .2319 L
.76 .23194 L
.764 .23201 L
.768 .2321 L
.772 .23225 L
.776 .23245 L
.78 .23273 L
.784 .23313 L
.788 .23369 L
.792 .23446 L
.796 .23549 L
.8 .23687 L
Mistroke
.804 .2387 L
.808 .24107 L
.812 .24412 L
.816 .24797 L
.82 .25278 L
.824 .25867 L
.828 .26578 L
.832 .27422 L
.836 .28404 L
.84 .29526 L
.844 .3078 L
.848 .3215 L
.852 .33608 L
.856 .35116 L
.86 .36623 L
.864 .38069 L
.868 .39386 L
.872 .40502 L
.876 .41346 L
.88 .41853 L
.884 .41972 L
.888 .41672 L
.892 .40944 L
.896 .39805 L
.9 .38306 L
.904 .36515 L
.908 .34531 L
.912 .32453 L
.916 .304 L
.92 .28469 L
.924 .26754 L
.928 .25316 L
.932 .24192 L
.936 .23389 L
.94 .22879 L
.944 .2263 L
.948 .22565 L
.952 .22641 L
.956 .22777 L
.96 .22942 L
.964 .23083 L
.968 .2319 L
.972 .23254 L
.976 .23273 L
.98 .23269 L
.984 .2324 L
.988 .2321 L
.992 .2318 L
.996 .2316 L
1 .23155 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000:Ool30004Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo00Qoo`80009oo`@000=oo`04001oogoo0009Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool0
1000Oomoo`001Goo000;Ool20009Ool30003Ool20009Ool01000Oomoogoo0P001Goo00@007ooOol0
00Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol0
07oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol01goo00<007ooOol00Woo1@000goo0P00
2Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Ao
o`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P001goo0P001Woo0P00HWoo000LOol00`00Oomo
o`06Ool00`00Oomoo`06Ool2001QOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001o
ogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001o
ogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00004Ool01@00Oomoogoo00000goo1@000goo00@007ooOomoo`<00003Ool007oo00=oo`03
001oogoo00Yoo`0077oo0P00E7oo0P001goo0P0057oo000LOol00`00Oomoo`1DOol20005Ool2000E
Ool001aoo`8005Ioo`8000Aoo`03001oogoo01Aoo`0077oo00<007ooOol0EWoo0P000Woo0P005Woo
000;Ool20004Ool01000Oomoogoo1@000Woo0P00F7oo00@007oo000001Moo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool00`00Oomoo`1HOol2000HOol000Yoo`04001oogoo0009Ool00`00Oomo
o`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004
Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo
000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=o
o`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007oo
Ool000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00@007ooOomoo`8007=oo`0077oo00<0
07ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo
079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`00
27oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<0
00=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009o
o`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03
001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`80
00Aoo`03001oogoo009oo`<007Qoo`002Woo00@007ooOol000Moo`05001oogooOol0001gOol000=o
o`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo
0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000]oo`8000Uoo`<000=o
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo
009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo10000goo0P00Lgoo000:Ool01000Oomoo`001goo00<007ooOol017oo00<007oo
Ool0LWoo000:Ool01000Oomoo`0027oo00<007ooOol00goo0P00Lgoo000;Ool2000:Ool20003Ool0
0`00Oomoo`1bOol001aoo`8000]oo`03001oogoo04]oo`8001Qoo`0077oo00<007ooOol02Goo00<0
07oo0000C7oo0P0067oo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000:Ool00`00Ool0001;
Ool01000Oomoo`005goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0000]oo`04001oogoo001:
Ool01000Oomoo`005goo0003Ool50002Ool01000Oomoo`001goo1@000Woo00<007ooOol027oo00D0
07ooOomoo`0004Yoo`04001oogoo000GOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P00
2Goo00D007ooOomoo`0004Yoo`04001oogoo000GOol000Yoo`04001oogoo0008Ool00`00Ool00003
Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`16Ool00`00Oomoo`02Ool00`00Oomoo`0D
Ool000Yoo`04001oogoo0009Ool20003Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`16Ool00`00
Oomoo`02Ool00`00Oomoo`0DOol000]oo`8000]oo`05001oogooOol0000:Ool00`00Oomoo`02Ool0
0`00Oomoo`16Ool00`00Oomoo`02Ool00`00Oomoo`0DOol001aoo`8000Uoo`03001oogoo009oo`03
001oogoo04Ioo`03001oogoo009oo`03001oogoo01Aoo`0077oo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol0AGoo00<007ooOol00goo00<007ooOol057oo000;Ool20004Ool01000Oomoogoo
1@000Woo0P0027oo00<007ooOol00goo00<007ooOol0AGoo00<007ooOol00goo00<007ooOol057oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo00Aoo`03001o
ogoo04Aoo`03001oogoo00=oo`03001oogoo01Aoo`000goo1@000Woo00@007ooOol000Uoo`03001o
ogoo009oo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo04Aoo`03001oogoo00Aoo`03001o
ogoo01=oo`002Woo00@007ooOol000Yoo`04001oogooOol20008Ool00`00Oomoo`03Ool30004Ool2
0009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20003Ool30005Ool5
0002Ool30004Ool20006Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol00P000Woo00@007ooOol000Uoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0004Ool20002Ool00`00Ool00003Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
00Moo`03001oogoo00Ioo`80009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oo`0000Moo`04001oogoo0002Ool00`00Oomo
o`03Ool000]oo`8000Uoo`<000=oo`03001oogoo00Ioo`03001oogoo00Ioo`80009oo`04001oogoo
0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo009o
o`04001oogoo0006Ool01000Oomoo`000Woo00<007ooOol00goo000LOol20007Ool00`00Oomoo`03
Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
1000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01@00Oomoo`00Ool00P00
0Woo00<007ooOol00Woo0P000Woo00<007oo00000`000goo00@007ooOol000Eoo`0077oo00<007oo
Ool01Woo00<007ooOol00goo00D007ooOomoo`00009oo`04001oogoo0008Ool20004Ool01000Oomo
o`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo
00000Woo00D007ooOol007oo0080009oo`03001oogoo009oo`80009oo`03001oo`0000Ioo`04001o
ogoo0005Ool001aoo`03001oogoo00Eoo`03001oogoo00Aoo`H0009oo`8000Yoo`03001oogoo00=o
o`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool2000017oo001oogoo0P001Woo
0`000Woo1@000goo0P001Woo000LOol20006Ool00`00Oomoo`09Ool00`00Oomoo`0mOol2000:Ool0
0`00Oomoo`0BOol001aoo`03001oogoo00Eoo`03001oogoo00Yoo`8003]oo`<000aoo`03001oogoo
015oo`0077ooJ@0037oo000LOol00`00Oomoo`03Ool2000=Ool00`00Oomoo`0BOol00`00Oomoo`0A
Ool00`00Oomoo`0BOol00`00Oomoo`0<Ool20004Ool00`00Oomoo`0:Ool001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000;
Ool20004Ool01000Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`03001oogoo079oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@007oo
Ool000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00
Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo
0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<0
07ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo
00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009
Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`05001oogooOol0001dOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol02Woo00<007ooOol0IGoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2
000:Ool00`00Ool0001VOol000Yoo`04001oogoo000:Ool01@00Oomoogoo00002goo00<007oo0000
IWoo0003Ool50002Ool01000Oomoo`001goo1@000Woo0P002Woo00@007ooOol006Eoo`002Woo00@0
07ooOol000Moo`04001oogoo0003Ool00`00Oomoo`08Ool01@00Oomoogoo0000IGoo000:Ool01000
Oomoo`0027oo00<007oo00000goo0P002Goo00D007ooOomoo`0006Eoo`002Woo00@007ooOol000Uo
o`8000=oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo069oo`002goo0P002goo00@007oo
Oomoo`8000Uoo`03001oogoo009oo`03001oogoo069oo`0077oo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol0HWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P002Goo00<007ooOol00Woo
00<007ooOol0HWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00Moo`03001o
ogoo00=oo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=o
o`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Uoo`03001o
ogoo009oo`8000Qoo`03001oogoo009oo`05001oo`00Ool00002Ool01000Oomoo`002Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009o
o`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo
001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Yoo`05001oogoo
Ool00009Ool00`00Oomoo`04Ool00`00Ool00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8000Qoo`03001o
ogoo00Eoo`80009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol01Woo00<007ooOol00goo1000
0goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Oomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uoo`<000=oo`8000Mo
o`03001oogoo00=oo`04001oogoo0003Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04
001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000L
Ool00`00Oomoo`06Ool00`00Oomoo`03Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006
Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo
000LOol20006Ool00`00Oomoo`08Ool2001POol001aoo`03001oogoo00Eoo`03001oogoo00Uoo`03
001oogoo05ioo`0077ooJ@0037oo000LOol01000Oomoogoo1@0017oo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`04001oogooOol60002
Ool01@00Oomoogoo00000goo00H007oo001oo`00Ool200000goo001oo`0;Ool001aoo`80059oo`80
00]oo`03001oogoo015oo`0077oo00<007ooOol0DWoo00<007ooOol027oo00<007ooOol04Woo000L
Ool2001DOol00`00Oomoo`07Ool00`00Oomoo`0BOol001aoo`03001oogoo05=oo`03001oogoo00Mo
o`03001oogoo019oo`002goo0P0017oo00@007ooOomoo`D0009oo`8005Eoo`03001oogoo00Eoo`03
001oogoo01=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1DOol00`00Oomo
o`05Ool00`00Oomoo`0COol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001EOol00`00Oomo
o`05Ool00`00Oomoo`0COol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000EWoo00<007ooOol0
1Goo00<007ooOol04goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8005Ioo`03001o
ogoo00=oo`03001oogoo01Aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1EOol00`00Oomoo`03Ool00`00Oomoo`0DOol000]oo`8000Uoo`<000=oo`8005Ioo`03001oogoo
00=oo`03001oogoo01Aoo`0077oo00<007ooOol0EWoo00<007ooOol00Woo00<007ooOol057oo000;
Ool20004Ool00`00Oomoo`03Ool30002Ool2001GOol00`00Oomoo`02Ool00`00Oomoo`0DOol000Yo
o`04001oogoo000:Ool01@00Oomoogoo0000F7oo00<007ooOol00Woo00<007ooOol057oo000:Ool0
1000Oomoo`001goo1@000Woo0P00F7oo00@007ooOol001Moo`002Woo00@007ooOol000Moo`04001o
ogoo0003Ool00`00Oomoo`1GOol01000Oomoo`005goo000:Ool01000Oomoo`0027oo00<007oo0000
0goo0P00F7oo00@007ooOol001Moo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo05Qoo`80
01Qoo`002goo0P002goo00@007ooOomoo`8005Uoo`8001Qoo`0077oo00<007ooOol0LWoo000;Ool2
0004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo
00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Ao
o`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo
0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`80
07=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo
00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`00
5goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo
0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2080\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23178 m
.008 .23182 L
.012 .23185 L
.016 .23185 L
.02 .23185 L
.024 .23181 L
.028 .23175 L
.032 .23167 L
.036 .23156 L
.04 .23149 L
.044 .23146 L
.048 .23155 L
.052 .23177 L
.056 .23214 L
.06 .23266 L
.064 .23321 L
.068 .23372 L
.072 .23396 L
.076 .23377 L
.08 .23289 L
.084 .23117 L
.088 .22843 L
.092 .22462 L
.096 .21977 L
.1 .21399 L
.104 .20752 L
.108 .20065 L
.112 .19374 L
.116 .18713 L
.12 .18121 L
.124 .17626 L
.128 .17253 L
.132 .17016 L
.136 .16921 L
.14 .16966 L
.144 .17138 L
.148 .17422 L
.152 .17795 L
.156 .18233 L
.16 .18714 L
.164 .19215 L
.168 .19715 L
.172 .20199 L
.176 .20653 L
.18 .21069 L
.184 .21441 L
.188 .21768 L
.192 .22048 L
.196 .22284 L
.2 .2248 L
Mistroke
.204 .2264 L
.208 .22769 L
.212 .2287 L
.216 .2295 L
.22 .23011 L
.224 .23057 L
.228 .23092 L
.232 .23118 L
.236 .23136 L
.24 .2315 L
.244 .2316 L
.248 .23167 L
.252 .23171 L
.256 .23175 L
.26 .23177 L
.264 .23178 L
.268 .23179 L
.272 .2318 L
.276 .23181 L
.28 .23181 L
.284 .23181 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23182 L
.724 .23182 L
.728 .23182 L
.732 .23182 L
.736 .23183 L
.74 .23183 L
.744 .23184 L
.748 .23186 L
.752 .23188 L
.756 .23191 L
.76 .23196 L
.764 .23203 L
.768 .23213 L
.772 .23226 L
.776 .23245 L
.78 .23271 L
.784 .23306 L
.788 .23352 L
.792 .23413 L
.796 .23493 L
.8 .23594 L
Mistroke
.804 .23723 L
.808 .23883 L
.812 .24079 L
.816 .24315 L
.82 .24595 L
.824 .24921 L
.828 .25293 L
.832 .25708 L
.836 .26162 L
.84 .26645 L
.844 .27145 L
.848 .27645 L
.852 .28125 L
.856 .28564 L
.86 .28937 L
.864 .2922 L
.868 .29393 L
.872 .29438 L
.876 .29344 L
.88 .29108 L
.884 .28735 L
.888 .28241 L
.892 .27649 L
.896 .26989 L
.9 .26298 L
.904 .2561 L
.908 .24962 L
.912 .24384 L
.916 .23897 L
.92 .23515 L
.924 .2324 L
.928 .23067 L
.932 .22979 L
.936 .2296 L
.94 .22984 L
.944 .23035 L
.948 .23092 L
.952 .23143 L
.956 .23182 L
.96 .23204 L
.964 .23212 L
.968 .23208 L
.972 .23201 L
.976 .23191 L
.98 .23184 L
.984 .2318 L
.988 .23179 L
.992 .23179 L
.996 .23178 L
1 .23175 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35314 m
.008 .35317 L
.012 .35323 L
.016 .35332 L
.02 .35335 L
.024 .3533 L
.028 .35312 L
.032 .35281 L
.036 .35248 L
.04 .35215 L
.044 .35208 L
.048 .35234 L
.052 .35313 L
.056 .35447 L
.06 .35626 L
.064 .35829 L
.068 .36001 L
.072 .36093 L
.076 .36018 L
.08 .35711 L
.084 .35093 L
.088 .3412 L
.092 .32763 L
.096 .31031 L
.1 .28971 L
.104 .26659 L
.108 .24206 L
.112 .21732 L
.116 .19373 L
.12 .17251 L
.124 .15479 L
.128 .14141 L
.132 .1329 L
.136 .12948 L
.14 .13103 L
.144 .13717 L
.148 .14728 L
.152 .1606 L
.156 .17628 L
.16 .19347 L
.164 .21137 L
.168 .22926 L
.172 .24656 L
.176 .2628 L
.18 .27768 L
.184 .29099 L
.188 .30265 L
.192 .31266 L
.196 .32112 L
.2 .32812 L
Mistroke
.204 .33384 L
.208 .33843 L
.212 .34207 L
.216 .3449 L
.22 .34708 L
.224 .34874 L
.228 .34998 L
.232 .35089 L
.236 .35156 L
.24 .35205 L
.244 .35239 L
.248 .35264 L
.252 .35281 L
.256 .35292 L
.26 .353 L
.264 .35306 L
.268 .35309 L
.272 .35312 L
.276 .35313 L
.28 .35314 L
.284 .35315 L
.288 .35316 L
.292 .35316 L
.296 .35316 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35316 L
.716 .35316 L
.72 .35316 L
.724 .35315 L
.728 .35314 L
.732 .35313 L
.736 .35312 L
.74 .35309 L
.744 .35306 L
.748 .353 L
.752 .35292 L
.756 .35281 L
.76 .35264 L
.764 .35239 L
.768 .35205 L
.772 .35156 L
.776 .35089 L
.78 .34998 L
.784 .34874 L
.788 .34708 L
.792 .3449 L
.796 .34207 L
.8 .33843 L
Mistroke
.804 .33384 L
.808 .32813 L
.812 .32112 L
.816 .31267 L
.82 .30265 L
.824 .29099 L
.828 .27768 L
.832 .26281 L
.836 .24656 L
.84 .22926 L
.844 .21137 L
.848 .19347 L
.852 .17628 L
.856 .16061 L
.86 .14729 L
.864 .13718 L
.868 .13104 L
.872 .12948 L
.876 .1329 L
.88 .14141 L
.884 .1548 L
.888 .17251 L
.892 .19373 L
.896 .21732 L
.9 .24207 L
.904 .26659 L
.908 .28971 L
.912 .31031 L
.916 .32763 L
.92 .3412 L
.924 .35093 L
.928 .35711 L
.932 .36017 L
.936 .36093 L
.94 .36001 L
.944 .35829 L
.948 .35626 L
.952 .35448 L
.956 .35314 L
.96 .35234 L
.964 .35208 L
.968 .35214 L
.972 .35246 L
.976 .3528 L
.98 .35312 L
.984 .35333 L
.988 .35341 L
.992 .3534 L
.996 .35329 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23184 L
.012 .23191 L
.016 .23194 L
.02 .23195 L
.024 .23187 L
.028 .23171 L
.032 .23146 L
.036 .23116 L
.04 .23093 L
.044 .23084 L
.048 .23109 L
.052 .23174 L
.056 .23286 L
.06 .23438 L
.064 .23604 L
.068 .23754 L
.072 .23825 L
.076 .23768 L
.08 .23506 L
.084 .2299 L
.088 .22172 L
.092 .21032 L
.096 .1958 L
.1 .17849 L
.104 .15911 L
.108 .1385 L
.112 .11775 L
.116 .09793 L
.12 .08014 L
.124 .06526 L
.128 .05403 L
.132 .04689 L
.136 .04402 L
.14 .04533 L
.144 .05048 L
.148 .05898 L
.152 .07016 L
.156 .08332 L
.16 .09775 L
.164 .11278 L
.168 .1278 L
.172 .14232 L
.176 .15596 L
.18 .16845 L
.184 .17962 L
.188 .18941 L
.192 .19782 L
.196 .20491 L
.2 .2108 L
Mistroke
.204 .2156 L
.208 .21945 L
.212 .2225 L
.216 .22488 L
.22 .22671 L
.224 .2281 L
.228 .22914 L
.232 .22991 L
.236 .23047 L
.24 .23088 L
.244 .23117 L
.248 .23137 L
.252 .23152 L
.256 .23161 L
.26 .23168 L
.264 .23173 L
.268 .23176 L
.272 .23178 L
.276 .23179 L
.28 .2318 L
.284 .2318 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23181 L
.708 .23182 L
.712 .23182 L
.716 .23182 L
.72 .23182 L
.724 .23182 L
.728 .23183 L
.732 .23184 L
.736 .23185 L
.74 .23187 L
.744 .2319 L
.748 .23195 L
.752 .23201 L
.756 .23211 L
.76 .23225 L
.764 .23246 L
.768 .23275 L
.772 .23316 L
.776 .23372 L
.78 .23449 L
.784 .23553 L
.788 .23692 L
.792 .23875 L
.796 .24113 L
.8 .24418 L
Mistroke
.804 .24803 L
.808 .25283 L
.812 .25871 L
.816 .26581 L
.82 .27422 L
.824 .28401 L
.828 .29518 L
.832 .30767 L
.836 .3213 L
.84 .33583 L
.844 .35085 L
.848 .36587 L
.852 .3803 L
.856 .39347 L
.86 .40465 L
.864 .41314 L
.868 .41829 L
.872 .4196 L
.876 .41674 L
.88 .4096 L
.884 .39837 L
.888 .38349 L
.892 .3657 L
.896 .34587 L
.9 .32513 L
.904 .30452 L
.908 .28514 L
.912 .26783 L
.916 .2533 L
.92 .24191 L
.924 .23372 L
.928 .22857 L
.932 .22595 L
.936 .22537 L
.94 .22608 L
.944 .22759 L
.948 .22925 L
.952 .23077 L
.956 .23189 L
.96 .23253 L
.964 .23278 L
.968 .23268 L
.972 .23246 L
.976 .23215 L
.98 .23193 L
.984 .23179 L
.988 .23173 L
.992 .23175 L
.996 .23177 L
1 .23179 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000;Ool40002Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo00Yoo`03001oo`0000<000=oo`04001oogoo0009Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo
00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003
Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool2000:Ool01P00Oomoo`00Ool000Aoo`04001o
ogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomo
ogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00Qoo`04001oogooOol50003Ool2
000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P00
17oo0P001Woo0`000Woo1@000goo0P001Woo000LOol20009Ool00`00Oomoo`04Ool2001QOol001ao
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo05ioo`0077ooJ@0037oo000LOol01@00Oomo
ogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00002Ool400000goo001oo`02Ool01@00
Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol2001COol20007Ool00`00Oomo
o`0DOol001aoo`03001oogoo05=oo`8000Eoo`8001Ioo`0077oo0P00EGoo00<007ooOol00goo00<0
07ooOol05Goo000LOol00`00Oomoo`1EOol01@00Oomoogoo000067oo000;Ool20004Ool01000Oomo
ogoo1@000Woo0P00Egoo00@007oo000001Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`1GOol2000IOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001cOol000Yoo`04
001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`80
00Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002
Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo
1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo
00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001o
ogoo079oo`002goo0P002goo00@007ooOomoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004
Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@0
07ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80
07=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P00
0goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<0
07ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo
00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00
NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<0
07Qoo`002Woo00@007ooOol000Moo`05001oogooOol0001gOol000=oo`D0009oo`04001oogoo0007
Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2001cOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo10000goo
0P00Lgoo000:Ool01000Oomoo`001goo00<007ooOol017oo00<007ooOol0LWoo000:Ool01000Oomo
o`0027oo00<007ooOol00goo0P00Lgoo000;Ool2000:Ool20003Ool00`00Oomoo`1bOol001aoo`80
00aoo`8004Yoo`8001Uoo`0077oo00<007ooOol02Woo00<007oo0000BWoo0P006Goo000;Ool20004
Ool00`00Oomoo`03Ool30002Ool2000;Ool01000Oomoo`00B7oo00@007ooOol001Qoo`002Woo00@0
07ooOol000Yoo`05001oogooOol0000<Ool01000Oomoo`00B7oo00@007ooOol001Qoo`000goo1@00
0Woo00@007ooOol000Moo`D0009oo`03001oogoo00Yoo`04001oogoo0018Ool01000Oomoo`0067oo
000:Ool01000Oomoo`001goo00@007ooOol000=oo`8000]oo`04001oogoo0017Ool01@00Oomoogoo
000067oo000:Ool01000Oomoo`0027oo00<007oo00000goo00<007ooOol02Goo00<007ooOol00Woo
00<007ooOol0A7oo00D007ooOomoo`0001Qoo`002Woo00@007ooOol000Uoo`8000=oo`8000Yoo`03
001oogoo009oo`03001oogoo04Aoo`05001oogooOol0000HOol000]oo`8000]oo`05001oogooOol0
000;Ool00`00Oomoo`02Ool00`00Oomoo`13Ool00`00Oomoo`03Ool00`00Oomoo`0EOol001aoo`80
00Yoo`03001oogoo009oo`03001oogoo04=oo`03001oogoo00=oo`03001oogoo01Eoo`0077oo00<0
07ooOol02Goo00<007ooOol00goo00<007ooOol0@Woo00<007ooOol00goo00<007ooOol05Goo000;
Ool20004Ool01000Oomoogoo1@000Woo0P002Goo00<007ooOol017oo00<007ooOol0@Woo00<007oo
Ool00goo00<007ooOol05Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00Qo
o`03001oogoo00Aoo`03001oogoo049oo`03001oogoo00=oo`03001oogoo01Eoo`000goo1@000Woo
00@007ooOol000Uoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo049o
o`03001oogoo00Aoo`03001oogoo01Aoo`002Woo00@007ooOol000Yoo`04001oogooOol20009Ool0
0`00Oomoo`02Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20002Ool01000Ool0000017oo1P000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo00Qoo`05001oogooOol00003Ool01000Oomoo`000Woo00<0
07ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo0000
0goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01@00Oomoo`00Ool00P000Woo
00L007ooOomoo`00Ool00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8000Uoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0200001Goo001o
ogoo00000goo00@007ooOol000Moo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Uoo`<0
00=oo`03001oogoo00Qoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`05Ool01@00Oomoogoo00000Woo0P0000Eoo`00Oomoo`0000=oo`05001oogooOol00006Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol20008Ool00`00Oomoo`02Ool4000017oo001oo`00
0Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomo
ogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`0200001Goo001oogoo
00000goo0P000goo00<007oo00000`000goo00@007ooOol000Eoo`0077oo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol00Woo00<007oo00000Woo00<007ooOol01Woo0P0017oo00@007ooOol0
009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`03001oogoo00800005Ool007ooOol00003Ool20003Ool00`00Ool00006Ool01000Oomoo`00
1Goo000LOol00`00Oomoo`07Ool00`00Oomoo`02Ool700000goo0000000:Ool00`00Oomoo`03Ool2
0004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0`000goo0P001Goo10000Woo1@00
0goo0P001Woo000LOol20008Ool00`00Oomoo`08Ool2000lOol00`00Oomoo`09Ool00`00Oomoo`0C
Ool001aoo`03001oogoo00Ioo`03001oogoo00Yoo`8003Uoo`8000aoo`03001oogoo01=oo`0077oo
J@0037oo000LOol00`00Oomoo`04Ool2000<Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomo
o`0BOol00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000;Ool2
0004Ool01000Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03
001oogoo079oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol0
00Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`00
0goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007oo
Ool00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@0
07ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool2
0003Ool00`00Oomoo`1bOol000]oo`8000]oo`05001oogooOol0001dOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol02goo0P00IGoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000;Ool00`00
Ool0001UOol000Yoo`04001oogoo000:Ool01@00Oomoogoo000037oo00@007ooOol006Aoo`000goo
1@000Woo00@007ooOol000Moo`D0009oo`8000]oo`04001oogoo001TOol000Yoo`04001oogoo0007
Ool01000Oomoo`000goo00<007ooOol02Woo00@007ooOol006Aoo`002Woo00@007ooOol000Qoo`03
001oo`0000=oo`8000]oo`04001oogoo001TOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomo
o`09Ool00`00Oomoo`02Ool00`00Oomoo`1QOol000]oo`8000]oo`04001oogooOol2000:Ool00`00
Oomoo`02Ool00`00Oomoo`1QOol001aoo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo065o
o`002goo0P0017oo00@007ooOomoo`D0009oo`8000Yoo`03001oogoo00=oo`03001oogoo061oo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`08Ool00`00Oomoo`02Ool30004Ool2
0009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool5
0002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool20009Ool0
1@00Oomoogoo00000Woo0P000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00002Woo00<007ooOol017oo
0P000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool20009Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo00Qoo`04001oogooOol50002Ool01000Oomoo`002Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Ao
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo1000
0goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P002Goo00D007ooOomoo`0000Aoo`03001o
o`00009oo`03001oogoo00Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<0
07ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0
00Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol01goo00<007oo
Ool00Woo1P000Woo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`80
00Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P0027oo00<007ooOol0
1goo0P00Ggoo000LOol00`00Oomoo`06Ool00`00Oomoo`09Ool2001NOol001aoofT000aoo`0077oo
00H007ooOomoo`00Ool30004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo000017oo00@007ooOomoo`D000=oo`05001oogooOol00003Ool20002
Ool30002Ool00`00Oomoo`0:Ool001aoo`80055oo`03001oogoo00Uoo`03001oogoo01=oo`0077oo
00<007ooOol0DGoo00<007ooOol027oo00<007ooOol04goo000LOol2001COol00`00Oomoo`06Ool0
0`00Oomoo`0DOol001aoo`03001oogoo059oo`03001oogoo00Ioo`03001oogoo01Aoo`002goo0P00
17oo00@007ooOomoo`D0009oo`8005=oo`03001oogoo00Ioo`03001oogoo01Aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool00`00Oomoo`1COol00`00Oomoo`05Ool00`00Oomoo`0DOol000Yo
o`04001oogoo0009Ool00`00Oomoo`02Ool2001DOol00`00Oomoo`05Ool00`00Oomoo`0DOol000Yo
o`04001oogoo000:Ool01@00Oomoogoo0000EGoo00<007ooOol01Goo00<007ooOol057oo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`8005Eoo`03001oogoo00=oo`03001oogoo01Eoo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1DOol00`00Oomoo`03Ool00`00
Oomoo`0EOol000]oo`8000Uoo`<000=oo`8005Eoo`03001oogoo00=oo`03001oogoo01Eoo`0077oo
00<007ooOol0E7oo00<007ooOol00goo00<007ooOol05Goo000;Ool20004Ool00`00Oomoo`03Ool3
0002Ool2001FOol01@00Oomoogoo000067oo000:Ool01000Oomoo`002Woo00D007ooOomoo`0005Mo
o`05001oogooOol0000HOol000Yoo`04001oogoo0007Ool50002Ool2001FOol01@00Oomoogoo0000
67oo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo05Ioo`04001oogoo000HOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001GOol01000Oomoo`0067oo000:Ool01000Oomo
o`002Goo0P000goo00<007ooOol0Egoo0P006Goo000;Ool2000;Ool01000Oomoogoo0P00F7oo0P00
6Goo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol0
0goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yo
o`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo
00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo
07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2120\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .2318 m
.008 .23178 L
.012 .23176 L
.016 .23176 L
.02 .23178 L
.024 .2318 L
.028 .23183 L
.032 .23184 L
.036 .23182 L
.04 .23176 L
.044 .23166 L
.048 .23156 L
.052 .23146 L
.056 .23145 L
.06 .23153 L
.064 .23177 L
.068 .23217 L
.072 .23271 L
.076 .23331 L
.08 .23381 L
.084 .23408 L
.088 .23386 L
.092 .23298 L
.096 .23121 L
.1 .22843 L
.104 .22457 L
.108 .21966 L
.112 .21385 L
.116 .20734 L
.12 .20046 L
.124 .19354 L
.128 .18696 L
.132 .18106 L
.136 .17616 L
.14 .17247 L
.144 .17016 L
.148 .16925 L
.152 .16974 L
.156 .17149 L
.16 .17434 L
.164 .17808 L
.168 .18246 L
.172 .18726 L
.176 .19225 L
.18 .19724 L
.184 .20205 L
.188 .20658 L
.192 .21072 L
.196 .21443 L
.2 .21768 L
Mistroke
.204 .22047 L
.208 .22283 L
.212 .22478 L
.216 .22638 L
.22 .22767 L
.224 .22869 L
.228 .22948 L
.232 .23009 L
.236 .23056 L
.24 .23091 L
.244 .23117 L
.248 .23136 L
.252 .2315 L
.256 .23159 L
.26 .23166 L
.264 .23171 L
.268 .23175 L
.272 .23177 L
.276 .23178 L
.28 .23179 L
.284 .2318 L
.288 .23181 L
.292 .23181 L
.296 .23181 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23181 L
.7 .23181 L
.704 .23182 L
.708 .23182 L
.712 .23182 L
.716 .23182 L
.72 .23182 L
.724 .23183 L
.728 .23183 L
.732 .23184 L
.736 .23186 L
.74 .23188 L
.744 .23192 L
.748 .23197 L
.752 .23203 L
.756 .23213 L
.76 .23227 L
.764 .23246 L
.768 .23272 L
.772 .23307 L
.776 .23354 L
.78 .23415 L
.784 .23495 L
.788 .23596 L
.792 .23725 L
.796 .23885 L
.8 .2408 L
Mistroke
.804 .24316 L
.808 .24595 L
.812 .2492 L
.816 .2529 L
.82 .25704 L
.824 .26156 L
.828 .26637 L
.832 .27135 L
.836 .27633 L
.84 .28113 L
.844 .28551 L
.848 .28924 L
.852 .2921 L
.856 .29385 L
.86 .29434 L
.864 .29344 L
.868 .29113 L
.872 .28745 L
.876 .28255 L
.88 .27666 L
.884 .27009 L
.888 .26317 L
.892 .25628 L
.896 .24977 L
.9 .24394 L
.904 .23902 L
.908 .23515 L
.912 .23236 L
.916 .23058 L
.92 .2297 L
.924 .22948 L
.928 .22975 L
.932 .23026 L
.936 .23086 L
.94 .2314 L
.944 .23181 L
.948 .23206 L
.952 .23214 L
.956 .23213 L
.96 .23204 L
.964 .23193 L
.968 .23183 L
.972 .23176 L
.976 .23174 L
.98 .23173 L
.984 .23176 L
.988 .23179 L
.992 .23182 L
.996 .23186 L
1 .23187 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35309 m
.008 .35309 L
.012 .35312 L
.016 .35317 L
.02 .35323 L
.024 .35332 L
.028 .35337 L
.032 .35339 L
.036 .35329 L
.04 .35308 L
.044 .35277 L
.048 .35238 L
.052 .35209 L
.056 .35199 L
.06 .35231 L
.064 .35315 L
.068 .35456 L
.072 .35647 L
.076 .35855 L
.08 .36039 L
.084 .36129 L
.088 .36057 L
.092 .35739 L
.096 .35112 L
.1 .3412 L
.104 .32744 L
.108 .30995 L
.112 .28918 L
.116 .26596 L
.12 .24135 L
.124 .21664 L
.128 .19309 L
.132 .172 L
.136 .15443 L
.14 .14122 L
.144 .13289 L
.148 .12963 L
.152 .13132 L
.156 .13755 L
.16 .14773 L
.164 .16107 L
.168 .17674 L
.172 .19389 L
.176 .21173 L
.18 .22956 L
.184 .24679 L
.188 .26296 L
.192 .27777 L
.196 .29103 L
.2 .30265 L
Mistroke
.204 .31263 L
.208 .32106 L
.212 .32806 L
.216 .33377 L
.22 .33836 L
.224 .342 L
.228 .34484 L
.232 .34703 L
.236 .34869 L
.24 .34994 L
.244 .35086 L
.248 .35154 L
.252 .35203 L
.256 .35238 L
.26 .35263 L
.264 .3528 L
.268 .35292 L
.272 .353 L
.276 .35306 L
.28 .35309 L
.284 .35312 L
.288 .35313 L
.292 .35314 L
.296 .35315 L
.3 .35316 L
.304 .35316 L
.308 .35316 L
.312 .35316 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35316 L
.7 .35316 L
.704 .35316 L
.708 .35316 L
.712 .35315 L
.716 .35314 L
.72 .35313 L
.724 .35312 L
.728 .35309 L
.732 .35306 L
.736 .353 L
.74 .35292 L
.744 .3528 L
.748 .35263 L
.752 .35238 L
.756 .35203 L
.76 .35154 L
.764 .35086 L
.768 .34994 L
.772 .34869 L
.776 .34703 L
.78 .34484 L
.784 .342 L
.788 .33836 L
.792 .33377 L
.796 .32806 L
.8 .32106 L
Mistroke
.804 .31263 L
.808 .30265 L
.812 .29103 L
.816 .27778 L
.82 .26297 L
.824 .24679 L
.828 .22956 L
.832 .21174 L
.836 .19389 L
.84 .17674 L
.844 .16107 L
.848 .14773 L
.852 .13756 L
.856 .13132 L
.86 .12963 L
.864 .13289 L
.868 .14123 L
.872 .15444 L
.876 .17201 L
.88 .1931 L
.884 .21664 L
.888 .24135 L
.892 .26597 L
.896 .28918 L
.9 .30995 L
.904 .32744 L
.908 .3412 L
.912 .35112 L
.916 .35739 L
.92 .36057 L
.924 .36129 L
.928 .3604 L
.932 .35855 L
.936 .35647 L
.94 .35456 L
.944 .35315 L
.948 .35231 L
.952 .35199 L
.956 .35209 L
.96 .35238 L
.964 .35277 L
.968 .35309 L
.972 .35329 L
.976 .35338 L
.98 .35335 L
.984 .3533 L
.988 .35322 L
.992 .35317 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23174 L
.012 .23172 L
.016 .23175 L
.02 .2318 L
.024 .23187 L
.028 .23194 L
.032 .23195 L
.036 .23188 L
.04 .2317 L
.044 .23143 L
.048 .23112 L
.052 .23085 L
.056 .23079 L
.06 .23104 L
.064 .23175 L
.068 .23294 L
.072 .23453 L
.076 .2363 L
.08 .23781 L
.084 .2386 L
.088 .23797 L
.092 .23532 L
.096 .23004 L
.1 .22172 L
.104 .21017 L
.108 .19548 L
.112 .17806 L
.116 .15856 L
.12 .13792 L
.124 .11716 L
.128 .09741 L
.132 .0797 L
.136 .06496 L
.14 .05387 L
.144 .04688 L
.148 .04415 L
.152 .04557 L
.156 .05081 L
.16 .05935 L
.164 .07055 L
.168 .0837 L
.172 .09811 L
.176 .11309 L
.18 .12805 L
.184 .14251 L
.188 .15609 L
.192 .16853 L
.196 .17966 L
.2 .18941 L
Mistroke
.204 .19779 L
.208 .20487 L
.212 .21074 L
.216 .21554 L
.22 .21939 L
.224 .22244 L
.228 .22483 L
.232 .22666 L
.236 .22806 L
.24 .22911 L
.244 .22988 L
.248 .23045 L
.252 .23086 L
.256 .23116 L
.26 .23136 L
.264 .23151 L
.268 .23161 L
.272 .23168 L
.276 .23172 L
.28 .23176 L
.284 .23178 L
.288 .23179 L
.292 .2318 L
.296 .2318 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23181 L
.696 .23182 L
.7 .23182 L
.704 .23182 L
.708 .23182 L
.712 .23182 L
.716 .23183 L
.72 .23184 L
.724 .23185 L
.728 .23187 L
.732 .2319 L
.736 .23195 L
.74 .23202 L
.744 .23212 L
.748 .23226 L
.752 .23247 L
.756 .23277 L
.76 .23318 L
.764 .23374 L
.768 .23452 L
.772 .23557 L
.776 .23696 L
.78 .2388 L
.784 .24118 L
.788 .24424 L
.792 .24809 L
.796 .25289 L
.8 .25876 L
Mistroke
.804 .26584 L
.808 .27422 L
.812 .28397 L
.816 .2951 L
.82 .30753 L
.824 .32111 L
.828 .33557 L
.832 .35054 L
.836 .36552 L
.84 .37992 L
.844 .39308 L
.848 .40428 L
.852 .41282 L
.856 .41806 L
.86 .41948 L
.864 .41674 L
.868 .40975 L
.872 .39866 L
.876 .38392 L
.88 .36621 L
.884 .34647 L
.888 .3257 L
.892 .30507 L
.896 .28556 L
.9 .26814 L
.904 .25345 L
.908 .2419 L
.912 .23359 L
.916 .2283 L
.92 .22566 L
.924 .22502 L
.928 .22582 L
.932 .22733 L
.936 .2291 L
.94 .23068 L
.944 .23187 L
.948 .23259 L
.952 .23284 L
.956 .23278 L
.96 .23251 L
.964 .23221 L
.968 .23193 L
.972 .23174 L
.976 .23167 L
.98 .23167 L
.984 .23174 L
.988 .23181 L
.992 .23189 L
.996 .23194 L
1 .23195 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000=Ool300001Goo001oogoo00000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo00]oo`D000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomo
o`001Goo000;Ool20009Ool30003Ool2000;Ool00`00Ool00002Ool01@00Oomoogoo00000Woo00<0
07ooOol01Woo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool0
1000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007oo
Oomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0:Ool00`00Ool000040003Ool2
000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P00
17oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000:Ool00`00Oomoo`05Ool00`00Oomoo`1N
Ool001aoo`03001oogoo00Qoo`03001oogoo00Moo`8005ioo`0077ooJ@0037oo000LOol01@00Oomo
ogoo00000goo0P000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000Aoo`06001oogooOol007oo0`000goo00D007ooOomoo`00009oo`8000=o
o`03001oogoo009oo`03001oogoo00Yoo`0077oo0P00DWoo0P001goo00<007ooOol05Goo000LOol0
0`00Oomoo`1BOol00`00Oomoo`04Ool00`00Oomoo`0FOol001aoo`8005Aoo`03001oogoo00=oo`03
001oogoo01Ioo`0077oo00<007ooOol0E7oo00D007ooOomoo`0001Uoo`002goo0P0017oo00@007oo
Oomoo`D0009oo`8005Eoo`800003Ool0000001Uoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool00`00Oomoo`1EOol3000JOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001cOol000Yo
o`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]o
o`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool3
0002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`00
1goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`00
2Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03
001oogoo079oo`002goo0P002goo00@007ooOomoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool2
0004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo
00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Ao
o`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo
0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`80
07=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo
00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`00
5goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo
0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009o
o`<007Qoo`002Woo00@007ooOol000Moo`05001oogooOol0001gOol000=oo`D0009oo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool2001cOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo1000
0goo0P00Lgoo000:Ool01000Oomoo`001goo00<007ooOol017oo00<007ooOol0LWoo000:Ool01000
Oomoo`0027oo00<007ooOol00goo0P00Lgoo000;Ool2000:Ool20003Ool00`00Oomoo`1bOol001ao
o`8000eoo`8004Qoo`8001Yoo`0077oo00<007ooOol037oo0P00Agoo00<007oo00006Woo000;Ool2
0004Ool00`00Oomoo`03Ool30002Ool2000<Ool01000Oomoo`00AWoo00<007oo00006Woo000:Ool0
1000Oomoo`002Woo00D007ooOomoo`0000eoo`04001oogoo0015Ool01000Oomoo`006Woo0003Ool5
0002Ool01000Oomoo`001goo1@000Woo00<007ooOol02goo00@007ooOol004Eoo`05001oogooOol0
000IOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P0037oo00D007ooOomoo`0004Aoo`05
001oogooOol0000IOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`0:Ool00`00
Oomoo`02Ool00`00Oomoo`12Ool01@00Oomoogoo00006Goo000:Ool01000Oomoo`002Goo0P000goo
0P002goo00<007ooOol00Woo00<007ooOol0@Woo00D007ooOomoo`0001Uoo`002goo0P002goo00D0
07ooOomoo`0000aoo`03001oogoo009oo`03001oogoo045oo`03001oogoo00=oo`03001oogoo01Io
o`0077oo0P002goo00<007ooOol00Woo00<007ooOol0@Goo00<007ooOol00goo00<007ooOol05Woo
000LOol00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`10Ool00`00Oomoo`03Ool00`00Oomo
o`0FOol000]oo`8000Aoo`04001oogooOol50002Ool2000;Ool00`00Oomoo`03Ool00`00Oomoo`10
Ool00`00Oomoo`03Ool00`00Oomoo`0FOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<0
07ooOol02Woo00<007ooOol00goo00<007ooOol0?goo00<007ooOol017oo00<007ooOol05Woo0003
Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol017oo00<0
07ooOol0?goo00<007ooOol017oo00<007ooOol05Woo000:Ool01000Oomoo`002Woo00@007ooOomo
o`8000Yoo`04001oogooOol3000017oo001oogoo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo
0`0017oo0P001Goo1@000goo0P0000Aoo`00Oomoo`80009oo`03001oogoo00D0009oo`<000Aoo`80
00Ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`09Ool01000Oomoo`00
0goo0P0000Eoo`00Oomoo`0000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00<007oo
Ool00P0000Moo`00Oomoo`00Ool00003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P002Woo00<007ooOol017oo
0P0000Eoo`00Oomoo`0000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`000Woo00D007ooOomoo`0000Moo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`80
00Uoo`<000=oo`03001oogoo00Uoo`03001oogoo00Aoo`800005Ool007ooOol00009Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000LOol20009Ool01000Oomoogoo10000Woo0P000Woo
00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo
10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009o
o`03001oo`0000=oo`03001oo`0000<000=oo`04001oogoo0005Ool001aoo`03001oogoo00Qoo`05
001oogooOol00005Ool20002Ool00`00Oomoo`06Ool20004Ool01000Oomoo`000Woo00@007ooOol0
00Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007oo0000
009oo`04001oogoo0002Ool00`00Ool00003Ool00`00Ool00006Ool01000Oomoo`001Goo000LOol0
0`00Oomoo`08Ool01000Oomoogoo1@000Woo0`002Woo00<007ooOol00goo0P0017oo0P001Woo00@0
07ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Aoo`03001oo`000080009oo`D000=oo`80
00Ioo`0077oo0P002Goo00<007ooOol02Goo00<007ooOol0>7oo00<007ooOol02Goo00<007ooOol0
57oo000LOol00`00Oomoo`08Ool00`00Oomoo`09Ool3000fOol2000<Ool00`00Oomoo`0DOol001ao
ofT000aoo`0077oo00<007ooOol01Goo0P002goo00<007ooOol04Woo00<007ooOol04Goo00<007oo
Ool04Woo00<007ooOol02Goo0P001goo00<007ooOol02Woo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002goo0P0017oo
00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001cOol000Yoo`04001oogoo000:Ool0
1@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=o
o`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo
0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo
000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo
00<007ooOol0LWoo000;Ool2000;Ool01@00Oomoogoo0000M7oo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo00aoo`8006Aoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P003Goo0P00I7oo000:
Ool01000Oomoo`002Woo00D007ooOomoo`0000eoo`04001oogoo001SOol000=oo`D0009oo`04001o
ogoo0007Ool50002Ool2000<Ool01000Oomoo`00Hgoo000:Ool01000Oomoo`001goo00@007ooOol0
00=oo`03001oogoo00]oo`05001oogooOol0001ROol000Yoo`04001oogoo0008Ool00`00Ool00003
Ool2000<Ool01@00Oomoogoo0000HWoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol02Woo
00<007ooOol00Woo00<007ooOol0H7oo000;Ool2000;Ool01000Oomoogoo0P002goo00<007ooOol0
0Woo00<007ooOol0H7oo000LOol00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`1POol000]o
o`8000Aoo`04001oogooOol50002Ool2000;Ool00`00Oomoo`03Ool00`00Oomoo`1OOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00<007ooOol02Woo00<007ooOol010000goo0P002Goo0`00
17oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`00
17oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo0P002goo00<007oo0000
0goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00002goo00<007ooOol017oo0P0000Eo
o`00Oomoo`0000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2000:Ool00`00Oomoo`04Ool200001Goo001oogoo00002Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00Uoo`03001oogoo00@00004Ool007oo0002Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool0
1000Oomoo`001Goo000;Ool20009Ool30003Ool2000:Ool01000Oomoo`001Goo0P000Woo00<007oo
Ool01Woo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000
Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomo
o`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`08Ool01000Oomoogoo1@0000=oo`00
Ool00P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Ao
o`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P002Goo00<007ooOol027oo00<007oo
Ool0G7oo000LOol00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`1KOol001aoofT000aoo`00
77oo00D007ooOomoo`00009oo`@0009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00004Ool00`00Oomoo`0400000goo001oo`02Ool01@00Oomo
ogoo00000Woo0P000Woo0P0017oo00<007ooOol02Woo000LOol2001@Ool00`00Oomoo`09Ool00`00
Oomoo`0DOol001aoo`03001oogoo04moo`8000Yoo`03001oogoo01Aoo`0077oo0P00DGoo00<007oo
Ool01goo00<007ooOol05Goo000LOol00`00Oomoo`1AOol00`00Oomoo`06Ool00`00Oomoo`0EOol0
00]oo`8000Aoo`04001oogooOol50002Ool2001BOol00`00Oomoo`06Ool00`00Oomoo`0EOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0DWoo00<007ooOol01Goo00<007ooOol0
5Goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00Dgoo00<007ooOol017oo00<007ooOol0
5Woo000:Ool01000Oomoo`002Woo00D007ooOomoo`0005Aoo`03001oogoo00Aoo`03001oogoo01Io
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001COol00`00Oomoo`04Ool00`00Oomo
o`0FOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0Dgoo00<007ooOol0
0goo00<007ooOol05Woo000;Ool20009Ool30003Ool2001DOol00`00Oomoo`03Ool00`00Oomoo`0F
Ool001aoo`03001oogoo05=oo`03001oogoo00=oo`03001oogoo01Ioo`002goo0P0017oo00<007oo
Ool00goo0`000Woo0P00EGoo00D007ooOomoo`0001Uoo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0001FOol01@00Oomoogoo00006Goo000:Ool01000Oomoo`001goo1@000Woo0P00EGoo00D007oo
Oomoo`0001Uoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1DOol01@00Oomo
ogoo00006Goo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00EWoo00<007oo00006Woo000:
Ool01000Oomoo`002Goo0P000goo00<007ooOol0EGoo00<007oo00006Woo000;Ool2000;Ool01000
Oomoogoo0P00Egoo0P006Woo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<0
00=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomo
o`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03
001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<0
00=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001c
Ool001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo
07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2160\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23177 L
.028 .23178 L
.032 .2318 L
.036 .23182 L
.04 .23184 L
.044 .23184 L
.048 .23181 L
.052 .23175 L
.056 .23165 L
.06 .23153 L
.064 .23144 L
.068 .23142 L
.072 .23152 L
.076 .23177 L
.08 .2322 L
.084 .23277 L
.088 .23338 L
.092 .23392 L
.096 .23418 L
.1 .23397 L
.104 .23305 L
.108 .23126 L
.112 .22843 L
.116 .22451 L
.12 .21956 L
.124 .21369 L
.128 .20716 L
.132 .20026 L
.136 .19335 L
.14 .18678 L
.144 .18093 L
.148 .17606 L
.152 .17243 L
.156 .17015 L
.16 .1693 L
.164 .16982 L
.168 .1716 L
.172 .17446 L
.176 .17821 L
.18 .18259 L
.184 .18738 L
.188 .19235 L
.192 .19732 L
.196 .20212 L
.2 .20662 L
Mistroke
.204 .21075 L
.208 .21444 L
.212 .21768 L
.216 .22046 L
.22 .22281 L
.224 .22477 L
.228 .22636 L
.232 .22765 L
.236 .22867 L
.24 .22946 L
.244 .23008 L
.248 .23055 L
.252 .2309 L
.256 .23116 L
.26 .23135 L
.264 .23149 L
.268 .23159 L
.272 .23166 L
.276 .23171 L
.28 .23174 L
.284 .23177 L
.288 .23178 L
.292 .23179 L
.296 .2318 L
.3 .23181 L
.304 .23181 L
.308 .23181 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23181 L
.688 .23181 L
.692 .23182 L
.696 .23182 L
.7 .23182 L
.704 .23182 L
.708 .23182 L
.712 .23183 L
.716 .23183 L
.72 .23184 L
.724 .23186 L
.728 .23188 L
.732 .23192 L
.736 .23197 L
.74 .23204 L
.744 .23214 L
.748 .23228 L
.752 .23247 L
.756 .23273 L
.76 .23308 L
.764 .23355 L
.768 .23417 L
.772 .23496 L
.776 .23598 L
.78 .23727 L
.784 .23887 L
.788 .24082 L
.792 .24317 L
.796 .24595 L
.8 .24919 L
Mistroke
.804 .25287 L
.808 .25699 L
.812 .26149 L
.816 .26629 L
.82 .27125 L
.824 .27622 L
.828 .281 L
.832 .28538 L
.836 .28912 L
.84 .29199 L
.844 .29377 L
.848 .29429 L
.852 .29344 L
.856 .29118 L
.86 .28755 L
.864 .28269 L
.868 .27684 L
.872 .27028 L
.876 .26337 L
.88 .25646 L
.884 .24992 L
.888 .24405 L
.892 .23908 L
.896 .23516 L
.9 .23232 L
.904 .23051 L
.908 .22959 L
.912 .22938 L
.916 .22964 L
.92 .23018 L
.924 .2308 L
.928 .23137 L
.932 .23181 L
.936 .23207 L
.94 .23217 L
.944 .23215 L
.948 .23206 L
.952 .23194 L
.956 .23184 L
.96 .23177 L
.964 .23174 L
.968 .23174 L
.972 .23176 L
.976 .23179 L
.98 .23181 L
.984 .23182 L
.988 .23182 L
.992 .23181 L
.996 .2318 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35319 m
.008 .35318 L
.012 .35315 L
.016 .35312 L
.02 .35311 L
.024 .35311 L
.028 .35315 L
.032 .35323 L
.036 .35332 L
.04 .3534 L
.044 .3534 L
.048 .3533 L
.052 .35307 L
.056 .35271 L
.06 .35232 L
.064 .35199 L
.068 .35192 L
.072 .35226 L
.076 .35317 L
.08 .35467 L
.084 .35666 L
.088 .35886 L
.092 .36074 L
.096 .3617 L
.1 .36092 L
.104 .35769 L
.108 .35127 L
.112 .3412 L
.116 .32725 L
.12 .30957 L
.124 .28865 L
.128 .26531 L
.132 .24066 L
.136 .21594 L
.14 .19248 L
.144 .1715 L
.148 .15409 L
.152 .14105 L
.156 .13289 L
.16 .12978 L
.164 .1316 L
.168 .13794 L
.172 .14817 L
.176 .16153 L
.18 .17719 L
.184 .19431 L
.188 .21209 L
.192 .22985 L
.196 .24701 L
.2 .26312 L
Mistroke
.204 .27787 L
.208 .29107 L
.212 .30265 L
.216 .3126 L
.22 .32101 L
.224 .32799 L
.228 .3337 L
.232 .33829 L
.236 .34193 L
.24 .34478 L
.244 .34697 L
.248 .34864 L
.252 .3499 L
.256 .35083 L
.26 .35151 L
.264 .35201 L
.268 .35236 L
.272 .35261 L
.276 .35279 L
.28 .35291 L
.284 .353 L
.288 .35305 L
.292 .35309 L
.296 .35312 L
.3 .35313 L
.304 .35314 L
.308 .35315 L
.312 .35315 L
.316 .35316 L
.32 .35316 L
.324 .35316 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35316 L
.688 .35316 L
.692 .35316 L
.696 .35315 L
.7 .35315 L
.704 .35314 L
.708 .35313 L
.712 .35312 L
.716 .35309 L
.72 .35305 L
.724 .353 L
.728 .35291 L
.732 .35279 L
.736 .35261 L
.74 .35236 L
.744 .35201 L
.748 .35151 L
.752 .35083 L
.756 .3499 L
.76 .34864 L
.764 .34697 L
.768 .34478 L
.772 .34193 L
.776 .33829 L
.78 .3337 L
.784 .32799 L
.788 .32101 L
.792 .3126 L
.796 .30265 L
.8 .29107 L
Mistroke
.804 .27787 L
.808 .26312 L
.812 .24701 L
.816 .22986 L
.82 .2121 L
.824 .19431 L
.828 .17719 L
.832 .16153 L
.836 .14817 L
.84 .13794 L
.844 .13161 L
.848 .12979 L
.852 .13289 L
.856 .14105 L
.86 .15409 L
.864 .1715 L
.868 .19248 L
.872 .21594 L
.876 .24067 L
.88 .26531 L
.884 .28865 L
.888 .30957 L
.892 .32725 L
.896 .3412 L
.9 .35127 L
.904 .35769 L
.908 .36092 L
.912 .3617 L
.916 .36073 L
.92 .35886 L
.924 .35666 L
.928 .35467 L
.932 .35317 L
.936 .35226 L
.94 .35192 L
.944 .35198 L
.948 .35232 L
.952 .35271 L
.956 .35307 L
.96 .3533 L
.964 .3534 L
.968 .3534 L
.972 .35332 L
.976 .35324 L
.98 .35316 L
.984 .35311 L
.988 .3531 L
.992 .3531 L
.996 .35313 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23175 L
.012 .23173 L
.016 .23172 L
.02 .23171 L
.024 .23173 L
.028 .23176 L
.032 .23182 L
.036 .2319 L
.04 .23195 L
.044 .23197 L
.048 .23188 L
.052 .23168 L
.056 .23139 L
.06 .23105 L
.064 .23078 L
.068 .23071 L
.072 .23101 L
.076 .23176 L
.08 .23303 L
.084 .2347 L
.088 .23653 L
.092 .23813 L
.096 .23891 L
.1 .23829 L
.104 .23556 L
.108 .23018 L
.112 .22172 L
.116 .21001 L
.12 .19517 L
.124 .17761 L
.128 .15803 L
.132 .13733 L
.136 .11659 L
.14 .09688 L
.144 .07928 L
.148 .06467 L
.152 .05372 L
.156 .04688 L
.16 .04428 L
.164 .04581 L
.168 .05113 L
.172 .05972 L
.176 .07094 L
.18 .08408 L
.184 .09846 L
.188 .11339 L
.192 .1283 L
.196 .1427 L
.2 .15623 L
Mistroke
.204 .16861 L
.208 .17969 L
.212 .18941 L
.216 .19777 L
.22 .20482 L
.224 .21069 L
.228 .21548 L
.232 .21933 L
.236 .22239 L
.24 .22478 L
.244 .22662 L
.248 .22802 L
.252 .22907 L
.256 .22986 L
.26 .23043 L
.264 .23085 L
.268 .23114 L
.272 .23135 L
.276 .2315 L
.28 .2316 L
.284 .23167 L
.288 .23172 L
.292 .23175 L
.296 .23177 L
.3 .23179 L
.304 .2318 L
.308 .2318 L
.312 .23181 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .23182 L
.688 .23182 L
.692 .23182 L
.696 .23182 L
.7 .23182 L
.704 .23183 L
.708 .23184 L
.712 .23185 L
.716 .23187 L
.72 .23191 L
.724 .23195 L
.728 .23202 L
.732 .23213 L
.736 .23227 L
.74 .23248 L
.744 .23278 L
.748 .2332 L
.752 .23377 L
.756 .23455 L
.76 .23561 L
.764 .23701 L
.768 .23885 L
.772 .24124 L
.776 .2443 L
.78 .24815 L
.784 .25294 L
.788 .2588 L
.792 .26586 L
.796 .27422 L
.8 .28393 L
Mistroke
.804 .29502 L
.808 .3074 L
.812 .32092 L
.816 .33533 L
.82 .35024 L
.824 .36517 L
.828 .37954 L
.832 .39269 L
.836 .40391 L
.84 .4125 L
.844 .41782 L
.848 .41935 L
.852 .41675 L
.856 .4099 L
.86 .39896 L
.864 .38434 L
.868 .36674 L
.872 .34704 L
.876 .3263 L
.88 .3056 L
.884 .28602 L
.888 .26845 L
.892 .25362 L
.896 .24191 L
.9 .23345 L
.904 .22807 L
.908 .22534 L
.912 .22471 L
.916 .22549 L
.92 .2271 L
.924 .22892 L
.928 .2306 L
.932 .23186 L
.936 .23262 L
.94 .23292 L
.944 .23284 L
.948 .23258 L
.952 .23224 L
.956 .23194 L
.96 .23175 L
.964 .23166 L
.968 .23167 L
.972 .23173 L
.976 .23181 L
.98 .23187 L
.984 .2319 L
.988 .2319 L
.992 .23189 L
.996 .23187 L
1 .23187 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000>Ool40002Ool01000Oomoo`002Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00aoo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2
0009Ool30003Ool2000<Ool20003Ool200001Goo001oogoo000027oo0P0017oo00@007ooOol0009o
o`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo
000LOol00`00Oomoo`0;Ool70002Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomo
ogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000;
Ool00`00Oomoo`05Ool2001NOol001aoo`03001oogoo00Yoo`03001oogoo00Ioo`8005eoo`0077oo
J@0037oo000LOol01@00Oomoogoo00000goo00<007oo00000Woo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`04001oogooOol50003Ool0
1000Oomoogoo0`0000=oo`00Ool00Woo00<007ooOol00Woo00<007ooOol02Woo000LOol2001@Ool2
0008Ool00`00Oomoo`0FOol001aoo`03001oogoo055oo`03001oogoo00Aoo`03001oogoo01Moo`00
77oo0P00Dgoo00<007ooOol00Woo0P006Goo000LOol00`00Oomoo`1BOol20003Ool00`00Oomoo`0H
Ool000]oo`8000Aoo`04001oogooOol50002Ool2001DOol200000goo0000000JOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00<007ooOol0E7oo0P0077oo000:Ool01000Oomoo`002Goo00<0
07ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`00
07Aoo`002Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo
0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04
001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001ao
o`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00
Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool0
0`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007oo
Ool000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2
001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009
Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomo
o`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000G
Ool00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;
Ool20004Ool00`00Oomoo`02Ool3001hOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000Mgoo
0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol0
00Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000;Ool20009Ool3
0003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00
Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`@000=oo`8007=oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`03
001oogoo079oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`8007=oo`002goo0P002Woo0P00
0goo00<007ooOol0LWoo000LOol2000>Ool20015Ool2000LOol001aoo`03001oogoo00eoo`03001o
o`0004Aoo`03001oo`0001]oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P003Woo00<007oo
0000A7oo00<007oo00006goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0000moo`03001oo`00
04=oo`04001oogoo000KOol000=oo`D0009oo`04001oogoo0007Ool50002Ool00`00Oomoo`0<Ool0
1000Oomoo`00@goo00D007ooOomoo`0001Yoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool2
000=Ool01@00Oomoogoo0000@Woo00D007ooOomoo`0001Yoo`002Woo00@007ooOol000Qoo`03001o
o`0000=oo`03001oogoo00aoo`05001oogooOol00011Ool00`00Oomoo`02Ool00`00Oomoo`0HOol0
00Yoo`04001oogoo0009Ool20003Ool2000=Ool01@00Oomoogoo0000@Goo00<007ooOol00Woo00<0
07ooOol067oo000;Ool2000;Ool01@00Oomoogoo00003Goo00<007ooOol00goo00<007ooOol0?Woo
00<007ooOol00Woo00<007ooOol067oo000LOol2000<Ool00`00Oomoo`03Ool00`00Oomoo`0nOol0
0`00Oomoo`02Ool00`00Oomoo`0HOol001aoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo
03ioo`03001oogoo009oo`03001oogoo01Qoo`002goo0P0017oo00@007ooOomoo`D0009oo`8000ao
o`03001oogoo00=oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo01Moo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0mOol00`00
Oomoo`04Ool00`00Oomoo`0GOol000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00
Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0mOol00`00Oomoo`04Ool00`00Oomoo`0GOol000Yo
o`04001oogoo000:Ool01000Oomoogoo0P002goo00<007ooOol00`000Woo00@007oo000000Uoo`<0
00Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`<000=oo`800003Ool007oo009o
o`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`0:Ool00`00Ool00003Ool01000Ool000000Woo00<007ooOol01goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=o
o`04001oogoo0002Ool01000Ool000000Woo00<007ooOol00P0017oo00H007ooOol007oo0003Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
00]oo`03001oogoo00=oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool01000Ool000000Woo00H007ooOol007oo0004Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000;Ool20009Ool30003Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool01000
Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00H007ooOomoo`00Ool20002Ool01P00
Oomoo`00Ool000Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000]o
o`03001oo`0000<000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`800005Ool0
07ooOol00002Ool00`00Ool00002Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001ao
o`03001oogoo00Yoo`03001oo`0000Ioo`800003Ool007oo00Moo`8000Aoo`04001oogoo0002Ool0
1000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool2
00001Goo001oogoo00000Woo00<007oo00000Woo00L007ooOomoo`00Ool00006Ool01000Oomoo`00
1Goo000LOol00`00Oomoo`09Ool00`00Oomoo`050003Ool2000:Ool00`00Oomoo`03Ool20004Ool2
0006Ool01000Oomoogoo1@000goo0P001Woo0`000goo0`0017oo0P000Woo00@007ooOomoo`<0009o
o`D000=oo`8000Ioo`0077oo0P002Woo00<007ooOol02Goo00<007ooOol0=Goo0P002Woo00<007oo
Ool05Woo000LOol00`00Oomoo`09Ool00`00Oomoo`0:Ool2000dOol2000<Ool00`00Oomoo`0EOol0
01aoofT000aoo`0077oo00<007ooOol01goo0P002Goo00<007ooOol04Woo00<007ooOol04Goo00<0
07ooOol04Woo00<007ooOol027oo0P0027oo00<007ooOol02Woo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002goo0P00
17oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001cOol000Yoo`04001oogoo000:
Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=o
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo
00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001o
ogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0
LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P00
0goo00<007ooOol0LWoo000;Ool2000;Ool01@00Oomoogoo0000M7oo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001ao
o`03001oogoo00eoo`8006=oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P003Woo00<007oo
0000HWoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0000moo`03001oo`00069oo`000goo1@00
0Woo00@007ooOol000Moo`D0009oo`8000ioo`03001oo`00069oo`002Woo00@007ooOol000Moo`04
001oogoo0003Ool00`00Oomoo`0<Ool01@00Oomoogoo0000HGoo000:Ool01000Oomoo`0027oo00<0
07oo00000goo0P003Goo00D007ooOomoo`00065oo`002Woo00@007ooOol000Uoo`8000=oo`03001o
ogoo00aoo`05001oogooOol0001QOol000]oo`8000]oo`04001oogooOol2000=Ool00`00Oomoo`02
Ool00`00Oomoo`1NOol001aoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo05ioo`002goo
0P0017oo00@007ooOomoo`D0009oo`8000aoo`03001oogoo00=oo`03001oogoo05ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0;Ool00`00Ool00002000017oo001oogoo0P00
2Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@00
0Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo0P0037oo0P00
0goo0P0000Eoo`00Oomoo`0000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo000037oo00<007ooOol00goo00@007oo0000009o
o`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2000;Ool00`00Oomoo`03Ool01000Ool000000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00Yoo`03001oo`0000<000=oo`04001oogoo0009Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007oo
Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000
Oomoo`001Goo000;Ool20009Ool30003Ool2000;Ool00`00Ool00006Ool01000Oomoo`0027oo0P00
17oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo
00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006
Ool01000Oomoo`001Goo000LOol00`00Oomoo`0:Ool00`00Ool000040003Ool2000:Ool00`00Oomo
o`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`00
0Woo1@000goo0P001Woo000LOol2000:Ool00`00Oomoo`08Ool00`00Oomoo`1KOol001aoo`03001o
ogoo00Uoo`03001oogoo00Uoo`8005]oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo1000
00=oo`00Ool00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00Aoo`H0009oo`05001oogooOol00003Ool01P00Ool007oo001oo`<000Aoo`03001oogoo00Yoo`00
77oo0P00CWoo0P002goo00<007ooOol05Goo000LOol00`00Oomoo`1>Ool20009Ool00`00Oomoo`0F
Ool001aoo`80051oo`03001oogoo00Moo`03001oogoo01Ioo`0077oo00<007ooOol0Cgoo00<007oo
Ool01goo00<007ooOol05Woo000;Ool20004Ool01000Oomoogoo1@000Woo0P00DGoo00<007ooOol0
1Woo00<007ooOol05Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo051oo`03
001oogoo00Ioo`03001oogoo01Ioo`002Woo00@007ooOol000Uoo`03001oogoo009oo`80059oo`03
001oogoo00Aoo`03001oogoo01Moo`002Woo00@007ooOol000Yoo`05001oogooOol0001COol00`00
Oomoo`04Ool00`00Oomoo`0GOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00DWoo
00<007ooOol017oo00<007ooOol05goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo059oo`03001oogoo00=oo`03001oogoo01Moo`002goo0P002Goo0`000goo0P00Dgoo00<0
07ooOol00Woo00<007ooOol067oo000LOol00`00Oomoo`1BOol00`00Oomoo`02Ool00`00Oomoo`0H
Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8005=oo`03001oogoo009oo`03001oogoo01Qo
o`002Woo00@007ooOol000Yoo`05001oogooOol0001DOol00`00Oomoo`02Ool00`00Oomoo`0HOol0
00Yoo`04001oogoo0007Ool50002Ool2001DOol01@00Oomoogoo00006Woo000:Ool01000Oomoo`00
1goo00@007ooOol000=oo`03001oogoo05=oo`05001oogooOol0000JOol000Yoo`04001oogoo0008
Ool00`00Ool00003Ool2001EOol00`00Ool0000KOol000Yoo`04001oogoo0009Ool20003Ool00`00
Oomoo`1DOol00`00Ool0000KOol000]oo`8000]oo`04001oogooOol2001EOol2000LOol001aoo`03
001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomo
o`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00
Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol0
00Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001c
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool3
0003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02
Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol0
0`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
0001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2200\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23178 L
.012 .23178 L
.016 .23178 L
.02 .23178 L
.024 .23177 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23177 L
.044 .2318 L
.048 .23183 L
.052 .23185 L
.056 .23185 L
.06 .23181 L
.064 .23174 L
.068 .23163 L
.072 .23151 L
.076 .23141 L
.08 .2314 L
.084 .23151 L
.088 .23178 L
.092 .23223 L
.096 .23282 L
.1 .23347 L
.104 .23402 L
.108 .2343 L
.112 .23407 L
.116 .23314 L
.12 .2313 L
.124 .22842 L
.128 .22446 L
.132 .21945 L
.136 .21354 L
.14 .20698 L
.144 .20006 L
.148 .19315 L
.152 .18661 L
.156 .18079 L
.16 .17597 L
.164 .17238 L
.168 .17016 L
.172 .16934 L
.176 .1699 L
.18 .1717 L
.184 .17459 L
.188 .17833 L
.192 .18271 L
.196 .18749 L
.2 .19245 L
Mistroke
.204 .1974 L
.208 .20218 L
.212 .20667 L
.216 .21077 L
.22 .21445 L
.224 .21768 L
.228 .22045 L
.232 .2228 L
.236 .22475 L
.24 .22634 L
.244 .22763 L
.248 .22865 L
.252 .22945 L
.256 .23006 L
.26 .23053 L
.264 .23089 L
.268 .23115 L
.272 .23134 L
.276 .23148 L
.28 .23158 L
.284 .23166 L
.288 .23171 L
.292 .23174 L
.296 .23177 L
.3 .23178 L
.304 .23179 L
.308 .2318 L
.312 .2318 L
.316 .23181 L
.32 .23181 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23181 L
.676 .23181 L
.68 .23182 L
.684 .23182 L
.688 .23182 L
.692 .23182 L
.696 .23182 L
.7 .23183 L
.704 .23183 L
.708 .23185 L
.712 .23186 L
.716 .23189 L
.72 .23192 L
.724 .23197 L
.728 .23204 L
.732 .23214 L
.736 .23229 L
.74 .23248 L
.744 .23274 L
.748 .2331 L
.752 .23357 L
.756 .23418 L
.76 .23498 L
.764 .236 L
.768 .23729 L
.772 .23888 L
.776 .24083 L
.78 .24318 L
.784 .24595 L
.788 .24917 L
.792 .25285 L
.796 .25695 L
.8 .26143 L
Mistroke
.804 .2662 L
.808 .27115 L
.812 .2761 L
.816 .28088 L
.82 .28525 L
.824 .289 L
.828 .29188 L
.832 .29369 L
.836 .29425 L
.84 .29344 L
.844 .29122 L
.848 .28764 L
.852 .28283 L
.856 .27701 L
.86 .27047 L
.864 .26356 L
.868 .25664 L
.872 .25007 L
.876 .24416 L
.88 .23914 L
.884 .23516 L
.888 .23228 L
.892 .23043 L
.896 .22949 L
.9 .22926 L
.904 .22954 L
.908 .2301 L
.912 .23075 L
.916 .23134 L
.92 .2318 L
.924 .23208 L
.928 .23219 L
.932 .23217 L
.936 .23208 L
.94 .23196 L
.944 .23184 L
.948 .23177 L
.952 .23173 L
.956 .23173 L
.96 .23175 L
.964 .23178 L
.968 .23181 L
.972 .23182 L
.976 .23183 L
.98 .23183 L
.984 .23182 L
.988 .23181 L
.992 .23181 L
.996 .2318 L
1 .23179 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35317 m
.008 .35318 L
.012 .35317 L
.016 .35317 L
.02 .35316 L
.024 .35313 L
.028 .35311 L
.032 .3531 L
.036 .35311 L
.04 .35316 L
.044 .35325 L
.048 .35335 L
.052 .35342 L
.056 .35342 L
.06 .3533 L
.064 .35304 L
.068 .35266 L
.072 .35223 L
.076 .3519 L
.08 .35183 L
.084 .35222 L
.088 .35319 L
.092 .35478 L
.096 .35687 L
.1 .35915 L
.104 .36112 L
.108 .36208 L
.112 .3613 L
.116 .35797 L
.12 .35143 L
.124 .34118 L
.128 .32705 L
.132 .30919 L
.136 .28811 L
.14 .26467 L
.144 .23996 L
.148 .21526 L
.152 .19186 L
.156 .17101 L
.16 .15374 L
.164 .14088 L
.168 .13289 L
.172 .12994 L
.176 .13189 L
.18 .13832 L
.184 .14861 L
.188 .16199 L
.192 .17764 L
.196 .19472 L
.2 .21245 L
Mistroke
.204 .23015 L
.208 .24723 L
.212 .26328 L
.216 .27796 L
.22 .29112 L
.224 .30265 L
.228 .31257 L
.232 .32096 L
.236 .32793 L
.24 .33363 L
.244 .33822 L
.248 .34187 L
.252 .34472 L
.256 .34692 L
.26 .3486 L
.264 .34986 L
.268 .3508 L
.272 .35149 L
.276 .35199 L
.28 .35235 L
.284 .3526 L
.288 .35278 L
.292 .35291 L
.296 .35299 L
.3 .35305 L
.304 .35309 L
.308 .35311 L
.312 .35313 L
.316 .35314 L
.32 .35315 L
.324 .35315 L
.328 .35316 L
.332 .35316 L
.336 .35316 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35316 L
.676 .35316 L
.68 .35316 L
.684 .35315 L
.688 .35315 L
.692 .35314 L
.696 .35313 L
.7 .35311 L
.704 .35309 L
.708 .35305 L
.712 .35299 L
.716 .35291 L
.72 .35278 L
.724 .3526 L
.728 .35235 L
.732 .35199 L
.736 .35149 L
.74 .3508 L
.744 .34986 L
.748 .3486 L
.752 .34692 L
.756 .34472 L
.76 .34187 L
.764 .33822 L
.768 .33363 L
.772 .32793 L
.776 .32096 L
.78 .31257 L
.784 .30265 L
.788 .29112 L
.792 .27797 L
.796 .26328 L
.8 .24724 L
Mistroke
.804 .23015 L
.808 .21245 L
.812 .19472 L
.816 .17764 L
.82 .16199 L
.824 .14861 L
.828 .13833 L
.832 .1319 L
.836 .12995 L
.84 .13289 L
.844 .14088 L
.848 .15375 L
.852 .17101 L
.856 .19186 L
.86 .21526 L
.864 .23996 L
.868 .26467 L
.872 .28811 L
.876 .30919 L
.88 .32705 L
.884 .34118 L
.888 .35143 L
.892 .35797 L
.896 .3613 L
.9 .36208 L
.904 .36112 L
.908 .35914 L
.912 .35687 L
.916 .35478 L
.92 .35319 L
.924 .35222 L
.928 .35183 L
.932 .3519 L
.936 .35223 L
.94 .35266 L
.944 .35304 L
.948 .3533 L
.952 .35342 L
.956 .35342 L
.96 .35335 L
.964 .35324 L
.968 .35316 L
.972 .35311 L
.976 .3531 L
.98 .35312 L
.984 .35314 L
.988 .35316 L
.992 .35318 L
.996 .35317 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23177 L
.012 .23178 L
.016 .23178 L
.02 .23176 L
.024 .23174 L
.028 .23172 L
.032 .23171 L
.036 .23172 L
.04 .23176 L
.044 .23184 L
.048 .23192 L
.052 .23198 L
.056 .23198 L
.06 .23188 L
.064 .23166 L
.068 .23134 L
.072 .23099 L
.076 .2307 L
.08 .23065 L
.084 .23097 L
.088 .23178 L
.092 .23312 L
.096 .23487 L
.1 .23679 L
.104 .23843 L
.108 .23926 L
.112 .23859 L
.116 .2358 L
.12 .2303 L
.124 .2217 L
.128 .20984 L
.132 .19485 L
.136 .17716 L
.14 .15748 L
.144 .13675 L
.148 .11601 L
.152 .09637 L
.156 .07887 L
.16 .06438 L
.164 .05358 L
.168 .04688 L
.172 .04441 L
.176 .04605 L
.18 .05145 L
.184 .06009 L
.188 .07132 L
.192 .08446 L
.196 .0988 L
.2 .11369 L
Mistroke
.204 .12854 L
.208 .14289 L
.212 .15636 L
.216 .16869 L
.22 .17973 L
.224 .18941 L
.228 .19774 L
.232 .20478 L
.236 .21063 L
.24 .21542 L
.244 .21927 L
.248 .22233 L
.252 .22472 L
.256 .22657 L
.26 .22798 L
.264 .22904 L
.268 .22983 L
.272 .23041 L
.276 .23083 L
.28 .23113 L
.284 .23134 L
.288 .23149 L
.292 .2316 L
.296 .23167 L
.3 .23172 L
.304 .23175 L
.308 .23177 L
.312 .23179 L
.316 .2318 L
.32 .2318 L
.324 .23181 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23181 L
.672 .23182 L
.676 .23182 L
.68 .23182 L
.684 .23182 L
.688 .23182 L
.692 .23183 L
.696 .23184 L
.7 .23185 L
.704 .23188 L
.708 .23191 L
.712 .23196 L
.716 .23203 L
.72 .23213 L
.724 .23228 L
.728 .2325 L
.732 .2328 L
.736 .23322 L
.74 .2338 L
.744 .23459 L
.748 .23565 L
.752 .23705 L
.756 .2389 L
.76 .2413 L
.764 .24436 L
.768 .24821 L
.772 .253 L
.776 .25885 L
.78 .26589 L
.784 .27422 L
.788 .2839 L
.792 .29494 L
.796 .30727 L
.8 .32074 L
Mistroke
.804 .33508 L
.808 .34994 L
.812 .36482 L
.816 .37916 L
.82 .3923 L
.824 .40354 L
.828 .41217 L
.832 .41757 L
.836 .41921 L
.84 .41674 L
.844 .41004 L
.848 .39924 L
.852 .38476 L
.856 .36725 L
.86 .34762 L
.864 .32688 L
.868 .30615 L
.872 .28647 L
.876 .26878 L
.88 .25379 L
.884 .24192 L
.888 .23333 L
.892 .22783 L
.896 .22504 L
.9 .22437 L
.904 .2252 L
.908 .22683 L
.912 .22875 L
.916 .23051 L
.92 .23184 L
.924 .23266 L
.928 .23298 L
.932 .23293 L
.936 .23264 L
.94 .23229 L
.944 .23196 L
.948 .23175 L
.952 .23165 L
.956 .23165 L
.96 .23171 L
.964 .23179 L
.968 .23186 L
.972 .23191 L
.976 .23192 L
.98 .23191 L
.984 .23189 L
.988 .23187 L
.992 .23186 L
.996 .23184 L
1 .23184 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000?Ool30002Ool01000Oomoo`002Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00aoo`@00004Ool007oo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`00
1Goo000;Ool20009Ool30003Ool2000=Ool20003Ool30002Ool00`00Oomoo`06Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool001aoo`03001oogoo00aoo`D00003Ool00000008000Yoo`03001oogoo00=oo`8000Ao
o`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool2
0006Ool001aoo`8000aoo`8000Ioo`8005eoo`0077oo00<007ooOol02goo00<007ooOol01Woo0P00
G7oo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`030003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00<007ooOol0100000=oo`00
Ool00Woo00@007ooOomoo`80009oo`05001oogooOol00004Ool00`00Oomoo`0:Ool001aoo`8004mo
o`8000Moo`8001Uoo`0077oo00<007ooOol0Cgoo0P001Woo00<007ooOol067oo000LOol2001AOol2
0004Ool2000JOol001aoo`03001oogoo055oo`8000=oo`03001oogoo01Uoo`002goo0P0017oo00@0
07ooOomoo`D0009oo`8005=oo`@001aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00
Oomoo`1COol2000MOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001cOol000Yoo`04001o
ogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
07=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uo
o`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2
001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@00
0Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo
079oo`002goo0P002goo00@007ooOomoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool0
0`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007oo
Ool000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=o
o`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo
0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007oo
Ool0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<0
07ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo
000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<007Qo
o`002Woo00@007ooOol000Moo`05001oogooOol0001gOol000=oo`D0009oo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2001cOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo10000goo0P00
Lgoo000:Ool01000Oomoo`001goo00<007ooOol017oo00<007ooOol0LWoo000:Ool01000Oomoo`00
27oo00<007ooOol00goo0P00Lgoo000;Ool2000:Ool20003Ool00`00Oomoo`1bOol001aoo`80011o
o`03001oogoo045oo`8001eoo`0077oo00<007ooOol03Woo00<007oo0000@Woo0P007Goo000;Ool2
0004Ool00`00Oomoo`03Ool30002Ool2000?Ool00`00Ool00011Ool01000Oomoo`0077oo000:Ool0
1000Oomoo`002Woo00D007ooOomoo`00011oo`04001oogoo0010Ool01000Oomoo`0077oo0003Ool5
0002Ool01000Oomoo`001goo1@000Woo00<007ooOol03Goo00D007ooOomoo`00041oo`04001oogoo
000LOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P003Woo00D007ooOomoo`00041oo`04
001oogoo000LOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`0=Ool01@00Oomo
ogoo0000@7oo00D007ooOomoo`0001]oo`002Woo00@007ooOol000Uoo`8000=oo`8000ioo`05001o
ogooOol0000oOol00`00Oomoo`02Ool00`00Oomoo`0IOol000]oo`8000]oo`05001oogooOol0000?
Ool00`00Oomoo`02Ool00`00Oomoo`0lOol00`00Oomoo`02Ool00`00Oomoo`0IOol001aoo`8000io
o`03001oogoo009oo`03001oogoo03aoo`03001oogoo009oo`03001oogoo01Uoo`0077oo00<007oo
Ool03Goo00<007ooOol00Woo00<007ooOol0>goo00<007ooOol00goo00<007ooOol06Goo000;Ool2
0004Ool01000Oomoogoo1@000Woo0P003Goo00<007ooOol00goo00<007ooOol0>goo00<007ooOol0
17oo00<007ooOol067oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00aoo`03
001oogoo00Aoo`03001oogoo03Yoo`03001oogoo00Aoo`03001oogoo01Qoo`000goo1@000Woo00@0
07ooOol000Uoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00Aoo`03001oogoo03Yoo`03
001oogoo00Aoo`03001oogoo01Qoo`002Woo00@007ooOol000Yoo`04001oogooOol2000=Ool40003
Ool30009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool30004
Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool037oo00D007ooOomoo`00009oo`800003Ool007oo00Qoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000
Oomoo`000Woo0P0000Eoo`00Oomoo`00009oo`03001oogoo00=oo`06001oogoo001oo`000goo00@0
07ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000<
Ool00`00Oomoo`02Ool00`00Oomoo`0200000goo001oo`08Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool200001Goo001oogoo00000Woo00<007ooOol017oo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00=oo`002goo0P002Goo0`000goo00<007ooOol02goo00<007ooOol00Woo00<007oo
Ool00P0000=oo`00Ool027oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00@007ooOomoo`800005Ool007ooOol00002
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000<
Ool50003Ool200000goo001oo`08Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool0
0`00Oomoo`020003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo
00]oo`8000Ioo`04001oo`000008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=o
o`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001o
ogoo008000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol02Woo
00<007oo000010000goo0`002Goo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=o
o`8000Ioo`<0009oo`04001oo`000004Ool200000goo001oo`03Ool30002Ool50003Ool20006Ool0
01aoo`8000]oo`03001oogoo00Uoo`03001oogoo03=oo`8000Yoo`03001oogoo01Moo`0077oo00<0
07ooOol02Woo00<007ooOol02Woo0P00<Woo0P0037oo00<007ooOol05Woo000LOomY000<Ool001ao
o`03001oogoo00Qoo`8000Qoo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001o
ogoo00Moo`8000Uoo`03001oogoo00Yoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogooOol5
0002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0LWoo000:Ool0
1000Oomoo`002Goo00<007ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`00
07Aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001c
Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo
0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079o
o`002goo0P002goo00D007ooOomoo`0007Aoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`0?Ool0
0`00Oomoo`1POol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8000moo`03001oo`00065oo`00
2Woo00@007ooOol000Yoo`05001oogooOol0000@Ool00`00Ool0001QOol000=oo`D0009oo`04001o
ogoo0007Ool50002Ool2000?Ool01000Oomoo`00H7oo000:Ool01000Oomoo`001goo00@007ooOol0
00=oo`03001oogoo00eoo`05001oogooOol0001POol000Yoo`04001oogoo0008Ool00`00Ool00003
Ool2000>Ool01@00Oomoogoo0000H7oo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol03Goo
00D007ooOomoo`00061oo`002goo0P002goo00@007ooOomoo`8000ioo`03001oogoo009oo`03001o
ogoo05eoo`0077oo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol0GGoo000;Ool20004Ool0
1000Oomoogoo1@000Woo0P003Goo00<007ooOol00goo00<007ooOol0GGoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`03001oogoo00aoo`@000=oo`<000Uoo`<000Aoo`8000Aoo`8000Eoo`<0
00=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`000goo1@00
0Woo00@007ooOol000Uoo`03001oogoo009oo`8000eoo`05001oogooOol00002Ool01000Oomoo`00
2Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@0
07ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eo
o`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Yo
o`05001oogooOol0000>Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Ao
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000=Ool01@00
Oomoogoo00000Woo0P0000=oo`00Ool027oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00]oo`D000=oo`800003Ool0
07oo00Qoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=o
o`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00
Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uoo`<000=oo`8000aoo`8000Ioo`80
0003Ool007oo00Moo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol0
17oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07
001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol02goo1P000goo0P002Woo
00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`80
00Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P002goo00<007ooOol027oo0P00Fgoo000LOol00`00
Oomoo`0:Ool00`00Oomoo`09Ool2001JOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03
001oo`0000<000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Ao
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0004Ool50003Ool01@00Oomoogoo00000goo0P000Woo0`0000=oo`00Ool00goo00<007ooOol02Woo
000LOol2001=Ool2000;Ool00`00Oomoo`0FOol001aoo`03001oogoo04eoo`03001oogoo00Qoo`03
001oogoo01Moo`0077oo0P00Cgoo00<007ooOol01goo00<007ooOol05goo000LOol00`00Oomoo`1>
Ool00`00Oomoo`07Ool00`00Oomoo`0GOol000]oo`8000Aoo`04001oogooOol50002Ool2001@Ool0
0`00Oomoo`05Ool00`00Oomoo`0HOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007oo
Ool0Cgoo00<007ooOol01Goo00<007ooOol067oo000:Ool01000Oomoo`002Goo00<007ooOol00Woo
0P00D7oo00<007ooOol01Goo00<007ooOol067oo000:Ool01000Oomoo`002Woo00D007ooOomoo`00
055oo`03001oogoo00Eoo`03001oogoo01Qoo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool2001AOol00`00Oomoo`04Ool00`00Oomoo`0HOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol0D7oo00<007ooOol017oo00<007ooOol067oo000;Ool20009Ool30003Ool2
001AOol00`00Oomoo`03Ool00`00Oomoo`0IOol001aoo`03001oogoo055oo`03001oogoo009oo`03
001oogoo01Uoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00DWoo00<007ooOol00Woo00<0
07ooOol06Goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0005=oo`03001oogoo009oo`03001o
ogoo01Uoo`002Woo00@007ooOol000Moo`D0009oo`8005=oo`04001oogoo000LOol000Yoo`04001o
ogoo0007Ool01000Oomoo`000goo00<007ooOol0DWoo00@007ooOol001aoo`002Woo00@007ooOol0
00Qoo`03001oo`0000=oo`8005=oo`04001oogoo000LOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1COol2000MOol000]oo`8000]oo`04001oogooOol2001DOol2000MOol001aoo`03001o
ogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1b
Ool000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomo
o`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qo
o`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003
Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool0
0`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00
Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2240\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23178 m
.008 .23178 L
.012 .23178 L
.016 .23178 L
.02 .23178 L
.024 .23178 L
.028 .23178 L
.032 .23177 L
.036 .23176 L
.04 .23176 L
.044 .23175 L
.048 .23176 L
.052 .23178 L
.056 .2318 L
.06 .23183 L
.064 .23185 L
.068 .23185 L
.072 .23181 L
.076 .23173 L
.08 .23161 L
.084 .23148 L
.088 .23139 L
.092 .23137 L
.096 .2315 L
.1 .23179 L
.104 .23227 L
.108 .23289 L
.112 .23355 L
.116 .23413 L
.12 .2344 L
.124 .23418 L
.128 .23321 L
.132 .23134 L
.136 .22841 L
.14 .22439 L
.144 .21934 L
.148 .21339 L
.152 .2068 L
.156 .19987 L
.16 .19296 L
.164 .18644 L
.168 .18065 L
.172 .17588 L
.176 .17234 L
.18 .17016 L
.184 .16939 L
.188 .16998 L
.192 .17181 L
.196 .17471 L
.2 .17846 L
Mistroke
.204 .18284 L
.208 .18761 L
.212 .19255 L
.216 .19748 L
.22 .20224 L
.224 .20671 L
.228 .2108 L
.232 .21446 L
.236 .21768 L
.24 .22044 L
.244 .22278 L
.248 .22473 L
.252 .22632 L
.256 .22761 L
.26 .22863 L
.264 .22943 L
.268 .23005 L
.272 .23052 L
.276 .23088 L
.28 .23114 L
.284 .23134 L
.288 .23148 L
.292 .23158 L
.296 .23165 L
.3 .2317 L
.304 .23174 L
.308 .23176 L
.312 .23178 L
.316 .23179 L
.32 .2318 L
.324 .2318 L
.328 .23181 L
.332 .23181 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23181 L
.664 .23181 L
.668 .23182 L
.672 .23182 L
.676 .23182 L
.68 .23182 L
.684 .23182 L
.688 .23183 L
.692 .23184 L
.696 .23185 L
.7 .23186 L
.704 .23189 L
.708 .23192 L
.712 .23197 L
.716 .23205 L
.72 .23215 L
.724 .23229 L
.728 .23249 L
.732 .23275 L
.736 .23311 L
.74 .23358 L
.744 .2342 L
.748 .235 L
.752 .23602 L
.756 .23731 L
.76 .2389 L
.764 .24085 L
.768 .24319 L
.772 .24595 L
.776 .24916 L
.78 .25282 L
.784 .25691 L
.788 .26137 L
.792 .26612 L
.796 .27105 L
.8 .27599 L
Mistroke
.804 .28075 L
.808 .28512 L
.812 .28887 L
.816 .29177 L
.82 .29361 L
.824 .2942 L
.828 .29344 L
.832 .29127 L
.836 .28773 L
.84 .28297 L
.844 .27718 L
.848 .27066 L
.852 .26376 L
.856 .25682 L
.86 .25022 L
.864 .24427 L
.868 .2392 L
.872 .23517 L
.876 .23224 L
.88 .23035 L
.884 .22938 L
.888 .22915 L
.892 .22943 L
.896 .23001 L
.9 .23068 L
.904 .23131 L
.908 .23179 L
.912 .23209 L
.916 .23222 L
.92 .2322 L
.924 .2321 L
.928 .23197 L
.932 .23185 L
.936 .23177 L
.94 .23173 L
.944 .23173 L
.948 .23175 L
.952 .23178 L
.956 .23181 L
.96 .23182 L
.964 .23183 L
.968 .23183 L
.972 .23182 L
.976 .23181 L
.98 .2318 L
.984 .2318 L
.988 .2318 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35315 m
.008 .35315 L
.012 .35316 L
.016 .35317 L
.02 .35318 L
.024 .35318 L
.028 .35317 L
.032 .35316 L
.036 .35313 L
.04 .3531 L
.044 .35309 L
.048 .35311 L
.052 .35317 L
.056 .35326 L
.06 .35337 L
.064 .35345 L
.068 .35344 L
.072 .3533 L
.076 .35302 L
.08 .3526 L
.084 .35215 L
.088 .3518 L
.092 .35175 L
.096 .35217 L
.1 .35321 L
.104 .3549 L
.108 .35709 L
.112 .35946 L
.116 .36148 L
.12 .36248 L
.124 .36166 L
.128 .35825 L
.132 .35157 L
.136 .34115 L
.14 .32683 L
.144 .30879 L
.148 .28756 L
.152 .26401 L
.156 .23927 L
.16 .21457 L
.164 .19125 L
.168 .17052 L
.172 .15342 L
.176 .14072 L
.18 .1329 L
.184 .13011 L
.188 .13218 L
.192 .1387 L
.196 .14905 L
.2 .16245 L
Mistroke
.204 .17808 L
.208 .19513 L
.212 .2128 L
.216 .23043 L
.22 .24745 L
.224 .26343 L
.228 .27806 L
.232 .29116 L
.236 .30265 L
.24 .31254 L
.244 .32091 L
.248 .32787 L
.252 .33356 L
.256 .33815 L
.26 .3418 L
.264 .34466 L
.268 .34687 L
.272 .34855 L
.276 .34982 L
.28 .35077 L
.284 .35146 L
.288 .35197 L
.292 .35233 L
.296 .35259 L
.3 .35277 L
.304 .3529 L
.308 .35299 L
.312 .35305 L
.316 .35309 L
.32 .35311 L
.324 .35313 L
.328 .35314 L
.332 .35315 L
.336 .35315 L
.34 .35316 L
.344 .35316 L
.348 .35316 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35316 L
.664 .35316 L
.668 .35316 L
.672 .35315 L
.676 .35315 L
.68 .35314 L
.684 .35313 L
.688 .35311 L
.692 .35309 L
.696 .35305 L
.7 .35299 L
.704 .3529 L
.708 .35277 L
.712 .35259 L
.716 .35233 L
.72 .35197 L
.724 .35146 L
.728 .35077 L
.732 .34982 L
.736 .34855 L
.74 .34687 L
.744 .34466 L
.748 .3418 L
.752 .33815 L
.756 .33356 L
.76 .32787 L
.764 .32091 L
.768 .31254 L
.772 .30265 L
.776 .29116 L
.78 .27806 L
.784 .26343 L
.788 .24746 L
.792 .23044 L
.796 .21281 L
.8 .19513 L
Mistroke
.804 .17809 L
.808 .16245 L
.812 .14905 L
.816 .13871 L
.82 .13219 L
.824 .13011 L
.828 .1329 L
.832 .14072 L
.836 .15342 L
.84 .17052 L
.844 .19126 L
.848 .21458 L
.852 .23927 L
.856 .26402 L
.86 .28757 L
.864 .30879 L
.868 .32683 L
.872 .34115 L
.876 .35157 L
.88 .35825 L
.884 .36166 L
.888 .36248 L
.892 .36148 L
.896 .35946 L
.9 .35709 L
.904 .3549 L
.908 .35321 L
.912 .35217 L
.916 .35175 L
.92 .3518 L
.924 .35215 L
.928 .3526 L
.932 .35302 L
.936 .3533 L
.94 .35344 L
.944 .35345 L
.948 .35337 L
.952 .35326 L
.956 .35317 L
.96 .35311 L
.964 .35309 L
.968 .3531 L
.972 .35313 L
.976 .35315 L
.98 .35317 L
.984 .35318 L
.988 .35318 L
.992 .35317 L
.996 .35317 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23177 L
.02 .23177 L
.024 .23178 L
.028 .23177 L
.032 .23176 L
.036 .23174 L
.04 .23172 L
.044 .2317 L
.048 .23172 L
.052 .23177 L
.056 .23185 L
.06 .23194 L
.064 .232 L
.068 .232 L
.072 .23188 L
.076 .23164 L
.08 .23129 L
.084 .23091 L
.088 .23062 L
.092 .23057 L
.096 .23093 L
.1 .23181 L
.104 .23322 L
.108 .23506 L
.112 .23705 L
.116 .23875 L
.12 .23958 L
.124 .2389 L
.128 .23603 L
.132 .23042 L
.136 .22168 L
.14 .20966 L
.144 .19452 L
.148 .1767 L
.152 .15694 L
.156 .13616 L
.16 .11544 L
.164 .09586 L
.168 .07846 L
.172 .0641 L
.176 .05345 L
.18 .04689 L
.184 .04455 L
.188 .04629 L
.192 .05177 L
.196 .06046 L
.2 .07171 L
Mistroke
.204 .08484 L
.208 .09914 L
.212 .11398 L
.216 .12879 L
.22 .14307 L
.224 .15648 L
.228 .16877 L
.232 .17976 L
.236 .18941 L
.24 .19772 L
.244 .20474 L
.248 .21058 L
.252 .21536 L
.256 .21921 L
.26 .22227 L
.264 .22467 L
.268 .22653 L
.272 .22794 L
.276 .22901 L
.28 .2298 L
.284 .23039 L
.288 .23081 L
.292 .23112 L
.296 .23133 L
.3 .23149 L
.304 .23159 L
.308 .23167 L
.312 .23172 L
.316 .23175 L
.32 .23177 L
.324 .23179 L
.328 .2318 L
.332 .2318 L
.336 .23181 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23181 L
.66 .23182 L
.664 .23182 L
.668 .23182 L
.672 .23182 L
.676 .23182 L
.68 .23183 L
.684 .23184 L
.688 .23186 L
.692 .23188 L
.696 .23191 L
.7 .23196 L
.704 .23203 L
.708 .23214 L
.712 .23229 L
.716 .23251 L
.72 .23282 L
.724 .23324 L
.728 .23382 L
.732 .23462 L
.736 .23568 L
.74 .2371 L
.744 .23895 L
.748 .24135 L
.752 .24441 L
.756 .24827 L
.76 .25305 L
.764 .25889 L
.768 .26591 L
.772 .27422 L
.776 .28386 L
.78 .29486 L
.784 .30714 L
.788 .32055 L
.792 .33484 L
.796 .34964 L
.8 .36448 L
Mistroke
.804 .37879 L
.808 .39192 L
.812 .40317 L
.816 .41185 L
.82 .41733 L
.824 .41908 L
.828 .41673 L
.832 .41017 L
.836 .39952 L
.84 .38517 L
.844 .36777 L
.848 .34819 L
.852 .32747 L
.856 .30669 L
.86 .28693 L
.864 .26911 L
.868 .25397 L
.872 .24195 L
.876 .2332 L
.88 .2276 L
.884 .22473 L
.888 .22405 L
.892 .22487 L
.896 .22658 L
.9 .22857 L
.904 .23041 L
.908 .23182 L
.912 .23269 L
.916 .23305 L
.92 .233 L
.924 .23272 L
.928 .23233 L
.932 .23199 L
.936 .23175 L
.94 .23163 L
.944 .23163 L
.948 .23169 L
.952 .23178 L
.956 .23186 L
.96 .23191 L
.964 .23193 L
.968 .23191 L
.972 .23189 L
.976 .23187 L
.98 .23185 L
.984 .23185 L
.988 .23185 L
.992 .23186 L
.996 .23187 L
1 .23187 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000@Ool300001Goo001oogoo00002Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00aoo`@0009oo`80009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool0
00]oo`8000Uoo`<000=oo`8000eoo`03001oo`0000Aoo`04001oogoo0008Ool20004Ool01000Oomo
o`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo
0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04
001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001ao
o`8000ioo`03001oogoo00Aoo`8005aoo`0077oo00<007ooOol037oo00<007ooOol01goo00<007oo
Ool0FGoo000LOomY000<Ool001aoo`05001oogooOol00003Ool01000Oomoogoo0P000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`03001oo`0000<0009o
o`05001oogooOol00002Ool20003Ool01@00Oomoogoo000017oo00<007ooOol02Woo000LOol2001>
Ool20007Ool2000JOol001aoo`03001oogoo04ioo`8000Ioo`03001oogoo01Uoo`0077oo0P00D7oo
00<007ooOol00goo00<007ooOol06Woo000LOol00`00Oomoo`1@Ool01@00Oomoogoo00007Goo000;
Ool20004Ool01000Oomoogoo1@000Woo0P00DWoo10007Goo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`03001oogoo059oo`8001ioo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=o
o`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079o
o`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo
00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001o
ogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0
LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P00
0goo00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol0
00]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo
000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007oo
Ool017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2
000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`00
0goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo
000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0
LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo
000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007oo
Ool00Woo0`00N7oo000:Ool01000Oomoo`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002goo0P002Goo0`000goo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo
0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@00
0Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool40003Ool2001cOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0008Ool00`00Oomoo`03Ool2001cOol000]oo`8000Yoo`8000=oo`03001oogoo079o
o`0077oo0P004Goo0P00@7oo0P007Woo000LOol00`00Oomoo`0?Ool00`00Ool00010Ool2000NOol0
00]oo`8000Aoo`03001oogoo00=oo`<0009oo`80011oo`03001oo`0003moo`04001oogoo000MOol0
00Yoo`04001oogoo000:Ool01@00Oomoogoo00004Goo00@007ooOol003ioo`04001oogoo000MOol0
00=oo`D0009oo`04001oogoo0007Ool50002Ool00`00Oomoo`0?Ool01000Oomoo`00?Woo00@007oo
Ool001eoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool2000@Ool01000Oomoo`00?Goo00D0
07ooOomoo`0001eoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo00ioo`05001o
ogooOol0000mOol01@00Oomoogoo00007Goo000:Ool01000Oomoo`002Goo0P000goo0P003goo00<0
07ooOol00Woo00<007ooOol0>Woo00D007ooOomoo`0001eoo`002goo0P002goo00D007ooOomoo`00
011oo`03001oogoo009oo`03001oogoo03Uoo`03001oogoo00=oo`03001oogoo01Yoo`0077oo0P00
3goo00<007ooOol00Woo00<007ooOol0>Goo00<007ooOol00goo00<007ooOol06Woo000LOol00`00
Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0hOol00`00Oomoo`03Ool00`00Oomoo`0JOol000]o
o`8000Aoo`04001oogooOol50002Ool2000>Ool00`00Oomoo`04Ool00`00Oomoo`0hOol00`00Oomo
o`03Ool00`00Oomoo`0JOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol03Goo
00<007ooOol017oo00<007ooOol0>7oo00<007ooOol00goo00<007ooOol06Woo0003Ool50002Ool0
1000Oomoo`002Goo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol017oo00<007ooOol0>7oo
00<007ooOol017oo00<007ooOol06Goo000:Ool01000Oomoo`002Woo00@007ooOomoo`8000ioo`<0
00Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D0009oo`<000Aoo`80
00Eoo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`0<Ool20002Ool01@00Oomoo`00Ool00P002Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007oo000000Eoo`06001oogoo001oo`000goo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000>Ool01000Oomo
o`000Woo00@007oo000000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`04001oogooOol20002Ool01@00Oomoo`00
Ool00P001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Goo0`00
0goo00<007ooOol03Goo00@007ooOol0009oo`04001oo`000009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`020002Ool01@00Oomoo`00Ool00P001goo00<007ooOol017oo00@007ooOol0009oo`03001o
ogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01P00Oomoogoo001oo`80
009oo`04001oogoo0002Ool00`00Oomoo`02Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005
Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01P00Oomoogoo001o
o`80009oo`04001oogoo0002Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo
0005Ool001aoo`03001oogoo00aoo`D000=oo`@000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04
001oogooOol50003Ool20006Ool3000017oo001oogoo0P0017oo0`001Goo0`000Woo1@000goo0P00
1Woo000LOol2000=Ool00`00Oomoo`08Ool2000bOol00`00Oomoo`09Ool00`00Oomoo`0HOol001ao
o`03001oogoo00]oo`03001oogoo00Yoo`8002moo`<000]oo`03001oogoo01Qoo`0077ooJ@0037oo
000LOol00`00Oomoo`09Ool20007Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol0
0`00Oomoo`06Ool2000:Ool00`00Oomoo`0:Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000;Ool20004Ool01000Oomo
ogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo079oo`00
2Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`D0
009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomo
o`1bOol000]oo`8000]oo`05001oogooOol0001dOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
47oo0P00H7oo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000@Ool00`00Ool0001POol000Yo
o`04001oogoo000:Ool01@00Oomoogoo00004Goo00<007oo0000H7oo0003Ool50002Ool01000Oomo
o`001goo1@000Woo0P0047oo00@007ooOol005moo`002Woo00@007ooOol000Moo`04001oogoo0003
Ool00`00Oomoo`0?Ool01000Oomoo`00Ggoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00
3goo00D007ooOomoo`0005moo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo00ioo`03001o
ogoo009oo`03001oogoo05aoo`002goo0P002goo00@007ooOomoo`8000moo`03001oogoo009oo`03
001oogoo05aoo`0077oo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol0G7oo000;Ool20004
Ool01000Oomoogoo1@000Woo0P003Woo00<007ooOol017oo00<007ooOol0Fgoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eo
o`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`000goo
1@000Woo00@007ooOol000Uoo`03001oogoo009oo`8000eoo`80009oo`03001oogoo00800003Ool0
07oo00Qoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo
000:Ool01@00Oomoogoo00003goo00@007ooOol0009oo`800003Ool007oo00Qoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000>Ool0
1000Oomoo`000Woo00@007oo000000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000Ool00000
2Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@0
07ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogoo
Ool007oo10000goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P003Goo0P001Goo00@007oo
Ool000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@0
07ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogoo
Ool007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0`002Goo00<007oo
Ool00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0
009oo`D000=oo`8000Ioo`0077oo0P003Goo00<007ooOol01goo0P00FWoo000LOol00`00Oomoo`0;
Ool00`00Oomoo`09Ool2001IOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo
00<000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool6
0003Ool01@00Oomoogoo00000goo00<007ooOol00`000Woo00<007ooOol00Woo00<007ooOol02Woo
000LOol2001<Ool00`00Oomoo`09Ool00`00Oomoo`0HOol001aoo`03001oogoo04aoo`03001oogoo
00Qoo`03001oogoo01Qoo`0077oo0P00CWoo00<007ooOol01goo00<007ooOol067oo000LOol00`00
Oomoo`1=Ool00`00Oomoo`07Ool00`00Oomoo`0HOol000]oo`8000Aoo`04001oogooOol50002Ool2
001>Ool00`00Oomoo`06Ool00`00Oomoo`0IOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00<007ooOol0CWoo00<007ooOol01Goo00<007ooOol06Goo000:Ool01000Oomoo`002Goo00<007oo
Ool00Woo0P00Cgoo00<007ooOol01Goo00<007ooOol06Goo000:Ool01000Oomoo`002Woo00D007oo
Oomoo`00051oo`03001oogoo00Eoo`03001oogoo01Uoo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool2001@Ool00`00Oomoo`03Ool00`00Oomoo`0JOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0Cgoo00<007ooOol00goo00<007ooOol06Woo000;Ool20009Ool3
0003Ool2001@Ool00`00Oomoo`03Ool00`00Oomoo`0JOol001aoo`03001oogoo04moo`03001oogoo
00=oo`03001oogoo01Yoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00DGoo00D007ooOomo
o`0001eoo`002Woo00@007ooOol000Yoo`05001oogooOol0001BOol01@00Oomoogoo00007Goo000:
Ool01000Oomoo`001goo1@000Woo0P00DGoo00D007ooOomoo`0001eoo`002Woo00@007ooOol000Mo
o`04001oogoo0003Ool00`00Oomoo`1AOol01000Oomoo`007Goo000:Ool01000Oomoo`0027oo00<0
07oo00000goo0P00DWoo00@007ooOol001eoo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo
059oo`8001ioo`002goo0P002goo00@007ooOomoo`8005=oo`8001ioo`0077oo00<007ooOol0LWoo
000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=o
o`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo
0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<0
00=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=o
o`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo
079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Mo
o`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2280\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23178 L
.032 .23178 L
.036 .23178 L
.04 .23178 L
.044 .23177 L
.048 .23176 L
.052 .23175 L
.056 .23175 L
.06 .23176 L
.064 .23178 L
.068 .23181 L
.072 .23184 L
.076 .23186 L
.08 .23186 L
.084 .23181 L
.088 .23172 L
.092 .2316 L
.096 .23146 L
.1 .23136 L
.104 .23135 L
.108 .23148 L
.112 .2318 L
.116 .2323 L
.12 .23295 L
.124 .23365 L
.128 .23423 L
.132 .23452 L
.136 .23428 L
.14 .23329 L
.144 .23137 L
.148 .2284 L
.152 .22433 L
.156 .21922 L
.16 .21323 L
.164 .20661 L
.168 .19967 L
.172 .19277 L
.176 .18628 L
.18 .18052 L
.184 .17579 L
.188 .17229 L
.192 .17017 L
.196 .16944 L
.2 .17006 L
Mistroke
.204 .17192 L
.208 .17483 L
.212 .17859 L
.216 .18296 L
.22 .18772 L
.224 .19265 L
.228 .19756 L
.232 .2023 L
.236 .20675 L
.24 .21082 L
.244 .21447 L
.248 .21768 L
.252 .22044 L
.256 .22277 L
.26 .22471 L
.264 .2263 L
.268 .22759 L
.272 .22861 L
.276 .22941 L
.28 .23003 L
.284 .23051 L
.288 .23087 L
.292 .23113 L
.296 .23133 L
.3 .23147 L
.304 .23158 L
.308 .23165 L
.312 .2317 L
.316 .23174 L
.32 .23176 L
.324 .23178 L
.328 .23179 L
.332 .2318 L
.336 .2318 L
.34 .23181 L
.344 .23181 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23181 L
.652 .23181 L
.656 .23182 L
.66 .23182 L
.664 .23182 L
.668 .23182 L
.672 .23182 L
.676 .23183 L
.68 .23184 L
.684 .23185 L
.688 .23186 L
.692 .23189 L
.696 .23193 L
.7 .23198 L
.704 .23205 L
.708 .23216 L
.712 .2323 L
.716 .2325 L
.72 .23276 L
.724 .23312 L
.728 .2336 L
.732 .23422 L
.736 .23502 L
.74 .23604 L
.744 .23733 L
.748 .23892 L
.752 .24086 L
.756 .24319 L
.76 .24595 L
.764 .24915 L
.768 .2528 L
.772 .25687 L
.776 .26131 L
.78 .26604 L
.784 .27095 L
.788 .27588 L
.792 .28063 L
.796 .285 L
.8 .28875 L
Mistroke
.804 .29167 L
.808 .29353 L
.812 .29415 L
.816 .29343 L
.82 .29131 L
.824 .28782 L
.828 .2831 L
.832 .27735 L
.836 .27085 L
.84 .26395 L
.844 .25701 L
.848 .25038 L
.852 .24438 L
.856 .23926 L
.86 .23518 L
.864 .2322 L
.868 .23027 L
.872 .22928 L
.876 .22904 L
.88 .22933 L
.884 .22992 L
.888 .23062 L
.892 .23127 L
.896 .23178 L
.9 .2321 L
.904 .23224 L
.908 .23223 L
.912 .23213 L
.916 .23199 L
.92 .23186 L
.924 .23177 L
.928 .23172 L
.932 .23172 L
.936 .23174 L
.94 .23177 L
.944 .2318 L
.948 .23182 L
.952 .23183 L
.956 .23183 L
.96 .23182 L
.964 .23181 L
.968 .23181 L
.972 .2318 L
.976 .2318 L
.98 .2318 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35317 L
.032 .35318 L
.036 .35318 L
.04 .35317 L
.044 .35315 L
.048 .35312 L
.052 .3531 L
.056 .35308 L
.06 .35311 L
.064 .35318 L
.068 .35328 L
.072 .3534 L
.076 .35347 L
.08 .35346 L
.084 .3533 L
.088 .35298 L
.092 .35254 L
.096 .35206 L
.1 .3517 L
.104 .35166 L
.108 .35213 L
.112 .35325 L
.116 .35502 L
.12 .35732 L
.124 .35978 L
.128 .36187 L
.132 .36288 L
.136 .36203 L
.14 .35852 L
.144 .3517 L
.148 .34111 L
.152 .3266 L
.156 .30838 L
.16 .28701 L
.164 .26336 L
.168 .23857 L
.172 .2139 L
.176 .19065 L
.18 .17004 L
.184 .15309 L
.188 .14057 L
.192 .13292 L
.196 .13028 L
.2 .13248 L
Mistroke
.204 .13909 L
.208 .14948 L
.212 .1629 L
.216 .17853 L
.22 .19553 L
.224 .21315 L
.228 .23072 L
.232 .24767 L
.236 .26358 L
.24 .27815 L
.244 .2912 L
.248 .30265 L
.252 .31251 L
.256 .32086 L
.26 .3278 L
.264 .33349 L
.268 .33808 L
.272 .34173 L
.276 .3446 L
.28 .34681 L
.284 .34851 L
.288 .34978 L
.292 .35074 L
.296 .35144 L
.3 .35195 L
.304 .35232 L
.308 .35258 L
.312 .35276 L
.316 .35289 L
.32 .35298 L
.324 .35304 L
.328 .35308 L
.332 .35311 L
.336 .35313 L
.34 .35314 L
.344 .35315 L
.348 .35315 L
.352 .35316 L
.356 .35316 L
.36 .35316 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35316 L
.652 .35316 L
.656 .35316 L
.66 .35315 L
.664 .35315 L
.668 .35314 L
.672 .35313 L
.676 .35311 L
.68 .35308 L
.684 .35304 L
.688 .35298 L
.692 .35289 L
.696 .35276 L
.7 .35258 L
.704 .35232 L
.708 .35195 L
.712 .35144 L
.716 .35074 L
.72 .34978 L
.724 .34851 L
.728 .34681 L
.732 .3446 L
.736 .34173 L
.74 .33808 L
.744 .33349 L
.748 .3278 L
.752 .32086 L
.756 .31251 L
.76 .30265 L
.764 .2912 L
.768 .27815 L
.772 .26358 L
.776 .24767 L
.78 .23072 L
.784 .21316 L
.788 .19554 L
.792 .17853 L
.796 .16291 L
.8 .14949 L
Mistroke
.804 .13909 L
.808 .13248 L
.812 .13028 L
.816 .13292 L
.82 .14057 L
.824 .1531 L
.828 .17005 L
.832 .19065 L
.836 .2139 L
.84 .23857 L
.844 .26336 L
.848 .28701 L
.852 .30838 L
.856 .3266 L
.86 .34111 L
.864 .3517 L
.868 .35852 L
.872 .36203 L
.876 .36288 L
.88 .36187 L
.884 .35978 L
.888 .35732 L
.892 .35502 L
.896 .35325 L
.9 .35213 L
.904 .35166 L
.908 .3517 L
.912 .35206 L
.916 .35254 L
.92 .35298 L
.924 .3533 L
.928 .35346 L
.932 .35347 L
.936 .3534 L
.94 .35328 L
.944 .35318 L
.948 .35311 L
.952 .35308 L
.956 .3531 L
.96 .35312 L
.964 .35315 L
.968 .35317 L
.972 .35318 L
.976 .35318 L
.98 .35317 L
.984 .35316 L
.988 .35316 L
.992 .35315 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23177 L
.032 .23178 L
.036 .23178 L
.04 .23177 L
.044 .23175 L
.048 .23173 L
.052 .23171 L
.056 .2317 L
.06 .23172 L
.064 .23178 L
.068 .23186 L
.072 .23196 L
.076 .23203 L
.08 .23201 L
.084 .23188 L
.088 .23161 L
.092 .23124 L
.096 .23084 L
.1 .23054 L
.104 .23051 L
.108 .2309 L
.112 .23183 L
.116 .23333 L
.12 .23525 L
.124 .23732 L
.128 .23907 L
.132 .23992 L
.136 .2392 L
.14 .23626 L
.144 .23053 L
.148 .22164 L
.152 .20947 L
.156 .19417 L
.16 .17623 L
.164 .15638 L
.168 .13557 L
.172 .11487 L
.176 .09536 L
.18 .07806 L
.184 .06383 L
.188 .05332 L
.192 .0469 L
.196 .04469 L
.2 .04654 L
Mistroke
.204 .05209 L
.208 .06082 L
.212 .07209 L
.216 .08521 L
.22 .09948 L
.224 .11428 L
.228 .12902 L
.232 .14326 L
.236 .15661 L
.24 .16884 L
.244 .1798 L
.248 .18941 L
.252 .19769 L
.256 .2047 L
.26 .21053 L
.264 .2153 L
.268 .21915 L
.272 .22222 L
.276 .22462 L
.28 .22648 L
.284 .22791 L
.288 .22898 L
.292 .22978 L
.296 .23037 L
.3 .2308 L
.304 .2311 L
.308 .23132 L
.312 .23148 L
.316 .23159 L
.32 .23166 L
.324 .23171 L
.328 .23175 L
.332 .23177 L
.336 .23179 L
.34 .2318 L
.344 .2318 L
.348 .23181 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23181 L
.648 .23182 L
.652 .23182 L
.656 .23182 L
.66 .23182 L
.664 .23183 L
.668 .23183 L
.672 .23184 L
.676 .23186 L
.68 .23188 L
.684 .23191 L
.688 .23197 L
.692 .23204 L
.696 .23215 L
.7 .2323 L
.704 .23252 L
.708 .23283 L
.712 .23326 L
.716 .23385 L
.72 .23465 L
.724 .23572 L
.728 .23714 L
.732 .239 L
.736 .24141 L
.74 .24447 L
.744 .24833 L
.748 .2531 L
.752 .25893 L
.756 .26594 L
.76 .27422 L
.764 .28383 L
.768 .29478 L
.772 .30701 L
.776 .32037 L
.78 .3346 L
.784 .34935 L
.788 .36414 L
.792 .37842 L
.796 .39153 L
.8 .4028 L
Mistroke
.804 .41153 L
.808 .41708 L
.812 .41893 L
.816 .41672 L
.82 .4103 L
.824 .39979 L
.828 .38557 L
.832 .36827 L
.836 .34876 L
.84 .32805 L
.844 .30724 L
.848 .28739 L
.852 .26945 L
.856 .25416 L
.86 .24198 L
.864 .23309 L
.868 .22736 L
.872 .22443 L
.876 .22371 L
.88 .22456 L
.884 .22631 L
.888 .22838 L
.892 .2303 L
.896 .23179 L
.9 .23273 L
.904 .23312 L
.908 .23309 L
.912 .23279 L
.916 .23239 L
.92 .23201 L
.924 .23175 L
.928 .23162 L
.932 .2316 L
.936 .23167 L
.94 .23176 L
.944 .23185 L
.948 .23191 L
.952 .23193 L
.956 .23192 L
.96 .2319 L
.964 .23187 L
.968 .23186 L
.972 .23185 L
.976 .23185 L
.98 .23186 L
.984 .23186 L
.988 .23187 L
.992 .23187 L
.996 .23187 L
1 .23187 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol40002Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Ao
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol037oo1@000Woo0P0000=oo`00Ool027oo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo
0P002Goo0`000goo0P003Goo00@007ooOol000=oo`800003Ool007oo00Moo`8000Aoo`04001oogoo
0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol0
00Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@0
07ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo
0P003goo00<007ooOol01Goo00<007ooOol0FGoo000LOol00`00Oomoo`0=Ool00`00Oomoo`07Ool2
001IOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`80009oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool50003Ool02@00Oomo
ogoo001oo`00Ool00003Ool01@00Oomoogoo000017oo00<007ooOol02Woo000LOol2001=Ool20007
Ool00`00Oomoo`0JOol001aoo`03001oogoo04eoo`03001oogoo00Aoo`03001oogoo01]oo`0077oo
0P00Cgoo00<007ooOol00goo00<007ooOol06goo000LOol00`00Oomoo`1?Ool01@00Oomoogoo0000
7Woo000;Ool20004Ool01000Oomoogoo1@000Woo0P00D7oo0P0000=oo`0000007Woo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`03001oogoo055oo`8001moo`002Woo00@007ooOol000Uoo`03
001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0
001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomo
o`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool0
1000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000L
Ool00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<0
07ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo
00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001o
ogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P00
2Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007oo
Ool00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`00
5goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
2goo0P0017oo00<007ooOol00Woo0`00N7oo000:Ool01000Oomoo`001goo00D007ooOomoo`0007Mo
o`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo
0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002goo0P002Goo
0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<0
07ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo079oo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool40003Ool2001cOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool2001cOol000]oo`8000Yoo`80
00=oo`03001oogoo079oo`0077oo0P004Woo0P00?Woo0P007goo000LOol00`00Oomoo`0AOol2000m
Ool00`00Ool0000OOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`80015oo`04001oogoo000l
Ool00`00Ool0000OOol000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo00@007ooOol003]o
o`04001oogoo000OOol000=oo`D0009oo`04001oogoo0007Ool50002Ool00`00Oomoo`0@Ool01000
Oomoo`00>goo00D007ooOomoo`0001ioo`002Woo00@007ooOol000Moo`04001oogoo0003Ool2000A
Ool01@00Oomoogoo0000>Woo00D007ooOomoo`0001ioo`002Woo00@007ooOol000Qoo`03001oo`00
00=oo`03001oogoo00moo`03001oogoo009oo`03001oogoo03Qoo`05001oogooOol0000NOol000Yo
o`04001oogoo0009Ool20003Ool2000@Ool00`00Oomoo`02Ool00`00Oomoo`0hOol01@00Oomoogoo
00007Woo000;Ool2000;Ool01@00Oomoogoo00004Goo00<007ooOol00Woo00<007ooOol0=goo00<0
07ooOol00goo00<007ooOol06goo000LOol2000@Ool00`00Oomoo`02Ool00`00Oomoo`0gOol00`00
Oomoo`03Ool00`00Oomoo`0KOol001aoo`03001oogoo00moo`03001oogoo00=oo`03001oogoo03Io
o`03001oogoo00=oo`03001oogoo01]oo`002goo0P0017oo00@007ooOomoo`D0009oo`80011oo`03
001oogoo00=oo`03001oogoo03Ioo`03001oogoo00=oo`03001oogoo01]oo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`0eOol00`00Oomo
o`04Ool00`00Oomoo`0KOol000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomo
o`0>Ool00`00Oomoo`04Ool00`00Oomoo`0eOol00`00Oomoo`04Ool00`00Oomoo`0KOol000Yoo`04
001oogoo000:Ool01000Oomoogoo0P003Woo0`0017oo0`0027oo0`0017oo0P0017oo0P001Goo0`00
0goo0`0017oo0P001Goo1@0000=oo`00Ool00P000goo0`001Goo1@000Woo0`0017oo0P001Woo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`05001oo`00Ool00002Ool0
1000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`03001oogoo00=oo`05001oogoo001oo`020002Ool01000Oomoo`00
0Woo00<007ooOol00goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8000moo`03001oo`00009oo`04001oogoo0009
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`04Ool01000Oomoogoo0P000Woo00<007ooOol00P0000=oo`00Ool01Goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Goo0`000goo00<007ooOol0
3Woo00<007oo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oo`00Ool00002Ool0
0`00Oomoo`0200000goo001oo`06Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo
000LOol2000=Ool40003Ool00`00Oomoo`020008Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00@007ooOomoo`800005Ool007oo
Ool00002Ool200000goo001oo`03Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001ao
o`03001oogoo00aoo`8000Eoo`03001oogoo008000Moo`8000Aoo`04001oogoo0002Ool01000Oomo
o`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomo
o`000Woo0P0000=oo`00Ool00goo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol0
0`00Oomoo`0<Ool50003Ool20002Ool00`00Oomoo`05Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo10000goo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2000>Ool00`00Oomoo`09Ool00`00Oomoo`0^Ool00`00Oomoo`09Ool00`00Oomoo`0IOol001ao
o`03001oogoo00eoo`03001oogoo00Uoo`<002aoo`8000aoo`03001oogoo01Uoo`0077ooJ@0037oo
000LOol00`00Oomoo`0:Ool20006Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol0
0`00Oomoo`04Ool3000;Ool00`00Oomoo`0:Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000;Ool20004Ool01000Oomo
ogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo079oo`00
2Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`D0
009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomo
o`1bOol000]oo`8000]oo`05001oogooOol0001dOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
4Goo0P00Ggoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000BOol2001OOol000Yoo`04001o
ogoo000:Ool01@00Oomoogoo00004Woo00@007ooOol005ioo`000goo1@000Woo00@007ooOol000Mo
o`D0009oo`80015oo`04001oogoo001NOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<0
07ooOol047oo00D007ooOomoo`0005eoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`80011o
o`03001oogoo009oo`03001oogoo05]oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo00mo
o`03001oogoo009oo`03001oogoo05]oo`002goo0P002goo00@007ooOomoo`80011oo`03001oogoo
009oo`03001oogoo05]oo`0077oo00<007ooOol03goo00<007ooOol00Woo00<007ooOol0Fgoo000;
Ool20004Ool01000Oomoogoo1@000Woo0P0047oo00<007ooOol00goo00<007ooOol0FWoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Ao
o`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Io
o`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`8000eoo`03001oogoo0080009oo`04
001oo`000009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol0
0003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`002Woo00D007ooOomoo`00011oo`03001oo`00009oo`04001oogoo0009Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P003goo
00<007oo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`00
2Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@0
07ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogoo
Ool007oo10000goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P003Goo00<007oo000017oo
00<007ooOol00P001goo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomo
o`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool20000
0goo001oo`07Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`00
17oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000>Ool00`00Oomoo`08Ool00`00
Oomoo`1GOol001aoo`03001oogoo00eoo`03001oogoo00Uoo`03001oogoo05Ioo`0077ooJ@0037oo
000LOol01@00Oomoogoo00000goo00@007ooOomoo`@00003Ool007oo009oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`@0009oo`05001oogooOol00003Ool00`00
Oomoo`02000017oo000000000goo00<007ooOol00Woo00<007ooOol02Woo000LOol2001;Ool00`00
Oomoo`09Ool00`00Oomoo`0IOol001aoo`03001oogoo04]oo`03001oogoo00Qoo`03001oogoo01Uo
o`0077oo0P00C7oo00<007ooOol01goo00<007ooOol06Woo000LOol00`00Oomoo`1<Ool00`00Oomo
o`06Ool00`00Oomoo`0JOol000]oo`8000Aoo`04001oogooOol50002Ool2001=Ool00`00Oomoo`06
Ool00`00Oomoo`0JOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0CGoo00<0
07ooOol01Goo00<007ooOol06Woo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00CWoo00<0
07ooOol017oo00<007ooOol06goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0004moo`03001o
ogoo00Aoo`03001oogoo01]oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001>Ool0
0`00Oomoo`04Ool00`00Oomoo`0KOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0CWoo00<007ooOol00goo00<007ooOol06goo000;Ool20009Ool30003Ool2001?Ool00`00
Oomoo`03Ool00`00Oomoo`0KOol001aoo`03001oogoo04ioo`03001oogoo00=oo`03001oogoo01]o
o`002goo0P0017oo00<007ooOol00goo0`000Woo0P00D7oo00<007ooOol00Woo00<007ooOol06goo
000:Ool01000Oomoo`002Woo00D007ooOomoo`00055oo`05001oogooOol0000NOol000Yoo`04001o
ogoo0007Ool50002Ool2001@Ool01@00Oomoogoo00007Woo000:Ool01000Oomoo`001goo00@007oo
Ool000=oo`03001oogoo04moo`05001oogooOol0000NOol000Yoo`04001oogoo0008Ool00`00Ool0
0003Ool2001AOol00`00Ool0000OOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1@Ool0
0`00Ool0000OOol000]oo`8000]oo`04001oogooOol2001BOol2000OOol001aoo`03001oogoo079o
o`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001c
Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00
Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]o
o`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool3
0003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001c
Ool001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomo
o`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1g
Ool001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2320\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23178 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23178 L
.044 .23178 L
.048 .23178 L
.052 .23178 L
.056 .23177 L
.06 .23176 L
.064 .23175 L
.068 .23175 L
.072 .23176 L
.076 .23178 L
.08 .23181 L
.084 .23185 L
.088 .23187 L
.092 .23186 L
.096 .23181 L
.1 .23171 L
.104 .23158 L
.108 .23143 L
.112 .23133 L
.116 .23132 L
.12 .23147 L
.124 .23181 L
.128 .23234 L
.132 .23302 L
.136 .23374 L
.14 .23434 L
.144 .23463 L
.148 .23438 L
.152 .23336 L
.156 .23141 L
.16 .22838 L
.164 .22426 L
.168 .2191 L
.172 .21308 L
.176 .20643 L
.18 .19948 L
.184 .19259 L
.188 .18611 L
.192 .18039 L
.196 .1757 L
.2 .17225 L
Mistroke
.204 .17017 L
.208 .16949 L
.212 .17014 L
.216 .17203 L
.22 .17495 L
.224 .17872 L
.228 .18308 L
.232 .18783 L
.236 .19275 L
.24 .19764 L
.244 .20236 L
.248 .20679 L
.252 .21085 L
.256 .21449 L
.26 .21768 L
.264 .22043 L
.268 .22276 L
.272 .2247 L
.276 .22629 L
.28 .22757 L
.284 .22859 L
.288 .2294 L
.292 .23002 L
.296 .2305 L
.3 .23086 L
.304 .23112 L
.308 .23132 L
.312 .23147 L
.316 .23157 L
.32 .23165 L
.324 .2317 L
.328 .23174 L
.332 .23176 L
.336 .23178 L
.34 .23179 L
.344 .2318 L
.348 .2318 L
.352 .23181 L
.356 .23181 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23181 L
.64 .23181 L
.644 .23182 L
.648 .23182 L
.652 .23182 L
.656 .23182 L
.66 .23182 L
.664 .23183 L
.668 .23184 L
.672 .23185 L
.676 .23187 L
.68 .23189 L
.684 .23193 L
.688 .23198 L
.692 .23206 L
.696 .23216 L
.7 .23231 L
.704 .2325 L
.708 .23277 L
.712 .23313 L
.716 .23361 L
.72 .23423 L
.724 .23504 L
.728 .23606 L
.732 .23735 L
.736 .23894 L
.74 .24087 L
.744 .2432 L
.748 .24595 L
.752 .24914 L
.756 .25277 L
.76 .25682 L
.764 .26125 L
.768 .26597 L
.772 .27086 L
.776 .27576 L
.78 .28051 L
.784 .28487 L
.788 .28863 L
.792 .29156 L
.796 .29344 L
.8 .2941 L
Mistroke
.804 .29342 L
.808 .29135 L
.812 .28791 L
.816 .28323 L
.82 .27751 L
.824 .27104 L
.828 .26415 L
.832 .25719 L
.836 .25054 L
.84 .2445 L
.844 .23933 L
.848 .2352 L
.852 .23217 L
.856 .2302 L
.86 .22918 L
.864 .22893 L
.868 .22922 L
.872 .22983 L
.876 .23055 L
.88 .23123 L
.884 .23177 L
.888 .23211 L
.892 .23226 L
.896 .23226 L
.9 .23216 L
.904 .23201 L
.908 .23187 L
.912 .23177 L
.916 .23172 L
.92 .23171 L
.924 .23173 L
.928 .23177 L
.932 .2318 L
.936 .23182 L
.94 .23183 L
.944 .23183 L
.948 .23182 L
.952 .23181 L
.956 .2318 L
.96 .2318 L
.964 .2318 L
.968 .2318 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35317 L
.044 .35318 L
.048 .35318 L
.052 .35317 L
.056 .35315 L
.06 .35312 L
.064 .35309 L
.068 .35308 L
.072 .35311 L
.076 .35319 L
.08 .3533 L
.084 .35342 L
.088 .3535 L
.092 .35348 L
.096 .3533 L
.1 .35295 L
.104 .35247 L
.108 .35197 L
.112 .3516 L
.116 .35158 L
.12 .35209 L
.124 .35329 L
.128 .35516 L
.132 .35755 L
.136 .36011 L
.14 .36225 L
.144 .36328 L
.148 .36239 L
.152 .35879 L
.156 .35182 L
.16 .34106 L
.164 .32636 L
.168 .30796 L
.172 .28645 L
.176 .2627 L
.18 .23787 L
.184 .21322 L
.188 .19006 L
.192 .16957 L
.196 .15278 L
.2 .14042 L
Mistroke
.204 .13294 L
.208 .13045 L
.212 .13277 L
.216 .13947 L
.22 .14992 L
.224 .16336 L
.228 .17897 L
.232 .19593 L
.236 .2135 L
.24 .231 L
.244 .24789 L
.248 .26373 L
.252 .27824 L
.256 .29124 L
.26 .30265 L
.264 .31248 L
.268 .32081 L
.272 .32774 L
.276 .33342 L
.28 .33801 L
.284 .34167 L
.288 .34454 L
.292 .34676 L
.296 .34846 L
.3 .34975 L
.304 .35071 L
.308 .35141 L
.312 .35193 L
.316 .3523 L
.32 .35257 L
.324 .35276 L
.328 .35289 L
.332 .35298 L
.336 .35304 L
.34 .35308 L
.344 .35311 L
.348 .35313 L
.352 .35314 L
.356 .35315 L
.36 .35315 L
.364 .35316 L
.368 .35316 L
.372 .35316 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35316 L
.64 .35316 L
.644 .35316 L
.648 .35315 L
.652 .35315 L
.656 .35314 L
.66 .35313 L
.664 .35311 L
.668 .35308 L
.672 .35304 L
.676 .35298 L
.68 .35289 L
.684 .35276 L
.688 .35257 L
.692 .3523 L
.696 .35193 L
.7 .35141 L
.704 .35071 L
.708 .34975 L
.712 .34846 L
.716 .34676 L
.72 .34454 L
.724 .34167 L
.728 .33801 L
.732 .33343 L
.736 .32774 L
.74 .32081 L
.744 .31249 L
.748 .30265 L
.752 .29124 L
.756 .27824 L
.76 .26373 L
.764 .24789 L
.768 .231 L
.772 .2135 L
.776 .19594 L
.78 .17897 L
.784 .16336 L
.788 .14992 L
.792 .13948 L
.796 .13278 L
.8 .13046 L
Mistroke
.804 .13295 L
.808 .14043 L
.812 .15278 L
.816 .16958 L
.82 .19006 L
.824 .21323 L
.828 .23787 L
.832 .2627 L
.836 .28645 L
.84 .30797 L
.844 .32636 L
.848 .34106 L
.852 .35182 L
.856 .35879 L
.86 .36239 L
.864 .36328 L
.868 .36225 L
.872 .36011 L
.876 .35755 L
.88 .35516 L
.884 .35329 L
.888 .35209 L
.892 .35158 L
.896 .3516 L
.9 .35197 L
.904 .35247 L
.908 .35295 L
.912 .3533 L
.916 .35348 L
.92 .3535 L
.924 .35342 L
.928 .3533 L
.932 .35319 L
.936 .35311 L
.94 .35308 L
.944 .35309 L
.948 .35312 L
.952 .35315 L
.956 .35317 L
.96 .35318 L
.964 .35318 L
.968 .35317 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23177 L
.044 .23178 L
.048 .23178 L
.052 .23177 L
.056 .23175 L
.06 .23172 L
.064 .2317 L
.068 .23169 L
.072 .23172 L
.076 .23178 L
.08 .23188 L
.084 .23198 L
.088 .23205 L
.092 .23203 L
.096 .23188 L
.1 .23158 L
.104 .23118 L
.108 .23076 L
.112 .23045 L
.116 .23043 L
.12 .23087 L
.124 .23187 L
.128 .23344 L
.132 .23545 L
.136 .23759 L
.14 .2394 L
.144 .24026 L
.148 .23951 L
.152 .23649 L
.156 .23064 L
.16 .2216 L
.164 .20927 L
.168 .19382 L
.172 .17576 L
.176 .15583 L
.18 .13499 L
.184 .1143 L
.188 .09486 L
.192 .07767 L
.196 .06357 L
.2 .0532 L
Mistroke
.204 .04692 L
.208 .04484 L
.212 .04679 L
.216 .05242 L
.22 .06119 L
.224 .07247 L
.228 .08557 L
.232 .09982 L
.236 .11457 L
.24 .12926 L
.244 .14344 L
.248 .15674 L
.252 .16892 L
.256 .17983 L
.26 .18941 L
.264 .19767 L
.268 .20465 L
.272 .21047 L
.276 .21524 L
.28 .2191 L
.284 .22216 L
.288 .22457 L
.292 .22644 L
.296 .22787 L
.3 .22895 L
.304 .22975 L
.308 .23035 L
.312 .23078 L
.316 .23109 L
.32 .23131 L
.324 .23147 L
.328 .23158 L
.332 .23166 L
.336 .23171 L
.34 .23175 L
.344 .23177 L
.348 .23178 L
.352 .2318 L
.356 .2318 L
.36 .23181 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23181 L
.636 .23182 L
.64 .23182 L
.644 .23182 L
.648 .23182 L
.652 .23183 L
.656 .23183 L
.66 .23184 L
.664 .23186 L
.668 .23188 L
.672 .23192 L
.676 .23197 L
.68 .23205 L
.684 .23216 L
.688 .23231 L
.692 .23254 L
.696 .23285 L
.7 .23328 L
.704 .23388 L
.708 .23468 L
.712 .23576 L
.716 .23719 L
.72 .23905 L
.724 .24146 L
.728 .24453 L
.732 .24838 L
.736 .25315 L
.74 .25897 L
.744 .26596 L
.748 .27421 L
.752 .28379 L
.756 .29471 L
.76 .30689 L
.764 .32019 L
.768 .33436 L
.772 .34906 L
.776 .3638 L
.78 .37805 L
.784 .39115 L
.788 .40244 L
.792 .41121 L
.796 .41683 L
.8 .41879 L
Mistroke
.804 .4167 L
.808 .41042 L
.812 .40005 L
.816 .38596 L
.82 .36877 L
.824 .34932 L
.828 .32864 L
.832 .30779 L
.836 .28787 L
.84 .2698 L
.844 .25436 L
.848 .24203 L
.852 .23299 L
.856 .22714 L
.86 .22412 L
.864 .22337 L
.868 .22423 L
.872 .22604 L
.876 .22818 L
.88 .23019 L
.884 .23176 L
.888 .23276 L
.892 .2332 L
.896 .23318 L
.9 .23287 L
.904 .23244 L
.908 .23204 L
.912 .23175 L
.916 .2316 L
.92 .23158 L
.924 .23164 L
.928 .23175 L
.932 .23184 L
.936 .23191 L
.94 .23194 L
.944 .23193 L
.948 .2319 L
.952 .23188 L
.956 .23186 L
.96 .23185 L
.964 .23185 L
.968 .23185 L
.972 .23186 L
.976 .23187 L
.98 .23187 L
.984 .23187 L
.988 .23187 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol500000goo001oo`08Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol037oo100000=oo`00Ool010002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Goo
0`000goo0P003Goo00@007ooOomoo`800003Ool007oo008000Qoo`8000Aoo`04001oogoo0002Ool0
1000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`00
77oo00<007ooOol037oo1@000goo0`002Goo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomo
o`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P0047oo
00<007ooOol01Goo0P00FGoo000LOol00`00Oomoo`0>Ool20008Ool2001HOol001aoofT000aoo`00
77oo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oo`00008000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`<00003Ool007oo009oo`04001oogooOol2
0002Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol2001<Ool00`00
Oomoo`06Ool00`00Oomoo`0KOol001aoo`03001oogoo04aoo`03001oogoo00Aoo`03001oogoo01ao
o`0077oo0P00CWoo00<007ooOol00Woo0P007Woo000LOol00`00Oomoo`1=Ool20003Ool00`00Oomo
o`0MOol000]oo`8000Aoo`04001oogooOol50002Ool2001?Ool200000goo0000000OOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0Cgoo0P008Goo000:Ool01000Oomoo`002Goo
00<007ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`00
2goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomo
o`0007Aoo`002Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001o
ogoo0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yo
o`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol0
01aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool0
0`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004
Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@0
07ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool2
0009Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00
Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo
000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
000;Ool20004Ool00`00Oomoo`02Ool3001hOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
Mgoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007oo
Ool000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000;Ool20009
Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool0
0`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`@000=oo`8007=oo`002Woo00@007ooOol000Moo`03001oogoo00Ao
o`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`8007=oo`002goo0P002Woo
0P000goo00<007ooOol0LWoo000LOol2000COol2000kOol2000QOol001aoo`03001oogoo019oo`03
001oo`0003Yoo`03001oo`00021oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P004Woo00@0
07ooOol003Yoo`03001oo`00021oo`002Woo00@007ooOol000Yoo`05001oogooOol0000COol01000
Oomoo`00>Goo00@007ooOol0021oo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo
015oo`04001oogoo000iOol01@00Oomoogoo00007goo000:Ool01000Oomoo`001goo00@007ooOol0
00=oo`80019oo`05001oogooOol0000hOol01@00Oomoogoo00007goo000:Ool01000Oomoo`0027oo
00<007oo00000goo00<007ooOol04Goo00D007ooOomoo`0003Qoo`05001oogooOol0000OOol000Yo
o`04001oogoo0009Ool20003Ool2000BOol01@00Oomoogoo0000=goo00<007ooOol00Woo00<007oo
Ool07Goo000;Ool2000;Ool01@00Oomoogoo00004Woo00<007ooOol00goo00<007ooOol0=7oo00<0
07ooOol00Woo00<007ooOol07Goo000LOol2000AOol00`00Oomoo`03Ool00`00Oomoo`0dOol00`00
Oomoo`02Ool00`00Oomoo`0MOol001aoo`03001oogoo011oo`03001oogoo00=oo`03001oogoo03Ao
o`03001oogoo00=oo`03001oogoo01aoo`002goo0P0017oo00@007ooOomoo`D0009oo`80015oo`03
001oogoo00=oo`03001oogoo03Aoo`03001oogoo00=oo`03001oogoo01aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool00`00Oomoo`0cOol00`00Oomo
o`04Ool00`00Oomoo`0LOol000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomo
o`0?Ool00`00Oomoo`04Ool00`00Oomoo`0cOol00`00Oomoo`04Ool00`00Oomoo`0LOol000Yoo`04
001oogoo000:Ool01000Oomoogoo0P003Woo0`0017oo0P0000=oo`00Ool01Woo0`0017oo0P0017oo
0P001Goo0`000goo0`0017oo0P001Goo1P000Woo0P000Woo00@007oo000000Eoo`D0009oo`<000Ao
o`8000Ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool00`00Oomo
o`020002Ool00`00Oomoo`020008Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`05001o
ogoo001oo`020002Ool00`00Oomoo`03Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P0047oo0P000Woo00<007oo
Ool00P0027oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol017oo00<007oo00000Woo00@007ooOol0009oo`04001oogoo0006
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool20009Ool30003Ool00`00
Oomoo`0?Ool20002Ool01P00Oomoo`00Ool000Moo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`80009oo`04001oogoo
0002Ool01000Oomoo`001goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo
0P003Goo10000goo00H007ooOol007oo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00
Oomoo`0<Ool01000Oomoo`000goo00@007ooOol0009oo`03001oogoo00=oo`8000Aoo`04001oogoo
0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`03001oogoo0080
009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`00
1Goo000LOol00`00Oomoo`0<Ool50003Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`03Ool20004
Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P000goo0`001Woo0`000Woo1@000goo
0P001Woo000LOol2000?Ool00`00Oomoo`09Ool00`00Oomoo`0[Ool2000:Ool00`00Oomoo`0KOol0
01aoo`03001oogoo00ioo`03001oogoo00Yoo`8002Yoo`8000aoo`03001oogoo01Yoo`0077ooJ@00
37oo000LOol00`00Oomoo`0;Ool30004Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0B
Ool00`00Oomoo`03Ool2000=Ool00`00Oomoo`0:Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000;Ool20004Ool01000
Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo079o
o`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001o
ogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`00
0Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Mo
o`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00
Oomoo`1bOol000]oo`8000]oo`05001oogooOol0001dOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool04Woo0P00GWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000COol00`00Ool0001MOol0
00Yoo`04001oogoo000:Ool01@00Oomoogoo00004goo00@007ooOol005eoo`000goo1@000Woo00@0
07ooOol000Moo`D0009oo`80019oo`04001oogoo001MOol000Yoo`04001oogoo0007Ool01000Oomo
o`000goo00<007ooOol04Goo00D007ooOomoo`0005aoo`002Woo00@007ooOol000Qoo`03001oo`00
00=oo`80019oo`05001oogooOol0001LOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`0A
Ool01@00Oomoogoo0000G7oo000;Ool2000;Ool01000Oomoogoo0P004Goo00<007ooOol00goo00<0
07ooOol0FGoo000LOol00`00Oomoo`0@Ool00`00Oomoo`03Ool00`00Oomoo`1IOol000]oo`8000Ao
o`04001oogooOol50002Ool2000AOol00`00Oomoo`03Ool00`00Oomoo`1IOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00<007ooOol03Goo10000goo0`0027oo0`0017oo0P0017oo0P001Goo
0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool5
0002Ool01000Oomoo`002Goo00<007ooOol00Woo0P003Goo00<007ooOol00P000Woo00@007ooOol0
00Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005
Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:
Ool01@00Oomoogoo00004Goo0P000Woo00<007ooOol00P0027oo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80011oo`80009oo`03001o
ogoo008000Qoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool01P00Oomoo`00Ool000Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=o
o`04001oogoo0005Ool000]oo`8000Uoo`<000=oo`8000eoo`04001oogoo0003Ool01P00Oomoo`00
Ool000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@0
07ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogoo
Ool007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P000goo00<007oo
Ool017oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`80
00Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P003goo00<007ooOol027oo00<007ooOol0
EWoo000LOol00`00Oomoo`0>Ool00`00Oomoo`09Ool2001FOol001aoofT000aoo`0077oo00D007oo
Oomoo`0000=oo`03001oogoo009oo`D000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00@007ooOomoo`H000=oo`05001oogooOol00003Ool20002Ool50003Ool00`00Oomoo`02Ool00`00
Oomoo`0:Ool001aoo`8004Uoo`8000]oo`03001oogoo01Yoo`0077oo00<007ooOol0BGoo0P002Goo
00<007ooOol06goo000LOol2001;Ool00`00Oomoo`07Ool00`00Oomoo`0KOol001aoo`03001oogoo
04]oo`03001oogoo00Ioo`03001oogoo01]oo`002goo0P0017oo00@007ooOomoo`D0009oo`8004ao
o`03001oogoo00Ioo`03001oogoo01]oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00
Oomoo`1;Ool00`00Oomoo`06Ool00`00Oomoo`0KOol000Yoo`04001oogoo0009Ool00`00Oomoo`02
Ool2001=Ool00`00Oomoo`04Ool00`00Oomoo`0LOol000Yoo`04001oogoo000:Ool01@00Oomoogoo
0000CWoo00<007ooOol017oo00<007ooOol077oo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8004eoo`03001oogoo00Aoo`03001oogoo01aoo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1=Ool00`00Oomoo`03Ool00`00Oomoo`0LOol000]oo`8000Uoo`<000=o
o`8004ioo`03001oogoo009oo`03001oogoo01eoo`0077oo00<007ooOol0CGoo00<007ooOol00Woo
00<007ooOol07Goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001>Ool00`00Oomoo`02Ool0
0`00Oomoo`0MOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000Cgoo00<007ooOol00Woo00<0
07ooOol07Goo000:Ool01000Oomoo`001goo1@000Woo0P00Cgoo00D007ooOomoo`0001moo`002Woo
00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1>Ool01@00Oomoogoo00007goo000:Ool0
1000Oomoo`0027oo00<007oo00000goo0P00D7oo00<007oo000087oo000:Ool01000Oomoo`002Goo
0P000goo00<007ooOol0Cgoo00<007oo000087oo000;Ool2000;Ool01000Oomoogoo0P00D7oo0P00
8Goo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol0
0goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yo
o`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo
00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo
07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2360\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23178 L
.052 .23178 L
.056 .23178 L
.06 .23178 L
.064 .23178 L
.068 .23177 L
.072 .23176 L
.076 .23175 L
.08 .23175 L
.084 .23176 L
.088 .23178 L
.092 .23182 L
.096 .23186 L
.1 .23188 L
.104 .23187 L
.108 .23181 L
.112 .2317 L
.116 .23155 L
.12 .23141 L
.124 .2313 L
.128 .2313 L
.132 .23146 L
.136 .23182 L
.14 .23238 L
.144 .23309 L
.148 .23383 L
.152 .23445 L
.156 .23474 L
.16 .23448 L
.164 .23344 L
.168 .23144 L
.172 .22837 L
.176 .22419 L
.18 .21898 L
.184 .21292 L
.188 .20624 L
.192 .19928 L
.196 .1924 L
.2 .18595 L
Mistroke
.204 .18026 L
.208 .17562 L
.212 .17222 L
.216 .17018 L
.22 .16954 L
.224 .17023 L
.228 .17213 L
.232 .17508 L
.236 .17884 L
.24 .18321 L
.244 .18794 L
.248 .19284 L
.252 .19772 L
.256 .20242 L
.26 .20683 L
.264 .21088 L
.268 .2145 L
.272 .21768 L
.276 .22042 L
.28 .22274 L
.284 .22468 L
.288 .22627 L
.292 .22755 L
.296 .22858 L
.3 .22938 L
.304 .23 L
.308 .23048 L
.312 .23085 L
.316 .23112 L
.32 .23132 L
.324 .23146 L
.328 .23157 L
.332 .23164 L
.336 .2317 L
.34 .23173 L
.344 .23176 L
.348 .23178 L
.352 .23179 L
.356 .2318 L
.36 .2318 L
.364 .23181 L
.368 .23181 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23181 L
.628 .23181 L
.632 .23182 L
.636 .23182 L
.64 .23182 L
.644 .23182 L
.648 .23182 L
.652 .23183 L
.656 .23184 L
.66 .23185 L
.664 .23187 L
.668 .23189 L
.672 .23193 L
.676 .23198 L
.68 .23206 L
.684 .23217 L
.688 .23231 L
.692 .23251 L
.696 .23278 L
.7 .23315 L
.704 .23363 L
.708 .23425 L
.712 .23506 L
.716 .23608 L
.72 .23736 L
.724 .23895 L
.728 .24089 L
.732 .24321 L
.736 .24595 L
.74 .24913 L
.744 .25274 L
.748 .25678 L
.752 .26119 L
.756 .26589 L
.76 .27076 L
.764 .27565 L
.768 .28039 L
.772 .28475 L
.776 .28851 L
.78 .29145 L
.784 .29336 L
.788 .29405 L
.792 .29341 L
.796 .29138 L
.8 .28799 L
Mistroke
.804 .28336 L
.808 .27767 L
.812 .27123 L
.816 .26434 L
.82 .25738 L
.824 .2507 L
.828 .24462 L
.832 .2394 L
.836 .23522 L
.84 .23214 L
.844 .23013 L
.848 .22908 L
.852 .22881 L
.856 .22911 L
.86 .22973 L
.864 .23048 L
.868 .23119 L
.872 .23176 L
.876 .23212 L
.88 .23229 L
.884 .23229 L
.888 .23218 L
.892 .23203 L
.896 .23188 L
.9 .23177 L
.904 .23171 L
.908 .2317 L
.912 .23172 L
.916 .23176 L
.92 .2318 L
.924 .23182 L
.928 .23183 L
.932 .23183 L
.936 .23182 L
.94 .23181 L
.944 .23181 L
.948 .2318 L
.952 .2318 L
.956 .2318 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35315 L
.044 .35316 L
.048 .35317 L
.052 .35318 L
.056 .35319 L
.06 .35319 L
.064 .35317 L
.068 .35314 L
.072 .35311 L
.076 .35308 L
.08 .35307 L
.084 .35311 L
.088 .3532 L
.092 .35333 L
.096 .35346 L
.1 .35353 L
.104 .35349 L
.108 .35329 L
.112 .35291 L
.116 .3524 L
.12 .35186 L
.124 .35149 L
.128 .35149 L
.132 .35206 L
.136 .35333 L
.14 .3553 L
.144 .3578 L
.148 .36044 L
.152 .36265 L
.156 .36369 L
.16 .36275 L
.164 .35905 L
.168 .35194 L
.172 .34099 L
.176 .32611 L
.18 .30754 L
.184 .28588 L
.188 .26204 L
.192 .23717 L
.196 .21256 L
.2 .18947 L
Mistroke
.204 .16911 L
.208 .15248 L
.212 .14029 L
.216 .13297 L
.22 .13063 L
.224 .13307 L
.228 .13986 L
.232 .15035 L
.236 .16381 L
.24 .1794 L
.244 .19633 L
.248 .21384 L
.252 .23128 L
.256 .2481 L
.26 .26388 L
.264 .27833 L
.268 .29128 L
.272 .30265 L
.276 .31246 L
.28 .32076 L
.284 .32768 L
.288 .33336 L
.292 .33795 L
.296 .3416 L
.3 .34448 L
.304 .34671 L
.308 .34842 L
.312 .34971 L
.316 .35068 L
.32 .35139 L
.324 .35191 L
.328 .35229 L
.332 .35256 L
.336 .35275 L
.34 .35288 L
.344 .35297 L
.348 .35304 L
.352 .35308 L
.356 .35311 L
.36 .35313 L
.364 .35314 L
.368 .35315 L
.372 .35315 L
.376 .35316 L
.38 .35316 L
.384 .35316 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35316 L
.628 .35316 L
.632 .35316 L
.636 .35315 L
.64 .35315 L
.644 .35314 L
.648 .35313 L
.652 .35311 L
.656 .35308 L
.66 .35304 L
.664 .35297 L
.668 .35288 L
.672 .35275 L
.676 .35256 L
.68 .35229 L
.684 .35191 L
.688 .35139 L
.692 .35068 L
.696 .34971 L
.7 .34842 L
.704 .34671 L
.708 .34448 L
.712 .3416 L
.716 .33795 L
.72 .33336 L
.724 .32768 L
.728 .32076 L
.732 .31246 L
.736 .30265 L
.74 .29128 L
.744 .27833 L
.748 .26388 L
.752 .2481 L
.756 .23128 L
.76 .21385 L
.764 .19633 L
.768 .1794 L
.772 .16381 L
.776 .15036 L
.78 .13986 L
.784 .13308 L
.788 .13063 L
.792 .13298 L
.796 .14029 L
.8 .15248 L
Mistroke
.804 .16912 L
.808 .18947 L
.812 .21256 L
.816 .23718 L
.82 .26204 L
.824 .28588 L
.828 .30754 L
.832 .32611 L
.836 .34099 L
.84 .35194 L
.844 .35905 L
.848 .36275 L
.852 .36369 L
.856 .36265 L
.86 .36044 L
.864 .3578 L
.868 .3553 L
.872 .35333 L
.876 .35206 L
.88 .35149 L
.884 .35149 L
.888 .35186 L
.892 .3524 L
.896 .35291 L
.9 .35329 L
.904 .35349 L
.908 .35353 L
.912 .35346 L
.916 .35333 L
.92 .3532 L
.924 .35311 L
.928 .35307 L
.932 .35308 L
.936 .35311 L
.94 .35314 L
.944 .35317 L
.948 .35319 L
.952 .35319 L
.956 .35318 L
.96 .35317 L
.964 .35316 L
.968 .35315 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23177 L
.052 .23178 L
.056 .23178 L
.06 .23178 L
.064 .23177 L
.068 .23175 L
.072 .23172 L
.076 .23169 L
.08 .23169 L
.084 .23172 L
.088 .23179 L
.092 .2319 L
.096 .23201 L
.1 .23207 L
.104 .23204 L
.108 .23187 L
.112 .23155 L
.116 .23112 L
.12 .23067 L
.124 .23036 L
.128 .23036 L
.132 .23084 L
.136 .2319 L
.14 .23356 L
.144 .23566 L
.148 .23788 L
.152 .23973 L
.156 .2406 L
.16 .23981 L
.164 .23671 L
.168 .23073 L
.172 .22155 L
.176 .20906 L
.18 .19347 L
.184 .17528 L
.188 .15528 L
.192 .1344 L
.196 .11374 L
.2 .09437 L
Mistroke
.204 .07728 L
.208 .06332 L
.212 .05309 L
.216 .04695 L
.22 .04499 L
.224 .04704 L
.228 .05274 L
.232 .06155 L
.236 .07285 L
.24 .08594 L
.244 .10015 L
.248 .11486 L
.252 .1295 L
.256 .14361 L
.26 .15686 L
.264 .169 L
.268 .17987 L
.272 .18941 L
.276 .19764 L
.28 .20461 L
.284 .21042 L
.288 .21519 L
.292 .21904 L
.296 .22211 L
.3 .22452 L
.304 .2264 L
.308 .22783 L
.312 .22892 L
.316 .22973 L
.32 .23033 L
.324 .23076 L
.328 .23108 L
.332 .23131 L
.336 .23146 L
.34 .23158 L
.344 .23165 L
.348 .23171 L
.352 .23174 L
.356 .23177 L
.36 .23178 L
.364 .23179 L
.368 .2318 L
.372 .23181 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23181 L
.624 .23182 L
.628 .23182 L
.632 .23182 L
.636 .23182 L
.64 .23183 L
.644 .23183 L
.648 .23184 L
.652 .23186 L
.656 .23188 L
.66 .23192 L
.664 .23197 L
.668 .23205 L
.672 .23216 L
.676 .23232 L
.68 .23255 L
.684 .23286 L
.688 .2333 L
.692 .2339 L
.696 .23471 L
.7 .2358 L
.704 .23723 L
.708 .2391 L
.712 .24152 L
.716 .24459 L
.72 .24844 L
.724 .2532 L
.728 .25901 L
.732 .26598 L
.736 .27421 L
.74 .28376 L
.744 .29463 L
.748 .30676 L
.752 .32001 L
.756 .33413 L
.76 .34877 L
.764 .36347 L
.768 .37768 L
.772 .39078 L
.776 .40207 L
.78 .41089 L
.784 .41658 L
.788 .41864 L
.792 .41667 L
.796 .41053 L
.8 .40031 L
Mistroke
.804 .38635 L
.808 .36926 L
.812 .34989 L
.816 .32922 L
.82 .30835 L
.824 .28834 L
.828 .27016 L
.832 .25457 L
.836 .24208 L
.84 .23289 L
.844 .22692 L
.848 .22382 L
.852 .22303 L
.856 .2239 L
.86 .22575 L
.864 .22797 L
.868 .23007 L
.872 .23172 L
.876 .23279 L
.88 .23327 L
.884 .23327 L
.888 .23295 L
.892 .23251 L
.896 .23208 L
.9 .23176 L
.904 .23159 L
.908 .23155 L
.912 .23162 L
.916 .23173 L
.92 .23183 L
.924 .23191 L
.928 .23194 L
.932 .23194 L
.936 .23191 L
.94 .23188 L
.944 .23186 L
.948 .23184 L
.952 .23184 L
.956 .23185 L
.96 .23186 L
.964 .23187 L
.968 .23187 L
.972 .23187 L
.976 .23187 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23187 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol00`00Oomoo`040009Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol037oo10000Woo0P000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo
0P002Goo0`000goo0P003Goo00<007ooOol00Woo0`000Woo0P001goo0P0017oo00@007ooOol0009o
o`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo
000LOol00`00Oomoo`0<Ool60002Ool200000goo00000007Ool00`00Oomoo`03Ool20004Ool20006
Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo
000LOol2000AOol20006Ool2001HOol001aoo`03001oogoo00moo`8000Qoo`8005Moo`0077ooJ@00
37oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol00P000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo10000Woo00D007ooOomoo`00009o
o`8000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`8004Yoo`80
00Moo`8001ioo`0077oo00<007ooOol0Bgoo00<007ooOol017oo00<007ooOol07Goo000LOol2001<
Ool20004Ool2000OOol001aoo`03001oogoo04aoo`8000=oo`03001oogoo01ioo`002goo0P0017oo
00@007ooOomoo`D0009oo`8004ioo`@0025oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`1>Ool2000ROol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001cOol000Yoo`04
001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`80
00Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002
Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo
1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo
00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001o
ogoo079oo`002goo0P002goo00@007ooOomoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004
Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@0
07ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80
07=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P00
0goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<0
07ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo
00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00
NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<0
07Qoo`002Woo00@007ooOol000Moo`05001oogooOol0001gOol000=oo`D0009oo`04001oogoo0007
Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2001cOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo10000goo
0P00Lgoo000:Ool01000Oomoo`001goo00<007ooOol017oo00<007ooOol0LWoo000:Ool01000Oomo
o`0027oo00<007ooOol00goo0P00Lgoo000;Ool2000:Ool20003Ool00`00Oomoo`1bOol001aoo`80
01Eoo`03001oogoo03Moo`80029oo`0077oo00<007ooOol04goo00<007oo0000>7oo0P008Woo000;
Ool20004Ool00`00Oomoo`03Ool30002Ool2000DOol00`00Ool0000gOol01000Oomoo`008Goo000:
Ool01000Oomoo`002Woo00D007ooOomoo`0001Eoo`04001oogoo000fOol01000Oomoo`008Goo0003
Ool50002Ool01000Oomoo`001goo1@000Woo00<007ooOol04Woo00D007ooOomoo`0003Ioo`04001o
ogoo000QOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P004goo00D007ooOomoo`0003Io
o`04001oogoo000QOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`0BOol01@00
Oomoogoo0000=Woo00D007ooOomoo`00021oo`002Woo00@007ooOol000Uoo`8000=oo`8001=oo`05
001oogooOol0000eOol00`00Oomoo`02Ool00`00Oomoo`0NOol000]oo`8000]oo`05001oogooOol0
000COol00`00Oomoo`02Ool00`00Oomoo`0cOol00`00Oomoo`02Ool00`00Oomoo`0NOol001aoo`80
019oo`03001oogoo00=oo`03001oogoo039oo`03001oogoo009oo`03001oogoo01ioo`0077oo00<0
07ooOol04Goo00<007ooOol00goo00<007ooOol0<Goo00<007ooOol017oo00<007ooOol07Goo000;
Ool20004Ool01000Oomoogoo1@000Woo0P004Woo00<007ooOol00goo00<007ooOol0<Goo00<007oo
Ool017oo00<007ooOol07Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo015o
o`03001oogoo00Aoo`03001oogoo031oo`03001oogoo00Aoo`03001oogoo01eoo`000goo1@000Woo
00@007ooOol000Uoo`03001oogoo009oo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo031o
o`03001oogoo00Aoo`03001oogoo01eoo`002Woo00@007ooOol000Yoo`04001oogooOol2000>Ool3
000017oo001oogoo0P000Woo00<007ooOol017oo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo
0P001Goo1@000goo0P0000Aoo`00Oomoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007oo
Oomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Ool000000Woo00<007ooOol00P00
00Eoo`00Oomoo`0000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00@007ooOol0
00Ioo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00Aoo`8000=oo`03001oogoo00800005Ool007ooOol00006Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool20009Ool30003Ool00`00Oomoo`0@Ool0
1000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool20000
1Goo001oogoo00001goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P00
3Goo1@000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Ool007oo00000Woo00D0
07ooOol007oo0080009oo`03001oogoo009oo`06001oogooOol007oo10000goo00@007ooOol000Eo
o`0077oo00<007ooOol037oo00D007ooOomoo`00009oo`04001oogoo0003Ool00`00Oomoo`02Ool2
0004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004
Ool01@00Ool007oo00000Woo00D007ooOol007oo0080009oo`03001oogoo009oo`07001oogooOol0
07oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P0017oo0P0017oo00<0
07ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`80009oo`04001o
o`000006Ool30002Ool50003Ool20006Ool001aoo`80011oo`03001oogoo00Uoo`03001oogoo02Uo
o`8000Yoo`03001oogoo01aoo`0077oo00<007ooOol03goo00<007ooOol02Woo0P00:7oo0P0037oo
00<007ooOol06goo000LOomY000<Ool001aoo`03001oogoo00eoo`8000=oo`03001oogoo019oo`03
001oogoo015oo`03001oogoo019oo`04001oogooOol3000>Ool00`00Oomoo`0:Ool001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`03001oogoo079oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo
00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo
0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P00
17oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Ao
o`002Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001o
ogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`05001oogooOol0001dOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol057oo00<007ooOol0Fgoo000;Ool20004Ool00`00Oomoo`03Ool3
0002Ool2000DOol00`00Ool0001LOol000Yoo`04001oogoo000:Ool01@00Oomoogoo00005Goo00<0
07oo0000G7oo0003Ool50002Ool01000Oomoo`001goo1@000Woo0P004goo00D007ooOomoo`0005]o
o`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0BOol01@00Oomoogoo0000Fgoo
000:Ool01000Oomoo`0027oo00<007oo00000goo0P004goo00D007ooOomoo`0005]oo`002Woo00@0
07ooOol000Uoo`8000=oo`03001oogoo019oo`05001oogooOol0001KOol000]oo`8000]oo`04001o
ogooOol2000BOol00`00Oomoo`03Ool00`00Oomoo`1HOol001aoo`03001oogoo015oo`03001oogoo
00=oo`03001oogoo05Qoo`002goo0P0017oo00@007ooOomoo`D0009oo`80019oo`03001oogoo00=o
o`03001oogoo05Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0=Ool30000
17oo001oogoo0P000Woo00<007ooOol017oo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P00
1Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`00
2Goo00<007ooOol00Woo0P003Goo00@007ooOomoo`800007Ool007ooOol007oo00001goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009o
o`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo
001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0000BOol200001goo001oogoo001oo`0000Moo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol200001Goo001oogoo00000Woo
00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo00aoo`D0009oo`04001oogoo0002Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000
Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomo
o`00Ool40003Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool2000=Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo00=oo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo
0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol0
37oo1@000goo0P0017oo00<007ooOol00goo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomo
o`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P0047oo
00<007ooOol027oo0P00EWoo000LOol00`00Oomoo`0?Ool00`00Oomoo`09Ool2001EOol001aoofT0
00aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oo`00008000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00@007ooOomoo`H000=oo`05001oogooOol00003Ool01000
Oomoogoo0P000Woo00D007ooOomoo`0000Aoo`03001oogoo00Yoo`0077oo0P00B7oo0P002goo00<0
07ooOol06goo000LOol00`00Oomoo`18Ool00`00Oomoo`08Ool00`00Oomoo`0LOol001aoo`8004Yo
o`03001oogoo00Moo`03001oogoo01aoo`0077oo00<007ooOol0BGoo00<007ooOol01goo00<007oo
Ool077oo000;Ool20004Ool01000Oomoogoo1@000Woo0P00Bgoo00<007ooOol01Goo00<007ooOol0
7Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo04Yoo`03001oogoo00Eoo`03
001oogoo01eoo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8004aoo`03001oogoo00Aoo`03
001oogoo01eoo`002Woo00@007ooOol000Yoo`05001oogooOol0001=Ool00`00Oomoo`04Ool00`00
Oomoo`0MOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00C7oo00<007ooOol017oo
00<007ooOol07Goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo04]oo`03
001oogoo00Aoo`03001oogoo01eoo`002goo0P002Goo0`000goo0P00C7oo00<007ooOol017oo00<0
07ooOol07Goo000LOol00`00Oomoo`1<Ool00`00Oomoo`02Ool00`00Oomoo`0NOol000]oo`8000Ao
o`03001oogoo00=oo`<0009oo`8004eoo`03001oogoo009oo`03001oogoo01ioo`002Woo00@007oo
Ool000Yoo`05001oogooOol0001>Ool00`00Oomoo`02Ool00`00Oomoo`0NOol000Yoo`04001oogoo
0007Ool50002Ool2001>Ool01000Oomoo`008Goo000:Ool01000Oomoo`001goo00@007ooOol000=o
o`03001oogoo04eoo`04001oogoo000QOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001>
Ool01000Oomoo`008Goo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0CWoo0P008Woo000;
Ool2000;Ool01000Oomoogoo0P00Cgoo0P008Woo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03
001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo
000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2
001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomo
o`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00
Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol0
01Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2400\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23178 L
.064 .23178 L
.068 .23178 L
.072 .23178 L
.076 .23178 L
.08 .23177 L
.084 .23176 L
.088 .23175 L
.092 .23175 L
.096 .23176 L
.1 .23179 L
.104 .23183 L
.108 .23187 L
.112 .23189 L
.116 .23187 L
.12 .23181 L
.124 .23169 L
.128 .23153 L
.132 .23138 L
.136 .23127 L
.14 .23128 L
.144 .23146 L
.148 .23184 L
.152 .23243 L
.156 .23316 L
.16 .23393 L
.164 .23457 L
.168 .23486 L
.172 .23458 L
.176 .23351 L
.18 .23147 L
.184 .22834 L
.188 .22412 L
.192 .21886 L
.196 .21275 L
.2 .20606 L
Mistroke
.204 .19909 L
.208 .19221 L
.212 .18578 L
.216 .18013 L
.22 .17553 L
.224 .17218 L
.228 .17019 L
.232 .16959 L
.236 .17031 L
.24 .17224 L
.244 .1752 L
.248 .17897 L
.252 .18333 L
.256 .18805 L
.26 .19294 L
.264 .19779 L
.268 .20248 L
.272 .20687 L
.276 .2109 L
.28 .21451 L
.284 .21768 L
.288 .22041 L
.292 .22273 L
.296 .22466 L
.3 .22625 L
.304 .22753 L
.308 .22856 L
.312 .22936 L
.316 .22999 L
.32 .23047 L
.324 .23083 L
.328 .23111 L
.332 .23131 L
.336 .23146 L
.34 .23156 L
.344 .23164 L
.348 .23169 L
.352 .23173 L
.356 .23176 L
.36 .23178 L
.364 .23179 L
.368 .2318 L
.372 .2318 L
.376 .23181 L
.38 .23181 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23181 L
.616 .23181 L
.62 .23182 L
.624 .23182 L
.628 .23182 L
.632 .23182 L
.636 .23182 L
.64 .23183 L
.644 .23184 L
.648 .23185 L
.652 .23187 L
.656 .2319 L
.66 .23193 L
.664 .23199 L
.668 .23206 L
.672 .23217 L
.676 .23232 L
.68 .23252 L
.684 .23279 L
.688 .23316 L
.692 .23364 L
.696 .23427 L
.7 .23507 L
.704 .2361 L
.708 .23738 L
.712 .23897 L
.716 .2409 L
.72 .24322 L
.724 .24595 L
.728 .24912 L
.732 .25272 L
.736 .25674 L
.74 .26113 L
.744 .26581 L
.748 .27067 L
.752 .27554 L
.756 .28026 L
.76 .28462 L
.764 .28839 L
.768 .29134 L
.772 .29327 L
.776 .294 L
.78 .2934 L
.784 .29142 L
.788 .28807 L
.792 .28348 L
.796 .27784 L
.8 .27141 L
Mistroke
.804 .26453 L
.808 .25756 L
.812 .25086 L
.816 .24474 L
.82 .23948 L
.824 .23524 L
.828 .23211 L
.832 .23006 L
.836 .22898 L
.84 .2287 L
.844 .22899 L
.848 .22963 L
.852 .23041 L
.856 .23115 L
.86 .23174 L
.864 .23213 L
.868 .23231 L
.872 .23232 L
.876 .23221 L
.88 .23205 L
.884 .2319 L
.888 .23178 L
.892 .23171 L
.896 .23169 L
.9 .23171 L
.904 .23175 L
.908 .23179 L
.912 .23182 L
.916 .23184 L
.92 .23184 L
.924 .23183 L
.928 .23182 L
.932 .23181 L
.936 .2318 L
.94 .2318 L
.944 .2318 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35315 L
.052 .35315 L
.056 .35316 L
.06 .35317 L
.064 .35318 L
.068 .35319 L
.072 .35319 L
.076 .35317 L
.08 .35314 L
.084 .3531 L
.088 .35307 L
.092 .35307 L
.096 .35311 L
.1 .35321 L
.104 .35335 L
.108 .35349 L
.112 .35356 L
.116 .35351 L
.12 .35328 L
.124 .35286 L
.128 .35232 L
.132 .35176 L
.136 .35138 L
.14 .35141 L
.144 .35203 L
.148 .35338 L
.152 .35546 L
.156 .35806 L
.16 .36079 L
.164 .36305 L
.168 .36409 L
.172 .36311 L
.176 .3593 L
.18 .35204 L
.184 .34092 L
.188 .32585 L
.192 .3071 L
.196 .2853 L
.2 .26138 L
Mistroke
.204 .23648 L
.208 .21189 L
.212 .18889 L
.216 .16866 L
.22 .15218 L
.224 .14016 L
.228 .13301 L
.232 .13081 L
.236 .13337 L
.24 .14024 L
.244 .15079 L
.248 .16425 L
.252 .17983 L
.256 .19672 L
.26 .21418 L
.264 .23156 L
.268 .24831 L
.272 .26403 L
.276 .27842 L
.28 .29132 L
.284 .30266 L
.288 .31243 L
.292 .32071 L
.296 .32762 L
.3 .33329 L
.304 .33788 L
.308 .34154 L
.312 .34442 L
.316 .34666 L
.32 .34837 L
.324 .34967 L
.328 .35064 L
.332 .35136 L
.336 .35189 L
.34 .35227 L
.344 .35254 L
.348 .35274 L
.352 .35287 L
.356 .35297 L
.36 .35303 L
.364 .35308 L
.368 .35311 L
.372 .35313 L
.376 .35314 L
.38 .35315 L
.384 .35315 L
.388 .35316 L
.392 .35316 L
.396 .35316 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35316 L
.616 .35316 L
.62 .35316 L
.624 .35315 L
.628 .35315 L
.632 .35314 L
.636 .35313 L
.64 .35311 L
.644 .35308 L
.648 .35303 L
.652 .35297 L
.656 .35287 L
.66 .35274 L
.664 .35254 L
.668 .35227 L
.672 .35189 L
.676 .35136 L
.68 .35064 L
.684 .34967 L
.688 .34837 L
.692 .34666 L
.696 .34442 L
.7 .34154 L
.704 .33788 L
.708 .33329 L
.712 .32762 L
.716 .32071 L
.72 .31243 L
.724 .30266 L
.728 .29132 L
.732 .27842 L
.736 .26403 L
.74 .24831 L
.744 .23156 L
.748 .21419 L
.752 .19673 L
.756 .17983 L
.76 .16426 L
.764 .15079 L
.768 .14025 L
.772 .13338 L
.776 .13082 L
.78 .13301 L
.784 .14017 L
.788 .15219 L
.792 .16867 L
.796 .18889 L
.8 .21189 L
Mistroke
.804 .23648 L
.808 .26138 L
.812 .2853 L
.816 .3071 L
.82 .32585 L
.824 .34092 L
.828 .35204 L
.832 .3593 L
.836 .36311 L
.84 .36409 L
.844 .36305 L
.848 .36079 L
.852 .35806 L
.856 .35546 L
.86 .35338 L
.864 .35203 L
.868 .35141 L
.872 .35138 L
.876 .35176 L
.88 .35232 L
.884 .35286 L
.888 .35328 L
.892 .35351 L
.896 .35356 L
.9 .35349 L
.904 .35335 L
.908 .35321 L
.912 .35311 L
.916 .35307 L
.92 .35307 L
.924 .3531 L
.928 .35314 L
.932 .35317 L
.936 .35319 L
.94 .35319 L
.944 .35318 L
.948 .35317 L
.952 .35316 L
.956 .35315 L
.96 .35315 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35317 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23177 L
.064 .23178 L
.068 .23179 L
.072 .23178 L
.076 .23177 L
.08 .23174 L
.084 .23171 L
.088 .23168 L
.092 .23168 L
.096 .23172 L
.1 .2318 L
.104 .23192 L
.108 .23204 L
.112 .2321 L
.116 .23205 L
.12 .23186 L
.124 .23151 L
.128 .23105 L
.132 .23059 L
.136 .23027 L
.14 .23029 L
.144 .23081 L
.148 .23195 L
.152 .23369 L
.156 .23587 L
.16 .23816 L
.164 .24006 L
.168 .24094 L
.172 .24011 L
.176 .23692 L
.18 .23082 L
.184 .22148 L
.188 .20884 L
.192 .1931 L
.196 .1748 L
.2 .15472 L
Mistroke
.204 .13382 L
.208 .11318 L
.212 .09388 L
.216 .0769 L
.22 .06307 L
.224 .05298 L
.228 .04698 L
.232 .04514 L
.236 .04729 L
.24 .05306 L
.244 .06192 L
.248 .07322 L
.252 .0863 L
.256 .10048 L
.26 .11514 L
.264 .12973 L
.268 .14379 L
.272 .15698 L
.276 .16907 L
.28 .1799 L
.284 .18941 L
.288 .19762 L
.292 .20457 L
.296 .21037 L
.3 .21513 L
.304 .21898 L
.308 .22206 L
.312 .22447 L
.316 .22635 L
.32 .22779 L
.324 .22888 L
.328 .2297 L
.332 .2303 L
.336 .23075 L
.34 .23107 L
.344 .2313 L
.348 .23146 L
.352 .23157 L
.356 .23165 L
.36 .2317 L
.364 .23174 L
.368 .23177 L
.372 .23178 L
.376 .23179 L
.38 .2318 L
.384 .23181 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23181 L
.612 .23182 L
.616 .23182 L
.62 .23182 L
.624 .23182 L
.628 .23183 L
.632 .23183 L
.636 .23184 L
.64 .23186 L
.644 .23189 L
.648 .23192 L
.652 .23198 L
.656 .23206 L
.66 .23217 L
.664 .23233 L
.668 .23256 L
.672 .23288 L
.676 .23332 L
.68 .23393 L
.684 .23474 L
.688 .23583 L
.692 .23727 L
.696 .23915 L
.7 .24157 L
.704 .24464 L
.708 .24849 L
.712 .25326 L
.716 .25905 L
.72 .26601 L
.724 .27421 L
.728 .28373 L
.732 .29456 L
.736 .30664 L
.74 .31984 L
.744 .3339 L
.748 .34848 L
.752 .36314 L
.756 .37732 L
.76 .3904 L
.764 .40171 L
.768 .41056 L
.772 .41633 L
.776 .41848 L
.78 .41664 L
.784 .41064 L
.788 .40056 L
.792 .38672 L
.796 .36975 L
.8 .35044 L
Mistroke
.804 .32981 L
.808 .30891 L
.812 .28883 L
.816 .27053 L
.82 .25479 L
.824 .24214 L
.828 .23281 L
.832 .22671 L
.836 .22352 L
.84 .22269 L
.844 .22356 L
.848 .22546 L
.852 .22775 L
.856 .22994 L
.86 .23168 L
.864 .23282 L
.868 .23334 L
.872 .23336 L
.876 .23304 L
.88 .23257 L
.884 .23211 L
.888 .23177 L
.892 .23157 L
.896 .23153 L
.9 .23159 L
.904 .23171 L
.908 .23182 L
.912 .23191 L
.916 .23195 L
.92 .23195 L
.924 .23192 L
.928 .23189 L
.932 .23186 L
.936 .23184 L
.94 .23184 L
.944 .23185 L
.948 .23186 L
.952 .23187 L
.956 .23187 L
.96 .23187 L
.964 .23187 L
.968 .23187 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23187 L
.996 .23187 L
1 .23187 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol00`00Oomoo`040009Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol037oo10000goo0P0000=oo`00000027oo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomo
o`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P00
2Goo0`000goo0P003Goo00<007ooOol017oo00H007ooOol007oo0006Ool20004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool001aoo`03001oogoo00aoo`D00003Ool007oo008000=oo`03001oogoo00Aoo`03001oogoo00=o
o`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool5
0003Ool20006Ool001aoo`80019oo`8000Ioo`8005Moo`0077oo00<007ooOol04Goo00<007ooOol0
1goo00<007ooOol0E7oo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool0
1000Oomoogoo0P000Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01P00Oomoogoo001o
o`@000=oo`09001oogooOol007oo001oo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool0
0`00Oomoo`0:Ool001aoo`8004Uoo`8000Moo`8001moo`0077oo00<007ooOol0BGoo0P001Woo00<0
07ooOol07Woo000LOol2001;Ool20004Ool00`00Oomoo`0OOol001aoo`03001oogoo04]oo`05001o
ogooOol0000ROol000]oo`8000Aoo`04001oogooOol50002Ool2001=Ool4000ROol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00<007ooOol0CGoo0P008goo000:Ool01000Oomoo`002Goo00<0
07ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`00
07Aoo`002Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo
0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04
001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001ao
o`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00
Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool0
0`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007oo
Ool000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2
001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009
Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomo
o`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000G
Ool00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;
Ool20004Ool00`00Oomoo`02Ool3001hOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000Mgoo
0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol0
00Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000;Ool20009Ool3
0003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00
Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`@000=oo`8007=oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`03
001oogoo079oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`8007=oo`002goo0P002Woo0P00
0goo00<007ooOol0LWoo000LOol2000FOol2000fOol2000SOol001aoo`03001oogoo01Aoo`03001o
o`0003Ioo`8002=oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P005Goo00<007oo0000=Goo
00@007ooOol0029oo`002Woo00@007ooOol000Yoo`05001oogooOol0000FOol01000Oomoo`00=7oo
00@007ooOol0029oo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo01Aoo`04001o
ogoo000dOol01000Oomoo`008Woo000:Ool01000Oomoo`001goo00@007ooOol000=oo`8001Eoo`04
001oogoo000cOol01@00Oomoogoo00008Woo000:Ool01000Oomoo`0027oo00<007oo00000goo00<0
07ooOol04goo00D007ooOomoo`0003=oo`05001oogooOol0000ROol000Yoo`04001oogoo0009Ool2
0003Ool2000DOol00`00Oomoo`02Ool00`00Oomoo`0`Ool01@00Oomoogoo00008Woo000;Ool2000;
Ool01@00Oomoogoo00005Goo00<007ooOol00Woo00<007ooOol0<7oo00<007ooOol00Woo00<007oo
Ool07goo000LOol2000DOol00`00Oomoo`02Ool00`00Oomoo`0`Ool00`00Oomoo`02Ool00`00Oomo
o`0OOol001aoo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo02ioo`03001oogoo00=oo`03
001oogoo01moo`002goo0P0017oo00@007ooOomoo`D0009oo`8001=oo`03001oogoo00Aoo`03001o
ogoo02ioo`03001oogoo00=oo`03001oogoo01moo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`0^Ool00`00Oomoo`03Ool00`00Oomoo`0O
Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`04
Ool00`00Oomoo`0^Ool00`00Oomoo`04Ool00`00Oomoo`0NOol000Yoo`04001oogoo000:Ool01000
Oomoogoo0P003Woo0`000Woo00@007oo000000=oo`03001oogoo00=oo`<000Aoo`8000Aoo`8000Eo
o`<000=oo`<000Aoo`8000Eoo`D000=oo`<000=oo`8000Eoo`D0009oo`<000Aoo`8000Ioo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool01000Oomoogoo0P0000Eoo`00
Oomoo`0000=oo`03001oogoo00=oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool200001Goo001oogoo00000Woo
00@007ooOol0009oo`03001oogoo00=oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol200001Goo001oogoo
00000goo00<007ooOol00goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool20009Ool3
0003Ool00`00Oomoo`0@Ool200001Goo001oogoo00000goo00<007ooOol00goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
0goo00<007oo00000goo00@007ooOol0009oo`04001oogoo0007Ool00`00Oomoo`04Ool01000Oomo
o`000Woo00<007ooOol00goo000LOol2000=Ool4000017oo001oo`000Woo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo1000
0goo00@007ooOol000Aoo`80009oo`04001oogoo0002Ool200001Goo001oogoo000017oo00H007oo
Oomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00
Ool00002Ool00`00Oomoo`02Ool01000Oomoogoo0P0017oo00@007ooOol0009oo`04001oogoo0004
Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo0P000Woo00@007ooOol0009oo`800005Ool0
07ooOol00004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00ao
o`H0009oo`8000Eoo`8000=oo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool2
0005Ool40004Ool2000017oo001oogoo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000BOol0
0`00Oomoo`08Ool2000XOol00`00Oomoo`09Ool00`00Oomoo`0MOol001aoo`03001oogoo011oo`03
001oogoo00Yoo`8002Eoo`<000]oo`03001oogoo01eoo`0077ooJ@0037oo000LOol00`00Oomoo`0>
Ool20002Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`03000?Ool0
0`00Oomoo`0:Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo00<007ooOol0LWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P00Lgoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo079oo`002Woo00@007ooOol000Uoo`03
001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001ao
o`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomo
o`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@0
07ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool0
0003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`05
001oogooOol0001dOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol05Goo0P00Fgoo000;Ool20004
Ool00`00Oomoo`03Ool30002Ool2000EOol00`00Ool0001KOol000Yoo`04001oogoo000:Ool01@00
Oomoogoo00005Woo00<007oo0000Fgoo0003Ool50002Ool01000Oomoo`001goo1@000Woo0P005Goo
00@007ooOol005Yoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0DOol01000
Oomoo`00FWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P0057oo00D007ooOomoo`0005Yo
o`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo01=oo`03001oogoo009oo`03001oogoo05Mo
o`002goo0P002goo00@007ooOomoo`8001Aoo`03001oogoo009oo`03001oogoo05Moo`0077oo00<0
07ooOol04goo00<007ooOol00Woo00<007ooOol0Egoo000;Ool20004Ool01000Oomoogoo1@000Woo
0P004goo00<007ooOol017oo00<007ooOol0EWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`03001oogoo00eoo`<0009oo`04001oo`000003Ool00`00Oomoo`03Ool30004Ool20004Ool20005
Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=o
o`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool2000=Ool01P00Oomoogoo001oo`80009oo`04
001oogoo0006Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol0
0003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`002Woo00D007ooOomoo`00019oo`04001oo`000002Ool01000Oomoo`001Woo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80015o
o`800005Ool007ooOol00003Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo100000Aoo`00
Ool0009oo`05001oogooOol00005Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool0
1000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool20009Ool30003
Ool2000=Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Oomoo`02Ool01000Oomoogoo0P0017oo
00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool0
1000Oomoo`001Goo000LOol00`00Oomoo`0<Ool60002Ool20005Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`00
0Woo1@000goo0P001Woo000LOol2000BOol00`00Oomoo`07Ool2001EOol001aoo`03001oogoo011o
o`03001oogoo00Uoo`8005Aoo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol0
0Woo00<007ooOol00`000Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`05
00000goo001oo`02Ool01@00Oomoogoo00000Woo0P000Woo0P000goo00D007ooOomoo`0000Aoo`03
001oogoo00Yoo`0077oo0P00Agoo00<007ooOol02Goo00<007ooOol07Goo000LOol00`00Oomoo`17
Ool00`00Oomoo`08Ool00`00Oomoo`0MOol001aoo`8004Uoo`03001oogoo00Moo`03001oogoo01eo
o`0077oo00<007ooOol0B7oo00<007ooOol01goo00<007ooOol07Goo000;Ool20004Ool01000Oomo
ogoo1@000Woo0P00BGoo00<007ooOol01Woo00<007ooOol07Woo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`03001oogoo04Uoo`03001oogoo00Eoo`03001oogoo01ioo`002Woo00@007ooOol0
00Uoo`03001oogoo009oo`8004Yoo`03001oogoo00Eoo`03001oogoo01ioo`002Woo00@007ooOol0
00Yoo`05001oogooOol0001;Ool00`00Oomoo`05Ool00`00Oomoo`0NOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo0P00Bgoo00<007ooOol00goo00<007ooOol07goo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo04Yoo`03001oogoo00=oo`03001oogoo01moo`00
2goo0P002Goo0`000goo0P00Bgoo00<007ooOol00goo00<007ooOol07goo000LOol00`00Oomoo`1;
Ool00`00Oomoo`02Ool00`00Oomoo`0OOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8004ao
o`03001oogoo009oo`03001oogoo01moo`002Woo00@007ooOol000Yoo`05001oogooOol0001=Ool0
1@00Oomoogoo00008Woo000:Ool01000Oomoo`001goo1@000Woo0P00C7oo00D007ooOomoo`00029o
o`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1<Ool01000Oomoo`008Woo000:
Ool01000Oomoo`0027oo00<007oo00000goo0P00CGoo00@007ooOol0029oo`002Woo00@007ooOol0
00Uoo`8000=oo`03001oogoo04eoo`8002=oo`002goo0P002goo00@007ooOomoo`8004ioo`8002=o
o`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=o
o`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`80
00Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool0
1000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]o
o`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03
001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1g
Ool001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2440\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23178 L
.076 .23178 L
.08 .23178 L
.084 .23178 L
.088 .23178 L
.092 .23176 L
.096 .23175 L
.1 .23174 L
.104 .23174 L
.108 .23176 L
.112 .23179 L
.116 .23184 L
.12 .23188 L
.124 .2319 L
.128 .23188 L
.132 .2318 L
.136 .23167 L
.14 .23151 L
.144 .23134 L
.148 .23124 L
.152 .23125 L
.156 .23145 L
.16 .23186 L
.164 .23247 L
.168 .23323 L
.172 .23403 L
.176 .23468 L
.18 .23497 L
.184 .23468 L
.188 .23358 L
.192 .23149 L
.196 .22832 L
.2 .22404 L
Mistroke
.204 .21874 L
.208 .21259 L
.212 .20587 L
.216 .1989 L
.22 .19203 L
.224 .18562 L
.228 .18001 L
.232 .17545 L
.236 .17215 L
.24 .1702 L
.244 .16964 L
.248 .1704 L
.252 .17235 L
.256 .17532 L
.26 .17909 L
.264 .18345 L
.268 .18816 L
.272 .19303 L
.276 .19787 L
.28 .20254 L
.284 .20691 L
.288 .21092 L
.292 .21452 L
.296 .21768 L
.3 .2204 L
.304 .22272 L
.308 .22464 L
.312 .22623 L
.316 .22751 L
.32 .22854 L
.324 .22935 L
.328 .22998 L
.332 .23046 L
.336 .23082 L
.34 .2311 L
.344 .2313 L
.348 .23145 L
.352 .23156 L
.356 .23164 L
.36 .23169 L
.364 .23173 L
.368 .23176 L
.372 .23178 L
.376 .23179 L
.38 .2318 L
.384 .2318 L
.388 .23181 L
.392 .23181 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23181 L
.6 .23181 L
Mistroke
.604 .23181 L
.608 .23182 L
.612 .23182 L
.616 .23182 L
.62 .23182 L
.624 .23182 L
.628 .23183 L
.632 .23184 L
.636 .23185 L
.64 .23187 L
.644 .2319 L
.648 .23194 L
.652 .23199 L
.656 .23207 L
.66 .23218 L
.664 .23233 L
.668 .23253 L
.672 .23281 L
.676 .23317 L
.68 .23365 L
.684 .23428 L
.688 .23509 L
.692 .23612 L
.696 .2374 L
.7 .23899 L
.704 .24091 L
.708 .24322 L
.712 .24595 L
.716 .2491 L
.72 .2527 L
.724 .2567 L
.728 .26107 L
.732 .26574 L
.736 .27057 L
.74 .27544 L
.744 .28015 L
.748 .2845 L
.752 .28827 L
.756 .29124 L
.76 .29319 L
.764 .29395 L
.768 .29339 L
.772 .29145 L
.776 .28815 L
.78 .2836 L
.784 .27799 L
.788 .27159 L
.792 .26473 L
.796 .25775 L
.8 .25102 L
Mistroke
.804 .24487 L
.808 .23956 L
.812 .23527 L
.816 .23208 L
.82 .22999 L
.824 .22888 L
.828 .22859 L
.832 .22888 L
.836 .22953 L
.84 .23033 L
.844 .2311 L
.848 .23172 L
.852 .23214 L
.856 .23233 L
.86 .23235 L
.864 .23224 L
.868 .23208 L
.872 .23191 L
.876 .23178 L
.88 .2317 L
.884 .23168 L
.888 .2317 L
.892 .23174 L
.896 .23179 L
.9 .23182 L
.904 .23184 L
.908 .23184 L
.912 .23183 L
.916 .23182 L
.92 .23181 L
.924 .2318 L
.928 .2318 L
.932 .2318 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35317 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35315 L
.064 .35315 L
.068 .35316 L
.072 .35317 L
.076 .35318 L
.08 .35319 L
.084 .35319 L
.088 .35317 L
.092 .35313 L
.096 .35309 L
.1 .35306 L
.104 .35306 L
.108 .35312 L
.112 .35323 L
.116 .35338 L
.12 .35352 L
.124 .35359 L
.128 .35352 L
.132 .35327 L
.136 .35281 L
.14 .35223 L
.144 .35165 L
.148 .35127 L
.152 .35132 L
.156 .352 L
.16 .35344 L
.164 .35562 L
.168 .35833 L
.172 .36114 L
.176 .36346 L
.18 .3645 L
.184 .36346 L
.188 .35955 L
.192 .35214 L
.196 .34083 L
.2 .32558 L
Mistroke
.204 .30666 L
.208 .28472 L
.212 .26071 L
.216 .23579 L
.22 .21123 L
.224 .18832 L
.228 .16822 L
.232 .1519 L
.236 .14004 L
.24 .13305 L
.244 .131 L
.248 .13367 L
.252 .14062 L
.256 .15122 L
.26 .1647 L
.264 .18026 L
.268 .19711 L
.272 .21452 L
.276 .23183 L
.28 .24852 L
.284 .26417 L
.288 .27851 L
.292 .29136 L
.296 .30266 L
.3 .3124 L
.304 .32066 L
.308 .32756 L
.312 .33323 L
.316 .33781 L
.32 .34148 L
.324 .34436 L
.328 .34661 L
.332 .34833 L
.336 .34963 L
.34 .35061 L
.344 .35134 L
.348 .35187 L
.352 .35226 L
.356 .35253 L
.36 .35273 L
.364 .35287 L
.368 .35296 L
.372 .35303 L
.376 .35307 L
.38 .3531 L
.384 .35312 L
.388 .35314 L
.392 .35315 L
.396 .35315 L
.4 .35316 L
Mistroke
.404 .35316 L
.408 .35316 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35316 L
Mistroke
.604 .35316 L
.608 .35316 L
.612 .35315 L
.616 .35315 L
.62 .35314 L
.624 .35312 L
.628 .3531 L
.632 .35307 L
.636 .35303 L
.64 .35296 L
.644 .35287 L
.648 .35273 L
.652 .35253 L
.656 .35226 L
.66 .35187 L
.664 .35134 L
.668 .35061 L
.672 .34963 L
.676 .34833 L
.68 .34661 L
.684 .34436 L
.688 .34148 L
.692 .33781 L
.696 .33323 L
.7 .32756 L
.704 .32067 L
.708 .3124 L
.712 .30266 L
.716 .29136 L
.72 .27851 L
.724 .26417 L
.728 .24852 L
.732 .23183 L
.736 .21452 L
.74 .19712 L
.744 .18026 L
.748 .1647 L
.752 .15122 L
.756 .14063 L
.76 .13368 L
.764 .131 L
.768 .13306 L
.772 .14005 L
.776 .1519 L
.78 .16822 L
.784 .18832 L
.788 .21123 L
.792 .23579 L
.796 .26071 L
.8 .28472 L
Mistroke
.804 .30666 L
.808 .32558 L
.812 .34083 L
.816 .35214 L
.82 .35955 L
.824 .36346 L
.828 .3645 L
.832 .36346 L
.836 .36114 L
.84 .35833 L
.844 .35562 L
.848 .35344 L
.852 .352 L
.856 .35132 L
.86 .35127 L
.864 .35165 L
.868 .35223 L
.872 .35281 L
.876 .35327 L
.88 .35352 L
.884 .35359 L
.888 .35352 L
.892 .35338 L
.896 .35323 L
.9 .35312 L
.904 .35306 L
.908 .35306 L
.912 .35309 L
.916 .35313 L
.92 .35317 L
.924 .35319 L
.928 .35319 L
.932 .35318 L
.936 .35317 L
.94 .35316 L
.944 .35315 L
.948 .35315 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35317 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23177 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23177 L
.076 .23178 L
.08 .23179 L
.084 .23179 L
.088 .23177 L
.092 .23174 L
.096 .2317 L
.1 .23167 L
.104 .23168 L
.108 .23172 L
.112 .23182 L
.116 .23194 L
.12 .23206 L
.124 .23212 L
.128 .23207 L
.132 .23185 L
.136 .23147 L
.14 .23098 L
.144 .2305 L
.148 .23018 L
.152 .23022 L
.156 .23079 L
.16 .232 L
.164 .23383 L
.168 .2361 L
.172 .23846 L
.176 .2404 L
.18 .24128 L
.184 .24041 L
.188 .23712 L
.192 .2309 L
.196 .22141 L
.2 .20861 L
Mistroke
.204 .19273 L
.208 .17431 L
.212 .15416 L
.216 .13324 L
.22 .11263 L
.224 .0934 L
.228 .07653 L
.232 .06283 L
.236 .05288 L
.24 .04702 L
.244 .0453 L
.248 .04755 L
.252 .05338 L
.256 .06228 L
.26 .07359 L
.264 .08666 L
.268 .10081 L
.272 .11542 L
.276 .12996 L
.28 .14396 L
.284 .15711 L
.288 .16914 L
.292 .17993 L
.296 .18942 L
.3 .1976 L
.304 .20453 L
.308 .21032 L
.312 .21508 L
.316 .21893 L
.32 .222 L
.324 .22443 L
.328 .22631 L
.332 .22776 L
.336 .22885 L
.34 .22967 L
.344 .23028 L
.348 .23073 L
.352 .23105 L
.356 .23129 L
.36 .23145 L
.364 .23157 L
.368 .23165 L
.372 .2317 L
.376 .23174 L
.38 .23176 L
.384 .23178 L
.388 .23179 L
.392 .2318 L
.396 .23181 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23182 L
.6 .23182 L
Mistroke
.604 .23182 L
.608 .23182 L
.612 .23182 L
.616 .23183 L
.62 .23183 L
.624 .23185 L
.628 .23186 L
.632 .23189 L
.636 .23193 L
.64 .23198 L
.644 .23206 L
.648 .23218 L
.652 .23234 L
.656 .23257 L
.66 .2329 L
.664 .23334 L
.668 .23395 L
.672 .23478 L
.676 .23587 L
.68 .23732 L
.684 .2392 L
.688 .24162 L
.692 .2447 L
.696 .24855 L
.7 .25331 L
.704 .25909 L
.708 .26603 L
.712 .27421 L
.716 .28369 L
.72 .29448 L
.724 .30652 L
.728 .31966 L
.732 .33367 L
.736 .3482 L
.74 .36281 L
.744 .37696 L
.748 .39003 L
.752 .40135 L
.756 .41024 L
.76 .41608 L
.764 .41833 L
.768 .41661 L
.772 .41074 L
.776 .4008 L
.78 .3871 L
.784 .37023 L
.788 .351 L
.792 .33039 L
.796 .30947 L
.8 .28931 L
Mistroke
.804 .2709 L
.808 .25502 L
.812 .24222 L
.816 .23273 L
.82 .2265 L
.824 .22322 L
.828 .22235 L
.832 .22323 L
.836 .22517 L
.84 .22753 L
.844 .2298 L
.848 .23163 L
.852 .23284 L
.856 .23341 L
.86 .23345 L
.864 .23313 L
.868 .23265 L
.872 .23216 L
.876 .23178 L
.88 .23156 L
.884 .2315 L
.888 .23156 L
.892 .23168 L
.896 .23181 L
.9 .2319 L
.904 .23195 L
.908 .23195 L
.912 .23193 L
.916 .23189 L
.92 .23186 L
.924 .23184 L
.928 .23184 L
.932 .23185 L
.936 .23186 L
.94 .23187 L
.944 .23187 L
.948 .23187 L
.952 .23187 L
.956 .23187 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23187 L
.984 .23187 L
.988 .23187 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01@00Oomoo`00Ool010001goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00aoo`@000=oo`@00003Ool0000000Ioo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]o
o`8000Uoo`<000=oo`8000eoo`03001oogoo00Aoo`800005Ool007ooOol00005Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Aoo`03001oogoo00=oo`03001oogoo00=o
o`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool5
0003Ool20006Ool001aoo`8001Aoo`03001oogoo00Eoo`03001oogoo05Aoo`0077oo00<007ooOol0
4Woo00<007ooOol01goo0P00E7oo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomo
o`02Ool01000Oomoogoo0`0000=oo`00Ool00Woo00D007ooOomoo`0000=oo`05001oogooOol00004
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoogoo
100000=oo`00Ool00Woo00@007ooOomoo`80009oo`05001oogooOol00003Ool01@00Oomoogoo0000
17oo00<007ooOol02Woo000LOol20018Ool20007Ool00`00Oomoo`0OOol001aoo`03001oogoo04Qo
o`03001oogoo00Aoo`03001oogoo021oo`0077oo0P00BWoo00<007ooOol00goo00<007ooOol087oo
000LOol00`00Oomoo`1:Ool01@00Oomoogoo00008goo000;Ool20004Ool01000Oomoogoo1@000Woo
0P00C7oo00@007oo000002=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1<
Ool2000TOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001cOol000Yoo`04001oogoo000:
Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=o
o`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol0
00Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo0P00
Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`00
2goo0P002goo00@007ooOomoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomo
o`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Mo
o`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo
00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo
000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo
000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol0
0Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol0
0`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<007Qoo`002Woo
00@007ooOol000Moo`05001oogooOol0001gOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2001cOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000L
Ool00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo10000goo0P00Lgoo000:
Ool01000Oomoo`001goo00<007ooOol017oo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<0
07ooOol00goo0P00Lgoo000;Ool2000:Ool20003Ool00`00Oomoo`1bOol001aoo`8001Moo`8003Ao
o`8002Aoo`0077oo00<007ooOol05Woo0P00<goo00<007oo000097oo000;Ool20004Ool00`00Oomo
o`03Ool30002Ool2000FOol01000Oomoo`00<Woo00<007oo000097oo000:Ool01000Oomoo`002Woo
00D007ooOomoo`0001Moo`04001oogoo000bOol00`00Ool0000TOol000=oo`D0009oo`04001oogoo
0007Ool50002Ool00`00Oomoo`0EOol01000Oomoo`00<Woo00@007ooOol002=oo`002Woo00@007oo
Ool000Moo`04001oogoo0003Ool2000FOol01@00Oomoogoo0000<7oo00D007ooOomoo`0002=oo`00
2Woo00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo01Aoo`03001oogoo009oo`03001oogoo
02ioo`05001oogooOol0000SOol000Yoo`04001oogoo0009Ool20003Ool2000EOol00`00Oomoo`02
Ool00`00Oomoo`0^Ool01@00Oomoogoo00008goo000;Ool2000;Ool01@00Oomoogoo00005Woo00<0
07ooOol00Woo00<007ooOol0;Woo00<007ooOol00Woo00<007ooOol087oo000LOol2000EOol00`00
Oomoo`02Ool00`00Oomoo`0]Ool00`00Oomoo`03Ool00`00Oomoo`0POol001aoo`03001oogoo01Ao
o`03001oogoo00=oo`03001oogoo02aoo`03001oogoo00=oo`03001oogoo021oo`002goo0P0017oo
00@007ooOomoo`D0009oo`8001Eoo`03001oogoo00=oo`03001oogoo02aoo`03001oogoo00=oo`03
001oogoo021oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0DOol00`00Oomo
o`03Ool00`00Oomoo`0[Ool00`00Oomoo`04Ool00`00Oomoo`0POol000=oo`D0009oo`04001oogoo
0009Ool00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`04Ool00`00Oomoo`0[Ool00`00Oomo
o`04Ool00`00Oomoo`0POol000Yoo`04001oogoo000:Ool01000Oomoogoo0P003Woo0`000goo0`00
1Goo00@007ooOomoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Ao
o`8000Eoo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`0<Ool01@00Oomoogoo00000Woo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool01000Oomoo`000Woo00@007oo0000009oo`04001oogoo0005Ool01P00Oomoo`00
Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P004Goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`8000Aoo`04001oo`000002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00=oo`002goo0P002Goo0`000goo00<007ooOol047oo00@007ooOol0009oo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`04001oogoo0003Ool01000Ool000000Woo
00@007ooOol000Moo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eo
o`@0009oo`80009oo`03001oogoo00=oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oo`00
0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00
Oomoo`0<Ool00`00Oomoo`03Ool20002Ool00`00Oomoo`03Ool00`00Oomoo`020004Ool01000Oomo
o`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0003Ool20003Ool01@00
Oomoo`00Ool00P000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eo
o`0077oo00<007ooOol037oo1@0000=oo`00Ool00P001goo00@007ooOol000Eoo`8000Aoo`8000Io
o`04001oogooOol50003Ool20004Ool00`00Ool000020004Ool30003Ool20006Ool30002Ool50003
Ool20006Ool001aoo`8001=oo`03001oogoo00Qoo`8002Ioo`03001oogoo00Uoo`03001oogoo01io
o`0077oo00<007ooOol04Goo00<007ooOol02Woo0`008Woo0P0037oo00<007ooOol07Woo000LOomY
000<Ool001aoo`03001oogoo00moo`@001Aoo`03001oogoo015oo`03001oogoo019oo`03001oo`00
0080011oo`03001oogoo00Yoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogooOol50002Ool2
001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0LWoo000:Ool01000Oomo
o`002Goo00<007ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yo
o`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo
000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qo
o`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo
0P002goo00D007ooOomoo`0007Aoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`0FOol2001JOol0
00]oo`8000Aoo`03001oogoo00=oo`<0009oo`8001Moo`8005Yoo`002Woo00@007ooOol000Yoo`05
001oogooOol0000GOol01000Oomoo`00FGoo0003Ool50002Ool01000Oomoo`001goo1@000Woo0P00
5Woo00@007ooOol005Uoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0EOol0
1@00Oomoogoo0000F7oo000:Ool01000Oomoo`0027oo00<007oo00000goo0P005Goo00<007ooOol0
0Woo00<007ooOol0EWoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol057oo00<007ooOol0
0Woo00<007ooOol0EWoo000;Ool2000;Ool01000Oomoogoo0P005Goo00<007ooOol00Woo00<007oo
Ool0EWoo000LOol00`00Oomoo`0DOol00`00Oomoo`02Ool00`00Oomoo`1FOol000]oo`8000Aoo`04
001oogooOol50002Ool2000EOol00`00Oomoo`03Ool00`00Oomoo`1EOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00<007ooOol03Goo0`0017oo0P0017oo00<007ooOol00Woo0`0017oo0P00
17oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P00
1Woo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo0P003Goo00D007ooOomoo`00009o
o`04001oogoo0003Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007oo
Ool00goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`04001oogoo0002Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P004Goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`0017oo00<007ooOol00Woo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Ao
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo1000
0goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P003Goo00<007ooOol00goo0P000Woo00<0
07ooOol00goo00<007ooOol00P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00
Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
17oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool500000goo
001oo`020006Ool01@00Oomoogoo00001Goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Io
o`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P004goo00<007ooOol027oo
00<007ooOol0DWoo000LOol00`00Oomoo`0AOol00`00Oomoo`09Ool2000dOol00`00Oomoo`0LOol0
01aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`04001oogooOol50003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`03001oo`0000<000=oo`05001oogooOol00003Ool01000Ool007oo
1@000goo00D007ooOomoo`0000Aoo`03001oogoo00Yoo`0077oo0P00AWoo00<007ooOol02Goo00<0
07ooOol07Woo000LOol00`00Oomoo`16Ool00`00Oomoo`08Ool00`00Oomoo`0NOol001aoo`8004Mo
o`03001oogoo00Moo`03001oogoo01moo`0077oo00<007ooOol0Agoo00<007ooOol01Woo00<007oo
Ool07goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00B7oo00<007ooOol01Woo00<007ooOol0
7goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo04Qoo`03001oogoo00Eoo`03
001oogoo01moo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8004Uoo`03001oogoo00Aoo`03
001oogoo021oo`002Woo00@007ooOol000Yoo`05001oogooOol0001:Ool00`00Oomoo`04Ool00`00
Oomoo`0POol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00BGoo00<007ooOol017oo
00<007ooOol087oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo04Uoo`03
001oogoo00=oo`03001oogoo021oo`002goo0P002Goo0`000goo0P00BWoo00<007ooOol00goo00<0
07ooOol087oo000LOol00`00Oomoo`19Ool00`00Oomoo`03Ool00`00Oomoo`0POol000]oo`8000Ao
o`03001oogoo00=oo`<0009oo`8004]oo`03001oogoo009oo`03001oogoo021oo`002Woo00@007oo
Ool000Yoo`05001oogooOol0001<Ool01@00Oomoogoo00008goo000:Ool01000Oomoo`001goo1@00
0Woo0P00Bgoo00D007ooOomoo`0002=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00
Oomoo`1;Ool01000Oomoo`008goo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00C7oo00<0
07oo000097oo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0Bgoo0`0097oo000;Ool2000;
Ool01000Oomoogoo0P00CGoo0P0097oo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo
009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo
10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool0
1000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol0
01aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol0
01Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02
Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03
001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2480\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23178 L
.088 .23178 L
.092 .23178 L
.096 .23178 L
.1 .23177 L
.104 .23176 L
.108 .23175 L
.112 .23174 L
.116 .23174 L
.12 .23176 L
.124 .2318 L
.128 .23185 L
.132 .23189 L
.136 .23191 L
.14 .23188 L
.144 .2318 L
.148 .23166 L
.152 .23148 L
.156 .23131 L
.16 .23121 L
.164 .23123 L
.168 .23144 L
.172 .23187 L
.176 .23252 L
.18 .23331 L
.184 .23413 L
.188 .23479 L
.192 .23509 L
.196 .23478 L
.2 .23364 L
Mistroke
.204 .23152 L
.208 .22829 L
.212 .22396 L
.216 .21861 L
.22 .21243 L
.224 .20568 L
.228 .1987 L
.232 .19185 L
.236 .18547 L
.24 .17989 L
.244 .17538 L
.248 .17212 L
.252 .17022 L
.256 .16969 L
.26 .17048 L
.264 .17246 L
.268 .17544 L
.272 .17921 L
.276 .18356 L
.28 .18827 L
.284 .19312 L
.288 .19795 L
.292 .20259 L
.296 .20696 L
.3 .21095 L
.304 .21453 L
.308 .21768 L
.312 .2204 L
.316 .2227 L
.32 .22463 L
.324 .22621 L
.328 .2275 L
.332 .22852 L
.336 .22933 L
.34 .22996 L
.344 .23045 L
.348 .23081 L
.352 .23109 L
.356 .2313 L
.36 .23145 L
.364 .23156 L
.368 .23163 L
.372 .23169 L
.376 .23173 L
.38 .23176 L
.384 .23178 L
.388 .23179 L
.392 .2318 L
.396 .2318 L
.4 .23181 L
Mistroke
.404 .23181 L
.408 .23181 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23181 L
.588 .23181 L
.592 .23181 L
.596 .23182 L
.6 .23182 L
Mistroke
.604 .23182 L
.608 .23182 L
.612 .23182 L
.616 .23183 L
.62 .23184 L
.624 .23185 L
.628 .23187 L
.632 .2319 L
.636 .23194 L
.64 .23199 L
.644 .23207 L
.648 .23218 L
.652 .23233 L
.656 .23254 L
.66 .23282 L
.664 .23318 L
.668 .23367 L
.672 .2343 L
.676 .23511 L
.68 .23614 L
.684 .23742 L
.688 .239 L
.692 .24093 L
.696 .24323 L
.7 .24595 L
.704 .24909 L
.708 .25267 L
.712 .25666 L
.716 .26102 L
.72 .26566 L
.724 .27048 L
.728 .27533 L
.732 .28003 L
.736 .28437 L
.74 .28815 L
.744 .29113 L
.748 .2931 L
.752 .2939 L
.756 .29338 L
.76 .29148 L
.764 .28823 L
.768 .28372 L
.772 .27815 L
.776 .27178 L
.78 .26492 L
.784 .25794 L
.788 .25119 L
.792 .245 L
.796 .23964 L
.8 .2353 L
Mistroke
.804 .23206 L
.808 .22992 L
.812 .22879 L
.816 .22847 L
.82 .22876 L
.824 .22943 L
.828 .23025 L
.832 .23105 L
.836 .2317 L
.84 .23214 L
.844 .23236 L
.848 .23238 L
.852 .23228 L
.856 .23211 L
.86 .23193 L
.864 .23179 L
.868 .2317 L
.872 .23167 L
.876 .23169 L
.88 .23174 L
.884 .23178 L
.888 .23182 L
.892 .23184 L
.896 .23184 L
.9 .23183 L
.904 .23182 L
.908 .23181 L
.912 .2318 L
.916 .2318 L
.92 .2318 L
.924 .2318 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35317 L
.056 .35317 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35315 L
.076 .35315 L
.08 .35316 L
.084 .35317 L
.088 .35319 L
.092 .3532 L
.096 .35319 L
.1 .35316 L
.104 .35312 L
.108 .35308 L
.112 .35304 L
.116 .35305 L
.12 .35312 L
.124 .35325 L
.128 .35341 L
.132 .35356 L
.136 .35362 L
.14 .35354 L
.144 .35325 L
.148 .35276 L
.152 .35214 L
.156 .35154 L
.16 .35116 L
.164 .35124 L
.168 .35198 L
.172 .35351 L
.176 .35579 L
.18 .3586 L
.184 .3615 L
.188 .36386 L
.192 .36491 L
.196 .36381 L
.2 .35979 L
Mistroke
.204 .35222 L
.208 .34073 L
.212 .32529 L
.216 .3062 L
.22 .28413 L
.224 .26004 L
.228 .2351 L
.232 .21058 L
.236 .18775 L
.24 .16778 L
.244 .15162 L
.248 .13993 L
.252 .1331 L
.256 .13119 L
.26 .13398 L
.264 .14101 L
.268 .15164 L
.272 .16514 L
.276 .18068 L
.28 .1975 L
.284 .21485 L
.288 .2321 L
.292 .24872 L
.296 .26431 L
.3 .2786 L
.304 .2914 L
.308 .30266 L
.312 .31237 L
.316 .32062 L
.32 .3275 L
.324 .33316 L
.328 .33775 L
.332 .34141 L
.336 .3443 L
.34 .34655 L
.344 .34828 L
.348 .3496 L
.352 .35058 L
.356 .35131 L
.36 .35185 L
.364 .35224 L
.368 .35252 L
.372 .35272 L
.376 .35286 L
.38 .35296 L
.384 .35302 L
.388 .35307 L
.392 .3531 L
.396 .35312 L
.4 .35314 L
Mistroke
.404 .35315 L
.408 .35315 L
.412 .35316 L
.416 .35316 L
.42 .35316 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35316 L
.592 .35316 L
.596 .35316 L
.6 .35315 L
Mistroke
.604 .35315 L
.608 .35314 L
.612 .35312 L
.616 .3531 L
.62 .35307 L
.624 .35302 L
.628 .35296 L
.632 .35286 L
.636 .35272 L
.64 .35252 L
.644 .35224 L
.648 .35185 L
.652 .35131 L
.656 .35058 L
.66 .3496 L
.664 .34828 L
.668 .34655 L
.672 .3443 L
.676 .34141 L
.68 .33775 L
.684 .33316 L
.688 .3275 L
.692 .32062 L
.696 .31237 L
.7 .30266 L
.704 .2914 L
.708 .2786 L
.712 .26432 L
.716 .24872 L
.72 .2321 L
.724 .21485 L
.728 .1975 L
.732 .18069 L
.736 .16514 L
.74 .15165 L
.744 .14101 L
.748 .13398 L
.752 .13119 L
.756 .1331 L
.76 .13994 L
.764 .15162 L
.768 .16779 L
.772 .18776 L
.776 .21058 L
.78 .2351 L
.784 .26004 L
.788 .28414 L
.792 .3062 L
.796 .32529 L
.8 .34073 L
Mistroke
.804 .35222 L
.808 .35979 L
.812 .36381 L
.816 .36491 L
.82 .36386 L
.824 .3615 L
.828 .3586 L
.832 .35579 L
.836 .35351 L
.84 .35198 L
.844 .35124 L
.848 .35116 L
.852 .35154 L
.856 .35214 L
.86 .35276 L
.864 .35325 L
.868 .35354 L
.872 .35362 L
.876 .35356 L
.88 .35341 L
.884 .35325 L
.888 .35312 L
.892 .35305 L
.896 .35304 L
.9 .35308 L
.904 .35312 L
.908 .35316 L
.912 .35319 L
.916 .3532 L
.92 .35319 L
.924 .35317 L
.928 .35316 L
.932 .35315 L
.936 .35315 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35317 L
.956 .35317 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23177 L
.056 .23177 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23175 L
.076 .23176 L
.08 .23176 L
.084 .23177 L
.088 .23178 L
.092 .23179 L
.096 .23179 L
.1 .23176 L
.104 .23173 L
.108 .23169 L
.112 .23166 L
.116 .23167 L
.12 .23173 L
.124 .23183 L
.128 .23197 L
.132 .2321 L
.136 .23215 L
.14 .23208 L
.144 .23184 L
.148 .23143 L
.152 .23091 L
.156 .2304 L
.16 .23008 L
.164 .23015 L
.168 .23077 L
.172 .23205 L
.176 .23397 L
.18 .23633 L
.184 .23877 L
.188 .24075 L
.192 .24162 L
.196 .2407 L
.2 .23733 L
Mistroke
.204 .23097 L
.208 .22133 L
.212 .20837 L
.216 .19235 L
.22 .17382 L
.224 .1536 L
.228 .13266 L
.232 .11208 L
.236 .09292 L
.24 .07616 L
.244 .0626 L
.248 .05279 L
.252 .04706 L
.256 .04546 L
.26 .0478 L
.264 .05371 L
.268 .06264 L
.272 .07396 L
.276 .08702 L
.28 .10113 L
.284 .1157 L
.288 .13018 L
.292 .14414 L
.296 .15723 L
.3 .16922 L
.304 .17997 L
.308 .18942 L
.312 .19757 L
.316 .20449 L
.32 .21027 L
.324 .21502 L
.328 .21887 L
.332 .22195 L
.336 .22438 L
.34 .22627 L
.344 .22772 L
.348 .22882 L
.352 .22965 L
.356 .23026 L
.36 .23071 L
.364 .23104 L
.368 .23128 L
.372 .23144 L
.376 .23156 L
.38 .23164 L
.384 .2317 L
.388 .23174 L
.392 .23176 L
.396 .23178 L
.4 .23179 L
Mistroke
.404 .2318 L
.408 .2318 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23182 L
.588 .23182 L
.592 .23182 L
.596 .23182 L
.6 .23182 L
Mistroke
.604 .23183 L
.608 .23184 L
.612 .23185 L
.616 .23186 L
.62 .23189 L
.624 .23193 L
.628 .23199 L
.632 .23207 L
.636 .23218 L
.64 .23235 L
.644 .23259 L
.648 .23291 L
.652 .23336 L
.656 .23398 L
.66 .23481 L
.664 .23591 L
.668 .23736 L
.672 .23925 L
.676 .24168 L
.68 .24475 L
.684 .2486 L
.688 .25335 L
.692 .25913 L
.696 .26605 L
.7 .27421 L
.704 .28366 L
.708 .29441 L
.712 .3064 L
.716 .31949 L
.72 .33344 L
.724 .34792 L
.728 .36249 L
.732 .37661 L
.736 .38966 L
.74 .40099 L
.744 .40992 L
.748 .41582 L
.752 .41817 L
.756 .41657 L
.76 .41083 L
.764 .40103 L
.768 .38746 L
.772 .3707 L
.776 .35155 L
.78 .33097 L
.784 .31003 L
.788 .28981 L
.792 .27128 L
.796 .25526 L
.8 .2423 L
Mistroke
.804 .23266 L
.808 .2263 L
.812 .22293 L
.816 .222 L
.82 .22288 L
.824 .22486 L
.828 .2273 L
.832 .22966 L
.836 .23157 L
.84 .23286 L
.844 .23348 L
.848 .23355 L
.852 .23323 L
.856 .23272 L
.86 .2322 L
.864 .23179 L
.868 .23155 L
.872 .23148 L
.876 .23153 L
.88 .23166 L
.884 .23179 L
.888 .2319 L
.892 .23196 L
.896 .23196 L
.9 .23194 L
.904 .2319 L
.908 .23186 L
.912 .23184 L
.916 .23184 L
.92 .23184 L
.924 .23185 L
.928 .23187 L
.932 .23187 L
.936 .23187 L
.94 .23187 L
.944 .23187 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23187 L
.972 .23187 L
.976 .23187 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo10001Woo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00aoo`@000=oo`04001oogoo0002Ool20005Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Ool000000goo0P000goo0P0017oo
00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool0
1000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool20005Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`00
0Woo1@000goo0P001Woo000LOol2000EOol00`00Oomoo`05Ool2001DOol001aoo`03001oogoo01=o
o`8000Qoo`8005=oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00H0
07ooOomoo`00Ool30003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`04001oogooOol30002Ool01@00Oomo
ogoo00000Woo0P000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool00`00Oomoo`0:Ool0
01aoo`8004Moo`03001oogoo00Ioo`03001oogoo021oo`0077oo00<007ooOol0Agoo00<007ooOol0
17oo00<007ooOol08Goo000LOol20019Ool00`00Oomoo`02Ool2000SOol001aoo`03001oogoo04Qo
o`8000=oo`03001oogoo029oo`002goo0P0017oo00@007ooOomoo`D0009oo`8004Yoo`800003Ool0
000002Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1;Ool00`00Oomoo`0T
Ool000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00
Oomoogoo0000M7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=o
o`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04
001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:
Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03
001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P00
2goo00@007ooOomoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool3
0003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007oo
Ool000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol0
0`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol3
0003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00
Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomo
o`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<007Qoo`002Woo00@007oo
Ool000Moo`05001oogooOol0001gOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2001cOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo10000goo0P00Lgoo000:Ool01000
Oomoo`001goo00<007ooOol017oo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007ooOol0
0goo0P00Lgoo000;Ool2000:Ool20003Ool00`00Oomoo`1bOol001aoo`8001Qoo`80039oo`03001o
ogoo02Aoo`0077oo00<007ooOol05goo00<007oo0000<7oo00<007oo00009Goo000;Ool20004Ool0
0`00Oomoo`03Ool30002Ool2000GOol01000Oomoo`00<7oo00<007oo00009Goo000:Ool01000Oomo
o`002Woo00D007ooOomoo`0001Qoo`04001oogoo000_Ool01000Oomoo`009Goo0003Ool50002Ool0
1000Oomoo`001goo1@000Woo00<007ooOol05Woo00@007ooOol002moo`05001oogooOol0000TOol0
00Yoo`04001oogoo0007Ool01000Oomoo`000goo0P005goo00D007ooOomoo`0002ioo`05001oogoo
Ool0000TOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`0FOol01@00Oomoogoo
0000;Woo00D007ooOomoo`0002Aoo`002Woo00@007ooOol000Uoo`8000=oo`8001Moo`05001oogoo
Ool0000]Ool00`00Oomoo`02Ool00`00Oomoo`0ROol000]oo`8000]oo`05001oogooOol0000GOol0
0`00Oomoo`02Ool00`00Oomoo`0[Ool00`00Oomoo`02Ool00`00Oomoo`0ROol001aoo`8001Ioo`03
001oogoo00=oo`03001oogoo02Yoo`03001oogoo009oo`03001oogoo029oo`0077oo00<007ooOol0
5Goo00<007ooOol00goo00<007ooOol0:Woo00<007ooOol00goo00<007ooOol08Goo000;Ool20004
Ool01000Oomoogoo1@000Woo0P005Woo00<007ooOol00goo00<007ooOol0:Woo00<007ooOol00goo
00<007ooOol08Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo01Eoo`03001o
ogoo00=oo`03001oogoo02Uoo`03001oogoo00Aoo`03001oogoo025oo`000goo1@000Woo00@007oo
Ool000Uoo`03001oogoo009oo`03001oogoo01Aoo`03001oogoo00Aoo`03001oogoo02Uoo`03001o
ogoo00Aoo`03001oogoo025oo`002Woo00@007ooOol000Yoo`04001oogooOol2000>Ool30004Ool2
0006Ool00`00Oomoo`030004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50002Ool30004
Ool20005Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol037oo00D007ooOomoo`00009oo`800003Ool007oo00Aoo`05001oogooOol00004Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00L007oo
Oomoo`00Ool00002Ool00`00Oomoo`0200001Goo001oogoo00000Woo00<007ooOol00goo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`80015oo`03001oogoo00800003Ool007oo00Aoo`05001oogooOol00004Ool01000
Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo0000
0Woo00<007ooOol00Woo0P0000Eoo`00Oomoo`00009oo`03001oogoo00Aoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Uoo`<000=oo`03001oogoo011oo`03001oogoo
00800003Ool007oo00Eoo`04001oogoo0004Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo00000goo00@007ooOomoo`800005Ool007ooOol0
0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2
000=Ool40003Ool200000goo001oo`05Ool01000Oomoo`0017oo00@007ooOol0009oo`04001oogoo
0005Ool01000Oomoogoo10000goo00@007ooOol000=oo`8000=oo`03001oogoo00800005Ool007oo
Ool00002Ool00`00Oomoo`02Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03
001oogoo00aoo`03001oogoo00Aoo`800003Ool007oo00Eoo`04001oo`000004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Ool00003Ool0
0`00Oomoo`0200001Goo001oogoo00000Woo00<007ooOol00Woo00L007ooOomoo`00Ool00006Ool0
1000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50002Ool30008Ool00`00Ool00005Ool20004Ool2
0006Ool01000Oomoogoo1@000goo0P000Woo0P000Woo0`0017oo0P0017oo0P001Woo0`000Woo1@00
0goo0P001Woo000LOol2000DOol00`00Oomoo`09Ool00`00Oomoo`0QOol2000:Ool00`00Oomoo`0P
Ool001aoo`03001oogoo01=oo`03001oogoo00Yoo`80021oo`8000aoo`03001oogoo01moo`0077oo
J@0037oo000LOol00`00Oomoo`0@Ool3000DOol00`00Oomoo`0AOol00`00Oomoo`0BOol3000BOol0
0`00Oomoo`0:Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo00<007ooOol0LWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P00Lgoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo079oo`002Woo00@007ooOol000Uoo`03
001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001ao
o`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomo
o`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@0
07ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool0
0003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`05
001oogooOol0001dOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol05goo0P00FGoo000;Ool20004
Ool00`00Oomoo`03Ool30002Ool2000HOol00`00Ool0001HOol000Yoo`04001oogoo000:Ool01@00
Oomoogoo000067oo00@007ooOol005Qoo`000goo1@000Woo00@007ooOol000Moo`D0009oo`8001Mo
o`04001oogoo001HOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol05Woo00D0
07ooOomoo`0005Moo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8001Moo`05001oogooOol0
001GOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`0FOol01@00Oomoogoo0000Egoo000;
Ool2000;Ool01000Oomoogoo0P005Woo00<007ooOol00goo00<007ooOol0E7oo000LOol00`00Oomo
o`0EOol00`00Oomoo`03Ool00`00Oomoo`1DOol000]oo`8000Aoo`04001oogooOol50002Ool2000F
Ool00`00Oomoo`03Ool00`00Oomoo`1DOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<0
07ooOol03Goo0`0017oo0P001Goo00@007ooOomoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Ao
o`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007oo
Ool000Uoo`03001oogoo009oo`8000eoo`05001oogooOol00002Ool200000goo001oo`03Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003
Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomo
o`002Woo00D007ooOomoo`00019oo`03001oogoo00800003Ool007oo00Aoo`05001oogooOol00004
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo
00<007ooOol00P0000=oo`00Ool017oo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool0
1000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool200000goo
001oo`05Ool01000Oomoo`0017oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo1000
0goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06
001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P003Goo00<007oo
Ool017oo0P0000=oo`00Ool01Goo00@007oo000000Aoo`04001oogoo0002Ool01000Oomoo`0017oo
0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol0
37oo1@000goo0P001goo00@007ooOol000Eoo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006
Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`8001Aoo`03001oogoo00Qo
o`03001oogoo055oo`0077oo00<007ooOol04goo00<007ooOol02Goo0P00<Goo00<007ooOol07Goo
000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01000Oomoogoo1@000goo
00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool50004Ool01@00Oomoogoo00000goo00@007ooOomoo`<00003Ool0
07oo009oo`05001oogooOol00004Ool00`00Oomoo`0:Ool001aoo`8004Aoo`8000]oo`03001oogoo
01moo`0077oo00<007ooOol0A7oo0P002Goo00<007ooOol087oo000LOol20016Ool00`00Oomoo`07
Ool00`00Oomoo`0POol001aoo`03001oogoo04Ioo`03001oogoo00Ioo`03001oogoo021oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8004Moo`03001oogoo00Ioo`03001oogoo021oo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`16Ool00`00Oomoo`06Ool00`00Oomoo`0POol0
00Yoo`04001oogoo0009Ool00`00Oomoo`02Ool20018Ool00`00Oomoo`04Ool00`00Oomoo`0QOol0
00Yoo`04001oogoo000:Ool01@00Oomoogoo0000BGoo00<007ooOol017oo00<007ooOol08Goo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8004Qoo`03001oogoo00Aoo`03001oogoo025o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`18Ool00`00Oomoo`03Ool0
0`00Oomoo`0QOol000]oo`8000Uoo`<000=oo`8004Uoo`03001oogoo00=oo`03001oogoo025oo`00
77oo00<007ooOol0B7oo00<007ooOol00Woo00<007ooOol08Woo000;Ool20004Ool00`00Oomoo`03
Ool30002Ool20019Ool00`00Oomoo`02Ool00`00Oomoo`0ROol000Yoo`04001oogoo000:Ool01@00
Oomoogoo0000Bgoo00D007ooOomoo`0002Aoo`002Woo00@007ooOol000Moo`D0009oo`8004Yoo`05
001oogooOol0000TOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0BGoo00D0
07ooOomoo`0002Aoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8004]oo`03001oo`0002Eo
o`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo04Yoo`<002Eoo`002goo0P002goo00@007oo
Oomoo`8004aoo`03001oogoo02Aoo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02
Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@0
00=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@0
07ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000L
Ool00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000F
Ool30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo
0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00
Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2520\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23178 L
.068 .23178 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23178 L
.1 .23178 L
.104 .23178 L
.108 .23178 L
.112 .23177 L
.116 .23176 L
.12 .23175 L
.124 .23174 L
.128 .23174 L
.132 .23176 L
.136 .2318 L
.14 .23185 L
.144 .2319 L
.148 .23191 L
.152 .23188 L
.156 .23179 L
.16 .23164 L
.164 .23146 L
.168 .23128 L
.172 .23117 L
.176 .23121 L
.18 .23144 L
.184 .2319 L
.188 .23257 L
.192 .23339 L
.196 .23423 L
.2 .23491 L
Mistroke
.204 .2352 L
.208 .23487 L
.212 .23371 L
.216 .23154 L
.22 .22826 L
.224 .22388 L
.228 .21848 L
.232 .21226 L
.236 .20549 L
.24 .19851 L
.244 .19166 L
.248 .18531 L
.252 .17977 L
.256 .1753 L
.26 .17209 L
.264 .17023 L
.268 .16975 L
.272 .17057 L
.276 .17256 L
.28 .17556 L
.284 .17934 L
.288 .18368 L
.292 .18838 L
.296 .19321 L
.3 .19802 L
.304 .20265 L
.308 .20699 L
.312 .21097 L
.316 .21454 L
.32 .21768 L
.324 .22039 L
.328 .22269 L
.332 .22461 L
.336 .22619 L
.34 .22748 L
.344 .2285 L
.348 .22932 L
.352 .22995 L
.356 .23043 L
.36 .2308 L
.364 .23108 L
.368 .23129 L
.372 .23144 L
.376 .23155 L
.38 .23163 L
.384 .23169 L
.388 .23173 L
.392 .23175 L
.396 .23177 L
.4 .23179 L
Mistroke
.404 .2318 L
.408 .2318 L
.412 .23181 L
.416 .23181 L
.42 .23181 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23181 L
.576 .23181 L
.58 .23181 L
.584 .23182 L
.588 .23182 L
.592 .23182 L
.596 .23182 L
.6 .23183 L
Mistroke
.604 .23183 L
.608 .23184 L
.612 .23185 L
.616 .23187 L
.62 .2319 L
.624 .23194 L
.628 .232 L
.632 .23208 L
.636 .23219 L
.64 .23234 L
.644 .23255 L
.648 .23283 L
.652 .2332 L
.656 .23368 L
.66 .23432 L
.664 .23513 L
.668 .23615 L
.672 .23744 L
.676 .23902 L
.68 .24094 L
.684 .24324 L
.688 .24595 L
.692 .24908 L
.696 .25265 L
.7 .25662 L
.704 .26096 L
.708 .26559 L
.712 .27039 L
.716 .27522 L
.72 .27991 L
.724 .28425 L
.728 .28803 L
.732 .29102 L
.736 .29302 L
.74 .29384 L
.744 .29336 L
.748 .29151 L
.752 .28831 L
.756 .28384 L
.76 .27831 L
.764 .27196 L
.768 .26511 L
.772 .25813 L
.776 .25135 L
.78 .24513 L
.784 .23972 L
.788 .23533 L
.792 .23204 L
.796 .22986 L
.8 .22869 L
Mistroke
.804 .22836 L
.808 .22865 L
.812 .22933 L
.816 .23017 L
.82 .231 L
.824 .23168 L
.828 .23215 L
.832 .23238 L
.836 .23242 L
.84 .23231 L
.844 .23213 L
.848 .23194 L
.852 .23179 L
.856 .2317 L
.86 .23167 L
.864 .23168 L
.868 .23173 L
.872 .23178 L
.876 .23182 L
.88 .23184 L
.884 .23185 L
.888 .23184 L
.892 .23182 L
.896 .23181 L
.9 .2318 L
.904 .2318 L
.908 .2318 L
.912 .2318 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35317 L
.068 .35317 L
.072 .35316 L
.076 .35316 L
.08 .35315 L
.084 .35315 L
.088 .35315 L
.092 .35316 L
.096 .35318 L
.1 .35319 L
.104 .3532 L
.108 .35319 L
.112 .35316 L
.116 .35311 L
.12 .35306 L
.124 .35303 L
.128 .35305 L
.132 .35313 L
.136 .35327 L
.14 .35344 L
.144 .3536 L
.148 .35366 L
.152 .35355 L
.156 .35323 L
.16 .3527 L
.164 .35205 L
.168 .35142 L
.172 .35104 L
.176 .35115 L
.18 .35196 L
.184 .35358 L
.188 .35597 L
.192 .35889 L
.196 .36187 L
.2 .36428 L
Mistroke
.204 .36532 L
.208 .36416 L
.212 .36002 L
.216 .35229 L
.22 .34062 L
.224 .325 L
.228 .30574 L
.232 .28354 L
.236 .25937 L
.24 .23441 L
.244 .20993 L
.248 .1872 L
.252 .16736 L
.256 .15135 L
.26 .13983 L
.264 .13316 L
.268 .13138 L
.272 .13428 L
.276 .14139 L
.28 .15207 L
.284 .16557 L
.288 .1811 L
.292 .19788 L
.296 .21518 L
.3 .23237 L
.304 .24892 L
.308 .26446 L
.312 .27868 L
.316 .29144 L
.32 .30266 L
.324 .31235 L
.328 .32057 L
.332 .32744 L
.336 .3331 L
.34 .33768 L
.344 .34135 L
.348 .34425 L
.352 .3465 L
.356 .34824 L
.36 .34956 L
.364 .35055 L
.368 .35129 L
.372 .35183 L
.376 .35223 L
.38 .35251 L
.384 .35271 L
.388 .35285 L
.392 .35295 L
.396 .35302 L
.4 .35307 L
Mistroke
.404 .3531 L
.408 .35312 L
.412 .35314 L
.416 .35315 L
.42 .35315 L
.424 .35316 L
.428 .35316 L
.432 .35316 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35316 L
.58 .35316 L
.584 .35316 L
.588 .35315 L
.592 .35315 L
.596 .35314 L
.6 .35312 L
Mistroke
.604 .3531 L
.608 .35307 L
.612 .35302 L
.616 .35295 L
.62 .35285 L
.624 .35271 L
.628 .35251 L
.632 .35223 L
.636 .35183 L
.64 .35129 L
.644 .35055 L
.648 .34956 L
.652 .34824 L
.656 .3465 L
.66 .34425 L
.664 .34135 L
.668 .33768 L
.672 .3331 L
.676 .32744 L
.68 .32057 L
.684 .31235 L
.688 .30266 L
.692 .29144 L
.696 .27869 L
.7 .26446 L
.704 .24893 L
.708 .23237 L
.712 .21518 L
.716 .19788 L
.72 .18111 L
.724 .16558 L
.728 .15208 L
.732 .1414 L
.736 .13429 L
.74 .13139 L
.744 .13316 L
.748 .13983 L
.752 .15135 L
.756 .16736 L
.76 .1872 L
.764 .20993 L
.768 .23441 L
.772 .25937 L
.776 .28354 L
.78 .30574 L
.784 .325 L
.788 .34063 L
.792 .35229 L
.796 .36002 L
.8 .36416 L
Mistroke
.804 .36532 L
.808 .36428 L
.812 .36187 L
.816 .35889 L
.82 .35597 L
.824 .35358 L
.828 .35196 L
.832 .35115 L
.836 .35104 L
.84 .35142 L
.844 .35205 L
.848 .3527 L
.852 .35323 L
.856 .35355 L
.86 .35366 L
.864 .3536 L
.868 .35344 L
.872 .35327 L
.876 .35313 L
.88 .35305 L
.884 .35303 L
.888 .35306 L
.892 .35311 L
.896 .35316 L
.9 .35319 L
.904 .3532 L
.908 .35319 L
.912 .35318 L
.916 .35316 L
.92 .35315 L
.924 .35315 L
.928 .35315 L
.932 .35316 L
.936 .35316 L
.94 .35317 L
.944 .35317 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23177 L
.068 .23177 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23175 L
.088 .23176 L
.092 .23176 L
.096 .23178 L
.1 .23179 L
.104 .23179 L
.108 .23179 L
.112 .23176 L
.116 .23172 L
.12 .23168 L
.124 .23165 L
.128 .23167 L
.132 .23173 L
.136 .23185 L
.14 .232 L
.144 .23213 L
.148 .23218 L
.152 .23209 L
.156 .23182 L
.16 .23138 L
.164 .23083 L
.168 .2303 L
.172 .22998 L
.176 .23008 L
.18 .23075 L
.184 .23211 L
.188 .23412 L
.192 .23657 L
.196 .23908 L
.2 .24109 L
Mistroke
.204 .24197 L
.208 .24099 L
.212 .23752 L
.216 .23103 L
.22 .22124 L
.224 .20812 L
.228 .19196 L
.232 .17332 L
.236 .15303 L
.24 .13208 L
.244 .11153 L
.248 .09245 L
.252 .07581 L
.256 .06237 L
.26 .0527 L
.264 .0471 L
.268 .04562 L
.272 .04806 L
.276 .05403 L
.28 .06299 L
.284 .07433 L
.288 .08737 L
.292 .10146 L
.296 .11598 L
.3 .13041 L
.304 .14431 L
.308 .15735 L
.312 .16929 L
.316 .18 L
.32 .18942 L
.324 .19755 L
.328 .20445 L
.332 .21022 L
.336 .21497 L
.34 .21882 L
.344 .2219 L
.348 .22433 L
.352 .22622 L
.356 .22768 L
.36 .22879 L
.364 .22962 L
.368 .23024 L
.372 .2307 L
.376 .23103 L
.38 .23127 L
.384 .23144 L
.388 .23155 L
.392 .23164 L
.396 .2317 L
.4 .23173 L
Mistroke
.404 .23176 L
.408 .23178 L
.412 .23179 L
.416 .2318 L
.42 .2318 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23181 L
.572 .23182 L
.576 .23182 L
.58 .23182 L
.584 .23182 L
.588 .23182 L
.592 .23183 L
.596 .23184 L
.6 .23185 L
Mistroke
.604 .23187 L
.608 .23189 L
.612 .23193 L
.616 .23199 L
.62 .23207 L
.624 .23219 L
.628 .23236 L
.632 .2326 L
.636 .23293 L
.64 .23339 L
.644 .234 L
.648 .23484 L
.652 .23595 L
.656 .2374 L
.66 .2393 L
.664 .24173 L
.668 .24481 L
.672 .24866 L
.676 .2534 L
.68 .25917 L
.684 .26608 L
.688 .27421 L
.692 .28363 L
.696 .29434 L
.7 .30628 L
.704 .31932 L
.708 .33322 L
.712 .34765 L
.716 .36217 L
.72 .37625 L
.724 .38929 L
.728 .40063 L
.732 .4096 L
.736 .41557 L
.74 .418 L
.744 .41652 L
.748 .41092 L
.752 .40126 L
.756 .38782 L
.76 .37117 L
.764 .35209 L
.768 .33155 L
.772 .31059 L
.776 .2903 L
.78 .27167 L
.784 .25551 L
.788 .24239 L
.792 .2326 L
.796 .22611 L
.8 .22263 L
Mistroke
.804 .22166 L
.808 .22253 L
.812 .22455 L
.816 .22706 L
.82 .22951 L
.824 .23151 L
.828 .23287 L
.832 .23355 L
.836 .23365 L
.84 .23333 L
.844 .2328 L
.848 .23225 L
.852 .23181 L
.856 .23154 L
.86 .23145 L
.864 .2315 L
.868 .23163 L
.872 .23178 L
.876 .23189 L
.88 .23196 L
.884 .23197 L
.888 .23195 L
.892 .23191 L
.896 .23187 L
.9 .23184 L
.904 .23183 L
.908 .23184 L
.912 .23185 L
.916 .23186 L
.92 .23187 L
.924 .23187 L
.928 .23187 L
.932 .23187 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23187 L
.96 .23187 L
.964 .23187 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007oo00000P00
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo00aoo`@000=oo`03001oogoo008000=oo`03001oogoo009oo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@0
00=oo`04001oogoo0005Ool000]oo`8000Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo
0004Ool20002Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Ao
o`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00
Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`<000Eoo`80
009oo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004
Ool20006Ool30002Ool50003Ool20006Ool001aoo`8001Ioo`8000Ioo`8005=oo`0077oo00<007oo
Ool057oo0P0027oo0P00DWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000Woo0`000Woo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Ool000030003Ool0
1P00Oomoogoo001oo`<000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00<007ooOol0
2Woo000LOol20015Ool20007Ool2000SOol001aoo`03001oogoo04Ioo`03001oogoo00Aoo`03001o
ogoo029oo`0077oo0P00Agoo0P0017oo0P0097oo000LOol00`00Oomoo`17Ool20003Ool00`00Oomo
o`0SOol000]oo`8000Aoo`04001oogooOol50002Ool20019Ool200000goo001oo`0UOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0BGoo0P009goo000:Ool01000Oomoo`002Goo
00<007ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`00
2goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomo
o`0007Aoo`002Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001o
ogoo0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yo
o`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol0
01aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool0
0`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004
Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@0
07ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool2
0009Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00
Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo
000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
000;Ool20004Ool00`00Oomoo`02Ool3001hOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
Mgoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007oo
Ool000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000;Ool20009
Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool0
0`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`@000=oo`8007=oo`002Woo00@007ooOol000Moo`03001oogoo00Ao
o`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`8007=oo`002goo0P002Woo
0P000goo00<007ooOol0LWoo000LOol2000JOol00`00Oomoo`0]Ool2000WOol001aoo`03001oogoo
01Qoo`03001oo`0002ioo`03001oo`0002Ioo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00
6Goo00<007oo0000;Goo00@007ooOol002Ioo`002Woo00@007ooOol000Yoo`05001oogooOol0000J
Ool00`00Ool0000]Ool01000Oomoo`009Woo0003Ool50002Ool01000Oomoo`001goo1@000Woo00<0
07ooOol05goo00D007ooOomoo`0002aoo`04001oogoo000VOol000Yoo`04001oogoo0007Ool01000
Oomoo`000goo0P0067oo00D007ooOomoo`0002aoo`04001oogoo000VOol000Yoo`04001oogoo0008
Ool00`00Ool00003Ool00`00Oomoo`0GOol01@00Oomoogoo0000;7oo00D007ooOomoo`0002Eoo`00
2Woo00@007ooOol000Uoo`8000=oo`8001Qoo`05001oogooOol0000[Ool00`00Oomoo`02Ool00`00
Oomoo`0SOol000]oo`8000]oo`05001oogooOol0000HOol00`00Oomoo`02Ool00`00Oomoo`0YOol0
0`00Oomoo`02Ool00`00Oomoo`0SOol001aoo`8001Moo`03001oogoo00=oo`03001oogoo02Qoo`03
001oogoo009oo`03001oogoo02=oo`0077oo00<007ooOol05Woo00<007ooOol00goo00<007ooOol0
9goo00<007ooOol017oo00<007ooOol08Woo000;Ool20004Ool01000Oomoogoo1@000Woo0P005goo
00<007ooOol00goo00<007ooOol09goo00<007ooOol017oo00<007ooOol08Woo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`03001oogoo01Ioo`03001oogoo00Aoo`03001oogoo02Ioo`03001o
ogoo00Aoo`03001oogoo029oo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`03001o
ogoo01Ioo`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo00Aoo`03001oogoo029oo`002Woo
00@007ooOol000Yoo`04001oogooOol2000>Ool30004Ool30006Ool00`00Ool000020004Ool20004
Ool20005Ool30003Ool30004Ool20004Ool600000goo001oo`020004Ool20005Ool50002Ool30004
Ool20006Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo00D007oo
Oomoo`00009oo`04001oo`000006Ool01000Oomoo`0017oo00@007ooOol0009oo`04001oogoo0005
Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoo`00Ool00P00
0Woo00@007ooOol0009oo`03001oogoo00=oo`06001oogoo001oo`000goo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01@00Oomoo`00
Ool00P001Woo00@007ooOol000Aoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo0P000Woo00@007ooOol0009oo`03001o
ogoo00Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Uoo`<000=o
o`03001oogoo011oo`05001oogoo001oo`020007Ool00`00Ool00004Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol00P00
0Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`8000eoo`@000=oo`04001oo`000007Ool00`00Ool00004Ool01000Oomoo`000Woo
00@007ooOol000Eoo`04001oogooOol40003Ool01P00Oomoo`00Ool0009oo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eo
o`0077oo00<007ooOol037oo00<007ooOol017oo00@007oo000000Qoo`8000Aoo`04001oogoo0002
Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00H007ooOol007oo0002Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo
0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Uoo`8000Eoo`8000Aoo`8000Ioo`04001oogoo
Ool50003Ool200000goo001oo`03Ool30003Ool30004Ool20006Ool30002Ool50003Ool20006Ool0
01aoo`8001Eoo`03001oogoo00Uoo`03001oogoo01moo`8000Yoo`03001oogoo025oo`0077oo00<0
07ooOol057oo00<007ooOol02Woo0P007Woo0P0037oo00<007ooOol087oo000LOomY000<Ool001ao
o`03001oogoo015oo`<001=oo`03001oogoo015oo`03001oogoo015oo`<001=oo`03001oogoo00Yo
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol000]oo`8000Aoo`04001oogooOol50002Ool2001cOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002Goo00<007ooOol00Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00
Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo
00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=o
o`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00D007ooOomoo`00
07Aoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`0IOol00`00Oomoo`1FOol000]oo`8000Aoo`03
001oogoo00=oo`<0009oo`8001Uoo`03001oo`0005Moo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0000JOol00`00Ool0001GOol000=oo`D0009oo`04001oogoo0007Ool50002Ool2000HOol01@00
Oomoogoo0000EWoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo01Moo`05001o
ogooOol0001FOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2000HOol01@00Oomoogoo0000
EWoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol05goo00D007ooOomoo`0005Ioo`002goo
0P002goo00@007ooOomoo`8001Moo`03001oogoo00=oo`03001oogoo05=oo`0077oo00<007ooOol0
5Woo00<007ooOol00goo00<007ooOol0Dgoo000;Ool20004Ool01000Oomoogoo1@000Woo0P005goo
00<007ooOol00goo00<007ooOol0Dgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001o
ogoo00eoo`<000Aoo`<000Ioo`03001oo`00008000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`80
00Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol0
00Uoo`03001oogoo009oo`8000eoo`05001oogooOol00002Ool01000Oomoo`001Woo00@007ooOol0
00Aoo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00
Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo
00004Woo00@007ooOol0009oo`03001oogoo00Aoo`04001oogoo0004Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo00D007ooOol007oo008000Io
o`04001oogoo0004Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol037oo10000goo00@007oo000000Moo`03001oo`0000Aoo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005
Ool000]oo`8000Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04001oo`000007Ool30004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Uoo`8000Eoo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`80
01Eoo`03001oogoo00Qoo`80055oo`0077oo00<007ooOol057oo00<007ooOol02Goo0P00;Woo0P00
87oo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0Woo0`000Woo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00002Ool60004Ool01@00Oomoogoo00000Woo0P000Woo0`00
0Woo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo0P004goo00<007oo
Ool0;Goo0P002goo00<007ooOol087oo000LOol00`00Oomoo`13Ool00`00Oomoo`08Ool00`00Oomo
o`0QOol001aoo`8004Eoo`03001oogoo00Moo`03001oogoo025oo`0077oo00<007ooOol0A7oo00<0
07ooOol01goo00<007ooOol08Goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00AWoo00<007oo
Ool01Woo00<007ooOol08Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo04Eo
o`03001oogoo00Eoo`03001oogoo029oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8004Mo
o`03001oogoo00Aoo`03001oogoo029oo`002Woo00@007ooOol000Yoo`05001oogooOol00018Ool0
0`00Oomoo`04Ool00`00Oomoo`0ROol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00
Agoo00<007ooOol017oo00<007ooOol08Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo04Ioo`03001oogoo00Aoo`03001oogoo029oo`002goo0P002Goo0`000goo0P00B7oo
00<007ooOol00goo00<007ooOol08Woo000LOol00`00Oomoo`17Ool00`00Oomoo`02Ool00`00Oomo
o`0SOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8004Qoo`03001oogoo009oo`03001oogoo
02=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001:Ool01@00Oomoogoo00009Goo000:Ool0
1000Oomoo`001goo1@000Woo0P00BGoo00D007ooOomoo`0002Eoo`002Woo00@007ooOol000Moo`04
001oogoo0003Ool00`00Oomoo`18Ool01000Oomoo`009Woo000:Ool01000Oomoo`0027oo00<007oo
00000goo0P00BGoo00@007ooOol002Ioo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo04Uo
o`03001oo`0002Ioo`002goo0P002goo00@007ooOomoo`8004]oo`03001oogoo02Eoo`0077oo00<0
07ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo
079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`00
27oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<0
00=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009o
o`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03
001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2560\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23178 L
.08 .23178 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23178 L
.112 .23178 L
.116 .23179 L
.12 .23178 L
.124 .23177 L
.128 .23176 L
.132 .23174 L
.136 .23173 L
.14 .23174 L
.144 .23177 L
.148 .23181 L
.152 .23186 L
.156 .23191 L
.16 .23192 L
.164 .23189 L
.168 .23178 L
.172 .23162 L
.176 .23143 L
.18 .23124 L
.184 .23114 L
.188 .23118 L
.192 .23143 L
.196 .23192 L
.2 .23262 L
Mistroke
.204 .23348 L
.208 .23434 L
.212 .23503 L
.216 .23531 L
.22 .23497 L
.224 .23377 L
.228 .23155 L
.232 .22823 L
.236 .22379 L
.24 .21835 L
.244 .21209 L
.248 .20531 L
.252 .19832 L
.256 .19148 L
.26 .18516 L
.264 .17965 L
.268 .17523 L
.272 .17206 L
.276 .17025 L
.28 .1698 L
.284 .17065 L
.288 .17267 L
.292 .17567 L
.296 .17946 L
.3 .1838 L
.304 .18848 L
.308 .1933 L
.312 .19809 L
.316 .20271 L
.32 .20703 L
.324 .211 L
.328 .21455 L
.332 .21768 L
.336 .22038 L
.34 .22268 L
.344 .2246 L
.348 .22618 L
.352 .22746 L
.356 .22849 L
.36 .2293 L
.364 .22993 L
.368 .23042 L
.372 .23079 L
.376 .23107 L
.38 .23128 L
.384 .23143 L
.388 .23155 L
.392 .23163 L
.396 .23168 L
.4 .23173 L
Mistroke
.404 .23175 L
.408 .23177 L
.412 .23179 L
.416 .2318 L
.42 .2318 L
.424 .23181 L
.428 .23181 L
.432 .23181 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23181 L
.564 .23181 L
.568 .23182 L
.572 .23182 L
.576 .23182 L
.58 .23182 L
.584 .23182 L
.588 .23183 L
.592 .23183 L
.596 .23184 L
.6 .23185 L
Mistroke
.604 .23187 L
.608 .2319 L
.612 .23194 L
.616 .232 L
.62 .23208 L
.624 .23219 L
.628 .23235 L
.632 .23256 L
.636 .23284 L
.64 .23321 L
.644 .2337 L
.648 .23433 L
.652 .23514 L
.656 .23617 L
.66 .23745 L
.664 .23903 L
.668 .24095 L
.672 .24325 L
.676 .24595 L
.68 .24907 L
.684 .25262 L
.688 .25658 L
.692 .2609 L
.696 .26551 L
.7 .2703 L
.704 .27512 L
.708 .27979 L
.712 .28413 L
.716 .28791 L
.72 .29091 L
.724 .29293 L
.728 .29379 L
.732 .29334 L
.736 .29154 L
.74 .28838 L
.744 .28396 L
.748 .27846 L
.752 .27214 L
.756 .26531 L
.76 .25831 L
.764 .25152 L
.768 .24526 L
.772 .23981 L
.776 .23536 L
.78 .23203 L
.784 .2298 L
.788 .22859 L
.792 .22824 L
.796 .22853 L
.8 .22922 L
Mistroke
.804 .23009 L
.808 .23095 L
.812 .23166 L
.816 .23215 L
.82 .2324 L
.824 .23245 L
.828 .23235 L
.832 .23216 L
.836 .23196 L
.84 .2318 L
.844 .2317 L
.848 .23166 L
.852 .23167 L
.856 .23172 L
.86 .23177 L
.864 .23181 L
.868 .23184 L
.872 .23185 L
.876 .23184 L
.88 .23183 L
.884 .23181 L
.888 .2318 L
.892 .2318 L
.896 .2318 L
.9 .2318 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35317 L
.08 .35317 L
.084 .35316 L
.088 .35316 L
.092 .35315 L
.096 .35315 L
.1 .35315 L
.104 .35316 L
.108 .35318 L
.112 .3532 L
.116 .3532 L
.12 .35319 L
.124 .35315 L
.128 .3531 L
.132 .35305 L
.136 .35302 L
.14 .35304 L
.144 .35314 L
.148 .35329 L
.152 .35348 L
.156 .35364 L
.16 .35369 L
.164 .35356 L
.168 .3532 L
.172 .35264 L
.176 .35194 L
.18 .3513 L
.184 .35092 L
.188 .35107 L
.192 .35195 L
.196 .35366 L
.2 .35616 L
Mistroke
.204 .35918 L
.208 .36225 L
.212 .3647 L
.216 .36573 L
.22 .3645 L
.224 .36024 L
.228 .35236 L
.232 .3405 L
.236 .32469 L
.24 .30527 L
.244 .28294 L
.248 .2587 L
.252 .23372 L
.256 .20928 L
.26 .18664 L
.264 .16694 L
.268 .15109 L
.272 .13973 L
.276 .13322 L
.28 .13158 L
.284 .13459 L
.288 .14178 L
.292 .1525 L
.296 .16601 L
.3 .18152 L
.304 .19826 L
.308 .2155 L
.312 .23263 L
.316 .24913 L
.32 .2646 L
.324 .27877 L
.328 .29148 L
.332 .30266 L
.336 .31232 L
.34 .32053 L
.344 .32739 L
.348 .33303 L
.352 .33762 L
.356 .34129 L
.36 .34419 L
.364 .34645 L
.368 .3482 L
.372 .34952 L
.376 .35052 L
.38 .35127 L
.384 .35181 L
.388 .35221 L
.392 .3525 L
.396 .3527 L
.4 .35285 L
Mistroke
.404 .35295 L
.408 .35302 L
.412 .35307 L
.416 .3531 L
.42 .35312 L
.424 .35313 L
.428 .35314 L
.432 .35315 L
.436 .35316 L
.44 .35316 L
.444 .35316 L
.448 .35316 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35316 L
.564 .35316 L
.568 .35316 L
.572 .35316 L
.576 .35315 L
.58 .35314 L
.584 .35313 L
.588 .35312 L
.592 .3531 L
.596 .35307 L
.6 .35302 L
Mistroke
.604 .35295 L
.608 .35285 L
.612 .3527 L
.616 .3525 L
.62 .35221 L
.624 .35181 L
.628 .35127 L
.632 .35052 L
.636 .34952 L
.64 .3482 L
.644 .34645 L
.648 .34419 L
.652 .34129 L
.656 .33762 L
.66 .33303 L
.664 .32739 L
.668 .32053 L
.672 .31232 L
.676 .30266 L
.68 .29148 L
.684 .27877 L
.688 .2646 L
.692 .24913 L
.696 .23263 L
.7 .21551 L
.704 .19826 L
.708 .18153 L
.712 .16601 L
.716 .1525 L
.72 .14178 L
.724 .13459 L
.728 .13159 L
.732 .13322 L
.736 .13973 L
.74 .15109 L
.744 .16694 L
.748 .18665 L
.752 .20928 L
.756 .23372 L
.76 .2587 L
.764 .28295 L
.768 .30527 L
.772 .32469 L
.776 .3405 L
.78 .35236 L
.784 .36024 L
.788 .3645 L
.792 .36573 L
.796 .3647 L
.8 .36225 L
Mistroke
.804 .35918 L
.808 .35616 L
.812 .35366 L
.816 .35195 L
.82 .35107 L
.824 .35092 L
.828 .3513 L
.832 .35194 L
.836 .35264 L
.84 .3532 L
.844 .35356 L
.848 .35369 L
.852 .35364 L
.856 .35348 L
.86 .35329 L
.864 .35314 L
.868 .35304 L
.872 .35302 L
.876 .35305 L
.88 .3531 L
.884 .35315 L
.888 .35319 L
.892 .3532 L
.896 .3532 L
.9 .35318 L
.904 .35316 L
.908 .35315 L
.912 .35315 L
.916 .35315 L
.92 .35316 L
.924 .35316 L
.928 .35317 L
.932 .35317 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23177 L
.08 .23177 L
.084 .23176 L
.088 .23176 L
.092 .23175 L
.096 .23175 L
.1 .23176 L
.104 .23176 L
.108 .23178 L
.112 .23179 L
.116 .2318 L
.12 .23179 L
.124 .23176 L
.128 .23171 L
.132 .23167 L
.136 .23164 L
.14 .23166 L
.144 .23174 L
.148 .23187 L
.152 .23203 L
.156 .23216 L
.16 .2322 L
.164 .2321 L
.168 .2318 L
.172 .23132 L
.176 .23074 L
.18 .2302 L
.184 .22988 L
.188 .23001 L
.192 .23074 L
.196 .23218 L
.2 .23428 L
Mistroke
.204 .23682 L
.208 .23939 L
.212 .24145 L
.216 .24231 L
.22 .24128 L
.224 .23771 L
.228 .23108 L
.232 .22114 L
.236 .20786 L
.24 .19156 L
.244 .17282 L
.248 .15247 L
.252 .1315 L
.256 .11099 L
.26 .09199 L
.264 .07545 L
.268 .06215 L
.272 .05262 L
.276 .04715 L
.28 .04579 L
.284 .04831 L
.288 .05435 L
.292 .06335 L
.296 .0747 L
.3 .08772 L
.304 .10177 L
.308 .11625 L
.312 .13063 L
.316 .14448 L
.32 .15746 L
.324 .16936 L
.328 .18003 L
.332 .18942 L
.336 .19753 L
.34 .20442 L
.344 .21017 L
.348 .21492 L
.352 .21877 L
.356 .22185 L
.36 .22428 L
.364 .22618 L
.368 .22764 L
.372 .22876 L
.376 .2296 L
.38 .23022 L
.384 .23068 L
.388 .23101 L
.392 .23126 L
.396 .23143 L
.4 .23155 L
Mistroke
.404 .23163 L
.408 .23169 L
.412 .23173 L
.416 .23176 L
.42 .23178 L
.424 .23179 L
.428 .2318 L
.432 .2318 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23181 L
.56 .23182 L
.564 .23182 L
.568 .23182 L
.572 .23182 L
.576 .23182 L
.58 .23183 L
.584 .23184 L
.588 .23185 L
.592 .23187 L
.596 .23189 L
.6 .23194 L
Mistroke
.604 .23199 L
.608 .23208 L
.612 .2322 L
.616 .23237 L
.62 .23261 L
.624 .23295 L
.628 .23341 L
.632 .23403 L
.636 .23487 L
.64 .23598 L
.644 .23745 L
.648 .23935 L
.652 .24178 L
.656 .24486 L
.66 .24871 L
.664 .25345 L
.668 .25921 L
.672 .2661 L
.676 .27421 L
.68 .28359 L
.684 .29426 L
.688 .30616 L
.692 .31915 L
.696 .333 L
.7 .34737 L
.704 .36185 L
.708 .3759 L
.712 .38893 L
.716 .40027 L
.72 .40928 L
.724 .41531 L
.728 .41784 L
.732 .41647 L
.736 .411 L
.74 .40147 L
.744 .38817 L
.748 .37163 L
.752 .35263 L
.756 .33212 L
.76 .31116 L
.764 .29081 L
.768 .27207 L
.772 .25577 L
.776 .24249 L
.78 .23254 L
.784 .22592 L
.788 .22235 L
.792 .22132 L
.796 .22218 L
.8 .22424 L
Mistroke
.804 .22681 L
.808 .22935 L
.812 .23144 L
.816 .23288 L
.82 .23362 L
.824 .23374 L
.828 .23343 L
.832 .23289 L
.836 .23231 L
.84 .23183 L
.844 .23153 L
.848 .23142 L
.852 .23147 L
.856 .2316 L
.86 .23176 L
.864 .23189 L
.868 .23196 L
.872 .23198 L
.876 .23196 L
.88 .23191 L
.884 .23187 L
.888 .23184 L
.892 .23183 L
.896 .23184 L
.9 .23185 L
.904 .23186 L
.908 .23187 L
.912 .23188 L
.916 .23187 L
.92 .23187 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23187 L
.948 .23187 L
.952 .23187 L
.956 .23187 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol00`00
17oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo00aoo`@000=oo`05001oogoo001oo`020002Ool01@00Oomoogoo0000
17oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo
00@007ooOol000Eoo`002goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00H007ooOol007oo
0004Ool01000Ool0000017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04
Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L0
07ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool200000goo
001oo`04Ool200000goo001oo`04Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`00
17oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000GOol20006Ool2001BOol001ao
o`03001oogoo01Ioo`03001oogoo00Moo`03001oogoo04moo`0077ooJ@0037oo000LOol01@00Oomo
ogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`<00003Ool007oo009oo`05001oogoo
Ool00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool50004Ool01000Oomoogoo0P000Woo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`8004Aoo`8000Moo`8002Aoo`0077oo00<007oo
Ool0A7oo0P001Woo00<007ooOol08goo000LOol20016Ool20004Ool00`00Oomoo`0TOol001aoo`03
001oogoo04Ioo`03001oogoo009oo`03001oogoo02Aoo`002goo0P0017oo00@007ooOomoo`D0009o
o`8004Qoo`@002Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`18Ool2000X
Ool000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00
Oomoogoo0000M7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=o
o`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04
001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:
Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03
001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P00
2goo00@007ooOomoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool3
0003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007oo
Ool000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol0
0`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol3
0003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00
Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomo
o`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<007Qoo`002Woo00@007oo
Ool000Moo`05001oogooOol0001gOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2001cOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo10000goo0P00Lgoo000:Ool01000
Oomoo`001goo00<007ooOol017oo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007ooOol0
0goo0P00Lgoo000;Ool2000:Ool20003Ool00`00Oomoo`1bOol001aoo`8001]oo`8002aoo`8002Qo
o`0077oo00<007ooOol06Goo00<007oo0000;7oo0P00:7oo000;Ool20004Ool00`00Oomoo`03Ool3
0002Ool2000JOol00`00Ool0000[Ool01000Oomoo`009goo000:Ool01000Oomoo`002Woo00D007oo
Oomoo`0001]oo`03001oo`0002]oo`04001oogoo000WOol000=oo`D0009oo`04001oogoo0007Ool5
0002Ool00`00Oomoo`0IOol01000Oomoo`00:Woo00@007ooOol002Moo`002Woo00@007ooOol000Mo
o`04001oogoo0003Ool2000JOol01000Oomoo`00:Goo00D007ooOomoo`0002Moo`002Woo00@007oo
Ool000Qoo`03001oo`0000=oo`03001oogoo01Qoo`05001oogooOol0000YOol00`00Oomoo`02Ool0
0`00Oomoo`0TOol000Yoo`04001oogoo0009Ool20003Ool2000IOol00`00Oomoo`02Ool00`00Oomo
o`0VOol00`00Oomoo`02Ool00`00Oomoo`0TOol000]oo`8000]oo`05001oogooOol0000JOol00`00
Oomoo`02Ool00`00Oomoo`0VOol00`00Oomoo`02Ool00`00Oomoo`0TOol001aoo`8001Uoo`03001o
ogoo009oo`03001oogoo02Ioo`03001oogoo009oo`03001oogoo02Aoo`0077oo00<007ooOol05goo
00<007ooOol00goo00<007ooOol09Goo00<007ooOol00goo00<007ooOol097oo000;Ool20004Ool0
1000Oomoogoo1@000Woo0P0067oo00<007ooOol00goo00<007ooOol09Goo00<007ooOol00goo00<0
07ooOol097oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo01Moo`03001oogoo
00Aoo`03001oogoo02Aoo`03001oogoo00=oo`03001oogoo02Aoo`000goo1@000Woo00@007ooOol0
00Uoo`03001oogoo009oo`03001oogoo01Moo`03001oogoo00Aoo`03001oogoo02Aoo`03001oogoo
00Aoo`03001oogoo02=oo`002Woo00@007ooOol000Yoo`04001oogooOol2000>Ool30004Ool20000
0goo001oo`05Ool40004Ool20004Ool20005Ool30003Ool30004Ool20002Ool00`00Oomoo`060002
Ool20004Ool20005Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol037oo00D007ooOomoo`00009oo`04001oogoo0008Ool20004Ool01000Oomo
o`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007oo00000goo
00<007ooOol00P0000Eoo`00Oomoo`00009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00
4Goo00@007ooOol0009oo`03001oogoo00Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol01Goo00@007ooOol0009oo`03001oo`0000Aoo`06001oogoo001oo`000Woo00@007oo
Ool0009oo`03001oogoo00Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]o
o`8000Uoo`<000=oo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`06Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool20006Ool01@00Ool0
07oo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool0
0`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool00`00Oomoo`020003Ool01P00Oomoogoo
001oo`80009oo`04001oogoo0002Ool00`00Oomoo`02Ool01P00Oomoogoo001oo`@000=oo`04001o
ogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`03001oogoo008000=oo`06001o
ogooOol007oo0P000Woo00@007ooOol0009oo`03001oogoo009oo`07001oogooOol007oo00001Woo
00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0`002Goo0P0017oo0P0017oo0P001Woo
00@007ooOomoo`D000=oo`<000Eoo`<0009oo`04001oo`000004Ool20006Ool30002Ool50003Ool2
0006Ool001aoo`8001Moo`03001oogoo00Qoo`8001ioo`03001oogoo00Uoo`03001oogoo029oo`00
77oo00<007ooOol05Goo00<007ooOol02Woo0P006goo0`002goo00<007ooOol08Woo000LOomY000<
Ool001aoo`03001oogoo019oo`<0019oo`03001oogoo015oo`03001oogoo011oo`<001Aoo`03001o
ogoo00Yoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogooOol50002Ool2001cOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002Goo00<007oo
Ool00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:
Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomo
o`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=o
o`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00D007oo
Oomoo`0007Aoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`0JOol2001FOol000]oo`8000Aoo`03
001oogoo00=oo`<0009oo`8001Yoo`03001oo`0005Ioo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0000KOol00`00Ool0001FOol000=oo`D0009oo`04001oogoo0007Ool50002Ool2000JOol01000
Oomoo`00EGoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo01Uoo`04001oogoo
001EOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2000IOol01@00Oomoogoo0000EGoo000:
Ool01000Oomoo`002Goo0P000goo00<007ooOol067oo00<007ooOol00Woo00<007ooOol0DWoo000;
Ool2000;Ool01000Oomoogoo0P006Goo00<007ooOol00Woo00<007ooOol0DWoo000LOol00`00Oomo
o`0HOol00`00Oomoo`02Ool00`00Oomoo`1BOol000]oo`8000Aoo`04001oogooOol50002Ool2000H
Ool00`00Oomoo`03Ool00`00Oomoo`1BOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<0
07ooOol03Goo0`0017oo0P0000=oo`00Ool01Goo100017oo0P0017oo0P001Goo0`000goo0`0017oo
0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomo
o`002Goo00<007ooOol00Woo0P003Goo00D007ooOomoo`00009oo`03001oogoo008000Ioo`03001o
o`0000Aoo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomo
ogoo00004Woo00@007ooOol0009oo`8000Ioo`03001oo`0000Aoo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol0
1Woo0P0017oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo00aoo`@000=oo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool20009
Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04
001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000L
Ool00`00Oomoo`0<Ool50003Ool30009Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo
1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000GOol0
0`00Oomoo`07Ool2001@Ool001aoo`03001oogoo01Eoo`03001oogoo00Uoo`8002aoo`03001oogoo
021oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`00
00=oo`<00003Ool007oo009oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`06001oogooOol007oo1@0000=oo`00Ool00goo00X007ooOomoo`00
Ool007oo001oo`<000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001ao
o`8001Eoo`03001oogoo02Yoo`03001oogoo00Uoo`03001oogoo029oo`0077oo00<007ooOol0@Woo
00<007ooOol027oo00<007ooOol08Woo000LOol20014Ool00`00Oomoo`07Ool00`00Oomoo`0ROol0
01aoo`03001oogoo04=oo`03001oogoo00Moo`03001oogoo029oo`002goo0P0017oo00@007ooOomo
o`D0009oo`8004Aoo`03001oogoo00Moo`03001oogoo029oo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool00`00Oomoo`14Ool00`00Oomoo`05Ool00`00Oomoo`0SOol000Yoo`04001oogoo0009
Ool00`00Oomoo`02Ool20015Ool00`00Oomoo`05Ool00`00Oomoo`0SOol000Yoo`04001oogoo000:
Ool01@00Oomoogoo0000Agoo00<007ooOol017oo00<007ooOol08goo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`8004Ioo`03001oogoo00Aoo`03001oogoo02=oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`15Ool00`00Oomoo`03Ool00`00Oomoo`0TOol000]o
o`8000Uoo`<000=oo`8004Moo`03001oogoo009oo`03001oogoo02Aoo`0077oo00<007ooOol0AWoo
00<007ooOol00Woo00<007ooOol097oo000;Ool20004Ool00`00Oomoo`03Ool30002Ool20017Ool0
0`00Oomoo`02Ool00`00Oomoo`0TOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000B7oo00<0
07ooOol00Woo00<007ooOol097oo000:Ool01000Oomoo`001goo1@000Woo0P00Agoo00<007ooOol0
0Woo00<007ooOol097oo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo04Moo`04
001oogoo000WOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool20018Ool01000Oomoo`009goo
000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0B7oo0P00:7oo000;Ool2000;Ool01000Oomo
ogoo0P00BGoo0P00:7oo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=o
o`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`00
27oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001o
ogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=o
o`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol0
01Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Mo
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2600\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23178 L
.088 .23178 L
.092 .23178 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23178 L
.12 .23178 L
.124 .23179 L
.128 .23179 L
.132 .23178 L
.136 .23177 L
.14 .23175 L
.144 .23174 L
.148 .23173 L
.152 .23174 L
.156 .23177 L
.16 .23182 L
.164 .23188 L
.168 .23192 L
.172 .23193 L
.176 .23189 L
.18 .23178 L
.184 .2316 L
.188 .2314 L
.192 .23121 L
.196 .23111 L
.2 .23116 L
Mistroke
.204 .23143 L
.208 .23194 L
.212 .23268 L
.216 .23356 L
.22 .23445 L
.224 .23515 L
.228 .23543 L
.232 .23506 L
.236 .23383 L
.24 .23157 L
.244 .22819 L
.248 .2237 L
.252 .21821 L
.256 .21193 L
.26 .20512 L
.264 .19813 L
.268 .19131 L
.272 .18501 L
.276 .17954 L
.28 .17516 L
.284 .17204 L
.288 .17027 L
.292 .16986 L
.296 .17074 L
.3 .17278 L
.304 .17579 L
.308 .17958 L
.312 .18391 L
.316 .18859 L
.32 .19339 L
.324 .19817 L
.328 .20276 L
.332 .20707 L
.336 .21102 L
.34 .21456 L
.344 .21768 L
.348 .22037 L
.352 .22266 L
.356 .22458 L
.36 .22616 L
.364 .22744 L
.368 .22847 L
.372 .22928 L
.376 .22992 L
.38 .23041 L
.384 .23078 L
.388 .23106 L
.392 .23127 L
.396 .23143 L
.4 .23154 L
Mistroke
.404 .23162 L
.408 .23168 L
.412 .23172 L
.416 .23175 L
.42 .23177 L
.424 .23179 L
.428 .2318 L
.432 .2318 L
.436 .23181 L
.44 .23181 L
.444 .23181 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23181 L
.552 .23181 L
.556 .23182 L
.56 .23182 L
.564 .23182 L
.568 .23182 L
.572 .23182 L
.576 .23183 L
.58 .23183 L
.584 .23184 L
.588 .23186 L
.592 .23188 L
.596 .2319 L
.6 .23195 L
Mistroke
.604 .232 L
.608 .23209 L
.612 .2322 L
.616 .23235 L
.62 .23256 L
.624 .23285 L
.628 .23322 L
.632 .23371 L
.636 .23435 L
.64 .23516 L
.644 .23619 L
.648 .23747 L
.652 .23905 L
.656 .24097 L
.66 .24325 L
.664 .24595 L
.668 .24906 L
.672 .2526 L
.676 .25654 L
.68 .26085 L
.684 .26544 L
.688 .27021 L
.692 .27501 L
.696 .27968 L
.7 .28401 L
.704 .28779 L
.708 .29081 L
.712 .29285 L
.716 .29373 L
.72 .29332 L
.724 .29156 L
.728 .28845 L
.732 .28407 L
.736 .27861 L
.74 .27232 L
.744 .2655 L
.748 .2585 L
.752 .25169 L
.756 .2454 L
.76 .2399 L
.764 .2354 L
.768 .23201 L
.772 .22974 L
.776 .2285 L
.78 .22813 L
.784 .22841 L
.788 .22911 L
.792 .23 L
.796 .23089 L
.8 .23163 L
Mistroke
.804 .23215 L
.808 .23243 L
.812 .23248 L
.816 .23238 L
.82 .23219 L
.824 .23198 L
.828 .23181 L
.832 .23169 L
.836 .23165 L
.84 .23166 L
.844 .2317 L
.848 .23176 L
.852 .23181 L
.856 .23184 L
.86 .23185 L
.864 .23185 L
.868 .23183 L
.872 .23181 L
.876 .2318 L
.88 .2318 L
.884 .2318 L
.888 .2318 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35317 L
.088 .35317 L
.092 .35317 L
.096 .35316 L
.1 .35316 L
.104 .35315 L
.108 .35315 L
.112 .35315 L
.116 .35317 L
.12 .35319 L
.124 .3532 L
.128 .35321 L
.132 .35319 L
.136 .35315 L
.14 .35309 L
.144 .35304 L
.148 .35301 L
.152 .35304 L
.156 .35315 L
.16 .35332 L
.164 .35352 L
.168 .35368 L
.172 .35372 L
.176 .35357 L
.18 .35317 L
.184 .35256 L
.188 .35184 L
.192 .35117 L
.196 .3508 L
.2 .35099 L
Mistroke
.204 .35194 L
.208 .35375 L
.212 .35636 L
.216 .35949 L
.22 .36264 L
.224 .36512 L
.228 .36614 L
.232 .36484 L
.236 .36046 L
.24 .35241 L
.244 .34037 L
.248 .32437 L
.252 .30479 L
.256 .28234 L
.26 .25803 L
.264 .23303 L
.268 .20864 L
.272 .1861 L
.276 .16653 L
.28 .15083 L
.284 .13964 L
.288 .13328 L
.292 .13178 L
.296 .1349 L
.3 .14216 L
.304 .15292 L
.308 .16644 L
.312 .18194 L
.316 .19864 L
.32 .21583 L
.324 .23289 L
.328 .24932 L
.332 .26474 L
.336 .27885 L
.34 .29152 L
.344 .30266 L
.348 .3123 L
.352 .32048 L
.356 .32733 L
.36 .33297 L
.364 .33756 L
.368 .34123 L
.372 .34413 L
.376 .3464 L
.38 .34815 L
.384 .34949 L
.388 .35049 L
.392 .35124 L
.396 .35179 L
.4 .3522 L
Mistroke
.404 .35249 L
.408 .35269 L
.412 .35284 L
.416 .35294 L
.42 .35301 L
.424 .35306 L
.428 .3531 L
.432 .35312 L
.436 .35313 L
.44 .35314 L
.444 .35315 L
.448 .35315 L
.452 .35316 L
.456 .35316 L
.46 .35316 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35316 L
.552 .35316 L
.556 .35316 L
.56 .35315 L
.564 .35315 L
.568 .35314 L
.572 .35313 L
.576 .35312 L
.58 .3531 L
.584 .35306 L
.588 .35301 L
.592 .35294 L
.596 .35284 L
.6 .35269 L
Mistroke
.604 .35249 L
.608 .3522 L
.612 .35179 L
.616 .35124 L
.62 .35049 L
.624 .34949 L
.628 .34815 L
.632 .3464 L
.636 .34413 L
.64 .34123 L
.644 .33756 L
.648 .33297 L
.652 .32733 L
.656 .32048 L
.66 .3123 L
.664 .30267 L
.668 .29152 L
.672 .27886 L
.676 .26474 L
.68 .24933 L
.684 .2329 L
.688 .21583 L
.692 .19864 L
.696 .18194 L
.7 .16644 L
.704 .15292 L
.708 .14216 L
.712 .1349 L
.716 .13179 L
.72 .13329 L
.724 .13964 L
.728 .15084 L
.732 .16653 L
.736 .1861 L
.74 .20864 L
.744 .23304 L
.748 .25803 L
.752 .28234 L
.756 .30479 L
.76 .32437 L
.764 .34037 L
.768 .35241 L
.772 .36046 L
.776 .36484 L
.78 .36614 L
.784 .36512 L
.788 .36264 L
.792 .35949 L
.796 .35636 L
.8 .35375 L
Mistroke
.804 .35194 L
.808 .35099 L
.812 .3508 L
.816 .35117 L
.82 .35184 L
.824 .35256 L
.828 .35317 L
.832 .35357 L
.836 .35372 L
.84 .35368 L
.844 .35352 L
.848 .35332 L
.852 .35315 L
.856 .35304 L
.86 .35301 L
.864 .35304 L
.868 .35309 L
.872 .35315 L
.876 .35319 L
.88 .35321 L
.884 .3532 L
.888 .35319 L
.892 .35317 L
.896 .35315 L
.9 .35315 L
.904 .35315 L
.908 .35316 L
.912 .35316 L
.916 .35317 L
.92 .35317 L
.924 .35317 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23176 L
.1 .23176 L
.104 .23175 L
.108 .23175 L
.112 .23176 L
.116 .23177 L
.12 .23178 L
.124 .2318 L
.128 .2318 L
.132 .23179 L
.136 .23175 L
.14 .2317 L
.144 .23166 L
.148 .23163 L
.152 .23166 L
.156 .23175 L
.16 .23189 L
.164 .23206 L
.168 .23219 L
.172 .23223 L
.176 .2321 L
.18 .23177 L
.184 .23126 L
.188 .23065 L
.192 .23009 L
.196 .22978 L
.2 .22994 L
Mistroke
.204 .23074 L
.208 .23226 L
.212 .23445 L
.216 .23707 L
.22 .23971 L
.224 .2418 L
.228 .24265 L
.232 .24156 L
.236 .23789 L
.24 .23113 L
.244 .22103 L
.248 .2076 L
.252 .19116 L
.256 .17232 L
.26 .15191 L
.264 .13093 L
.268 .11046 L
.272 .09154 L
.276 .07511 L
.28 .06194 L
.284 .05254 L
.288 .04721 L
.292 .04595 L
.296 .04857 L
.3 .05467 L
.304 .06371 L
.308 .07506 L
.312 .08807 L
.316 .10209 L
.32 .11652 L
.324 .13085 L
.328 .14464 L
.332 .15758 L
.336 .16943 L
.34 .18007 L
.344 .18942 L
.348 .19751 L
.352 .20438 L
.356 .21013 L
.36 .21486 L
.364 .21871 L
.368 .2218 L
.372 .22424 L
.376 .22614 L
.38 .22761 L
.384 .22873 L
.388 .22957 L
.392 .2302 L
.396 .23066 L
.4 .231 L
Mistroke
.404 .23125 L
.408 .23142 L
.412 .23154 L
.416 .23163 L
.42 .23169 L
.424 .23173 L
.428 .23176 L
.432 .23178 L
.436 .23179 L
.44 .2318 L
.444 .2318 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23181 L
.548 .23182 L
.552 .23182 L
.556 .23182 L
.56 .23182 L
.564 .23182 L
.568 .23183 L
.572 .23184 L
.576 .23185 L
.58 .23187 L
.584 .2319 L
.588 .23194 L
.592 .232 L
.596 .23208 L
.6 .23221 L
Mistroke
.604 .23238 L
.608 .23263 L
.612 .23296 L
.616 .23343 L
.62 .23406 L
.624 .2349 L
.628 .23602 L
.632 .23749 L
.636 .23939 L
.64 .24183 L
.644 .24491 L
.648 .24876 L
.652 .2535 L
.656 .25925 L
.66 .26612 L
.664 .2742 L
.668 .28356 L
.672 .29419 L
.676 .30605 L
.68 .31898 L
.684 .33278 L
.688 .3471 L
.692 .36154 L
.696 .37556 L
.7 .38856 L
.704 .39992 L
.708 .40895 L
.712 .41505 L
.716 .41767 L
.72 .41641 L
.724 .41108 L
.728 .40169 L
.732 .38851 L
.736 .37209 L
.74 .35317 L
.744 .3327 L
.748 .31172 L
.752 .29131 L
.756 .27247 L
.76 .25603 L
.764 .2426 L
.768 .2325 L
.772 .22574 L
.776 .22206 L
.78 .22097 L
.784 .22183 L
.788 .22391 L
.792 .22656 L
.796 .22918 L
.8 .23137 L
Mistroke
.804 .23289 L
.808 .23369 L
.812 .23385 L
.816 .23354 L
.82 .23298 L
.824 .23237 L
.828 .23186 L
.832 .23153 L
.836 .2314 L
.84 .23143 L
.844 .23157 L
.848 .23174 L
.852 .23188 L
.856 .23197 L
.86 .23199 L
.864 .23197 L
.868 .23192 L
.872 .23188 L
.876 .23184 L
.88 .23183 L
.884 .23183 L
.888 .23184 L
.892 .23186 L
.896 .23187 L
.9 .23188 L
.904 .23187 L
.908 .23187 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23187 L
.936 .23187 L
.94 .23187 L
.944 .23187 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00@007ooOomoo`@0
009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`000Woo0P000Woo00@007ooOol000Ao
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04
001oogoo0005Ool000]oo`8000Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0002Ool0
0`00Oomoo`02Ool30004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Ao
o`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00
Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000=oo`03
001oogoo00=oo`8000Eoo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004
Ool20006Ool30002Ool50003Ool20006Ool001aoo`8001Uoo`03001oogoo00Eoo`03001oogoo04mo
o`0077oo00<007ooOol05goo00<007ooOol01goo0P00Cgoo000LOomY000<Ool001aoo`05001oogoo
Ool00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007oo00000P000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`<00003Ool007oo00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo0P00@goo0P001goo00<007ooOol0
97oo000LOol00`00Oomoo`13Ool00`00Oomoo`05Ool00`00Oomoo`0TOol001aoo`8004Eoo`03001o
ogoo00=oo`03001oogoo02Eoo`0077oo00<007ooOol0AGoo00D007ooOomoo`0002Qoo`002goo0P00
17oo00@007ooOomoo`D0009oo`8004Moo`04001oo`00000XOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00<007ooOol0Agoo0P00:Goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00
Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007oo
Ool00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@0
07ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool2
0003Ool00`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079o
o`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001c
Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00
Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]o
o`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool3
0003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001c
Ool001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomo
o`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1g
Ool001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00
Oomoo`02Ool3001hOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000;Ool20009Ool30003Ool00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003
Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool5
0002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`@000=oo`8007=oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`03001oogoo079oo`00
2Woo00@007ooOol000Qoo`03001oogoo00=oo`8007=oo`002goo0P002Woo0P000goo00<007ooOol0
LWoo000LOol2000LOol2000ZOol2000YOol001aoo`03001oogoo01]oo`8002Uoo`03001oo`0002Uo
o`002goo0P0017oo00<007ooOol00goo0`000Woo0P006goo00@007ooOol002Qoo`03001oo`0002Uo
o`002Woo00@007ooOol000Yoo`05001oogooOol0000LOol01000Oomoo`00:7oo00<007oo0000:Goo
0003Ool50002Ool01000Oomoo`001goo1@000Woo00<007ooOol06Woo00@007ooOol002Qoo`04001o
ogoo000XOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P006goo00@007ooOol002Moo`05
001oogooOol0000XOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`0IOol01@00
Oomoogoo00009goo00D007ooOomoo`0002Qoo`002Woo00@007ooOol000Uoo`8000=oo`8001Yoo`03
001oogoo009oo`03001oogoo02Aoo`05001oogooOol0000XOol000]oo`8000]oo`05001oogooOol0
000KOol00`00Oomoo`02Ool00`00Oomoo`0TOol00`00Oomoo`02Ool00`00Oomoo`0UOol001aoo`80
01Yoo`03001oogoo009oo`03001oogoo02=oo`03001oogoo00=oo`03001oogoo02Eoo`0077oo00<0
07ooOol06Goo00<007ooOol00goo00<007ooOol08Woo00<007ooOol00goo00<007ooOol09Goo000;
Ool20004Ool01000Oomoogoo1@000Woo0P006Woo00<007ooOol00goo00<007ooOol08Woo00<007oo
Ool00goo00<007ooOol09Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo01Qo
o`03001oogoo00Aoo`03001oogoo025oo`03001oogoo00Eoo`03001oogoo02Aoo`000goo1@000Woo
00@007ooOol000Uoo`03001oogoo009oo`03001oogoo01Qoo`03001oogoo00Aoo`03001oogoo025o
o`03001oogoo00Eoo`03001oogoo02Aoo`002Woo00@007ooOol000Yoo`04001oogooOol2000>Ool3
0004Ool20002Ool00`00Oomoo`04Ool30004Ool20004Ool20005Ool30003Ool30004Ool200000goo
001oo`02Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol037oo00D007ooOomoo`00009oo`06001oogoo001oo`00
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@0
07ooOol0009oo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001o
ogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2000AOol01000Oomoo`000Woo00<007oo00001goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo0P001Goo00<007oo0000
0Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool00goo000;Ool20009Ool30003Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00<007oo00001goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo0P000Woo00@007ooOol0009oo`04001oogoo0007Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool00`00Oomoo`020008Ool20003
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool0
1000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`020007Ool30003
Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oo`000004Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Io
o`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`800003Ool007oo00Moo`03001oo`00
00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool3000017oo001oogoo0P0017oo0P00
1Woo0`000Woo1@000goo0P001Woo000LOol2000HOol00`00Oomoo`08Ool2000LOol00`00Oomoo`09
Ool00`00Oomoo`0SOol001aoo`03001oogoo01Ioo`03001oogoo00Yoo`8001Uoo`8000aoo`03001o
ogoo02=oo`0077ooJ@0037oo000LOol00`00Oomoo`0BOol00`00Ool00002000@Ool00`00Oomoo`0A
Ool00`00Oomoo`0?Ool4000DOol00`00Oomoo`0:Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000;Ool20004Ool01000
Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo079o
o`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001o
ogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`00
0Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Mo
o`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00
Oomoo`1bOol000]oo`8000]oo`05001oogooOol0001dOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool06goo00<007ooOol0E7oo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000LOol2001EOol0
00Yoo`04001oogoo000:Ool01@00Oomoogoo000077oo00@007ooOol005Aoo`000goo1@000Woo00@0
07ooOol000Moo`D0009oo`8001]oo`04001oogoo001DOol000Yoo`04001oogoo0007Ool01000Oomo
o`000goo00<007ooOol06Woo00@007ooOol005Aoo`002Woo00@007ooOol000Qoo`03001oo`0000=o
o`8001Yoo`05001oogooOol0001DOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`0IOol0
0`00Oomoo`02Ool00`00Oomoo`1AOol000]oo`8000]oo`04001oogooOol2000JOol00`00Oomoo`02
Ool00`00Oomoo`1AOol001aoo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo055oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8001Yoo`03001oogoo00=oo`03001oogoo051oo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0=Ool30004Ool20003Ool00`00Oomoo`03Ool3
0004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool3
0004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool2000=Ool01@00Oomo
ogoo00000Woo00H007ooOol007oo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol000Eoo`05
001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo
000:Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`04001oogoo0002Ool00`00Ool00007Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P004Goo00@007ooOol0009oo`03001oo`0000Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool0
1P00Oomoo`00Ool000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Oomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uoo`<000=oo`8000eo
o`03001oogoo00Aoo`03001oogoo008000Moo`<000=oo`04001oogoo0002Ool01000Oomoo`0017oo
0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol0
37oo1@000goo0P0000=oo`00Ool01goo0P0017oo0P0017oo0P001Woo00@007ooOomoo`D000=oo`80
00Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P0067oo00<007ooOol0
27oo00<007ooOol0CGoo000LOol00`00Oomoo`0FOol00`00Oomoo`09Ool2000YOol2000SOol001ao
ofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`04001oogooOol20002Ool50003
Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01000Oomoogoo1@000goo00<007ooOol00Woo00@007ooOomoo`80009oo`<00003Ool007oo009o
o`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`8001Ioo`03001oogoo
02Qoo`03001oogoo00Uoo`03001oogoo02=oo`0077oo00<007ooOol0@Goo00<007ooOol027oo00<0
07ooOol08goo000LOol20012Ool00`00Oomoo`08Ool00`00Oomoo`0SOol001aoo`03001oogoo049o
o`03001oogoo00Ioo`03001oogoo02Aoo`002goo0P0017oo00@007ooOomoo`D0009oo`8004=oo`03
001oogoo00Ioo`03001oogoo02Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomo
o`13Ool00`00Oomoo`05Ool00`00Oomoo`0TOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2
0014Ool00`00Oomoo`05Ool00`00Oomoo`0TOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000
AGoo00<007ooOol01Goo00<007ooOol097oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`8004Aoo`03001oogoo00Eoo`03001oogoo02Aoo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`14Ool00`00Oomoo`03Ool00`00Oomoo`0UOol000]oo`8000Uoo`<000=oo`80
04Eoo`03001oogoo00=oo`03001oogoo02Eoo`0077oo00<007ooOol0A7oo00<007ooOol00goo00<0
07ooOol09Goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool20016Ool00`00Oomoo`02Ool00`00
Oomoo`0UOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000Agoo00D007ooOomoo`0002Qoo`00
2Woo00@007ooOol000Moo`D0009oo`8004Ioo`05001oogooOol0000XOol000Yoo`04001oogoo0007
Ool01000Oomoo`000goo00<007ooOol0AWoo00@007ooOol002Qoo`002Woo00@007ooOol000Qoo`03
001oo`0000=oo`8004Moo`03001oo`0002Uoo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo
04Ioo`<002Uoo`002goo0P002goo00@007ooOomoo`8004Qoo`8002Uoo`0077oo00<007ooOol0LWoo
000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=o
o`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo
0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<0
00=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=o
o`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo
079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Mo
o`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2640\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23178 L
.1 .23178 L
.104 .23178 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23178 L
.132 .23178 L
.136 .23179 L
.14 .23179 L
.144 .23178 L
.148 .23177 L
.152 .23175 L
.156 .23173 L
.16 .23173 L
.164 .23174 L
.168 .23177 L
.172 .23183 L
.176 .23189 L
.18 .23193 L
.184 .23194 L
.188 .23189 L
.192 .23177 L
.196 .23158 L
.2 .23136 L
Mistroke
.204 .23117 L
.208 .23107 L
.212 .23114 L
.216 .23143 L
.22 .23197 L
.224 .23274 L
.228 .23365 L
.232 .23456 L
.236 .23527 L
.24 .23554 L
.244 .23515 L
.248 .23389 L
.252 .23158 L
.256 .22815 L
.26 .22361 L
.264 .21808 L
.268 .21175 L
.272 .20493 L
.276 .19794 L
.28 .19113 L
.284 .18486 L
.288 .17943 L
.292 .17509 L
.296 .17202 L
.3 .17029 L
.304 .16992 L
.308 .17083 L
.312 .17288 L
.316 .17591 L
.32 .1797 L
.324 .18403 L
.328 .18869 L
.332 .19348 L
.336 .19824 L
.34 .20282 L
.344 .20711 L
.348 .21104 L
.352 .21457 L
.356 .21768 L
.36 .22037 L
.364 .22265 L
.368 .22456 L
.372 .22614 L
.376 .22742 L
.38 .22845 L
.384 .22927 L
.388 .22991 L
.392 .2304 L
.396 .23077 L
.4 .23106 L
Mistroke
.404 .23127 L
.408 .23142 L
.412 .23154 L
.416 .23162 L
.42 .23168 L
.424 .23172 L
.428 .23175 L
.432 .23177 L
.436 .23179 L
.44 .23179 L
.444 .2318 L
.448 .23181 L
.452 .23181 L
.456 .23181 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23181 L
.54 .23181 L
.544 .23182 L
.548 .23182 L
.552 .23182 L
.556 .23182 L
.56 .23182 L
.564 .23183 L
.568 .23183 L
.572 .23184 L
.576 .23186 L
.58 .23188 L
.584 .23191 L
.588 .23195 L
.592 .23201 L
.596 .23209 L
.6 .2322 L
Mistroke
.604 .23236 L
.608 .23257 L
.612 .23286 L
.616 .23323 L
.62 .23373 L
.624 .23436 L
.628 .23518 L
.632 .23621 L
.636 .23749 L
.64 .23907 L
.644 .24098 L
.648 .24326 L
.652 .24595 L
.656 .24905 L
.66 .25258 L
.664 .25651 L
.668 .26079 L
.672 .26537 L
.676 .27012 L
.68 .27491 L
.684 .27956 L
.688 .28389 L
.692 .28768 L
.696 .2907 L
.7 .29276 L
.704 .29367 L
.708 .2933 L
.712 .29158 L
.716 .28852 L
.72 .28418 L
.724 .27876 L
.728 .27249 L
.732 .26569 L
.736 .25869 L
.74 .25186 L
.744 .24553 L
.748 .23999 L
.752 .23544 L
.756 .232 L
.76 .22968 L
.764 .22841 L
.768 .22801 L
.772 .22829 L
.776 .229 L
.78 .22991 L
.784 .23083 L
.788 .2316 L
.792 .23215 L
.796 .23245 L
.8 .23252 L
Mistroke
.804 .23242 L
.808 .23222 L
.812 .23201 L
.816 .23182 L
.82 .23169 L
.824 .23164 L
.828 .23165 L
.832 .23169 L
.836 .23175 L
.84 .23181 L
.844 .23184 L
.848 .23186 L
.852 .23185 L
.856 .23183 L
.86 .23182 L
.864 .2318 L
.868 .23179 L
.872 .23179 L
.876 .2318 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35317 L
.1 .35317 L
.104 .35317 L
.108 .35316 L
.112 .35315 L
.116 .35315 L
.12 .35315 L
.124 .35315 L
.128 .35317 L
.132 .35319 L
.136 .35321 L
.14 .35321 L
.144 .35319 L
.148 .35314 L
.152 .35308 L
.156 .35302 L
.16 .353 L
.164 .35304 L
.168 .35316 L
.172 .35335 L
.176 .35356 L
.18 .35372 L
.184 .35375 L
.188 .35357 L
.192 .35314 L
.196 .35249 L
.2 .35172 L
Mistroke
.204 .35104 L
.208 .35068 L
.212 .35091 L
.216 .35194 L
.22 .35385 L
.224 .35657 L
.228 .3598 L
.232 .36303 L
.236 .36555 L
.24 .36655 L
.244 .36517 L
.248 .36067 L
.252 .35245 L
.256 .34023 L
.26 .32405 L
.264 .3043 L
.268 .28173 L
.272 .25735 L
.276 .23235 L
.28 .20801 L
.284 .18557 L
.288 .16613 L
.292 .15059 L
.296 .13956 L
.3 .13335 L
.304 .13199 L
.308 .13521 L
.312 .14254 L
.316 .15334 L
.32 .16687 L
.324 .18235 L
.328 .19901 L
.332 .21615 L
.336 .23315 L
.34 .24952 L
.344 .26487 L
.348 .27894 L
.352 .29156 L
.356 .30267 L
.36 .31227 L
.364 .32044 L
.368 .32727 L
.372 .33291 L
.376 .33749 L
.38 .34117 L
.384 .34408 L
.388 .34635 L
.392 .34811 L
.396 .34945 L
.4 .35046 L
Mistroke
.404 .35122 L
.408 .35177 L
.412 .35218 L
.416 .35247 L
.42 .35268 L
.424 .35283 L
.428 .35294 L
.432 .35301 L
.436 .35306 L
.44 .35309 L
.444 .35312 L
.448 .35313 L
.452 .35314 L
.456 .35315 L
.46 .35315 L
.464 .35316 L
.468 .35316 L
.472 .35316 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35316 L
.54 .35316 L
.544 .35316 L
.548 .35315 L
.552 .35315 L
.556 .35314 L
.56 .35313 L
.564 .35312 L
.568 .35309 L
.572 .35306 L
.576 .35301 L
.58 .35294 L
.584 .35283 L
.588 .35268 L
.592 .35247 L
.596 .35218 L
.6 .35177 L
Mistroke
.604 .35122 L
.608 .35046 L
.612 .34945 L
.616 .34811 L
.62 .34635 L
.624 .34408 L
.628 .34117 L
.632 .33749 L
.636 .33291 L
.64 .32727 L
.644 .32044 L
.648 .31227 L
.652 .30267 L
.656 .29156 L
.66 .27894 L
.664 .26487 L
.668 .24952 L
.672 .23315 L
.676 .21615 L
.68 .19901 L
.684 .18235 L
.688 .16687 L
.692 .15335 L
.696 .14254 L
.7 .13521 L
.704 .13199 L
.708 .13336 L
.712 .13956 L
.716 .15059 L
.72 .16613 L
.724 .18557 L
.728 .20801 L
.732 .23235 L
.736 .25735 L
.74 .28174 L
.744 .3043 L
.748 .32405 L
.752 .34023 L
.756 .35245 L
.76 .36067 L
.764 .36517 L
.768 .36655 L
.772 .36555 L
.776 .36303 L
.78 .3598 L
.784 .35657 L
.788 .35385 L
.792 .35194 L
.796 .35091 L
.8 .35068 L
Mistroke
.804 .35104 L
.808 .35172 L
.812 .35249 L
.816 .35314 L
.82 .35357 L
.824 .35375 L
.828 .35372 L
.832 .35356 L
.836 .35335 L
.84 .35316 L
.844 .35304 L
.848 .353 L
.852 .35302 L
.856 .35308 L
.86 .35314 L
.864 .35319 L
.868 .35321 L
.872 .35321 L
.876 .35319 L
.88 .35317 L
.884 .35315 L
.888 .35315 L
.892 .35315 L
.896 .35315 L
.9 .35316 L
.904 .35317 L
.908 .35317 L
.912 .35317 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23176 L
.112 .23176 L
.116 .23175 L
.12 .23175 L
.124 .23176 L
.128 .23177 L
.132 .23179 L
.136 .2318 L
.14 .2318 L
.144 .23178 L
.148 .23174 L
.152 .23169 L
.156 .23164 L
.16 .23163 L
.164 .23166 L
.168 .23176 L
.172 .23192 L
.176 .23209 L
.18 .23223 L
.184 .23226 L
.188 .2321 L
.192 .23174 L
.196 .2312 L
.2 .23056 L
Mistroke
.204 .22998 L
.208 .22968 L
.212 .22987 L
.216 .23073 L
.22 .23234 L
.224 .23462 L
.228 .23734 L
.232 .24004 L
.236 .24216 L
.24 .243 L
.244 .24184 L
.248 .23806 L
.252 .23116 L
.256 .22091 L
.26 .20732 L
.264 .19075 L
.268 .17181 L
.272 .15134 L
.276 .13036 L
.28 .10992 L
.284 .09109 L
.288 .07477 L
.292 .06173 L
.296 .05248 L
.3 .04727 L
.304 .04613 L
.308 .04883 L
.312 .05499 L
.316 .06406 L
.32 .07542 L
.324 .08841 L
.328 .1024 L
.332 .11679 L
.336 .13107 L
.34 .14481 L
.344 .1577 L
.348 .1695 L
.352 .1801 L
.356 .18942 L
.36 .19749 L
.364 .20434 L
.368 .21008 L
.372 .21481 L
.376 .21866 L
.38 .22175 L
.384 .22419 L
.388 .2261 L
.392 .22757 L
.396 .2287 L
.4 .22955 L
Mistroke
.404 .23018 L
.408 .23065 L
.412 .23099 L
.416 .23124 L
.42 .23141 L
.424 .23154 L
.428 .23163 L
.432 .23169 L
.436 .23173 L
.44 .23176 L
.444 .23178 L
.448 .23179 L
.452 .2318 L
.456 .2318 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23181 L
.536 .23182 L
.54 .23182 L
.544 .23182 L
.548 .23182 L
.552 .23182 L
.556 .23183 L
.56 .23184 L
.564 .23185 L
.568 .23187 L
.572 .2319 L
.576 .23194 L
.58 .232 L
.584 .23209 L
.588 .23222 L
.592 .23239 L
.596 .23264 L
.6 .23298 L
Mistroke
.604 .23345 L
.608 .23408 L
.612 .23493 L
.616 .23606 L
.62 .23753 L
.624 .23944 L
.628 .24188 L
.632 .24497 L
.636 .24882 L
.64 .25355 L
.644 .25929 L
.648 .26614 L
.652 .2742 L
.656 .28353 L
.66 .29412 L
.664 .30593 L
.668 .31882 L
.672 .33256 L
.676 .34684 L
.68 .36122 L
.684 .37521 L
.688 .3882 L
.692 .39956 L
.696 .40863 L
.7 .41479 L
.704 .4175 L
.708 .41635 L
.712 .41115 L
.716 .40189 L
.72 .38885 L
.724 .37254 L
.728 .3537 L
.732 .33327 L
.736 .31229 L
.74 .29182 L
.744 .27288 L
.748 .25631 L
.752 .24272 L
.756 .23246 L
.76 .22557 L
.764 .22178 L
.768 .22063 L
.772 .22147 L
.776 .22358 L
.78 .22629 L
.784 .229 L
.788 .23129 L
.792 .23289 L
.796 .23375 L
.8 .23395 L
Mistroke
.804 .23365 L
.808 .23307 L
.812 .23243 L
.816 .23188 L
.82 .23152 L
.824 .23137 L
.828 .2314 L
.832 .23153 L
.836 .23171 L
.84 .23187 L
.844 .23197 L
.848 .232 L
.852 .23198 L
.856 .23194 L
.86 .23188 L
.864 .23184 L
.868 .23182 L
.872 .23183 L
.876 .23184 L
.88 .23186 L
.884 .23187 L
.888 .23188 L
.892 .23188 L
.896 .23187 L
.9 .23187 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23187 L
.924 .23187 L
.928 .23187 L
.932 .23187 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol00Woo
100000=oo`00Ool00goo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0004Ool00`00Oomoo`030004Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomo
o`001Goo000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`000goo00<007oo
Ool00Woo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000
Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomo
o`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool20003Ool20005Ool0
0`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P00
1Woo0`000Woo1@000goo0P001Woo000LOol2000JOol00`00Oomoo`05Ool2001?Ool001aoo`03001o
ogoo01Qoo`8000Qoo`8004ioo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol0
0Woo00D007ooOomoo`0000=oo`03001oogoo008000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00002Ool30002Ool00`00
Oomoo`02Ool00`00Oomoo`020003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001o
ogoo009oo`03001oogoo00Yoo`0077oo0P00@Woo00<007ooOol01Woo00<007ooOol09Goo000LOol0
0`00Oomoo`12Ool00`00Oomoo`04Ool00`00Oomoo`0VOol001aoo`8004Aoo`03001oogoo009oo`80
02Qoo`0077oo00<007ooOol0@goo0P000goo00<007ooOol09goo000;Ool20004Ool01000Oomoogoo
1@000Woo0P00AGoo0P0000=oo`000000:Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03
001oogoo04Ioo`03001oogoo02Uoo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`00
2Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=o
o`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo
0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo
000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo
00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:
Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol0
17oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:
Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo
0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000L
Ool00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo
000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000F
Ool2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol0
0Woo0`00N7oo000:Ool01000Oomoo`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007oo
Ool000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002goo0P002Goo0`000goo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00
Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool4
0003Ool2001cOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0008Ool00`00Oomoo`03Ool2001cOol000]oo`8000Yoo`8000=oo`03001oogoo079oo`00
77oo0P007Goo0P00:7oo00<007ooOol0:Goo000LOol00`00Oomoo`0LOol2000WOol00`00Ool0000Z
Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8001aoo`04001oogoo000VOol00`00Ool0000Z
Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00007Goo00@007ooOol002Ioo`03001oo`0002Yo
o`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo01]oo`04001oogoo000UOol01@00
Oomoogoo0000:Goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`8001aoo`05001oogooOol0
000TOol01@00Oomoogoo0000:Goo000:Ool01000Oomoo`0027oo00<007oo00000goo00<007ooOol0
6goo00D007ooOomoo`0002Aoo`05001oogooOol0000YOol000Yoo`04001oogoo0009Ool20003Ool2
000LOol01@00Oomoogoo00008goo00<007ooOol00Woo00<007ooOol09goo000;Ool2000;Ool01@00
Oomoogoo000077oo00<007ooOol00Woo00<007ooOol08Goo00<007ooOol00Woo00<007ooOol09goo
000LOol2000KOol00`00Oomoo`03Ool00`00Oomoo`0POol00`00Oomoo`02Ool00`00Oomoo`0WOol0
01aoo`03001oogoo01Yoo`03001oogoo00=oo`03001oogoo021oo`03001oogoo00=oo`03001oogoo
02Ioo`002goo0P0017oo00@007ooOomoo`D0009oo`8001]oo`03001oogoo00=oo`03001oogoo021o
o`03001oogoo00=oo`03001oogoo02Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00
Oomoo`0IOol00`00Oomoo`04Ool00`00Oomoo`0OOol00`00Oomoo`04Ool00`00Oomoo`0VOol000=o
o`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`04Ool00`00
Oomoo`0OOol00`00Oomoo`04Ool00`00Oomoo`0VOol000Yoo`04001oogoo000:Ool01000Oomoogoo
0P003Woo0`0017oo0P000goo00<007ooOol00goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo
0`0017oo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo00aoo`05001oogooOol00002Ool01000Oomoo`000Woo00<0
07ooOol017oo0P000goo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00D0
07ooOol007oo008000Eoo`04001oo`000002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001o
ogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2000AOol01000Oomoo`000Woo00@007ooOol000Ioo`8000=oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol01Goo00D007ooOol007oo008000Ioo`8000=oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo
0P002Goo0`000goo00<007ooOol047oo00@007ooOol0009oo`04001oogoo0006Ool00`00Ool00002
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`05001oogoo001oo`020007Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo
0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0002Ool00`00Oomoo`04Ool0
0`00Ool00002Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Ool0
000017oo00<007ooOol00P000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001o
o`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0002
Ool00`00Oomoo`03Ool200001Goo001oogoo00000Woo00@007ooOol0009oo`03001oogoo009oo`80
00=oo`03001oogoo00Aoo`800003Ool007oo00=oo`03001oogoo0080009oo`04001oogoo0002Ool0
1000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<
Ool50003Ool20002Ool00`00Oomoo`05Ool01000Oomoo`000Woo0P0017oo0P001Woo00@007ooOomo
o`D0009oo`<000Ioo`@000=oo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P006Goo
00<007ooOol02Goo00<007ooOol067oo00<007ooOol02Goo00<007ooOol097oo000LOol00`00Oomo
o`0HOol00`00Oomoo`09Ool3000FOol2000<Ool00`00Oomoo`0TOol001aoofT000aoo`0077oo00<0
07ooOol04Woo00<007ooOol00`003goo00<007ooOol04Goo00<007ooOol03Woo0`0000=oo`00Ool0
4goo00<007ooOol02Woo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`002goo0P0017oo00@007ooOomoo`D0009oo`8007=o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0009
Ool00`00Oomoo`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@0
07ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yo
o`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<0
07oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;
Ool01@00Oomoogoo0000M7oo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000L
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo01aoo`8005Aoo`002goo
0P0017oo00<007ooOol00goo0`000Woo0P007Goo0P00E7oo000:Ool01000Oomoo`002Woo00D007oo
Oomoo`0001eoo`04001oogoo001COol000=oo`D0009oo`04001oogoo0007Ool50002Ool2000LOol0
1000Oomoo`00Dgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo01]oo`04001o
ogoo001COol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2000LOol01@00Oomoogoo0000DWoo
000:Ool01000Oomoo`002Goo0P000goo00<007ooOol06goo00D007ooOomoo`00059oo`002goo0P00
2goo00@007ooOomoo`8001]oo`03001oogoo009oo`03001oogoo051oo`0077oo00<007ooOol06Woo
00<007ooOol00goo00<007ooOol0Cgoo000;Ool20004Ool01000Oomoogoo1@000Woo0P006goo00<0
07ooOol00goo00<007ooOol0Cgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo
00eoo`<000Aoo`8000Aoo`03001oogoo009oo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`80
00Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol0
00Uoo`03001oogoo009oo`8000eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0
17oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@0
07ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eo
o`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Yo
o`05001oogooOol0000BOol01000Oomoo`000Woo00@007ooOol000Ioo`8000=oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo
00@007ooOol000Ioo`8000=oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`000Woo00<007ooOol017oo00<0
07oo00000Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo
10000goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`800005Ool007ooOol00002Ool01000Oomoo`000Woo00<007ooOol0
0Woo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007oo
Ool037oo1@000goo0P000goo00<007ooOol017oo00<007oo00000goo0P0017oo0P001Woo00@007oo
Oomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00
6Goo00<007ooOol027oo00<007ooOol0C7oo000LOol00`00Oomoo`0HOol00`00Oomoo`09Ool00`00
Oomoo`0UOol2000TOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`0:
001oogooOol007oo001oo`00Ool40002Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`060003Ool00`00Oomoo`02Ool00`00Oomo
o`020002Ool30002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`03001oogoo00Yoo`00
77oo0P005goo00<007ooOol09Woo00<007ooOol02Goo00<007ooOol097oo000LOol00`00Oomoo`0o
Ool2000:Ool00`00Oomoo`0TOol001aoo`80045oo`03001oogoo00Qoo`03001oogoo02Aoo`0077oo
00<007ooOol0@Goo00<007ooOol01Woo00<007ooOol09Goo000;Ool20004Ool01000Oomoogoo1@00
0Woo0P00@Woo00<007ooOol01Woo00<007ooOol09Goo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`03001oogoo045oo`03001oogoo00Ioo`03001oogoo02Eoo`002Woo00@007ooOol000Uoo`03
001oogoo009oo`8004=oo`03001oogoo00Eoo`03001oogoo02Eoo`002Woo00@007ooOol000Yoo`05
001oogooOol00014Ool00`00Oomoo`04Ool00`00Oomoo`0VOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo0P00@goo00<007ooOol017oo00<007ooOol09Woo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo04=oo`03001oogoo00=oo`03001oogoo02Ioo`002goo0P00
2Goo0`000goo0P00A7oo00<007ooOol00goo00<007ooOol09Woo000LOol00`00Oomoo`13Ool00`00
Oomoo`02Ool00`00Oomoo`0WOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8004Aoo`03001o
ogoo009oo`03001oogoo02Moo`002Woo00@007ooOol000Yoo`05001oogooOol00016Ool01@00Oomo
ogoo0000:Goo000:Ool01000Oomoo`001goo1@000Woo0P00AGoo00D007ooOomoo`0002Uoo`002Woo
00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`14Ool01@00Oomoogoo0000:Goo000:Ool0
1000Oomoo`0027oo00<007oo00000goo0P00AWoo00<007oo0000:Woo000:Ool01000Oomoo`002Goo
0P000goo00<007ooOol0AGoo0`00:Woo000;Ool2000;Ool01000Oomoogoo0P00Agoo00<007ooOol0
:Goo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol0
0goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yo
o`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo
00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo
07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2680\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23178 L
.112 .23178 L
.116 .23178 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23178 L
.144 .23178 L
.148 .23179 L
.152 .23179 L
.156 .23178 L
.16 .23176 L
.164 .23175 L
.168 .23173 L
.172 .23172 L
.176 .23174 L
.18 .23178 L
.184 .23184 L
.188 .2319 L
.192 .23195 L
.196 .23195 L
.2 .23189 L
Mistroke
.204 .23175 L
.208 .23156 L
.212 .23133 L
.216 .23113 L
.22 .23104 L
.224 .23112 L
.228 .23143 L
.232 .232 L
.236 .2328 L
.24 .23374 L
.244 .23467 L
.248 .23539 L
.252 .23566 L
.256 .23525 L
.26 .23394 L
.264 .23159 L
.268 .2281 L
.272 .22351 L
.276 .21794 L
.28 .21158 L
.284 .20474 L
.288 .19775 L
.292 .19095 L
.296 .18471 L
.3 .17932 L
.304 .17502 L
.308 .17199 L
.312 .17031 L
.316 .16998 L
.32 .17091 L
.324 .17299 L
.328 .17603 L
.332 .17982 L
.336 .18414 L
.34 .18879 L
.344 .19357 L
.348 .19831 L
.352 .20287 L
.356 .20715 L
.36 .21107 L
.364 .21458 L
.368 .21768 L
.372 .22036 L
.376 .22264 L
.38 .22455 L
.384 .22612 L
.388 .22741 L
.392 .22844 L
.396 .22925 L
.4 .22989 L
Mistroke
.404 .23039 L
.408 .23076 L
.412 .23105 L
.416 .23126 L
.42 .23142 L
.424 .23153 L
.428 .23162 L
.432 .23168 L
.436 .23172 L
.44 .23175 L
.444 .23177 L
.448 .23178 L
.452 .23179 L
.456 .2318 L
.46 .23181 L
.464 .23181 L
.468 .23181 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23181 L
.528 .23181 L
.532 .23182 L
.536 .23182 L
.54 .23182 L
.544 .23182 L
.548 .23182 L
.552 .23183 L
.556 .23183 L
.56 .23184 L
.564 .23186 L
.568 .23188 L
.572 .23191 L
.576 .23195 L
.58 .23201 L
.584 .23209 L
.588 .23221 L
.592 .23237 L
.596 .23258 L
.6 .23287 L
Mistroke
.604 .23324 L
.608 .23374 L
.612 .23438 L
.616 .23519 L
.62 .23622 L
.624 .23751 L
.628 .23908 L
.632 .24099 L
.636 .24327 L
.64 .24594 L
.644 .24904 L
.648 .25255 L
.652 .25647 L
.656 .26074 L
.66 .2653 L
.664 .27003 L
.668 .2748 L
.672 .27945 L
.676 .28377 L
.68 .28756 L
.684 .29059 L
.688 .29267 L
.692 .29361 L
.696 .29328 L
.7 .2916 L
.704 .28858 L
.708 .28429 L
.712 .27891 L
.716 .27267 L
.72 .26588 L
.724 .25888 L
.728 .25203 L
.732 .24567 L
.736 .24009 L
.74 .23549 L
.744 .23199 L
.748 .22963 L
.752 .22832 L
.756 .2279 L
.76 .22817 L
.764 .22889 L
.768 .22982 L
.772 .23077 L
.776 .23157 L
.78 .23215 L
.784 .23247 L
.788 .23255 L
.792 .23246 L
.796 .23226 L
.8 .23203 L
Mistroke
.804 .23183 L
.808 .23169 L
.812 .23163 L
.816 .23163 L
.82 .23168 L
.824 .23174 L
.828 .2318 L
.832 .23184 L
.836 .23186 L
.84 .23185 L
.844 .23184 L
.848 .23182 L
.852 .2318 L
.856 .23179 L
.86 .23179 L
.864 .2318 L
.868 .2318 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35317 L
.112 .35317 L
.116 .35317 L
.12 .35316 L
.124 .35315 L
.128 .35315 L
.132 .35315 L
.136 .35316 L
.14 .35317 L
.144 .3532 L
.148 .35321 L
.152 .35321 L
.156 .35319 L
.16 .35313 L
.164 .35306 L
.168 .353 L
.172 .35299 L
.176 .35304 L
.18 .35317 L
.184 .35338 L
.188 .3536 L
.192 .35376 L
.196 .35378 L
.2 .35357 L
Mistroke
.204 .3531 L
.208 .3524 L
.212 .35161 L
.216 .3509 L
.22 .35056 L
.224 .35084 L
.228 .35194 L
.232 .35396 L
.236 .35679 L
.24 .36012 L
.244 .36343 L
.248 .36598 L
.252 .36695 L
.256 .3655 L
.26 .36086 L
.264 .35248 L
.268 .34007 L
.272 .32371 L
.276 .30381 L
.28 .28112 L
.284 .25668 L
.288 .23167 L
.292 .20738 L
.296 .18504 L
.3 .16574 L
.304 .15035 L
.308 .13948 L
.312 .13343 L
.316 .13219 L
.32 .13552 L
.324 .14292 L
.328 .15376 L
.332 .1673 L
.336 .18275 L
.34 .19938 L
.344 .21646 L
.348 .23341 L
.352 .24972 L
.356 .26501 L
.36 .27902 L
.364 .2916 L
.368 .30267 L
.372 .31224 L
.376 .32039 L
.38 .32722 L
.384 .33285 L
.388 .33743 L
.392 .34111 L
.396 .34402 L
.4 .3463 L
Mistroke
.404 .34807 L
.408 .34941 L
.412 .35043 L
.416 .35119 L
.42 .35175 L
.424 .35216 L
.428 .35246 L
.432 .35267 L
.436 .35283 L
.44 .35293 L
.444 .35301 L
.448 .35306 L
.452 .35309 L
.456 .35312 L
.46 .35313 L
.464 .35314 L
.468 .35315 L
.472 .35315 L
.476 .35316 L
.48 .35316 L
.484 .35316 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35316 L
.528 .35316 L
.532 .35316 L
.536 .35315 L
.54 .35315 L
.544 .35314 L
.548 .35313 L
.552 .35312 L
.556 .35309 L
.56 .35306 L
.564 .35301 L
.568 .35293 L
.572 .35283 L
.576 .35268 L
.58 .35246 L
.584 .35216 L
.588 .35175 L
.592 .35119 L
.596 .35043 L
.6 .34941 L
Mistroke
.604 .34807 L
.608 .3463 L
.612 .34402 L
.616 .34111 L
.62 .33743 L
.624 .33285 L
.628 .32722 L
.632 .32039 L
.636 .31225 L
.64 .30267 L
.644 .2916 L
.648 .27902 L
.652 .26501 L
.656 .24972 L
.66 .23341 L
.664 .21647 L
.668 .19938 L
.672 .18276 L
.676 .1673 L
.68 .15377 L
.684 .14293 L
.688 .13552 L
.692 .1322 L
.696 .13343 L
.7 .13949 L
.704 .15035 L
.708 .16574 L
.712 .18504 L
.716 .20738 L
.72 .23167 L
.724 .25668 L
.728 .28112 L
.732 .30381 L
.736 .32371 L
.74 .34007 L
.744 .35248 L
.748 .36086 L
.752 .3655 L
.756 .36695 L
.76 .36598 L
.764 .36343 L
.768 .36012 L
.772 .35679 L
.776 .35396 L
.78 .35194 L
.784 .35084 L
.788 .35056 L
.792 .3509 L
.796 .35161 L
.8 .3524 L
Mistroke
.804 .3531 L
.808 .35357 L
.812 .35378 L
.816 .35376 L
.82 .3536 L
.824 .35338 L
.828 .35317 L
.832 .35304 L
.836 .35299 L
.84 .353 L
.844 .35306 L
.848 .35313 L
.852 .35319 L
.856 .35321 L
.86 .35321 L
.864 .3532 L
.868 .35317 L
.872 .35316 L
.876 .35315 L
.88 .35315 L
.884 .35315 L
.888 .35316 L
.892 .35317 L
.896 .35317 L
.9 .35317 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23176 L
.124 .23175 L
.128 .23175 L
.132 .23175 L
.136 .23176 L
.14 .23177 L
.144 .23179 L
.148 .23181 L
.152 .23181 L
.156 .23178 L
.16 .23174 L
.164 .23168 L
.168 .23163 L
.172 .23162 L
.176 .23166 L
.18 .23177 L
.184 .23194 L
.188 .23213 L
.192 .23227 L
.196 .23228 L
.2 .23211 L
Mistroke
.204 .23171 L
.208 .23113 L
.212 .23046 L
.216 .22987 L
.22 .22958 L
.224 .22981 L
.228 .23074 L
.232 .23243 L
.236 .23481 L
.24 .23761 L
.244 .24038 L
.248 .24252 L
.252 .24334 L
.256 .24212 L
.26 .23823 L
.264 .23119 L
.268 .22078 L
.272 .20704 L
.276 .19033 L
.28 .17129 L
.284 .15077 L
.288 .12978 L
.292 .1094 L
.296 .09064 L
.3 .07444 L
.304 .06153 L
.308 .05241 L
.312 .04733 L
.316 .0463 L
.32 .0491 L
.324 .05531 L
.328 .06441 L
.332 .07578 L
.336 .08876 L
.34 .10271 L
.344 .11706 L
.348 .13128 L
.352 .14497 L
.356 .15781 L
.36 .16957 L
.364 .18013 L
.368 .18943 L
.372 .19746 L
.376 .2043 L
.38 .21003 L
.384 .21476 L
.388 .21861 L
.392 .2217 L
.396 .22414 L
.4 .22606 L
Mistroke
.404 .22754 L
.408 .22867 L
.412 .22952 L
.416 .23016 L
.42 .23063 L
.424 .23098 L
.428 .23123 L
.432 .2314 L
.436 .23153 L
.44 .23162 L
.444 .23168 L
.448 .23173 L
.452 .23176 L
.456 .23178 L
.46 .23179 L
.464 .2318 L
.468 .2318 L
.472 .23181 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23181 L
.524 .23182 L
.528 .23182 L
.532 .23182 L
.536 .23182 L
.54 .23182 L
.544 .23183 L
.548 .23184 L
.552 .23185 L
.556 .23187 L
.56 .2319 L
.564 .23194 L
.568 .23201 L
.572 .2321 L
.576 .23222 L
.58 .2324 L
.584 .23265 L
.588 .233 L
.592 .23347 L
.596 .23411 L
.6 .23496 L
Mistroke
.604 .23609 L
.608 .23757 L
.612 .23949 L
.616 .24193 L
.62 .24502 L
.624 .24887 L
.628 .25359 L
.632 .25932 L
.636 .26616 L
.64 .2742 L
.644 .2835 L
.648 .29405 L
.652 .30582 L
.656 .31865 L
.66 .33234 L
.664 .34657 L
.668 .36091 L
.672 .37487 L
.676 .38785 L
.68 .39921 L
.684 .40831 L
.688 .41453 L
.692 .41732 L
.696 .41629 L
.7 .41121 L
.704 .40209 L
.708 .38918 L
.712 .37298 L
.716 .35423 L
.72 .33384 L
.724 .31285 L
.728 .29233 L
.732 .27329 L
.736 .25659 L
.74 .24285 L
.744 .23244 L
.748 .2254 L
.752 .22151 L
.756 .22029 L
.76 .22111 L
.764 .22325 L
.768 .22602 L
.772 .22882 L
.776 .2312 L
.78 .23289 L
.784 .23382 L
.788 .23405 L
.792 .23376 L
.796 .23317 L
.8 .2325 L
Mistroke
.804 .23192 L
.808 .23152 L
.812 .23135 L
.816 .23136 L
.82 .2315 L
.824 .23168 L
.828 .23185 L
.832 .23197 L
.836 .23201 L
.84 .232 L
.844 .23195 L
.848 .23189 L
.852 .23185 L
.856 .23182 L
.86 .23182 L
.864 .23184 L
.868 .23185 L
.872 .23187 L
.876 .23188 L
.88 .23188 L
.884 .23187 L
.888 .23187 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23187 L
.916 .23187 L
.92 .23187 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol017oo
100017oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00aoo`@000=oo`04001oogoo0005Ool00`00Oomoo`020004Ool01000Oomoo`000Woo
00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;
Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0017oo00@007ooOomoo`<000=o
o`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo
00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P001Goo00<007ooOol00Woo0`000goo
0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D0
00=oo`8000Ioo`0077oo0P006goo00<007ooOol01Goo0P00CWoo000LOol00`00Oomoo`0IOol20008
Ool2001=Ool001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogoo
Ool00003Ool01000Oomoogoo0`0000=oo`00Ool00Woo00D007ooOomoo`0000Aoo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00@007ooOomoo`D000=oo`03001oogoo009oo`<00003Ool007oo
009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo
000LOol20010Ool20007Ool2000XOol001aoo`03001oogoo045oo`03001oogoo00Aoo`03001oogoo
02Moo`0077oo0P00@Woo0P0017oo0P00:Goo000LOol00`00Oomoo`12Ool20003Ool00`00Oomoo`0X
Ool000]oo`8000Aoo`04001oogooOol50002Ool20014Ool200000goo001oo`0ZOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00<007ooOol0A7oo0P00;7oo000:Ool01000Oomoo`002Goo00<0
07ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`00
07Aoo`002Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo
0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04
001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001ao
o`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00
Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool0
0`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007oo
Ool000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2
001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009
Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomo
o`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000G
Ool00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;
Ool20004Ool00`00Oomoo`02Ool3001hOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000Mgoo
0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol0
00Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000;Ool20009Ool3
0003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00
Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`@000=oo`8007=oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`03
001oogoo079oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`8007=oo`002goo0P002Woo0P00
0goo00<007ooOol0LWoo000LOol2000NOol2000UOol2000/Ool001aoo`03001oogoo01eoo`03001o
o`0002Aoo`03001oo`0002]oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P007Woo00<007oo
00008goo00@007ooOol002]oo`002Woo00@007ooOol000Yoo`05001oogooOol0000OOol00`00Ool0
000SOol01000Oomoo`00:goo0003Ool50002Ool01000Oomoo`001goo1@000Woo00<007ooOol077oo
00D007ooOomoo`00029oo`04001oogoo000[Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo
0P007Goo00D007ooOomoo`00029oo`04001oogoo000[Ool000Yoo`04001oogoo0008Ool00`00Ool0
0003Ool00`00Oomoo`0LOol01@00Oomoogoo00008Woo00D007ooOomoo`0002Yoo`002Woo00@007oo
Ool000Uoo`8000=oo`8001eoo`05001oogooOol0000QOol00`00Oomoo`02Ool00`00Oomoo`0XOol0
00]oo`8000]oo`05001oogooOol0000MOol00`00Oomoo`02Ool00`00Oomoo`0OOol00`00Oomoo`02
Ool00`00Oomoo`0XOol001aoo`8001aoo`03001oogoo00=oo`03001oogoo01ioo`03001oogoo009o
o`03001oogoo02Qoo`0077oo00<007ooOol06goo00<007ooOol00goo00<007ooOol07Woo00<007oo
Ool00goo00<007ooOol09goo000;Ool20004Ool01000Oomoogoo1@000Woo0P0077oo00<007ooOol0
0goo00<007ooOol07Goo00<007ooOol017oo00<007ooOol09goo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`03001oogoo01]oo`03001oogoo00Aoo`03001oogoo01aoo`03001oogoo00Aoo`03
001oogoo02Moo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo01]oo`03
001oogoo00Aoo`03001oogoo01aoo`03001oogoo00Aoo`03001oogoo02Moo`002Woo00@007ooOol0
00Yoo`04001oogooOol2000>Ool30004Ool20005Ool01000Oomoogoo10000goo0P0017oo0P001Goo
0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`05001oogooOol00002Ool01000
Oomoo`000goo00<007ooOol00goo00<007oo00000Woo00@007ooOol0009oo`04001oogoo0005Ool0
1@00Oomoogoo00000goo00<007ooOol00P0000=oo`00Ool017oo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04001oogoo0002Ool01@00Oomo
ogoo00001Goo00<007oo00000Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool0
0`00Oomoo`0200000goo001oo`04Ool20004Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Uoo`<000=oo`03001oogoo011o
o`04001oogoo0002Ool01@00Oomoogoo00001Goo00H007ooOol007oo0002Ool01000Oomoo`000Woo
00<007ooOol00goo00<007ooOol01Goo00<007ooOol00P0000=oo`00Ool01Goo0P000goo00@007oo
Ool0009oo`04001oogoo0007Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000L
Ool2000=Ool40003Ool01000Oomoo`000goo00<007ooOol00goo00H007ooOol007oo0002Ool01000
Oomoo`000Woo00<007ooOol00goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Ool007oo
00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo
0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0003Ool00`00Oomoo`02Ool2
0003Ool20002Ool01000Oomoo`000Woo00<007ooOol00Woo0P000goo00<007ooOol017oo00@007oo
Ool000Aoo`05001oo`00Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol0
07oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P000goo00<007ooOol0
17oo00H007ooOomoo`00Ool20004Ool20006Ool01000Oomoogoo1@0000=oo`0000000P001Woo0`00
17oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000JOol00`00Oomoo`09Ool00`00
Oomoo`0EOol2000:Ool00`00Oomoo`0VOol001aoo`03001oogoo01Uoo`03001oogoo00Yoo`8001Ao
o`8000aoo`03001oogoo02Eoo`0077ooJ@0037oo000LOol00`00Oomoo`0BOol01000Oomoogoo0`00
3Woo00<007ooOol04Goo00<007ooOol03Goo0`000Woo00<007ooOol04Woo00<007ooOol02Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03
001oogoo079oo`002goo0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001c
Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
00]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000
Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:
Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01@00Oomoogoo0000M7oo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo01eoo`8005=oo`002goo0P0017oo00<007ooOol00goo
0`000Woo0P007Woo0`00DWoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0001moo`03001oo`00
059oo`000goo1@000Woo00@007ooOol000Moo`D0009oo`8001eoo`05001oogooOol0001AOol000Yo
o`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol077oo00D007ooOomoo`00055oo`002Woo
00@007ooOol000Qoo`03001oo`0000=oo`8001eoo`05001oogooOol0001AOol000Yoo`04001oogoo
0009Ool20003Ool00`00Oomoo`0LOol01@00Oomoogoo0000DGoo000;Ool2000;Ool01000Oomoogoo
0P0077oo00<007ooOol00Woo00<007ooOol0Cgoo000LOol00`00Oomoo`0KOol00`00Oomoo`03Ool0
0`00Oomoo`1>Ool000]oo`8000Aoo`04001oogooOol50002Ool2000LOol00`00Oomoo`03Ool00`00
Oomoo`1>Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol03Goo0`0017oo0P00
1Goo00@007ooOomoo`@000=oo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Ao
o`8000Eoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009o
o`8000eoo`05001oogooOol00002Ool01000Oomoo`0017oo00<007ooOol00Woo00<007oo00000Woo
00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001o
ogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`00
0goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Yoo`05001oogooOol0000B
Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo00<007oo00000Woo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04001oogoo0002
Ool01@00Oomoogoo00001Goo00<007oo00000Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0003Ool00`00
Oomoo`03Ool01P00Oomoo`00Ool0009oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoogoo
10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Ao
o`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P003Goo00<0
07ooOol017oo00@007ooOol000=oo`03001oogoo009oo`80009oo`03001oo`00009oo`04001oogoo
0002Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`00
1Goo000LOol00`00Oomoo`0<Ool50003Ool20004Ool00`00Oomoo`03Ool01P00Oomoogoo001oo`80
00Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003
Ool20006Ool001aoo`8001Yoo`03001oogoo00Qoo`03001oogoo04]oo`0077oo00<007ooOol06Goo
00<007ooOol02Goo0P0097oo0P009Goo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00
Oomoo`02Ool01@00Oomoogoo00000Woo0P000Woo0P0000Aoo`00Ool000=oo`05001oogooOol00004
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oo`0000<0009oo`05001oogooOol0
0004Ool01P00Ool007oo001oo`<000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00<0
07ooOol02Woo000LOol2000HOol2000TOol2000;Ool00`00Oomoo`0UOol001aoo`03001oogoo03io
o`8000Uoo`03001oogoo02Ioo`0077oo0P00@7oo00<007ooOol01goo00<007ooOol09Woo000LOol0
0`00Oomoo`0oOol00`00Oomoo`07Ool00`00Oomoo`0VOol000]oo`8000Aoo`04001oogooOol50002
Ool20011Ool00`00Oomoo`06Ool00`00Oomoo`0VOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00<007ooOol0@7oo00<007ooOol01Goo00<007ooOol09goo000:Ool01000Oomoo`002Goo00<0
07ooOol00Woo0P00@Woo00<007ooOol017oo00<007ooOol09goo000:Ool01000Oomoo`002Woo00D0
07ooOomoo`0004=oo`03001oogoo00Aoo`03001oogoo02Moo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool20012Ool00`00Oomoo`04Ool00`00Oomoo`0WOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0@Goo00<007ooOol017oo00<007ooOol09goo000;Ool20009
Ool30003Ool20013Ool00`00Oomoo`03Ool00`00Oomoo`0WOol001aoo`03001oogoo049oo`03001o
ogoo009oo`03001oogoo02Qoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00@goo00<007oo
Ool00Woo00<007ooOol0:7oo000:Ool01000Oomoo`002Woo00D007ooOomoo`0004Eoo`05001oogoo
Ool0000ZOol000Yoo`04001oogoo0007Ool50002Ool20014Ool01@00Oomoogoo0000:Woo000:Ool0
1000Oomoo`001goo00@007ooOol000=oo`03001oogoo04=oo`04001oogoo000[Ool000Yoo`04001o
ogoo0008Ool00`00Ool00003Ool20014Ool01000Oomoo`00:goo000:Ool01000Oomoo`002Goo0P00
0goo00<007ooOol0A7oo00<007oo0000:goo000;Ool2000;Ool01000Oomoogoo0P00AWoo00<007oo
Ool0:Woo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007oo
Ool00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`00
2goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol0
00Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079o
o`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`00
5goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001o
ogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2720\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23178 L
.12 .23178 L
.124 .23178 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23178 L
.156 .23179 L
.16 .23179 L
.164 .23179 L
.168 .23178 L
.172 .23176 L
.176 .23174 L
.18 .23172 L
.184 .23172 L
.188 .23174 L
.192 .23178 L
.196 .23185 L
.2 .23191 L
Mistroke
.204 .23196 L
.208 .23196 L
.212 .23189 L
.216 .23174 L
.22 .23153 L
.224 .2313 L
.228 .23109 L
.232 .231 L
.236 .2311 L
.24 .23144 L
.244 .23204 L
.248 .23287 L
.252 .23383 L
.256 .23478 L
.26 .23551 L
.264 .23577 L
.268 .23534 L
.272 .23399 L
.276 .23159 L
.28 .22806 L
.284 .22342 L
.288 .2178 L
.292 .21141 L
.296 .20455 L
.3 .19756 L
.304 .19078 L
.308 .18456 L
.312 .17921 L
.316 .17496 L
.32 .17198 L
.324 .17033 L
.328 .17004 L
.332 .171 L
.336 .1731 L
.34 .17614 L
.344 .17994 L
.348 .18426 L
.352 .18889 L
.356 .19366 L
.36 .19838 L
.364 .20293 L
.368 .20719 L
.372 .21109 L
.376 .2146 L
.38 .21768 L
.384 .22035 L
.388 .22263 L
.392 .22453 L
.396 .22611 L
.4 .22739 L
Mistroke
.404 .22842 L
.408 .22924 L
.412 .22988 L
.416 .23037 L
.42 .23075 L
.424 .23104 L
.428 .23125 L
.432 .23141 L
.436 .23153 L
.44 .23161 L
.444 .23167 L
.448 .23172 L
.452 .23175 L
.456 .23177 L
.46 .23178 L
.464 .23179 L
.468 .2318 L
.472 .2318 L
.476 .23181 L
.48 .23181 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23181 L
.516 .23181 L
.52 .23182 L
.524 .23182 L
.528 .23182 L
.532 .23182 L
.536 .23182 L
.54 .23183 L
.544 .23183 L
.548 .23184 L
.552 .23186 L
.556 .23188 L
.56 .23191 L
.564 .23195 L
.568 .23201 L
.572 .2321 L
.576 .23222 L
.58 .23237 L
.584 .23259 L
.588 .23288 L
.592 .23326 L
.596 .23375 L
.6 .23439 L
Mistroke
.604 .23521 L
.608 .23624 L
.612 .23752 L
.616 .2391 L
.62 .241 L
.624 .24327 L
.628 .24594 L
.632 .24903 L
.636 .25253 L
.64 .25643 L
.644 .26069 L
.648 .26522 L
.652 .26994 L
.656 .2747 L
.66 .27934 L
.664 .28365 L
.668 .28744 L
.672 .29049 L
.676 .29258 L
.68 .29355 L
.684 .29326 L
.688 .29162 L
.692 .28864 L
.696 .2844 L
.7 .27905 L
.704 .27284 L
.708 .26607 L
.712 .25907 L
.716 .25221 L
.72 .24581 L
.724 .24018 L
.728 .23553 L
.732 .23199 L
.736 .22958 L
.74 .22823 L
.744 .22779 L
.748 .22805 L
.752 .22877 L
.756 .22973 L
.76 .2307 L
.764 .23154 L
.768 .23215 L
.772 .23249 L
.776 .23259 L
.78 .2325 L
.784 .23229 L
.788 .23206 L
.792 .23184 L
.796 .23169 L
.8 .23162 L
Mistroke
.804 .23162 L
.808 .23167 L
.812 .23173 L
.816 .2318 L
.82 .23184 L
.824 .23186 L
.828 .23186 L
.832 .23184 L
.836 .23182 L
.84 .2318 L
.844 .23179 L
.848 .23179 L
.852 .2318 L
.856 .2318 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35317 L
.12 .35317 L
.124 .35317 L
.128 .35317 L
.132 .35316 L
.136 .35315 L
.14 .35314 L
.144 .35315 L
.148 .35316 L
.152 .35318 L
.156 .3532 L
.16 .35322 L
.164 .35321 L
.168 .35318 L
.172 .35312 L
.176 .35305 L
.18 .35299 L
.184 .35298 L
.188 .35304 L
.192 .35319 L
.196 .35341 L
.2 .35365 L
Mistroke
.204 .35381 L
.208 .35381 L
.212 .35357 L
.216 .35306 L
.22 .35232 L
.224 .35148 L
.228 .35077 L
.232 .35044 L
.236 .35076 L
.24 .35195 L
.244 .35407 L
.248 .35702 L
.252 .36046 L
.256 .36383 L
.26 .36641 L
.264 .36736 L
.268 .36582 L
.272 .36105 L
.276 .3525 L
.28 .33991 L
.284 .32336 L
.288 .30331 L
.292 .28051 L
.296 .256 L
.3 .23099 L
.304 .20676 L
.308 .18452 L
.312 .16535 L
.316 .15012 L
.32 .13941 L
.324 .13351 L
.328 .13241 L
.332 .13583 L
.336 .1433 L
.34 .15418 L
.344 .16772 L
.348 .18316 L
.352 .19974 L
.356 .21678 L
.36 .23366 L
.364 .24991 L
.368 .26514 L
.372 .2791 L
.376 .29163 L
.38 .30267 L
.384 .31222 L
.388 .32035 L
.392 .32716 L
.396 .33279 L
.4 .33737 L
Mistroke
.404 .34105 L
.408 .34397 L
.412 .34625 L
.416 .34802 L
.42 .34938 L
.424 .3504 L
.428 .35117 L
.432 .35173 L
.436 .35215 L
.44 .35245 L
.444 .35267 L
.448 .35282 L
.452 .35293 L
.456 .353 L
.46 .35305 L
.464 .35309 L
.468 .35311 L
.472 .35313 L
.476 .35314 L
.48 .35315 L
.484 .35315 L
.488 .35316 L
.492 .35316 L
.496 .35316 L
.5 .35316 L
.504 .35316 L
.508 .35316 L
.512 .35316 L
.516 .35316 L
.52 .35316 L
.524 .35315 L
.528 .35315 L
.532 .35314 L
.536 .35313 L
.54 .35311 L
.544 .35309 L
.548 .35305 L
.552 .353 L
.556 .35293 L
.56 .35282 L
.564 .35267 L
.568 .35245 L
.572 .35215 L
.576 .35173 L
.58 .35117 L
.584 .3504 L
.588 .34938 L
.592 .34802 L
.596 .34625 L
.6 .34397 L
Mistroke
.604 .34105 L
.608 .33737 L
.612 .33279 L
.616 .32716 L
.62 .32035 L
.624 .31222 L
.628 .30267 L
.632 .29164 L
.636 .27911 L
.64 .26515 L
.644 .24991 L
.648 .23366 L
.652 .21678 L
.656 .19974 L
.66 .18316 L
.664 .16772 L
.668 .15418 L
.672 .14331 L
.676 .13584 L
.68 .13241 L
.684 .13351 L
.688 .13942 L
.692 .15013 L
.696 .16535 L
.7 .18452 L
.704 .20676 L
.708 .231 L
.712 .256 L
.716 .28051 L
.72 .30331 L
.724 .32336 L
.728 .33991 L
.732 .3525 L
.736 .36105 L
.74 .36582 L
.744 .36736 L
.748 .36641 L
.752 .36383 L
.756 .36046 L
.76 .35702 L
.764 .35407 L
.768 .35195 L
.772 .35076 L
.776 .35044 L
.78 .35077 L
.784 .35148 L
.788 .35232 L
.792 .35306 L
.796 .35357 L
.8 .35381 L
Mistroke
.804 .35381 L
.808 .35365 L
.812 .35341 L
.816 .35319 L
.82 .35304 L
.824 .35298 L
.828 .35299 L
.832 .35305 L
.836 .35312 L
.84 .35318 L
.844 .35321 L
.848 .35322 L
.852 .3532 L
.856 .35318 L
.86 .35316 L
.864 .35315 L
.868 .35314 L
.872 .35315 L
.876 .35316 L
.88 .35317 L
.884 .35317 L
.888 .35317 L
.892 .35317 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23176 L
.136 .23175 L
.14 .23175 L
.144 .23175 L
.148 .23176 L
.152 .23178 L
.156 .2318 L
.16 .23181 L
.164 .23181 L
.168 .23178 L
.172 .23173 L
.176 .23167 L
.18 .23162 L
.184 .23161 L
.188 .23166 L
.192 .23179 L
.196 .23197 L
.2 .23217 L
Mistroke
.204 .23231 L
.208 .23231 L
.212 .2321 L
.216 .23167 L
.22 .23105 L
.224 .23035 L
.228 .22975 L
.232 .22947 L
.236 .22975 L
.24 .23075 L
.244 .23253 L
.248 .235 L
.252 .23788 L
.256 .24072 L
.26 .24288 L
.264 .24368 L
.268 .24239 L
.272 .23839 L
.276 .23121 L
.28 .22064 L
.284 .20675 L
.288 .18991 L
.292 .17078 L
.296 .15021 L
.3 .12922 L
.304 .10887 L
.308 .09021 L
.312 .07412 L
.316 .06134 L
.32 .05235 L
.324 .0474 L
.328 .04648 L
.332 .04936 L
.336 .05563 L
.34 .06476 L
.344 .07613 L
.348 .0891 L
.352 .10302 L
.356 .11732 L
.36 .13149 L
.364 .14513 L
.368 .15792 L
.372 .16964 L
.376 .18016 L
.38 .18943 L
.384 .19744 L
.388 .20427 L
.392 .20999 L
.396 .21471 L
.4 .21856 L
Mistroke
.404 .22165 L
.408 .2241 L
.412 .22601 L
.416 .2275 L
.42 .22864 L
.424 .2295 L
.428 .23014 L
.432 .23061 L
.436 .23096 L
.44 .23122 L
.444 .2314 L
.448 .23153 L
.452 .23162 L
.456 .23168 L
.46 .23172 L
.464 .23175 L
.468 .23177 L
.472 .23179 L
.476 .2318 L
.48 .2318 L
.484 .23181 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23182 L
.516 .23182 L
.52 .23182 L
.524 .23182 L
.528 .23182 L
.532 .23183 L
.536 .23184 L
.54 .23185 L
.544 .23187 L
.548 .2319 L
.552 .23195 L
.556 .23201 L
.56 .2321 L
.564 .23223 L
.568 .23241 L
.572 .23266 L
.576 .23301 L
.58 .23349 L
.584 .23413 L
.588 .23499 L
.592 .23613 L
.596 .23761 L
.6 .23953 L
Mistroke
.604 .24198 L
.608 .24507 L
.612 .24892 L
.616 .25364 L
.62 .25936 L
.624 .26618 L
.628 .2742 L
.632 .28346 L
.636 .29398 L
.64 .3057 L
.644 .31849 L
.648 .33213 L
.652 .34631 L
.656 .36061 L
.66 .37453 L
.664 .38749 L
.668 .39886 L
.672 .40799 L
.676 .41427 L
.68 .41715 L
.684 .41622 L
.688 .41127 L
.692 .40228 L
.696 .3895 L
.7 .37342 L
.704 .35475 L
.708 .33441 L
.712 .31342 L
.716 .29285 L
.72 .27371 L
.724 .25688 L
.728 .24299 L
.732 .23242 L
.736 .22524 L
.74 .22124 L
.744 .21995 L
.748 .22074 L
.752 .22291 L
.756 .22574 L
.76 .22863 L
.764 .2311 L
.768 .23288 L
.772 .23388 L
.776 .23415 L
.78 .23388 L
.784 .23328 L
.788 .23258 L
.792 .23195 L
.796 .23152 L
.8 .23132 L
Mistroke
.804 .23132 L
.808 .23146 L
.812 .23165 L
.816 .23184 L
.82 .23197 L
.824 .23202 L
.828 .23201 L
.832 .23196 L
.836 .2319 L
.84 .23185 L
.844 .23182 L
.848 .23182 L
.852 .23183 L
.856 .23185 L
.86 .23187 L
.864 .23188 L
.868 .23188 L
.872 .23188 L
.876 .23187 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23187 L
.904 .23187 L
.908 .23187 L
.912 .23187 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01Goo
0`0017oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00aoo`@000=oo`04001oogoo0006Ool00`00Oomoo`020003Ool01000Oomoo`000Woo
00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;
Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`001Woo00H007oo000007oo0002
Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Io
o`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Ioo`06001oogooOol007oo0P00
0Woo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009o
o`D000=oo`8000Ioo`0077oo0P0077oo00<007ooOol01Goo0P00CGoo000LOol00`00Oomoo`0KOol0
0`00Oomoo`06Ool2001<Ool001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009o
o`05001oogooOol00003Ool01P00Oomoogoo001oo`<000=oo`05001oogooOol00004Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`04001oogooOol50003Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomo
o`0:Ool001aoo`8003moo`8000Moo`8002Uoo`0077oo00<007ooOol0?goo0P001Woo00<007ooOol0
:7oo000LOol20011Ool20004Ool00`00Oomoo`0YOol001aoo`03001oogoo045oo`03001oogoo009o
o`03001oogoo02Uoo`002goo0P0017oo00@007ooOomoo`D0009oo`8004=oo`@002aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`13Ool2000]Ool000Yoo`04001oogoo0009Ool0
0`00Oomoo`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000;
Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo
0000M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007oo
Ool000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo
00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00@007ooOomoo`8007=oo`00
77oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03
001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Ao
o`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000
Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`80
00Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001o
ogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol0
01Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
00]oo`8000Aoo`03001oogoo009oo`<007Qoo`002Woo00@007ooOol000Moo`05001oogooOol0001g
Ool000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000]oo`8000Uo
o`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03
001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo10000goo0P00Lgoo000:Ool01000Oomoo`001goo00<007ooOol017oo
00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007ooOol00goo0P00Lgoo000;Ool2000:Ool2
0003Ool00`00Oomoo`1bOol001aoo`80021oo`80029oo`8002eoo`0077oo00<007ooOol07Woo00<0
07oo00008Woo0P00;Goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000OOol00`00Ool0000Q
Ool01000Oomoo`00;7oo000:Ool01000Oomoo`002Woo00D007ooOomoo`0001moo`04001oogoo000Q
Ool01000Oomoo`00;7oo0003Ool50002Ool01000Oomoo`001goo1@000Woo00<007ooOol07Goo00D0
07ooOomoo`00021oo`04001oogoo000/Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P00
7Woo00D007ooOomoo`0001moo`03001oogoo009oo`03001oogoo02Uoo`002Woo00@007ooOol000Qo
o`03001oo`0000=oo`03001oogoo01eoo`05001oogooOol0000OOol00`00Oomoo`02Ool00`00Oomo
o`0YOol000Yoo`04001oogoo0009Ool20003Ool2000NOol00`00Oomoo`02Ool00`00Oomoo`0LOol0
0`00Oomoo`02Ool00`00Oomoo`0YOol000]oo`8000]oo`05001oogooOol0000OOol00`00Oomoo`02
Ool00`00Oomoo`0LOol00`00Oomoo`02Ool00`00Oomoo`0YOol001aoo`8001ioo`03001oogoo009o
o`03001oogoo01aoo`03001oogoo009oo`03001oogoo02Uoo`0077oo00<007ooOol077oo00<007oo
Ool00goo00<007ooOol077oo00<007ooOol00Woo00<007ooOol0:Goo000;Ool20004Ool01000Oomo
ogoo1@000Woo0P007Goo00<007ooOol00goo00<007ooOol06goo00<007ooOol00goo00<007ooOol0
:Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo01aoo`03001oogoo00Aoo`03
001oogoo01Yoo`03001oogoo00Aoo`03001oogoo02Qoo`000goo1@000Woo00@007ooOol000Uoo`03
001oogoo009oo`03001oogoo01aoo`03001oogoo00Aoo`03001oogoo01Yoo`03001oogoo00Aoo`03
001oogoo02Qoo`002Woo00@007ooOol000Yoo`04001oogooOol2000>Ool30004Ool20006Ool00`00
Oomoo`03000017oo001oogoo0P0017oo0P001Goo0`000goo0`000goo0`001Goo1@000goo0P0017oo
0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo00aoo`05001oogooOol00002Ool01000Oomoo`0017oo00<007ooOol00Woo00@007ooOomo
o`80009oo`04001oogoo0002Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00@007ooOol0009o
o`03001oogoo009oo`80009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00goo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`80015oo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000
Oomoogoo0P000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`02Ool00`00Ool00004Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Uoo`<000=oo`03001oogoo011oo`04
001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoogoo0P000Woo00@007ooOol0
009oo`03001oogoo00=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Ool0
0003Ool01000Oomoo`000Woo00@007ooOol000Moo`03001oogoo00Aoo`04001oogoo0002Ool00`00
Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0004Ool00`00Oomoo`02Ool01000Oomoogoo
0P000Woo00@007ooOol0009oo`03001oogoo00=oo`04001oogooOol40002Ool20002Ool00`00Oomo
o`02Ool20002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo009oo`06001oogooOol0
07oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol0
00Aoo`04001oogooOol20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo
00=oo`80009oo`03001oogoo009oo`80009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007oo
Ool00Woo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003
Ool20005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool30004Ool20006Ool01000Oomoogoo1P000Woo
0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000LOol00`00Oomo
o`08Ool2000DOol00`00Oomoo`09Ool00`00Oomoo`0WOol001aoo`03001oogoo01Yoo`03001oogoo
00Yoo`80015oo`<000]oo`03001oogoo02Moo`0077ooJ@0037oo000LOol00`00Oomoo`0BOol00`00
Oomoo`02Ool3000=Ool00`00Oomoo`0AOol00`00Oomoo`0;Ool30004Ool00`00Oomoo`0BOol00`00
Oomoo`0:Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P00Lgoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`03001oogoo079oo`002Woo00@007ooOol000Uoo`03001o
ogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`00
2Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007oo
Ool000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003
Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`05001o
ogooOol0001dOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol07goo00<007ooOol0D7oo000;Ool2
0004Ool00`00Oomoo`03Ool30002Ool2000OOol00`00Ool0001AOol000Yoo`04001oogoo000:Ool0
1@00Oomoogoo000087oo00<007oo0000DGoo0003Ool50002Ool01000Oomoo`001goo1@000Woo0P00
7Woo00D007ooOomoo`00051oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0M
Ool01@00Oomoogoo0000D7oo000:Ool01000Oomoo`0027oo00<007oo00000goo0P007Woo00D007oo
Oomoo`00051oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo01eoo`03001oogoo009oo`03
001oogoo04eoo`002goo0P002goo00@007ooOomoo`8001ioo`03001oogoo009oo`03001oogoo04eo
o`0077oo00<007ooOol07Goo00<007ooOol00Woo00<007ooOol0CGoo000;Ool20004Ool01000Oomo
ogoo1@000Woo0P007Goo00<007ooOol00goo00<007ooOol0CGoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`03001oogoo00eoo`<000Aoo`8000Ioo`03001oogoo00@000=oo`8000Aoo`8000Eo
o`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`000goo
1@000Woo00@007ooOol000Uoo`03001oogoo009oo`8000eoo`05001oogooOol00002Ool01000Oomo
o`001Goo00D007ooOomoo`00009oo`03001oo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool0
1@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomo
o`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=o
o`002Woo00@007ooOol000Yoo`05001oogooOol0000BOol01000Oomoo`000Woo00<007ooOol00goo
00D007ooOomoo`00009oo`03001oo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`80015oo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool01000Oomoogoo0P000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eo
o`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol037oo10000goo00@007ooOol000Aoo`03001oogoo009oo`04001o
ogooOol20002Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOomoo`@000=oo`04001oogoo
0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001o
o`@000=oo`04001oogoo0005Ool000]oo`8000Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04001o
ogoo0004Ool01000Oomoogoo0P000goo0P000Woo00@007ooOol0009oo`03001oogoo009oo`8000=o
o`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D0
00=oo`8000Eoo`03001oogoo009oo`03001oogoo009oo`<000Aoo`8000Ioo`04001oogooOol50003
Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`8001aoo`03001o
ogoo00Moo`8004]oo`0077oo00<007ooOol06Woo00<007ooOol02Goo0P008Woo0P009Woo000LOomY
000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo0P000Woo
1@000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo1@000goo
00D007ooOomoo`0000Aoo`80009oo`D000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo
00<007ooOol02Woo000LOol2000IOol2000ROol00`00Oomoo`09Ool00`00Oomoo`0WOol001aoo`03
001oogoo03eoo`03001oogoo00Qoo`03001oogoo02Moo`0077oo0P00?goo00<007ooOol01goo00<0
07ooOol09goo000LOol00`00Oomoo`0nOol00`00Oomoo`07Ool00`00Oomoo`0WOol000]oo`8000Ao
o`04001oogooOol50002Ool20010Ool00`00Oomoo`06Ool00`00Oomoo`0WOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00<007ooOol0?goo00<007ooOol01Goo00<007ooOol0:7oo000:Ool0
1000Oomoo`002Goo00<007ooOol00Woo0P00@7oo00<007ooOol01Goo00<007ooOol0:7oo000:Ool0
1000Oomoo`002Woo00D007ooOomoo`00049oo`03001oogoo00Aoo`03001oogoo02Qoo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool20011Ool00`00Oomoo`04Ool00`00Oomoo`0XOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0@7oo00<007ooOol00goo00<007oo
Ool0:Goo000;Ool20009Ool30003Ool20012Ool00`00Oomoo`02Ool00`00Oomoo`0YOol001aoo`03
001oogoo045oo`03001oogoo009oo`03001oogoo02Uoo`002goo0P0017oo00<007ooOol00goo0`00
0Woo0P00@Woo00<007ooOol00Woo00<007ooOol0:Goo000:Ool01000Oomoo`002Woo00D007ooOomo
o`0004=oo`03001oogoo009oo`03001oogoo02Uoo`002Woo00@007ooOol000Moo`D0009oo`80049o
o`03001oogoo009oo`03001oogoo02Uoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00
Oomoo`12Ool01000Oomoo`00;7oo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00@goo00@0
07ooOol002aoo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo04=oo`8002eoo`002goo0P00
2goo00@007ooOomoo`8004Aoo`8002eoo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomo
o`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Mo
o`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo
00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo
000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo
000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol0
0Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol0
0`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2760\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23178 L
.132 .23178 L
.136 .23178 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23178 L
.168 .23179 L
.172 .23179 L
.176 .23179 L
.18 .23178 L
.184 .23176 L
.188 .23174 L
.192 .23172 L
.196 .23172 L
.2 .23174 L
Mistroke
.204 .23179 L
.208 .23186 L
.212 .23193 L
.216 .23197 L
.22 .23196 L
.224 .23189 L
.228 .23173 L
.232 .2315 L
.236 .23126 L
.24 .23106 L
.244 .23097 L
.248 .23108 L
.252 .23144 L
.256 .23207 L
.26 .23293 L
.264 .23393 L
.268 .2349 L
.272 .23563 L
.276 .23588 L
.28 .23542 L
.284 .23404 L
.288 .23159 L
.292 .22801 L
.296 .22332 L
.3 .21765 L
.304 .21124 L
.308 .20436 L
.312 .19737 L
.316 .19061 L
.32 .18442 L
.324 .17911 L
.328 .1749 L
.332 .17196 L
.336 .17036 L
.34 .1701 L
.344 .17109 L
.348 .1732 L
.352 .17626 L
.356 .18005 L
.36 .18437 L
.364 .189 L
.368 .19375 L
.372 .19845 L
.376 .20298 L
.38 .20722 L
.384 .21111 L
.388 .21461 L
.392 .21768 L
.396 .22035 L
.4 .22262 L
Mistroke
.404 .22452 L
.408 .22609 L
.412 .22737 L
.416 .2284 L
.42 .22922 L
.424 .22986 L
.428 .23036 L
.432 .23074 L
.436 .23103 L
.44 .23125 L
.444 .23141 L
.448 .23152 L
.452 .23161 L
.456 .23167 L
.46 .23172 L
.464 .23175 L
.468 .23177 L
.472 .23178 L
.476 .23179 L
.48 .2318 L
.484 .2318 L
.488 .23181 L
.492 .23181 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23181 L
.512 .23182 L
.516 .23182 L
.52 .23182 L
.524 .23182 L
.528 .23183 L
.532 .23183 L
.536 .23184 L
.54 .23186 L
.544 .23188 L
.548 .23191 L
.552 .23196 L
.556 .23202 L
.56 .2321 L
.564 .23222 L
.568 .23238 L
.572 .2326 L
.576 .23289 L
.58 .23327 L
.584 .23377 L
.588 .23441 L
.592 .23523 L
.596 .23626 L
.6 .23754 L
Mistroke
.604 .23911 L
.608 .24101 L
.612 .24328 L
.616 .24594 L
.62 .24902 L
.624 .25251 L
.628 .25639 L
.632 .26063 L
.636 .26515 L
.64 .26986 L
.644 .2746 L
.648 .27923 L
.652 .28354 L
.656 .28733 L
.66 .29038 L
.664 .2925 L
.668 .29349 L
.672 .29323 L
.676 .29164 L
.68 .28871 L
.684 .2845 L
.688 .2792 L
.692 .27301 L
.696 .26625 L
.7 .25926 L
.704 .25238 L
.708 .24596 L
.712 .24029 L
.716 .23559 L
.72 .23199 L
.724 .22953 L
.728 .22814 L
.732 .22767 L
.736 .22793 L
.74 .22866 L
.744 .22963 L
.748 .23063 L
.752 .2315 L
.756 .23214 L
.76 .23251 L
.764 .23262 L
.768 .23254 L
.772 .23233 L
.776 .23208 L
.78 .23186 L
.784 .2317 L
.788 .23162 L
.792 .23161 L
.796 .23165 L
.8 .23172 L
Mistroke
.804 .23179 L
.808 .23184 L
.812 .23186 L
.816 .23186 L
.82 .23185 L
.824 .23182 L
.828 .2318 L
.832 .23179 L
.836 .23179 L
.84 .23179 L
.844 .2318 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35317 L
.132 .35317 L
.136 .35317 L
.14 .35316 L
.144 .35316 L
.148 .35315 L
.152 .35314 L
.156 .35314 L
.16 .35316 L
.164 .35318 L
.168 .35321 L
.172 .35322 L
.176 .35322 L
.18 .35318 L
.184 .35311 L
.188 .35303 L
.192 .35297 L
.196 .35297 L
.2 .35304 L
Mistroke
.204 .35321 L
.208 .35345 L
.212 .35369 L
.216 .35385 L
.22 .35384 L
.224 .35356 L
.228 .35301 L
.232 .35222 L
.236 .35135 L
.24 .35062 L
.244 .35031 L
.248 .35069 L
.252 .35197 L
.256 .3542 L
.26 .35726 L
.264 .3608 L
.268 .36424 L
.272 .36685 L
.276 .36776 L
.28 .36614 L
.284 .36123 L
.288 .35251 L
.292 .33973 L
.296 .32301 L
.3 .3028 L
.304 .27989 L
.308 .25533 L
.312 .23032 L
.316 .20614 L
.32 .184 L
.324 .16497 L
.328 .1499 L
.332 .13935 L
.336 .1336 L
.34 .13262 L
.344 .13615 L
.348 .14368 L
.352 .15459 L
.356 .16814 L
.36 .18356 L
.364 .2001 L
.368 .21709 L
.372 .23391 L
.376 .2501 L
.38 .26528 L
.384 .27919 L
.388 .29167 L
.392 .30267 L
.396 .3122 L
.4 .32031 L
Mistroke
.404 .32711 L
.408 .33273 L
.412 .33731 L
.416 .34099 L
.42 .34391 L
.424 .34621 L
.428 .34798 L
.432 .34934 L
.436 .35037 L
.44 .35114 L
.444 .35171 L
.448 .35213 L
.452 .35244 L
.456 .35266 L
.46 .35281 L
.464 .35292 L
.468 .353 L
.472 .35305 L
.476 .35309 L
.48 .35311 L
.484 .35313 L
.488 .35314 L
.492 .35315 L
.496 .35315 L
.5 .35315 L
.504 .35316 L
.508 .35315 L
.512 .35315 L
.516 .35315 L
.52 .35314 L
.524 .35313 L
.528 .35311 L
.532 .35309 L
.536 .35305 L
.54 .353 L
.544 .35292 L
.548 .35281 L
.552 .35266 L
.556 .35244 L
.56 .35213 L
.564 .35171 L
.568 .35114 L
.572 .35037 L
.576 .34934 L
.58 .34798 L
.584 .34621 L
.588 .34391 L
.592 .34099 L
.596 .33731 L
.6 .33273 L
Mistroke
.604 .32711 L
.608 .32031 L
.612 .3122 L
.616 .30267 L
.62 .29167 L
.624 .27919 L
.628 .26528 L
.632 .2501 L
.636 .23392 L
.64 .21709 L
.644 .20011 L
.648 .18356 L
.652 .16815 L
.656 .1546 L
.66 .14369 L
.664 .13615 L
.668 .13262 L
.672 .1336 L
.676 .13935 L
.68 .1499 L
.684 .16498 L
.688 .184 L
.692 .20614 L
.696 .23032 L
.7 .25533 L
.704 .27989 L
.708 .3028 L
.712 .32301 L
.716 .33973 L
.72 .35251 L
.724 .36123 L
.728 .36614 L
.732 .36776 L
.736 .36685 L
.74 .36424 L
.744 .3608 L
.748 .35726 L
.752 .3542 L
.756 .35197 L
.76 .35069 L
.764 .35031 L
.768 .35062 L
.772 .35135 L
.776 .35222 L
.78 .35301 L
.784 .35356 L
.788 .35384 L
.792 .35385 L
.796 .35369 L
.8 .35345 L
Mistroke
.804 .35321 L
.808 .35304 L
.812 .35297 L
.816 .35297 L
.82 .35303 L
.824 .35311 L
.828 .35318 L
.832 .35322 L
.836 .35322 L
.84 .35321 L
.844 .35318 L
.848 .35316 L
.852 .35314 L
.856 .35314 L
.86 .35315 L
.864 .35316 L
.868 .35316 L
.872 .35317 L
.876 .35317 L
.88 .35317 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23176 L
.144 .23176 L
.148 .23175 L
.152 .23175 L
.156 .23175 L
.16 .23176 L
.164 .23178 L
.168 .2318 L
.172 .23182 L
.176 .23181 L
.18 .23178 L
.184 .23172 L
.188 .23165 L
.192 .2316 L
.196 .2316 L
.2 .23166 L
Mistroke
.204 .23181 L
.208 .232 L
.212 .23221 L
.216 .23234 L
.22 .23233 L
.224 .2321 L
.228 .23163 L
.232 .23097 L
.236 .23024 L
.24 .22963 L
.244 .22937 L
.248 .22969 L
.252 .23076 L
.256 .23263 L
.26 .2352 L
.264 .23817 L
.268 .24106 L
.272 .24325 L
.276 .24402 L
.28 .24266 L
.284 .23854 L
.288 .23121 L
.292 .22049 L
.296 .20645 L
.3 .18948 L
.304 .17026 L
.308 .14964 L
.312 .12865 L
.316 .10836 L
.32 .08977 L
.324 .0738 L
.328 .06115 L
.332 .0523 L
.336 .04747 L
.34 .04666 L
.344 .04962 L
.348 .05595 L
.352 .06511 L
.356 .07649 L
.36 .08943 L
.364 .10332 L
.368 .11758 L
.372 .13171 L
.376 .14529 L
.38 .15804 L
.384 .16971 L
.388 .18019 L
.392 .18943 L
.396 .19742 L
.4 .20423 L
Mistroke
.404 .20994 L
.408 .21466 L
.412 .2185 L
.416 .2216 L
.42 .22405 L
.424 .22597 L
.428 .22746 L
.432 .22861 L
.436 .22947 L
.44 .23012 L
.444 .2306 L
.448 .23095 L
.452 .23121 L
.456 .23139 L
.46 .23152 L
.464 .23161 L
.468 .23168 L
.472 .23172 L
.476 .23175 L
.48 .23177 L
.484 .23179 L
.488 .2318 L
.492 .2318 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23182 L
.512 .23182 L
.516 .23182 L
.52 .23183 L
.524 .23184 L
.528 .23185 L
.532 .23188 L
.536 .23191 L
.54 .23195 L
.544 .23202 L
.548 .23211 L
.552 .23224 L
.556 .23242 L
.56 .23268 L
.564 .23303 L
.568 .23351 L
.572 .23416 L
.576 .23502 L
.58 .23616 L
.584 .23765 L
.588 .23958 L
.592 .24203 L
.596 .24512 L
.6 .24897 L
Mistroke
.604 .25369 L
.608 .25939 L
.612 .2662 L
.616 .2742 L
.62 .28343 L
.624 .29391 L
.628 .30559 L
.632 .31833 L
.636 .33192 L
.64 .34605 L
.644 .3603 L
.648 .37419 L
.652 .38714 L
.656 .39851 L
.66 .40767 L
.664 .414 L
.668 .41697 L
.672 .41615 L
.676 .41132 L
.68 .40247 L
.684 .38982 L
.688 .37385 L
.692 .35527 L
.696 .33497 L
.7 .31399 L
.704 .29337 L
.708 .27414 L
.712 .25718 L
.716 .24314 L
.72 .23241 L
.724 .22509 L
.728 .22097 L
.732 .21961 L
.736 .22038 L
.74 .22256 L
.744 .22546 L
.748 .22843 L
.752 .23099 L
.756 .23287 L
.76 .23394 L
.764 .23426 L
.768 .234 L
.772 .23338 L
.776 .23265 L
.78 .232 L
.784 .23153 L
.788 .2313 L
.792 .23128 L
.796 .23142 L
.8 .23162 L
Mistroke
.804 .23182 L
.808 .23196 L
.812 .23203 L
.816 .23203 L
.82 .23198 L
.824 .23191 L
.828 .23185 L
.832 .23182 L
.836 .23181 L
.84 .23183 L
.844 .23185 L
.848 .23187 L
.852 .23188 L
.856 .23188 L
.86 .23188 L
.864 .23187 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23187 L
.892 .23187 L
.896 .23187 L
.9 .23187 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01Woo
0`000goo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00aoo`@000=oo`04001oogoo0007Ool300001Goo001oogoo00000Woo00@007ooOol0
009oo`03001oogoo00=oo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`001goo0`000Woo00<007oo
00000Woo00@007ooOol0009oo`03001oogoo009oo`8000=oo`03001oogoo00Aoo`04001oogoo0004
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`00
00Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Moo`04001oogoo0003Ool0
1000Ool0000017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0
009oo`D000=oo`8000Ioo`0077oo0P007Woo00<007ooOol017oo0P00C7oo000LOol00`00Oomoo`0L
Ool00`00Oomoo`07Ool2001:Ool001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo
009oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo0`000Woo00D007ooOomoo`0000Aoo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00`000Woo00D007ooOomoo`0000=o
o`8000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`03001o
ogoo00Yoo`0077oo0P00?Woo0P001goo00<007ooOol0:Goo000LOol00`00Oomoo`0nOol20006Ool0
0`00Oomoo`0YOol001aoo`80041oo`03001oogoo00=oo`03001oogoo02Yoo`0077oo00<007ooOol0
@7oo00@007ooOomoo`8002aoo`002goo0P0017oo00@007ooOomoo`D0009oo`80049oo`04001oo`00
000]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0@Woo0P00;Woo000:Ool0
1000Oomoo`002Goo00<007ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`00
07Aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03
001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`00
2Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007oo
Ool000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003
Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`04001o
ogooOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00
Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool0
0`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0
LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
07=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00
Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo
00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3001hOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo0000Mgoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=o
o`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00
Lgoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`@000=oo`8007=oo`002Woo00@007ooOol000Mo
o`03001oogoo00Aoo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`8007=o
o`002goo0P002Woo0P000goo00<007ooOol0LWoo000LOol2000QOol2000POol2000^Ool001aoo`03
001oogoo021oo`8001moo`03001oo`0002ioo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00
87oo00@007ooOol001ioo`03001oo`0002ioo`002Woo00@007ooOol000Yoo`05001oogooOol0000Q
Ool01000Oomoo`007Woo00@007ooOol002eoo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03
001oogoo01moo`04001oogoo000NOol01000Oomoo`00;Goo000:Ool01000Oomoo`001goo00@007oo
Ool000=oo`8001moo`05001oogooOol0000MOol01@00Oomoogoo0000;Goo000:Ool01000Oomoo`00
27oo00<007oo00000goo00<007ooOol07Woo00D007ooOomoo`0001eoo`05001oogooOol0000]Ool0
00Yoo`04001oogoo0009Ool20003Ool2000OOol00`00Oomoo`02Ool00`00Oomoo`0JOol00`00Oomo
o`02Ool00`00Oomoo`0ZOol000]oo`8000]oo`05001oogooOol0000POol00`00Oomoo`02Ool00`00
Oomoo`0JOol00`00Oomoo`02Ool00`00Oomoo`0ZOol001aoo`8001moo`03001oogoo009oo`03001o
ogoo01Uoo`03001oogoo00=oo`03001oogoo02Yoo`0077oo00<007ooOol07Goo00<007ooOol00goo
00<007ooOol06Goo00<007ooOol00goo00<007ooOol0:Woo000;Ool20004Ool01000Oomoogoo1@00
0Woo0P007Woo00<007ooOol017oo00<007ooOol067oo00<007ooOol00goo00<007ooOol0:Woo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo01eoo`03001oogoo00Aoo`03001oogoo
01Qoo`03001oogoo00Aoo`03001oogoo02Uoo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo
009oo`03001oogoo01eoo`03001oogoo00Aoo`03001oogoo01Qoo`03001oogoo00Aoo`03001oogoo
02Uoo`002Woo00@007ooOol000Yoo`04001oogooOol2000>Ool30004Ool20007Ool00`00Ool00002
0002Ool01000Ool0000017oo0P001Goo0`000goo0`000Woo00@007oo000000Aoo`H000=oo`8000Ao
o`8000Eoo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`0<Ool01@00Oomoogoo00000Woo00@007ooOol000Ioo`04001oogoo0004Ool01000Oomo
o`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Ool000000Woo00L007ooOomoo`00
Ool00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo00=oo`06001oogoo001oo`00
0goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool2000AOol01000Oomoo`000Woo00<007ooOol017oo00@007ooOol000Aoo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007oo0000009oo`05001oogooOol00002Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`03Ool000]oo`8000Uoo`<000=oo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool20000
1Goo001oogoo00000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`001goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol0
00Eoo`05001oogooOol00004Ool200001Goo001oogoo00000Woo00<007ooOol00goo00@007ooOomo
o`@00004Ool007oo0002Ool01000Oomoogoo0P000goo00@007ooOol0009oo`04001oogoo0002Ool0
0`00Oomoo`02Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00ao
o`03001oogoo00Aoo`04001oogoo0005Ool00`00Oomoo`020004Ool200001Goo001oogoo00000Woo
00<007ooOol00Woo0P000goo00D007ooOomoo`00009oo`04001oogoo0003Ool20003Ool01000Oomo
o`000Woo00@007ooOol0009oo`03001oogoo009oo`07001oogooOol007oo00001Woo00@007ooOol0
00Eoo`0077oo00<007ooOol037oo1@000goo0P001Woo00D007ooOomoo`0000Eoo`8000Aoo`8000Io
o`04001oogooOol50003Ool20005Ool40004Ool20004Ool20006Ool30002Ool50003Ool20006Ool0
01aoo`8001eoo`03001oogoo00Qoo`80019oo`03001oogoo00Uoo`03001oogoo02Qoo`0077oo00<0
07ooOol06goo00<007ooOol02Woo0P003goo0P0037oo00<007ooOol0:7oo000LOomY000<Ool001ao
o`03001oogoo019oo`03001oogoo00Aoo`<000]oo`03001oogoo015oo`03001oogoo00Yoo`<000Eo
o`03001oogoo019oo`03001oogoo00Yoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogooOol5
0002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0LWoo000:Ool0
1000Oomoo`002Goo00<007ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`00
07Aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001c
Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo
0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079o
o`002goo0P002goo00D007ooOomoo`0007Aoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`0POol0
0`00Oomoo`1?Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`80025oo`80051oo`002Woo00@0
07ooOol000Yoo`05001oogooOol0000QOol01000Oomoo`00Cgoo0003Ool50002Ool01000Oomoo`00
1goo1@000Woo0P0087oo00@007ooOol004moo`002Woo00@007ooOol000Moo`04001oogoo0003Ool0
0`00Oomoo`0OOol01000Oomoo`00Cgoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P007goo
00D007ooOomoo`0004moo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo01ioo`03001oogoo
009oo`03001oogoo04aoo`002goo0P002goo00@007ooOomoo`8001moo`03001oogoo009oo`03001o
ogoo04aoo`0077oo00<007ooOol07Woo00<007ooOol00Woo00<007ooOol0C7oo000;Ool20004Ool0
1000Oomoogoo1@000Woo0P007Woo00<007ooOol017oo00<007ooOol0Bgoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`03001oogoo00eoo`<000Aoo`8000Moo`03001oo`000080009oo`04001o
o`000004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004
Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool2000=Ool01@00Oomoogoo
00000Woo00@007ooOol000Ioo`04001oogoo0003Ool20002Ool01000Oomoo`000Woo00<007ooOol0
0goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo00@007ooOol0009oo`03001oogoo
00Aoo`04001oogoo0003Ool20002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol017oo00@007ooOol000Aoo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eo
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`0<Ool40003Ool01000Oomoo`001Woo00@007ooOol000Aoo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uoo`<0
00=oo`8000eoo`03001oogoo00Aoo`04001oogoo0005Ool00`00Oomoo`020004Ool200001Goo001o
ogoo00000Woo00<007ooOol00Woo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007oo
Ool000Eoo`0077oo00<007ooOol037oo1@000goo0P001Woo00D007ooOomoo`0000Eoo`8000Aoo`80
00Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006
Ool001aoo`8001eoo`03001oogoo00Qoo`03001oogoo04Qoo`0077oo00<007ooOol06goo00<007oo
Ool02Goo0P007goo0P00:7oo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00H007oo001oo`00Ool40002Ool01@00Oomoogoo000017oo00D007oo
Oomoo`0000=oo`05001oogooOol00002Ool60003Ool01@00Oomoogoo000017oo00<007ooOol00`00
0Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool0
01aoo`8001Yoo`8001moo`8000]oo`03001oogoo02Qoo`0077oo00<007ooOol0?7oo00<007ooOol0
27oo00<007ooOol0:7oo000LOol2000mOol00`00Oomoo`08Ool00`00Oomoo`0XOol001aoo`03001o
ogoo03eoo`03001oogoo00Ioo`03001oogoo02Uoo`002goo0P0017oo00@007ooOomoo`D0009oo`80
03ioo`03001oogoo00Ioo`03001oogoo02Uoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0nOol00`00Oomoo`05Ool00`00Oomoo`0YOol000Yoo`04001oogoo0009Ool00`00Oomo
o`02Ool2000oOol00`00Oomoo`05Ool00`00Oomoo`0YOol000Yoo`04001oogoo000:Ool01@00Oomo
ogoo0000@Goo00<007ooOol017oo00<007ooOol0:Goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`80041oo`03001oogoo00Aoo`03001oogoo02Uoo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`0oOol00`00Oomoo`03Ool00`00Oomoo`0ZOol000]oo`8000Uoo`<0
00=oo`80041oo`03001oogoo00=oo`03001oogoo02Yoo`0077oo00<007ooOol0?goo00<007ooOol0
0goo00<007ooOol0:Woo000;Ool20004Ool00`00Oomoo`03Ool30002Ool20011Ool00`00Oomoo`02
Ool00`00Oomoo`0ZOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000@Woo00D007ooOomoo`00
02eoo`002Woo00@007ooOol000Moo`D0009oo`80045oo`05001oogooOol0000]Ool000Yoo`04001o
ogoo0007Ool01000Oomoo`000goo00<007ooOol0@Goo00@007ooOol002eoo`002Woo00@007ooOol0
00Qoo`03001oo`0000=oo`80049oo`03001oo`0002ioo`002Woo00@007ooOol000Uoo`8000=oo`03
001oogoo045oo`<002ioo`002goo0P002goo00@007ooOomoo`8004=oo`8002ioo`0077oo00<007oo
Ool0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079o
o`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo
009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo
0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=o
o`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03
001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001o
ogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2800\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23178 L
.144 .23178 L
.148 .23178 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23178 L
.18 .23179 L
.184 .23179 L
.188 .23179 L
.192 .23178 L
.196 .23175 L
.2 .23173 L
Mistroke
.204 .23171 L
.208 .23172 L
.212 .23174 L
.216 .2318 L
.22 .23187 L
.224 .23194 L
.228 .23198 L
.232 .23197 L
.236 .23188 L
.24 .23171 L
.244 .23148 L
.248 .23122 L
.252 .23101 L
.256 .23094 L
.26 .23106 L
.264 .23145 L
.268 .23211 L
.272 .23301 L
.276 .23403 L
.28 .23502 L
.284 .23575 L
.288 .236 L
.292 .23551 L
.296 .23409 L
.3 .23159 L
.304 .22795 L
.308 .22321 L
.312 .21751 L
.316 .21106 L
.32 .20417 L
.324 .19718 L
.328 .19044 L
.332 .18428 L
.336 .179 L
.34 .17484 L
.344 .17194 L
.348 .17038 L
.352 .17016 L
.356 .17118 L
.36 .17331 L
.364 .17638 L
.368 .18017 L
.372 .18448 L
.376 .1891 L
.38 .19383 L
.384 .19852 L
.388 .20303 L
.392 .20726 L
.396 .21114 L
.4 .21462 L
Mistroke
.404 .21768 L
.408 .22034 L
.412 .2226 L
.416 .2245 L
.42 .22607 L
.424 .22736 L
.428 .22839 L
.432 .22921 L
.436 .22985 L
.44 .23035 L
.444 .23073 L
.448 .23102 L
.452 .23124 L
.456 .2314 L
.46 .23152 L
.464 .23161 L
.468 .23167 L
.472 .23171 L
.476 .23174 L
.48 .23177 L
.484 .23178 L
.488 .23179 L
.492 .2318 L
.496 .23181 L
.5 .23181 L
.504 .23181 L
.508 .23182 L
.512 .23182 L
.516 .23183 L
.52 .23183 L
.524 .23185 L
.528 .23186 L
.532 .23188 L
.536 .23191 L
.54 .23196 L
.544 .23202 L
.548 .23211 L
.552 .23223 L
.556 .23239 L
.56 .23261 L
.564 .2329 L
.568 .23328 L
.572 .23378 L
.576 .23442 L
.58 .23524 L
.584 .23628 L
.588 .23756 L
.592 .23913 L
.596 .24103 L
.6 .24329 L
Mistroke
.604 .24594 L
.608 .24901 L
.612 .25248 L
.616 .25636 L
.62 .26058 L
.624 .26509 L
.628 .26977 L
.632 .2745 L
.636 .27911 L
.64 .28342 L
.644 .28721 L
.648 .29028 L
.652 .29241 L
.656 .29343 L
.66 .29321 L
.664 .29165 L
.668 .28876 L
.672 .28461 L
.676 .27934 L
.68 .27318 L
.684 .26644 L
.688 .25945 L
.692 .25255 L
.696 .2461 L
.7 .24039 L
.704 .23564 L
.708 .23199 L
.712 .22948 L
.716 .22805 L
.72 .22756 L
.724 .2278 L
.728 .22854 L
.732 .22953 L
.736 .23056 L
.74 .23146 L
.744 .23213 L
.748 .23252 L
.752 .23265 L
.756 .23258 L
.76 .23237 L
.764 .23211 L
.768 .23187 L
.772 .2317 L
.776 .23161 L
.78 .2316 L
.784 .23164 L
.788 .23171 L
.792 .23178 L
.796 .23184 L
.8 .23187 L
Mistroke
.804 .23187 L
.808 .23185 L
.812 .23183 L
.816 .23181 L
.82 .23179 L
.824 .23179 L
.828 .23179 L
.832 .2318 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35317 L
.144 .35317 L
.148 .35317 L
.152 .35316 L
.156 .35315 L
.16 .35314 L
.164 .35314 L
.168 .35314 L
.172 .35316 L
.176 .35319 L
.18 .35322 L
.184 .35323 L
.188 .35322 L
.192 .35317 L
.196 .3531 L
.2 .35301 L
Mistroke
.204 .35295 L
.208 .35296 L
.212 .35305 L
.216 .35324 L
.22 .35349 L
.224 .35374 L
.228 .3539 L
.232 .35386 L
.236 .35355 L
.24 .35295 L
.244 .35212 L
.248 .35122 L
.252 .35048 L
.256 .35019 L
.26 .35063 L
.264 .35199 L
.268 .35433 L
.272 .35751 L
.276 .36115 L
.28 .36466 L
.284 .36728 L
.288 .36817 L
.292 .36645 L
.296 .3614 L
.3 .35251 L
.304 .33954 L
.308 .32264 L
.312 .30228 L
.316 .27926 L
.32 .25465 L
.324 .22965 L
.328 .20553 L
.332 .1835 L
.336 .1646 L
.34 .14969 L
.344 .13929 L
.348 .13369 L
.352 .13284 L
.356 .13646 L
.36 .14406 L
.364 .15501 L
.368 .16856 L
.372 .18396 L
.376 .20046 L
.38 .21739 L
.384 .23416 L
.388 .25029 L
.392 .26541 L
.396 .27927 L
.4 .29171 L
Mistroke
.404 .30268 L
.408 .31217 L
.412 .32026 L
.416 .32705 L
.42 .33267 L
.424 .33725 L
.428 .34093 L
.432 .34386 L
.436 .34616 L
.44 .34794 L
.444 .34931 L
.448 .35034 L
.452 .35112 L
.456 .35169 L
.46 .35212 L
.464 .35243 L
.468 .35265 L
.472 .35281 L
.476 .35292 L
.48 .35299 L
.484 .35305 L
.488 .35308 L
.492 .35311 L
.496 .35312 L
.5 .35313 L
.504 .35313 L
.508 .35313 L
.512 .35312 L
.516 .35311 L
.52 .35308 L
.524 .35305 L
.528 .35299 L
.532 .35292 L
.536 .35281 L
.54 .35265 L
.544 .35243 L
.548 .35212 L
.552 .35169 L
.556 .35112 L
.56 .35034 L
.564 .34931 L
.568 .34794 L
.572 .34616 L
.576 .34386 L
.58 .34093 L
.584 .33725 L
.588 .33267 L
.592 .32705 L
.596 .32026 L
.6 .31217 L
Mistroke
.604 .30268 L
.608 .29171 L
.612 .27927 L
.616 .26541 L
.62 .25029 L
.624 .23416 L
.628 .2174 L
.632 .20047 L
.636 .18396 L
.64 .16856 L
.644 .15501 L
.648 .14407 L
.652 .13646 L
.656 .13284 L
.66 .13369 L
.664 .1393 L
.668 .14969 L
.672 .16461 L
.676 .1835 L
.68 .20553 L
.684 .22965 L
.688 .25465 L
.692 .27927 L
.696 .30228 L
.7 .32264 L
.704 .33954 L
.708 .35251 L
.712 .3614 L
.716 .36645 L
.72 .36817 L
.724 .36728 L
.728 .36466 L
.732 .36115 L
.736 .35751 L
.74 .35433 L
.744 .35199 L
.748 .35063 L
.752 .35019 L
.756 .35048 L
.76 .35122 L
.764 .35212 L
.768 .35295 L
.772 .35355 L
.776 .35386 L
.78 .3539 L
.784 .35374 L
.788 .35349 L
.792 .35324 L
.796 .35305 L
.8 .35296 L
Mistroke
.804 .35295 L
.808 .35301 L
.812 .3531 L
.816 .35317 L
.82 .35322 L
.824 .35323 L
.828 .35322 L
.832 .35319 L
.836 .35316 L
.84 .35314 L
.844 .35314 L
.848 .35314 L
.852 .35315 L
.856 .35316 L
.86 .35317 L
.864 .35317 L
.868 .35317 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23176 L
.156 .23176 L
.16 .23175 L
.164 .23174 L
.168 .23175 L
.172 .23176 L
.176 .23179 L
.18 .23181 L
.184 .23182 L
.188 .23181 L
.192 .23177 L
.196 .23171 L
.2 .23164 L
Mistroke
.204 .23159 L
.208 .23159 L
.212 .23167 L
.216 .23183 L
.22 .23204 L
.224 .23225 L
.228 .23238 L
.232 .23235 L
.236 .23209 L
.24 .23158 L
.244 .23089 L
.248 .23013 L
.252 .22951 L
.256 .22927 L
.26 .22964 L
.264 .23078 L
.268 .23275 L
.272 .23541 L
.276 .23846 L
.28 .24141 L
.284 .24362 L
.288 .24436 L
.292 .24292 L
.296 .23868 L
.3 .23121 L
.304 .22033 L
.308 .20614 L
.312 .18905 L
.316 .16973 L
.32 .14907 L
.324 .12809 L
.328 .10784 L
.332 .08935 L
.336 .07349 L
.34 .06097 L
.344 .05225 L
.348 .04755 L
.352 .04684 L
.356 .04988 L
.36 .05627 L
.364 .06546 L
.368 .07684 L
.372 .08977 L
.376 .10362 L
.38 .11784 L
.384 .13191 L
.388 .14545 L
.392 .15815 L
.396 .16978 L
.4 .18023 L
Mistroke
.404 .18943 L
.408 .1974 L
.412 .2042 L
.416 .2099 L
.42 .21461 L
.424 .21845 L
.428 .22155 L
.432 .224 L
.436 .22593 L
.44 .22743 L
.444 .22858 L
.448 .22945 L
.452 .2301 L
.456 .23058 L
.46 .23094 L
.464 .2312 L
.468 .23138 L
.472 .23151 L
.476 .23161 L
.48 .23167 L
.484 .23172 L
.488 .23175 L
.492 .23177 L
.496 .23179 L
.5 .2318 L
.504 .23181 L
.508 .23182 L
.512 .23184 L
.516 .23185 L
.52 .23188 L
.524 .23191 L
.528 .23195 L
.532 .23202 L
.536 .23211 L
.54 .23225 L
.544 .23243 L
.548 .23269 L
.552 .23305 L
.556 .23353 L
.56 .23418 L
.564 .23505 L
.568 .2362 L
.572 .23769 L
.576 .23962 L
.58 .24208 L
.584 .24517 L
.588 .24902 L
.592 .25373 L
.596 .25943 L
.6 .26622 L
Mistroke
.604 .2742 L
.608 .2834 L
.612 .29385 L
.616 .30548 L
.62 .31817 L
.624 .33171 L
.628 .34579 L
.632 .36 L
.636 .37386 L
.64 .38679 L
.644 .39816 L
.648 .40735 L
.652 .41374 L
.656 .41678 L
.66 .41607 L
.664 .41137 L
.668 .40265 L
.672 .39013 L
.676 .37428 L
.68 .35578 L
.684 .33554 L
.688 .31455 L
.692 .29389 L
.696 .27458 L
.7 .25749 L
.704 .2433 L
.708 .23242 L
.712 .22495 L
.716 .22071 L
.72 .21927 L
.724 .22001 L
.728 .22221 L
.732 .22516 L
.736 .22822 L
.74 .23088 L
.744 .23285 L
.748 .23399 L
.752 .23436 L
.756 .23412 L
.76 .2335 L
.764 .23274 L
.768 .23204 L
.772 .23154 L
.776 .23128 L
.78 .23124 L
.784 .23138 L
.788 .23159 L
.792 .2318 L
.796 .23196 L
.8 .23204 L
Mistroke
.804 .23204 L
.808 .23199 L
.812 .23192 L
.816 .23186 L
.82 .23182 L
.824 .23181 L
.828 .23182 L
.832 .23184 L
.836 .23186 L
.84 .23188 L
.844 .23188 L
.848 .23188 L
.852 .23187 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23187 L
.88 .23187 L
.884 .23187 L
.888 .23187 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23187 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
0`000Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`030002Ool01000Oomoo`000Woo
00<007ooOol00goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]o
o`8000Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008Ool20003Ool20002Ool01000
Oomoo`000Woo00<007ooOol00Woo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007oo
Ool000Eoo`0077oo00<007ooOol037oo1@000goo0P0027oo0`0017oo0`0017oo0P001Woo00@007oo
Oomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00
7goo00<007ooOol01Goo0P00BWoo000LOol00`00Oomoo`0MOol00`00Oomoo`07Ool20019Ool001ao
ofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo0`0000=oo`00Ool00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool00`00Ool000020003Ool01@00Oomoogoo00000Woo00<007oo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00<007ooOol02Woo000LOol2
000mOol00`00Oomoo`06Ool00`00Oomoo`0ZOol001aoo`03001oogoo03eoo`03001oogoo00Aoo`03
001oogoo02]oo`0077oo0P00?goo00<007ooOol00goo00<007ooOol0:goo000LOol00`00Oomoo`0o
Ool01@00Oomoogoo0000;Woo000;Ool20004Ool01000Oomoogoo1@000Woo0P00@7oo0P0000=oo`00
0000;Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo045oo`03001oogoo02io
o`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001o
ogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo
000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@0
07ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yo
o`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<0
07oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;
Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<0
00=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomo
o`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03
001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<0
00=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001c
Ool001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo
07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00N7oo000:Ool01000Oomo
o`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002
Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8007=oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool40003Ool2001cOol000Yoo`04001o
ogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Oomoo`03
Ool2001cOol000]oo`8000Yoo`8000=oo`03001oogoo079oo`0077oo0P008Woo0P007Woo00<007oo
Ool0;Woo000LOol00`00Oomoo`0QOol2000MOol3000_Ool000]oo`8000Aoo`03001oogoo00=oo`<0
009oo`80025oo`04001oogoo000LOol00`00Ool0000_Ool000Yoo`04001oogoo000:Ool01@00Oomo
ogoo00008Woo00@007ooOol001aoo`04001oogoo000^Ool000=oo`D0009oo`04001oogoo0007Ool5
0002Ool00`00Oomoo`0POol01000Oomoo`006goo00D007ooOomoo`0002ioo`002Woo00@007ooOol0
00Moo`04001oogoo0003Ool2000QOol01@00Oomoogoo00006Woo00D007ooOomoo`0002ioo`002Woo
00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo021oo`05001oogooOol0000JOol01@00Oomo
ogoo0000;Woo000:Ool01000Oomoo`002Goo0P000goo0P0087oo00<007ooOol00Woo00<007ooOol0
67oo00D007ooOomoo`0002ioo`002goo0P002goo00D007ooOomoo`00025oo`03001oogoo009oo`03
001oogoo01Qoo`05001oogooOol0000^Ool001aoo`80021oo`03001oogoo009oo`03001oogoo01Mo
o`03001oogoo009oo`03001oogoo02aoo`0077oo00<007ooOol07goo00<007ooOol00Woo00<007oo
Ool05goo00<007ooOol00goo00<007ooOol0:goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00
87oo00<007ooOol00goo00<007ooOol05Woo00<007ooOol00goo00<007ooOol0:goo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`03001oogoo01ioo`03001oogoo00Aoo`03001oogoo01Eoo`03
001oogoo00Aoo`03001oogoo02]oo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`03
001oogoo01ioo`03001oogoo00Aoo`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo02]oo`00
2Woo00@007ooOol000Yoo`04001oogooOol2000>Ool30004Ool20008Ool40004Ool20004Ool20005
Ool30003Ool3000017oo001oogoo0P000Woo00<007ooOol01@000goo0P0017oo0P001Goo1@000Woo
0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`05
001oogooOol00002Ool01000Oomoo`001goo00<007oo000017oo0P0000Eoo`00Oomoo`00009oo`03
001oogoo00=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomo
o`000Woo00<007ooOol01Goo00<007oo000017oo0P0000Eoo`00Oomoo`00009oo`03001oogoo00=o
o`03001oogoo00Eoo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2
0009Ool30003Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol017oo00@007ooOol000Ao
o`04001oo`000002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`04001oogoo
0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04
001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0006Ool01000Oomo
o`0017oo00@007oo0000009oo`04001oogoo0005Ool01000Oomoogoo1@000Woo00@007ooOol0009o
o`03001oo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo00H007ooOomo
o`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomo
o`001Woo00@007oo000000Aoo`04001oo`000002Ool01000Oomoo`0017oo0P000goo00@007ooOol0
00=oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@00
0goo0P001goo00@007ooOol000Eoo`<000=oo`8000Ioo`04001oogooOol50003Ool20004Ool00`00
Ool000020004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`8001ioo`03001oogoo
00Uoo`03001oogoo00ioo`03001oogoo00Uoo`03001oogoo02Uoo`0077oo00<007ooOol07Goo00<0
07ooOol02Goo0`0037oo0P0037oo00<007ooOol0:Goo000LOomY000<Ool001aoo`03001oogoo019o
o`03001oogoo00Eoo`<000Yoo`03001oogoo015oo`03001oogoo00Uoo`<000Ioo`03001oogoo019o
o`03001oogoo00Yoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogooOol50002Ool2001cOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002Goo
00<007ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001o
ogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool0
1000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001o
o`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo
00D007ooOomoo`0007Aoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`0QOol2001?Ool000]oo`80
00Aoo`03001oogoo00=oo`<0009oo`80029oo`8004moo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0000ROol01000Oomoo`00CWoo0003Ool50002Ool01000Oomoo`001goo1@000Woo0P008Goo00@0
07ooOol004ioo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0POol01000Oomo
o`00CWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P008Goo00D007ooOomoo`0004eoo`00
2Woo00@007ooOol000Uoo`8000=oo`03001oogoo021oo`05001oogooOol0001=Ool000]oo`8000]o
o`04001oogooOol2000POol00`00Oomoo`02Ool00`00Oomoo`1;Ool001aoo`03001oogoo01moo`03
001oogoo009oo`03001oogoo04]oo`002goo0P0017oo00@007ooOomoo`D0009oo`80021oo`03001o
ogoo00=oo`03001oogoo04Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0=
Ool30004Ool20009Ool30003Ool30004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004
Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02
Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oo`0000Aoo`04001oogoo0002
Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo00@007ooOol0
009oo`03001oogoo00Eoo`03001oo`0000Aoo`800005Ool007ooOol00002Ool00`00Oomoo`03Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Ool00004Ool200001Goo001oogoo00000Woo00<007ooOol00goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`001goo00<007oo000017oo00@007oo0000
009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eo
o`002goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Ioo`04001oo`000004
Ool01000Ool000000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Io
o`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Moo`04001oogoo0005Ool20004
Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo
0P001Woo000LOol2000NOol00`00Oomoo`08Ool00`00Oomoo`17Ool001aoo`03001oogoo01eoo`03
001oogoo00Uoo`03001oogoo01]oo`8002Uoo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo
00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oo`000080009oo`800004Ool007oo0003Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000goo00H007ooOomoo`00Ool500000goo001oo`02Ool01@00
Oomoogoo00000Woo00@007oo001oo`<000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00<007ooOol00Woo00<007ooOol02Woo000LOol2000LOol00`00Oomoo`0KOol2000;Ool00`00Oomo
o`0YOol001aoo`03001oogoo03Yoo`8000Yoo`03001oogoo02Uoo`0077oo0P00?7oo00<007ooOol0
27oo00<007ooOol0:Goo000LOol00`00Oomoo`0lOol00`00Oomoo`06Ool00`00Oomoo`0ZOol000]o
o`8000Aoo`04001oogooOol50002Ool2000mOol00`00Oomoo`06Ool00`00Oomoo`0ZOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0?7oo00<007ooOol01Woo00<007ooOol0:Woo
000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00?Woo00<007ooOol01Goo00<007ooOol0:Woo
000:Ool01000Oomoo`002Woo00D007ooOomoo`0003moo`03001oogoo00Aoo`03001oogoo02]oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2000nOol00`00Oomoo`04Ool00`00Oomoo`0[
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0?Woo00<007ooOol00goo
00<007ooOol0:goo000;Ool20009Ool30003Ool2000oOol00`00Oomoo`03Ool00`00Oomoo`0[Ool0
01aoo`03001oogoo03ioo`03001oogoo009oo`03001oogoo02aoo`002goo0P0017oo00<007ooOol0
0goo0`000Woo0P00@7oo00D007ooOomoo`0002ioo`002Woo00@007ooOol000Yoo`05001oogooOol0
0011Ool01@00Oomoogoo0000;Woo000:Ool01000Oomoo`001goo1@000Woo0P00@7oo00D007ooOomo
o`0002ioo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0oOol01@00Oomoogoo
0000;Woo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00@Goo00<007oo0000;goo000:Ool0
1000Oomoo`002Goo0P000goo00<007ooOol0@7oo0`00;goo000;Ool2000;Ool01000Oomoogoo0P00
@Woo00<007ooOol0;Woo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=o
o`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`00
27oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001o
ogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=o
o`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol0
01Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Mo
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2840\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23178 L
.156 .23178 L
.16 .23178 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23178 L
.188 .23178 L
.192 .23179 L
.196 .2318 L
.2 .23179 L
Mistroke
.204 .23177 L
.208 .23175 L
.212 .23173 L
.216 .23171 L
.22 .23171 L
.224 .23175 L
.228 .2318 L
.232 .23188 L
.236 .23195 L
.24 .232 L
.244 .23198 L
.248 .23188 L
.252 .23169 L
.256 .23145 L
.26 .23118 L
.264 .23097 L
.268 .2309 L
.272 .23104 L
.276 .23146 L
.28 .23215 L
.284 .23308 L
.288 .23413 L
.292 .23513 L
.296 .23587 L
.3 .23611 L
.304 .2356 L
.308 .23413 L
.312 .23159 L
.316 .2279 L
.32 .22311 L
.324 .21736 L
.328 .21089 L
.332 .20399 L
.336 .19699 L
.34 .19027 L
.344 .18414 L
.348 .1789 L
.352 .17478 L
.356 .17193 L
.36 .17041 L
.364 .17022 L
.368 .17127 L
.372 .17342 L
.376 .17649 L
.38 .18029 L
.384 .18459 L
.388 .1892 L
.392 .19392 L
.396 .19859 L
.4 .20308 L
Mistroke
.404 .2073 L
.408 .21116 L
.412 .21463 L
.416 .21768 L
.42 .22033 L
.424 .22259 L
.428 .22449 L
.432 .22606 L
.436 .22734 L
.44 .22837 L
.444 .22919 L
.448 .22984 L
.452 .23034 L
.456 .23072 L
.46 .23101 L
.464 .23123 L
.468 .2314 L
.472 .23152 L
.476 .2316 L
.48 .23167 L
.484 .23171 L
.488 .23175 L
.492 .23177 L
.496 .23179 L
.5 .2318 L
.504 .23181 L
.508 .23183 L
.512 .23184 L
.516 .23186 L
.52 .23188 L
.524 .23191 L
.528 .23196 L
.532 .23202 L
.536 .23211 L
.54 .23223 L
.544 .2324 L
.548 .23261 L
.552 .23291 L
.556 .23329 L
.56 .23379 L
.564 .23444 L
.568 .23526 L
.572 .23629 L
.576 .23757 L
.58 .23914 L
.584 .24104 L
.588 .24329 L
.592 .24594 L
.596 .249 L
.6 .25246 L
Mistroke
.604 .25632 L
.608 .26053 L
.612 .26502 L
.616 .26969 L
.62 .2744 L
.624 .279 L
.628 .2833 L
.632 .2871 L
.636 .29017 L
.64 .29232 L
.644 .29337 L
.648 .29318 L
.652 .29167 L
.656 .28882 L
.66 .28471 L
.664 .27948 L
.668 .27335 L
.672 .26663 L
.676 .25964 L
.68 .25273 L
.684 .24625 L
.688 .2405 L
.692 .2357 L
.696 .232 L
.7 .22944 L
.704 .22797 L
.708 .22745 L
.712 .22768 L
.716 .22842 L
.72 .22943 L
.724 .23049 L
.728 .23142 L
.732 .23212 L
.736 .23254 L
.74 .23269 L
.744 .23262 L
.748 .23241 L
.752 .23214 L
.756 .23189 L
.76 .2317 L
.764 .2316 L
.768 .23158 L
.772 .23162 L
.776 .2317 L
.78 .23178 L
.784 .23184 L
.788 .23187 L
.792 .23187 L
.796 .23186 L
.8 .23183 L
Mistroke
.804 .23181 L
.808 .23179 L
.812 .23179 L
.816 .23179 L
.82 .2318 L
.824 .23181 L
.828 .23181 L
.832 .23182 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35317 L
.156 .35317 L
.16 .35317 L
.164 .35316 L
.168 .35315 L
.172 .35314 L
.176 .35314 L
.18 .35315 L
.184 .35317 L
.188 .3532 L
.192 .35322 L
.196 .35324 L
.2 .35322 L
Mistroke
.204 .35316 L
.208 .35308 L
.212 .35299 L
.216 .35294 L
.22 .35295 L
.224 .35306 L
.228 .35327 L
.232 .35354 L
.236 .3538 L
.24 .35395 L
.244 .35389 L
.248 .35354 L
.252 .35289 L
.256 .35201 L
.26 .35108 L
.264 .35033 L
.268 .35007 L
.272 .35057 L
.276 .35202 L
.28 .35448 L
.284 .35777 L
.288 .3615 L
.292 .36508 L
.296 .36772 L
.3 .36856 L
.304 .36675 L
.308 .36156 L
.312 .35249 L
.316 .33934 L
.32 .32226 L
.324 .30176 L
.328 .27864 L
.332 .25398 L
.336 .22898 L
.34 .20492 L
.344 .183 L
.348 .16424 L
.352 .14948 L
.356 .13924 L
.36 .13378 L
.364 .13306 L
.368 .13677 L
.372 .14444 L
.376 .15542 L
.38 .16898 L
.384 .18435 L
.388 .20082 L
.392 .2177 L
.396 .23441 L
.4 .25048 L
Mistroke
.404 .26554 L
.408 .27935 L
.412 .29175 L
.416 .30268 L
.42 .31215 L
.424 .32022 L
.428 .327 L
.432 .33261 L
.436 .33719 L
.44 .34087 L
.444 .34381 L
.448 .34611 L
.452 .3479 L
.456 .34927 L
.46 .35031 L
.464 .35109 L
.468 .35167 L
.472 .3521 L
.476 .35241 L
.48 .35263 L
.484 .35279 L
.488 .3529 L
.492 .35298 L
.496 .35302 L
.5 .35305 L
.504 .35306 L
.508 .35305 L
.512 .35302 L
.516 .35298 L
.52 .3529 L
.524 .35279 L
.528 .35263 L
.532 .35241 L
.536 .3521 L
.54 .35167 L
.544 .35109 L
.548 .35031 L
.552 .34927 L
.556 .3479 L
.56 .34611 L
.564 .34381 L
.568 .34087 L
.572 .33719 L
.576 .33261 L
.58 .327 L
.584 .32022 L
.588 .31215 L
.592 .30268 L
.596 .29175 L
.6 .27935 L
Mistroke
.604 .26554 L
.608 .25048 L
.612 .23441 L
.616 .2177 L
.62 .20082 L
.624 .18436 L
.628 .16898 L
.632 .15542 L
.636 .14445 L
.64 .13678 L
.644 .13306 L
.648 .13379 L
.652 .13925 L
.656 .14948 L
.66 .16425 L
.664 .183 L
.668 .20493 L
.672 .22899 L
.676 .25398 L
.68 .27864 L
.684 .30176 L
.688 .32226 L
.692 .33934 L
.696 .35249 L
.7 .36156 L
.704 .36675 L
.708 .36856 L
.712 .36772 L
.716 .36508 L
.72 .3615 L
.724 .35777 L
.728 .35448 L
.732 .35202 L
.736 .35057 L
.74 .35007 L
.744 .35033 L
.748 .35108 L
.752 .35201 L
.756 .35289 L
.76 .35354 L
.764 .35389 L
.768 .35395 L
.772 .3538 L
.776 .35354 L
.78 .35327 L
.784 .35306 L
.788 .35295 L
.792 .35294 L
.796 .35299 L
.8 .35308 L
Mistroke
.804 .35316 L
.808 .35322 L
.812 .35324 L
.816 .35322 L
.82 .3532 L
.824 .35317 L
.828 .35315 L
.832 .35314 L
.836 .35314 L
.84 .35315 L
.844 .35316 L
.848 .35317 L
.852 .35317 L
.856 .35317 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23176 L
.168 .23175 L
.172 .23175 L
.176 .23174 L
.18 .23175 L
.184 .23177 L
.188 .23179 L
.192 .23181 L
.196 .23182 L
.2 .23181 L
Mistroke
.204 .23176 L
.208 .23169 L
.212 .23162 L
.216 .23157 L
.22 .23158 L
.224 .23168 L
.228 .23185 L
.232 .23208 L
.236 .2323 L
.24 .23242 L
.244 .23237 L
.248 .23208 L
.252 .23153 L
.256 .2308 L
.26 .23001 L
.264 .22939 L
.268 .22917 L
.272 .22959 L
.276 .23081 L
.28 .23287 L
.284 .23563 L
.288 .23877 L
.292 .24177 L
.296 .24399 L
.3 .24469 L
.304 .24317 L
.308 .23882 L
.312 .2312 L
.316 .22016 L
.32 .20583 L
.324 .18861 L
.328 .16921 L
.332 .14851 L
.336 .12753 L
.34 .10734 L
.344 .08893 L
.348 .07319 L
.352 .0608 L
.356 .05221 L
.36 .04763 L
.364 .04702 L
.368 .05015 L
.372 .05659 L
.376 .06581 L
.38 .07719 L
.384 .0901 L
.388 .10392 L
.392 .11809 L
.396 .13212 L
.4 .14561 L
Mistroke
.404 .15826 L
.408 .16985 L
.412 .18026 L
.416 .18943 L
.42 .19738 L
.424 .20416 L
.428 .20985 L
.432 .21456 L
.436 .2184 L
.44 .2215 L
.444 .22396 L
.448 .22589 L
.452 .22739 L
.456 .22855 L
.46 .22942 L
.464 .23008 L
.468 .23057 L
.472 .23093 L
.476 .23119 L
.48 .23138 L
.484 .23151 L
.488 .23161 L
.492 .23168 L
.496 .23174 L
.5 .23178 L
.504 .23181 L
.508 .23185 L
.512 .23189 L
.516 .23194 L
.52 .23202 L
.524 .23211 L
.528 .23225 L
.532 .23244 L
.536 .2327 L
.54 .23306 L
.544 .23355 L
.548 .23421 L
.552 .23508 L
.556 .23623 L
.56 .23773 L
.564 .23967 L
.568 .24213 L
.572 .24522 L
.576 .24907 L
.58 .25378 L
.584 .25947 L
.588 .26624 L
.592 .27419 L
.596 .28337 L
.6 .29378 L
Mistroke
.604 .30537 L
.608 .31801 L
.612 .3315 L
.616 .34553 L
.62 .3597 L
.624 .37353 L
.628 .38644 L
.632 .39782 L
.636 .40703 L
.64 .41348 L
.644 .4166 L
.648 .41599 L
.652 .41141 L
.656 .40282 L
.66 .39043 L
.664 .37469 L
.668 .35629 L
.672 .3361 L
.676 .31512 L
.68 .29442 L
.684 .27501 L
.688 .2578 L
.692 .24346 L
.696 .23243 L
.7 .22481 L
.704 .22046 L
.708 .21894 L
.712 .21964 L
.716 .22186 L
.72 .22486 L
.724 .228 L
.728 .23076 L
.732 .23282 L
.736 .23404 L
.74 .23446 L
.744 .23424 L
.748 .23362 L
.752 .23283 L
.756 .23209 L
.76 .23155 L
.764 .23126 L
.768 .23121 L
.772 .23133 L
.776 .23155 L
.78 .23178 L
.784 .23195 L
.788 .23204 L
.792 .23205 L
.796 .23201 L
.8 .23193 L
Mistroke
.804 .23186 L
.808 .23182 L
.812 .2318 L
.816 .23181 L
.82 .23184 L
.824 .23186 L
.828 .23188 L
.832 .23189 L
.836 .23188 L
.84 .23187 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23187 L
.868 .23187 L
.872 .23187 L
.876 .23187 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23187 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007oo00000`000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol037oo10000goo00@007ooOol000Uoo`80009oo`80009oo`04001oogoo
0002Ool00`00Oomoo`03Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eo
o`002goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`800005
Ool007ooOol00002Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool0
1000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool2
0006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P00
1Woo000LOol2000POol00`00Oomoo`05Ool20019Ool001aoo`03001oogoo01ioo`8000Qoo`8004Qo
o`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool50003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`D000=oo`04001oogooOol30002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`8003]oo`8000Moo`80
02eoo`0077oo00<007ooOol0?7oo00<007ooOol017oo00<007ooOol0;7oo000LOol2000mOol20005
Ool00`00Oomoo`0/Ool001aoo`03001oogoo03eoo`8000=oo`03001oogoo02eoo`002goo0P0017oo
00@007ooOomoo`D0009oo`8003moo`800003Ool007oo02moo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool00`00Oomoo`0oOol2000aOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001c
Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomo
o`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000
Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo
079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`80
00=oo`03001oogoo079oo`002goo0P002goo00@007ooOomoo`8007=oo`0077oo00<007ooOol0LWoo
000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=o
o`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo
0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<0
00=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=o
o`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo
079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Mo
o`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001o
ogoo009oo`<007Qoo`002Woo00@007ooOol000Moo`05001oogooOol0001gOol000=oo`D0009oo`04
001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000]oo`8000Uoo`<000=oo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=o
o`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0
009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo10000goo0P00Lgoo000:Ool01000Oomoo`001goo00<007ooOol017oo00<007ooOol0LWoo000:
Ool01000Oomoo`0027oo00<007ooOol00goo0P00Lgoo000;Ool2000:Ool20003Ool00`00Oomoo`1b
Ool001aoo`8002=oo`8001aoo`03001oogoo02moo`0077oo00<007ooOol08Woo0`006Woo00<007oo
0000<7oo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000SOol00`00Ool0000JOol00`00Ool0
000`Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00008goo00@007ooOol001Yoo`03001oo`00
031oo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo025oo`04001oogoo000IOol0
1000Oomoo`00<7oo000:Ool01000Oomoo`001goo00@007ooOol000=oo`80029oo`05001oogooOol0
000HOol01@00Oomoogoo0000;goo000:Ool01000Oomoo`0027oo00<007oo00000goo00<007ooOol0
8Goo00D007ooOomoo`0001Qoo`05001oogooOol0000_Ool000Yoo`04001oogoo0009Ool20003Ool2
000QOol00`00Oomoo`02Ool00`00Oomoo`0EOol00`00Oomoo`02Ool00`00Oomoo`0]Ool000]oo`80
00]oo`05001oogooOol0000ROol00`00Oomoo`02Ool00`00Oomoo`0EOol00`00Oomoo`02Ool00`00
Oomoo`0]Ool001aoo`80025oo`03001oogoo00=oo`03001oogoo01Aoo`03001oogoo009oo`03001o
ogoo02eoo`0077oo00<007ooOol087oo00<007ooOol00goo00<007ooOol057oo00<007ooOol00goo
00<007ooOol0;7oo000;Ool20004Ool01000Oomoogoo1@000Woo0P008Goo00<007ooOol00goo00<0
07ooOol04goo00<007ooOol017oo00<007ooOol0;7oo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`03001oogoo021oo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo
02aoo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo021oo`03001oogoo
00Aoo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo02aoo`002Woo00@007ooOol000Yoo`04
001oogooOol2000>Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool40003Ool20000
0goo001oo`02Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo00D007ooOomoo`00009oo`04001oogoo0008
Ool20004Ool01000Ool000000Woo00@007ooOol000Eoo`05001oogooOol00002Ool20002Ool00`00
Oomoo`020004Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00
Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P004Goo00@007ooOol0009oo`03001oogoo00Ioo`8000Aoo`04001oo`000002Ool01000
Oomoo`001Goo00<007ooOol017oo0P000Woo00<007ooOol00P001Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;
Ool20009Ool30003Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01Woo0P0017oo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`04Ool20002Ool01P00Oomoo`00Ool000Eoo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0
009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Qoo`8000Aoo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`06001oogoo001oo`000Woo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00<007oo
Ool00P0000Eoo`00Oomoo`0000Aoo`8000=oo`03001oo`0000Aoo`06001oogoo001oo`000Woo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool0
1000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool20008Ool00`00Ool00005Ool2000017oo
001oogoo0P001Woo00@007ooOomoo`D000=oo`80009oo`04001oogooOol30004Ool20004Ool20006
Ool30002Ool50003Ool20006Ool001aoo`8001moo`03001oogoo00Uoo`03001oogoo00]oo`8000]o
o`03001oogoo02Yoo`0077oo00<007ooOol07Woo00<007ooOol02Woo0P002Woo0P0037oo00<007oo
Ool0:Woo000LOomY000<Ool001aoo`03001oogoo019oo`03001oogoo00Ioo`<000Uoo`03001oogoo
015oo`03001oogoo00Qoo`<000Moo`03001oogoo019oo`03001oogoo00Yoo`0077oo0P00Lgoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
00]oo`8000Aoo`04001oogooOol50002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00<007ooOol0LWoo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00Lgoo000:Ool01000
Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2
001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009
Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool0
0`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:
Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03
001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol0
00Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00D007ooOomoo`0007Aoo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1b
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`0ROol2001>Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8002=o
o`<004eoo`002Woo00@007ooOol000Yoo`05001oogooOol0000TOol00`00Ool0001=Ool000=oo`D0
009oo`04001oogoo0007Ool50002Ool2000ROol01000Oomoo`00CGoo000:Ool01000Oomoo`001goo
00@007ooOol000=oo`03001oogoo025oo`04001oogoo001=Ool000Yoo`04001oogoo0008Ool00`00
Ool00003Ool2000ROol01@00Oomoogoo0000C7oo000:Ool01000Oomoo`002Goo0P000goo00<007oo
Ool08Goo00D007ooOomoo`0004aoo`002goo0P002goo00@007ooOomoo`80025oo`03001oogoo009o
o`03001oogoo04Yoo`0077oo00<007ooOol087oo00<007ooOol00goo00<007ooOol0BGoo000;Ool2
0004Ool01000Oomoogoo1@000Woo0P008Goo00<007ooOol00goo00<007ooOol0BGoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`80
00Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`00
0goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`8000eoo`05001oogooOol00002Ool01000
Oomoo`002Goo00<007ooOol00Woo00@007oo0000009oo`04001oogoo0005Ool01@00Oomoogoo0000
0goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Yoo`05001oogooOol0000BOol01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo
00@007oo0000009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
17oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04
001oogoo0002Ool00`00Oomoo`06Ool20004Ool01000Ool000000Woo00@007ooOol000Eoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo10000goo00@007ooOol000Qoo`8000Ao
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04
001oogoo0005Ool000]oo`8000Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008Ool2
0004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`00
00Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Uoo`8000Eoo`800004Ool0
07ooOol20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@00
0goo0P001Woo000LOol2000OOol00`00Oomoo`08Ool00`00Oomoo`16Ool001aoo`03001oogoo01io
o`03001oogoo00Uoo`8001Yoo`8002Yoo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool200000goo00000003Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00@007ooOomoo`H0009oo`05001oogooOol00003Ool00`00
Ool00002Ool50003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03
001oogoo00Yoo`0077oo0P007Goo0P006Woo0P002goo00<007ooOol0:Woo000LOol00`00Oomoo`0i
Ool20009Ool00`00Oomoo`0[Ool001aoo`8003]oo`03001oogoo00Moo`03001oogoo02]oo`0077oo
00<007ooOol0>Woo00<007ooOol01goo00<007ooOol0:goo000;Ool20004Ool01000Oomoogoo1@00
0Woo0P00?7oo00<007ooOol01Woo00<007ooOol0:goo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`03001oogoo03]oo`03001oogoo00Eoo`03001oogoo02aoo`002Woo00@007ooOol000Uoo`03
001oogoo009oo`8003eoo`03001oogoo00Aoo`03001oogoo02aoo`002Woo00@007ooOol000Yoo`05
001oogooOol0000nOol00`00Oomoo`04Ool00`00Oomoo`0/Ool000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo0P00?Goo00<007ooOol017oo00<007ooOol0;7oo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo03aoo`03001oogoo00Aoo`03001oogoo02aoo`002goo0P00
2Goo0`000goo0P00?Woo00<007ooOol00goo00<007ooOol0;7oo000LOol00`00Oomoo`0mOol00`00
Oomoo`02Ool00`00Oomoo`0]Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8003ioo`03001o
ogoo009oo`03001oogoo02eoo`002Woo00@007ooOol000Yoo`05001oogooOol00010Ool01@00Oomo
ogoo0000;goo000:Ool01000Oomoo`001goo1@000Woo0P00?goo00D007ooOomoo`0002moo`002Woo
00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0nOol01000Oomoo`00<7oo000:Ool01000
Oomoo`0027oo00<007oo00000goo0P00@7oo00<007oo0000<7oo000:Ool01000Oomoo`002Goo0P00
0goo00<007ooOol0?goo0`00<7oo000;Ool2000;Ool01000Oomoogoo0P00@Goo00<007ooOol0;goo
000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo
00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P00
17oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04
001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo
0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<0
07ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Mo
o`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2880\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23178 L
.164 .23178 L
.168 .23178 L
.172 .23178 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23178 L
.2 .23179 L
Mistroke
.204 .23179 L
.208 .2318 L
.212 .23179 L
.216 .23177 L
.22 .23175 L
.224 .23172 L
.228 .2317 L
.232 .23171 L
.236 .23175 L
.24 .23181 L
.244 .23189 L
.248 .23197 L
.252 .23201 L
.256 .23198 L
.26 .23187 L
.264 .23167 L
.268 .23141 L
.272 .23114 L
.276 .23093 L
.28 .23087 L
.284 .23103 L
.288 .23147 L
.292 .23219 L
.296 .23315 L
.3 .23423 L
.304 .23525 L
.308 .236 L
.312 .23622 L
.316 .23568 L
.32 .23418 L
.324 .23158 L
.328 .22784 L
.332 .223 L
.336 .21721 L
.34 .21071 L
.344 .2038 L
.348 .19681 L
.352 .1901 L
.356 .184 L
.36 .1788 L
.364 .17473 L
.368 .17192 L
.372 .17044 L
.376 .17028 L
.38 .17135 L
.384 .17352 L
.388 .17661 L
.392 .1804 L
.396 .1847 L
.4 .18929 L
Mistroke
.404 .194 L
.408 .19866 L
.412 .20314 L
.416 .20733 L
.42 .21118 L
.424 .21464 L
.428 .21769 L
.432 .22033 L
.436 .22258 L
.44 .22447 L
.444 .22604 L
.448 .22732 L
.452 .22836 L
.456 .22918 L
.46 .22982 L
.464 .23033 L
.468 .23071 L
.472 .23101 L
.476 .23123 L
.48 .2314 L
.484 .23152 L
.488 .23161 L
.492 .23168 L
.496 .23173 L
.5 .23178 L
.504 .23181 L
.508 .23185 L
.512 .2319 L
.516 .23195 L
.52 .23202 L
.524 .23211 L
.528 .23223 L
.532 .2324 L
.536 .23262 L
.54 .23292 L
.544 .2333 L
.548 .23381 L
.552 .23445 L
.556 .23528 L
.56 .23631 L
.564 .23759 L
.568 .23916 L
.572 .24105 L
.576 .2433 L
.58 .24594 L
.584 .24899 L
.588 .25244 L
.592 .25628 L
.596 .26048 L
.6 .26495 L
Mistroke
.604 .2696 L
.608 .2743 L
.612 .27889 L
.616 .28319 L
.62 .28698 L
.624 .29006 L
.628 .29223 L
.632 .29331 L
.636 .29315 L
.64 .29168 L
.644 .28888 L
.648 .28481 L
.652 .27961 L
.656 .27352 L
.66 .26681 L
.664 .25982 L
.668 .25291 L
.672 .2464 L
.676 .2406 L
.68 .23576 L
.684 .232 L
.688 .2294 L
.692 .22789 L
.696 .22734 L
.7 .22756 L
.704 .2283 L
.708 .22933 L
.712 .23041 L
.716 .23138 L
.72 .23211 L
.724 .23256 L
.728 .23272 L
.732 .23266 L
.736 .23245 L
.74 .23218 L
.744 .23191 L
.748 .23171 L
.752 .2316 L
.756 .23157 L
.76 .23161 L
.764 .23168 L
.768 .23177 L
.772 .23183 L
.776 .23187 L
.78 .23188 L
.784 .23186 L
.788 .23184 L
.792 .23181 L
.796 .23179 L
.8 .23179 L
Mistroke
.804 .23179 L
.808 .2318 L
.812 .23181 L
.816 .23181 L
.82 .23182 L
.824 .23182 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35317 L
.164 .35317 L
.168 .35317 L
.172 .35317 L
.176 .35316 L
.18 .35315 L
.184 .35314 L
.188 .35314 L
.192 .35315 L
.196 .35317 L
.2 .3532 L
Mistroke
.204 .35323 L
.208 .35324 L
.212 .35322 L
.216 .35315 L
.22 .35306 L
.224 .35297 L
.228 .35292 L
.232 .35294 L
.236 .35307 L
.24 .3533 L
.244 .35358 L
.248 .35385 L
.252 .35399 L
.256 .35391 L
.26 .35352 L
.264 .35282 L
.268 .3519 L
.272 .35093 L
.276 .35018 L
.28 .34995 L
.284 .35051 L
.288 .35206 L
.292 .35463 L
.296 .35804 L
.3 .36187 L
.304 .36551 L
.308 .36816 L
.312 .36896 L
.316 .36705 L
.32 .36172 L
.324 .35247 L
.328 .33913 L
.332 .32188 L
.336 .30123 L
.34 .27801 L
.344 .2533 L
.348 .22832 L
.352 .20433 L
.356 .1825 L
.36 .16389 L
.364 .14928 L
.368 .1392 L
.372 .13388 L
.376 .13328 L
.38 .13709 L
.384 .14482 L
.388 .15583 L
.392 .16939 L
.396 .18474 L
.4 .20117 L
Mistroke
.404 .218 L
.408 .23465 L
.412 .25066 L
.416 .26567 L
.42 .27943 L
.424 .29178 L
.428 .30268 L
.432 .31213 L
.436 .32018 L
.44 .32695 L
.444 .33255 L
.448 .33713 L
.452 .34082 L
.456 .34375 L
.46 .34606 L
.464 .34785 L
.468 .34923 L
.472 .35028 L
.476 .35106 L
.48 .35164 L
.484 .35206 L
.488 .35237 L
.492 .35258 L
.496 .35271 L
.5 .35279 L
.504 .35281 L
.508 .35279 L
.512 .35271 L
.516 .35258 L
.52 .35237 L
.524 .35206 L
.528 .35164 L
.532 .35106 L
.536 .35028 L
.54 .34923 L
.544 .34785 L
.548 .34606 L
.552 .34375 L
.556 .34082 L
.56 .33713 L
.564 .33255 L
.568 .32695 L
.572 .32018 L
.576 .31213 L
.58 .30268 L
.584 .29179 L
.588 .27943 L
.592 .26567 L
.596 .25066 L
.6 .23466 L
Mistroke
.604 .218 L
.608 .20117 L
.612 .18475 L
.616 .16939 L
.62 .15583 L
.624 .14483 L
.628 .1371 L
.632 .13328 L
.636 .13389 L
.64 .1392 L
.644 .14928 L
.648 .16389 L
.652 .18251 L
.656 .20433 L
.66 .22832 L
.664 .2533 L
.668 .27801 L
.672 .30123 L
.676 .32188 L
.68 .33913 L
.684 .35247 L
.688 .36172 L
.692 .36705 L
.696 .36896 L
.7 .36816 L
.704 .36551 L
.708 .36187 L
.712 .35804 L
.716 .35463 L
.72 .35206 L
.724 .35051 L
.728 .34995 L
.732 .35018 L
.736 .35093 L
.74 .3519 L
.744 .35282 L
.748 .35352 L
.752 .35391 L
.756 .35399 L
.76 .35385 L
.764 .35358 L
.768 .3533 L
.772 .35307 L
.776 .35294 L
.78 .35292 L
.784 .35297 L
.788 .35306 L
.792 .35315 L
.796 .35322 L
.8 .35324 L
Mistroke
.804 .35323 L
.808 .3532 L
.812 .35317 L
.816 .35315 L
.82 .35314 L
.824 .35314 L
.828 .35315 L
.832 .35316 L
.836 .35317 L
.84 .35317 L
.844 .35317 L
.848 .35317 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23176 L
.18 .23175 L
.184 .23174 L
.188 .23174 L
.192 .23175 L
.196 .23177 L
.2 .2318 L
Mistroke
.204 .23182 L
.208 .23183 L
.212 .23181 L
.216 .23176 L
.22 .23168 L
.224 .2316 L
.228 .23156 L
.232 .23158 L
.236 .23168 L
.24 .23187 L
.244 .23212 L
.248 .23234 L
.252 .23246 L
.256 .23239 L
.26 .23206 L
.264 .23148 L
.268 .2307 L
.272 .22989 L
.276 .22926 L
.28 .22906 L
.284 .22954 L
.288 .23084 L
.292 .23299 L
.296 .23585 L
.3 .23907 L
.304 .24213 L
.308 .24436 L
.312 .24502 L
.316 .24342 L
.32 .23894 L
.324 .23118 L
.328 .21999 L
.332 .2055 L
.336 .18817 L
.34 .16868 L
.344 .14794 L
.348 .12697 L
.352 .10683 L
.356 .08852 L
.36 .07289 L
.364 .06063 L
.368 .05217 L
.372 .04771 L
.376 .04721 L
.38 .05041 L
.384 .05691 L
.388 .06615 L
.392 .07753 L
.396 .09043 L
.4 .10422 L
Mistroke
.404 .11834 L
.408 .13233 L
.412 .14577 L
.416 .15837 L
.42 .16991 L
.424 .18029 L
.428 .18944 L
.432 .19736 L
.436 .20413 L
.44 .20981 L
.444 .21451 L
.448 .21835 L
.452 .22145 L
.456 .22392 L
.46 .22585 L
.464 .22736 L
.468 .22852 L
.472 .2294 L
.476 .23007 L
.48 .23056 L
.484 .23093 L
.488 .23121 L
.492 .23141 L
.496 .23157 L
.5 .2317 L
.504 .23181 L
.508 .23193 L
.512 .23206 L
.516 .23222 L
.52 .23242 L
.524 .2327 L
.528 .23307 L
.532 .23356 L
.536 .23423 L
.54 .23511 L
.544 .23627 L
.548 .23777 L
.552 .23971 L
.556 .24218 L
.56 .24527 L
.564 .24912 L
.568 .25382 L
.572 .2595 L
.576 .26626 L
.58 .27419 L
.584 .28334 L
.588 .29371 L
.592 .30526 L
.596 .31786 L
.6 .3313 L
Mistroke
.604 .34528 L
.608 .35941 L
.612 .3732 L
.616 .38609 L
.62 .39747 L
.624 .40672 L
.628 .41321 L
.632 .41641 L
.636 .41591 L
.64 .41145 L
.644 .40299 L
.648 .39073 L
.652 .37511 L
.656 .35679 L
.66 .33665 L
.664 .31569 L
.668 .29495 L
.672 .27546 L
.676 .25812 L
.68 .24364 L
.684 .23245 L
.688 .22469 L
.692 .22021 L
.696 .2186 L
.7 .21927 L
.704 .2215 L
.708 .22455 L
.712 .22777 L
.716 .23063 L
.72 .23279 L
.724 .23409 L
.728 .23456 L
.732 .23437 L
.736 .23374 L
.74 .23293 L
.744 .23215 L
.748 .23157 L
.752 .23124 L
.756 .23117 L
.76 .23129 L
.764 .23151 L
.768 .23175 L
.772 .23194 L
.776 .23205 L
.78 .23207 L
.784 .23202 L
.788 .23195 L
.792 .23187 L
.796 .23182 L
.8 .2318 L
Mistroke
.804 .23181 L
.808 .23183 L
.812 .23186 L
.816 .23188 L
.82 .23189 L
.824 .23188 L
.828 .23188 L
.832 .23187 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23187 L
.856 .23187 L
.86 .23187 L
.864 .23187 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23187 L
.896 .23187 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00`000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol037oo10000goo00@007ooOol000Uoo`03001oo`00009oo`800005Ool0
07ooOol00002Ool00`00Oomoo`03Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007oo
Ool000Eoo`002goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`800006
Ool007ooOol007oo0P000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`00
00Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`8000Aoo`<000=oo`80
00Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006
Ool001aoo`80025oo`03001oogoo00Eoo`8004Qoo`0077oo00<007ooOol087oo00<007ooOol01Woo
0P00Agoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`03001oo`00008000=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000Woo100000=oo`00Ool00Woo00D007ooOomoo`0000Aoo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo
00Yoo`0077oo0P00>Woo0P001goo0P00;Woo000LOol00`00Oomoo`0jOol20006Ool00`00Oomoo`0]
Ool001aoo`8003aoo`8000Aoo`03001oogoo02ioo`0077oo00<007ooOol0?7oo00<007ooOol00Woo
00<007ooOol0;Woo000;Ool20004Ool01000Oomoogoo1@000Woo0P00?Woo1000<Goo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`03001oogoo03ioo`80039oo`002Woo00@007ooOol000Uoo`03
001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0
001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomo
o`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool0
1000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000L
Ool00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<0
07ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo
00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001o
ogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P00
2Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007oo
Ool00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`00
5goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
2goo0P0017oo00<007ooOol00Woo0`00N7oo000:Ool01000Oomoo`001goo00D007ooOomoo`0007Mo
o`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo
0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002goo0P002Goo
0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<0
07ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo079oo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool40003Ool2001cOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool2001cOol000]oo`8000Yoo`80
00=oo`03001oogoo079oo`0077oo0P009Goo00<007ooOol067oo00<007ooOol0<7oo000LOol00`00
Oomoo`0SOol3000HOol2000bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8002Aoo`03001o
o`0001Qoo`03001oo`00035oo`002Woo00@007ooOol000Yoo`05001oogooOol0000TOol01000Oomo
o`005goo00@007ooOol0035oo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo029o
o`05001oogooOol0000FOol01000Oomoo`00<Goo000:Ool01000Oomoo`001goo00@007ooOol000=o
o`8002=oo`05001oogooOol0000FOol01@00Oomoogoo0000<7oo000:Ool01000Oomoo`0027oo00<0
07oo00000goo00<007ooOol08Woo00D007ooOomoo`0001Eoo`03001oogoo009oo`03001oogoo02io
o`002Woo00@007ooOol000Uoo`8000=oo`8002=oo`03001oogoo009oo`03001oogoo019oo`03001o
ogoo009oo`03001oogoo02ioo`002goo0P002goo00D007ooOomoo`0002Aoo`03001oogoo009oo`03
001oogoo019oo`03001oogoo009oo`03001oogoo02ioo`0077oo0P008goo00<007ooOol00Woo00<0
07ooOol04Woo00<007ooOol00Woo00<007ooOol0;Woo000LOol00`00Oomoo`0QOol00`00Oomoo`03
Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0^Ool000]oo`8000Aoo`04001oogooOol5
0002Ool2000ROol00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0^Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol08Goo00<007ooOol017oo00<007oo
Ool047oo00<007ooOol017oo00<007ooOol0;Goo0003Ool50002Ool01000Oomoo`002Goo00<007oo
Ool00Woo00<007ooOol08Goo00<007ooOol017oo00<007ooOol047oo00<007ooOol017oo00<007oo
Ool0;Goo000:Ool01000Oomoo`002Woo00@007ooOomoo`8000ioo`<000Aoo`8000Uoo`<000Aoo`<0
00=oo`8000Eoo`<000=oo`<000Aoo`<000Aoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`80
00Ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool01@00Oomoogoo
00000Woo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo00800005Ool007ooOol00005Ool0
2@00Oomoogoo001oo`00Ool00002Ool01000Oomoo`001Goo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04001oogoo0002Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool00`00Oomoo`0200001Goo001oogoo00001Goo00<007ooOol00goo00<007oo
00000Woo00@007ooOol000Ioo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Goo0`000goo00<007ooOol0
47oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00800005Ool007oo
Ool00005Ool00`00Oomoo`03Ool00`00Ool00002Ool00`00Oomoo`020006Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`020000
1Goo001oogoo00001Goo00@007ooOomoo`@000=oo`03001oogoo008000=oo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eo
o`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`05001oogoo001o
o`020002Ool00`00Oomoo`02Ool20003Ool20005Ool00`00Oomoo`020003Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`03001oogoo00=oo`8000=oo`<000Ioo`04001o
ogooOol50003Ool200000goo001oo`03Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006
Ool001aoo`80021oo`03001oogoo00Uoo`8000Yoo`8000Yoo`03001oogoo02aoo`0077oo00<007oo
Ool07goo00<007ooOol02Woo0`001Woo0`002goo00<007ooOol0;7oo000LOomY000<Ool001aoo`03
001oogoo019oo`03001oogoo00Moo`<000Qoo`03001oogoo015oo`03001oogoo00Ioo`<000Uoo`03
001oogoo019oo`03001oogoo00Yoo`0077oo0P007Woo00<007ooOol09Goo00<007ooOol0:Woo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
00]oo`8000Aoo`04001oogooOol50002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00<007ooOol0LWoo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00Lgoo000:Ool01000
Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2
001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009
Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool0
0`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:
Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03
001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol0
00Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00D007ooOomoo`0007Aoo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1b
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`0TOol00`00Oomoo`1;Ool000]oo`8000Aoo`03001oogoo00=oo`<0009o
o`8002Aoo`<004aoo`002Woo00@007ooOol000Yoo`05001oogooOol0000UOol00`00Ool0001<Ool0
00=oo`D0009oo`04001oogoo0007Ool50002Ool2000SOol01000Oomoo`00C7oo000:Ool01000Oomo
o`001goo00@007ooOol000=oo`03001oogoo029oo`05001oogooOol0001;Ool000Yoo`04001oogoo
0008Ool00`00Ool00003Ool2000SOol01@00Oomoogoo0000Bgoo000:Ool01000Oomoo`002Goo0P00
0goo00<007ooOol08Woo00<007ooOol00Woo00<007ooOol0B7oo000;Ool2000;Ool01000Oomoogoo
0P008goo00<007ooOol00Woo00<007ooOol0B7oo000LOol00`00Oomoo`0ROol00`00Oomoo`02Ool0
0`00Oomoo`18Ool000]oo`8000Aoo`04001oogooOol50002Ool2000ROol00`00Oomoo`03Ool00`00
Oomoo`18Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol03Goo0`0017oo0P00
2Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@00
0Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo0P003Goo00D0
07ooOomoo`00009oo`04001oogoo0009Ool20003Ool01000Oomoo`000Woo00@007ooOol000Eoo`05
001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo
000:Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`04001oogoo0002Ool00`00Oomoo`07Ool2
0003Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00
4Goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00800005Ool007oo
Ool00005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009o
o`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol0
0goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`@000=oo`04001o
ogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0200001Goo001oogoo00001Goo00@007ooOomoo`@0
00=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool0
1P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uoo`<000=oo`8000eoo`03001o
ogoo00Aoo`04001oogoo0008Ool20004Ool00`00Oomoo`0200001Goo001oogoo000017oo0P000goo
00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@00
0goo0P002Woo00<007ooOol00goo0P000Woo00@007oo000000Ioo`04001oogooOol50003Ool20006
Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`80025oo`03001oogoo00Mo
o`8004Ioo`0077oo00<007ooOol07goo00<007ooOol02Goo0P0067oo0P00:goo000LOomY000<Ool0
01aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00@007ooOomoo`<0
0006Ool00000001oo`000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`04001oogooOol50003
Ool01@00Oomoogoo00000goo0P000goo0`0000=oo`00Ool00Woo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`8001ioo`8001Qoo`8000Yoo`03
001oogoo02aoo`0077oo00<007ooOol0>7oo00<007ooOol027oo00<007ooOol0;7oo000LOol2000j
Ool00`00Oomoo`07Ool00`00Oomoo`0/Ool001aoo`03001oogoo03Uoo`03001oogoo00Moo`03001o
ogoo02aoo`002goo0P0017oo00@007ooOomoo`D0009oo`8003]oo`03001oogoo00Ioo`03001oogoo
02aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0jOol00`00Oomoo`05Ool0
0`00Oomoo`0]Ool000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000kOol00`00Oomoo`05Ool0
0`00Oomoo`0]Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000?Goo00<007ooOol017oo00<0
07ooOol0;Goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8003aoo`03001oogoo00Ao
o`03001oogoo02eoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0kOol0
0`00Oomoo`03Ool00`00Oomoo`0^Ool000]oo`8000Uoo`<000=oo`8003eoo`03001oogoo009oo`03
001oogoo02ioo`0077oo00<007ooOol0?7oo00<007ooOol00Woo00<007ooOol0;Woo000;Ool20004
Ool00`00Oomoo`03Ool30002Ool2000mOol00`00Oomoo`02Ool00`00Oomoo`0^Ool000Yoo`04001o
ogoo000:Ool01@00Oomoogoo0000?Woo00<007ooOol00Woo00<007ooOol0;Woo000:Ool01000Oomo
o`001goo1@000Woo0P00?Woo00D007ooOomoo`00031oo`002Woo00@007ooOol000Moo`04001oogoo
0003Ool00`00Oomoo`0mOol01000Oomoo`00<Goo000:Ool01000Oomoo`0027oo00<007oo00000goo
0P00?Woo00@007ooOol0035oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo03ioo`80039o
o`002goo0P002goo00@007ooOomoo`80041oo`03001oogoo031oo`0077oo00<007ooOol0LWoo000;
Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`00
2Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo
00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P00
2Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=o
o`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`00
77oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079o
o`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`00
5Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2920\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23178 L
.176 .23178 L
.18 .23178 L
.184 .23178 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23178 L
.212 .23179 L
.216 .2318 L
.22 .2318 L
.224 .23179 L
.228 .23177 L
.232 .23174 L
.236 .23171 L
.24 .2317 L
.244 .23171 L
.248 .23175 L
.252 .23182 L
.256 .23191 L
.26 .23199 L
.264 .23202 L
.268 .23199 L
.272 .23187 L
.276 .23165 L
.28 .23138 L
.284 .2311 L
.288 .23089 L
.292 .23083 L
.296 .23102 L
.3 .23148 L
.304 .23224 L
.308 .23323 L
.312 .23434 L
.316 .23538 L
.32 .23612 L
.324 .23633 L
.328 .23576 L
.332 .23422 L
.336 .23157 L
.34 .22777 L
.344 .22289 L
.348 .21706 L
.352 .21053 L
.356 .20361 L
.36 .19663 L
.364 .18993 L
.368 .18387 L
.372 .17871 L
.376 .17467 L
.38 .17191 L
.384 .17047 L
.388 .17034 L
.392 .17144 L
.396 .17363 L
.4 .17672 L
Mistroke
.404 .18052 L
.408 .18481 L
.412 .18939 L
.416 .19408 L
.42 .19873 L
.424 .20319 L
.428 .20737 L
.432 .2112 L
.436 .21465 L
.44 .21769 L
.444 .22032 L
.448 .22257 L
.452 .22446 L
.456 .22603 L
.46 .22731 L
.464 .22834 L
.468 .22917 L
.472 .22982 L
.476 .23032 L
.48 .23072 L
.484 .23102 L
.488 .23125 L
.492 .23144 L
.496 .23158 L
.5 .2317 L
.504 .23181 L
.508 .23193 L
.512 .23205 L
.516 .23219 L
.52 .23237 L
.524 .23261 L
.528 .23291 L
.532 .23331 L
.536 .23381 L
.54 .23446 L
.544 .23529 L
.548 .23632 L
.552 .2376 L
.556 .23917 L
.56 .24106 L
.564 .24331 L
.568 .24594 L
.572 .24898 L
.576 .25242 L
.58 .25625 L
.584 .26042 L
.588 .26488 L
.592 .26952 L
.596 .27421 L
.6 .27879 L
Mistroke
.604 .28307 L
.608 .28687 L
.612 .28996 L
.616 .29214 L
.62 .29325 L
.624 .29312 L
.628 .29169 L
.632 .28893 L
.636 .2849 L
.64 .27975 L
.644 .27368 L
.648 .267 L
.652 .26001 L
.656 .25308 L
.66 .24655 L
.664 .24072 L
.668 .23582 L
.672 .23201 L
.676 .22936 L
.68 .22781 L
.684 .22723 L
.688 .22743 L
.692 .22818 L
.696 .22922 L
.7 .23033 L
.704 .23133 L
.708 .2321 L
.712 .23257 L
.716 .23276 L
.72 .2327 L
.724 .23249 L
.728 .23221 L
.732 .23193 L
.736 .23172 L
.74 .23159 L
.744 .23156 L
.748 .23159 L
.752 .23167 L
.756 .23176 L
.76 .23183 L
.764 .23187 L
.768 .23188 L
.772 .23187 L
.776 .23184 L
.78 .23181 L
.784 .23179 L
.788 .23178 L
.792 .23179 L
.796 .23179 L
.8 .2318 L
Mistroke
.804 .23181 L
.808 .23182 L
.812 .23182 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35317 L
.176 .35317 L
.18 .35317 L
.184 .35317 L
.188 .35316 L
.192 .35315 L
.196 .35313 L
.2 .35313 L
Mistroke
.204 .35315 L
.208 .35318 L
.212 .35321 L
.216 .35324 L
.22 .35325 L
.224 .35321 L
.228 .35314 L
.232 .35305 L
.236 .35295 L
.24 .3529 L
.244 .35294 L
.248 .35308 L
.252 .35333 L
.256 .35363 L
.26 .35391 L
.264 .35404 L
.268 .35393 L
.272 .3535 L
.276 .35275 L
.28 .35178 L
.284 .35078 L
.288 .35003 L
.292 .34983 L
.296 .35046 L
.3 .35211 L
.304 .35479 L
.308 .35831 L
.312 .36224 L
.316 .36594 L
.32 .36861 L
.324 .36935 L
.328 .36734 L
.332 .36186 L
.336 .35244 L
.34 .33891 L
.344 .32149 L
.348 .30069 L
.352 .27738 L
.356 .25263 L
.36 .22766 L
.364 .20373 L
.368 .18202 L
.372 .16354 L
.376 .14909 L
.38 .13916 L
.384 .13398 L
.388 .1335 L
.392 .13741 L
.396 .1452 L
.4 .15624 L
Mistroke
.404 .1698 L
.408 .18513 L
.412 .20152 L
.416 .2183 L
.42 .23489 L
.424 .25085 L
.428 .2658 L
.432 .27951 L
.436 .29182 L
.44 .30268 L
.444 .3121 L
.448 .32014 L
.452 .32689 L
.456 .33249 L
.46 .33706 L
.464 .34075 L
.468 .34368 L
.472 .34599 L
.476 .34778 L
.48 .34914 L
.484 .35017 L
.488 .35092 L
.492 .35146 L
.496 .35181 L
.5 .35201 L
.504 .35208 L
.508 .35201 L
.512 .35181 L
.516 .35146 L
.52 .35092 L
.524 .35017 L
.528 .34914 L
.532 .34778 L
.536 .34599 L
.54 .34368 L
.544 .34075 L
.548 .33706 L
.552 .33249 L
.556 .32689 L
.56 .32014 L
.564 .3121 L
.568 .30268 L
.572 .29182 L
.576 .27951 L
.58 .2658 L
.584 .25085 L
.588 .2349 L
.592 .2183 L
.596 .20152 L
.6 .18514 L
Mistroke
.604 .1698 L
.608 .15624 L
.612 .1452 L
.616 .13741 L
.62 .13351 L
.624 .13399 L
.628 .13916 L
.632 .14909 L
.636 .16355 L
.64 .18202 L
.644 .20374 L
.648 .22766 L
.652 .25263 L
.656 .27738 L
.66 .30069 L
.664 .32149 L
.668 .33891 L
.672 .35244 L
.676 .36186 L
.68 .36734 L
.684 .36935 L
.688 .36861 L
.692 .36594 L
.696 .36224 L
.7 .35831 L
.704 .35479 L
.708 .35211 L
.712 .35046 L
.716 .34983 L
.72 .35003 L
.724 .35078 L
.728 .35178 L
.732 .35275 L
.736 .3535 L
.74 .35393 L
.744 .35404 L
.748 .35391 L
.752 .35363 L
.756 .35333 L
.76 .35308 L
.764 .35294 L
.768 .3529 L
.772 .35295 L
.776 .35305 L
.78 .35314 L
.784 .35321 L
.788 .35325 L
.792 .35324 L
.796 .35321 L
.8 .35318 L
Mistroke
.804 .35315 L
.808 .35313 L
.812 .35314 L
.816 .35315 L
.82 .35316 L
.824 .35317 L
.828 .35317 L
.832 .35317 L
.836 .35317 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23176 L
.192 .23175 L
.196 .23174 L
.2 .23174 L
Mistroke
.204 .23175 L
.208 .23177 L
.212 .2318 L
.216 .23183 L
.22 .23183 L
.224 .23181 L
.228 .23175 L
.232 .23166 L
.236 .23159 L
.24 .23154 L
.244 .23157 L
.248 .23169 L
.252 .2319 L
.256 .23216 L
.26 .23239 L
.264 .2325 L
.268 .2324 L
.272 .23204 L
.276 .23141 L
.28 .2306 L
.284 .22976 L
.288 .22913 L
.292 .22896 L
.296 .2295 L
.3 .23088 L
.304 .23313 L
.308 .23609 L
.312 .23939 L
.316 .24249 L
.32 .24473 L
.324 .24535 L
.328 .24366 L
.332 .23906 L
.336 .23115 L
.34 .2198 L
.344 .20517 L
.348 .18772 L
.352 .16815 L
.356 .14737 L
.36 .12642 L
.364 .10633 L
.368 .08811 L
.372 .0726 L
.376 .06047 L
.38 .05214 L
.384 .0478 L
.388 .0474 L
.392 .05068 L
.396 .05722 L
.4 .06649 L
Mistroke
.404 .07788 L
.408 .09075 L
.412 .10451 L
.416 .1186 L
.42 .13253 L
.424 .14592 L
.428 .15847 L
.432 .16998 L
.436 .18032 L
.44 .18944 L
.444 .19735 L
.448 .20409 L
.452 .20977 L
.456 .21447 L
.46 .21831 L
.464 .22141 L
.468 .22388 L
.472 .22583 L
.476 .22735 L
.48 .22853 L
.484 .22944 L
.488 .23014 L
.492 .23068 L
.496 .23112 L
.5 .23148 L
.504 .23181 L
.508 .23215 L
.512 .23251 L
.516 .23294 L
.52 .23349 L
.524 .23419 L
.528 .23509 L
.532 .23627 L
.536 .23779 L
.54 .23974 L
.544 .24222 L
.548 .24532 L
.552 .24916 L
.556 .25386 L
.56 .25953 L
.564 .26628 L
.568 .27419 L
.572 .28331 L
.576 .29365 L
.58 .30515 L
.584 .3177 L
.588 .3311 L
.592 .34503 L
.596 .35911 L
.6 .37287 L
Mistroke
.604 .38575 L
.608 .39713 L
.612 .4064 L
.616 .41294 L
.62 .41623 L
.624 .41582 L
.628 .41148 L
.632 .40315 L
.636 .39102 L
.64 .37551 L
.644 .35729 L
.648 .33721 L
.652 .31625 L
.656 .29548 L
.66 .27591 L
.664 .25845 L
.668 .24383 L
.672 .23248 L
.676 .22457 L
.68 .21996 L
.684 .21827 L
.688 .2189 L
.692 .22114 L
.696 .22424 L
.7 .22754 L
.704 .2305 L
.708 .23275 L
.712 .23413 L
.716 .23466 L
.72 .2345 L
.724 .23386 L
.728 .23303 L
.732 .23221 L
.736 .23159 L
.74 .23122 L
.744 .23113 L
.748 .23124 L
.752 .23147 L
.756 .23172 L
.76 .23193 L
.764 .23205 L
.768 .23208 L
.772 .23204 L
.776 .23196 L
.78 .23188 L
.784 .23182 L
.788 .23179 L
.792 .2318 L
.796 .23182 L
.8 .23185 L
Mistroke
.804 .23188 L
.808 .23189 L
.812 .23189 L
.816 .23188 L
.82 .23187 L
.824 .23186 L
.828 .23186 L
.832 .23186 L
.836 .23186 L
.84 .23186 L
.844 .23187 L
.848 .23187 L
.852 .23187 L
.856 .23187 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23187 L
.884 .23187 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00@007ooOomoo`<00005Ool007ooOol00002Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`0300000goo0000
0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005
Ool000]oo`8000Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008Ool20002Ool00`00
Ool00002Ool01000Oomoo`000Woo00<007ooOol00Woo0P000goo00<007ooOol017oo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo
00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007oo00000goo
0P0000Aoo`00Oomoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool3
0002Ool50003Ool20006Ool001aoo`8002=oo`03001oogoo00Aoo`8004Moo`0077oo00<007ooOol0
8Goo00<007ooOol01goo0P00AGoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo00@00003Ool007oo00=o
o`05001oogooOol00003Ool01P00Oomoogoo001oo`@0009oo`05001oogooOol00002Ool20004Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool0
0`00Oomoo`0:Ool001aoo`8003Uoo`8000Moo`03001oogoo02ioo`0077oo00<007ooOol0>Goo0P00
1Woo00<007ooOol0;Woo000LOol2000kOol00`00Oomoo`03Ool00`00Oomoo`0_Ool001aoo`03001o
ogoo03]oo`04001oogooOol2000aOol000]oo`8000Aoo`04001oogooOol50002Ool2000mOol01000
Ool00000<Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo03eoo`8003=oo`00
2Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000L
Ool00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007oo
Ool000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04
001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo
00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool0
1000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=o
o`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`00
27oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001o
ogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=o
o`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol0
01Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Mo
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00N7oo000:Ool01000Oomoo`00
1goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool2
001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`8007=oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool40003Ool2001cOol000Yoo`04001oogoo
0007Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool2
001cOol000]oo`8000Yoo`8000=oo`03001oogoo079oo`0077oo0P009Woo00<007ooOol05Goo0P00
<goo000LOol00`00Oomoo`0TOol00`00Ool0000EOol3000cOol000]oo`8000Aoo`03001oogoo00=o
o`<0009oo`8002Eoo`03001oo`0001Eoo`04001oogoo000bOol000Yoo`04001oogoo000:Ool01@00
Oomoogoo00009Woo00@007ooOol001Aoo`04001oogoo000bOol000=oo`D0009oo`04001oogoo0007
Ool50002Ool00`00Oomoo`0TOol01000Oomoo`0057oo00@007ooOol0039oo`002Woo00@007ooOol0
00Moo`04001oogoo0003Ool2000TOol01@00Oomoogoo000057oo00@007ooOol0039oo`002Woo00@0
07ooOol000Qoo`03001oo`0000=oo`03001oogoo02=oo`05001oogooOol0000COol01@00Oomoogoo
0000<Woo000:Ool01000Oomoo`002Goo0P000goo0P0097oo00<007ooOol00Woo00<007ooOol047oo
00<007ooOol00Woo00<007ooOol0;goo000;Ool2000;Ool01@00Oomoogoo00009Goo00<007ooOol0
0Woo00<007ooOol047oo00<007ooOol00Woo00<007ooOol0;goo000LOol2000SOol00`00Oomoo`03
Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`0_Ool001aoo`03001oogoo029oo`03001o
ogoo00=oo`03001oogoo00moo`03001oogoo00=oo`03001oogoo02moo`002goo0P0017oo00@007oo
Oomoo`D0009oo`8002=oo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo
02moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0ROol00`00Oomoo`04Ool0
0`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`0^Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool00`00Oomoo`0ROol00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool0
0`00Oomoo`0^Ool000Yoo`04001oogoo000:Ool01000Oomoogoo0P003Woo0`0017oo0P002Goo1000
0goo0P0000Aoo`00Oomoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0
009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<
Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oo`00009oo`05001oogoo001oo`020002
Ool00`00Oomoo`03Ool01000Oomoogoo0P000Woo00D007ooOol007oo008000Eoo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`00
0Woo00<007ooOol01goo00<007oo00000Woo00D007ooOol007oo0080009oo`03001oogoo00=oo`03
001oogoo009oo`04001oogoo0002Ool01000Ool000001Woo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool20009
Ool30003Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo0P000goo00D007ooOol0
07oo0080009oo`03001oogoo00=oo`05001oogooOol00003Ool01@00Oomoo`00Ool00P001goo00D0
07ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`00
0Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo0P000goo00@007ooOol0
009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007oo000000Aoo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eo
o`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`<000=oo`04001oogoo0002
Ool200000goo001oo`03Ool20002Ool20006Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000L
Ool00`00Oomoo`0<Ool50003Ool2000:Ool20004Ool20004Ool20006Ool00`00Oomoo`060003Ool3
0005Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`80025oo`03001oogoo
00Uoo`8000Qoo`03001oogoo00Uoo`03001oogoo02eoo`0077oo00<007ooOol087oo00<007ooOol0
2Woo0`0017oo0P0037oo00<007ooOol0;Goo000LOomY000<Ool001aoo`03001oogoo019oo`03001o
ogoo00Qoo`@000Ioo`03001oogoo015oo`03001oogoo00Eoo`<000Yoo`03001oogoo019oo`03001o
ogoo00Yoo`0077oo0P0087oo00<007ooOol08Woo00<007ooOol0:goo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001o
ogooOol50002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0LWoo
000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007oo
Oomoo`0007Aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002
Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo
1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo
00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001o
ogoo079oo`002goo0P002goo00D007ooOomoo`0007Aoo`0077oo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`0UOol00`00Oomoo`1:Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8002Eoo`03001oo`00
04]oo`002Woo00@007ooOol000Yoo`05001oogooOol0000VOol01000Oomoo`00BWoo0003Ool50002
Ool01000Oomoo`001goo1@000Woo0P009Goo00@007ooOol004Yoo`002Woo00@007ooOol000Moo`04
001oogoo0003Ool00`00Oomoo`0TOol01000Oomoo`00BWoo000:Ool01000Oomoo`0027oo00<007oo
00000goo0P0097oo00D007ooOomoo`0004Yoo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo
02=oo`03001oogoo009oo`03001oogoo04Moo`002goo0P002goo00@007ooOomoo`8002Aoo`03001o
ogoo009oo`03001oogoo04Moo`0077oo00<007ooOol08Woo00<007ooOol00goo00<007ooOol0Agoo
000;Ool20004Ool01000Oomoogoo1@000Woo0P008goo00<007ooOol017oo00<007ooOol0AWoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00eoo`<000Aoo`8000Uoo`@000=oo`80
0004Ool007ooOol20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool3
0004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool2000=Ool01@00Oomo
ogoo00000Woo00@007ooOol000Uoo`03001oo`00009oo`03001oogoo00800005Ool007ooOol00005
Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Yoo`05001oogooOol0000BOol01000Oomoo`000Woo00<007ooOol0
1goo00<007oo00000Woo00<007ooOol00P0000Eoo`00Oomoo`0000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P004Goo00@007ooOol0009oo`03001oogoo00Moo`03001oo`00009oo`05001oogoo
001oo`020002Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo
00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo
00aoo`@000=oo`04001oogoo0009Ool00`00Ool00002Ool01@00Oomoo`00Ool00P000Woo00<007oo
Ool00goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uo
o`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008Ool30003Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001ao
o`03001oogoo00aoo`D000=oo`8000Yoo`8000Aoo`8000=oo`<000Ioo`04001oogooOol50003Ool2
0006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`80029oo`03001oogoo
00Qoo`03001oogoo04=oo`0077oo00<007ooOol087oo00<007ooOol02Goo0P005Goo0`00;7oo000L
OomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00H0
07ooOomoo`00Ool30002Ool2000017oo001oo`0017oo00D007ooOomoo`0000=oo`03001oogoo00@0
0003Ool007oo009oo`05001oogooOol00003Ool00`00Oomoo`030003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00004Ool00`00Oomoo`0:Ool001aoo`8001moo`8001Eo
o`8000]oo`03001oogoo02eoo`0077oo00<007ooOol0=goo00<007ooOol027oo00<007ooOol0;Goo
000LOol2000iOol00`00Oomoo`07Ool00`00Oomoo`0]Ool001aoo`03001oogoo03Qoo`03001oogoo
00Ioo`03001oogoo02ioo`002goo0P0017oo00@007ooOomoo`D0009oo`8003Uoo`03001oogoo00Io
o`03001oogoo02ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0iOol00`00
Oomoo`05Ool00`00Oomoo`0^Ool000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000jOol00`00
Oomoo`05Ool00`00Oomoo`0^Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000?7oo00<007oo
Ool017oo00<007ooOol0;Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8003]oo`03
001oogoo00Aoo`03001oogoo02ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`0jOol00`00Oomoo`03Ool00`00Oomoo`0_Ool000]oo`8000Uoo`<000=oo`8003]oo`03001o
ogoo00=oo`03001oogoo02moo`0077oo00<007ooOol0>Woo00<007ooOol00goo00<007ooOol0;goo
000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000lOol00`00Oomoo`02Ool00`00Oomoo`0_Ool0
00Yoo`04001oogoo000:Ool01@00Oomoogoo0000?Goo00D007ooOomoo`00039oo`002Woo00@007oo
Ool000Moo`D0009oo`8003eoo`04001oogoo000bOol000Yoo`04001oogoo0007Ool01000Oomoo`00
0goo00<007ooOol0?7oo00@007ooOol0039oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`80
03eoo`04001oogoo000bOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`0mOol2000cOol0
00]oo`8000]oo`04001oogooOol2000nOol00`00Oomoo`0bOol001aoo`03001oogoo079oo`002goo
0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yo
o`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04
Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yo
o`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2
001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001ao
o`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol0
01Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Io
o`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(2960\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23178 L
.188 .23178 L
.192 .23178 L
.196 .23178 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23177 L
.216 .23177 L
.22 .23178 L
.224 .23179 L
.228 .2318 L
.232 .2318 L
.236 .23179 L
.24 .23176 L
.244 .23173 L
.248 .23171 L
.252 .23169 L
.256 .23171 L
.26 .23176 L
.264 .23183 L
.268 .23192 L
.272 .232 L
.276 .23204 L
.28 .23199 L
.284 .23186 L
.288 .23163 L
.292 .23134 L
.296 .23106 L
.3 .23084 L
.304 .2308 L
.308 .231 L
.312 .2315 L
.316 .23229 L
.32 .23331 L
.324 .23445 L
.328 .2355 L
.332 .23625 L
.336 .23644 L
.34 .23584 L
.344 .23425 L
.348 .23156 L
.352 .22771 L
.356 .22278 L
.36 .21691 L
.364 .21036 L
.368 .20342 L
.372 .19644 L
.376 .18977 L
.38 .18373 L
.384 .17861 L
.388 .17462 L
.392 .1719 L
.396 .1705 L
.4 .17041 L
Mistroke
.404 .17153 L
.408 .17373 L
.412 .17683 L
.416 .18063 L
.42 .18492 L
.424 .18949 L
.428 .19417 L
.432 .19879 L
.436 .20324 L
.44 .20741 L
.444 .21123 L
.448 .21466 L
.452 .21769 L
.456 .22032 L
.46 .22256 L
.464 .22446 L
.468 .22603 L
.472 .22731 L
.476 .22836 L
.48 .2292 L
.484 .22987 L
.488 .23041 L
.492 .23085 L
.496 .23121 L
.5 .23152 L
.504 .23181 L
.508 .23211 L
.512 .23242 L
.516 .23278 L
.52 .23322 L
.524 .23376 L
.528 .23443 L
.532 .23527 L
.536 .23632 L
.54 .23761 L
.544 .23917 L
.548 .24106 L
.552 .24331 L
.556 .24594 L
.56 .24896 L
.564 .25239 L
.568 .25621 L
.572 .26037 L
.576 .26481 L
.58 .26944 L
.584 .27411 L
.588 .27868 L
.592 .28296 L
.596 .28675 L
.6 .28985 L
Mistroke
.604 .29205 L
.608 .29318 L
.612 .29309 L
.616 .2917 L
.62 .28898 L
.624 .285 L
.628 .27988 L
.632 .27385 L
.636 .26718 L
.64 .2602 L
.644 .25326 L
.648 .2467 L
.652 .24083 L
.656 .23588 L
.66 .23203 L
.664 .22932 L
.668 .22773 L
.672 .22712 L
.676 .22731 L
.68 .22806 L
.684 .22911 L
.688 .23025 L
.692 .23128 L
.696 .23208 L
.7 .23258 L
.704 .23279 L
.708 .23275 L
.712 .23254 L
.716 .23225 L
.72 .23196 L
.724 .23173 L
.728 .23159 L
.732 .23154 L
.736 .23158 L
.74 .23165 L
.744 .23175 L
.748 .23182 L
.752 .23187 L
.756 .23189 L
.76 .23188 L
.764 .23185 L
.768 .23182 L
.772 .23179 L
.776 .23178 L
.78 .23178 L
.784 .23179 L
.788 .2318 L
.792 .23181 L
.796 .23182 L
.8 .23182 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .2318 L
.82 .2318 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35317 L
.188 .35317 L
.192 .35317 L
.196 .35317 L
.2 .35316 L
Mistroke
.204 .35314 L
.208 .35313 L
.212 .35313 L
.216 .35315 L
.22 .35318 L
.224 .35322 L
.228 .35325 L
.232 .35325 L
.236 .35321 L
.24 .35313 L
.244 .35303 L
.248 .35293 L
.252 .35288 L
.256 .35293 L
.26 .3531 L
.264 .35337 L
.268 .35369 L
.272 .35397 L
.276 .35409 L
.28 .35394 L
.284 .35347 L
.288 .35267 L
.292 .35165 L
.296 .35063 L
.3 .34987 L
.304 .34971 L
.308 .35041 L
.312 .35217 L
.316 .35497 L
.32 .3586 L
.324 .36263 L
.328 .36638 L
.332 .36905 L
.336 .36974 L
.34 .36762 L
.344 .36199 L
.348 .35239 L
.352 .33868 L
.356 .32108 L
.36 .30015 L
.364 .27674 L
.368 .25196 L
.372 .22701 L
.376 .20315 L
.38 .18154 L
.384 .16321 L
.388 .1489 L
.392 .13913 L
.396 .13409 L
.4 .13373 L
Mistroke
.404 .13772 L
.408 .14558 L
.412 .15664 L
.416 .17021 L
.42 .18552 L
.424 .20187 L
.428 .21859 L
.432 .23513 L
.436 .25103 L
.44 .26592 L
.444 .27958 L
.448 .29185 L
.452 .30268 L
.456 .31206 L
.46 .32008 L
.464 .32681 L
.468 .33238 L
.472 .33693 L
.476 .34058 L
.48 .34346 L
.484 .3457 L
.488 .34739 L
.492 .34861 L
.496 .34944 L
.5 .34992 L
.504 .35007 L
.508 .34992 L
.512 .34944 L
.516 .34861 L
.52 .34739 L
.524 .3457 L
.528 .34346 L
.532 .34058 L
.536 .33693 L
.54 .33238 L
.544 .32681 L
.548 .32008 L
.552 .31207 L
.556 .30268 L
.56 .29185 L
.564 .27958 L
.568 .26592 L
.572 .25103 L
.576 .23514 L
.58 .2186 L
.584 .20187 L
.588 .18552 L
.592 .17021 L
.596 .15665 L
.6 .14558 L
Mistroke
.604 .13773 L
.608 .13373 L
.612 .1341 L
.616 .13913 L
.62 .14891 L
.624 .16321 L
.628 .18155 L
.632 .20315 L
.636 .22701 L
.64 .25196 L
.644 .27675 L
.648 .30015 L
.652 .32108 L
.656 .33868 L
.66 .35239 L
.664 .36199 L
.668 .36762 L
.672 .36974 L
.676 .36905 L
.68 .36638 L
.684 .36263 L
.688 .3586 L
.692 .35497 L
.696 .35217 L
.7 .35041 L
.704 .34971 L
.708 .34987 L
.712 .35063 L
.716 .35165 L
.72 .35267 L
.724 .35347 L
.728 .35394 L
.732 .35409 L
.736 .35397 L
.74 .35369 L
.744 .35337 L
.748 .3531 L
.752 .35293 L
.756 .35288 L
.76 .35293 L
.764 .35303 L
.768 .35313 L
.772 .35321 L
.776 .35325 L
.78 .35325 L
.784 .35322 L
.788 .35318 L
.792 .35315 L
.796 .35313 L
.8 .35313 L
Mistroke
.804 .35314 L
.808 .35316 L
.812 .35317 L
.816 .35317 L
.82 .35317 L
.824 .35317 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23176 L
Mistroke
.204 .23175 L
.208 .23174 L
.212 .23174 L
.216 .23175 L
.22 .23178 L
.224 .23181 L
.228 .23184 L
.232 .23184 L
.236 .2318 L
.24 .23174 L
.244 .23165 L
.248 .23157 L
.252 .23153 L
.256 .23157 L
.26 .23171 L
.264 .23193 L
.268 .2322 L
.272 .23244 L
.276 .23254 L
.28 .23242 L
.284 .23202 L
.288 .23135 L
.292 .2305 L
.296 .22963 L
.3 .229 L
.304 .22886 L
.308 .22946 L
.312 .23093 L
.316 .23328 L
.32 .23633 L
.324 .23971 L
.328 .24286 L
.332 .2451 L
.336 .24568 L
.34 .2439 L
.344 .23917 L
.348 .23111 L
.352 .21961 L
.356 .20484 L
.36 .18726 L
.364 .16762 L
.368 .14681 L
.372 .12587 L
.376 .10584 L
.38 .08771 L
.384 .07232 L
.388 .06032 L
.392 .05211 L
.396 .04789 L
.4 .04759 L
Mistroke
.404 .05095 L
.408 .05754 L
.412 .06683 L
.416 .07822 L
.42 .09108 L
.424 .1048 L
.428 .11884 L
.432 .13273 L
.436 .14607 L
.44 .15858 L
.444 .17005 L
.448 .18036 L
.452 .18945 L
.456 .19734 L
.46 .20408 L
.464 .20975 L
.468 .21446 L
.472 .21832 L
.476 .22146 L
.48 .22398 L
.484 .226 L
.488 .22761 L
.492 .22892 L
.496 .23 L
.5 .23094 L
.504 .23181 L
.508 .23268 L
.512 .23362 L
.516 .23471 L
.52 .23601 L
.524 .23763 L
.528 .23965 L
.532 .24217 L
.536 .2453 L
.54 .24917 L
.544 .25388 L
.548 .25955 L
.552 .26629 L
.556 .27418 L
.56 .28327 L
.564 .29358 L
.568 .30504 L
.572 .31755 L
.576 .33089 L
.58 .34478 L
.584 .35882 L
.588 .37255 L
.592 .3854 L
.596 .39679 L
.6 .40608 L
Mistroke
.604 .41268 L
.608 .41604 L
.612 .41573 L
.616 .41151 L
.62 .40331 L
.624 .3913 L
.628 .37591 L
.632 .35778 L
.636 .33776 L
.64 .31682 L
.644 .29601 L
.648 .27636 L
.652 .25879 L
.656 .24402 L
.66 .23251 L
.664 .22446 L
.668 .21973 L
.672 .21795 L
.676 .21853 L
.68 .22077 L
.684 .22392 L
.688 .2273 L
.692 .23035 L
.696 .2327 L
.7 .23417 L
.704 .23476 L
.708 .23462 L
.712 .23399 L
.716 .23313 L
.72 .23228 L
.724 .23161 L
.728 .23121 L
.732 .23109 L
.736 .23119 L
.74 .23142 L
.744 .23169 L
.748 .23192 L
.752 .23206 L
.756 .2321 L
.76 .23206 L
.764 .23198 L
.768 .23189 L
.772 .23182 L
.776 .23179 L
.78 .23179 L
.784 .23182 L
.788 .23185 L
.792 .23188 L
.796 .23189 L
.8 .23189 L
Mistroke
.804 .23188 L
.808 .23187 L
.812 .23186 L
.816 .23186 L
.82 .23186 L
.824 .23186 L
.828 .23186 L
.832 .23187 L
.836 .23187 L
.84 .23187 L
.844 .23187 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23187 L
.872 .23187 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo10000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Ao
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol037oo10000goo00@007ooOol000Uoo`04001oogooOol20002Ool200001Goo001oogoo
00001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uo
o`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008Ool20003Ool20002Ool200001Goo001o
ogoo000017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo
00<007ooOol037oo1@000goo0P002Woo00<007ooOol00P0000=oo`0000000Woo00@007oo000000Io
o`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool0
01aoo`8002Aoo`03001oogoo00Eoo`8004Eoo`0077oo00<007ooOol08Woo00<007ooOol01goo0P00
A7oo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`04001oogooOol50004Ool01@00Oomoogoo00000goo00@007ooOomo
o`D000=oo`09001oogooOol007oo001oo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo0P00>7oo0P001goo
00<007ooOol0;goo000LOol00`00Oomoo`0hOol00`00Oomoo`04Ool00`00Oomoo`0`Ool001aoo`80
03Yoo`03001oogoo00=oo`03001oogoo031oo`0077oo00<007ooOol0>Woo00@007ooOomoo`80039o
o`002goo0P0017oo00@007ooOomoo`D0009oo`8003]oo`D003=oo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool00`00Oomoo`0lOol00`00Oomoo`0cOol000Yoo`04001oogoo0009Ool00`00Oomo
o`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004
Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo
000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=o
o`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007oo
Ool000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00@007ooOomoo`8007=oo`0077oo00<0
07ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo
079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`00
27oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<0
00=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009o
o`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03
001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`80
00Aoo`03001oogoo009oo`<007Qoo`002Woo00@007ooOol000Moo`05001oogooOol0001gOol000=o
o`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo
0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000]oo`8000Uoo`<000=o
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo
009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo10000goo0P00Lgoo000:Ool01000Oomoo`001goo00<007ooOol017oo00<007oo
Ool0LWoo000:Ool01000Oomoo`0027oo00<007ooOol00goo0P00Lgoo000;Ool2000:Ool20003Ool0
0`00Oomoo`1bOol001aoo`8002Moo`8001Aoo`03001oogoo03=oo`0077oo00<007ooOol09Woo0P00
4goo0`00=7oo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000VOol00`00Ool0000COol00`00
Ool0000dOol000Yoo`04001oogoo000:Ool01@00Oomoogoo00009goo00@007ooOol0019oo`04001o
ogoo000cOol000=oo`D0009oo`04001oogoo0007Ool50002Ool00`00Oomoo`0UOol01000Oomoo`00
4Goo00D007ooOomoo`0003=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool2000UOol01@00
Oomoogoo00004Goo00D007ooOomoo`0003=oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`03
001oogoo02Aoo`03001oogoo009oo`03001oogoo00ioo`05001oogooOol0000cOol000Yoo`04001o
ogoo0009Ool20003Ool2000UOol00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00
Oomoo`0`Ool000]oo`8000]oo`05001oogooOol0000VOol00`00Oomoo`02Ool00`00Oomoo`0>Ool0
0`00Oomoo`02Ool00`00Oomoo`0`Ool001aoo`8002Eoo`03001oogoo009oo`03001oogoo00eoo`03
001oogoo00=oo`03001oogoo031oo`0077oo00<007ooOol097oo00<007ooOol00Woo00<007ooOol0
3Goo00<007ooOol00goo00<007ooOol0<7oo000;Ool20004Ool01000Oomoogoo1@000Woo0P009Goo
00<007ooOol00goo00<007ooOol037oo00<007ooOol00goo00<007ooOol0<7oo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`03001oogoo02=oo`03001oogoo00Aoo`03001oogoo00]oo`03001o
ogoo00Aoo`03001oogoo031oo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`03001o
ogoo02=oo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo031oo`002Woo
00@007ooOol000Yoo`04001oogooOol2000>Ool30004Ool20009Ool3000017oo001oogoo0P000goo
0`001Goo0`000Woo100017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`05001oogooOol00002
Ool01000Oomoo`002Goo00H007ooOol007oo0002Ool01000Oomoo`000Woo00<007ooOol00goo00D0
07ooOomoo`0000=oo`03001oogoo00800003Ool007oo00Aoo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol0
1goo00H007ooOol007oo0002Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`0000=o
o`03001oogoo00800003Ool007oo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Goo0`000goo00<0
07ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oo`00009oo`04001oogoo0002Ool2
00000goo001oo`04Ool01000Oomoo`0017oo00<007ooOol00P0000=oo`00Ool01Woo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007oo00000Woo00@007ooOol0
009oo`800003Ool007oo00Aoo`03001oogoo00D000=oo`800003Ool007oo00=oo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol0
00Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`800005Ool007ooOol0
0002Ool00`00Oomoo`040004Ool2000017oo001oo`001Woo00@007oo000000Aoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol0
00Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007oo00000goo0P0017oo0P001Woo0P00
0Woo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000S
Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`0^Ool001aoo`03001o
ogoo029oo`03001oogoo00Uoo`<0009oo`8000aoo`03001oogoo02ioo`0077ooJ@0037oo000LOol0
0`00Oomoo`0BOol00`00Oomoo`0:Ool30005Ool00`00Oomoo`0AOol00`00Oomoo`04Ool3000;Ool0
0`00Oomoo`0BOol00`00Oomoo`0:Ool001aoo`80025oo`03001oogoo021oo`03001oogoo02aoo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000;Ool20004Ool01000Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`03001oogoo079oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@0
07ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P00
2Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo
00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`00
2Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo
0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`05001oogooOol0001dOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol09Woo0P00BWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000W
Ool2001:Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00009goo00@007ooOol004Uoo`000goo
1@000Woo00@007ooOol000Moo`D0009oo`8002Ioo`04001oogoo0019Ool000Yoo`04001oogoo0007
Ool01000Oomoo`000goo00<007ooOol09Goo00@007ooOol004Uoo`002Woo00@007ooOol000Qoo`03
001oo`0000=oo`8002Eoo`03001oogoo009oo`03001oogoo04Ioo`002Woo00@007ooOol000Uoo`80
00=oo`03001oogoo02Aoo`03001oogoo009oo`03001oogoo04Ioo`002goo0P002goo00@007ooOomo
o`8002Eoo`03001oogoo009oo`03001oogoo04Ioo`0077oo00<007ooOol097oo00<007ooOol00Woo
00<007ooOol0AWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P009Goo00<007ooOol00goo00<0
07ooOol0AGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00eoo`<000Aoo`80
00Uoo`<0009oo`04001oo`000002Ool01000Ool000001Goo0`000goo0`0017oo0P001Goo1@000goo
0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo00<007oo
Ool00Woo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool01P00Oomoo`00Ool0009oo`04
001oo`000002Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo
00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo
00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Yoo`05001oogooOol0000BOol0
1000Oomoo`000Woo00<007ooOol01goo00H007ooOol007oo0002Ool01000Oomoo`000Woo00<007oo
Ool00goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol0
1goo00H007ooOol007oo0002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`002Goo00H007ooOol007oo0002
Ool00`00Oomoo`0200000goo001oo`04Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@0
07ooOol000Eoo`002goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`80
0005Ool007ooOol00002Ool00`00Oomoo`0200000goo001oo`03Ool20003Ool00`00Oomoo`04Ool0
1000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007oo
Oomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00
Ool00003Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo
0`000Woo1@000goo0P001Woo000LOol2000SOol00`00Oomoo`08Ool00`00Oomoo`12Ool001aoo`03
001oogoo029oo`03001oogoo00Uoo`03001oogoo015oo`8002ioo`0077ooJ@0037oo000LOol01@00
Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00002Ool20003
Ool200000goo00000004Ool01@00Oomoogoo00000goo00<007ooOol00`000Woo00D007ooOomoo`00
00=oo`06001oo`00Ool007oo10000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo000017oo00<007ooOol02Woo000LOol2000POol2000COol2000;Ool00`00Oomoo`0^Ool0
01aoo`03001oogoo03Eoo`8000Yoo`03001oogoo02ioo`0077oo0P00=goo00<007ooOol027oo00<0
07ooOol0;Woo000LOol00`00Oomoo`0gOol00`00Oomoo`06Ool00`00Oomoo`0_Ool000]oo`8000Ao
o`04001oogooOol50002Ool2000hOol00`00Oomoo`06Ool00`00Oomoo`0_Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00<007ooOol0>7oo00<007ooOol01Goo00<007ooOol0;goo000:Ool0
1000Oomoo`002Goo00<007ooOol00Woo0P00>Goo00<007ooOol01Goo00<007ooOol0;goo000:Ool0
1000Oomoo`002Woo00D007ooOomoo`0003Yoo`03001oogoo00Aoo`03001oogoo031oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2000iOol00`00Oomoo`04Ool00`00Oomoo`0`Ool000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0>Goo00<007ooOol00goo00<007oo
Ool0<7oo000;Ool20009Ool30003Ool2000jOol00`00Oomoo`03Ool00`00Oomoo`0`Ool001aoo`03
001oogoo03Uoo`03001oogoo00=oo`03001oogoo031oo`002goo0P0017oo00<007ooOol00goo0`00
0Woo0P00>goo00<007ooOol00Woo00<007ooOol0<7oo000:Ool01000Oomoo`002Woo00D007ooOomo
o`0003aoo`05001oogooOol0000cOol000Yoo`04001oogoo0007Ool50002Ool2000kOol01@00Oomo
ogoo0000<goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo03Yoo`05001oogoo
Ool0000cOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2000lOol00`00Ool0000dOol000Yo
o`04001oogoo0009Ool20003Ool00`00Oomoo`0lOol2000dOol000]oo`8000]oo`04001oogooOol2
001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomo
o`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;
Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`00
2Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo
000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000G
Ool00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007oo
Ool0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3000\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23178 L
.2 .23178 L
Mistroke
.204 .23178 L
.208 .23178 L
.212 .23177 L
.216 .23177 L
.22 .23176 L
.224 .23177 L
.228 .23177 L
.232 .23178 L
.236 .23179 L
.24 .2318 L
.244 .2318 L
.248 .23179 L
.252 .23176 L
.256 .23173 L
.26 .2317 L
.264 .23169 L
.268 .23171 L
.272 .23176 L
.276 .23185 L
.28 .23194 L
.284 .23202 L
.288 .23205 L
.292 .232 L
.296 .23185 L
.3 .23161 L
.304 .23131 L
.308 .23101 L
.312 .2308 L
.316 .23077 L
.32 .23099 L
.324 .23152 L
.328 .23234 L
.332 .2334 L
.336 .23456 L
.34 .23562 L
.344 .23637 L
.348 .23654 L
.352 .23591 L
.356 .23429 L
.36 .23154 L
.364 .22764 L
.368 .22266 L
.372 .21676 L
.376 .21018 L
.38 .20323 L
.384 .19626 L
.388 .18961 L
.392 .1836 L
.396 .17852 L
.4 .17457 L
Mistroke
.404 .17189 L
.408 .17053 L
.412 .17047 L
.416 .17162 L
.42 .17384 L
.424 .17695 L
.428 .18074 L
.432 .18502 L
.436 .18959 L
.44 .19425 L
.444 .19886 L
.448 .2033 L
.452 .20745 L
.456 .21126 L
.46 .21469 L
.464 .21772 L
.468 .22036 L
.472 .22262 L
.476 .22454 L
.48 .22615 L
.484 .2275 L
.488 .22862 L
.492 .22957 L
.496 .23039 L
.5 .23113 L
.504 .23182 L
.508 .23251 L
.512 .23324 L
.516 .23406 L
.52 .23501 L
.524 .23613 L
.528 .23748 L
.532 .23909 L
.536 .24101 L
.54 .24327 L
.544 .2459 L
.548 .24893 L
.552 .25236 L
.556 .25617 L
.56 .26032 L
.564 .26474 L
.568 .26935 L
.572 .27401 L
.576 .27857 L
.58 .28285 L
.584 .28664 L
.588 .28975 L
.592 .29197 L
.596 .29312 L
.6 .29306 L
Mistroke
.604 .29171 L
.608 .28903 L
.612 .28509 L
.616 .28001 L
.62 .27401 L
.624 .26736 L
.628 .26039 L
.632 .25344 L
.636 .24686 L
.64 .24094 L
.644 .23595 L
.648 .23205 L
.652 .22929 L
.656 .22765 L
.66 .22701 L
.664 .22719 L
.668 .22793 L
.672 .229 L
.676 .23017 L
.68 .23123 L
.684 .23206 L
.688 .23259 L
.692 .23282 L
.696 .23279 L
.7 .23258 L
.704 .23228 L
.708 .23198 L
.712 .23174 L
.716 .23158 L
.72 .23153 L
.724 .23156 L
.728 .23164 L
.732 .23173 L
.736 .23182 L
.74 .23187 L
.744 .23189 L
.748 .23188 L
.752 .23186 L
.756 .23182 L
.76 .2318 L
.764 .23178 L
.768 .23178 L
.772 .23179 L
.776 .2318 L
.78 .23181 L
.784 .23182 L
.788 .23182 L
.792 .23182 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .2318 L
.808 .2318 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35317 L
.2 .35317 L
Mistroke
.204 .35317 L
.208 .35317 L
.212 .35315 L
.216 .35314 L
.22 .35313 L
.224 .35313 L
.228 .35315 L
.232 .35319 L
.236 .35323 L
.24 .35326 L
.244 .35325 L
.248 .35321 L
.252 .35312 L
.256 .353 L
.26 .35291 L
.264 .35287 L
.268 .35293 L
.272 .35312 L
.276 .35341 L
.28 .35374 L
.284 .35403 L
.288 .35413 L
.292 .35396 L
.296 .35343 L
.3 .35258 L
.304 .35152 L
.308 .35047 L
.312 .34972 L
.316 .34959 L
.32 .35037 L
.324 .35223 L
.328 .35515 L
.332 .3589 L
.336 .36302 L
.34 .36682 L
.344 .36949 L
.348 .37013 L
.352 .3679 L
.356 .36211 L
.36 .35233 L
.364 .33844 L
.368 .32067 L
.372 .2996 L
.376 .27611 L
.38 .25128 L
.384 .22635 L
.388 .20256 L
.392 .18107 L
.396 .16287 L
.4 .14872 L
Mistroke
.404 .1391 L
.408 .13421 L
.412 .13396 L
.416 .13804 L
.42 .14595 L
.424 .15705 L
.428 .17061 L
.432 .1859 L
.436 .2022 L
.44 .21888 L
.444 .23535 L
.448 .25118 L
.452 .26601 L
.456 .2796 L
.46 .29181 L
.464 .30256 L
.468 .31187 L
.472 .31979 L
.476 .3264 L
.48 .33182 L
.484 .33616 L
.488 .33953 L
.492 .34203 L
.496 .34375 L
.5 .34476 L
.504 .3451 L
.508 .34476 L
.512 .34375 L
.516 .34203 L
.52 .33953 L
.524 .33616 L
.528 .33182 L
.532 .3264 L
.536 .31979 L
.54 .31187 L
.544 .30256 L
.548 .29181 L
.552 .2796 L
.556 .26601 L
.56 .25118 L
.564 .23536 L
.568 .21888 L
.572 .20221 L
.576 .1859 L
.58 .17061 L
.584 .15705 L
.588 .14596 L
.592 .13805 L
.596 .13396 L
.6 .13421 L
Mistroke
.604 .13911 L
.608 .14873 L
.612 .16288 L
.616 .18108 L
.62 .20257 L
.624 .22636 L
.628 .25129 L
.632 .27611 L
.636 .2996 L
.64 .32067 L
.644 .33844 L
.648 .35233 L
.652 .36211 L
.656 .3679 L
.66 .37013 L
.664 .36949 L
.668 .36682 L
.672 .36302 L
.676 .3589 L
.68 .35515 L
.684 .35223 L
.688 .35037 L
.692 .34959 L
.696 .34972 L
.7 .35047 L
.704 .35152 L
.708 .35258 L
.712 .35343 L
.716 .35396 L
.72 .35413 L
.724 .35403 L
.728 .35374 L
.732 .35341 L
.736 .35312 L
.74 .35293 L
.744 .35287 L
.748 .35291 L
.752 .353 L
.756 .35312 L
.76 .35321 L
.764 .35325 L
.768 .35326 L
.772 .35323 L
.776 .35319 L
.78 .35315 L
.784 .35313 L
.788 .35313 L
.792 .35314 L
.796 .35315 L
.8 .35317 L
Mistroke
.804 .35317 L
.808 .35317 L
.812 .35317 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23176 L
.216 .23174 L
.22 .23173 L
.224 .23174 L
.228 .23175 L
.232 .23178 L
.236 .23182 L
.24 .23184 L
.244 .23184 L
.248 .2318 L
.252 .23172 L
.256 .23163 L
.26 .23155 L
.264 .23151 L
.268 .23157 L
.272 .23172 L
.276 .23197 L
.28 .23225 L
.284 .23249 L
.288 .23258 L
.292 .23243 L
.296 .23199 L
.3 .23128 L
.304 .23038 L
.308 .2295 L
.312 .22887 L
.316 .22877 L
.32 .22942 L
.324 .23098 L
.328 .23343 L
.332 .23658 L
.336 .24004 L
.34 .24323 L
.344 .24547 L
.348 .24601 L
.352 .24413 L
.356 .23928 L
.36 .23107 L
.364 .21941 L
.368 .20449 L
.372 .18681 L
.376 .16708 L
.38 .14625 L
.384 .12532 L
.388 .10535 L
.392 .08732 L
.396 .07204 L
.4 .06017 L
Mistroke
.404 .05209 L
.408 .04799 L
.412 .04778 L
.416 .05121 L
.42 .05786 L
.424 .06717 L
.428 .07856 L
.432 .0914 L
.436 .10509 L
.44 .1191 L
.444 .13294 L
.448 .14625 L
.452 .15872 L
.456 .17016 L
.46 .18045 L
.464 .18955 L
.468 .19746 L
.472 .20425 L
.476 .21001 L
.48 .21484 L
.484 .21887 L
.488 .22225 L
.492 .2251 L
.496 .22755 L
.5 .22975 L
.504 .23181 L
.508 .23388 L
.512 .23608 L
.516 .23853 L
.52 .24138 L
.524 .24475 L
.528 .24879 L
.532 .25362 L
.536 .25937 L
.54 .26616 L
.544 .27408 L
.548 .28317 L
.552 .29347 L
.556 .30491 L
.56 .31738 L
.564 .33068 L
.568 .34453 L
.572 .35853 L
.576 .37222 L
.58 .38506 L
.584 .39645 L
.588 .40577 L
.592 .41241 L
.596 .41584 L
.6 .41564 L
Mistroke
.604 .41153 L
.608 .40346 L
.612 .39158 L
.616 .37631 L
.62 .35827 L
.624 .3383 L
.628 .31738 L
.632 .29654 L
.636 .27682 L
.64 .25914 L
.644 .24422 L
.648 .23256 L
.652 .22435 L
.656 .21949 L
.66 .21762 L
.664 .21816 L
.668 .2204 L
.672 .22359 L
.676 .22705 L
.68 .2302 L
.684 .23265 L
.688 .2342 L
.692 .23486 L
.696 .23476 L
.7 .23413 L
.704 .23324 L
.708 .23235 L
.712 .23164 L
.716 .2312 L
.72 .23105 L
.724 .23114 L
.728 .23138 L
.732 .23166 L
.736 .2319 L
.74 .23206 L
.744 .23211 L
.748 .23208 L
.752 .232 L
.756 .2319 L
.76 .23183 L
.764 .23179 L
.768 .23179 L
.772 .23181 L
.776 .23184 L
.78 .23187 L
.784 .23189 L
.788 .23189 L
.792 .23189 L
.796 .23187 L
.8 .23186 L
Mistroke
.804 .23185 L
.808 .23185 L
.812 .23186 L
.816 .23186 L
.82 .23187 L
.824 .23187 L
.828 .23187 L
.832 .23187 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23187 L
.86 .23187 L
.864 .23187 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00<007oo00000P0000Eoo`00Oomoo`0000Eoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol037oo10000goo00@007ooOol000Uoo`03001oogoo009oo`800003Ool0
00000080009oo`03001oogoo00=oo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomo
o`001Goo000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo
00D007ooOol007oo0080009oo`03001oogoo009oo`8000=oo`03001oogoo00Aoo`04001oogoo0004
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`00
00Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`04001oogooOol40003
Ool30006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo
0P001Woo000LOol2000UOol00`00Oomoo`05Ool00`00Oomoo`13Ool001aoo`03001oogoo02=oo`80
00Qoo`8004=oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01P00Oomoogoo001oo`<000Aoo`05001oogooOol00003
Ool01000Oomoogoo0`0000=oo`00Ool00Woo00@007ooOomoo`80009oo`03001oogoo009oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001o
ogoo00Yoo`0077oo0P00=Woo0P0027oo00<007ooOol0<7oo000LOol00`00Oomoo`0gOol00`00Oomo
o`04Ool2000bOol001aoo`8003Uoo`03001oogoo00=oo`03001oogoo035oo`0077oo00<007ooOol0
>7oo0P000goo00<007ooOol0<Woo000;Ool20004Ool01000Oomoogoo1@000Woo0P00>Woo0P0000=o
o`00Ool0=7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo03]oo`03001oogoo
03Aoo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05
001oogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00
Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo
00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol0
00Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo
00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2
000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009o
o`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo1000
0goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000
Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001ao
o`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Io
o`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2
001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001o
ogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00N7oo000:Ool01000
Oomoo`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`8007=oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool40003Ool2001cOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Oomo
o`03Ool2001cOol000]oo`8000Yoo`8000=oo`03001oogoo079oo`0077oo0P00:7oo0P004Woo00<0
07ooOol0=7oo000LOol00`00Oomoo`0WOol3000@Ool00`00Ool0000eOol000]oo`8000Aoo`03001o
ogoo00=oo`<0009oo`8002Qoo`03001oo`00011oo`03001oo`0003Eoo`002Woo00@007ooOol000Yo
o`05001oogooOol0000XOol01000Oomoo`0047oo00<007oo0000=Goo0003Ool50002Ool01000Oomo
o`001goo1@000Woo00<007ooOol09Woo00@007ooOol000moo`04001oogoo000eOol000Yoo`04001o
ogoo0007Ool01000Oomoo`000goo0P009goo00@007ooOol000moo`05001oogooOol0000dOol000Yo
o`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`0VOol01@00Oomoogoo00003Woo00D007oo
Oomoo`0003Aoo`002Woo00@007ooOol000Uoo`8000=oo`8002Ioo`03001oogoo009oo`03001oogoo
00]oo`03001oogoo009oo`03001oogoo039oo`002goo0P002goo00D007ooOomoo`0002Moo`03001o
ogoo009oo`03001oogoo00]oo`03001oogoo009oo`03001oogoo039oo`0077oo0P009Woo00<007oo
Ool00goo00<007ooOol02Woo00<007ooOol00goo00<007ooOol0<Goo000LOol00`00Oomoo`0UOol0
0`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`0aOol000]oo`8000Aoo`04
001oogooOol50002Ool2000VOol00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00
Oomoo`0aOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol097oo00<007ooOol0
1Goo00<007ooOol027oo00<007ooOol017oo00<007ooOol0<Goo0003Ool50002Ool01000Oomoo`00
2Goo00<007ooOol00Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol027oo00<007ooOol0
17oo00<007ooOol0<Goo000:Ool01000Oomoo`002Woo00@007ooOomoo`8000ioo`<000Aoo`8000Uo
o`<0009oo`04001oo`000004Ool20005Ool300000goo001oo`030003Ool30005Ool50003Ool20004
Ool20005Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol037oo00D007ooOomoo`00009oo`04001oogoo0009Ool01000Oomoogoo0P000Woo00<0
07ooOol00P0000=oo`00Ool017oo00D007oo001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00
4Goo00@007ooOol0009oo`03001oogoo00Moo`04001oogooOol20002Ool00`00Oomoo`0200000goo
001oo`04Ool00`00Ool00005Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo
000;Ool20009Ool30003Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00@007oo
Oomoo`80009oo`05001oogoo001oo`020005Ool00`00Ool00005Ool01000Oomoo`000Woo00<007oo
Ool01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00@007oo
Oomoo`80009oo`05001oogoo001oo`020005Ool20002Ool40003Ool01000Oomoo`0017oo00D007oo
Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000
Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P000Woo00<0
07oo00000Woo00@007ooOol0009oo`03001oogoo009oo`<0009oo`03001oogoo00Aoo`04001oogoo
0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001o
o`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`04001oogoo0002
Ool20004Ool30005Ool01000Oomoogoo1@000Woo0`001Woo0`0017oo0P0017oo0P001Woo0`000Woo
1@000goo0P001Woo000LOol2000TOol00`00Oomoo`09Ool20002Ool2000;Ool00`00Oomoo`0_Ool0
01aoo`03001oogoo02=oo`03001oogoo00Yoo`@000aoo`03001oogoo02moo`0077ooJ@0037oo000L
Ool00`00Oomoo`0BOol00`00Oomoo`0;Ool00`00Ool00004Ool00`00Oomoo`0AOol00`00Oomoo`03
Ool3000<Ool00`00Oomoo`0BOol00`00Oomoo`0:Ool001aoo`80029oo`03001oogoo01eoo`8002mo
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`03001oogoo079oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo
00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo
0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P00
17oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Ao
o`002Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001o
ogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`05001oogooOol0001dOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol09goo0P00BGoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2
000XOol30018Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000:Goo00<007oo0000B7oo0003
Ool50002Ool01000Oomoo`001goo1@000Woo0P009goo00@007ooOol004Qoo`002Woo00@007ooOol0
00Moo`04001oogoo0003Ool00`00Oomoo`0VOol01000Oomoo`00B7oo000:Ool01000Oomoo`0027oo
00<007oo00000goo0P009goo00D007ooOomoo`0004Moo`002Woo00@007ooOol000Uoo`8000=oo`03
001oogoo02Eoo`03001oogoo009oo`03001oogoo04Eoo`002goo0P002goo00@007ooOomoo`8002Io
o`03001oogoo009oo`03001oogoo04Eoo`0077oo00<007ooOol09Goo00<007ooOol00goo00<007oo
Ool0A7oo000;Ool20004Ool01000Oomoogoo1@000Woo0P009Woo00<007ooOol00goo00<007ooOol0
A7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00eoo`<000Aoo`8000Uoo`<0
009oo`04001oo`000003Ool30005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool5
0002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool2000=Ool0
1@00Oomoogoo00000Woo00@007ooOol000Uoo`04001oogooOol20002Ool00`00Oomoo`0200000goo
001oo`04Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Yoo`05001oogooOol0000BOol01000Oomoo`000Woo00<0
07ooOol01goo00@007ooOomoo`80009oo`03001oogoo00800003Ool007oo00Aoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P004Goo00@007ooOol0009oo`03001oogoo00Moo`04001oogooOol20002
Ool00`00Oomoo`0200000goo001oo`04Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
1Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000
Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo00aoo`@000=oo`04001oogoo0009Ool01000Oomoogoo0P000Woo00D007ooOol007oo008000Eo
o`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool0
1000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool20009Ool30003
Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P000goo0P000Woo00D007ooOol007oo0080
00Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001o
ogoo00aoo`D000=oo`8000Yoo`06001oogooOol007oo0P0017oo0`001Goo00@007ooOomoo`D000=o
o`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P0097oo00<007oo
Ool027oo00<007ooOol0@Goo000LOol00`00Oomoo`0SOol00`00Oomoo`09Ool2000@Ool2000_Ool0
01aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo0P000Woo0`0000=oo`00Ool00goo00D007ooOomoo`0000=oo`03001oogoo
008000=oo`05001oogooOol00003Ool20002Ool400000goo001oo`02Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00004Ool00`00Oomoo`0:Ool001aoo`80025oo`<0011o
o`8000]oo`03001oogoo02moo`0077oo00<007ooOol0=7oo0P002Goo00<007ooOol0<7oo000LOol2
000fOol00`00Oomoo`07Ool00`00Oomoo`0`Ool001aoo`03001oogoo03Eoo`03001oogoo00Moo`03
001oogoo031oo`002goo0P0017oo00@007ooOomoo`D0009oo`8003Moo`03001oogoo00Ioo`03001o
ogoo031oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0fOol00`00Oomoo`06
Ool00`00Oomoo`0`Ool000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000hOol00`00Oomoo`05
Ool00`00Oomoo`0`Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000>Goo00<007ooOol017oo
00<007ooOol0<Goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8003Qoo`03001oogoo
00Aoo`03001oogoo035oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0h
Ool00`00Oomoo`03Ool00`00Oomoo`0aOol000]oo`8000Uoo`<000=oo`8003Uoo`03001oogoo00=o
o`03001oogoo035oo`0077oo00<007ooOol0>7oo00<007ooOol00Woo00<007ooOol0<Woo000;Ool2
0004Ool00`00Oomoo`03Ool30002Ool2000iOol00`00Oomoo`02Ool00`00Oomoo`0bOol000Yoo`04
001oogoo000:Ool01@00Oomoogoo0000>goo00D007ooOomoo`0003Aoo`002Woo00@007ooOol000Mo
o`D0009oo`8003Yoo`05001oogooOol0000dOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo
00<007ooOol0>Woo00<007oo0000=Goo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00>goo
00<007oo0000=Goo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0>Woo0`00=Goo000;Ool2
000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009o
o`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo1000
0goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000
Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001ao
o`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Io
o`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2
001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001o
ogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3040\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23178 L
.208 .23178 L
.212 .23178 L
.216 .23178 L
.22 .23177 L
.224 .23177 L
.228 .23177 L
.232 .23176 L
.236 .23177 L
.24 .23177 L
.244 .23178 L
.248 .2318 L
.252 .2318 L
.256 .2318 L
.26 .23178 L
.264 .23176 L
.268 .23172 L
.272 .23169 L
.276 .23169 L
.28 .23171 L
.284 .23177 L
.288 .23186 L
.292 .23196 L
.296 .23204 L
.3 .23206 L
.304 .232 L
.308 .23184 L
.312 .23158 L
.316 .23127 L
.32 .23096 L
.324 .23076 L
.328 .23074 L
.332 .23098 L
.336 .23154 L
.34 .2324 L
.344 .23348 L
.348 .23467 L
.352 .23575 L
.356 .23649 L
.36 .23665 L
.364 .23599 L
.368 .23432 L
.372 .23152 L
.376 .22757 L
.38 .22254 L
.384 .2166 L
.388 .21 L
.392 .20305 L
.396 .19608 L
.4 .18945 L
Mistroke
.404 .18348 L
.408 .17843 L
.412 .17453 L
.416 .17189 L
.42 .17057 L
.424 .17054 L
.428 .17171 L
.432 .17395 L
.436 .17707 L
.44 .18087 L
.444 .18514 L
.448 .1897 L
.452 .19437 L
.456 .19898 L
.46 .20342 L
.464 .20759 L
.468 .21143 L
.472 .21491 L
.476 .21801 L
.48 .22075 L
.484 .22315 L
.488 .22526 L
.492 .22712 L
.496 .22879 L
.5 .23034 L
.504 .23182 L
.508 .2333 L
.512 .23484 L
.516 .23651 L
.52 .23837 L
.524 .24048 L
.528 .24288 L
.532 .24562 L
.536 .24872 L
.54 .25219 L
.544 .25603 L
.548 .2602 L
.552 .26463 L
.556 .26924 L
.56 .27389 L
.564 .27845 L
.568 .28272 L
.572 .28652 L
.576 .28964 L
.58 .29187 L
.584 .29305 L
.588 .29303 L
.592 .29171 L
.596 .28908 L
.6 .28518 L
Mistroke
.604 .28014 L
.608 .27417 L
.612 .26754 L
.616 .26058 L
.62 .25362 L
.624 .24701 L
.628 .24106 L
.632 .23602 L
.636 .23207 L
.64 .22926 L
.644 .22758 L
.648 .22691 L
.652 .22706 L
.656 .22781 L
.66 .22889 L
.664 .23008 L
.668 .23118 L
.672 .23204 L
.676 .2326 L
.68 .23285 L
.684 .23284 L
.688 .23263 L
.692 .23232 L
.696 .23201 L
.7 .23175 L
.704 .23158 L
.708 .23152 L
.712 .23154 L
.716 .23162 L
.72 .23172 L
.724 .23181 L
.728 .23187 L
.732 .2319 L
.736 .23189 L
.74 .23186 L
.744 .23183 L
.748 .2318 L
.752 .23178 L
.756 .23178 L
.76 .23179 L
.764 .2318 L
.768 .23181 L
.772 .23182 L
.776 .23182 L
.78 .23182 L
.784 .23181 L
.788 .23181 L
.792 .2318 L
.796 .2318 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35317 L
.208 .35317 L
.212 .35318 L
.216 .35317 L
.22 .35316 L
.224 .35315 L
.228 .35313 L
.232 .35313 L
.236 .35313 L
.24 .35316 L
.244 .3532 L
.248 .35324 L
.252 .35327 L
.256 .35326 L
.26 .3532 L
.264 .3531 L
.268 .35298 L
.272 .35288 L
.276 .35285 L
.28 .35293 L
.284 .35314 L
.288 .35345 L
.292 .3538 L
.296 .35409 L
.3 .35418 L
.304 .35396 L
.308 .35339 L
.312 .35249 L
.316 .35138 L
.32 .3503 L
.324 .34956 L
.328 .34948 L
.332 .35034 L
.336 .3523 L
.34 .35534 L
.344 .35921 L
.348 .36341 L
.352 .36727 L
.356 .36993 L
.36 .37051 L
.364 .36817 L
.368 .36223 L
.372 .35227 L
.376 .33819 L
.38 .32026 L
.384 .29905 L
.388 .27547 L
.392 .25061 L
.396 .22571 L
.4 .20199 L
Mistroke
.404 .18061 L
.408 .16255 L
.412 .14855 L
.416 .13908 L
.42 .13432 L
.424 .13418 L
.428 .13835 L
.432 .14631 L
.436 .15742 L
.44 .17097 L
.444 .18622 L
.448 .20246 L
.452 .21905 L
.456 .23542 L
.46 .25111 L
.464 .26578 L
.468 .27917 L
.472 .29112 L
.476 .30156 L
.48 .31045 L
.484 .31783 L
.488 .32375 L
.492 .32826 L
.496 .33142 L
.5 .3333 L
.504 .33392 L
.508 .3333 L
.512 .33142 L
.516 .32826 L
.52 .32375 L
.524 .31783 L
.528 .31045 L
.532 .30156 L
.536 .29112 L
.54 .27917 L
.544 .26578 L
.548 .25111 L
.552 .23542 L
.556 .21905 L
.56 .20247 L
.564 .18623 L
.568 .17098 L
.572 .15743 L
.576 .14632 L
.58 .13835 L
.584 .13419 L
.588 .13432 L
.592 .13908 L
.596 .14855 L
.6 .16255 L
Mistroke
.604 .18061 L
.608 .20199 L
.612 .22571 L
.616 .25062 L
.62 .27547 L
.624 .29905 L
.628 .32026 L
.632 .33819 L
.636 .35227 L
.64 .36223 L
.644 .36817 L
.648 .37051 L
.652 .36993 L
.656 .36727 L
.66 .36341 L
.664 .35921 L
.668 .35534 L
.672 .3523 L
.676 .35034 L
.68 .34948 L
.684 .34956 L
.688 .3503 L
.692 .35138 L
.696 .35249 L
.7 .35339 L
.704 .35396 L
.708 .35418 L
.712 .35409 L
.716 .3538 L
.72 .35345 L
.724 .35314 L
.728 .35293 L
.732 .35285 L
.736 .35288 L
.74 .35298 L
.744 .3531 L
.748 .3532 L
.752 .35326 L
.756 .35327 L
.76 .35324 L
.764 .3532 L
.768 .35316 L
.772 .35313 L
.776 .35313 L
.78 .35313 L
.784 .35315 L
.788 .35316 L
.792 .35317 L
.796 .35318 L
.8 .35317 L
Mistroke
.804 .35317 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23177 L
.216 .23177 L
.22 .23176 L
.224 .23175 L
.228 .23174 L
.232 .23173 L
.236 .23174 L
.24 .23176 L
.244 .23179 L
.248 .23183 L
.252 .23185 L
.256 .23184 L
.26 .23179 L
.264 .23171 L
.268 .23161 L
.272 .23153 L
.276 .2315 L
.28 .23157 L
.284 .23174 L
.288 .23201 L
.292 .2323 L
.296 .23254 L
.3 .23261 L
.304 .23244 L
.308 .23196 L
.312 .2312 L
.316 .23027 L
.32 .22936 L
.324 .22874 L
.328 .22867 L
.332 .22939 L
.336 .23104 L
.34 .23359 L
.344 .23684 L
.348 .24037 L
.352 .2436 L
.356 .24584 L
.36 .24633 L
.364 .24436 L
.368 .23937 L
.372 .23101 L
.376 .2192 L
.38 .20414 L
.384 .18634 L
.388 .16655 L
.392 .14568 L
.396 .12478 L
.4 .10487 L
Mistroke
.404 .08693 L
.408 .07177 L
.412 .06002 L
.416 .05208 L
.42 .04809 L
.424 .04798 L
.428 .05149 L
.432 .05819 L
.436 .06753 L
.44 .07893 L
.444 .09177 L
.448 .10545 L
.452 .11944 L
.456 .13329 L
.46 .14661 L
.464 .15913 L
.468 .17065 L
.472 .18109 L
.476 .1904 L
.48 .19862 L
.484 .20583 L
.488 .21215 L
.492 .21774 L
.496 .22275 L
.5 .22738 L
.504 .23181 L
.508 .23625 L
.512 .24088 L
.516 .24589 L
.52 .25147 L
.524 .2578 L
.528 .26501 L
.532 .27323 L
.536 .28254 L
.54 .29297 L
.544 .3045 L
.548 .31702 L
.552 .33034 L
.556 .34418 L
.56 .35818 L
.564 .37186 L
.568 .38469 L
.572 .39609 L
.576 .40544 L
.58 .41213 L
.584 .41564 L
.588 .41554 L
.592 .41155 L
.596 .4036 L
.6 .39185 L
Mistroke
.604 .3767 L
.608 .35875 L
.612 .33885 L
.616 .31794 L
.62 .29708 L
.624 .27728 L
.628 .25949 L
.632 .24443 L
.636 .23262 L
.64 .22426 L
.644 .21927 L
.648 .2173 L
.652 .21779 L
.656 .22002 L
.66 .22326 L
.664 .22679 L
.668 .23004 L
.672 .23259 L
.676 .23423 L
.68 .23496 L
.684 .23489 L
.688 .23426 L
.692 .23336 L
.696 .23243 L
.7 .23167 L
.704 .23119 L
.708 .23101 L
.712 .23109 L
.716 .23133 L
.72 .23162 L
.724 .23188 L
.728 .23206 L
.732 .23213 L
.736 .2321 L
.74 .23202 L
.744 .23192 L
.748 .23183 L
.752 .23179 L
.756 .23178 L
.76 .2318 L
.764 .23184 L
.768 .23187 L
.772 .23189 L
.776 .2319 L
.78 .23189 L
.784 .23188 L
.788 .23186 L
.792 .23185 L
.796 .23185 L
.8 .23186 L
Mistroke
.804 .23186 L
.808 .23187 L
.812 .23187 L
.816 .23187 L
.82 .23187 L
.824 .23186 L
.828 .23186 L
.832 .23186 L
.836 .23186 L
.84 .23186 L
.844 .23187 L
.848 .23187 L
.852 .23187 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00<007ooOol010000Woo00<007ooOol00goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00D007oo0000
07oo0080009oo`03001oogoo00=oo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomo
o`001Goo000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo
00@007oo0000009oo`800003Ool007oo00=oo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Io
o`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Ao
o`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool2
0006Ool001aoo`8002Ioo`03001oogoo00Eoo`8004=oo`0077oo00<007ooOol097oo0P0027oo0P00
@Woo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00002Ool30003Ool01@00Oomoogoo00000goo00<0
07ooOol00`000Woo00D007ooOomoo`00009oo`8000=oo`03001oogoo009oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`00
77oo0P00=Goo0P0027oo00<007ooOol0<Goo000LOol00`00Oomoo`0eOol20006Ool00`00Oomoo`0b
Ool001aoo`8003Moo`8000Aoo`03001oogoo03=oo`0077oo00<007ooOol0=goo0P000goo00<007oo
Ool0<goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00>Goo1000=Woo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`03001oogoo03Yoo`03001oogoo03Eoo`002Woo00@007ooOol000Uoo`03
001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0
001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomo
o`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool0
1000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000L
Ool00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<0
07ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo
00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001o
ogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P00
2Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007oo
Ool00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`00
5goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
2goo0P0017oo00<007ooOol00Woo0`00N7oo000:Ool01000Oomoo`001goo00D007ooOomoo`0007Mo
o`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo
0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002goo0P002Goo
0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<0
07ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo079oo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool40003Ool2001cOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool2001cOol000]oo`8000Yoo`80
00=oo`03001oogoo079oo`0077oo0P00:Woo00<007ooOol03Woo00<007ooOol0=Goo000LOol00`00
Oomoo`0XOol2000?Ool2000gOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8002Uoo`03001o
o`0000ioo`03001oo`0003Ioo`002Woo00@007ooOol000Yoo`05001oogooOol0000YOol01000Oomo
o`003Goo00@007ooOol003Ioo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo02Mo
o`05001oogooOol0000<Ool01000Oomoo`00=Woo000:Ool01000Oomoo`001goo00@007ooOol000=o
o`8002Qoo`05001oogooOol0000<Ool01@00Oomoogoo0000=Goo000:Ool01000Oomoo`0027oo00<0
07oo00000goo00<007ooOol09goo00D007ooOomoo`0000aoo`05001oogooOol0000eOol000Yoo`04
001oogoo0009Ool20003Ool2000XOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool0
0`00Oomoo`0cOol000]oo`8000]oo`05001oogooOol0000YOol00`00Oomoo`02Ool00`00Oomoo`08
Ool00`00Oomoo`02Ool00`00Oomoo`0cOol001aoo`8002Moo`03001oogoo00=oo`03001oogoo00Qo
o`03001oogoo009oo`03001oogoo03=oo`0077oo00<007ooOol09Woo00<007ooOol00goo00<007oo
Ool027oo00<007ooOol00Woo00<007ooOol0<goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00
9goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00<007ooOol0<goo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`03001oogoo02Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03
001oogoo00Aoo`03001oogoo039oo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`03
001oogoo02Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo039oo`00
2Woo00@007ooOol000Yoo`04001oogooOol2000>Ool30004Ool20009Ool30003Ool30004Ool20005
Ool30003Ool3000017oo001oogoo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P00
1Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`05001oogooOol0
0002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool20002
Ool01000Oomoogoo0P0000Eoo`00Oomoo`0000Eoo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool20006Ool200001Goo001oogoo00001Woo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000;Ool20009Ool30003Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00<0
07ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool20006Ool01000Ool0
00000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomo
o`002Goo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo008000Aoo`04001oogooOol40002
Ool20002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004
Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo
00Aoo`04001oogoo0008Ool20003Ool20002Ool01000Oomoo`000Woo0P000goo0P000goo00<007oo
Ool00goo0P000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomo
o`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003
Ool2000:Ool01P00Oomoogoo001oo`8000Aoo`80009oo`03001oogoo008000=oo`D00003Ool007oo
008000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P009Goo00<007oo
Ool02Goo0`0037oo00<007ooOol0<7oo000LOol00`00Oomoo`0TOol00`00Oomoo`0HOol00`00Oomo
o`0`Ool001aoofT000aoo`0077oo00<007ooOol04Woo00<007ooOol037oo0`000goo00<007ooOol0
4Goo00@007ooOomoo`@000eoo`03001oogoo019oo`03001oogoo00Yoo`0077oo0P008goo00<007oo
Ool06goo0P00<7oo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol000]oo`8000Aoo`04001oogooOol50002Ool2001cOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002Goo00<007ooOol00Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00
Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo
00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=o
o`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00D007ooOomoo`00
07Aoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`0YOol00`00Oomoo`16Ool000]oo`8000Aoo`03
001oogoo00=oo`<0009oo`8002Uoo`8004Qoo`002Woo00@007ooOol000Yoo`05001oogooOol0000Z
Ool00`00Ool00017Ool000=oo`D0009oo`04001oogoo0007Ool50002Ool2000XOol01000Oomoo`00
Agoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo02Moo`05001oogooOol00016
Ool000Yoo`04001oogoo0008Ool00`00Ool00003Ool2000XOol01@00Oomoogoo0000AWoo000:Ool0
1000Oomoo`002Goo0P000goo00<007ooOol09goo00<007ooOol00Woo00<007ooOol0@goo000;Ool2
000;Ool01000Oomoogoo0P00:7oo00<007ooOol00Woo00<007ooOol0@goo000LOol00`00Oomoo`0V
Ool00`00Oomoo`03Ool00`00Oomoo`13Ool000]oo`8000Aoo`04001oogooOol50002Ool2000WOol0
0`00Oomoo`03Ool00`00Oomoo`13Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007oo
Ool03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo
0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo00<007oo
Ool00Woo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool200001Woo
001oogoo001oo`8000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`04001oogoo
0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool200001Woo001oogoo001oo`8000Eoo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo0P004Goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@0
07ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`0<Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Goo
0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000
Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo
00<007ooOol037oo1@000goo0P002Woo00<007ooOol00Woo0`0017oo0P0000=oo`00Ool00goo00@0
07ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo
0P009Goo00<007ooOol027oo0P00@Goo000LOol00`00Oomoo`0TOol00`00Oomoo`09Ool00`00Oomo
o`0=Ool2000`Ool001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo1@0000=oo`0000000P000goo00D007ooOomoo`0000=o
o`03001oogoo008000=oo`05001oogooOol00003Ool01000Oomoogoo0`000Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo
000LOol2000SOol2000?Ool00`00Oomoo`09Ool00`00Oomoo`0`Ool001aoo`03001oogoo03=oo`03
001oogoo00Qoo`03001oogoo035oo`0077oo0P00=Goo00<007ooOol01goo00<007ooOol0<Goo000L
Ool00`00Oomoo`0dOol00`00Oomoo`07Ool00`00Oomoo`0aOol000]oo`8000Aoo`04001oogooOol5
0002Ool2000fOol00`00Oomoo`06Ool00`00Oomoo`0aOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00<007ooOol0=Goo00<007ooOol01Goo00<007ooOol0<Woo000:Ool01000Oomoo`002Goo
00<007ooOol00Woo0P00=Woo00<007ooOol01Goo00<007ooOol0<Woo000:Ool01000Oomoo`002Woo
00D007ooOomoo`0003Qoo`03001oogoo00Aoo`03001oogoo039oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool2000gOol00`00Oomoo`04Ool00`00Oomoo`0bOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0=Woo00<007ooOol00goo00<007ooOol0<goo000;Ool2
0009Ool30003Ool2000hOol00`00Oomoo`02Ool00`00Oomoo`0cOol001aoo`03001oogoo03Moo`03
001oogoo009oo`03001oogoo03=oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00>7oo00<0
07ooOol00Woo00<007ooOol0<goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0003Yoo`05001o
ogooOol0000eOol000Yoo`04001oogoo0007Ool50002Ool2000iOol01@00Oomoogoo0000=Goo000:
Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo03Qoo`04001oogoo000fOol000Yoo`04
001oogoo0008Ool00`00Ool00003Ool2000jOol00`00Ool0000fOol000Yoo`04001oogoo0009Ool2
0003Ool00`00Oomoo`0iOol2000gOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001o
ogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1b
Ool000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomo
o`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qo
o`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003
Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool0
0`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00
Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3080\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23177 L
.216 .23178 L
.22 .23178 L
.224 .23178 L
.228 .23178 L
.232 .23177 L
.236 .23177 L
.24 .23176 L
.244 .23176 L
.248 .23177 L
.252 .23177 L
.256 .23179 L
.26 .2318 L
.264 .23181 L
.268 .2318 L
.272 .23178 L
.276 .23175 L
.28 .23171 L
.284 .23169 L
.288 .23168 L
.292 .23171 L
.296 .23178 L
.3 .23187 L
.304 .23198 L
.308 .23205 L
.312 .23207 L
.316 .232 L
.32 .23182 L
.324 .23155 L
.328 .23123 L
.332 .23092 L
.336 .23071 L
.34 .23071 L
.344 .23098 L
.348 .23156 L
.352 .23245 L
.356 .23357 L
.36 .23478 L
.364 .23587 L
.368 .23662 L
.372 .23676 L
.376 .23606 L
.38 .23434 L
.384 .2315 L
.388 .2275 L
.392 .22242 L
.396 .21645 L
.4 .20982 L
Mistroke
.404 .20286 L
.408 .1959 L
.412 .18929 L
.416 .18335 L
.42 .17835 L
.424 .17449 L
.428 .17189 L
.432 .17061 L
.436 .17063 L
.44 .17184 L
.444 .1741 L
.448 .17725 L
.452 .18108 L
.456 .1854 L
.46 .19 L
.464 .19473 L
.468 .19944 L
.472 .20401 L
.476 .20836 L
.48 .21244 L
.484 .21624 L
.488 .21975 L
.492 .22301 L
.496 .22607 L
.5 .22898 L
.504 .23182 L
.508 .23466 L
.512 .23757 L
.516 .24062 L
.52 .24388 L
.524 .24739 L
.528 .25118 L
.532 .25526 L
.536 .2596 L
.54 .26417 L
.544 .26887 L
.548 .27359 L
.552 .2782 L
.556 .28251 L
.56 .28634 L
.564 .28948 L
.568 .29175 L
.572 .29296 L
.576 .29298 L
.58 .2917 L
.584 .28911 L
.588 .28526 L
.592 .28026 L
.596 .27433 L
.6 .26772 L
Mistroke
.604 .26076 L
.608 .2538 L
.612 .24717 L
.616 .24118 L
.62 .2361 L
.624 .23209 L
.628 .22923 L
.632 .22751 L
.636 .2268 L
.64 .22694 L
.644 .22768 L
.648 .22878 L
.652 .22999 L
.656 .23112 L
.66 .23202 L
.664 .23261 L
.668 .23288 L
.672 .23288 L
.676 .23268 L
.68 .23237 L
.684 .23204 L
.688 .23176 L
.692 .23158 L
.696 .23151 L
.7 .23152 L
.704 .2316 L
.708 .23171 L
.712 .2318 L
.716 .23187 L
.72 .2319 L
.724 .2319 L
.728 .23187 L
.732 .23183 L
.736 .2318 L
.74 .23178 L
.744 .23178 L
.748 .23178 L
.752 .23179 L
.756 .23181 L
.76 .23182 L
.764 .23182 L
.768 .23182 L
.772 .23181 L
.776 .23181 L
.78 .2318 L
.784 .2318 L
.788 .2318 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35317 L
.22 .35317 L
.224 .35318 L
.228 .35317 L
.232 .35316 L
.236 .35315 L
.24 .35313 L
.244 .35312 L
.248 .35313 L
.252 .35316 L
.256 .35321 L
.26 .35325 L
.264 .35327 L
.268 .35326 L
.272 .35319 L
.276 .35308 L
.28 .35296 L
.284 .35286 L
.288 .35284 L
.292 .35293 L
.296 .35316 L
.3 .3535 L
.304 .35387 L
.308 .35415 L
.312 .35422 L
.316 .35397 L
.32 .35335 L
.324 .35239 L
.328 .35124 L
.332 .35014 L
.336 .3494 L
.34 .34937 L
.344 .35031 L
.348 .35238 L
.352 .35554 L
.356 .35952 L
.36 .36382 L
.364 .36772 L
.368 .37037 L
.372 .37089 L
.376 .36843 L
.38 .36233 L
.384 .35219 L
.388 .33793 L
.392 .31983 L
.396 .29849 L
.4 .27483 L
Mistroke
.404 .24994 L
.408 .22506 L
.412 .20141 L
.416 .18014 L
.42 .16222 L
.424 .14836 L
.428 .13902 L
.432 .13438 L
.436 .13433 L
.44 .13855 L
.444 .14651 L
.448 .15757 L
.452 .171 L
.456 .18608 L
.46 .20207 L
.464 .21831 L
.468 .23423 L
.472 .24935 L
.476 .26327 L
.48 .27571 L
.484 .28645 L
.488 .29536 L
.492 .30234 L
.496 .30736 L
.5 .31037 L
.504 .31137 L
.508 .31037 L
.512 .30736 L
.516 .30235 L
.52 .29536 L
.524 .28645 L
.528 .27571 L
.532 .26327 L
.536 .24935 L
.54 .23424 L
.544 .21831 L
.548 .20207 L
.552 .18608 L
.556 .17101 L
.56 .15757 L
.564 .14651 L
.568 .13855 L
.572 .13434 L
.576 .13438 L
.58 .13903 L
.584 .14836 L
.588 .16222 L
.592 .18015 L
.596 .20142 L
.6 .22506 L
Mistroke
.604 .24994 L
.608 .27483 L
.612 .29849 L
.616 .31983 L
.62 .33793 L
.624 .35219 L
.628 .36233 L
.632 .36843 L
.636 .37089 L
.64 .37037 L
.644 .36772 L
.648 .36382 L
.652 .35952 L
.656 .35554 L
.66 .35238 L
.664 .35031 L
.668 .34937 L
.672 .3494 L
.676 .35014 L
.68 .35124 L
.684 .35239 L
.688 .35335 L
.692 .35397 L
.696 .35422 L
.7 .35415 L
.704 .35387 L
.708 .3535 L
.712 .35316 L
.716 .35293 L
.72 .35284 L
.724 .35286 L
.728 .35296 L
.732 .35308 L
.736 .35319 L
.74 .35326 L
.744 .35327 L
.748 .35325 L
.752 .35321 L
.756 .35316 L
.76 .35313 L
.764 .35312 L
.768 .35313 L
.772 .35315 L
.776 .35316 L
.78 .35317 L
.784 .35318 L
.788 .35317 L
.792 .35317 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23177 L
.22 .23177 L
.224 .23178 L
.228 .23177 L
.232 .23176 L
.236 .23175 L
.24 .23174 L
.244 .23173 L
.248 .23174 L
.252 .23176 L
.256 .2318 L
.26 .23184 L
.264 .23186 L
.268 .23184 L
.272 .23179 L
.276 .2317 L
.28 .23159 L
.284 .23151 L
.288 .23149 L
.292 .23157 L
.296 .23177 L
.3 .23205 L
.304 .23235 L
.308 .23259 L
.312 .23265 L
.316 .23244 L
.32 .23192 L
.324 .23111 L
.328 .23015 L
.332 .22922 L
.336 .22861 L
.34 .22858 L
.344 .22937 L
.348 .23111 L
.352 .23376 L
.356 .2371 L
.36 .24071 L
.364 .24398 L
.368 .24621 L
.372 .24664 L
.376 .24458 L
.38 .23946 L
.384 .23094 L
.388 .21898 L
.392 .20378 L
.396 .18588 L
.4 .16601 L
Mistroke
.404 .14512 L
.408 .12424 L
.412 .1044 L
.416 .08656 L
.42 .07152 L
.424 .05991 L
.428 .0521 L
.432 .04824 L
.436 .04825 L
.44 .05186 L
.444 .05865 L
.448 .06808 L
.452 .07957 L
.456 .09252 L
.46 .10635 L
.464 .12054 L
.468 .13467 L
.472 .14838 L
.476 .16144 L
.48 .17368 L
.484 .18507 L
.488 .19561 L
.492 .20539 L
.496 .21456 L
.5 .2233 L
.504 .23181 L
.508 .24033 L
.512 .24907 L
.516 .25824 L
.52 .26802 L
.524 .27856 L
.528 .28994 L
.532 .30219 L
.536 .31525 L
.54 .32896 L
.544 .34308 L
.548 .35728 L
.552 .37111 L
.556 .38405 L
.56 .39554 L
.564 .40498 L
.568 .41176 L
.572 .41538 L
.576 .41539 L
.58 .41153 L
.584 .40372 L
.588 .3921 L
.592 .37707 L
.596 .35922 L
.6 .33938 L
Mistroke
.604 .3185 L
.608 .29761 L
.612 .27775 L
.616 .25984 L
.62 .24465 L
.624 .23268 L
.628 .22417 L
.632 .21905 L
.636 .21699 L
.64 .21742 L
.644 .21965 L
.648 .22292 L
.652 .22652 L
.656 .22987 L
.66 .23252 L
.664 .23426 L
.668 .23505 L
.672 .23502 L
.676 .2344 L
.68 .23348 L
.684 .23251 L
.688 .23171 L
.692 .23119 L
.696 .23098 L
.7 .23104 L
.704 .23127 L
.708 .23158 L
.712 .23186 L
.716 .23206 L
.72 .23214 L
.724 .23212 L
.728 .23204 L
.732 .23193 L
.736 .23184 L
.74 .23178 L
.744 .23177 L
.748 .23179 L
.752 .23183 L
.756 .23187 L
.76 .23189 L
.764 .2319 L
.768 .23189 L
.772 .23188 L
.776 .23186 L
.78 .23185 L
.784 .23185 L
.788 .23186 L
.792 .23186 L
.796 .23187 L
.8 .23187 L
Mistroke
.804 .23187 L
.808 .23187 L
.812 .23187 L
.816 .23186 L
.82 .23186 L
.824 .23186 L
.828 .23186 L
.832 .23186 L
.836 .23187 L
.84 .23187 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00<007ooOol010000Woo00<007ooOol00goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00<007ooOol0
0P0000Eoo`00001oo`0000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`00
1Goo000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@0
07ooOol0009oo`04001oo`000004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007oo
Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000
Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool30005
Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo
000LOol2000XOol00`00Oomoo`04Ool20012Ool001aoo`03001oogoo02Ioo`03001oogoo00Ioo`80
045oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo0`000Woo00D007ooOomoo`0000=oo`03
001oogoo008000=oo`09001oogooOol007oo001oo`0000=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yo
o`0077oo0P00=7oo0P001goo00<007ooOol0<goo000LOol00`00Oomoo`0dOol20006Ool00`00Oomo
o`0cOol001aoo`8003Ioo`03001oogoo00=oo`03001oogoo03Aoo`0077oo00<007ooOol0=Woo00@0
07ooOomoo`8003Ioo`002goo0P0017oo00@007ooOomoo`D0009oo`8003Qoo`@003Moo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0hOol2000hOol000Yoo`04001oogoo0009Ool0
0`00Oomoo`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000;
Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo
0000M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007oo
Ool000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo
00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00@007ooOomoo`8007=oo`00
77oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03
001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Ao
o`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000
Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`80
00Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001o
ogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol0
01Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
00]oo`8000Aoo`03001oogoo009oo`<007Qoo`002Woo00@007ooOol000Moo`05001oogooOol0001g
Ool000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000]oo`8000Uo
o`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03
001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo10000goo0P00Lgoo000:Ool01000Oomoo`001goo00<007ooOol017oo
00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007ooOol00goo0P00Lgoo000;Ool2000:Ool2
0003Ool00`00Oomoo`1bOol001aoo`8002]oo`03001oogoo00]oo`8003Qoo`0077oo00<007ooOol0
:Goo00<007oo000037oo0P00>7oo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000ZOol00`00
Ool0000<Ool00`00Ool0000gOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000:goo00@007oo
Ool000Yoo`04001oogoo000gOol000=oo`D0009oo`04001oogoo0007Ool50002Ool00`00Oomoo`0Y
Ool01000Oomoo`002Woo00@007ooOol003Moo`002Woo00@007ooOol000Moo`04001oogoo0003Ool2
000YOol01@00Oomoogoo00002Woo00@007ooOol003Moo`002Woo00@007ooOol000Qoo`03001oo`00
00=oo`03001oogoo02Qoo`05001oogooOol00009Ool01@00Oomoogoo0000=goo000:Ool01000Oomo
o`002Goo0P000goo0P00:Goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol00Woo00<007oo
Ool0=7oo000;Ool2000;Ool01@00Oomoogoo0000:Woo00<007ooOol00Woo00<007ooOol01Woo00<0
07ooOol00Woo00<007ooOol0=7oo000LOol2000XOol00`00Oomoo`03Ool00`00Oomoo`05Ool00`00
Oomoo`03Ool00`00Oomoo`0dOol001aoo`03001oogoo02Moo`03001oogoo00=oo`03001oogoo00Eo
o`03001oogoo00=oo`03001oogoo03Aoo`002goo0P0017oo00@007ooOomoo`D0009oo`8002Qoo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo03Aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool00`00Oomoo`0WOol00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomo
o`04Ool00`00Oomoo`0cOol000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomo
o`0WOol00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0cOol000Yoo`04
001oogoo000:Ool01000Oomoogoo0P003Woo0`0017oo0P002Goo0`0017oo0P0017oo0`0017oo0`00
0goo10000goo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`05001oogooOol00002Ool01000Oomo
o`002Goo00<007ooOol00Woo00@007oo0000009oo`03001oogoo008000Aoo`05001oogooOol00003
Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`80015oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool01000Ool000000Woo00<007ooOol00P000goo0P001goo00@007ooOol0009oo`03001oogoo
00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`002goo0P002Goo0`000goo00<007ooOol047oo00@007ooOol0009o
o`03001oogoo00Moo`03001oogoo009oo`800005Ool007ooOol00002Ool00`00Ool00002Ool20007
Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003
Ool01000Oomoo`002Goo00<007ooOol00Woo0P0000Eoo`00Oomoo`00009oo`03001oo`0000@000=o
o`D0009oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004
Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo
00Aoo`04001oogoo0008Ool20004Ool200001Goo001oogoo00000Woo00D007ooOol007oo008000=o
o`03001oogoo009oo`03001oo`00009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomo
o`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<0
07ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`H0009o
o`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P009Woo00<007oo
Ool05Goo00<007ooOol0<Woo000LOol00`00Oomoo`0UOol00`00Oomoo`0EOol00`00Oomoo`0bOol0
01aoofT000aoo`0077oo00<007ooOol04Woo00<007ooOol03Goo0`000Woo00<007ooOol04Goo00<0
07ooOol010003Woo00<007ooOol04Woo00<007ooOol02Woo000LOol2000TOol2000JOol00`00Oomo
o`0`Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`002goo0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001cOol0
00Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0
001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomo
o`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool0
1000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01@00Oomoogoo0000M7oo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03
001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo02Yoo`03001oogoo04Eoo`002goo0P0017oo00<007ooOol0
0goo0`000Woo0P00:Woo00<007oo0000AWoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0002]o
o`03001oo`0004Ioo`000goo1@000Woo00@007ooOol000Moo`D0009oo`8002Yoo`04001oogoo0015
Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0:7oo00D007ooOomoo`0004Eo
o`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8002Uoo`05001oogooOol00015Ool000Yoo`04
001oogoo0009Ool20003Ool00`00Oomoo`0XOol00`00Oomoo`02Ool00`00Oomoo`12Ool000]oo`80
00]oo`04001oogooOol2000YOol00`00Oomoo`02Ool00`00Oomoo`12Ool001aoo`03001oogoo02Mo
o`03001oogoo00=oo`03001oogoo049oo`002goo0P0017oo00@007ooOomoo`D0009oo`8002Qoo`03
001oogoo00Aoo`03001oogoo045oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomo
o`0=Ool30004Ool20009Ool30004Ool20004Ool30004Ool30003Ool30004Ool20005Ool50003Ool2
0004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomo
o`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oo`00
0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo00@007oo
Ool0009oo`03001oogoo00Moo`03001oogoo009oo`04001oo`000002Ool01000Oomoo`001Goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo00<007oo
Ool00Woo00@007oo0000009oo`03001oogoo008000Aoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol037oo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oo`000002Ool0
0`00Oomoo`020004Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`00
2goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`800005Ool0
07ooOol00002Ool20003Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`00
1Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20002Ool01@00
Oomoogoo00000goo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo
000LOol2000WOol00`00Oomoo`07Ool00`00Oomoo`0oOol001aoo`03001oogoo02Eoo`03001oogoo
00Qoo`03001oogoo00aoo`80035oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007oo
Ool00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`020003Ool00`00Ool0
0002Ool01@00Oomoogoo00000goo00<007ooOol00P000goo00D007ooOomoo`00009oo`800003Ool0
0000008000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03
001oogoo009oo`03001oogoo00Yoo`0077oo0P0097oo0P003Goo00<007ooOol027oo00<007ooOol0
<Woo000LOol00`00Oomoo`0cOol00`00Oomoo`07Ool00`00Oomoo`0bOol001aoo`8003Aoo`03001o
ogoo00Moo`03001oogoo039oo`0077oo00<007ooOol0<goo00<007ooOol01Woo00<007ooOol0<goo
000;Ool20004Ool01000Oomoogoo1@000Woo0P00=Goo00<007ooOol01Goo00<007ooOol0<goo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo03Aoo`03001oogoo00Eoo`03001oogoo
03=oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8003Eoo`03001oogoo00Eoo`03001oogoo
03=oo`002Woo00@007ooOol000Yoo`05001oogooOol0000gOol00`00Oomoo`04Ool00`00Oomoo`0c
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00=Woo00<007ooOol017oo00<007oo
Ool0<goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo03Eoo`03001oogoo
00=oo`03001oogoo03Aoo`002goo0P002Goo0`000goo0P00=Woo00<007ooOol00goo00<007ooOol0
=7oo000LOol00`00Oomoo`0fOol00`00Oomoo`02Ool00`00Oomoo`0dOol000]oo`8000Aoo`03001o
ogoo00=oo`<0009oo`8003Moo`03001oogoo009oo`03001oogoo03Aoo`002Woo00@007ooOol000Yo
o`05001oogooOol0000hOol01@00Oomoogoo0000=goo000:Ool01000Oomoo`001goo1@000Woo0P00
>7oo00@007ooOol003Moo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0gOol0
1000Oomoo`00=goo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00>Goo00<007oo0000=goo
000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0>7oo0P00>7oo000;Ool2000;Ool01000Oomo
ogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<0
07ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079o
o`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001c
Ool000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo
079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=o
o`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03
001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3120\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23177 L
.216 .23177 L
.22 .23177 L
.224 .23177 L
.228 .23178 L
.232 .23178 L
.236 .23178 L
.24 .23178 L
.244 .23177 L
.248 .23177 L
.252 .23176 L
.256 .23176 L
.26 .23177 L
.264 .23178 L
.268 .23179 L
.272 .2318 L
.276 .23181 L
.28 .2318 L
.284 .23178 L
.288 .23174 L
.292 .23171 L
.296 .23168 L
.3 .23168 L
.304 .23171 L
.308 .23179 L
.312 .23189 L
.316 .23199 L
.32 .23207 L
.324 .23208 L
.328 .232 L
.332 .23181 L
.336 .23152 L
.34 .23118 L
.344 .23087 L
.348 .23067 L
.352 .23068 L
.356 .23097 L
.36 .23159 L
.364 .23251 L
.368 .23366 L
.372 .2349 L
.376 .236 L
.38 .23674 L
.384 .23686 L
.388 .23613 L
.392 .23437 L
.396 .23147 L
.4 .22742 L
Mistroke
.404 .2223 L
.408 .21629 L
.412 .20965 L
.416 .20268 L
.42 .19574 L
.424 .18916 L
.428 .18326 L
.432 .17831 L
.436 .17452 L
.44 .172 L
.444 .1708 L
.448 .1709 L
.452 .17222 L
.456 .17461 L
.46 .17791 L
.464 .18194 L
.468 .1865 L
.472 .19143 L
.476 .19656 L
.48 .20178 L
.484 .20699 L
.488 .21213 L
.492 .21718 L
.496 .22213 L
.5 .22699 L
.504 .23181 L
.508 .23664 L
.512 .2415 L
.516 .24644 L
.52 .25149 L
.524 .25662 L
.528 .26183 L
.532 .26705 L
.536 .27218 L
.54 .2771 L
.544 .28166 L
.548 .28568 L
.552 .28898 L
.556 .29137 L
.56 .29269 L
.564 .29279 L
.568 .2916 L
.572 .28908 L
.576 .28529 L
.58 .28035 L
.584 .27446 L
.588 .26788 L
.592 .26094 L
.596 .25397 L
.6 .24732 L
Mistroke
.604 .2413 L
.608 .23617 L
.612 .23211 L
.616 .2292 L
.62 .22744 L
.624 .2267 L
.628 .22682 L
.632 .22755 L
.636 .22866 L
.64 .2299 L
.644 .23106 L
.648 .23199 L
.652 .23261 L
.656 .23291 L
.66 .23292 L
.664 .23272 L
.668 .23241 L
.672 .23207 L
.676 .23178 L
.68 .23158 L
.684 .2315 L
.688 .23151 L
.692 .23158 L
.696 .23169 L
.7 .2318 L
.704 .23187 L
.708 .23191 L
.712 .2319 L
.716 .23188 L
.72 .23184 L
.724 .2318 L
.728 .23178 L
.732 .23177 L
.736 .23178 L
.74 .23179 L
.744 .23181 L
.748 .23182 L
.752 .23182 L
.756 .23182 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .2318 L
.776 .2318 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35317 L
.232 .35318 L
.236 .35318 L
.24 .35317 L
.244 .35316 L
.248 .35314 L
.252 .35312 L
.256 .35312 L
.26 .35313 L
.264 .35317 L
.268 .35322 L
.272 .35326 L
.276 .35328 L
.28 .35326 L
.284 .35318 L
.288 .35306 L
.292 .35293 L
.296 .35283 L
.3 .35282 L
.304 .35294 L
.308 .35319 L
.312 .35355 L
.316 .35393 L
.32 .35421 L
.324 .35426 L
.328 .35397 L
.332 .3533 L
.336 .35228 L
.34 .35109 L
.344 .34997 L
.348 .34925 L
.352 .34926 L
.356 .35029 L
.36 .35247 L
.364 .35576 L
.368 .35985 L
.372 .36423 L
.376 .36817 L
.38 .37081 L
.384 .37126 L
.388 .36868 L
.392 .36242 L
.396 .3521 L
.4 .33765 L
Mistroke
.404 .31938 L
.408 .29792 L
.412 .27416 L
.416 .24924 L
.42 .22436 L
.424 .20077 L
.428 .17957 L
.432 .16173 L
.436 .14794 L
.44 .13864 L
.444 .13398 L
.448 .13382 L
.452 .13783 L
.456 .14545 L
.46 .15601 L
.464 .16875 L
.468 .18289 L
.472 .19767 L
.476 .21237 L
.48 .22635 L
.484 .23906 L
.488 .25004 L
.492 .25894 L
.496 .26548 L
.5 .26948 L
.504 .27083 L
.508 .26948 L
.512 .26548 L
.516 .25894 L
.52 .25004 L
.524 .23906 L
.528 .22635 L
.532 .21237 L
.536 .19767 L
.54 .1829 L
.544 .16876 L
.548 .15601 L
.552 .14546 L
.556 .13784 L
.56 .13383 L
.564 .13398 L
.568 .13864 L
.572 .14794 L
.576 .16173 L
.58 .17958 L
.584 .20077 L
.588 .22437 L
.592 .24924 L
.596 .27416 L
.6 .29792 L
Mistroke
.604 .31938 L
.608 .33765 L
.612 .3521 L
.616 .36242 L
.62 .36868 L
.624 .37126 L
.628 .37081 L
.632 .36817 L
.636 .36423 L
.64 .35985 L
.644 .35576 L
.648 .35247 L
.652 .35029 L
.656 .34926 L
.66 .34925 L
.664 .34997 L
.668 .35109 L
.672 .35228 L
.676 .3533 L
.68 .35397 L
.684 .35426 L
.688 .35421 L
.692 .35393 L
.696 .35355 L
.7 .35319 L
.704 .35294 L
.708 .35282 L
.712 .35283 L
.716 .35293 L
.72 .35306 L
.724 .35318 L
.728 .35326 L
.732 .35328 L
.736 .35326 L
.74 .35322 L
.744 .35317 L
.748 .35313 L
.752 .35312 L
.756 .35313 L
.76 .35314 L
.764 .35316 L
.768 .35317 L
.772 .35318 L
.776 .35318 L
.78 .35317 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23177 L
.232 .23177 L
.236 .23178 L
.24 .23177 L
.244 .23176 L
.248 .23175 L
.252 .23173 L
.256 .23173 L
.26 .23174 L
.264 .23177 L
.268 .23181 L
.272 .23185 L
.276 .23186 L
.28 .23184 L
.284 .23178 L
.288 .23168 L
.292 .23157 L
.296 .23149 L
.3 .23148 L
.304 .23158 L
.308 .23179 L
.312 .23209 L
.316 .23241 L
.32 .23264 L
.324 .23268 L
.328 .23244 L
.332 .23187 L
.336 .23102 L
.34 .23002 L
.344 .22908 L
.348 .22848 L
.352 .22849 L
.356 .22935 L
.36 .23119 L
.364 .23394 L
.368 .23738 L
.372 .24105 L
.376 .24436 L
.38 .24658 L
.384 .24695 L
.388 .24479 L
.392 .23954 L
.396 .23087 L
.4 .21876 L
Mistroke
.404 .20343 L
.408 .18542 L
.412 .16549 L
.416 .1446 L
.42 .12376 L
.424 .104 L
.428 .08628 L
.432 .07141 L
.436 .05999 L
.44 .0524 L
.444 .04878 L
.448 .04907 L
.452 .053 L
.456 .06016 L
.46 .07006 L
.464 .08213 L
.468 .09582 L
.472 .1106 L
.476 .12601 L
.48 .14168 L
.484 .15731 L
.488 .17275 L
.492 .18789 L
.496 .20273 L
.5 .21734 L
.504 .23181 L
.508 .24629 L
.512 .2609 L
.516 .27574 L
.52 .29088 L
.524 .30631 L
.528 .32195 L
.532 .33761 L
.536 .35302 L
.54 .36781 L
.544 .38149 L
.548 .39357 L
.552 .40346 L
.556 .41063 L
.56 .41456 L
.564 .41484 L
.568 .41122 L
.572 .40363 L
.576 .39221 L
.58 .37734 L
.584 .35963 L
.588 .33987 L
.592 .31903 L
.596 .29813 L
.6 .27821 L
Mistroke
.604 .2602 L
.608 .24487 L
.612 .23275 L
.616 .22409 L
.62 .21884 L
.624 .21667 L
.628 .21705 L
.632 .21926 L
.636 .22257 L
.64 .22625 L
.644 .22969 L
.648 .23244 L
.652 .23427 L
.656 .23514 L
.66 .23515 L
.664 .23455 L
.668 .23361 L
.672 .2326 L
.676 .23175 L
.68 .23119 L
.684 .23094 L
.688 .23098 L
.692 .23122 L
.696 .23154 L
.7 .23184 L
.704 .23205 L
.708 .23215 L
.712 .23214 L
.716 .23206 L
.72 .23195 L
.724 .23185 L
.728 .23178 L
.732 .23176 L
.736 .23178 L
.74 .23182 L
.744 .23186 L
.748 .23189 L
.752 .2319 L
.756 .2319 L
.76 .23188 L
.764 .23187 L
.768 .23186 L
.772 .23185 L
.776 .23185 L
.78 .23186 L
.784 .23187 L
.788 .23187 L
.792 .23187 L
.796 .23187 L
.8 .23187 L
Mistroke
.804 .23186 L
.808 .23186 L
.812 .23186 L
.816 .23186 L
.82 .23186 L
.824 .23187 L
.828 .23187 L
.832 .23187 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00D007ooOol007oo00<00003Ool007oo00Aoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol037oo10000goo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo
00@00003Ool0000000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00<007oo
Ool00P0000Eoo`00Oomoo`0000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`03001oogoo00=oo`@0009oo`@000Ao
o`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool0
01aoo`8002Uoo`03001oogoo00Aoo`80045oo`0077oo00<007ooOol09goo00<007ooOol01Woo00<0
07ooOol0?goo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Ool000030003Ool01@00
Oomoogoo00000Woo0P000goo00@007ooOomoo`80009oo`05001oogooOol00004Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:
Ool001aoo`8003Aoo`03001oogoo00Eoo`03001oogoo03Aoo`0077oo00<007ooOol0<goo0P001Goo
0P00=Woo000LOol2000eOol20004Ool00`00Oomoo`0eOol001aoo`03001oogoo03Eoo`04001oogoo
Ool2000gOol000]oo`8000Aoo`04001oogooOol50002Ool2000gOol4000hOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00<007ooOol0=goo0P00>Goo000:Ool01000Oomoo`002Goo00<007oo
Ool00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`002goo0P00
17oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Ao
o`002Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001o
ogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03
001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomo
o`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00
Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol0
00Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001c
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool3
0003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02
Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol0
0`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool2
0004Ool00`00Oomoo`02Ool3001hOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000Mgoo0003
Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qo
o`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000;Ool20009Ool30003
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomo
o`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`@000=oo`8007=oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`03001o
ogoo079oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`8007=oo`002goo0P002Woo0P000goo
00<007ooOol0LWoo000LOol2000/Ool2000:Ool2000iOol001aoo`03001oogoo02]oo`8000Uoo`<0
03Uoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00:goo00<007oo00002Goo00<007oo0000
>Goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0002aoo`04001oogoo0008Ool01000Oomoo`00
>7oo0003Ool50002Ool01000Oomoo`001goo1@000Woo00<007ooOol0:Woo00@007ooOol000Moo`05
001oogooOol0000hOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P00:Woo00<007ooOol0
0Woo00<007ooOol017oo00D007ooOomoo`0003Qoo`002Woo00@007ooOol000Qoo`03001oo`0000=o
o`03001oogoo02Uoo`03001oogoo009oo`03001oogoo00Aoo`05001oogooOol0000hOol000Yoo`04
001oogoo0009Ool20003Ool2000ZOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
0`00Oomoo`0eOol000]oo`8000]oo`05001oogooOol0000[Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`0eOol001aoo`8002Yoo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo00=oo`03001oogoo03Eoo`0077oo00<007ooOol0:Goo00<007ooOol00goo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol0=Goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00
:Woo00<007ooOol00goo00D007ooOomoo`0000Ioo`03001oogoo03Eoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool00`00Oomoo`0XOol00`00Oomoo`05Ool01000Oomoo`001Woo00<007ooOol0
=Goo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo00<007ooOol0:7oo00<007ooOol0
1Goo00@007ooOol000Ioo`03001oogoo03Eoo`002Woo00@007ooOol000Yoo`04001oogooOol2000>
Ool30004Ool20009Ool30004Ool30003Ool20002Ool60003Ool30004Ool20005Ool50003Ool20004
Ool20005Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol037oo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`05001oogooOol00002Ool20002Ool01000Oomoo`001Goo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`00
0Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04001o
ogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo00Aoo`80009oo`04001oogoo0006Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Uoo`<000=o
o`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Ool00000
0Woo00@007ooOol000Eoo`03001oogoo00Aoo`80009oo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Ool000000Woo
00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000L
Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo0000009oo`04
001oogoo0004Ool20003Ool01@00Oomoogoo00000Woo00@007ooOol000Aoo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eo
o`0077oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007oo
Oomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00
:7oo00<007ooOol04Woo00<007ooOol0<goo000LOol00`00Oomoo`0QOol00`00Oomoo`03Ool00`00
Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0^Ool001aoofT000aoo`0077oo00<007ooOol04Woo
00<007ooOol03Woo0P0000=oo`0000004goo00D007oo001oo`00011oo`03001oogoo019oo`03001o
ogoo00Yoo`0077oo0P009Goo0P005goo0P00<goo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogooOol50002Ool2
001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0LWoo000:Ool01000Oomo
o`002Goo00<007ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yo
o`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo
000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qo
o`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo
0P002goo00D007ooOomoo`0007Aoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`80
00Aoo`03001oogoo00=oo`<0009oo`8002aoo`8004Eoo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0000/Ool00`00Ool00015Ool000=oo`D0009oo`04001oogoo0007Ool50002Ool2000[Ool01000
Oomoo`00A7oo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo02Uoo`05001oogoo
Ool00014Ool000Yoo`04001oogoo0008Ool00`00Ool00003Ool2000ZOol00`00Oomoo`02Ool00`00
Oomoo`11Ool000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`0YOol00`00Oomoo`02Ool00`00
Oomoo`11Ool000]oo`8000]oo`04001oogooOol2000ZOol00`00Oomoo`02Ool00`00Oomoo`11Ool0
01aoo`03001oogoo02Uoo`03001oogoo009oo`03001oogoo045oo`002goo0P0017oo00@007ooOomo
o`D0009oo`8002Yoo`03001oogoo009oo`03001oogoo045oo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool00`00Oomoo`0=Ool30004Ool20009Ool30004Ool30003Ool200000goo001oo`02Ool3
0003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0
009oo`04001oogoo0009Ool00`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol0
00Uoo`03001oogoo009oo`04001oogoo0002Ool00`00Oomoo`020004Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol0
00Yoo`05001oogooOol0000BOol01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@0
07ooOol0009oo`03001oogoo008000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01P00Oomoo`00Ool0
00=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo10000goo00@007ooOol0
00Uoo`03001oogoo009oo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogooOol40003
Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H0
07ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool2000=Ool00`00Oomo
o`04Ool01000Oomoo`0027oo0P0017oo00@007oo0000009oo`06001oogoo001oo`000Woo0P000goo
00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@00
0goo0P002Woo00<007ooOol00goo0P0017oo0P000Woo00D007ooOomoo`0000=oo`D000=oo`8000Io
o`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00:7oo00<007ooOol01Woo
00<007ooOol0?goo000LOol00`00Oomoo`0WOol00`00Oomoo`07Ool00`00Oomoo`09Ool3000bOol0
01aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00@007ooOomoo`80009oo`<00003Ool0000000=oo`09001oogooOol007oo
001oo`0000=oo`04001oogooOol20002Ool50004Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`8002Eoo`8000ao
o`03001oogoo00Moo`03001oogoo03=oo`0077oo00<007ooOol0<Woo00<007ooOol01goo00<007oo
Ool0<goo000LOol2000cOol00`00Oomoo`07Ool00`00Oomoo`0cOol001aoo`03001oogoo03=oo`03
001oogoo00Eoo`03001oogoo03Aoo`002goo0P0017oo00@007ooOomoo`D0009oo`8003Aoo`03001o
ogoo00Eoo`03001oogoo03Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0c
Ool00`00Oomoo`05Ool00`00Oomoo`0dOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000d
Ool00`00Oomoo`05Ool00`00Oomoo`0dOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000=Goo
00<007ooOol017oo00<007ooOol0=Goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
03Eoo`03001oogoo00=oo`03001oogoo03Eoo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`0dOol00`00Oomoo`03Ool00`00Oomoo`0eOol000]oo`8000Uoo`<000=oo`8003Eo
o`03001oogoo00=oo`03001oogoo03Eoo`0077oo00<007ooOol0=Goo00<007ooOol00Woo00<007oo
Ool0=Goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000fOol00`00Oomoo`02Ool00`00Oomo
o`0eOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000=goo00D007ooOomoo`0003Qoo`002Woo
00@007ooOol000Moo`D0009oo`8003Ioo`05001oogooOol0000hOol000Yoo`04001oogoo0007Ool0
1000Oomoo`000goo00<007ooOol0=Woo00@007ooOol003Qoo`002Woo00@007ooOol000Qoo`03001o
o`0000=oo`8003Moo`03001oo`0003Uoo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo03Mo
o`8003Uoo`002goo0P002goo00@007ooOomoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004
Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@0
07ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80
07=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P00
0goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<0
07ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo
00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00
NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3160\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23177 L
.216 .23177 L
.22 .23177 L
.224 .23177 L
.228 .23177 L
.232 .23177 L
.236 .23177 L
.24 .23178 L
.244 .23178 L
.248 .23178 L
.252 .23178 L
.256 .23177 L
.26 .23177 L
.264 .23176 L
.268 .23176 L
.272 .23177 L
.276 .23178 L
.28 .23179 L
.284 .23181 L
.288 .23181 L
.292 .2318 L
.296 .23178 L
.3 .23174 L
.304 .2317 L
.308 .23167 L
.312 .23167 L
.316 .23171 L
.32 .23179 L
.324 .2319 L
.328 .23201 L
.332 .23209 L
.336 .23209 L
.34 .232 L
.344 .23179 L
.348 .23149 L
.352 .23114 L
.356 .23082 L
.36 .23062 L
.364 .23065 L
.368 .23097 L
.372 .23162 L
.376 .23258 L
.38 .23376 L
.384 .23501 L
.388 .23613 L
.392 .23687 L
.396 .23697 L
.4 .23621 L
Mistroke
.404 .2344 L
.408 .23146 L
.412 .22737 L
.416 .22222 L
.42 .21619 L
.424 .20954 L
.428 .2026 L
.432 .19571 L
.436 .18922 L
.44 .18343 L
.444 .17864 L
.448 .17503 L
.452 .17274 L
.456 .17184 L
.46 .1723 L
.464 .17406 L
.468 .177 L
.472 .18096 L
.476 .18579 L
.48 .19133 L
.484 .1974 L
.488 .20388 L
.492 .21065 L
.496 .21761 L
.5 .22468 L
.504 .23181 L
.508 .23893 L
.512 .24601 L
.516 .25296 L
.52 .25972 L
.524 .2662 L
.528 .27227 L
.532 .2778 L
.536 .28263 L
.54 .28659 L
.544 .28953 L
.548 .29129 L
.552 .29175 L
.556 .29085 L
.56 .28857 L
.564 .28497 L
.568 .28018 L
.572 .2744 L
.576 .26791 L
.58 .26102 L
.584 .25407 L
.588 .24743 L
.592 .24139 L
.596 .23623 L
.6 .23213 L
Mistroke
.604 .22917 L
.608 .22736 L
.612 .22659 L
.616 .22669 L
.62 .22742 L
.624 .22854 L
.628 .2298 L
.632 .23099 L
.636 .23196 L
.64 .23262 L
.644 .23294 L
.648 .23297 L
.652 .23277 L
.656 .23245 L
.66 .2321 L
.664 .23179 L
.668 .23158 L
.672 .23149 L
.676 .23149 L
.68 .23157 L
.684 .23168 L
.688 .23179 L
.692 .23187 L
.696 .23191 L
.7 .23191 L
.704 .23188 L
.708 .23185 L
.712 .23181 L
.716 .23178 L
.72 .23177 L
.724 .23178 L
.728 .23179 L
.732 .2318 L
.736 .23182 L
.74 .23182 L
.744 .23182 L
.748 .23182 L
.752 .23181 L
.756 .23181 L
.76 .2318 L
.764 .2318 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35317 L
.244 .35318 L
.248 .35318 L
.252 .35317 L
.256 .35316 L
.26 .35314 L
.264 .35312 L
.268 .35312 L
.272 .35313 L
.276 .35317 L
.28 .35323 L
.284 .35327 L
.288 .35329 L
.292 .35326 L
.296 .35317 L
.3 .35304 L
.304 .3529 L
.308 .35281 L
.312 .35281 L
.316 .35295 L
.32 .35323 L
.324 .35361 L
.328 .354 L
.332 .35427 L
.336 .3543 L
.34 .35397 L
.344 .35324 L
.348 .35217 L
.352 .35093 L
.356 .34979 L
.36 .34909 L
.364 .34916 L
.368 .35028 L
.372 .35257 L
.376 .35598 L
.38 .36018 L
.384 .36464 L
.388 .36862 L
.392 .37124 L
.396 .37161 L
.4 .36889 L
Mistroke
.404 .36246 L
.408 .35194 L
.412 .33729 L
.416 .31881 L
.42 .29716 L
.424 .27325 L
.428 .24819 L
.432 .22319 L
.436 .19946 L
.44 .17808 L
.444 .15998 L
.448 .14582 L
.452 .13596 L
.456 .13052 L
.46 .1293 L
.464 .13189 L
.468 .13768 L
.472 .14591 L
.476 .15577 L
.48 .1664 L
.484 .17699 L
.488 .18678 L
.492 .19511 L
.496 .20145 L
.5 .20542 L
.504 .20677 L
.508 .20542 L
.512 .20145 L
.516 .19511 L
.52 .18678 L
.524 .17699 L
.528 .1664 L
.532 .15577 L
.536 .14591 L
.54 .13768 L
.544 .1319 L
.548 .12931 L
.552 .13052 L
.556 .13597 L
.56 .14582 L
.564 .15999 L
.568 .17809 L
.572 .19946 L
.576 .22319 L
.58 .24819 L
.584 .27325 L
.588 .29717 L
.592 .31882 L
.596 .33729 L
.6 .35194 L
Mistroke
.604 .36246 L
.608 .36889 L
.612 .37161 L
.616 .37124 L
.62 .36862 L
.624 .36464 L
.628 .36018 L
.632 .35598 L
.636 .35257 L
.64 .35028 L
.644 .34916 L
.648 .34909 L
.652 .34979 L
.656 .35093 L
.66 .35217 L
.664 .35324 L
.668 .35397 L
.672 .3543 L
.676 .35427 L
.68 .354 L
.684 .35361 L
.688 .35323 L
.692 .35295 L
.696 .35281 L
.7 .35281 L
.704 .3529 L
.708 .35304 L
.712 .35317 L
.716 .35326 L
.72 .35329 L
.724 .35327 L
.728 .35323 L
.732 .35317 L
.736 .35314 L
.74 .35312 L
.744 .35312 L
.748 .35314 L
.752 .35316 L
.756 .35317 L
.76 .35318 L
.764 .35318 L
.768 .35317 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23177 L
.244 .23178 L
.248 .23178 L
.252 .23177 L
.256 .23176 L
.26 .23174 L
.264 .23173 L
.268 .23173 L
.272 .23174 L
.276 .23177 L
.28 .23182 L
.284 .23185 L
.288 .23187 L
.292 .23184 L
.296 .23177 L
.3 .23166 L
.304 .23154 L
.308 .23146 L
.312 .23147 L
.316 .23158 L
.32 .23182 L
.324 .23214 L
.328 .23247 L
.332 .2327 L
.336 .23272 L
.34 .23244 L
.344 .23183 L
.348 .23093 L
.352 .22989 L
.356 .22893 L
.36 .22834 L
.364 .2284 L
.368 .22934 L
.372 .23127 L
.376 .23413 L
.38 .23766 L
.384 .24141 L
.388 .24475 L
.392 .24696 L
.396 .24728 L
.4 .24502 L
Mistroke
.404 .23964 L
.408 .23084 L
.412 .21859 L
.416 .20316 L
.42 .1851 L
.424 .16518 L
.428 .14436 L
.432 .12367 L
.436 .10417 L
.44 .08679 L
.444 .07237 L
.448 .06152 L
.452 .05464 L
.456 .0519 L
.46 .05326 L
.464 .05852 L
.468 .06731 L
.472 .0792 L
.476 .09369 L
.48 .11029 L
.484 .12852 L
.488 .14797 L
.492 .16828 L
.496 .18917 L
.5 .21041 L
.504 .23181 L
.508 .25321 L
.512 .27445 L
.516 .29534 L
.52 .31566 L
.524 .33511 L
.528 .35334 L
.532 .36993 L
.536 .38442 L
.54 .39631 L
.544 .4051 L
.548 .41036 L
.552 .41173 L
.556 .40899 L
.56 .4021 L
.564 .39125 L
.568 .37683 L
.572 .35946 L
.576 .33995 L
.58 .31927 L
.584 .29845 L
.588 .27853 L
.592 .26046 L
.596 .24503 L
.6 .23279 L
Mistroke
.604 .22399 L
.608 .21861 L
.612 .21635 L
.616 .21667 L
.62 .21888 L
.624 .22222 L
.628 .22597 L
.632 .2295 L
.636 .23236 L
.64 .23429 L
.644 .23522 L
.648 .23528 L
.652 .23469 L
.656 .23374 L
.66 .2327 L
.664 .2318 L
.668 .23119 L
.672 .23091 L
.676 .23093 L
.68 .23116 L
.684 .23149 L
.688 .23181 L
.692 .23204 L
.696 .23216 L
.7 .23216 L
.704 .23208 L
.708 .23197 L
.712 .23186 L
.716 .23178 L
.72 .23176 L
.724 .23177 L
.728 .23181 L
.732 .23185 L
.736 .23189 L
.74 .2319 L
.744 .2319 L
.748 .23189 L
.752 .23187 L
.756 .23186 L
.76 .23185 L
.764 .23185 L
.768 .23186 L
.772 .23186 L
.776 .23187 L
.78 .23187 L
.784 .23187 L
.788 .23187 L
.792 .23186 L
.796 .23186 L
.8 .23186 L
Mistroke
.804 .23186 L
.808 .23186 L
.812 .23187 L
.816 .23187 L
.82 .23187 L
.824 .23186 L
.828 .23186 L
.832 .23186 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`@000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Ao
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol037oo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`80
00Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01@00Oomoo`00Ool0
0P000Woo0P000goo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`00
77oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P0000Aoo`00001oo`800003Ool0
000000=oo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool2
0006Ool001aoo`8002Yoo`03001oogoo00Aoo`03001oogoo03moo`0077oo00<007ooOol0:7oo0P00
1Woo00<007ooOol0?goo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`030003
Ool01@00Oomoogoo00000Woo0P000goo00<007ooOol00P000goo00D007ooOomoo`0000Aoo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001o
ogoo00Yoo`0077oo0P00<goo0P001Woo00<007ooOol0=Goo000LOol00`00Oomoo`0cOol00`00Oomo
o`03Ool2000gOol001aoo`8003Aoo`8000Aoo`03001oogoo03Ioo`0077oo00<007ooOol0=7oo00D0
07ooOomoo`0003Uoo`002goo0P0017oo00@007ooOomoo`D0009oo`8003Ioo`@003Uoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0009Ool00`00Oomo
o`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004
Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo
000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=o
o`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007oo
Ool000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00@007ooOomoo`8007=oo`0077oo00<0
07ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo
079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`00
27oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<0
00=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009o
o`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03
001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`80
00Aoo`03001oogoo009oo`<007Qoo`002Woo00@007ooOol000Moo`05001oogooOol0001gOol000=o
o`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo
0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000]oo`8000Uoo`<000=o
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo
009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo10000goo0P00Lgoo000:Ool01000Oomoo`001goo00<007ooOol017oo00<007oo
Ool0LWoo000:Ool01000Oomoo`0027oo00<007ooOol00goo0P00Lgoo000;Ool2000:Ool20003Ool0
0`00Oomoo`1bOol001aoo`8002eoo`8000Moo`<003Yoo`0077oo00<007ooOol0;7oo00<007oo0000
1Woo00<007oo0000>Woo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000]Ool00`00Ool00006
Ool00`00Ool0000jOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000;Goo00@007ooOol000Eo
o`05001oogooOol0000iOol000=oo`D0009oo`04001oogoo0007Ool50002Ool00`00Oomoo`0[Ool0
1@00Oomoogoo000017oo00D007ooOomoo`0003Uoo`002Woo00@007ooOol000Moo`04001oogoo0003
Ool2000/Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol0=goo000:Ool01000Oomo
o`0027oo00<007oo00000goo00<007ooOol0:goo00<007ooOol00Woo00@007ooOol000Aoo`03001o
ogoo03Moo`002Woo00@007ooOol000Uoo`8000=oo`8002]oo`03001oogoo00=oo`04001oo`000004
Ool00`00Oomoo`0gOol000]oo`8000]oo`05001oogooOol0000/Ool00`00Oomoo`04Ool20005Ool0
0`00Oomoo`0gOol001aoo`8002]oo`03001oogoo00aoo`03001oogoo03Ioo`0077oo00<007ooOol0
:Woo00<007ooOol037oo00<007ooOol0=Woo000;Ool20004Ool01000Oomoogoo1@000Woo0P00:Woo
00<007ooOol03Goo00<007ooOol0=Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001o
ogoo02Uoo`03001oogoo00eoo`03001oogoo03Ioo`000goo1@000Woo00@007ooOol000Uoo`03001o
ogoo009oo`03001oogoo02Uoo`03001oogoo00eoo`03001oogoo03Ioo`002Woo00@007ooOol000Yo
o`04001oogooOol2000>Ool30004Ool20009Ool30004Ool2000017oo001oogoo0P001Goo0`000goo
0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`05001oogooOol00002Ool01000Oomoo`00
2Goo00<007ooOol00Woo00<007ooOol00P0000Eoo`00Oomoo`0000Eoo`09001oogooOol007oo001o
o`00009oo`04001oogoo0005Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P004Goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`03
001oogoo00800005Ool007ooOol00005Ool00`00Oomoo`03Ool00`00Ool00002Ool01000Oomoo`00
1Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00goo000;Ool20009Ool30003Ool00`00Oomoo`0@Ool01000Oomoo`000Woo
00<007ooOol01goo00<007ooOol00Woo00<007ooOol00P0000Eoo`00Oomoo`0000Eoo`03001oogoo
00=oo`03001oo`00009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@0
00=oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0200001Goo001oogoo00001Goo00@0
07ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03
001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=o
o`03001oo`0000Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D0
00=oo`8000Yoo`03001oogoo00=oo`<000=oo`8000Ioo`04001oogooOol50003Ool20006Ool30004
Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`8002Uoo`03001oogoo011oo`03001o
ogoo03Aoo`0077oo00<007ooOol08Woo0P0017oo00<007ooOol047oo00<007ooOol00Woo00<007oo
Ool0;goo000LOomY000<Ool001aoo`03001oogoo019oo`03001oogoo00moo`800003Ool007oo019o
o`800003Ool007oo011oo`03001oogoo019oo`03001oogoo00Yoo`0077oo0P009Woo0`0057oo0P00
=7oo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol000]oo`8000Aoo`04001oogooOol50002Ool2001cOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00Lgoo000:
Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;
Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool2
0004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000
M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol0
00=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@0
07ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00D007ooOomoo`0007Aoo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8002eo
o`8004Aoo`002Woo00@007ooOol000Yoo`05001oogooOol0000^Ool30013Ool000=oo`D0009oo`04
001oogoo0007Ool50002Ool2000/Ool01000Oomoo`00@goo000:Ool01000Oomoo`001goo00@007oo
Ool000=oo`03001oogoo02]oo`04001oogoo0013Ool000Yoo`04001oogoo0008Ool00`00Ool00003
Ool2000/Ool01000Oomoo`00@goo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0:Woo00D0
07ooOomoo`0004=oo`002goo0P002goo00@007ooOomoo`8002]oo`03001oogoo009oo`03001oogoo
041oo`0077oo00<007ooOol0:Woo00<007ooOol00Woo00<007ooOol0@7oo000;Ool20004Ool01000
Oomoogoo1@000Woo0P00:goo00<007ooOol00Woo00<007ooOol0@7oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`800004Ool007ooOol20000
0goo001oo`02Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool2
0006Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool2000=Ool01@00Oomoogoo0000
0Woo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo00800007Ool007ooOol007oo00000goo
00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo00@007ooOol0009oo`03001oogoo00Mo
o`03001oogoo009oo`03001oogoo00800007Ool007ooOol007oo00000goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00<007oo
Ool00P0000Moo`00Oomoo`00Ool00003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
1Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000
Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0200001goo001oogoo
001oo`0000=oo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2
0009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00<007ooOol00P00
00Moo`00Oomoo`00Ool00002Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool30003Ool20002Ool0
1@00Oomoogoo00000goo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P00
1Woo000LOol2000YOol00`00Oomoo`06Ool00`00Oomoo`0nOol001aoo`03001oogoo02Qoo`03001o
ogoo00Ioo`03001oogoo00Qoo`<003=oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoogoo0`0000=oo`00
Ool00P0000=oo`00Ool00Woo00T007ooOomoo`00Ool007oo00000goo00D007ooOomoo`0000=oo`<0
0003Ool007oo00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`03001oogoo009oo`03001oogoo00Yoo`0077oo0P009Woo0`002Woo00<007ooOol01Woo00<007oo
Ool0=7oo000LOol00`00Oomoo`0bOol00`00Oomoo`05Ool00`00Oomoo`0eOol001aoo`8003=oo`03
001oogoo00Eoo`03001oogoo03Eoo`0077oo00<007ooOol0<Woo00<007ooOol01Goo00<007ooOol0
=Goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00<goo00<007ooOol01Goo00<007ooOol0=Goo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo03=oo`03001oogoo00Aoo`03001o
ogoo03Eoo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8003Aoo`03001oogoo00Aoo`03001o
ogoo03Eoo`002Woo00@007ooOol000Yoo`05001oogooOol0000eOol00`00Oomoo`03Ool00`00Oomo
o`0fOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00=7oo00<007ooOol00goo00<0
07ooOol0=Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo03=oo`03001o
ogoo00=oo`03001oogoo03Ioo`002goo0P002Goo0`000goo0P00=7oo00<007ooOol00goo00<007oo
Ool0=Woo000LOol00`00Oomoo`0dOol00`00Oomoo`02Ool00`00Oomoo`0fOol000]oo`8000Aoo`03
001oogoo00=oo`<0009oo`8003Eoo`05001oogooOol0000iOol000Yoo`04001oogoo000:Ool01@00
Oomoogoo0000=Woo00D007ooOomoo`0003Uoo`002Woo00@007ooOol000Moo`D0009oo`8003Ioo`04
001oogoo000iOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0=Goo00@007oo
Ool003Uoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8003Ioo`03001oo`0003Yoo`002Woo
00@007ooOol000Uoo`8000=oo`03001oogoo03Ioo`8003Yoo`002goo0P002goo00@007ooOomoo`80
07=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo
00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:
Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Mo
o`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomo
o`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3200\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23177 L
.216 .23177 L
.22 .23177 L
.224 .23177 L
.228 .23177 L
.232 .23177 L
.236 .23177 L
.24 .23177 L
.244 .23177 L
.248 .23177 L
.252 .23178 L
.256 .23178 L
.26 .23178 L
.264 .23178 L
.268 .23177 L
.272 .23177 L
.276 .23176 L
.28 .23176 L
.284 .23177 L
.288 .23178 L
.292 .2318 L
.296 .23181 L
.3 .23181 L
.304 .2318 L
.308 .23177 L
.312 .23173 L
.316 .23169 L
.32 .23167 L
.324 .23167 L
.328 .23172 L
.332 .23181 L
.336 .23192 L
.34 .23203 L
.344 .23211 L
.348 .2321 L
.352 .232 L
.356 .23177 L
.36 .23146 L
.364 .23109 L
.368 .23077 L
.372 .23058 L
.376 .23062 L
.38 .23097 L
.384 .23165 L
.388 .23265 L
.392 .23387 L
.396 .23515 L
.4 .23628 L
Mistroke
.404 .23703 L
.408 .23712 L
.412 .23635 L
.416 .23453 L
.42 .23158 L
.424 .2275 L
.428 .22239 L
.432 .21644 L
.436 .20992 L
.44 .20317 L
.444 .19655 L
.448 .19041 L
.452 .18508 L
.456 .18085 L
.46 .17794 L
.464 .1765 L
.468 .1766 L
.472 .17825 L
.476 .18139 L
.48 .1859 L
.484 .19162 L
.488 .19839 L
.492 .206 L
.496 .21424 L
.5 .22291 L
.504 .2318 L
.508 .24068 L
.512 .24935 L
.516 .25759 L
.52 .2652 L
.524 .27196 L
.528 .27769 L
.532 .2822 L
.536 .28534 L
.54 .28699 L
.544 .2871 L
.548 .28566 L
.552 .28276 L
.556 .27854 L
.56 .27321 L
.564 .26707 L
.568 .26045 L
.572 .2537 L
.576 .24718 L
.58 .24122 L
.584 .2361 L
.588 .232 L
.592 .22904 L
.596 .22722 L
.6 .22644 L
Mistroke
.604 .22653 L
.608 .22727 L
.612 .22841 L
.616 .22969 L
.62 .23092 L
.624 .23192 L
.628 .23261 L
.632 .23297 L
.636 .23301 L
.64 .23282 L
.644 .2325 L
.648 .23213 L
.652 .23181 L
.656 .23159 L
.66 .23147 L
.664 .23147 L
.668 .23155 L
.672 .23166 L
.676 .23177 L
.68 .23186 L
.684 .23191 L
.688 .23192 L
.692 .23189 L
.696 .23185 L
.7 .23181 L
.704 .23178 L
.708 .23177 L
.712 .23177 L
.716 .23179 L
.72 .2318 L
.724 .23181 L
.728 .23182 L
.732 .23182 L
.736 .23182 L
.74 .23181 L
.744 .23181 L
.748 .2318 L
.752 .2318 L
.756 .2318 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35317 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35315 L
.244 .35316 L
.248 .35316 L
.252 .35317 L
.256 .35318 L
.26 .35318 L
.264 .35317 L
.268 .35315 L
.272 .35313 L
.276 .35312 L
.28 .35312 L
.284 .35314 L
.288 .35318 L
.292 .35324 L
.296 .35328 L
.3 .3533 L
.304 .35325 L
.308 .35316 L
.312 .35302 L
.316 .35287 L
.32 .35278 L
.324 .3528 L
.328 .35296 L
.332 .35326 L
.336 .35367 L
.34 .35407 L
.344 .35434 L
.348 .35434 L
.352 .35396 L
.356 .35317 L
.36 .35205 L
.364 .35076 L
.368 .34961 L
.372 .34892 L
.376 .34905 L
.38 .35026 L
.384 .35266 L
.388 .35618 L
.392 .36048 L
.396 .36501 L
.4 .36899 L
Mistroke
.404 .37155 L
.408 .37178 L
.412 .36886 L
.416 .36215 L
.42 .35128 L
.424 .33623 L
.428 .31731 L
.432 .29513 L
.436 .27062 L
.44 .24484 L
.444 .21895 L
.448 .19412 L
.452 .17136 L
.456 .15151 L
.46 .13514 L
.464 .12256 L
.468 .11377 L
.472 .10852 L
.476 .10635 L
.48 .10661 L
.484 .10858 L
.488 .1115 L
.492 .11465 L
.496 .11739 L
.5 .11924 L
.504 .11989 L
.508 .11924 L
.512 .11739 L
.516 .11465 L
.52 .11151 L
.524 .10859 L
.528 .10661 L
.532 .10635 L
.536 .10852 L
.54 .11377 L
.544 .12256 L
.548 .13515 L
.552 .15151 L
.556 .17136 L
.56 .19412 L
.564 .21896 L
.568 .24484 L
.572 .27062 L
.576 .29514 L
.58 .31731 L
.584 .33623 L
.588 .35128 L
.592 .36215 L
.596 .36886 L
.6 .37178 L
Mistroke
.604 .37155 L
.608 .36899 L
.612 .36501 L
.616 .36048 L
.62 .35618 L
.624 .35266 L
.628 .35026 L
.632 .34905 L
.636 .34892 L
.64 .34961 L
.644 .35076 L
.648 .35205 L
.652 .35317 L
.656 .35396 L
.66 .35434 L
.664 .35434 L
.668 .35407 L
.672 .35367 L
.676 .35326 L
.68 .35296 L
.684 .3528 L
.688 .35278 L
.692 .35287 L
.696 .35302 L
.7 .35316 L
.704 .35326 L
.708 .3533 L
.712 .35328 L
.716 .35324 L
.72 .35318 L
.724 .35314 L
.728 .35312 L
.732 .35312 L
.736 .35313 L
.74 .35315 L
.744 .35317 L
.748 .35318 L
.752 .35318 L
.756 .35317 L
.76 .35316 L
.764 .35316 L
.768 .35315 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35317 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23177 L
.224 .23177 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23177 L
.256 .23178 L
.26 .23178 L
.264 .23177 L
.268 .23176 L
.272 .23174 L
.276 .23172 L
.28 .23172 L
.284 .23174 L
.288 .23178 L
.292 .23183 L
.296 .23186 L
.3 .23187 L
.304 .23184 L
.308 .23176 L
.312 .23164 L
.316 .23152 L
.32 .23144 L
.324 .23146 L
.328 .23159 L
.332 .23185 L
.336 .23219 L
.34 .23252 L
.344 .23275 L
.348 .23275 L
.352 .23243 L
.356 .23177 L
.36 .23083 L
.364 .22975 L
.368 .22879 L
.372 .22821 L
.376 .22833 L
.38 .22935 L
.384 .23138 L
.388 .23435 L
.392 .23798 L
.396 .24182 L
.4 .24521 L
Mistroke
.404 .24744 L
.408 .24774 L
.412 .24544 L
.416 .24002 L
.42 .23121 L
.424 .21899 L
.428 .20368 L
.432 .18584 L
.436 .16631 L
.44 .14606 L
.444 .12617 L
.448 .10772 L
.452 .09171 L
.456 .07899 L
.46 .07024 L
.464 .06589 L
.468 .06618 L
.472 .07111 L
.476 .0805 L
.48 .09402 L
.484 .1112 L
.488 .13151 L
.492 .15435 L
.496 .17911 L
.5 .20514 L
.504 .23181 L
.508 .25848 L
.512 .28452 L
.516 .30927 L
.52 .33212 L
.524 .35243 L
.528 .36961 L
.532 .38312 L
.536 .39251 L
.54 .39744 L
.544 .39773 L
.548 .39339 L
.552 .38463 L
.556 .37191 L
.56 .3559 L
.564 .33745 L
.568 .31756 L
.572 .29732 L
.576 .27778 L
.58 .25995 L
.584 .24464 L
.588 .23242 L
.592 .22361 L
.596 .21819 L
.6 .21589 L
Mistroke
.604 .21619 L
.608 .21842 L
.612 .22181 L
.616 .22564 L
.62 .22928 L
.624 .23225 L
.628 .23428 L
.632 .2353 L
.636 .23541 L
.64 .23484 L
.644 .23387 L
.648 .2328 L
.652 .23186 L
.656 .2312 L
.66 .23088 L
.664 .23088 L
.668 .2311 L
.672 .23144 L
.676 .23178 L
.68 .23204 L
.684 .23217 L
.688 .23218 L
.692 .23211 L
.696 .23199 L
.7 .23187 L
.704 .23179 L
.708 .23175 L
.712 .23176 L
.716 .2318 L
.72 .23185 L
.724 .23189 L
.728 .2319 L
.732 .2319 L
.736 .23189 L
.74 .23187 L
.744 .23186 L
.748 .23185 L
.752 .23185 L
.756 .23186 L
.76 .23186 L
.764 .23187 L
.768 .23187 L
.772 .23187 L
.776 .23187 L
.78 .23186 L
.784 .23186 L
.788 .23186 L
.792 .23186 L
.796 .23186 L
.8 .23187 L
Mistroke
.804 .23187 L
.808 .23187 L
.812 .23186 L
.816 .23186 L
.82 .23186 L
.824 .23186 L
.828 .23186 L
.832 .23186 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo10001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`80
00Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo
0P0000=oo`0000000goo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eo
o`0077oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P000goo0`000Woo00D007oo
Oomoo`0000=oo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`00
77oo0P00:goo00<007ooOol00goo00<007ooOol0?goo000LOol00`00Oomoo`0YOol20006Ool00`00
Oomoo`0nOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`04001oogooOol30002Ool01@00
Oomoogoo00000Woo0P000goo00<007oo00000P000goo00D007ooOomoo`0000Aoo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yo
o`0077oo0P00<goo00<007ooOol017oo00<007ooOol0=Woo000LOol00`00Oomoo`0cOol00`00Oomo
o`02Ool00`00Oomoo`0gOol001aoo`8003Aoo`03001oogoo009oo`03001oogoo03Moo`0077oo00<0
07ooOol0=7oo00@007ooOol003Yoo`002goo0P0017oo00@007ooOomoo`D0009oo`8003Ioo`8003]o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0009
Ool00`00Oomoo`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo
000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomo
ogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@0
07ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`00
2Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00@007ooOomoo`8007=o
o`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=o
o`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`80
00Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool0
1000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]o
o`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03
001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1g
Ool001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool000]oo`8000Aoo`03001oogoo009oo`<007Qoo`002Woo00@007ooOol000Moo`05001oogooOol0
001gOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000
Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000]oo`80
00Uoo`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Ao
o`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo10000goo0P00Lgoo000:Ool01000Oomoo`001goo00<007ooOol0
17oo00<007ooOol0;Woo0P0017oo00<007ooOol0>goo000:Ool01000Oomoo`0027oo00<007ooOol0
0goo0P00;goo0`000Woo00<007oo0000?7oo000;Ool2000:Ool20003Ool00`00Oomoo`0]Ool00`00
Oomoo`030002Ool00`00Oomoo`0jOol001aoo`8002ioo`03001oogoo00Ioo`03001oogoo03Uoo`00
77oo00<007ooOol0;Goo00<007ooOol01Woo00<007ooOol0>Goo000;Ool20004Ool00`00Oomoo`03
Ool30002Ool2000]Ool00`00Oomoo`07Ool00`00Oomoo`0iOol000Yoo`04001oogoo000:Ool01@00
Oomoogoo0000;Woo00<007ooOol01goo00<007ooOol0>Goo0003Ool50002Ool01000Oomoo`001goo
1@000Woo00<007ooOol0;7oo00<007ooOol027oo00<007ooOol0>7oo000:Ool01000Oomoo`001goo
00@007ooOol000=oo`8002eoo`03001oogoo00Qoo`03001oogoo03Qoo`002Woo00@007ooOol000Qo
o`03001oo`0000=oo`03001oogoo02aoo`03001oogoo00Qoo`03001oogoo03Qoo`002Woo00@007oo
Ool000Uoo`8000=oo`8002eoo`03001oogoo00Qoo`03001oogoo03Qoo`002goo0P002goo00D007oo
Oomoo`0002eoo`03001oogoo00Yoo`03001oogoo03Moo`0077oo0P00;7oo00<007ooOol02Woo00<0
07ooOol0=goo000LOol00`00Oomoo`0[Ool00`00Oomoo`0:Ool00`00Oomoo`0gOol000]oo`8000Ao
o`04001oogooOol50002Ool2000/Ool00`00Oomoo`0:Ool00`00Oomoo`0gOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00<007ooOol0:goo00<007ooOol02Woo00<007ooOol0=goo0003Ool5
0002Ool01000Oomoo`002Goo00<007ooOol00Woo00<007ooOol0:goo00<007ooOol02Woo00<007oo
Ool0=goo000:Ool01000Oomoo`002Woo00@007ooOomoo`8000ioo`<000Aoo`8000Uoo`<000Aoo`80
009oo`04001oo`000005Ool30002Ool40004Ool20005Ool50003Ool20004Ool20005Ool50002Ool3
0004Ool20006Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo00D0
07ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01@00Oomoo`00Ool00P000Woo00<0
07ooOol00goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo00@007ooOol0
009oo`03001oogoo00Moo`03001oogoo009oo`05001oogoo001oo`020002Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P00
2Goo0`000goo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`05
001oogoo001oo`020002Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Moo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo
00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001o
ogoo009oo`05001oogoo001oo`020002Ool00`00Oomoo`03Ool01000Oomoogoo10000goo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol0
07oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol0
00Qoo`8000Aoo`03001oogoo00800005Ool007ooOol00004Ool20003Ool20005Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool0
0006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool2
000017oo001oogoo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0
009oo`D000=oo`8000Ioo`0077oo0P00:Woo00<007ooOol03Woo00<007ooOol0=Goo000LOol00`00
Oomoo`0TOol00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0`Ool001ao
ofT000aoo`0077oo00<007ooOol04Woo00<007ooOol04Goo0`004Goo10004Woo00<007ooOol04Woo
00<007ooOol02Woo000LOol2000XOol2000BOol2000eOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002goo0P0017oo00@007ooOomoo`D0
009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0009Ool00`00Oomoo`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000
M7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=o
o`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool50002Ool2
001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomo
o`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo
000;Ool2000;Ool01@00Oomoogoo0000M7oo000LOol2001cOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
2goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomo
o`0002moo`8004=oo`000goo1@000Woo00@007ooOol000Moo`D0009oo`8002ioo`8004=oo`002Woo
00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0/Ool00`00Ool00013Ool000Yoo`04001o
ogoo0008Ool00`00Ool00003Ool2000]Ool01000Oomoo`00@Woo000:Ool01000Oomoo`002Goo0P00
0goo00<007ooOol0;7oo00@007ooOol0049oo`002goo0P002goo00@007ooOomoo`8002eoo`04001o
ogoo0012Ool001aoo`03001oogoo02aoo`04001oogoo0012Ool000]oo`8000Aoo`04001oogooOol5
0002Ool2000/Ool00`00Oomoo`02Ool00`00Oomoo`0oOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P000goo0`000Woo00<007ooOol00`00
0goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002
Ool01000Oomoo`002Goo00<007ooOol00Woo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol0
00Yoo`05001oogooOol0000BOol01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@0
07ooOol0009oo`06001oogoo001oo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol0
1000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00D007ooOol007oo0080009oo`03001o
o`0000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo10000goo00@007oo
Ool000Uoo`03001oogoo009oo`05001oogoo001oo`020002Ool00`00Ool00003Ool01000Oomoogoo
10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Ao
o`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P003Goo00<0
07ooOol017oo00@007ooOol000Qoo`8000Aoo`05001oogoo001oo`020002Ool00`00Ool00002Ool2
0003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool0
1000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<
Ool50003Ool2000:Ool00`00Oomoo`03Ool20002Ool01000Ool000000goo00@007ooOol000=oo`D0
00=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00:Woo00<0
07ooOol01Goo00<007ooOol0?Woo000LOol00`00Oomoo`0YOol00`00Oomoo`05Ool00`00Oomoo`07
Ool2000eOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00H007ooOomoo`00Ool30002Ool40002Ool02@00Oomoogoo
001oo`00Ool00003Ool00`00Oomoo`020002Ool30002Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool0
01aoo`8002Qoo`8000Uoo`03001oogoo00Eoo`03001oogoo03Eoo`0077oo00<007ooOol0<Woo00<0
07ooOol017oo00<007ooOol0=Woo000LOol2000cOol00`00Oomoo`04Ool00`00Oomoo`0fOol001ao
o`03001oogoo039oo`03001oogoo00Aoo`03001oogoo03Ioo`002goo0P0017oo00@007ooOomoo`D0
009oo`8003=oo`03001oogoo00Aoo`03001oogoo03Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool00`00Oomoo`0bOol00`00Oomoo`03Ool00`00Oomoo`0gOol000Yoo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000dOol00`00Oomoo`02Ool00`00Oomoo`0gOol000Yoo`04001oogoo000:Ool0
1@00Oomoogoo0000=Goo00<007ooOol00Woo00<007ooOol0=goo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`8003Aoo`03001oogoo009oo`03001oogoo03Moo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`0cOol00`00Oomoo`02Ool00`00Oomoo`0gOol000]oo`80
00Uoo`<000=oo`8003Aoo`03001oogoo009oo`03001oogoo03Moo`0077oo00<007ooOol0<goo00D0
07ooOomoo`0003Yoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00=7oo00D007ooOomoo`00
03Yoo`002Woo00@007ooOol000Yoo`05001oogooOol0000fOol01000Oomoo`00>Woo000:Ool01000
Oomoo`001goo1@000Woo0P00=Goo00<007oo0000>goo000:Ool01000Oomoo`001goo00@007ooOol0
00=oo`03001oogoo03Eoo`8003]oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8003Ioo`03
001oogoo03Yoo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00@0
07ooOomoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2
001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qo
o`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomo
o`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2
001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000G
Ool00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3240\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23177 L
.216 .23177 L
.22 .23177 L
.224 .23177 L
.228 .23177 L
.232 .23178 L
.236 .23177 L
.24 .23177 L
.244 .23177 L
.248 .23177 L
.252 .23177 L
.256 .23177 L
.26 .23178 L
.264 .23178 L
.268 .23178 L
.272 .23178 L
.276 .23178 L
.28 .23177 L
.284 .23176 L
.288 .23176 L
.292 .23176 L
.296 .23177 L
.3 .23178 L
.304 .2318 L
.308 .23181 L
.312 .23181 L
.316 .2318 L
.32 .23177 L
.324 .23172 L
.328 .23168 L
.332 .23166 L
.336 .23167 L
.34 .23172 L
.344 .23182 L
.348 .23194 L
.352 .23205 L
.356 .23213 L
.36 .23212 L
.364 .23199 L
.368 .23176 L
.372 .23142 L
.376 .23106 L
.38 .23073 L
.384 .23056 L
.388 .23062 L
.392 .23101 L
.396 .23174 L
.4 .2328 L
Mistroke
.404 .23408 L
.408 .23543 L
.412 .23663 L
.416 .23745 L
.42 .23764 L
.424 .23697 L
.428 .23531 L
.432 .23257 L
.436 .22877 L
.44 .22403 L
.444 .21858 L
.448 .2127 L
.452 .20675 L
.456 .20111 L
.46 .19614 L
.464 .19219 L
.468 .18955 L
.472 .18843 L
.476 .18896 L
.48 .19118 L
.484 .19503 L
.488 .20038 L
.492 .20702 L
.496 .21468 L
.5 .22305 L
.504 .23178 L
.508 .24051 L
.512 .24889 L
.516 .25655 L
.52 .2632 L
.524 .26855 L
.528 .27241 L
.532 .27463 L
.536 .27517 L
.54 .27405 L
.544 .27142 L
.548 .26748 L
.552 .26251 L
.556 .25687 L
.56 .25092 L
.564 .24504 L
.568 .23958 L
.572 .23483 L
.576 .23102 L
.58 .22827 L
.584 .22659 L
.588 .22593 L
.592 .22611 L
.596 .22692 L
.6 .22813 L
Mistroke
.604 .22948 L
.608 .23077 L
.612 .23184 L
.616 .23258 L
.62 .23297 L
.624 .23304 L
.628 .23286 L
.632 .23254 L
.636 .23217 L
.64 .23183 L
.644 .23159 L
.648 .23146 L
.652 .23145 L
.656 .23152 L
.66 .23164 L
.664 .23176 L
.668 .23186 L
.672 .23191 L
.676 .23192 L
.68 .2319 L
.684 .23186 L
.688 .23182 L
.692 .23178 L
.696 .23177 L
.7 .23177 L
.704 .23178 L
.708 .2318 L
.712 .23181 L
.716 .23182 L
.72 .23182 L
.724 .23182 L
.728 .23181 L
.732 .23181 L
.736 .2318 L
.74 .2318 L
.744 .2318 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35317 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35315 L
.252 .35315 L
.256 .35316 L
.26 .35317 L
.264 .35318 L
.268 .35318 L
.272 .35318 L
.276 .35317 L
.28 .35315 L
.284 .35313 L
.288 .35311 L
.292 .35311 L
.296 .35314 L
.3 .35319 L
.304 .35325 L
.308 .35329 L
.312 .3533 L
.316 .35325 L
.32 .35314 L
.324 .35299 L
.328 .35284 L
.332 .35276 L
.336 .35279 L
.34 .35297 L
.344 .35331 L
.348 .35373 L
.352 .35414 L
.356 .3544 L
.36 .35436 L
.364 .35394 L
.368 .35309 L
.372 .3519 L
.376 .35057 L
.38 .34939 L
.384 .3487 L
.388 .34886 L
.392 .35012 L
.396 .35259 L
.4 .35615 L
Mistroke
.404 .36045 L
.408 .36489 L
.412 .36868 L
.416 .37092 L
.42 .37066 L
.424 .36708 L
.428 .35949 L
.432 .34753 L
.436 .33112 L
.44 .31053 L
.444 .28635 L
.448 .25941 L
.452 .23074 L
.456 .20143 L
.46 .17255 L
.464 .14508 L
.468 .11982 L
.472 .09734 L
.476 .078 L
.48 .06191 L
.484 .049 L
.488 .03905 L
.492 .03178 L
.496 .02686 L
.5 .02403 L
.504 .02311 L
.508 .02403 L
.512 .02686 L
.516 .03178 L
.52 .03905 L
.524 .049 L
.528 .06191 L
.532 .078 L
.536 .09734 L
.54 .11982 L
.544 .14508 L
.548 .17255 L
.552 .20143 L
.556 .23074 L
.56 .25942 L
.564 .28635 L
.568 .31053 L
.572 .33112 L
.576 .34753 L
.58 .35949 L
.584 .36708 L
.588 .37066 L
.592 .37092 L
.596 .36868 L
.6 .36489 L
Mistroke
.604 .36045 L
.608 .35615 L
.612 .35259 L
.616 .35012 L
.62 .34886 L
.624 .3487 L
.628 .34939 L
.632 .35057 L
.636 .3519 L
.64 .35309 L
.644 .35394 L
.648 .35436 L
.652 .3544 L
.656 .35414 L
.66 .35373 L
.664 .35331 L
.668 .35297 L
.672 .35279 L
.676 .35276 L
.68 .35284 L
.684 .35299 L
.688 .35314 L
.692 .35325 L
.696 .3533 L
.7 .35329 L
.704 .35325 L
.708 .35319 L
.712 .35314 L
.716 .35311 L
.72 .35311 L
.724 .35313 L
.728 .35315 L
.732 .35317 L
.736 .35318 L
.74 .35318 L
.744 .35318 L
.748 .35317 L
.752 .35316 L
.756 .35315 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35317 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23177 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23177 L
.264 .23177 L
.268 .23178 L
.272 .23178 L
.276 .23177 L
.28 .23175 L
.284 .23173 L
.288 .23172 L
.292 .23172 L
.296 .23175 L
.3 .23179 L
.304 .23184 L
.308 .23187 L
.312 .23188 L
.316 .23184 L
.32 .23174 L
.324 .23162 L
.328 .2315 L
.332 .23142 L
.336 .23145 L
.34 .23161 L
.344 .23188 L
.348 .23224 L
.352 .23259 L
.356 .23281 L
.36 .23278 L
.364 .23243 L
.368 .23172 L
.372 .23074 L
.376 .22964 L
.38 .22867 L
.384 .22813 L
.388 .22832 L
.392 .22946 L
.396 .23164 L
.4 .23478 L
Mistroke
.404 .23861 L
.408 .24264 L
.412 .24625 L
.416 .2487 L
.42 .24928 L
.424 .24732 L
.428 .24235 L
.432 .23415 L
.436 .22278 L
.44 .2086 L
.444 .19225 L
.448 .17463 L
.452 .15678 L
.456 .13984 L
.46 .12492 L
.464 .11306 L
.468 .10512 L
.472 .10174 L
.476 .10331 L
.48 .10994 L
.484 .12148 L
.488 .13753 L
.492 .15746 L
.496 .18046 L
.5 .20559 L
.504 .23181 L
.508 .25803 L
.512 .28316 L
.516 .30616 L
.52 .32609 L
.524 .34214 L
.528 .35368 L
.532 .36032 L
.536 .36189 L
.54 .35851 L
.544 .35057 L
.548 .3387 L
.552 .32379 L
.556 .30684 L
.56 .28899 L
.564 .27137 L
.568 .25503 L
.572 .24085 L
.576 .22947 L
.58 .22127 L
.584 .21631 L
.588 .21435 L
.592 .21492 L
.596 .21738 L
.6 .22099 L
Mistroke
.604 .22502 L
.608 .22885 L
.612 .23199 L
.616 .23417 L
.62 .23531 L
.624 .23549 L
.628 .23496 L
.632 .23399 L
.636 .23289 L
.64 .2319 L
.644 .2312 L
.648 .23085 L
.652 .23082 L
.656 .23104 L
.66 .23139 L
.664 .23174 L
.668 .23202 L
.672 .23218 L
.676 .2322 L
.68 .23213 L
.684 .23201 L
.688 .23188 L
.692 .23179 L
.696 .23175 L
.7 .23175 L
.704 .23179 L
.708 .23184 L
.712 .23188 L
.716 .23191 L
.72 .23191 L
.724 .23189 L
.728 .23188 L
.732 .23186 L
.736 .23185 L
.74 .23185 L
.744 .23185 L
.748 .23186 L
.752 .23187 L
.756 .23187 L
.76 .23187 L
.764 .23187 L
.768 .23186 L
.772 .23186 L
.776 .23186 L
.78 .23186 L
.784 .23186 L
.788 .23187 L
.792 .23187 L
.796 .23187 L
.8 .23187 L
Mistroke
.804 .23186 L
.808 .23186 L
.812 .23186 L
.816 .23186 L
.82 .23186 L
.824 .23186 L
.828 .23186 L
.832 .23186 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`03001oo`00008000=oo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`80009o
o`05001oogooOol00003Ool50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool2
0006Ool001aoo`8002eoo`05001oogooOol00011Ool001aoo`03001oogoo02]oo`03001oogoo009o
o`80041oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo0`0000=oo`00
Ool00Woo00<007ooOol00P000goo0P000Woo00D007ooOomoo`0000=oo`03001oogoo009oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001o
ogoo00Yoo`0077oo0P00<goo00<007ooOol00Woo0P00>Goo000LOol00`00Oomoo`0cOol00`00Oomo
o`02000jOol001aoo`8003Aoo`@003]oo`0077oo00<007ooOol0=7oo0P00?7oo000;Ool20004Ool0
1000Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo
079oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05
001oogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00
Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo
00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol0
00Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo
00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2
000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009o
o`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo1000
0goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000
Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001ao
o`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Io
o`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2
001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001o
ogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00N7oo000:Ool01000
Oomoo`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`80035oo`<003moo`002goo0P002Goo0`000goo00<007ooOol0<7oo00@007ooOol003io
o`0077oo0P00<7oo00D007ooOomoo`0003ioo`0077oo00<007ooOol0;goo00D007ooOomoo`0003io
o`002goo0P0017oo00<007ooOol00Woo0`000goo0P00<7oo00<007ooOol00Woo00<007ooOol0>goo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo02ioo`03001oogoo00=oo`03
001oogoo03]oo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0^
Ool00`00Oomoo`03Ool00`00Oomoo`0kOol000Yoo`04001oogoo0007Ool40003Ool2000_Ool00`00
Oomoo`04Ool00`00Oomoo`0jOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`0^
Ool00`00Oomoo`04Ool00`00Oomoo`0jOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool2000_
Ool00`00Oomoo`04Ool00`00Oomoo`0jOol000]oo`8000Yoo`8000=oo`03001oogoo02ioo`03001o
ogoo00Aoo`03001oogoo03Yoo`0077oo0P00;goo00<007ooOol017oo00<007ooOol0>Woo000LOol0
0`00Oomoo`0]Ool00`00Oomoo`05Ool00`00Oomoo`0jOol000]oo`8000Aoo`03001oogoo00=oo`<0
009oo`8002ioo`03001oogoo00Eoo`03001oogoo03Yoo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0000_Ool00`00Oomoo`06Ool00`00Oomoo`0iOol000=oo`D0009oo`04001oogoo0007Ool50002
Ool00`00Oomoo`0]Ool00`00Oomoo`06Ool00`00Oomoo`0iOol000Yoo`04001oogoo0007Ool01000
Oomoo`000goo0P00;Woo00<007ooOol01Woo00<007ooOol0>Goo000:Ool01000Oomoo`0027oo00<0
07oo00000goo00<007ooOol0;7oo00<007ooOol01goo00<007ooOol0>Goo000:Ool01000Oomoo`00
2Goo0P000goo0P00;Goo00<007ooOol01goo00<007ooOol0>Goo000;Ool2000;Ool01@00Oomoogoo
0000;Woo00<007ooOol01goo00<007ooOol0>Goo000LOol2000]Ool00`00Oomoo`08Ool00`00Oomo
o`0hOol001aoo`03001oogoo02aoo`03001oogoo00Qoo`03001oogoo03Qoo`002goo0P0017oo00@0
07ooOomoo`D0009oo`8002eoo`03001oogoo00Qoo`03001oogoo03Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool00`00Oomoo`0/Ool00`00Oomoo`08Ool00`00Oomoo`0hOol000=oo`D0009o
o`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0/Ool00`00Oomoo`08Ool00`00Oomoo`0h
Ool000Yoo`04001oogoo000:Ool01000Oomoogoo0P003Woo0`0017oo0P002Goo0`0017oo0P0017oo
0P001Goo0`0000=oo`00Ool00`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo
0P001Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`05001oogoo
Ool00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
1@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomo
o`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Goo0`000goo00<0
07ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool0
0`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`00
1Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0
009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`00
1Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20002Ool01000Ool00000
1Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Io
o`0077oo0P00:goo00<007ooOol02goo00<007ooOol0=goo000LOol00`00Oomoo`0UOol00`00Oomo
o`02Ool00`00Oomoo`0<Ool01000Oomoogoo0P00<goo000LOomY000<Ool001aoo`03001oogoo019o
o`03001oogoo019oo`03001oo`0000moo`@001=oo`03001oogoo019oo`03001oogoo00Yoo`0077oo
0P00:Goo0P0047oo0P00=Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogooOol50002Ool2001cOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002Goo00<007oo
Ool00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:
Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomo
o`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=o
o`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00D007oo
Oomoo`0007Aoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo
00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000=oo`D0009o
o`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`00
2Goo0P000goo00<007ooOol0;Woo00<007ooOol0@Goo000;Ool2000;Ool01000Oomoogoo0P00;Woo
00<007oo0000@Woo000LOol00`00Oomoo`0]Ool00`00Ool00012Ool000]oo`8000Aoo`04001oogoo
Ool50002Ool2000^Ool00`00Ool00012Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<0
07ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P000Woo00<007ooOol00`000goo0`0017oo
0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomo
o`002Goo00<007ooOol00Woo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomo
o`02Ool01000Oomoo`000Woo0P0000Aoo`00Ool000=oo`05001oogooOol00003Ool01000Oomoo`00
0Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`002Woo00D007oo
Oomoo`00019oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo
0P0000Aoo`00Ool000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo00@007ooOol0009o
o`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool2000017oo001oo`000goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`002Goo00<007oo
Ool00Woo00@007ooOol0009oo`800004Ool007oo0003Ool01000Oomoogoo10000goo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo
10000goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007oo
Ool000Qoo`8000Aoo`04001oogoo0002Ool01P00Oomoo`00Ool0009oo`8000=oo`03001oogoo00Ao
o`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00
Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`03
001oogoo00=oo`8000=oo`<000=oo`04001oogoo0003Ool50003Ool20006Ool30004Ool20004Ool2
0006Ool30002Ool50003Ool20006Ool001aoo`8002aoo`03001oogoo00=oo`03001oogoo03ioo`00
77oo00<007ooOol0:goo00<007ooOol00goo00<007ooOol01Goo0`00=Woo000LOomY000<Ool001ao
o`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00002Ool30003Ool00`00Oomoo`020003Ool01@00Ool007oo00000goo0P000Woo
00<007oo00000P000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol2000XOol30008Ool00`00
Oomoo`03Ool00`00Oomoo`0gOol001aoo`03001oogoo039oo`03001oogoo00=oo`03001oogoo03Mo
o`0077oo0P00<goo00<007ooOol00goo00<007ooOol0=goo000LOol00`00Oomoo`0bOol00`00Oomo
o`03Ool00`00Oomoo`0gOol000]oo`8000Aoo`04001oogooOol50002Ool2000cOol00`00Oomoo`02
Ool00`00Oomoo`0hOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0<Woo00<0
07ooOol00Woo00<007ooOol0>7oo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00=7oo00D0
07ooOomoo`0003Yoo`002Woo00@007ooOol000Yoo`05001oogooOol0000eOol01@00Oomoogoo0000
>Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8003Aoo`04001oogoo000kOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0<goo00@007ooOol003]oo`002goo
0P002Goo0`000goo0P00=7oo00@007ooOol003]oo`0077oo00<007ooOol0=7oo0P00?7oo000;Ool2
0004Ool00`00Oomoo`03Ool30002Ool2000eOol2000lOol000Yoo`04001oogoo000:Ool01@00Oomo
ogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@0
07ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`00
2Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00@007ooOomoo`8007=o
o`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=o
o`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`80
00Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool0
1000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]o
o`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03
001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1g
Ool001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3280\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23177 L
.216 .23177 L
.22 .23177 L
.224 .23177 L
.228 .23177 L
.232 .23177 L
.236 .23177 L
.24 .23177 L
.244 .23178 L
.248 .23177 L
.252 .23177 L
.256 .23177 L
.26 .23177 L
.264 .23177 L
.268 .23177 L
.272 .23178 L
.276 .23178 L
.28 .23178 L
.284 .23178 L
.288 .23178 L
.292 .23177 L
.296 .23176 L
.3 .23176 L
.304 .23176 L
.308 .23177 L
.312 .23179 L
.316 .2318 L
.32 .23182 L
.324 .23182 L
.328 .2318 L
.332 .23176 L
.336 .23172 L
.34 .23168 L
.344 .23165 L
.348 .23167 L
.352 .23173 L
.356 .23183 L
.36 .23196 L
.364 .23208 L
.368 .23216 L
.372 .23214 L
.376 .23202 L
.38 .23177 L
.384 .23144 L
.388 .23109 L
.392 .23079 L
.396 .23067 L
.4 .23082 L
Mistroke
.404 .23131 L
.408 .2322 L
.412 .23344 L
.416 .23495 L
.42 .23658 L
.424 .23812 L
.428 .23935 L
.432 .24004 L
.436 .24 L
.44 .23909 L
.444 .23727 L
.448 .23457 L
.452 .23114 L
.456 .22719 L
.46 .22304 L
.464 .219 L
.468 .21543 L
.472 .21265 L
.476 .21092 L
.48 .21042 L
.484 .21127 L
.488 .21344 L
.492 .21682 L
.496 .2212 L
.5 .2263 L
.504 .23177 L
.508 .23725 L
.512 .24235 L
.516 .24674 L
.52 .25013 L
.524 .25231 L
.528 .25316 L
.532 .25268 L
.536 .25096 L
.54 .24818 L
.544 .24461 L
.548 .24058 L
.552 .23642 L
.556 .23247 L
.56 .22903 L
.564 .22632 L
.568 .22449 L
.572 .22357 L
.576 .22352 L
.58 .22421 L
.584 .22544 L
.588 .22698 L
.592 .22861 L
.596 .23013 L
.6 .23138 L
Mistroke
.604 .23227 L
.608 .23277 L
.612 .23292 L
.616 .2328 L
.62 .23251 L
.624 .23215 L
.628 .23182 L
.632 .23157 L
.636 .23144 L
.64 .23142 L
.644 .23149 L
.648 .23162 L
.652 .23175 L
.656 .23185 L
.66 .23191 L
.664 .23193 L
.668 .23191 L
.672 .23187 L
.676 .23182 L
.68 .23179 L
.684 .23177 L
.688 .23177 L
.692 .23178 L
.696 .2318 L
.7 .23181 L
.704 .23182 L
.708 .23182 L
.712 .23182 L
.716 .23181 L
.72 .23181 L
.724 .2318 L
.728 .2318 L
.732 .2318 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35317 L
.244 .35317 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35315 L
.264 .35315 L
.268 .35316 L
.272 .35317 L
.276 .35318 L
.28 .35318 L
.284 .35318 L
.288 .35317 L
.292 .35314 L
.296 .35312 L
.3 .35311 L
.304 .35311 L
.308 .35315 L
.312 .3532 L
.316 .35326 L
.32 .35331 L
.324 .35331 L
.328 .35324 L
.332 .35312 L
.336 .35296 L
.34 .35281 L
.344 .35273 L
.348 .35278 L
.352 .35298 L
.356 .35334 L
.36 .35378 L
.364 .35419 L
.368 .35442 L
.372 .35433 L
.376 .35382 L
.38 .35288 L
.384 .35157 L
.388 .35012 L
.392 .34881 L
.396 .34799 L
.4 .34799 L
Mistroke
.404 .34905 L
.408 .35123 L
.412 .35437 L
.416 .35807 L
.42 .36166 L
.424 .3643 L
.428 .365 L
.432 .36277 L
.436 .35671 L
.44 .34609 L
.444 .33048 L
.448 .30978 L
.452 .28422 L
.456 .2544 L
.46 .22117 L
.464 .18561 L
.468 .14894 L
.472 .11241 L
.476 .07725 L
.48 .04457 L
.484 .01536 L
Mfstroke
.484 .01536 m
.48647 0 L
s
.52153 0 m
.524 .01537 L
.528 .04458 L
.532 .07725 L
.536 .11242 L
.54 .14894 L
.544 .18561 L
.548 .22117 L
.552 .2544 L
.556 .28422 L
.56 .30977 L
.564 .33048 L
.568 .34609 L
.572 .35671 L
.576 .36277 L
.58 .365 L
.584 .3643 L
.588 .36166 L
.592 .35807 L
.596 .35437 L
.6 .35123 L
.604 .34905 L
.608 .34799 L
.612 .34799 L
.616 .34881 L
.62 .35012 L
.624 .35157 L
.628 .35288 L
.632 .35382 L
.636 .35433 L
.64 .35442 L
.644 .35419 L
.648 .35378 L
.652 .35334 L
.656 .35298 L
.66 .35278 L
.664 .35273 L
.668 .35281 L
.672 .35296 L
.676 .35312 L
.68 .35324 L
.684 .35331 L
.688 .35331 L
.692 .35326 L
.696 .3532 L
.7 .35315 L
.704 .35311 L
.708 .35311 L
.712 .35312 L
.716 .35314 L
Mistroke
.72 .35317 L
.724 .35318 L
.728 .35318 L
.732 .35318 L
.736 .35317 L
.74 .35316 L
.744 .35315 L
.748 .35315 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35317 L
.768 .35317 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
Mistroke
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23177 L
.244 .23177 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23177 L
.276 .23178 L
.28 .23178 L
.284 .23178 L
.288 .23177 L
.292 .23175 L
.296 .23173 L
.3 .23172 L
.304 .23172 L
.308 .23175 L
.312 .2318 L
.316 .23185 L
.32 .23188 L
.324 .23188 L
.328 .23183 L
.332 .23173 L
.336 .2316 L
.34 .23147 L
.344 .23141 L
.348 .23145 L
.352 .23163 L
.356 .23193 L
.36 .23231 L
.364 .23267 L
.368 .2329 L
.372 .23286 L
.376 .23249 L
.38 .23177 L
.384 .23079 L
.388 .22973 L
.392 .22885 L
.396 .22847 L
.4 .2289 L
Mistroke
.404 .23037 L
.408 .233 L
.412 .2367 L
.416 .24121 L
.42 .24608 L
.424 .2507 L
.428 .2544 L
.432 .25649 L
.436 .25639 L
.44 .25369 L
.444 .24825 L
.448 .24018 L
.452 .22991 L
.456 .21811 L
.46 .20566 L
.464 .19356 L
.468 .18286 L
.472 .1745 L
.476 .16929 L
.48 .16781 L
.484 .17033 L
.488 .17683 L
.492 .18697 L
.496 .20011 L
.5 .2154 L
.504 .23181 L
.508 .24822 L
.512 .26351 L
.516 .27665 L
.52 .28679 L
.524 .29329 L
.528 .29581 L
.532 .29433 L
.536 .28912 L
.54 .28077 L
.544 .27006 L
.548 .25797 L
.552 .24552 L
.556 .23372 L
.56 .22344 L
.564 .21538 L
.568 .20993 L
.572 .20724 L
.576 .20714 L
.58 .20923 L
.584 .21293 L
.588 .21755 L
.592 .22242 L
.596 .22693 L
.6 .23063 L
Mistroke
.604 .23325 L
.608 .23473 L
.612 .23515 L
.616 .23478 L
.62 .2339 L
.624 .23284 L
.628 .23186 L
.632 .23114 L
.636 .23077 L
.64 .23073 L
.644 .23095 L
.648 .23131 L
.652 .23169 L
.656 .232 L
.66 .23218 L
.664 .23222 L
.668 .23216 L
.672 .23203 L
.676 .2319 L
.68 .23179 L
.684 .23174 L
.688 .23174 L
.692 .23178 L
.696 .23183 L
.7 .23188 L
.704 .23191 L
.708 .23191 L
.712 .2319 L
.716 .23188 L
.72 .23186 L
.724 .23185 L
.728 .23185 L
.732 .23185 L
.736 .23186 L
.74 .23187 L
.744 .23187 L
.748 .23187 L
.752 .23187 L
.756 .23187 L
.76 .23186 L
.764 .23186 L
.768 .23186 L
.772 .23186 L
.776 .23187 L
.78 .23187 L
.784 .23187 L
.788 .23187 L
.792 .23186 L
.796 .23186 L
.8 .23186 L
Mistroke
.804 .23186 L
.808 .23186 L
.812 .23186 L
.816 .23186 L
.82 .23186 L
.824 .23186 L
.828 .23186 L
.832 .23186 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2000_Ool30011Ool001aoo`03001oogoo02eoo`800003Ool007oo00Ioo`8003Qoo`0077ooJ@00
37oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo1P000Woo00<007ooOol00P000Woo0P00
0goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo0P00=7oo0`00?7oo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool01000
Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo079o
o`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001o
ogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo
000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@0
07ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yo
o`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<0
07oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;
Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<0
00=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomo
o`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03
001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<0
00=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001c
Ool001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo
07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00N7oo000:Ool01000Oomo
o`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002
Ool2000`Ool01@00Oomoogoo0000?Woo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0;goo
00D007ooOomoo`0003ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0_
Ool01@00Oomoogoo0000?Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80031oo`05
001oogooOol0000nOol000]oo`8000Uoo`<000=oo`03001oogoo02moo`03001oogoo009oo`03001o
ogoo03]oo`0077oo0P00<7oo00<007ooOol00Woo00<007ooOol0>goo000LOol00`00Oomoo`0_Ool0
0`00Oomoo`02Ool00`00Oomoo`0kOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8002moo`03
001oogoo00=oo`03001oogoo03]oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`0^Ool00`00Oomoo`03Ool00`00Oomoo`0kOol000=oo`D0009oo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0;Woo00<007ooOol00goo00<007ooOol0>goo000:Ool01000Oomo
o`001goo10000goo0P00;goo00<007ooOol00goo00<007ooOol0>goo000:Ool01000Oomoo`001goo
00<007ooOol017oo00<007ooOol0;Woo00<007ooOol017oo00<007ooOol0>Woo000:Ool01000Oomo
o`0027oo00<007ooOol00goo0P00;goo00<007ooOol017oo00<007ooOol0>Woo000;Ool2000:Ool2
0003Ool00`00Oomoo`0^Ool00`00Oomoo`04Ool00`00Oomoo`0jOol001aoo`8002moo`03001oogoo
00Aoo`03001oogoo03Yoo`0077oo00<007ooOol0;Woo00<007ooOol017oo00<007ooOol0>Woo000;
Ool20004Ool00`00Oomoo`03Ool30002Ool2000_Ool00`00Oomoo`04Ool00`00Oomoo`0jOol000Yo
o`04001oogoo000:Ool01@00Oomoogoo0000<7oo00<007ooOol017oo00<007ooOol0>Woo0003Ool5
0002Ool01000Oomoo`001goo1@000Woo00<007ooOol0;Woo00<007ooOol017oo00<007ooOol0>Woo
000:Ool01000Oomoo`001goo00@007ooOol000=oo`8002ioo`03001oogoo00Eoo`03001oogoo03Yo
o`002Woo00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo02eoo`03001oogoo00Eoo`03001o
ogoo03Yoo`002Woo00@007ooOol000Uoo`8000=oo`8002ioo`03001oogoo00Eoo`03001oogoo03Yo
o`002goo0P002goo00D007ooOomoo`0002moo`03001oogoo00Ioo`03001oogoo03Uoo`0077oo0P00
;Woo00<007ooOol01Woo00<007ooOol0>Goo000LOol00`00Oomoo`0]Ool00`00Oomoo`06Ool00`00
Oomoo`0iOol000]oo`8000Aoo`04001oogooOol50002Ool2000^Ool00`00Oomoo`06Ool00`00Oomo
o`0iOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0;7oo00<007ooOol01goo
00<007ooOol0>Goo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo00<007ooOol0;7oo
00<007ooOol01goo00<007ooOol0>Goo000:Ool01000Oomoo`002Woo00@007ooOomoo`8000ioo`<0
00Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`@0009oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`80
00Eoo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`0<Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002
Ool200000goo001oo`04Ool00`00Oomoo`020003Ool01000Oomoo`000Woo00<007ooOol00goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04
001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo0P0000=oo`00Ool0
17oo00@007ooOol000Aoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]o
o`8000Uoo`<000=oo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool01000Oomoo`000Woo0P0000=oo`00Ool017oo00@007ooOol000Aoo`04001oogoo0002Ool00`00
Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Ao
o`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00
Oomoo`02Ool01000Oomoo`000Woo0P0000=oo`00Ool017oo00<007ooOol01@000goo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo
10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qo
o`8000Aoo`04001oogoo0002Ool200000goo001oo`03Ool20002Ool20006Ool01000Oomoo`0017oo
00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006
Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20003
Ool30006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo
0P001Woo000LOol2000/Ool00`00Oomoo`0:Ool00`00Oomoo`0gOol001aoo`03001oogoo02Ioo`80
00=oo`03001oogoo00Yoo`04001oogooOol2000dOol001aoofT000aoo`0077oo00<007ooOol04Woo
00<007ooOol04Woo00@007oo000000ioo`<001Aoo`03001oogoo019oo`03001oogoo00Yoo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol000]oo`8000Aoo`04001oogooOol50002Ool2001cOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00Lgoo
000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo
000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;
Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo
0000M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007oo
Ool000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo
00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00D007ooOomoo`0007Aoo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol0
0`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`80
07=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000=oo`D0009oo`04001oogoo0007
Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:
Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<0
07ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`80
00Aoo`04001oogooOol50002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<0
07ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@00
0goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo00<0
07ooOol00Woo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol0
0goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`04
001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo00@007ooOol0009oo`03001oogoo00Moo`03
001oogoo009oo`04001oogoo0002Ool00`00Oomoo`020004Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00H007ooOol007oo0003Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol0
00Eoo`002goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04
001oogoo0002Ool01P00Oomoo`00Ool0009oo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Io
o`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Ao
o`80009oo`05001oogooOol00003Ool50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool5
0003Ool20006Ool001aoo`8002ioo`04001oogoo0007Ool2000hOol001aoo`03001oogoo02aoo`03
001oogoo009oo`03001oogoo00Aoo`03001oo`0003Moo`0077ooJ@0037oo000LOol01@00Oomoogoo
00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo0`000Woo0P000Woo0P000Woo00D007oo001oo`0000=oo`04001oogooOol50002Ool20004
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool00`00Oomoo`0:Ool001aoo`8002Yoo`03001oo`0000Ioo`05001oogooOol0000kOol001aoo`03
001oogoo02Uoo`<000Ioo`05001oogooOol0000kOol001aoo`8003=oo`04001oogoo000lOol001ao
o`03001oogoo03=oo`03001oo`0003aoo`002goo0P0017oo00@007ooOomoo`D0009oo`8003Aoo`03
001oo`0003aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0cOol2000mOol0
00Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomo
ogoo0000M7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`00
77oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001o
ogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool0
1000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001o
o`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo
00@007ooOomoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003
Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol0
00Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00
Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003
Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo
000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1g
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3320\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23177 L
.216 .23177 L
.22 .23177 L
.224 .23177 L
.228 .23177 L
.232 .23177 L
.236 .23177 L
.24 .23177 L
.244 .23177 L
.248 .23177 L
.252 .23178 L
.256 .23178 L
.26 .23177 L
.264 .23177 L
.268 .23177 L
.272 .23177 L
.276 .23177 L
.28 .23177 L
.284 .23178 L
.288 .23178 L
.292 .23178 L
.296 .23178 L
.3 .23177 L
.304 .23177 L
.308 .23176 L
.312 .23176 L
.316 .23176 L
.32 .23177 L
.324 .23179 L
.328 .23181 L
.332 .23182 L
.336 .23182 L
.34 .2318 L
.344 .23176 L
.348 .23171 L
.352 .23167 L
.356 .23166 L
.36 .23169 L
.364 .23176 L
.368 .23189 L
.372 .23204 L
.376 .23218 L
.38 .23229 L
.384 .23231 L
.388 .23223 L
.392 .23206 L
.396 .23182 L
.4 .23161 L
Mistroke
.404 .23151 L
.408 .23166 L
.412 .23216 L
.416 .23311 L
.42 .23455 L
.424 .23648 L
.428 .23883 L
.432 .24144 L
.436 .24414 L
.44 .2467 L
.444 .24891 L
.448 .25056 L
.452 .25152 L
.456 .25169 L
.46 .25109 L
.464 .24979 L
.468 .24791 L
.472 .24565 L
.476 .24321 L
.48 .24078 L
.484 .23853 L
.488 .23657 L
.492 .23496 L
.496 .23368 L
.5 .23266 L
.504 .23178 L
.508 .2309 L
.512 .22988 L
.516 .2286 L
.52 .227 L
.524 .22505 L
.528 .2228 L
.532 .22038 L
.536 .21794 L
.54 .21568 L
.544 .21381 L
.548 .2125 L
.552 .21189 L
.556 .21206 L
.56 .21301 L
.564 .21465 L
.568 .21686 L
.572 .21942 L
.576 .22212 L
.58 .22474 L
.584 .22708 L
.588 .22902 L
.592 .23048 L
.596 .23143 L
.6 .23193 L
Mistroke
.604 .23208 L
.608 .23198 L
.612 .23177 L
.616 .23153 L
.62 .23135 L
.624 .23127 L
.628 .23129 L
.632 .23139 L
.636 .23154 L
.64 .23169 L
.644 .23182 L
.648 .2319 L
.652 .23192 L
.656 .23191 L
.66 .23187 L
.664 .23182 L
.668 .23179 L
.672 .23176 L
.676 .23176 L
.68 .23177 L
.684 .23179 L
.688 .23181 L
.692 .23182 L
.696 .23183 L
.7 .23182 L
.704 .23182 L
.708 .23181 L
.712 .2318 L
.716 .2318 L
.72 .2318 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35317 L
.256 .35317 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35315 L
.276 .35315 L
.28 .35316 L
.284 .35317 L
.288 .35318 L
.292 .35319 L
.296 .35318 L
.3 .35316 L
.304 .35314 L
.308 .35311 L
.312 .3531 L
.316 .35311 L
.32 .35315 L
.324 .35321 L
.328 .35327 L
.332 .35331 L
.336 .3533 L
.34 .35323 L
.344 .35309 L
.348 .35291 L
.352 .35275 L
.356 .35266 L
.36 .35271 L
.364 .35291 L
.368 .35325 L
.372 .35365 L
.376 .35398 L
.38 .35408 L
.384 .35379 L
.388 .35301 L
.392 .35169 L
.396 .34993 L
.4 .34789 L
Mistroke
.404 .34586 L
.408 .34415 L
.412 .34304 L
.416 .34269 L
.42 .3431 L
.424 .34402 L
.428 .34496 L
.432 .34517 L
.436 .34372 L
.44 .33959 L
.444 .33177 L
.448 .31937 L
.452 .30175 L
.456 .2786 L
.46 .25003 L
.464 .21655 L
.468 .17909 L
.472 .13894 L
.476 .09767 L
.48 .057 L
.484 .01873 L
Mfstroke
.484 .01873 m
.4862 0 L
s
.5218 0 m
.524 .01873 L
.528 .057 L
.532 .09767 L
.536 .13894 L
.54 .17909 L
.544 .21655 L
.548 .25002 L
.552 .2786 L
.556 .30174 L
.56 .31937 L
.564 .33177 L
.568 .33959 L
.572 .34372 L
.576 .34517 L
.58 .34496 L
.584 .34402 L
.588 .3431 L
.592 .34269 L
.596 .34304 L
.6 .34415 L
.604 .34586 L
.608 .34789 L
.612 .34993 L
.616 .35169 L
.62 .35301 L
.624 .35379 L
.628 .35408 L
.632 .35398 L
.636 .35365 L
.64 .35325 L
.644 .35291 L
.648 .35271 L
.652 .35266 L
.656 .35275 L
.66 .35291 L
.664 .35309 L
.668 .35323 L
.672 .3533 L
.676 .35331 L
.68 .35327 L
.684 .35321 L
.688 .35315 L
.692 .35311 L
.696 .3531 L
.7 .35311 L
.704 .35314 L
.708 .35316 L
.712 .35318 L
.716 .35319 L
Mistroke
.72 .35318 L
.724 .35317 L
.728 .35316 L
.732 .35315 L
.736 .35315 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35317 L
.756 .35317 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
Mistroke
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23177 L
.256 .23177 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23175 L
.276 .23176 L
.28 .23176 L
.284 .23177 L
.288 .23178 L
.292 .23178 L
.296 .23178 L
.3 .23176 L
.304 .23174 L
.308 .23172 L
.312 .23171 L
.316 .23172 L
.32 .23176 L
.324 .23181 L
.328 .23186 L
.332 .2319 L
.336 .23189 L
.34 .23183 L
.344 .23172 L
.348 .23159 L
.352 .23147 L
.356 .23142 L
.36 .2315 L
.364 .23173 L
.368 .23209 L
.372 .23254 L
.376 .23298 L
.38 .23329 L
.384 .23336 L
.388 .23313 L
.392 .23262 L
.396 .23193 L
.4 .23129 L
Mistroke
.404 .23101 L
.408 .23143 L
.412 .23292 L
.416 .23574 L
.42 .24005 L
.424 .24583 L
.428 .25284 L
.432 .26067 L
.436 .26876 L
.44 .27645 L
.444 .28309 L
.448 .28808 L
.452 .29099 L
.456 .29157 L
.46 .28981 L
.464 .28593 L
.468 .28035 L
.472 .2736 L
.476 .26629 L
.48 .25901 L
.484 .25226 L
.488 .24637 L
.492 .2415 L
.496 .23762 L
.5 .2345 L
.504 .23181 L
.508 .22912 L
.512 .226 L
.516 .22212 L
.52 .21725 L
.524 .21137 L
.528 .20461 L
.532 .19733 L
.536 .19003 L
.54 .18328 L
.544 .17769 L
.548 .17382 L
.552 .17206 L
.556 .17264 L
.56 .17554 L
.564 .18054 L
.568 .18718 L
.572 .19487 L
.576 .20296 L
.58 .21079 L
.584 .2178 L
.588 .22357 L
.592 .22789 L
.596 .23071 L
.6 .23219 L
Mistroke
.604 .23262 L
.608 .23233 L
.612 .23169 L
.616 .23101 L
.62 .23049 L
.624 .23027 L
.628 .23034 L
.632 .23065 L
.636 .23109 L
.64 .23154 L
.644 .2319 L
.648 .23213 L
.652 .2322 L
.656 .23216 L
.66 .23204 L
.664 .2319 L
.668 .23179 L
.672 .23173 L
.676 .23173 L
.68 .23177 L
.684 .23182 L
.688 .23187 L
.692 .23191 L
.696 .23191 L
.7 .2319 L
.704 .23188 L
.708 .23186 L
.712 .23185 L
.716 .23184 L
.72 .23185 L
.724 .23186 L
.728 .23187 L
.732 .23187 L
.736 .23187 L
.74 .23187 L
.744 .23187 L
.748 .23186 L
.752 .23186 L
.756 .23186 L
.76 .23186 L
.764 .23186 L
.768 .23187 L
.772 .23187 L
.776 .23187 L
.78 .23186 L
.784 .23186 L
.788 .23186 L
.792 .23186 L
.796 .23186 L
.8 .23186 L
Mistroke
.804 .23186 L
.808 .23186 L
.812 .23186 L
.816 .23186 L
.82 .23186 L
.824 .23186 L
.828 .23186 L
.832 .23186 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2000fOol4000iOol001aoo`03001oogoo03Aoo`80009oo`8003Qoo`0077ooJ@0037oo000LOol0
1@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00<007ooOol00Woo00<007oo00000P000Woo0`000Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`8002]oo`D004=o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00@0
07ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00
Oomoogoo0000M7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=o
o`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04
001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:
Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03
001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P00
2goo00@007ooOomoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool3
0003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007oo
Ool000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol0
0`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol3
0003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00
Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomo
o`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<007Qoo`002Woo00@007oo
Ool000Moo`05001oogooOol0001gOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P00<7oo00D007ooOomoo`0003ioo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo02mo
o`05001oogooOol0000nOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
;goo00D007ooOomoo`0003ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000`Ool0
1@00Oomoogoo0000?Woo000;Ool20009Ool30003Ool00`00Oomoo`0_Ool01@00Oomoogoo0000?Woo
000LOol2000`Ool00`00Oomoo`02Ool00`00Oomoo`0kOol001aoo`03001oogoo02moo`03001oogoo
009oo`03001oogoo03]oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00<7oo00<007ooOol0
0Woo00<007ooOol0>goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo02mo
o`03001oogoo009oo`03001oogoo03]oo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`0^Ool00`00Oomoo`03Ool00`00Oomoo`0kOol000Yoo`04001oogoo0007Ool4
0003Ool2000_Ool00`00Oomoo`03Ool00`00Oomoo`0kOol000Yoo`04001oogoo0007Ool00`00Oomo
o`04Ool00`00Oomoo`0^Ool00`00Oomoo`03Ool00`00Oomoo`0kOol000Yoo`04001oogoo0008Ool0
0`00Oomoo`03Ool2000_Ool00`00Oomoo`03Ool00`00Oomoo`0kOol000]oo`8000Yoo`8000=oo`03
001oogoo02ioo`03001oogoo00=oo`03001oogoo03]oo`0077oo0P00;goo00<007ooOol017oo00<0
07ooOol0>Woo000LOol00`00Oomoo`0^Ool00`00Oomoo`04Ool00`00Oomoo`0jOol000]oo`8000Ao
o`03001oogoo00=oo`<0009oo`8002moo`03001oogoo00Aoo`03001oogoo03Yoo`002Woo00@007oo
Ool000Yoo`05001oogooOol0000`Ool00`00Oomoo`04Ool00`00Oomoo`0jOol000=oo`D0009oo`04
001oogoo0007Ool50002Ool00`00Oomoo`0^Ool00`00Oomoo`04Ool00`00Oomoo`0jOol000Yoo`04
001oogoo0007Ool01000Oomoo`000goo0P00;goo00<007ooOol017oo00<007ooOol0>Woo000:Ool0
1000Oomoo`0027oo00<007oo00000goo00<007ooOol0;Woo00<007ooOol017oo00<007ooOol0>Woo
000:Ool01000Oomoo`002Goo0P000goo0P00;goo00<007ooOol017oo00<007ooOol0>Woo000;Ool2
000;Ool01@00Oomoogoo0000;goo00<007ooOol01Goo00<007ooOol0>Woo000LOol2000^Ool00`00
Oomoo`05Ool00`00Oomoo`0jOol001aoo`03001oogoo02eoo`03001oogoo00Eoo`03001oogoo03Yo
o`002goo0P0017oo00@007ooOomoo`D0009oo`8002ioo`03001oogoo00Ioo`03001oogoo03Uoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0]Ool00`00Oomoo`06Ool00`00Oomo
o`0iOol000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0]Ool00`00Oomo
o`06Ool00`00Oomoo`0iOol000Yoo`04001oogoo000:Ool01000Oomoogoo0P003Woo0`0017oo0P00
2Goo0`0017oo0P0017oo0P001Goo10000Woo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@00
0Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00ao
o`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`800003
Ool007oo00Aoo`05001oo`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04001oogoo
0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo0P0000=oo`00Ool017oo00<0
07oo00001Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Goo
0`000goo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001o
ogoo0002Ool200000goo001oo`04Ool01000Oomoo`0017oo00@007ooOol0009oo`03001oogoo00Eo
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009o
o`04001oogoo0002Ool200000goo001oo`04Ool00`00Oomoo`050003Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool0
1000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo
00@007ooOol0009oo`800003Ool007oo00=oo`80009oo`8000Ioo`04001oogoo0004Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Io
o`03001oogoo00H000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`00
77oo0P00;7oo00<007ooOol02Woo00<007ooOol0=goo000LOol00`00Oomoo`0WOol5000<Ool5000e
Ool001aoofT000aoo`0077oo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Goo00<007oo
Ool04Woo00<007ooOol04Woo00<007ooOol02Woo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002goo0P0017oo00@007oo
Oomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomo
ogoo0000M7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009o
o`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool5
0002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007oo
Ool0LWoo000;Ool2000;Ool01@00Oomoogoo0000M7oo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D0
07ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007oo
Ool000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003
Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`04001o
ogooOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00@007ooOomoo`D0009oo`8007=o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0=Ool30004Ool20009Ool30004
Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004
Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool2000=Ool01@00Oomoogoo
00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D0
07ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool0
00Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo00@007ooOol0009oo`03001oogoo00Moo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool01000Ool0000017oo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool0
1000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool200000goo0000
00030003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
17oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool2000=Ool0
0`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool30002
Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000
Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool5
0003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`00
17oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000dOol20004Ool00`00Oomoo`0f
Ool001aoo`03001oogoo03=oo`03001oogoo00Aoo`03001oogoo03Eoo`0077ooJ@0037oo000LOol0
1@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00<007oo00001@0000=oo`00Ool00Woo0`0000=oo`00Ool00Woo00@007oo
Oomoo`80009oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`8002Yoo`03001oogoo00Ao
o`03001oogoo03moo`0077oo00<007ooOol0:Goo0P0017oo00<007ooOol0@7oo000LOol2000[Ool0
1@00Oomoogoo0000@goo000LOol00`00Oomoo`0[Ool01000Oomoo`00@goo000;Ool20004Ool01000
Oomoogoo1@000Woo0P00;7oo0`00A7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001o
ogoo02aoo`03001oogoo04=oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo
00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo
0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0
009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007
Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:
Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<0
07ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`80
00Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool0
1000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo
0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool2
0003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00
Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol0
0`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000G
Ool00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2
001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3360\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23177 L
.216 .23177 L
.22 .23177 L
.224 .23177 L
.228 .23177 L
.232 .23177 L
.236 .23177 L
.24 .23177 L
.244 .23177 L
.248 .23177 L
.252 .23177 L
.256 .23177 L
.26 .23177 L
.264 .23178 L
.268 .23178 L
.272 .23177 L
.276 .23177 L
.28 .23177 L
.284 .23177 L
.288 .23177 L
.292 .23177 L
.296 .23178 L
.3 .23178 L
.304 .23178 L
.308 .23178 L
.312 .23177 L
.316 .23177 L
.32 .23176 L
.324 .23176 L
.328 .23176 L
.332 .23178 L
.336 .2318 L
.34 .23182 L
.344 .23184 L
.348 .23184 L
.352 .23182 L
.356 .23179 L
.36 .23176 L
.364 .23175 L
.368 .23177 L
.372 .23185 L
.376 .232 L
.38 .23221 L
.384 .23249 L
.388 .23279 L
.392 .23308 L
.396 .23336 L
.4 .2336 L
Mistroke
.404 .23383 L
.408 .23411 L
.412 .23454 L
.416 .23525 L
.42 .23636 L
.424 .23803 L
.428 .24034 L
.432 .24335 L
.436 .24705 L
.44 .25132 L
.444 .256 L
.448 .26084 L
.452 .26555 L
.456 .26982 L
.46 .27334 L
.464 .27584 L
.468 .27709 L
.472 .27696 L
.476 .27537 L
.48 .27232 L
.484 .26791 L
.488 .26227 L
.492 .25559 L
.496 .24812 L
.5 .24009 L
.504 .23179 L
.508 .22349 L
.512 .21547 L
.516 .20799 L
.52 .20131 L
.524 .19567 L
.528 .19125 L
.532 .1882 L
.536 .1866 L
.54 .18647 L
.544 .18772 L
.548 .19021 L
.552 .19373 L
.556 .19799 L
.56 .20271 L
.564 .20755 L
.568 .21224 L
.572 .21652 L
.576 .22022 L
.58 .22324 L
.584 .22556 L
.588 .22723 L
.592 .22835 L
.596 .22906 L
.6 .22948 L
Mistroke
.604 .22976 L
.608 .22999 L
.612 .23023 L
.616 .2305 L
.62 .23079 L
.624 .23109 L
.628 .23137 L
.632 .23158 L
.636 .23173 L
.64 .23182 L
.644 .23184 L
.648 .23182 L
.652 .23179 L
.656 .23176 L
.66 .23175 L
.664 .23175 L
.668 .23176 L
.672 .23178 L
.676 .2318 L
.68 .23182 L
.684 .23182 L
.688 .23182 L
.692 .23182 L
.696 .23181 L
.7 .2318 L
.704 .2318 L
.708 .2318 L
.712 .2318 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35317 L
.268 .35317 L
.272 .35316 L
.276 .35316 L
.28 .35315 L
.284 .35315 L
.288 .35315 L
.292 .35316 L
.296 .35317 L
.3 .35318 L
.304 .35319 L
.308 .35318 L
.312 .35316 L
.316 .35313 L
.32 .3531 L
.324 .35309 L
.328 .3531 L
.332 .35314 L
.336 .3532 L
.34 .35326 L
.344 .35328 L
.348 .35324 L
.352 .35312 L
.356 .35292 L
.36 .35268 L
.364 .35243 L
.368 .35223 L
.372 .35213 L
.376 .35213 L
.38 .35219 L
.384 .3522 L
.388 .35199 L
.392 .35136 L
.396 .35011 L
.4 .34808 L
Mistroke
.404 .3452 L
.408 .34148 L
.412 .33707 L
.416 .33217 L
.42 .32704 L
.424 .32191 L
.428 .31688 L
.432 .31193 L
.436 .3068 L
.44 .30104 L
.444 .294 L
.448 .28492 L
.452 .27302 L
.456 .25763 L
.46 .23826 L
.464 .21477 L
.468 .18741 L
.472 .15682 L
.476 .12408 L
.48 .09061 L
.484 .05808 L
.488 .02827 L
.492 .00291 L
Mfstroke
.492 .00291 m
.4926 0 L
s
.5154 0 m
.516 .00291 L
.52 .02827 L
.524 .05808 L
.528 .09061 L
.532 .12407 L
.536 .15681 L
.54 .1874 L
.544 .21477 L
.548 .23826 L
.552 .25762 L
.556 .27302 L
.56 .28492 L
.564 .29399 L
.568 .30104 L
.572 .3068 L
.576 .31193 L
.58 .31688 L
.584 .3219 L
.588 .32704 L
.592 .33217 L
.596 .33706 L
.6 .34148 L
.604 .3452 L
.608 .34808 L
.612 .35011 L
.616 .35136 L
.62 .35199 L
.624 .3522 L
.628 .35219 L
.632 .35213 L
.636 .35213 L
.64 .35223 L
.644 .35243 L
.648 .35268 L
.652 .35292 L
.656 .35312 L
.66 .35324 L
.664 .35328 L
.668 .35326 L
.672 .3532 L
.676 .35314 L
.68 .3531 L
.684 .35309 L
.688 .3531 L
.692 .35313 L
.696 .35316 L
.7 .35318 L
.704 .35319 L
.708 .35318 L
Mistroke
.712 .35317 L
.716 .35316 L
.72 .35315 L
.724 .35315 L
.728 .35315 L
.732 .35316 L
.736 .35316 L
.74 .35317 L
.744 .35317 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
Mistroke
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23177 L
.268 .23177 L
.272 .23176 L
.276 .23176 L
.28 .23176 L
.284 .23175 L
.288 .23176 L
.292 .23176 L
.296 .23177 L
.3 .23178 L
.304 .23178 L
.308 .23178 L
.312 .23176 L
.316 .23174 L
.32 .23172 L
.324 .23171 L
.328 .23173 L
.332 .23177 L
.336 .23183 L
.34 .2319 L
.344 .23194 L
.348 .23195 L
.352 .23191 L
.356 .23182 L
.36 .23173 L
.364 .23169 L
.368 .23175 L
.372 .23198 L
.376 .23242 L
.38 .23307 L
.384 .23388 L
.388 .23477 L
.392 .23567 L
.396 .23649 L
.4 .23722 L
Mistroke
.404 .23792 L
.408 .23878 L
.412 .24008 L
.416 .24219 L
.42 .24554 L
.424 .25052 L
.428 .25745 L
.432 .26647 L
.436 .27753 L
.44 .29034 L
.444 .30437 L
.448 .3189 L
.452 .33306 L
.456 .3459 L
.46 .35651 L
.464 .36405 L
.468 .36787 L
.472 .36752 L
.476 .36277 L
.48 .35365 L
.484 .34041 L
.488 .32346 L
.492 .30341 L
.496 .28092 L
.5 .25679 L
.504 .23181 L
.508 .20684 L
.512 .1827 L
.516 .16022 L
.52 .14016 L
.524 .12322 L
.528 .10997 L
.532 .10085 L
.536 .09611 L
.54 .09575 L
.544 .09957 L
.548 .10712 L
.552 .11772 L
.556 .13057 L
.56 .14472 L
.564 .15925 L
.568 .17329 L
.572 .1861 L
.576 .19716 L
.58 .20618 L
.584 .21311 L
.588 .21809 L
.592 .22144 L
.596 .22355 L
.6 .22485 L
Mistroke
.604 .22571 L
.608 .22641 L
.612 .22714 L
.616 .22796 L
.62 .22885 L
.624 .22975 L
.628 .23056 L
.632 .23121 L
.636 .23165 L
.64 .23188 L
.644 .23194 L
.648 .2319 L
.652 .2318 L
.656 .23172 L
.66 .23168 L
.664 .23168 L
.668 .23173 L
.672 .23179 L
.676 .23185 L
.68 .2319 L
.684 .23191 L
.688 .23191 L
.692 .23189 L
.696 .23186 L
.7 .23185 L
.704 .23184 L
.708 .23185 L
.712 .23186 L
.716 .23187 L
.72 .23187 L
.724 .23187 L
.728 .23187 L
.732 .23187 L
.736 .23186 L
.74 .23186 L
.744 .23186 L
.748 .23186 L
.752 .23186 L
.756 .23187 L
.76 .23187 L
.764 .23187 L
.768 .23186 L
.772 .23186 L
.776 .23186 L
.78 .23186 L
.784 .23186 L
.788 .23186 L
.792 .23186 L
.796 .23186 L
.8 .23186 L
Mistroke
.804 .23186 L
.808 .23186 L
.812 .23186 L
.816 .23186 L
.82 .23186 L
.824 .23186 L
.828 .23186 L
.832 .23186 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool400000goo001oo`05Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`00
1Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20005Ool20002
Ool60003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`8003Ao
o`03001oogoo009oo`03001oogoo03Moo`0077oo00<007ooOol0<Woo00<007ooOol00goo0P00>7oo
000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool50003Ool01@00Ool007oo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`8002]o
o`8000Aoo`03001oogoo03moo`0077oo00<007ooOol0:goo0P000goo00<007ooOol0?goo000LOol2
000]Ool01000Oomoo`00@Woo000LOol00`00Oomoo`0]Ool20013Ool000]oo`8000Aoo`04001oogoo
Ool50002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0LWoo000:
Ool01000Oomoo`002Goo00<007ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomo
o`0007Aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001ao
o`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomo
o`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@0
07ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool0
0003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`04
001oogooOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo
0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008
Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007oo
Ool0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo
0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`00
5goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3001hOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
035oo`03001oo`0003moo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo031oo`04001oogoo
000nOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0<7oo00@007ooOol0
03ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000aOol01000Oomoo`00?Woo000;
Ool20009Ool30003Ool00`00Oomoo`0`Ool01000Oomoo`00?Woo000LOol2000`Ool01@00Oomoogoo
0000?Woo000LOol00`00Oomoo`0_Ool01@00Oomoogoo0000?Woo000;Ool20004Ool00`00Oomoo`02
Ool30003Ool2000`Ool01@00Oomoogoo0000?Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo02moo`05001oogooOol0000nOol000=oo`D0009oo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0;goo00<007ooOol00Woo00<007ooOol0>goo000:Ool01000Oomo
o`001goo10000goo0P00<7oo00<007ooOol00Woo00<007ooOol0>goo000:Ool01000Oomoo`001goo
00<007ooOol017oo00<007ooOol0;goo00<007ooOol00Woo00<007ooOol0>goo000:Ool01000Oomo
o`0027oo00<007ooOol00goo0P00;goo00<007ooOol00goo00<007ooOol0>goo000;Ool2000:Ool2
0003Ool00`00Oomoo`0^Ool00`00Oomoo`03Ool00`00Oomoo`0kOol001aoo`8002moo`03001oogoo
00=oo`03001oogoo03]oo`0077oo00<007ooOol0;Woo00<007ooOol00goo00<007ooOol0>goo000;
Ool20004Ool00`00Oomoo`03Ool30002Ool2000_Ool00`00Oomoo`04Ool00`00Oomoo`0jOol000Yo
o`04001oogoo000:Ool01@00Oomoogoo0000<7oo00<007ooOol017oo00<007ooOol0>Woo0003Ool5
0002Ool01000Oomoo`001goo1@000Woo00<007ooOol0;Woo00<007ooOol017oo00<007ooOol0>Woo
000:Ool01000Oomoo`001goo00@007ooOol000=oo`8002moo`03001oogoo00Aoo`03001oogoo03Yo
o`002Woo00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo02ioo`03001oogoo00Aoo`03001o
ogoo03Yoo`002Woo00@007ooOol000Uoo`8000=oo`8002moo`03001oogoo00Aoo`03001oogoo03Yo
o`002goo0P002goo00D007ooOomoo`0002moo`03001oogoo00Eoo`03001oogoo03Yoo`0077oo0P00
;Woo00<007ooOol01Goo00<007ooOol0>Woo000LOol00`00Oomoo`0]Ool00`00Oomoo`05Ool00`00
Oomoo`0jOol000]oo`8000Aoo`04001oogooOol50002Ool2000^Ool00`00Oomoo`06Ool00`00Oomo
o`0iOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0;Goo00<007ooOol01Woo
00<007ooOol0>Goo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo00<007ooOol0;7oo
00<007ooOol01goo00<007ooOol0>Goo000:Ool01000Oomoo`002Woo00@007ooOomoo`8000ioo`<0
00Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`@0009oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`80
00Eoo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`0<Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002
Ool200000goo001oo`04Ool00`00Oomoo`020003Ool01000Oomoo`000Woo00<007ooOol00goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04
001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo0P0000=oo`00Ool0
17oo00@007ooOol000Aoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]o
o`8000Uoo`<000=oo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<0
07ooOol00Woo00D007ooOol007oo0080009oo`03001oogoo00=oo`04001oogooOol40003Ool01000
Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomo
o`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomo
o`0027oo0P0017oo00<007ooOol010000Woo00<007ooOol00Woo0P000goo0P001Goo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo
00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo
0P0000Aoo`00Oomoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool3
0002Ool50003Ool20006Ool001aoo`8002Uoo`03001oogoo00moo`8003Ioo`0077oo00<007ooOol0
9goo00<007ooOol04Goo0P00=Goo000LOomY000<Ool001aoo`03001oogoo019oo`03001oogoo019o
o`03001oogoo015oo`03001oogoo019oo`03001oogoo019oo`03001oogoo00Yoo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1b
Ool000]oo`8000Aoo`04001oogooOol50002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00Lgoo000:Ool0
1000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool2
0009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004
Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo
000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=o
o`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007oo
Ool000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00D007ooOomoo`0007Aoo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`00
2Woo00@007ooOol000Yoo`05001oogooOol0001dOol000=oo`D0009oo`04001oogoo0007Ool50002
Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000
Oomoo`0027oo00<007oo00000goo0P00=Woo00<007ooOol0>Woo000:Ool01000Oomoo`002Goo0P00
0goo00<007ooOol0=7oo0P00?7oo000;Ool2000;Ool01000Oomoogoo0P00=Goo00<007oo0000>goo
000LOol00`00Oomoo`0cOol01000Oomoo`00>goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00
=7oo00D007ooOomoo`0003Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0=
Ool30004Ool20009Ool30004Ool20004Ool20005Ool300000goo001oo`030004Ool20005Ool50003
Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool00`00
Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`0017oo0P000Woo0P000goo00@007ooOol0009oo`03001oogoo00=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Yoo`05001oogooOol0000BOol01000Oomo
o`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0004Ool20003
Ool01@00Oomoogoo00000Woo00@007ooOol000Ioo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0004Ool20003Ool01@00Oomoogoo00000Woo00@007ooOol0
00Moo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@0
07ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`0<Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0003Ool00`00Ool00003Ool40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool20009
Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04
001oogoo0003Ool30003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000L
Ool00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20004Ool00`00Ool00003
Ool50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`8003=o
o`03001oogoo00Aoo`03001oogoo03Ioo`0077oo00<007ooOol0<Woo00<007ooOol01Goo00<007oo
Ool0=Goo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Ool000040002Ool02@00Oomo
ogoo001oo`00Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yo
o`0077oo0P00:Goo0P001goo00<007ooOol0?Woo000LOol00`00Oomoo`0YOol00`00Oomoo`05Ool0
0`00Oomoo`0nOol001aoo`8002]oo`03001oogoo00Aoo`03001oogoo03ioo`0077oo00<007ooOol0
:Woo00<007ooOol00goo00<007ooOol0?goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00:goo
00<007ooOol00goo00<007ooOol0?goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001o
ogoo02]oo`03001oogoo009oo`03001oogoo03moo`002Woo00@007ooOol000Uoo`03001oogoo009o
o`8002aoo`03001oogoo009oo`03001oogoo03moo`002Woo00@007ooOol000Yoo`05001oogooOol0
000^Ool01@00Oomoogoo0000@Goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8002eo
o`05001oogooOol00011Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
;7oo00D007ooOomoo`00045oo`002goo0P002Goo0`000goo0P00;Goo00@007ooOol0049oo`0077oo
00<007ooOol0;Goo00<007oo0000@Woo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000^Ool2
0013Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000<7oo00<007ooOol0@Goo000:Ool01000
Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo
079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`80
00=oo`03001oogoo079oo`002goo0P002goo00@007ooOomoo`8007=oo`0077oo00<007ooOol0LWoo
000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=o
o`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo
0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<0
00=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=o
o`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo
079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Mo
o`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3400\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23177 L
.216 .23177 L
.22 .23177 L
.224 .23177 L
.228 .23177 L
.232 .23177 L
.236 .23177 L
.24 .23177 L
.244 .23177 L
.248 .23177 L
.252 .23177 L
.256 .23177 L
.26 .23177 L
.264 .23177 L
.268 .23177 L
.272 .23178 L
.276 .23178 L
.28 .23178 L
.284 .23177 L
.288 .23177 L
.292 .23177 L
.296 .23177 L
.3 .23177 L
.304 .23178 L
.308 .23178 L
.312 .23178 L
.316 .23178 L
.32 .23178 L
.324 .23178 L
.328 .23177 L
.332 .23177 L
.336 .23178 L
.34 .23179 L
.344 .23182 L
.348 .23186 L
.352 .23191 L
.356 .23196 L
.36 .232 L
.364 .23205 L
.368 .2321 L
.372 .23218 L
.376 .23232 L
.38 .23255 L
.384 .2329 L
.388 .23339 L
.392 .23403 L
.396 .23484 L
.4 .2358 L
Mistroke
.404 .23689 L
.408 .23811 L
.412 .23948 L
.416 .24102 L
.42 .24282 L
.424 .24496 L
.428 .24755 L
.432 .25072 L
.436 .25453 L
.44 .25902 L
.444 .26415 L
.448 .26977 L
.452 .27566 L
.456 .28149 L
.46 .28685 L
.464 .29132 L
.468 .29444 L
.472 .29581 L
.476 .2951 L
.48 .29209 L
.484 .2867 L
.488 .279 L
.492 .26924 L
.496 .25777 L
.5 .2451 L
.504 .2318 L
.508 .21851 L
.512 .20583 L
.516 .19436 L
.52 .18458 L
.524 .17687 L
.528 .17147 L
.532 .16844 L
.536 .16772 L
.54 .16908 L
.544 .1722 L
.548 .17667 L
.552 .18204 L
.556 .18787 L
.56 .19377 L
.564 .19941 L
.568 .20454 L
.572 .20905 L
.576 .21287 L
.58 .21604 L
.584 .21863 L
.588 .22077 L
.592 .22257 L
.596 .22411 L
.6 .22547 L
Mistroke
.604 .22669 L
.608 .22778 L
.612 .22874 L
.616 .22955 L
.62 .2302 L
.624 .23069 L
.628 .23104 L
.632 .23126 L
.636 .2314 L
.64 .23148 L
.644 .23154 L
.648 .23158 L
.652 .23163 L
.656 .23167 L
.66 .23172 L
.664 .23176 L
.668 .23179 L
.672 .23181 L
.676 .23181 L
.68 .23181 L
.684 .2318 L
.688 .2318 L
.692 .2318 L
.696 .2318 L
.7 .2318 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35317 L
.276 .35317 L
.28 .35317 L
.284 .35316 L
.288 .35316 L
.292 .35315 L
.296 .35315 L
.3 .35315 L
.304 .35316 L
.308 .35317 L
.312 .35318 L
.316 .35318 L
.32 .35316 L
.324 .35313 L
.328 .35309 L
.332 .35305 L
.336 .35302 L
.34 .35301 L
.344 .35301 L
.348 .35301 L
.352 .35298 L
.356 .35288 L
.36 .35266 L
.364 .3523 L
.368 .35178 L
.372 .35111 L
.376 .35031 L
.38 .34941 L
.384 .3484 L
.388 .34724 L
.392 .34582 L
.396 .34395 L
.4 .3414 L
Mistroke
.404 .33789 L
.408 .33315 L
.412 .32699 L
.416 .31928 L
.42 .31004 L
.424 .29944 L
.428 .28777 L
.432 .2754 L
.436 .26272 L
.44 .25011 L
.444 .23784 L
.448 .22604 L
.452 .2147 L
.456 .20369 L
.46 .19276 L
.464 .18167 L
.468 .17021 L
.472 .15828 L
.476 .14598 L
.48 .13356 L
.484 .12147 L
.488 .1103 L
.492 .10069 L
.496 .09329 L
.5 .08861 L
.504 .08701 L
.508 .08861 L
.512 .09329 L
.516 .10069 L
.52 .1103 L
.524 .12147 L
.528 .13355 L
.532 .14597 L
.536 .15828 L
.54 .1702 L
.544 .18167 L
.548 .19276 L
.552 .20368 L
.556 .2147 L
.56 .22604 L
.564 .23784 L
.568 .25011 L
.572 .26272 L
.576 .2754 L
.58 .28777 L
.584 .29944 L
.588 .31004 L
.592 .31927 L
.596 .32699 L
.6 .33315 L
Mistroke
.604 .33789 L
.608 .3414 L
.612 .34395 L
.616 .34582 L
.62 .34724 L
.624 .3484 L
.628 .34941 L
.632 .35031 L
.636 .35111 L
.64 .35178 L
.644 .3523 L
.648 .35266 L
.652 .35288 L
.656 .35298 L
.66 .35301 L
.664 .35301 L
.668 .35301 L
.672 .35302 L
.676 .35305 L
.68 .35309 L
.684 .35313 L
.688 .35316 L
.692 .35318 L
.696 .35318 L
.7 .35317 L
.704 .35316 L
.708 .35315 L
.712 .35315 L
.716 .35315 L
.72 .35316 L
.724 .35316 L
.728 .35317 L
.732 .35317 L
.736 .35317 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23177 L
.276 .23177 L
.28 .23177 L
.284 .23176 L
.288 .23176 L
.292 .23176 L
.296 .23175 L
.3 .23176 L
.304 .23177 L
.308 .23178 L
.312 .23179 L
.316 .23179 L
.32 .23179 L
.324 .23178 L
.328 .23176 L
.332 .23175 L
.336 .23177 L
.34 .23182 L
.344 .2319 L
.348 .23202 L
.352 .23216 L
.356 .2323 L
.36 .23244 L
.364 .23258 L
.368 .23274 L
.372 .23299 L
.376 .23341 L
.38 .23408 L
.384 .23511 L
.388 .23658 L
.392 .23852 L
.396 .24093 L
.4 .2438 L
Mistroke
.404 .24708 L
.408 .25076 L
.412 .25486 L
.416 .25951 L
.42 .26491 L
.424 .27134 L
.428 .27914 L
.432 .28864 L
.436 .30008 L
.44 .31355 L
.444 .32893 L
.448 .3458 L
.452 .36346 L
.456 .38095 L
.46 .39706 L
.464 .41047 L
.468 .41985 L
.472 .42398 L
.476 .42185 L
.48 .41282 L
.484 .39664 L
.488 .37354 L
.492 .34422 L
.496 .30979 L
.5 .27174 L
.504 .23181 L
.508 .19189 L
.512 .15384 L
.516 .11941 L
.52 .09008 L
.524 .06698 L
.528 .0508 L
.532 .04177 L
.536 .03964 L
.54 .04377 L
.544 .05315 L
.548 .06657 L
.552 .08268 L
.556 .10016 L
.56 .11782 L
.564 .13469 L
.568 .15007 L
.572 .16355 L
.576 .17499 L
.58 .18448 L
.584 .19228 L
.588 .19871 L
.592 .20411 L
.596 .20876 L
.6 .21287 L
Mistroke
.604 .21655 L
.608 .21983 L
.612 .22269 L
.616 .22511 L
.62 .22705 L
.624 .22851 L
.628 .22955 L
.632 .23022 L
.636 .23064 L
.64 .23088 L
.644 .23105 L
.648 .23119 L
.652 .23132 L
.656 .23147 L
.66 .23161 L
.664 .23173 L
.668 .23181 L
.672 .23186 L
.676 .23187 L
.68 .23187 L
.684 .23185 L
.688 .23184 L
.692 .23183 L
.696 .23184 L
.7 .23185 L
.704 .23186 L
.708 .23187 L
.712 .23187 L
.716 .23187 L
.72 .23187 L
.724 .23186 L
.728 .23186 L
.732 .23186 L
.736 .23186 L
.74 .23186 L
.744 .23187 L
.748 .23187 L
.752 .23187 L
.756 .23187 L
.76 .23186 L
.764 .23186 L
.768 .23186 L
.772 .23186 L
.776 .23186 L
.78 .23186 L
.784 .23186 L
.788 .23186 L
.792 .23186 L
.796 .23186 L
.8 .23186 L
Mistroke
.804 .23186 L
.808 .23186 L
.812 .23186 L
.816 .23186 L
.82 .23186 L
.824 .23186 L
.828 .23186 L
.832 .23186 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool20006Ool01000Oomoo`000Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`800003Ool007oo00@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]o
o`8000Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`80009oo`8000Ioo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001ao
o`03001oogoo00aoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Eoo`8000=oo`D000=o
o`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00<goo00<007oo
Ool00goo0P00>7oo000LOol00`00Oomoo`0bOol00`00Oomoo`04Ool3000fOol001aoofT000aoo`00
77oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`04001oogooOol400000goo001oo`02Ool01@00Ool007oo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`8002Yoo`8000Io
o`03001oogoo03ioo`0077oo00<007ooOol0:Woo0P0017oo00<007ooOol0?goo000LOol2000/Ool2
0003Ool00`00Oomoo`0oOol001aoo`03001oogoo02aoo`05001oogooOol00011Ool000]oo`8000Ao
o`04001oogooOol50002Ool2000^Ool00`00Ool00012Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00<007ooOol0;Woo00<007ooOol0@Goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<0
07ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo
00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009
Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo
079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2
001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
0`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol0
00]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02
Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<0
00=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2
001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00
Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomo
o`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool0
0`00Oomoo`02Ool3001hOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000Mgoo0003Ool50002
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000;Ool20009Ool30003Ool00`00
Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool3
0003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003
Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo035oo`03001oogoo03io
o`002Woo00@007ooOol000Moo`@000=oo`80035oo`<003moo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`03001oogoo031oo`04001oogoo000nOol000Yoo`04001oogoo0008Ool00`00Oomoo`03
Ool2000aOol01000Oomoo`00?Woo000;Ool2000:Ool20003Ool00`00Oomoo`0_Ool01@00Oomoogoo
0000?Woo000LOol2000`Ool00`00Oomoo`02Ool00`00Oomoo`0kOol001aoo`03001oogoo02ioo`03
001oogoo00=oo`03001oogoo03]oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00;goo00<0
07ooOol00goo00<007ooOol0>goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00031oo`03001o
ogoo00Aoo`03001oogoo03Yoo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo02io
o`03001oogoo00Aoo`03001oogoo03Yoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool2000^
Ool00`00Oomoo`05Ool00`00Oomoo`0jOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool00`00
Oomoo`0]Ool00`00Oomoo`06Ool00`00Oomoo`0iOol000Yoo`04001oogoo0009Ool20003Ool2000]
Ool00`00Oomoo`07Ool00`00Oomoo`0iOol000]oo`8000]oo`05001oogooOol0000^Ool00`00Oomo
o`07Ool00`00Oomoo`0iOol001aoo`8002eoo`03001oogoo00Qoo`03001oogoo03Qoo`0077oo00<0
07ooOol0;7oo00<007ooOol027oo00<007ooOol0>7oo000;Ool20004Ool01000Oomoogoo1@000Woo
0P00;7oo00<007ooOol02Woo00<007ooOol0=goo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`03001oogoo02]oo`03001oogoo00Yoo`03001oogoo03Moo`000goo1@000Woo00@007ooOol000Uo
o`03001oogoo009oo`03001oogoo02]oo`03001oogoo00Yoo`03001oogoo03Moo`002Woo00@007oo
Ool000Yoo`04001oogooOol2000>Ool30004Ool20009Ool30004Ool20002Ool01000Ool000001Goo
0`000Woo100017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`05001oogooOol00002Ool01000
Oomoo`002Goo00<007ooOol00Woo00D007ooOol007oo0080009oo`03001oogoo00=oo`04001oogoo
Ool20002Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04001oogoo0002Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool00`00Oomoo`0200001Goo001oogoo00001Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0006Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Uoo`<000=oo`03001oogoo011o
o`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0200001Goo001oogoo
00001Goo00<007ooOol00goo00<007oo00000Woo00@007ooOol000Moo`05001oogooOol00002Ool0
1000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=o
o`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo00800005Ool0
07ooOol00005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo
00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000
Oomoo`0017oo0P000goo00<007oo000017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo
00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0`000goo0P001Woo00@007ooOomoo`D0
00=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00:7oo00<0
07ooOol04Goo0P00=Goo000LOol00`00Oomoo`0UOol3000DOol3000cOol001aoofT000aoo`0077oo
00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Woo
00<007ooOol02Woo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`002goo0P0017oo00@007ooOomoo`D0009oo`8007=oo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0009Ool0
0`00Oomoo`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000L
Ool00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007oo
Ool000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04
001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo
00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool0
1@00Oomoogoo0000M7oo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo03Aoo`8003aoo`002goo0P00
17oo00<007ooOol00goo0`000Woo0P00=Goo0P00?7oo000:Ool01000Oomoo`002Woo00D007ooOomo
o`0003Eoo`04001oogoo000kOol000=oo`D0009oo`04001oogoo0007Ool50002Ool2000dOol01000
Oomoo`00>goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo03=oo`04001oogoo
000kOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2000dOol01000Oomoo`00>goo000:Ool0
1000Oomoo`002Goo0P000goo00<007ooOol0<goo00D007ooOomoo`0003Yoo`002goo0P002goo00@0
07ooOomoo`8003Aoo`05001oogooOol0000jOol001aoo`03001oogoo03=oo`05001oogooOol0000j
Ool000]oo`8000Aoo`04001oogooOol50002Ool2000dOol00`00Oomoo`02Ool00`00Oomoo`0gOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo
0P0017oo0P0017oo10000Woo100017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo
0P001Woo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo0P003Goo00D007ooOomoo`00
009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
o`0000=oo`05001oogooOol00002Ool01000Oomoo`001Goo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000=oo`05001oogooOol00002
Ool01000Oomoo`001Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`80015oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000=oo`03001oo`0000=oo`05001oogooOol00002Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo
00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`@0
00=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
o`0000=oo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uoo`<000=oo`80
00eoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000=o
o`<000=oo`<000Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D0
00=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Aoo`03001oo`0000=oo`D000=oo`8000Ioo`<0
00Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00<goo00<007ooOol01Goo0P00
=Woo000LOol00`00Oomoo`0aOol00`00Oomoo`07Ool2000eOol001aoofT000aoo`0077oo00D007oo
Oomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`H000=oo`09001oogooOol007oo001oo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00<007ooOol00Woo00<007ooOol02Woo000LOol2000XOol00`00Oomoo`07Ool00`00Oomoo`0nOol0
01aoo`03001oogoo02Qoo`03001oogoo00Ioo`03001oogoo03ioo`0077oo0P00:Woo00<007ooOol0
1Goo00<007ooOol0?Woo000LOol00`00Oomoo`0YOol00`00Oomoo`05Ool00`00Oomoo`0nOol000]o
o`8000Aoo`04001oogooOol50002Ool2000[Ool00`00Oomoo`04Ool00`00Oomoo`0nOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0:Woo00<007ooOol017oo00<007ooOol0?Woo
000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00:goo00<007ooOol00goo00<007ooOol0?goo
000:Ool01000Oomoo`002Woo00D007ooOomoo`0002eoo`03001oogoo009oo`03001oogoo03moo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2000/Ool00`00Oomoo`02Ool00`00Oomoo`0o
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0:goo00<007ooOol00Woo
00<007ooOol0?goo000;Ool20009Ool30003Ool2000]Ool01@00Oomoogoo0000@Goo000LOol00`00
Oomoo`0/Ool01@00Oomoogoo0000@Goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000]Ool0
1@00Oomoogoo0000@Goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0002ioo`05001oogooOol0
0011Ool000Yoo`04001oogoo0007Ool50002Ool2000]Ool01@00Oomoogoo0000@Goo000:Ool01000
Oomoo`001goo00@007ooOol000=oo`03001oogoo02aoo`04001oogoo0012Ool000Yoo`04001oogoo
0008Ool00`00Ool00003Ool2000^Ool00`00Ool00012Ool000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`0]Ool00`00Ool00012Ool000]oo`8000]oo`04001oogooOol2000_Ool00`00Oomoo`11
Ool001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03
Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool2
0004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo
00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;
Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol0
0`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0
Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3440\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23177 L
.216 .23177 L
.22 .23177 L
.224 .23177 L
.228 .23177 L
.232 .23177 L
.236 .23177 L
.24 .23177 L
.244 .23177 L
.248 .23177 L
.252 .23177 L
.256 .23177 L
.26 .23177 L
.264 .23177 L
.268 .23177 L
.272 .23177 L
.276 .23177 L
.28 .23177 L
.284 .23178 L
.288 .23178 L
.292 .23178 L
.296 .23178 L
.3 .23177 L
.304 .23177 L
.308 .23178 L
.312 .23178 L
.316 .23179 L
.32 .23179 L
.324 .2318 L
.328 .23181 L
.332 .23182 L
.336 .23184 L
.34 .23186 L
.344 .23189 L
.348 .23194 L
.352 .23202 L
.356 .23214 L
.36 .2323 L
.364 .2325 L
.368 .23275 L
.372 .23305 L
.376 .23343 L
.38 .23391 L
.384 .23452 L
.388 .23531 L
.392 .23634 L
.396 .23765 L
.4 .23929 L
Mistroke
.404 .24127 L
.408 .24361 L
.412 .24627 L
.416 .24924 L
.42 .25248 L
.424 .25594 L
.428 .25961 L
.432 .26346 L
.436 .26748 L
.44 .27166 L
.444 .27596 L
.448 .28032 L
.452 .28463 L
.456 .28869 L
.46 .29226 L
.464 .29505 L
.468 .29671 L
.472 .29691 L
.476 .29534 L
.48 .29178 L
.484 .2861 L
.488 .27833 L
.492 .26863 L
.496 .25732 L
.5 .24486 L
.504 .2318 L
.508 .21874 L
.512 .20627 L
.516 .19495 L
.52 .18524 L
.524 .17745 L
.528 .17176 L
.532 .16818 L
.536 .16661 L
.54 .16681 L
.544 .16847 L
.548 .17126 L
.552 .17484 L
.556 .17892 L
.56 .18323 L
.564 .1876 L
.568 .19191 L
.572 .19609 L
.576 .20012 L
.58 .20397 L
.584 .20763 L
.588 .2111 L
.592 .21433 L
.596 .2173 L
.6 .21997 L
Mistroke
.604 .2223 L
.608 .22429 L
.612 .22593 L
.616 .22725 L
.62 .22828 L
.624 .22907 L
.628 .22968 L
.632 .23015 L
.636 .23053 L
.64 .23083 L
.644 .23108 L
.648 .23128 L
.652 .23144 L
.656 .23156 L
.66 .23164 L
.664 .2317 L
.668 .23173 L
.672 .23175 L
.676 .23176 L
.68 .23177 L
.684 .23178 L
.688 .23179 L
.692 .2318 L
.696 .2318 L
.7 .23181 L
.704 .23181 L
.708 .23181 L
.712 .23181 L
.716 .23181 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35317 L
.292 .35316 L
.296 .35316 L
.3 .35315 L
.304 .35314 L
.308 .35314 L
.312 .35313 L
.316 .35313 L
.32 .35313 L
.324 .35311 L
.328 .35308 L
.332 .35302 L
.336 .35292 L
.34 .35279 L
.344 .35262 L
.348 .35243 L
.352 .35219 L
.356 .35189 L
.36 .35148 L
.364 .35089 L
.368 .35007 L
.372 .34891 L
.376 .34733 L
.38 .34529 L
.384 .34272 L
.388 .33958 L
.392 .33583 L
.396 .33141 L
.4 .32621 L
Mistroke
.404 .32007 L
.408 .31277 L
.412 .3041 L
.416 .29383 L
.42 .2818 L
.424 .268 L
.428 .25256 L
.432 .23586 L
.436 .21847 L
.44 .20114 L
.444 .18477 L
.448 .17029 L
.452 .15859 L
.456 .1504 L
.46 .14621 L
.464 .14621 L
.468 .15025 L
.472 .15787 L
.476 .1683 L
.48 .18058 L
.484 .19361 L
.488 .20622 L
.492 .21734 L
.496 .22602 L
.5 .23154 L
.504 .23343 L
.508 .23154 L
.512 .22602 L
.516 .21734 L
.52 .20622 L
.524 .1936 L
.528 .18058 L
.532 .1683 L
.536 .15786 L
.54 .15025 L
.544 .14621 L
.548 .14621 L
.552 .1504 L
.556 .15859 L
.56 .17029 L
.564 .18476 L
.568 .20114 L
.572 .21847 L
.576 .23586 L
.58 .25256 L
.584 .26799 L
.588 .2818 L
.592 .29382 L
.596 .3041 L
.6 .31277 L
Mistroke
.604 .32007 L
.608 .32621 L
.612 .33141 L
.616 .33583 L
.62 .33958 L
.624 .34272 L
.628 .34529 L
.632 .34733 L
.636 .3489 L
.64 .35007 L
.644 .35089 L
.648 .35148 L
.652 .35189 L
.656 .35219 L
.66 .35243 L
.664 .35262 L
.668 .35279 L
.672 .35292 L
.676 .35302 L
.68 .35308 L
.684 .35311 L
.688 .35313 L
.692 .35313 L
.696 .35313 L
.7 .35314 L
.704 .35314 L
.708 .35315 L
.712 .35316 L
.716 .35316 L
.72 .35317 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23176 L
.276 .23176 L
.28 .23176 L
.284 .23177 L
.288 .23177 L
.292 .23177 L
.296 .23177 L
.3 .23176 L
.304 .23176 L
.308 .23177 L
.312 .23178 L
.316 .23179 L
.32 .23182 L
.324 .23185 L
.328 .23188 L
.332 .23191 L
.336 .23195 L
.34 .23201 L
.344 .2321 L
.348 .23226 L
.352 .23251 L
.356 .23286 L
.36 .23333 L
.364 .23393 L
.368 .23468 L
.372 .23559 L
.376 .23672 L
.38 .23815 L
.384 .23998 L
.388 .24236 L
.392 .24544 L
.396 .24938 L
.4 .25429 L
Mistroke
.404 .26024 L
.408 .26724 L
.412 .27525 L
.416 .28417 L
.42 .29389 L
.424 .30431 L
.428 .31534 L
.432 .32691 L
.436 .339 L
.44 .35155 L
.444 .36448 L
.448 .37756 L
.452 .39046 L
.456 .40262 L
.46 .41331 L
.464 .42163 L
.468 .42658 L
.472 .42715 L
.476 .42242 L
.48 .41171 L
.484 .39465 L
.488 .37132 L
.492 .34222 L
.496 .30832 L
.5 .27097 L
.504 .23181 L
.508 .19266 L
.512 .15531 L
.516 .12141 L
.52 .09231 L
.524 .06897 L
.528 .05192 L
.532 .04121 L
.536 .03648 L
.54 .03704 L
.544 .04199 L
.548 .05031 L
.552 .061 L
.556 .07317 L
.56 .08606 L
.564 .09915 L
.568 .11207 L
.572 .12462 L
.576 .13671 L
.58 .14829 L
.584 .15931 L
.588 .16973 L
.592 .17946 L
.596 .18838 L
.6 .19639 L
Mistroke
.604 .20339 L
.608 .20934 L
.612 .21425 L
.616 .21818 L
.62 .22127 L
.624 .22365 L
.628 .22548 L
.632 .22691 L
.636 .22803 L
.64 .22895 L
.644 .22969 L
.648 .2303 L
.652 .23077 L
.656 .23112 L
.66 .23137 L
.664 .23152 L
.668 .23162 L
.672 .23168 L
.676 .23172 L
.68 .23175 L
.684 .23178 L
.688 .23181 L
.692 .23183 L
.696 .23185 L
.7 .23186 L
.704 .23186 L
.708 .23186 L
.712 .23186 L
.716 .23186 L
.72 .23186 L
.724 .23186 L
.728 .23186 L
.732 .23187 L
.736 .23187 L
.74 .23187 L
.744 .23187 L
.748 .23186 L
.752 .23186 L
.756 .23186 L
.76 .23186 L
.764 .23186 L
.768 .23186 L
.772 .23187 L
.776 .23186 L
.78 .23186 L
.784 .23186 L
.788 .23186 L
.792 .23186 L
.796 .23186 L
.8 .23186 L
Mistroke
.804 .23186 L
.808 .23186 L
.812 .23186 L
.816 .23186 L
.82 .23186 L
.824 .23186 L
.828 .23186 L
.832 .23186 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool30005Ool01000Oomoo`000Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`80009oo`D000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uo
o`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001ao
o`03001oogoo00aoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Eoo`8000=oo`D000=o
o`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00<goo00<007oo
Ool01Goo00<007ooOol0=Goo000LOol00`00Oomoo`0bOol00`00Oomoo`06Ool2000eOol001aoofT0
00aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`03001oogoo00<000=oo`09001oogooOol007oo001oo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol2000YOol2
0007Ool00`00Oomoo`0nOol001aoo`03001oogoo02Uoo`03001oogoo00Aoo`03001oogoo03moo`00
77oo0P00:goo0P0017oo00<007ooOol0?goo000LOol00`00Oomoo`0[Ool20003Ool00`00Oomoo`0o
Ool000]oo`8000Aoo`04001oogooOol50002Ool2000]Ool01000Oomoo`00@Woo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`03001oogoo02eoo`8004=oo`002Woo00@007ooOol000Uoo`03001o
ogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`80
00Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001d
Ool000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`00
0goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000
Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol0
0`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007oo
Ool0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<0
07ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo
0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00
Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo
0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol0
0Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo
00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo
0P0017oo00<007ooOol00Woo0`00N7oo000:Ool01000Oomoo`001goo00D007ooOomoo`0007Moo`00
0goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008
Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002goo0P002Goo0`00
0goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007oo
Ool00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo
079oo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool40003Ool2001cOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool2001cOol000]oo`8000Yoo`8000=o
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo
00=oo`<0009oo`8002eoo`<000Ioo`8003]oo`002Woo00@007ooOol000Yoo`05001oogooOol0000^
Ool00`00Ool00006Ool00`00Ool0000jOol000=oo`D0009oo`04001oogoo0007Ool50002Ool00`00
Oomoo`0/Ool00`00Ool00005Ool01000Oomoo`00>Woo000:Ool01000Oomoo`001goo00@007ooOol0
00=oo`8002eoo`04001oogoo0004Ool01000Oomoo`00>Woo000:Ool01000Oomoo`0027oo00<007oo
00000goo00<007ooOol0:goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo03Moo`00
2Woo00@007ooOol000Uoo`8000=oo`8002aoo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00
Oomoo`0gOol000]oo`8000]oo`05001oogooOol0000]Ool00`00Oomoo`02Ool01000Oomoo`0017oo
00<007ooOol0=goo000LOol2000[Ool00`00Oomoo`03Ool01000Oomoo`0017oo00<007ooOol0=goo
000LOol00`00Oomoo`0ZOol00`00Oomoo`03Ool30005Ool00`00Oomoo`0gOol000]oo`8000Aoo`04
001oogooOol50002Ool2000[Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0fOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0:Woo00<007ooOol037oo00<007ooOol0
=Woo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo00<007ooOol0:Goo00<007ooOol0
3Goo00<007ooOol0=Woo000:Ool01000Oomoo`002Woo00@007ooOomoo`8000ioo`<000Aoo`8000Uo
o`<000Aoo`800004Ool007ooOol20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005
Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool037oo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`020000
1Goo001oogoo00001Goo00T007ooOomoo`00Ool007oo00000Woo00@007ooOol000Eoo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomo
o`000Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol00P0000Eoo`00Oomoo`0000Eoo`03
001oogoo00=oo`03001oo`00009oo`04001oogoo0006Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Uo
o`<000=oo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00=oo`03001oo`00009oo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo
0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007oo
Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000
Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@0
07oo0000009oo`04001oogoo0004Ool20003Ool00`00Oomoo`020002Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool0
1000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool2
0006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P00
1Woo000LOol2000WOol00`00Oomoo`0COol2000dOol001aoo`03001oogoo02Aoo`8001Moo`<0039o
o`0077ooJ@0037oo000LOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomo
o`0BOol00`00Oomoo`0BOol00`00Oomoo`0:Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000;Ool20004Ool01000Oomo
ogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo079oo`00
2Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`D0
009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomo
o`1bOol000]oo`8000]oo`05001oogooOol0001dOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8003Ioo`03001oogoo03Yoo`00
77oo00<007ooOol0=7oo0P00?7oo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000eOol00`00
Ool0000kOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000=Woo00<007oo0000>goo0003Ool5
0002Ool01000Oomoo`001goo1@000Woo0P00=7oo00D007ooOomoo`0003Yoo`002Woo00@007ooOol0
00Moo`04001oogoo0003Ool00`00Oomoo`0cOol01@00Oomoogoo0000>Woo000:Ool01000Oomoo`00
27oo00<007oo00000goo0P00=7oo00D007ooOomoo`0003Yoo`002Woo00@007ooOol000Uoo`8000=o
o`03001oogoo03=oo`03001oogoo009oo`03001oogoo03Moo`002goo0P002goo00@007ooOomoo`80
03Aoo`03001oogoo009oo`03001oogoo03Moo`0077oo00<007ooOol0<goo00<007ooOol00Woo00<0
07ooOol0=goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00=7oo00<007ooOol00Woo00<007oo
Ool0=goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00eoo`<000Aoo`8000Uo
o`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009o
o`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`8000eoo`05001o
ogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool00`00Ool00003Ool20002Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007oo
Ool00goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`04001oogoo0002Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Eoo`03001o
o`00009oo`04001oogoo0006Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P004Goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`000goo00<007oo00001Goo00<007oo00000Woo00@007ooOol000Moo`05001o
ogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool4
0003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00
Ool00003Ool40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000
Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool2
000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0003
Ool30003Ool01000Oomoo`000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007oo
Ool037oo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P0017oo00<007oo00000goo1@000goo
0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000cOol00`00Oomo
o`07Ool00`00Oomoo`0cOol001aoo`03001oogoo035oo`03001oogoo00Qoo`8003Aoo`0077ooJ@00
37oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000Woo1@0000=oo`00Ool00Woo00T007ooOomoo`00Ool007oo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`8002Ioo`80
00Yoo`03001oogoo03ioo`0077oo00<007ooOol09goo00<007ooOol01goo00<007ooOol0?Woo000L
Ool2000XOol00`00Oomoo`07Ool00`00Oomoo`0nOol001aoo`03001oogoo02Qoo`03001oogoo00Io
o`03001oogoo03ioo`002goo0P0017oo00@007ooOomoo`D0009oo`8002Uoo`03001oogoo00Ioo`03
001oogoo03ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0YOol00`00Oomo
o`04Ool00`00Oomoo`0oOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2000ZOol00`00Oomo
o`04Ool00`00Oomoo`0oOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000:goo00<007ooOol0
17oo00<007ooOol0?goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8002]oo`03001o
ogoo00=oo`03001oogoo03moo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`0ZOol00`00Oomoo`03Ool00`00Oomoo`0oOol000]oo`8000Uoo`<000=oo`8002]oo`03001oogoo
00=oo`03001oogoo03moo`0077oo00<007ooOol0:goo00<007ooOol00Woo00<007ooOol0?goo000;
Ool20004Ool00`00Oomoo`03Ool30002Ool2000/Ool00`00Oomoo`02Ool00`00Oomoo`0oOol000Yo
o`04001oogoo000:Ool01@00Oomoogoo0000;Goo00<007ooOol00Woo00<007ooOol0?goo000:Ool0
1000Oomoo`001goo1@000Woo0P00;Goo00D007ooOomoo`00045oo`002Woo00@007ooOol000Moo`04
001oogoo0003Ool00`00Oomoo`0/Ool01000Oomoo`00@Woo000:Ool01000Oomoo`0027oo00<007oo
00000goo0P00;Goo00@007ooOol0049oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo02eo
o`03001oo`00049oo`002goo0P002goo00@007ooOomoo`8002ioo`8004=oo`0077oo00<007ooOol0
;Woo00<007ooOol0@Goo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03
001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Ao
o`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000
Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`80
00Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001o
ogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol0
01Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3480\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23177 L
.216 .23177 L
.22 .23177 L
.224 .23177 L
.228 .23177 L
.232 .23177 L
.236 .23177 L
.24 .23177 L
.244 .23177 L
.248 .23177 L
.252 .23177 L
.256 .23177 L
.26 .23177 L
.264 .23177 L
.268 .23177 L
.272 .23177 L
.276 .23177 L
.28 .23177 L
.284 .23177 L
.288 .23178 L
.292 .23178 L
.296 .23178 L
.3 .23178 L
.304 .23179 L
.308 .23179 L
.312 .23179 L
.316 .2318 L
.32 .23182 L
.324 .23184 L
.328 .23187 L
.332 .23192 L
.336 .23197 L
.34 .23205 L
.344 .23214 L
.348 .23227 L
.352 .23245 L
.356 .23268 L
.36 .233 L
.364 .23342 L
.368 .23397 L
.372 .23466 L
.376 .23551 L
.38 .23656 L
.384 .23782 L
.388 .23932 L
.392 .24112 L
.396 .24324 L
.4 .24574 L
Mistroke
.404 .24865 L
.408 .25198 L
.412 .25574 L
.416 .25985 L
.42 .26425 L
.424 .2688 L
.428 .27334 L
.432 .27769 L
.436 .28167 L
.44 .28511 L
.444 .28786 L
.448 .28981 L
.452 .2909 L
.456 .29107 L
.46 .29033 L
.464 .28868 L
.468 .28616 L
.472 .28279 L
.476 .2786 L
.48 .27364 L
.484 .26795 L
.488 .26161 L
.492 .2547 L
.496 .24733 L
.5 .23964 L
.504 .23178 L
.508 .22392 L
.512 .21622 L
.516 .20885 L
.52 .20194 L
.524 .19559 L
.528 .18991 L
.532 .18495 L
.536 .18076 L
.54 .17739 L
.544 .17487 L
.548 .17322 L
.552 .17248 L
.556 .17266 L
.56 .17374 L
.564 .17569 L
.568 .17844 L
.572 .18188 L
.576 .18586 L
.58 .19021 L
.584 .19476 L
.588 .19931 L
.592 .20371 L
.596 .20783 L
.6 .21159 L
Mistroke
.604 .21493 L
.608 .21784 L
.612 .22034 L
.616 .22247 L
.62 .22426 L
.624 .22577 L
.628 .22703 L
.632 .22807 L
.636 .22893 L
.64 .22962 L
.644 .23016 L
.648 .23058 L
.652 .2309 L
.656 .23114 L
.66 .23131 L
.664 .23144 L
.668 .23154 L
.672 .23161 L
.676 .23167 L
.68 .23171 L
.684 .23174 L
.688 .23177 L
.692 .23178 L
.696 .23179 L
.7 .23179 L
.704 .2318 L
.708 .2318 L
.712 .2318 L
.716 .2318 L
.72 .23181 L
.724 .23181 L
.728 .23181 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35316 L
.284 .35316 L
.288 .35315 L
.292 .35315 L
.296 .35315 L
.3 .35314 L
.304 .35313 L
.308 .35311 L
.312 .35308 L
.316 .35304 L
.32 .35299 L
.324 .35292 L
.328 .35283 L
.332 .3527 L
.336 .35252 L
.34 .35225 L
.344 .35187 L
.348 .35135 L
.352 .35066 L
.356 .34978 L
.36 .34865 L
.364 .34722 L
.368 .34541 L
.372 .3431 L
.376 .34018 L
.38 .3365 L
.384 .3319 L
.388 .32625 L
.392 .31946 L
.396 .31145 L
.4 .30222 L
Mistroke
.404 .29178 L
.408 .28017 L
.412 .26746 L
.416 .25372 L
.42 .23907 L
.424 .22366 L
.428 .20772 L
.432 .19161 L
.436 .17584 L
.44 .16111 L
.444 .14824 L
.448 .13821 L
.452 .132 L
.456 .13053 L
.46 .13452 L
.464 .14437 L
.468 .16002 L
.472 .18095 L
.476 .20609 L
.48 .23392 L
.484 .26256 L
.488 .28992 L
.492 .31389 L
.496 .33258 L
.5 .34445 L
.504 .34852 L
.508 .34445 L
.512 .33258 L
.516 .31389 L
.52 .28991 L
.524 .26256 L
.528 .23392 L
.532 .20609 L
.536 .18095 L
.54 .16002 L
.544 .14436 L
.548 .13452 L
.552 .13053 L
.556 .132 L
.56 .13821 L
.564 .14824 L
.568 .1611 L
.572 .17584 L
.576 .1916 L
.58 .20771 L
.584 .22365 L
.588 .23907 L
.592 .25372 L
.596 .26746 L
.6 .28017 L
Mistroke
.604 .29178 L
.608 .30222 L
.612 .31145 L
.616 .31946 L
.62 .32625 L
.624 .33189 L
.628 .3365 L
.632 .34018 L
.636 .3431 L
.64 .34541 L
.644 .34722 L
.648 .34865 L
.652 .34978 L
.656 .35066 L
.66 .35135 L
.664 .35187 L
.668 .35225 L
.672 .35252 L
.676 .3527 L
.68 .35283 L
.684 .35292 L
.688 .35299 L
.692 .35304 L
.696 .35308 L
.7 .35311 L
.704 .35313 L
.708 .35314 L
.712 .35315 L
.716 .35315 L
.72 .35315 L
.724 .35316 L
.728 .35316 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23176 L
.272 .23176 L
.276 .23176 L
.28 .23176 L
.284 .23176 L
.288 .23177 L
.292 .23177 L
.296 .23178 L
.3 .23179 L
.304 .2318 L
.308 .23181 L
.312 .23182 L
.316 .23185 L
.32 .23189 L
.324 .23196 L
.328 .23205 L
.332 .23218 L
.336 .23235 L
.34 .23258 L
.344 .23287 L
.348 .23326 L
.352 .23378 L
.356 .23448 L
.36 .23543 L
.364 .23669 L
.368 .23832 L
.372 .24039 L
.376 .24295 L
.38 .24609 L
.384 .24987 L
.388 .25439 L
.392 .25978 L
.396 .26616 L
.4 .27366 L
Mistroke
.404 .2824 L
.408 .29241 L
.412 .30367 L
.416 .31604 L
.42 .32925 L
.424 .34291 L
.428 .35655 L
.432 .36963 L
.436 .3816 L
.44 .39193 L
.444 .4002 L
.448 .40606 L
.452 .40929 L
.456 .40978 L
.46 .4075 L
.464 .4025 L
.468 .39486 L
.472 .38468 L
.476 .37206 L
.48 .35714 L
.484 .34007 L
.488 .32105 L
.492 .30035 L
.496 .2783 L
.5 .2553 L
.504 .23181 L
.508 .20833 L
.512 .18533 L
.516 .16328 L
.52 .14258 L
.524 .12356 L
.528 .10649 L
.532 .09157 L
.536 .07895 L
.54 .06876 L
.544 .06112 L
.548 .05612 L
.552 .05385 L
.556 .05434 L
.56 .05757 L
.564 .06343 L
.568 .07169 L
.572 .08203 L
.576 .09399 L
.58 .10707 L
.584 .12071 L
.588 .13438 L
.592 .14758 L
.596 .15995 L
.6 .17122 L
Mistroke
.604 .18123 L
.608 .18996 L
.612 .19747 L
.616 .20385 L
.62 .20923 L
.624 .21376 L
.628 .21754 L
.632 .22068 L
.636 .22324 L
.64 .22531 L
.644 .22694 L
.648 .2282 L
.652 .22914 L
.656 .22985 L
.66 .23037 L
.664 .23076 L
.668 .23105 L
.672 .23127 L
.676 .23144 L
.68 .23158 L
.684 .23167 L
.688 .23174 L
.692 .23178 L
.696 .23181 L
.7 .23182 L
.704 .23183 L
.708 .23184 L
.712 .23185 L
.716 .23185 L
.72 .23186 L
.724 .23186 L
.728 .23186 L
.732 .23186 L
.736 .23186 L
.74 .23186 L
.744 .23186 L
.748 .23186 L
.752 .23186 L
.756 .23186 L
.76 .23187 L
.764 .23186 L
.768 .23186 L
.772 .23186 L
.776 .23186 L
.78 .23186 L
.784 .23186 L
.788 .23186 L
.792 .23186 L
.796 .23186 L
.8 .23186 L
Mistroke
.804 .23186 L
.808 .23186 L
.812 .23186 L
.816 .23186 L
.82 .23186 L
.824 .23186 L
.828 .23186 L
.832 .23186 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool50003Ool01000Oomoo`000Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`80009oo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uo
o`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`8000=oo`<000Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001o
ogoo00aoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Eoo`8000=oo`D000=oo`8000Io
o`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00=7oo00<007ooOol01Goo
00<007ooOol0=7oo000LOol00`00Oomoo`0bOol00`00Oomoo`07Ool2000dOol001aoofT000aoo`00
77oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`03001oo`0000<000=oo`09001oogooOol007oo001oo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol2000XOol00`00Oomo
o`06Ool00`00Oomoo`0oOol001aoo`03001oogoo02Qoo`03001oogoo00Eoo`03001oogoo03moo`00
77oo0P00:Woo00<007ooOol00goo00<007ooOol0@7oo000LOol00`00Oomoo`0YOol20003Ool20012
Ool000]oo`8000Aoo`04001oogooOol50002Ool2000/Ool40013Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00Lgoo
000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo
000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol0
0goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007oo
Ool000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003
Ool00`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`00
2goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol0
00Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomo
o`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`80
00Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003
Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol0
01aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1b
Ool001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol0
01Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomo
o`02Ool3001hOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000;Ool20009Ool30003Ool00`00Oomoo`1b
Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2
001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`@000=oo`8007=oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`03001oogoo079oo`002Woo
00@007ooOol000Qoo`03001oogoo00=oo`8007=oo`002goo0P002Woo0P000goo00<007ooOol0LWoo
000LOol2000]Ool20008Ool2000jOol001aoo`03001oogoo02aoo`8000Moo`03001oo`0003Yoo`00
2goo0P0017oo00<007ooOol00goo0`000Woo0P00;7oo00<007oo00001goo00@007ooOol003Uoo`00
2Woo00@007ooOol000Yoo`05001oogooOol0000]Ool01000Oomoo`001Woo00@007ooOol003Uoo`00
0goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo02]oo`04001oogoo0006Ool01000Oomo
o`00>Goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`8002]oo`05001oogooOol00006Ool0
1000Oomoo`00>Goo000:Ool01000Oomoo`0027oo00<007oo00000goo00<007ooOol0:Woo00D007oo
Oomoo`0000Ioo`05001oogooOol0000hOol000Yoo`04001oogoo0009Ool20003Ool2000[Ool01@00
Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol0=Woo000;Ool2000;Ool01@00Oomoogoo0000
:goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0=Woo000LOol2000Z
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0fOol001aoo`03001o
ogoo02Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo03Eoo`002goo
0P0017oo00@007ooOomoo`D0009oo`8002Yoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo03Eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0YOol0
0`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0eOol000=oo`D0009oo`04
001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0XOol00`00Oomoo`04Ool01@00Oomoogoo0000
1Woo00<007ooOol0=Goo000:Ool01000Oomoo`002Woo00@007ooOomoo`8000ioo`<000Aoo`8000Uo
o`<000Aoo`<000=oo`800003Ool007oo009oo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`80
00Eoo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`0<Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oo`000002
Ool00`00Oomoo`020003Ool20003Ool00`00Oomoo`020002Ool01000Oomoo`001Goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04001oogoo
0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Ool000000Woo00H007ooOol007oo0002Ool2
0006Ool20002Ool01000Oomoo`001Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool20009Ool30003Ool00`00
Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007oo0000009oo`06
001oogoo001oo`000Woo0P001goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002
Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo
00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oo`000002Ool0
1P00Oomoo`00Ool0009oo`8000=oo`D0009oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001ao
o`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool200001Goo001oogoo0000
0Woo00<007oo00000Woo0P000goo00@007ooOomoo`800005Ool007ooOol00004Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo
0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`03001oogoo009oo`<000Aoo`80009oo`03
001oogoo008000=oo`H0009oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Io
o`0077oo0P009Goo0P002Woo00<007oo00002goo00<007ooOol0<Goo000LOol00`00Oomoo`0ROol3
000<Ool2000<Ool2000aOol001aoofT000aoo`0077oo00<007ooOol04Woo00<007ooOol04Woo00<0
07ooOol04Goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol02Woo000LOol2001cOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00
2goo0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001cOol000Yoo`04001o
ogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
07=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uo
o`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03
001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yo
o`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`00
2Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01@00Oomoogoo0000M7oo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00=goo0P00>Woo
000:Ool01000Oomoo`002Woo00D007ooOomoo`0003Moo`04001oogoo000iOol000=oo`D0009oo`04
001oogoo0007Ool50002Ool2000fOol01000Oomoo`00>Goo000:Ool01000Oomoo`001goo00@007oo
Ool000=oo`03001oogoo03Eoo`04001oogoo000iOol000Yoo`04001oogoo0008Ool00`00Ool00003
Ool2000eOol00`00Oomoo`02Ool00`00Oomoo`0fOol000Yoo`04001oogoo0009Ool20003Ool00`00
Oomoo`0dOol00`00Oomoo`02Ool00`00Oomoo`0fOol000]oo`8000]oo`04001oogooOol2000eOol0
0`00Oomoo`02Ool00`00Oomoo`0fOol001aoo`03001oogoo03=oo`03001oogoo00Aoo`03001oogoo
03Eoo`002goo0P0017oo00@007ooOomoo`D0009oo`8003Aoo`03001oogoo00Aoo`03001oogoo03Eo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0=Ool30004Ool20009Ool30004
Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004
Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool2000=Ool01@00Oomoogoo
00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo0P00
0goo00D007oo001oo`00009oo`04001oogoo0005Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04
001oogoo000:Ool01@00Oomoogoo00004Woo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`0017oo0P001Woo0P000Woo00@007ooOol000Ioo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`00
0Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0004Ool20006Ool2
0002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000=oo`03001oo`0000=oo`D0009oo`04001oogoo0004Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo
0005Ool000]oo`8000Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool0
1000Oomoo`000Woo00@007ooOol000=oo`<000=oo`05001oogooOol00002Ool01000Oomoo`0017oo
00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006
Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004
Ool20004Ool00`00Ool00003Ool50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003
Ool20006Ool001aoo`8003=oo`03001oogoo00Qoo`03001oogoo039oo`0077oo00<007ooOol0<Woo
00<007ooOol02Goo0P00<Woo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`06001oogooOol007oo1@000Woo00D007oo
Oomoo`0000=oo`05001oo`00Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03
001oogoo00Yoo`0077oo0P009Goo0P002goo00<007ooOol0?Woo000LOol00`00Oomoo`0UOol2000:
Ool00`00Oomoo`0nOol001aoo`8002Moo`03001oogoo00Qoo`03001oogoo03ioo`0077oo00<007oo
Ool09goo00<007ooOol01Woo00<007ooOol0?goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00
:7oo00<007ooOol01Woo00<007ooOol0?goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03
001oogoo02Moo`03001oogoo00Ioo`03001oogoo03moo`002Woo00@007ooOol000Uoo`03001oogoo
009oo`8002Uoo`03001oogoo00Eoo`03001oogoo03moo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0000ZOol00`00Oomoo`05Ool00`00Oomoo`0oOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00:Goo00<007ooOol01Goo00<007ooOol0?goo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo02Uoo`03001oogoo00Aoo`03001oogoo03moo`002goo0P002Goo0`00
0goo0P00:Woo00<007ooOol00goo00<007ooOol0@7oo000LOol00`00Oomoo`0YOol00`00Oomoo`03
Ool00`00Oomoo`10Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8002Yoo`03001oogoo00=o
o`03001oogoo041oo`002Woo00@007ooOol000Yoo`05001oogooOol0000/Ool01@00Oomoogoo0000
@goo000:Ool01000Oomoo`001goo1@000Woo0P00:goo00D007ooOomoo`0004=oo`002Woo00@007oo
Ool000Moo`04001oogoo0003Ool00`00Oomoo`0[Ool01000Oomoo`00@goo000:Ool01000Oomoo`00
27oo00<007oo00000goo0P00;7oo0`00A7oo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0
;7oo0P00A7oo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`80
00Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool0
1000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo
0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool2
0003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00
Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol0
0`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000G
Ool00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2
001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3520\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23177 L
.216 .23177 L
.22 .23177 L
.224 .23177 L
.228 .23177 L
.232 .23177 L
.236 .23177 L
.24 .23177 L
.244 .23177 L
.248 .23177 L
.252 .23177 L
.256 .23177 L
.26 .23177 L
.264 .23177 L
.268 .23178 L
.272 .23178 L
.276 .23178 L
.28 .23178 L
.284 .23178 L
.288 .23178 L
.292 .23178 L
.296 .23179 L
.3 .2318 L
.304 .23181 L
.308 .23182 L
.312 .23184 L
.316 .23187 L
.32 .23191 L
.324 .23196 L
.328 .23204 L
.332 .23214 L
.336 .23228 L
.34 .23247 L
.344 .23272 L
.348 .23304 L
.352 .23345 L
.356 .23397 L
.36 .23463 L
.364 .23546 L
.368 .23649 L
.372 .23777 L
.376 .23932 L
.38 .24119 L
.384 .24339 L
.388 .24594 L
.392 .24885 L
.396 .25211 L
.4 .25571 L
Mistroke
.404 .25961 L
.408 .26379 L
.412 .26816 L
.416 .27265 L
.42 .27712 L
.424 .28142 L
.428 .28534 L
.432 .28868 L
.436 .2912 L
.44 .29266 L
.444 .29289 L
.448 .29177 L
.452 .28925 L
.456 .2854 L
.46 .28039 L
.464 .27449 L
.468 .26804 L
.472 .26141 L
.476 .255 L
.48 .24914 L
.484 .24408 L
.488 .23998 L
.492 .23686 L
.496 .2346 L
.5 .233 L
.504 .23175 L
.508 .2305 L
.512 .22891 L
.516 .22666 L
.52 .22355 L
.524 .21946 L
.528 .21442 L
.532 .20857 L
.536 .20216 L
.54 .19554 L
.544 .18909 L
.548 .18319 L
.552 .17817 L
.556 .17431 L
.56 .17178 L
.564 .17065 L
.568 .17088 L
.572 .17234 L
.576 .17485 L
.58 .1782 L
.584 .18213 L
.588 .18643 L
.592 .19091 L
.596 .1954 L
.6 .19978 L
Mistroke
.604 .20396 L
.608 .20787 L
.612 .21147 L
.616 .21473 L
.62 .21764 L
.624 .22019 L
.628 .2224 L
.632 .22426 L
.636 .22582 L
.64 .22709 L
.644 .22813 L
.648 .22895 L
.652 .22961 L
.656 .23013 L
.66 .23054 L
.664 .23086 L
.668 .23111 L
.672 .2313 L
.676 .23144 L
.68 .23154 L
.684 .23162 L
.688 .23167 L
.692 .23171 L
.696 .23174 L
.7 .23176 L
.704 .23177 L
.708 .23179 L
.712 .23179 L
.716 .2318 L
.72 .2318 L
.724 .2318 L
.728 .2318 L
.732 .23181 L
.736 .23181 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35316 L
.268 .35316 L
.272 .35316 L
.276 .35316 L
.28 .35315 L
.284 .35315 L
.288 .35314 L
.292 .35312 L
.296 .35311 L
.3 .35308 L
.304 .35305 L
.308 .353 L
.312 .35293 L
.316 .35282 L
.32 .35267 L
.324 .35247 L
.328 .35219 L
.332 .35183 L
.336 .35134 L
.34 .3507 L
.344 .34984 L
.348 .34872 L
.352 .34725 L
.356 .34534 L
.36 .34293 L
.364 .3399 L
.368 .33617 L
.372 .33162 L
.376 .32615 L
.38 .31963 L
.384 .31193 L
.388 .30293 L
.392 .29256 L
.396 .28076 L
.4 .2676 L
Mistroke
.404 .25321 L
.408 .23786 L
.412 .22192 L
.416 .20587 L
.42 .19026 L
.424 .17566 L
.428 .16267 L
.432 .15185 L
.436 .14373 L
.44 .13876 L
.444 .13733 L
.448 .13974 L
.452 .14623 L
.456 .15691 L
.46 .17175 L
.464 .19054 L
.468 .21286 L
.472 .23802 L
.476 .26508 L
.48 .29285 L
.484 .31994 L
.488 .34487 L
.492 .36614 L
.496 .38243 L
.5 .39267 L
.504 .39616 L
.508 .39267 L
.512 .38243 L
.516 .36614 L
.52 .34487 L
.524 .31994 L
.528 .29285 L
.532 .26508 L
.536 .23802 L
.54 .21285 L
.544 .19053 L
.548 .17174 L
.552 .15691 L
.556 .14623 L
.56 .13974 L
.564 .13732 L
.568 .13876 L
.572 .14373 L
.576 .15185 L
.58 .16266 L
.584 .17565 L
.588 .19025 L
.592 .20587 L
.596 .22192 L
.6 .23786 L
Mistroke
.604 .25321 L
.608 .2676 L
.612 .28076 L
.616 .29255 L
.62 .30293 L
.624 .31193 L
.628 .31963 L
.632 .32615 L
.636 .33162 L
.64 .33617 L
.644 .3399 L
.648 .34293 L
.652 .34534 L
.656 .34725 L
.66 .34872 L
.664 .34984 L
.668 .3507 L
.672 .35134 L
.676 .35183 L
.68 .35219 L
.684 .35247 L
.688 .35267 L
.692 .35282 L
.696 .35293 L
.7 .353 L
.704 .35305 L
.708 .35308 L
.712 .35311 L
.716 .35312 L
.72 .35314 L
.724 .35315 L
.728 .35315 L
.732 .35316 L
.736 .35316 L
.74 .35316 L
.744 .35316 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23176 L
.26 .23176 L
.264 .23176 L
.268 .23177 L
.272 .23177 L
.276 .23177 L
.28 .23177 L
.284 .23178 L
.288 .23178 L
.292 .23179 L
.296 .23181 L
.3 .23183 L
.304 .23186 L
.308 .23191 L
.312 .23197 L
.316 .23205 L
.32 .23217 L
.324 .23233 L
.328 .23255 L
.332 .23286 L
.336 .23328 L
.34 .23385 L
.344 .23459 L
.348 .23555 L
.352 .23678 L
.356 .23834 L
.36 .24032 L
.364 .2428 L
.368 .2459 L
.372 .24972 L
.376 .25438 L
.38 .25998 L
.384 .26659 L
.388 .27425 L
.392 .28299 L
.396 .29279 L
.4 .3036 L
Mistroke
.404 .31534 L
.408 .32788 L
.412 .34102 L
.416 .35449 L
.42 .36792 L
.424 .38082 L
.428 .39261 L
.432 .40262 L
.436 .41015 L
.44 .41454 L
.444 .41522 L
.448 .41182 L
.452 .40423 L
.456 .39265 L
.46 .37759 L
.464 .35984 L
.468 .34045 L
.472 .32055 L
.476 .30129 L
.48 .28369 L
.484 .26853 L
.488 .25626 L
.492 .24693 L
.496 .24023 L
.5 .2355 L
.504 .23181 L
.508 .22813 L
.512 .2234 L
.516 .2167 L
.52 .20737 L
.524 .1951 L
.528 .17994 L
.532 .16234 L
.536 .14308 L
.54 .12318 L
.544 .10378 L
.548 .08604 L
.552 .07097 L
.556 .05939 L
.56 .0518 L
.564 .0484 L
.568 .04908 L
.572 .05347 L
.576 .061 L
.58 .07102 L
.584 .08281 L
.588 .09571 L
.592 .10913 L
.596 .12261 L
.6 .13575 L
Mistroke
.604 .14828 L
.608 .16003 L
.612 .17084 L
.616 .18064 L
.62 .18938 L
.624 .19704 L
.628 .20365 L
.632 .20924 L
.636 .21391 L
.64 .21773 L
.644 .22083 L
.648 .22331 L
.652 .22529 L
.656 .22685 L
.66 .22808 L
.664 .22904 L
.668 .22978 L
.672 .23034 L
.676 .23076 L
.68 .23107 L
.684 .2313 L
.688 .23146 L
.692 .23157 L
.696 .23166 L
.7 .23172 L
.704 .23177 L
.708 .2318 L
.712 .23182 L
.716 .23184 L
.72 .23185 L
.724 .23185 L
.728 .23185 L
.732 .23186 L
.736 .23186 L
.74 .23186 L
.744 .23186 L
.748 .23186 L
.752 .23186 L
.756 .23186 L
.76 .23186 L
.764 .23186 L
.768 .23186 L
.772 .23186 L
.776 .23186 L
.78 .23186 L
.784 .23186 L
.788 .23186 L
.792 .23186 L
.796 .23186 L
.8 .23186 L
Mistroke
.804 .23186 L
.808 .23186 L
.812 .23186 L
.816 .23186 L
.82 .23186 L
.824 .23186 L
.828 .23186 L
.832 .23186 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`030002Ool01000Oomo
o`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oo`00Ool40003Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`00
1Goo000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@0
07ooOol0009oo`04001oogoo0004Ool30002Ool00`00Ool00004Ool01000Oomoo`0017oo00D007oo
Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000
Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006
Ool20002Ool50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001ao
o`8003Eoo`03001oogoo00Eoo`03001oogoo03=oo`0077oo00<007ooOol0<goo00<007ooOol01goo
0`00<Woo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool400000goo001oo`02Ool01000Oomo
ogoo0P000Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomo
o`0:Ool001aoo`8002Ioo`8000Qoo`03001oogoo041oo`0077oo00<007ooOol09goo00<007ooOol0
17oo00<007ooOol0@Goo000LOol2000XOol20005Ool00`00Oomoo`11Ool001aoo`03001oogoo02Uo
o`05001oogooOol00014Ool000]oo`8000Aoo`04001oogooOol50002Ool2000ZOol200000goo001o
o`14Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0:goo00<007ooOol0A7oo
000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007oo
Oomoo`0007Aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol0
01aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000
Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo
00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00
Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]o
o`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`00
0goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo
0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<0
07ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`00
0goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=o
o`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0
Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3001hOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo0000Mgoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P00Lgoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`@000=oo`8007=oo`002Woo00@007oo
Ool000Moo`03001oogoo00Aoo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oogoo00=o
o`8007=oo`002goo0P002Woo0P000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
02Yoo`<000Yoo`8003Uoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00:goo00<007oo0000
2Woo00<007oo0000>7oo000:Ool01000Oomoo`002Woo00D007ooOomoo`0002]oo`04001oogoo0009
Ool01000Oomoo`00>7oo0003Ool50002Ool01000Oomoo`001goo1@000Woo00<007ooOol0:Goo00D0
07ooOomoo`0000Qoo`04001oogoo000hOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P00
:Woo00D007ooOomoo`0000Qoo`05001oogooOol0000gOol000Yoo`04001oogoo0008Ool00`00Ool0
0003Ool00`00Oomoo`0YOol01@00Oomoogoo00001goo00<007ooOol00Woo00<007ooOol0=Goo000:
Ool01000Oomoo`002Goo0P000goo0P00:Woo00D007ooOomoo`0000Moo`03001oogoo009oo`03001o
ogoo03Eoo`002goo0P002goo00D007ooOomoo`0002Yoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo009oo`03001oogoo03Eoo`0077oo0P00:Goo00<007ooOol00goo00<007ooOol017oo00<0
07ooOol00goo00<007ooOol0=7oo000LOol00`00Oomoo`0XOol00`00Oomoo`03Ool00`00Oomoo`04
Ool00`00Oomoo`03Ool00`00Oomoo`0dOol000]oo`8000Aoo`04001oogooOol50002Ool2000XOol0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0dOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00<007ooOol09goo00<007ooOol017oo00<007ooOol017oo00<007oo
Ool00goo00<007ooOol0=7oo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo00<007oo
Ool09goo00<007ooOol017oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol0<goo000:Ool0
1000Oomoo`002Woo00@007ooOomoo`8000ioo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`<000Aoo`<0
00=oo`@000=oo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool01@00Oomoogoo00000Woo00@007oo
Ool000Uoo`03001oogoo009oo`800005Ool007ooOol00002Ool00`00Oomoo`03Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo00<0
07ooOol00Woo0P0000Eoo`00Oomoo`00009oo`8000Aoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Uoo`<000=oo`03001oogoo011oo`04001o
ogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool200001Goo001oogoo00000Woo0P0017oo00<0
07ooOol01Goo0P0000Eoo`00Oomoo`0000Moo`05001oogooOol00002Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo1000
0goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool00`00Oomoo`020004Ool01000
Oomoogoo100000Aoo`00Ool0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007oo
Ool037oo00<007ooOol017oo00@007ooOol000Qoo`8000=oo`80009oo`04001oogoo0002Ool20003
Ool20003Ool00`00Oomoo`03Ool20002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03
001oogoo00aoo`D000=oo`8000Yoo`06001oogooOol007oo0P0017oo0P0000=oo`00Ool00Woo0P00
0goo1@000Woo0`001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000T
Ool2000;Ool01000Oomoo`002goo00<007ooOol0<7oo000LOol00`00Oomoo`0QOol3000<Ool01000
Oomoo`0037oo0P00<7oo000LOomY000<Ool001aoo`03001oogoo019oo`03001oogoo019oo`03001o
ogoo00Ioo`04001oogoo0007Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0:Ool001ao
o`80035oo`04001oogoo000nOol001aoo`03001oogoo031oo`03001oo`0003moo`0077oo0P00<Woo
0P00?goo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002goo0P0017oo00@007ooOomo
o`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0009Ool00`00Oomoo`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo
0000M7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`03001oogoo079o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`80
07=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool50002
Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000
Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0
LWoo000;Ool2000;Ool01@00Oomoogoo0000M7oo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`002goo0P0017oo00<007ooOol00goo0`000Woo0P00>7oo0P00>Goo000:Ool01000Oomoo`002Woo
00D007ooOomoo`0003Uoo`03001oo`0003Qoo`000goo1@000Woo00@007ooOol000Moo`D0009oo`80
03Moo`04001oogoo000hOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0=Woo
00D007ooOomoo`0003Moo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8003Moo`05001oogoo
Ool0000gOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`0eOol00`00Oomoo`02Ool00`00
Oomoo`0eOol000]oo`8000]oo`04001oogooOol2000fOol00`00Oomoo`02Ool00`00Oomoo`0eOol0
01aoo`03001oogoo03Eoo`03001oogoo00=oo`03001oogoo03Aoo`002goo0P0017oo00@007ooOomo
o`D0009oo`8003Ioo`03001oogoo00=oo`03001oogoo03Aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004
Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001o
ogoo0009Ool00`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo0P000Woo00D007ooOomoo`00009oo`04001o
ogoo0005Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool0
00=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000
4Woo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol0
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogooOol4000017oo001oo`000Woo00<007ooOol00Woo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool0
1000Oomoo`001Goo000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo
0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`02Ool00`00Ool00002
Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00
Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`03
001oogoo00=oo`8000Aoo`8000Eoo`8000=oo`D00003Ool007oo008000Ioo`<000Aoo`8000Aoo`80
00Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00=7oo00<007ooOol027oo0P00<Woo000LOol00`00
Oomoo`0cOol00`00Oomoo`09Ool2000aOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03
001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOomoo`D000Aoo`05
001oogooOol00003Ool300000goo001oo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Ao
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009o
o`03001oogoo00Yoo`0077oo0P0097oo0P002goo00<007ooOol0?goo000LOol00`00Oomoo`0TOol0
0`00Oomoo`09Ool00`00Oomoo`0oOol001aoo`8002Ioo`03001oogoo00Moo`03001oogoo041oo`00
77oo00<007ooOol09Goo00<007ooOol01goo00<007ooOol0@7oo000;Ool20004Ool01000Oomoogoo
1@000Woo0P009goo00<007ooOol01Woo00<007ooOol0@7oo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`03001oogoo02Ioo`03001oogoo00Ioo`03001oogoo041oo`002Woo00@007ooOol000Uo
o`03001oogoo009oo`8002Qoo`03001oogoo00Aoo`03001oogoo045oo`002Woo00@007ooOol000Yo
o`05001oogooOol0000YOol00`00Oomoo`04Ool00`00Oomoo`11Ool000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P00:7oo00<007ooOol017oo00<007ooOol0@Goo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo02Moo`03001oogoo00Aoo`03001oogoo045oo`002goo
0P002Goo0`000goo0P00:Goo00<007ooOol00goo00<007ooOol0@Goo000LOol00`00Oomoo`0XOol0
0`00Oomoo`03Ool00`00Oomoo`11Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8002Uoo`03
001oogoo009oo`03001oogoo049oo`002Woo00@007ooOol000Yoo`05001oogooOol0000[Ool01@00
Oomoogoo0000A7oo000:Ool01000Oomoo`001goo1@000Woo0P00:Woo00D007ooOomoo`0004Aoo`00
2Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0YOol01000Oomoo`00AGoo000:Ool0
1000Oomoo`0027oo00<007oo00000goo0P00:goo00<007oo0000AGoo000:Ool01000Oomoo`002Goo
0P000goo00<007ooOol0:Woo0`00AGoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00
Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0
LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007oo
Ool00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008
Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`00
0goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo
00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<0
07ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3560\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23177 L
.216 .23177 L
.22 .23177 L
.224 .23177 L
.228 .23177 L
.232 .23177 L
.236 .23177 L
.24 .23177 L
.244 .23177 L
.248 .23177 L
.252 .23177 L
.256 .23178 L
.26 .23178 L
.264 .23178 L
.268 .23178 L
.272 .23178 L
.276 .23178 L
.28 .23178 L
.284 .23179 L
.288 .2318 L
.292 .23181 L
.296 .23182 L
.3 .23184 L
.304 .23187 L
.308 .23191 L
.312 .23197 L
.316 .23205 L
.32 .23215 L
.324 .23229 L
.328 .23248 L
.332 .23272 L
.336 .23304 L
.34 .23345 L
.344 .23398 L
.348 .23465 L
.352 .23549 L
.356 .23654 L
.36 .23781 L
.364 .23935 L
.368 .24118 L
.372 .24335 L
.376 .24586 L
.38 .24876 L
.384 .25203 L
.388 .25567 L
.392 .25964 L
.396 .26389 L
.4 .2683 L
Mistroke
.404 .27278 L
.408 .27716 L
.412 .2813 L
.416 .28501 L
.42 .28814 L
.424 .29051 L
.428 .29197 L
.432 .29238 L
.436 .29164 L
.44 .28967 L
.444 .28646 L
.448 .28205 L
.452 .27653 L
.456 .27011 L
.46 .26304 L
.464 .25567 L
.468 .24838 L
.472 .24158 L
.476 .23567 L
.48 .23098 L
.484 .22775 L
.488 .22607 L
.492 .22591 L
.496 .22704 L
.5 .22914 L
.504 .23174 L
.508 .23435 L
.512 .23645 L
.516 .2376 L
.52 .23745 L
.524 .23579 L
.528 .23258 L
.532 .2279 L
.536 .222 L
.54 .2152 L
.544 .20791 L
.548 .20054 L
.552 .19346 L
.556 .18703 L
.56 .18151 L
.564 .17709 L
.568 .17388 L
.572 .17191 L
.576 .17116 L
.58 .17158 L
.584 .17303 L
.588 .1754 L
.592 .17853 L
.596 .18225 L
.6 .18639 L
Mistroke
.604 .19078 L
.608 .19526 L
.612 .19968 L
.616 .20392 L
.62 .2079 L
.624 .21155 L
.628 .21482 L
.632 .21772 L
.636 .22024 L
.64 .2224 L
.644 .22423 L
.648 .22577 L
.652 .22705 L
.656 .22809 L
.66 .22893 L
.664 .22961 L
.668 .23014 L
.672 .23055 L
.676 .23086 L
.68 .23111 L
.684 .23129 L
.688 .23143 L
.692 .23154 L
.696 .23161 L
.7 .23167 L
.704 .23171 L
.708 .23174 L
.712 .23176 L
.716 .23177 L
.72 .23178 L
.724 .23179 L
.728 .2318 L
.732 .2318 L
.736 .2318 L
.74 .23181 L
.744 .23181 L
.748 .23181 L
.752 .23181 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35316 L
.256 .35316 L
.26 .35316 L
.264 .35315 L
.268 .35315 L
.272 .35314 L
.276 .35314 L
.28 .35313 L
.284 .35311 L
.288 .35308 L
.292 .35304 L
.296 .35299 L
.3 .35291 L
.304 .35281 L
.308 .35267 L
.312 .35247 L
.316 .3522 L
.32 .35183 L
.324 .35133 L
.328 .35067 L
.332 .34979 L
.336 .34864 L
.34 .34716 L
.344 .34528 L
.348 .3429 L
.352 .33992 L
.356 .33622 L
.36 .33168 L
.364 .32617 L
.368 .31956 L
.372 .31175 L
.376 .30268 L
.38 .2923 L
.384 .28061 L
.388 .26768 L
.392 .25362 L
.396 .23862 L
.4 .22294 L
Mistroke
.404 .20694 L
.408 .1911 L
.412 .17599 L
.416 .16226 L
.42 .15067 L
.424 .14194 L
.428 .1368 L
.432 .1358 L
.436 .13933 L
.44 .14752 L
.444 .16018 L
.448 .17686 L
.452 .1968 L
.456 .21905 L
.46 .24256 L
.464 .26621 L
.468 .28901 L
.472 .3101 L
.476 .32885 L
.48 .34487 L
.484 .358 L
.488 .36829 L
.492 .37591 L
.496 .3811 L
.5 .3841 L
.504 .38509 L
.508 .3841 L
.512 .3811 L
.516 .37591 L
.52 .36829 L
.524 .358 L
.528 .34487 L
.532 .32885 L
.536 .3101 L
.54 .28901 L
.544 .26621 L
.548 .24255 L
.552 .21905 L
.556 .1968 L
.56 .17686 L
.564 .16018 L
.568 .14751 L
.572 .13933 L
.576 .13579 L
.58 .13679 L
.584 .14194 L
.588 .15066 L
.592 .16226 L
.596 .17598 L
.6 .1911 L
Mistroke
.604 .20694 L
.608 .22293 L
.612 .23861 L
.616 .25362 L
.62 .26768 L
.624 .28061 L
.628 .29229 L
.632 .30268 L
.636 .31175 L
.64 .31956 L
.644 .32617 L
.648 .33168 L
.652 .33622 L
.656 .33992 L
.66 .3429 L
.664 .34528 L
.668 .34716 L
.672 .34864 L
.676 .34979 L
.68 .35067 L
.684 .35133 L
.688 .35183 L
.692 .3522 L
.696 .35247 L
.7 .35267 L
.704 .35281 L
.708 .35291 L
.712 .35299 L
.716 .35304 L
.72 .35308 L
.724 .35311 L
.728 .35313 L
.732 .35314 L
.736 .35314 L
.74 .35315 L
.744 .35315 L
.748 .35316 L
.752 .35316 L
.756 .35316 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23176 L
.248 .23176 L
.252 .23176 L
.256 .23177 L
.26 .23177 L
.264 .23177 L
.268 .23177 L
.272 .23178 L
.276 .23178 L
.28 .23179 L
.284 .23181 L
.288 .23183 L
.292 .23186 L
.296 .23191 L
.3 .23197 L
.304 .23205 L
.308 .23218 L
.312 .23235 L
.316 .23258 L
.32 .23289 L
.324 .23331 L
.328 .23386 L
.332 .23459 L
.336 .23554 L
.34 .23677 L
.344 .23836 L
.348 .24037 L
.352 .2429 L
.356 .24603 L
.36 .24985 L
.364 .25447 L
.368 .25998 L
.372 .26647 L
.376 .27403 L
.38 .28271 L
.384 .29254 L
.388 .30348 L
.392 .31542 L
.396 .32816 L
.4 .34143 L
Mistroke
.404 .35487 L
.408 .36805 L
.412 .38047 L
.416 .39164 L
.42 .40102 L
.424 .40812 L
.428 .41247 L
.432 .41367 L
.436 .41141 L
.44 .40547 L
.444 .39579 L
.448 .3825 L
.452 .36593 L
.456 .34664 L
.46 .32543 L
.464 .30332 L
.468 .28147 L
.472 .26112 L
.476 .24343 L
.48 .22941 L
.484 .21975 L
.488 .21477 L
.492 .2143 L
.496 .21773 L
.5 .22402 L
.504 .23181 L
.508 .23961 L
.512 .2459 L
.516 .24932 L
.52 .24886 L
.524 .24387 L
.528 .23422 L
.532 .2202 L
.536 .20251 L
.54 .18216 L
.544 .16031 L
.548 .1382 L
.552 .11699 L
.556 .0977 L
.56 .08112 L
.564 .06783 L
.568 .05816 L
.572 .05222 L
.576 .04995 L
.58 .05115 L
.584 .05551 L
.588 .06261 L
.592 .07199 L
.596 .08315 L
.6 .09558 L
Mistroke
.604 .10875 L
.608 .12219 L
.612 .13546 L
.616 .14821 L
.62 .16015 L
.624 .17108 L
.628 .18091 L
.632 .1896 L
.636 .19715 L
.64 .20365 L
.644 .20915 L
.648 .21377 L
.652 .2176 L
.656 .22073 L
.66 .22325 L
.664 .22527 L
.668 .22685 L
.672 .22809 L
.676 .22904 L
.68 .22977 L
.684 .23032 L
.688 .23074 L
.692 .23105 L
.696 .23128 L
.7 .23145 L
.704 .23157 L
.708 .23166 L
.712 .23172 L
.716 .23177 L
.72 .2318 L
.724 .23182 L
.728 .23183 L
.732 .23184 L
.736 .23185 L
.74 .23186 L
.744 .23186 L
.748 .23186 L
.752 .23186 L
.756 .23186 L
.76 .23186 L
.764 .23186 L
.768 .23186 L
.772 .23186 L
.776 .23186 L
.78 .23186 L
.784 .23186 L
.788 .23186 L
.792 .23186 L
.796 .23186 L
.8 .23186 L
Mistroke
.804 .23186 L
.808 .23186 L
.812 .23186 L
.816 .23186 L
.82 .23186 L
.824 .23186 L
.828 .23186 L
.832 .23186 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo0`0000Eoo`00Oomo
o`00009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`050003Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`00
1Goo000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@0
07ooOol0009oo`04001oogoo0004Ool2000017oo000000000Woo0P000Woo00@007ooOol000Aoo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo
00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P0017oo
0P001Woo00@007oo001oo`H0009oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`80
00Ioo`0077oo0P00=Woo00<007ooOol01Goo0P00<goo000LOol00`00Oomoo`0eOol00`00Oomoo`06
Ool3000aOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`@0009oo`05001oogooOol00002
Ool20002Ool20003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`00
77oo0P009Goo0P0027oo00<007ooOol0@Goo000LOol00`00Oomoo`0UOol20006Ool00`00Oomoo`12
Ool001aoo`8002Moo`8000Aoo`03001oogoo04=oo`0077oo00<007ooOol09goo0P000goo00<007oo
Ool0@goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00:Goo1000AWoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`03001oogoo02Yoo`03001oogoo04Eoo`002Woo00@007ooOol000Uoo`03
001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0
001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomo
o`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool0
1000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000L
Ool00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<0
07ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo
00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001o
ogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P00
2Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007oo
Ool00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`00
5goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
2goo0P0017oo00<007ooOol00Woo0`00N7oo000:Ool01000Oomoo`001goo00D007ooOomoo`0007Mo
o`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo
0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002goo0P002Goo
0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<0
07ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo079oo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool40003Ool2001cOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool2001cOol000]oo`8000Yoo`80
00=oo`03001oogoo079oo`0077oo0P00:goo00<007ooOol037oo00<007ooOol0=Woo000LOol00`00
Oomoo`0YOol2000=Ool3000gOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8002Yoo`03001o
o`0000aoo`03001oo`0003Moo`002Woo00@007ooOol000Yoo`05001oogooOol0000ZOol01000Oomo
o`0037oo00<007oo0000=goo0003Ool50002Ool01000Oomoo`001goo1@000Woo00<007ooOol0:7oo
00@007ooOol000aoo`03001oo`0003Moo`002Woo00@007ooOol000Moo`04001oogoo0003Ool2000Y
Ool01@00Oomoogoo00002Woo00D007ooOomoo`0003Ioo`002Woo00@007ooOol000Qoo`03001oo`00
00=oo`03001oogoo02Moo`03001oogoo009oo`03001oogoo00Qoo`05001oogooOol0000fOol000Yo
o`04001oogoo0009Ool20003Ool2000XOol00`00Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo
0000=Woo000;Ool2000;Ool01@00Oomoogoo0000:Goo00<007ooOol00Woo00<007ooOol027oo00<0
07ooOol00Woo00<007ooOol0<goo000LOol2000XOol00`00Oomoo`02Ool00`00Oomoo`07Ool00`00
Oomoo`03Ool00`00Oomoo`0cOol001aoo`03001oogoo02Moo`03001oogoo009oo`03001oogoo00Mo
o`03001oogoo00=oo`03001oogoo03=oo`002goo0P0017oo00@007ooOomoo`D0009oo`8002Moo`03
001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo03=oo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool00`00Oomoo`0VOol00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomo
o`03Ool00`00Oomoo`0cOol000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomo
o`0VOol00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`0bOol000Yoo`04
001oogoo000:Ool01000Oomoogoo0P003Woo0`0017oo0P002Goo0`000goo0`0017oo0P001Goo0`00
0goo0`0000Aoo`00Oomoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool01@00Oomoogoo00000Woo
00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Ool000001Goo0P000Woo00H0
07ooOomoo`00Ool20002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P004Goo00@007ooOol0009oo`03001oogoo00Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo0P001Woo00@007oo0000009oo`03001oogoo
00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`002goo0P002Goo0`000goo00<007ooOol047oo00@007ooOol0009o
o`03001oogoo00Moo`04001oogooOol20002Ool01000Oomoo`000Woo00<007ooOol00goo0P001Woo
00@007oo0000009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo
00@007ooOol000Uoo`04001oogooOol20002Ool01000Oomoo`000Woo00<007ooOol00goo0P000Woo
10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Ao
o`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol0
17oo00@007ooOol000Qoo`80009oo`<0009oo`04001oogoo0002Ool00`00Oomoo`02Ool30002Ool0
0`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomo
o`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003
Ool2000:Ool01000Oomoo`000Woo0P0017oo0`001Goo00@007ooOomoo`D000=oo`8000Ioo`<000Ao
o`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P008goo00<007ooOol02Goo00<007oo
Ool00goo00<007ooOol02Goo0P00<7oo000LOol00`00Oomoo`0POol3000<Ool00`00Oomoo`02Ool0
0`00Oomoo`0:Ool3000^Ool001aoofT000aoo`0077oo00<007ooOol04Woo00<007ooOol04Woo00<0
07ooOol01Woo00@007ooOol000Moo`03001oogoo019oo`03001oogoo019oo`03001oogoo00Yoo`00
77oo0P00<Goo00@007ooOol003ioo`0077oo00<007ooOol0<7oo0`00?goo000LOol2001cOol001ao
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P00
Lgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo079oo`002Woo00@007ooOol0
00Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool0
1000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`D0009oo`8007=oo`00
2Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool0
0`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`80
00]oo`05001oogooOol0001dOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004
Ool00`00Oomoo`03Ool30002Ool2000iOol3000gOol000Yoo`04001oogoo000:Ool01@00Oomoogoo
0000>Woo00<007oo0000=goo0003Ool50002Ool01000Oomoo`001goo1@000Woo0P00>Goo00<007oo
0000=goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo03Moo`05001oogooOol0
000fOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2000hOol01@00Oomoogoo0000=Woo000:
Ool01000Oomoo`002Goo0P000goo00<007ooOol0=goo00D007ooOomoo`0003Ioo`002goo0P002goo
00@007ooOomoo`8003Qoo`03001oogoo009oo`03001oogoo03=oo`0077oo00<007ooOol0=Woo00<0
07ooOol00goo00<007ooOol0<goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00=goo00<007oo
Ool00goo00<007ooOol0<goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00eo
o`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`@0009oo`@000=oo`8000Eoo`D000=oo`8000Ao
o`8000Eoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009o
o`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool01@00Ool007oo00000goo0P0000Eoo`00Oomoo`0000Eoo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Yoo`05001oogooOol0000BOol01000Oomoo`000Woo00<0
07ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool20006Ool200001Goo
001oogoo00001Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`80015oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`8000Ioo`04001oo`000002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo10000goo00@007ooOol0
00Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo0P000Woo10000Woo0P000Woo
00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007oo
Oomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04
Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool30002Ool00`00Oomo
o`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:
Ool00`00Oomoo`03Ool20004Ool20006Ool20002Ool50002Ool30006Ool30004Ool20004Ool20006
Ool30002Ool50003Ool20006Ool001aoo`8003Ioo`03001oogoo00Moo`80035oo`0077oo00<007oo
Ool0;goo0P000goo00<007ooOol02Goo0P00<7oo000LOomY000<Ool001aoo`05001oogooOol00003
Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo00H000Ao
o`05001oogooOol00003Ool00`00Oomoo`030002Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo
009oo`03001oogoo00Yoo`0077oo0P008goo00<007ooOol02Goo00@007ooOomoo`8003ioo`0077oo
00<007ooOol08goo00<007ooOol027oo00<007ooOol0@Goo000LOol2000UOol00`00Oomoo`07Ool0
0`00Oomoo`11Ool001aoo`03001oogoo02Aoo`03001oogoo00Moo`03001oogoo045oo`002goo0P00
17oo00@007ooOomoo`D0009oo`8002Eoo`03001oogoo00Moo`03001oogoo045oo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool00`00Oomoo`0UOol00`00Oomoo`06Ool00`00Oomoo`11Ool000Yo
o`04001oogoo0009Ool00`00Oomoo`02Ool2000VOol00`00Oomoo`05Ool00`00Oomoo`12Ool000Yo
o`04001oogoo000:Ool01@00Oomoogoo0000:7oo00<007ooOol017oo00<007ooOol0@Woo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`8002Moo`03001oogoo00Aoo`03001oogoo049oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0VOol00`00Oomoo`04Ool00`00
Oomoo`12Ool000]oo`8000Uoo`<000=oo`8002Qoo`03001oogoo009oo`03001oogoo04=oo`0077oo
00<007ooOol09goo00<007ooOol00Woo00<007ooOol0@goo000;Ool20004Ool00`00Oomoo`03Ool3
0002Ool2000XOol00`00Oomoo`02Ool00`00Oomoo`13Ool000Yoo`04001oogoo000:Ool01@00Oomo
ogoo0000:Goo00<007ooOol00Woo00<007ooOol0@goo000:Ool01000Oomoo`001goo1@000Woo0P00
:Goo00D007ooOomoo`0004Eoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0X
Ool01000Oomoo`00AWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00:Woo00<007oo0000
AWoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0:Goo0P00Agoo000;Ool2000;Ool01000
Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`80
07=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo
00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo
079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2
001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`80
07=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Mo
o`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3600\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23177 L
.216 .23177 L
.22 .23177 L
.224 .23177 L
.228 .23177 L
.232 .23177 L
.236 .23177 L
.24 .23177 L
.244 .23177 L
.248 .23178 L
.252 .23178 L
.256 .23178 L
.26 .23178 L
.264 .23178 L
.268 .23178 L
.272 .23179 L
.276 .2318 L
.28 .23181 L
.284 .23182 L
.288 .23184 L
.292 .23187 L
.296 .23192 L
.3 .23197 L
.304 .23205 L
.308 .23215 L
.312 .23229 L
.316 .23248 L
.32 .23273 L
.324 .23305 L
.328 .23346 L
.332 .234 L
.336 .23467 L
.34 .2355 L
.344 .23654 L
.348 .23781 L
.352 .23935 L
.356 .24119 L
.36 .24336 L
.364 .24589 L
.368 .24878 L
.372 .25204 L
.376 .25565 L
.38 .25958 L
.384 .26378 L
.388 .26815 L
.392 .2726 L
.396 .27701 L
.4 .2812 L
Mistroke
.404 .285 L
.408 .28821 L
.412 .29065 L
.416 .29212 L
.42 .29247 L
.424 .29159 L
.428 .28944 L
.432 .28605 L
.436 .28152 L
.44 .27603 L
.444 .2698 L
.448 .26313 L
.452 .2563 L
.456 .24962 L
.46 .24335 L
.464 .23775 L
.468 .23298 L
.472 .2292 L
.476 .22646 L
.48 .22479 L
.484 .22414 L
.488 .22442 L
.492 .22551 L
.496 .22722 L
.5 .22938 L
.504 .23176 L
.508 .23413 L
.512 .23629 L
.516 .23801 L
.52 .2391 L
.524 .23939 L
.528 .23874 L
.532 .23708 L
.536 .23434 L
.54 .23057 L
.544 .22581 L
.548 .22021 L
.552 .21395 L
.556 .20726 L
.56 .20044 L
.564 .19377 L
.568 .18754 L
.572 .18205 L
.576 .17751 L
.58 .17411 L
.584 .17196 L
.588 .17108 L
.592 .17142 L
.596 .17289 L
.6 .17533 L
Mistroke
.604 .17855 L
.608 .18235 L
.612 .18655 L
.616 .19095 L
.62 .19541 L
.624 .19979 L
.628 .20399 L
.632 .20792 L
.636 .21153 L
.64 .2148 L
.644 .21769 L
.648 .22022 L
.652 .22239 L
.656 .22423 L
.66 .22577 L
.664 .22704 L
.668 .22808 L
.672 .22892 L
.676 .22959 L
.68 .23012 L
.684 .23053 L
.688 .23086 L
.692 .2311 L
.696 .23129 L
.7 .23143 L
.704 .23153 L
.708 .23161 L
.712 .23167 L
.716 .23171 L
.72 .23174 L
.724 .23176 L
.728 .23177 L
.732 .23178 L
.736 .23179 L
.74 .2318 L
.744 .2318 L
.748 .2318 L
.752 .2318 L
.756 .23181 L
.76 .23181 L
.764 .23181 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35316 L
.244 .35316 L
.248 .35316 L
.252 .35315 L
.256 .35315 L
.26 .35315 L
.264 .35314 L
.268 .35312 L
.272 .35311 L
.276 .35308 L
.28 .35304 L
.284 .35299 L
.288 .35291 L
.292 .35281 L
.296 .35266 L
.3 .35246 L
.304 .35218 L
.308 .35181 L
.312 .3513 L
.316 .35064 L
.32 .34976 L
.324 .34862 L
.328 .34715 L
.332 .34526 L
.336 .34286 L
.34 .33986 L
.344 .33614 L
.348 .33158 L
.352 .32608 L
.356 .31951 L
.36 .31177 L
.364 .30277 L
.368 .29245 L
.372 .28079 L
.376 .26784 L
.38 .25372 L
.384 .23864 L
.388 .22291 L
.392 .20694 L
.396 .19123 L
.4 .17635 L
Mistroke
.404 .16294 L
.408 .15163 L
.412 .14307 L
.416 .13783 L
.42 .13644 L
.424 .13926 L
.428 .14654 L
.432 .15828 L
.436 .17427 L
.44 .19403 L
.444 .2168 L
.448 .24158 L
.452 .26715 L
.456 .29219 L
.46 .31536 L
.464 .33547 L
.468 .35158 L
.472 .36312 L
.476 .37 L
.48 .37258 L
.484 .37164 L
.488 .36831 L
.492 .36388 L
.496 .3596 L
.5 .35656 L
.504 .35546 L
.508 .35656 L
.512 .3596 L
.516 .36388 L
.52 .36831 L
.524 .37164 L
.528 .37258 L
.532 .37 L
.536 .36313 L
.54 .35158 L
.544 .33547 L
.548 .31536 L
.552 .29219 L
.556 .26715 L
.56 .24158 L
.564 .2168 L
.568 .19403 L
.572 .17427 L
.576 .15828 L
.58 .14653 L
.584 .13926 L
.588 .13643 L
.592 .13783 L
.596 .14306 L
.6 .15163 L
Mistroke
.604 .16293 L
.608 .17635 L
.612 .19123 L
.616 .20694 L
.62 .22291 L
.624 .23864 L
.628 .25372 L
.632 .26784 L
.636 .28079 L
.64 .29245 L
.644 .30277 L
.648 .31177 L
.652 .31951 L
.656 .32608 L
.66 .33158 L
.664 .33614 L
.668 .33986 L
.672 .34286 L
.676 .34526 L
.68 .34715 L
.684 .34862 L
.688 .34976 L
.692 .35064 L
.696 .3513 L
.7 .35181 L
.704 .35218 L
.708 .35246 L
.712 .35266 L
.716 .35281 L
.72 .35291 L
.724 .35299 L
.728 .35304 L
.732 .35308 L
.736 .35311 L
.74 .35312 L
.744 .35314 L
.748 .35315 L
.752 .35315 L
.756 .35315 L
.76 .35316 L
.764 .35316 L
.768 .35316 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23176 L
.236 .23176 L
.24 .23176 L
.244 .23177 L
.248 .23177 L
.252 .23177 L
.256 .23177 L
.26 .23178 L
.264 .23178 L
.268 .2318 L
.272 .23181 L
.276 .23183 L
.28 .23186 L
.284 .23191 L
.288 .23197 L
.292 .23206 L
.296 .23219 L
.3 .23236 L
.304 .23259 L
.308 .2329 L
.312 .23332 L
.316 .23388 L
.32 .23461 L
.324 .23558 L
.328 .23682 L
.332 .23841 L
.336 .24042 L
.34 .24293 L
.344 .24604 L
.348 .24986 L
.352 .25447 L
.356 .25999 L
.36 .26651 L
.364 .2741 L
.368 .28279 L
.372 .29258 L
.376 .30343 L
.38 .31524 L
.384 .32784 L
.388 .34098 L
.392 .35436 L
.396 .36758 L
.4 .38017 L
Mistroke
.404 .39157 L
.408 .40122 L
.412 .40852 L
.416 .41291 L
.42 .41394 L
.424 .41128 L
.428 .40479 L
.432 .39458 L
.436 .38094 L
.44 .36442 L
.444 .34572 L
.448 .32568 L
.452 .30519 L
.456 .28515 L
.46 .26638 L
.464 .24961 L
.468 .23539 L
.472 .22411 L
.476 .21597 L
.48 .21101 L
.484 .20911 L
.488 .20998 L
.492 .21322 L
.496 .21834 L
.5 .22475 L
.504 .23181 L
.508 .23888 L
.512 .24529 L
.516 .25041 L
.52 .25365 L
.524 .25452 L
.528 .25261 L
.532 .24766 L
.536 .23952 L
.54 .22824 L
.544 .21402 L
.548 .19724 L
.552 .17848 L
.556 .15844 L
.56 .13795 L
.564 .1179 L
.568 .0992 L
.572 .08268 L
.576 .06905 L
.58 .05883 L
.584 .05235 L
.588 .04968 L
.592 .05071 L
.596 .0551 L
.6 .0624 L
Mistroke
.604 .07205 L
.608 .08346 L
.612 .09604 L
.616 .10926 L
.62 .12264 L
.624 .13579 L
.628 .14838 L
.632 .16019 L
.636 .17105 L
.64 .18084 L
.644 .18953 L
.648 .19711 L
.652 .20363 L
.656 .20916 L
.66 .21377 L
.664 .21758 L
.668 .22069 L
.672 .22321 L
.676 .22522 L
.68 .22681 L
.684 .22805 L
.688 .22901 L
.692 .22975 L
.696 .23031 L
.7 .23073 L
.704 .23104 L
.708 .23127 L
.712 .23144 L
.716 .23157 L
.72 .23166 L
.724 .23172 L
.728 .23176 L
.732 .2318 L
.736 .23182 L
.74 .23183 L
.744 .23184 L
.748 .23185 L
.752 .23186 L
.756 .23186 L
.76 .23186 L
.764 .23186 L
.768 .23186 L
.772 .23186 L
.776 .23186 L
.78 .23186 L
.784 .23186 L
.788 .23186 L
.792 .23186 L
.796 .23186 L
.8 .23186 L
Mistroke
.804 .23186 L
.808 .23186 L
.812 .23186 L
.816 .23186 L
.82 .23186 L
.824 .23186 L
.828 .23186 L
.832 .23186 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02Ool40002Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogooOol50002Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2
0009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009o
o`04001oogoo0004Ool20003Ool01000Oomoogoo0P0000Eoo`00Oomoo`0000Aoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol0
00Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00<0
07ooOol0200000=oo`0000001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool2000gOol20007Ool00`00Oomoo`0`Ool001aoo`03001oogoo02moo`03001oogoo00Aoo`03001o
ogoo00Ioo`<0031oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01P00Oomoogoo001oo`<000Aoo`09001oogooOol0
07oo001oo`00009oo`@00003Ool007oo009oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00
Oomoo`0:Ool001aoo`8002Aoo`8000Moo`03001oogoo04=oo`0077oo00<007ooOol097oo00<007oo
Ool01Goo00<007ooOol0@goo000LOol2000VOol20004Ool20015Ool001aoo`03001oogoo02Ioo`80
009oo`8004Ioo`002goo0P0017oo00@007ooOomoo`D0009oo`8002Qoo`@004Moo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool00`00Oomoo`0XOol20018Ool000Yoo`04001oogoo0009Ool00`00
Oomoo`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool2
0004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000
M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol0
00=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@0
07ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00@007ooOomoo`8007=oo`0077oo
00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001o
ogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03
001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
07=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uo
o`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo
009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Mo
o`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]o
o`8000Aoo`03001oogoo009oo`<007Qoo`002Woo00@007ooOol000Moo`05001oogooOol0001gOol0
00=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`00
27oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000]oo`8000Uoo`<0
00=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo10000goo0P00Lgoo000:Ool01000Oomoo`001goo00<007ooOol017oo00<0
07ooOol0LWoo000:Ool01000Oomoo`0027oo00<007ooOol00goo0P00Lgoo000;Ool2000:Ool20003
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0:7oo0P0047oo0P00=Woo000;Ool2
0004Ool00`00Oomoo`03Ool30002Ool2000XOol00`00Ool0000?Ool00`00Ool0000fOol000Yoo`04
001oogoo000:Ool01@00Oomoogoo0000:Goo00@007ooOol000ioo`04001oogoo000eOol000=oo`D0
009oo`04001oogoo0007Ool50002Ool00`00Oomoo`0WOol01000Oomoo`003Goo00D007ooOomoo`00
03Eoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool2000XOol01000Oomoo`003Goo00D007oo
Oomoo`0003Eoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo02Ioo`03001oogoo
009oo`03001oogoo00Yoo`05001oogooOol0000eOol000Yoo`04001oogoo0009Ool20003Ool2000W
Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01@00Oomoogoo0000=Goo000;Ool2000;Ool01@00Oomo
ogoo0000:7oo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol0<Woo000L
Ool2000VOol00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0bOol001ao
o`03001oogoo02Eoo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo039o
o`002goo0P0017oo00@007ooOomoo`D0009oo`8002Ioo`03001oogoo00Aoo`03001oogoo00Qoo`03
001oogoo00Aoo`03001oogoo035oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomo
o`0UOol00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`0aOol000=oo`D0
009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomo
o`08Ool00`00Oomoo`04Ool00`00Oomoo`0aOol000Yoo`04001oogoo000:Ool01000Oomoogoo0P00
3Woo0`0017oo0P002Goo0`000Woo00@007oo000000Aoo`8000Eoo`<00003Ool007oo00<000=oo`<0
00Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`0<Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`04001o
ogooOol20002Ool00`00Oomoo`0200000goo001oo`04Ool00`00Oomoo`020003Ool01000Oomoo`00
0Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`80015oo`04001oogoo0002Ool00`00Oomoo`07Ool01000Oomoogoo0P000Woo00<0
07ooOol00P0000=oo`00Ool017oo00<007oo00001Goo00@007ooOol0009oo`03001oogoo00Aoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00=oo`002goo0P002Goo0`000goo00<007ooOol047oo00@007ooOol0009oo`03001o
ogoo00Moo`06001oogoo001oo`000Woo00<007ooOol00P0000=oo`00Ool017oo00<007oo00001Goo
00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo
00@007ooOol000Uoo`06001oogoo001oo`000Woo00<007ooOol00P0000=oo`00Ool017oo00@007oo
001oo`@000=oo`800003Ool007oo00=oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<0
07ooOol017oo00@007ooOol000Qoo`800005Ool007ooOol00002Ool01@00Oomoo`00Ool00P0017oo
0P0000Aoo`00Ool000Ioo`@000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0
00Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo
0P002Woo00<007oo00000goo0P0017oo0P001Woo00@007oo001oo`D000=oo`8000Ioo`<000Aoo`80
00Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P008Woo00<007ooOol02Goo00<007ooOol0
1Goo00<007ooOol02Goo0P00;goo000LOol00`00Oomoo`0OOol2000<Ool00`00Oomoo`05Ool00`00
Oomoo`0:Ool3000]Ool001aoofT000aoo`0077oo00<007ooOol04Woo00<007ooOol04Woo00<007oo
Ool017oo00@007oo001oo`800003Ool007oo00Aoo`03001oogoo019oo`03001oogoo019oo`03001o
ogoo00Yoo`0077oo0P00;goo0P000goo0P00?Goo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogooOol50002Ool2
001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0LWoo000:Ool01000Oomo
o`002Goo00<007ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yo
o`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo
000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qo
o`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo
0P002goo00D007ooOomoo`0007Aoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`80
00Aoo`03001oogoo00=oo`<0009oo`8003]oo`8003Ioo`002Woo00@007ooOol000Yoo`05001oogoo
Ool0000kOol00`00Ool0000fOol000=oo`D0009oo`04001oogoo0007Ool50002Ool2000jOol01000
Oomoo`00=Goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo03Qoo`05001oogoo
Ool0000eOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2000iOol01@00Oomoogoo0000=Goo
000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0>7oo00D007ooOomoo`0003Eoo`002goo0P00
2goo00@007ooOomoo`8003Uoo`03001oogoo009oo`03001oogoo039oo`0077oo00<007ooOol0>7oo
00<007ooOol00Woo00<007ooOol0<Woo000;Ool20004Ool01000Oomoogoo1@000Woo0P00>Goo00<0
07ooOol00Woo00<007ooOol0<Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo
00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<00003Ool007oo00<0009oo`04001oo`00
0005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo
0009Ool00`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P000goo00@007oo0000009oo`03
001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001o
o`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Yoo`05001oogooOol0
000BOol01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool01000Oomoo`0017oo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`0017oo00@0
07ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool01000Ool007oo10000goo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007oo
Ool000Eoo`002goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`8000Ao
o`04001oogoo0002Ool01000Oomoo`0017oo0P0000Aoo`00Ool000Ioo`800003Ool007oo00=oo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo
00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P0017oo
0P001Woo00@007oo001oo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`80
00Ioo`0077oo0P00<7oo0P001Goo00<007ooOol027oo00<007ooOol0;Woo000LOol00`00Oomoo`0^
Ool00`00Ool00004Ool00`00Oomoo`09Ool2000_Ool001aoofT000aoo`0077oo00D007ooOomoo`00
00=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo00001000
00=oo`00Ool00goo00D007ooOomoo`00009oo`80009oo`800004Ool007oo0003Ool01@00Oomoogoo
00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol2000QOol2000;Ool00`00Oomoo`02Ool3
000mOol001aoo`03001oogoo029oo`03001oogoo00Qoo`03001oogoo00=oo`8003eoo`0077oo0P00
8goo00<007ooOol027oo00<007ooOol0@Woo000LOol00`00Oomoo`0SOol00`00Oomoo`07Ool00`00
Oomoo`12Ool000]oo`8000Aoo`04001oogooOol50002Ool2000TOol00`00Oomoo`06Ool00`00Oomo
o`13Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol097oo00<007ooOol01Goo
00<007ooOol0@goo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P009Goo00<007ooOol01Goo
00<007ooOol0@goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0002Ioo`03001oogoo00Eoo`03
001oogoo04=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000VOol00`00Oomoo`04
Ool00`00Oomoo`13Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol09Goo
00<007ooOol017oo00<007ooOol0@goo000;Ool20009Ool30003Ool2000VOol00`00Oomoo`03Ool0
0`00Oomoo`14Ool001aoo`03001oogoo02Ioo`03001oogoo009oo`03001oogoo04Aoo`002goo0P00
17oo00<007ooOol00goo0`000Woo0P009goo00<007ooOol00Woo00<007ooOol0A7oo000:Ool01000
Oomoo`002Woo00D007ooOomoo`0002Qoo`03001oogoo009oo`03001oogoo04Aoo`002Woo00@007oo
Ool000Moo`D0009oo`8002Qoo`04001oogoo0017Ool000Yoo`04001oogoo0007Ool01000Oomoo`00
0goo00<007ooOol09goo00@007ooOol004Moo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`80
02Qoo`03001oo`0004Qoo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo02Qoo`8004Qoo`00
2goo0P002goo00@007ooOomoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomo
o`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Mo
o`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo
00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo
000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo
000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol0
0Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol0
0`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3640\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23177 L
.216 .23177 L
.22 .23177 L
.224 .23177 L
.228 .23177 L
.232 .23178 L
.236 .23178 L
.24 .23178 L
.244 .23178 L
.248 .23178 L
.252 .23178 L
.256 .23179 L
.26 .23179 L
.264 .2318 L
.268 .23181 L
.272 .23182 L
.276 .23185 L
.28 .23188 L
.284 .23192 L
.288 .23197 L
.292 .23205 L
.296 .23216 L
.3 .2323 L
.304 .23249 L
.308 .23274 L
.312 .23306 L
.316 .23347 L
.32 .234 L
.324 .23468 L
.328 .23552 L
.332 .23656 L
.336 .23783 L
.34 .23937 L
.344 .2412 L
.348 .24337 L
.352 .24588 L
.356 .24876 L
.36 .25201 L
.364 .25561 L
.368 .25954 L
.372 .26373 L
.376 .26811 L
.38 .27256 L
.384 .27694 L
.388 .28111 L
.392 .28487 L
.396 .28805 L
.4 .29047 L
Mistroke
.404 .29196 L
.408 .29236 L
.412 .29159 L
.416 .28956 L
.42 .2863 L
.424 .28186 L
.428 .27638 L
.432 .27009 L
.436 .26325 L
.44 .25619 L
.444 .24927 L
.448 .24284 L
.452 .2372 L
.456 .23259 L
.46 .22916 L
.464 .22694 L
.468 .22586 L
.472 .22574 L
.476 .22633 L
.48 .22735 L
.484 .22853 L
.488 .22965 L
.492 .23054 L
.496 .23117 L
.5 .23154 L
.504 .23178 L
.508 .23201 L
.512 .23238 L
.516 .23299 L
.52 .23388 L
.524 .23498 L
.528 .23616 L
.532 .23718 L
.536 .23777 L
.54 .23765 L
.544 .23658 L
.548 .23438 L
.552 .23096 L
.556 .22636 L
.56 .22073 L
.564 .2143 L
.568 .20738 L
.572 .20033 L
.576 .19348 L
.58 .18718 L
.584 .1817 L
.588 .17726 L
.592 .17399 L
.596 .17196 L
.6 .17118 L
Mistroke
.604 .17159 L
.608 .17307 L
.612 .17549 L
.616 .17867 L
.62 .18244 L
.624 .18661 L
.628 .191 L
.632 .19545 L
.636 .19983 L
.64 .20403 L
.644 .20796 L
.648 .21157 L
.652 .21482 L
.656 .2177 L
.66 .22021 L
.664 .22238 L
.668 .22422 L
.672 .22576 L
.676 .22703 L
.68 .22807 L
.684 .22891 L
.688 .22958 L
.692 .23011 L
.696 .23053 L
.7 .23085 L
.704 .23109 L
.708 .23128 L
.712 .23142 L
.716 .23153 L
.72 .23161 L
.724 .23167 L
.728 .23171 L
.732 .23174 L
.736 .23176 L
.74 .23177 L
.744 .23178 L
.748 .23179 L
.752 .2318 L
.756 .2318 L
.76 .2318 L
.764 .2318 L
.768 .23181 L
.772 .23181 L
.776 .23181 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35316 L
.232 .35316 L
.236 .35316 L
.24 .35315 L
.244 .35315 L
.248 .35314 L
.252 .35314 L
.256 .35312 L
.26 .3531 L
.264 .35308 L
.268 .35304 L
.272 .35299 L
.276 .35291 L
.28 .3528 L
.284 .35265 L
.288 .35245 L
.292 .35217 L
.296 .35179 L
.3 .35129 L
.304 .35062 L
.308 .34974 L
.312 .34859 L
.316 .3471 L
.32 .34521 L
.324 .34281 L
.328 .33981 L
.332 .33609 L
.336 .33155 L
.34 .32606 L
.344 .3195 L
.348 .31176 L
.352 .30276 L
.356 .29244 L
.36 .28081 L
.364 .26791 L
.368 .25387 L
.372 .23889 L
.376 .22326 L
.38 .20737 L
.384 .19168 L
.388 .17676 L
.392 .16324 L
.396 .15178 L
.4 .14308 L
Mistroke
.404 .13777 L
.408 .13639 L
.412 .13935 L
.416 .14681 L
.42 .15872 L
.424 .17476 L
.428 .19435 L
.432 .21668 L
.436 .24076 L
.44 .2655 L
.444 .28978 L
.448 .31252 L
.452 .33275 L
.456 .34972 L
.46 .36287 L
.464 .37194 L
.468 .37692 L
.472 .3781 L
.476 .37601 L
.48 .37139 L
.484 .36515 L
.488 .35825 L
.492 .35166 L
.496 .34624 L
.5 .3427 L
.504 .34147 L
.508 .3427 L
.512 .34624 L
.516 .35166 L
.52 .35825 L
.524 .36515 L
.528 .37139 L
.532 .37601 L
.536 .3781 L
.54 .37692 L
.544 .37194 L
.548 .36287 L
.552 .34972 L
.556 .33275 L
.56 .31252 L
.564 .28978 L
.568 .2655 L
.572 .24076 L
.576 .21668 L
.58 .19435 L
.584 .17476 L
.588 .15872 L
.592 .1468 L
.596 .13934 L
.6 .13639 L
Mistroke
.604 .13776 L
.608 .14307 L
.612 .15178 L
.616 .16323 L
.62 .17676 L
.624 .19168 L
.628 .20737 L
.632 .22326 L
.636 .23889 L
.64 .25387 L
.644 .26791 L
.648 .28081 L
.652 .29244 L
.656 .30275 L
.66 .31176 L
.664 .31949 L
.668 .32606 L
.672 .33155 L
.676 .33609 L
.68 .33981 L
.684 .34281 L
.688 .34521 L
.692 .3471 L
.696 .34859 L
.7 .34974 L
.704 .35062 L
.708 .35129 L
.712 .35179 L
.716 .35217 L
.72 .35245 L
.724 .35265 L
.728 .3528 L
.732 .35291 L
.736 .35299 L
.74 .35304 L
.744 .35308 L
.748 .3531 L
.752 .35312 L
.756 .35314 L
.76 .35314 L
.764 .35315 L
.768 .35315 L
.772 .35316 L
.776 .35316 L
.78 .35316 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23176 L
.224 .23176 L
.228 .23176 L
.232 .23177 L
.236 .23177 L
.24 .23177 L
.244 .23177 L
.248 .23178 L
.252 .23178 L
.256 .2318 L
.26 .23181 L
.264 .23183 L
.268 .23187 L
.272 .23191 L
.276 .23198 L
.28 .23207 L
.284 .23219 L
.288 .23236 L
.292 .2326 L
.296 .23291 L
.3 .23334 L
.304 .2339 L
.308 .23464 L
.312 .2356 L
.316 .23685 L
.32 .23844 L
.324 .24045 L
.328 .24297 L
.332 .24609 L
.336 .24991 L
.34 .25453 L
.344 .26004 L
.348 .26653 L
.352 .27408 L
.356 .28272 L
.36 .29248 L
.364 .3033 L
.368 .3151 L
.372 .3277 L
.376 .34085 L
.38 .35422 L
.384 .36739 L
.388 .3799 L
.392 .3912 L
.396 .40075 L
.4 .408 L
Mistroke
.404 .41243 L
.408 .41363 L
.412 .41126 L
.416 .40516 L
.42 .39532 L
.424 .38196 L
.428 .3655 L
.432 .34658 L
.436 .32605 L
.44 .30488 L
.444 .28414 L
.448 .26486 L
.452 .24797 L
.456 .23419 L
.46 .22396 L
.464 .21737 L
.468 .21418 L
.472 .21386 L
.476 .21566 L
.48 .21874 L
.484 .22228 L
.488 .2256 L
.492 .22825 L
.496 .23008 L
.5 .23116 L
.504 .23181 L
.508 .23247 L
.512 .23355 L
.516 .23537 L
.52 .23803 L
.524 .24135 L
.528 .24489 L
.532 .24797 L
.536 .24977 L
.54 .24945 L
.544 .24626 L
.548 .23967 L
.552 .22943 L
.556 .21566 L
.56 .19877 L
.564 .17949 L
.568 .15874 L
.572 .13758 L
.576 .11704 L
.58 .09813 L
.584 .08167 L
.588 .0683 L
.592 .05847 L
.596 .05236 L
.6 .04999 L
Mistroke
.604 .05119 L
.608 .05563 L
.612 .06288 L
.616 .07242 L
.62 .08373 L
.624 .09623 L
.628 .10941 L
.632 .12278 L
.636 .13593 L
.64 .14853 L
.644 .16032 L
.648 .17115 L
.652 .1809 L
.656 .18955 L
.66 .19709 L
.664 .20359 L
.668 .2091 L
.672 .21372 L
.676 .21754 L
.68 .22066 L
.684 .22318 L
.688 .22519 L
.692 .22678 L
.696 .22802 L
.7 .22899 L
.704 .22973 L
.708 .23029 L
.712 .23072 L
.716 .23103 L
.72 .23127 L
.724 .23144 L
.728 .23156 L
.732 .23165 L
.736 .23172 L
.74 .23176 L
.744 .23179 L
.748 .23182 L
.752 .23183 L
.756 .23184 L
.76 .23185 L
.764 .23185 L
.768 .23186 L
.772 .23186 L
.776 .23186 L
.78 .23186 L
.784 .23186 L
.788 .23186 L
.792 .23186 L
.796 .23186 L
.8 .23186 L
Mistroke
.804 .23186 L
.808 .23186 L
.812 .23186 L
.816 .23186 L
.82 .23186 L
.824 .23186 L
.828 .23186 L
.832 .23186 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`03Ool30002Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogooOol4000017oo001oo`000Woo00<007ooOol00Woo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`00
1Goo000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@0
07ooOol0009oo`04001oogoo0004Ool20003Ool20004Ool20002Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Io
o`04001oogooOol50002Ool30006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool0
01aoo`8003Uoo`03001oogoo00Eoo`03001oogoo02moo`0077oo00<007ooOol0=goo00<007ooOol0
1goo0P00;goo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`04001oogooOol50004Ool01000Oomoogoo0P000Woo00@0
07ooOomoo`D000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`80
02=oo`03001oogoo00Ioo`03001oogoo04Aoo`0077oo00<007ooOol08goo00<007ooOol01Goo00<0
07ooOol0A7oo000LOol2000UOol00`00Oomoo`03Ool00`00Oomoo`15Ool001aoo`03001oogoo02Eo
o`05001oogooOol00018Ool000]oo`8000Aoo`04001oogooOol50002Ool2000WOol40018Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol09goo00<007ooOol0B7oo000:Ool01000
Oomoo`002Goo00<007ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Ao
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001o
ogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo
00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol0
00Moo`04001oogoo0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2
001cOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`04001oogoo
Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00
Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo
000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=o
o`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo
000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<0
07ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3001hOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo0000Mgoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`00
2Woo00@007ooOol000Qoo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo
000;Ool20009Ool30003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;
Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`@000=oo`8007=oo`002Woo00@007ooOol000Moo`03
001oogoo00Aoo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`8007=oo`00
2goo0P002Woo0P000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo02Moo`80019o
o`8003Eoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P009goo00<007oo00004Goo00<007oo
0000=Goo000:Ool01000Oomoo`002Woo00D007ooOomoo`0002Qoo`04001oogoo000@Ool01000Oomo
o`00=7oo0003Ool50002Ool01000Oomoo`001goo1@000Woo00<007ooOol09Woo00@007ooOol0011o
o`04001oogoo000dOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P009Woo00D007ooOomo
o`00011oo`04001oogoo000dOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`0U
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0<Goo000:Ool01000Oomoo`002Goo
0P000goo0P009Woo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo035oo`002goo0P00
2goo00D007ooOomoo`0002Ioo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03001o
ogoo035oo`0077oo0P009Goo00<007ooOol00goo00<007ooOol037oo00<007ooOol00goo00<007oo
Ool0<7oo000LOol00`00Oomoo`0TOol00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool0
0`00Oomoo`0`Ool000]oo`8000Aoo`04001oogooOol50002Ool2000UOol00`00Oomoo`03Ool00`00
Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0`Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00<007ooOol097oo00<007ooOol00goo00<007ooOol02goo00<007ooOol017oo00<007ooOol0
<7oo0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo00<007ooOol08goo00<007ooOol0
1Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol0<7oo000:Ool01000Oomoo`002Woo00@0
07ooOomoo`8000ioo`<000Aoo`8000Uoo`<00004Ool007ooOol20003Ool30005Ool30002Ool40004
Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol037oo00D007ooOomoo`00009oo`04001oogoo0009Ool0
0`00Ool00002Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool00`00Oomo
o`0200000goo001oo`04Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00
Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo0P004Goo00@007ooOol0009oo`03001oogoo00Moo`03001oo`00009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`03001oogoo00800003Ool007oo00Eo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00=oo`002goo0P002Goo0`000goo00<007ooOol047oo00@007ooOol0009oo`03
001oogoo00Moo`03001oo`00009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`00
00=oo`05001oogoo001oo`020007Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo
00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04
001oogoo0009Ool00`00Ool00002Ool01000Oomoo`000Woo0P0000=oo`00Ool017oo00<007ooOol0
1@000goo00@007oo000000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Ao
o`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol0
17oo00@007ooOol000Qoo`<000=oo`04001oogoo0002Ool200000goo001oo`03Ool20002Ool20006
Ool01000Ool0000017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L0
07ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool0
0`00Oomoo`03Ool20004Ool20006Ool00`00Oomoo`060003Ool30005Ool30004Ool20004Ool20006
Ool30002Ool50003Ool20006Ool001aoo`80025oo`03001oogoo00Uoo`03001oogoo00Qoo`03001o
ogoo00Uoo`03001oogoo02aoo`0077oo00<007ooOol07Goo0`0037oo00@007ooOomoo`<000Aoo`03
001oogoo00Uoo`<002aoo`0077ooJ@0037oo000LOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00
Oomoo`03Ool00`00Ool00003Ool01000Oomoo`0017oo00<007ooOol04Woo00<007ooOol04Woo00<0
07ooOol02Woo000LOol2000^Ool30004Ool2000lOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002goo0P0017oo00@007ooOomoo`D0009o
o`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0009Ool00`00Oomoo`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`00
2Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool50002Ool2001c
Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
27oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;
Ool2000;Ool01@00Oomoogoo0000M7oo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00<007ooOol00goo0`000Woo0P00?7oo0P00=Goo000:Ool01000Oomoo`002Woo00D007oo
Oomoo`0003aoo`03001oo`0003Eoo`000goo1@000Woo00@007ooOol000Moo`D0009oo`8003]oo`04
001oogoo000dOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0>Woo00@007oo
Ool003Aoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8003]oo`05001oogooOol0000cOol0
00Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`0iOol00`00Oomoo`02Ool00`00Oomoo`0aOol0
00]oo`8000]oo`04001oogooOol2000jOol00`00Oomoo`02Ool00`00Oomoo`0aOol001aoo`03001o
ogoo03Uoo`03001oogoo00=oo`03001oogoo031oo`002goo0P0017oo00@007ooOomoo`D0009oo`80
03Yoo`03001oogoo00=oo`03001oogoo031oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30002Ool40003Ool30005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00D007ooOomoo`0000=oo`03001oogoo00800003Ool007oo00Eoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol0
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00<0
07ooOol00P0000=oo`00Ool01Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Ool0000017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomo
o`001Goo000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo
00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Ool0000017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool0
1000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool2
0006Ool00`00Oomoo`060003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006
Ool001aoo`8003Qoo`03001oogoo00Qoo`03001oogoo02eoo`0077oo00<007ooOol0;Goo0`001goo
00<007ooOol02Goo00<007ooOol0;7oo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`H0009oo`03001oogoo009oo`04
001oogooOol20002Ool00`00Oomoo`020002Ool20003Ool01@00Oomoogoo00000goo00<007ooOol0
0Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol0
0Woo00<007ooOol02Woo000LOol2000POol2000;Ool00`00Oomoo`05Ool2000lOol001aoo`03001o
ogoo021oo`8000Yoo`03001oogoo04=oo`0077oo0P008Woo00<007ooOol027oo00<007ooOol0@goo
000LOol00`00Oomoo`0ROol00`00Oomoo`07Ool00`00Oomoo`13Ool000]oo`8000Aoo`04001oogoo
Ool50002Ool2000SOol00`00Oomoo`06Ool00`00Oomoo`14Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00<007ooOol08Woo00<007ooOol01Woo00<007ooOol0A7oo000:Ool01000Oomoo`00
2Goo00<007ooOol00Woo0P0097oo00<007ooOol01Goo00<007ooOol0A7oo000:Ool01000Oomoo`00
2Woo00D007ooOomoo`0002Eoo`03001oogoo00Eoo`03001oogoo04Aoo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2000UOol00`00Oomoo`03Ool00`00Oomoo`15Ool000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol097oo00<007ooOol00goo00<007ooOol0AGoo000;
Ool20009Ool30003Ool2000UOol00`00Oomoo`03Ool00`00Oomoo`15Ool001aoo`03001oogoo02Ao
o`03001oogoo00=oo`03001oogoo04Eoo`002goo0P0017oo00<007ooOol00goo0`000Woo0P009Woo
00D007ooOomoo`0004Qoo`002Woo00@007ooOol000Yoo`05001oogooOol0000WOol01@00Oomoogoo
0000B7oo000:Ool01000Oomoo`001goo1@000Woo0P009Woo00D007ooOomoo`0004Qoo`002Woo00@0
07ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0VOol01000Oomoo`00B7oo000:Ool01000Oomo
o`0027oo00<007oo00000goo0P009goo00<007oo0000BGoo000:Ool01000Oomoo`002Goo0P000goo
00<007ooOol09goo0P00BGoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1b
Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00
Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<0
07ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;
Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo
0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00
Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007oo
Ool0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0
Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3680\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23177 L
.216 .23177 L
.22 .23178 L
.224 .23178 L
.228 .23178 L
.232 .23178 L
.236 .23178 L
.24 .23178 L
.244 .23179 L
.248 .23179 L
.252 .2318 L
.256 .23181 L
.26 .23183 L
.264 .23185 L
.268 .23188 L
.272 .23192 L
.276 .23198 L
.28 .23206 L
.284 .23216 L
.288 .23231 L
.292 .2325 L
.296 .23274 L
.3 .23307 L
.304 .23348 L
.308 .23402 L
.312 .23469 L
.316 .23553 L
.32 .23657 L
.324 .23784 L
.328 .23938 L
.332 .24121 L
.336 .24337 L
.34 .24588 L
.344 .24875 L
.348 .25199 L
.352 .25559 L
.356 .2595 L
.36 .26367 L
.364 .26803 L
.368 .27246 L
.372 .27683 L
.376 .28099 L
.38 .28477 L
.384 .28797 L
.388 .29041 L
.392 .29192 L
.396 .29235 L
.4 .29158 L
Mistroke
.404 .28956 L
.408 .28629 L
.412 .28186 L
.416 .27642 L
.42 .27019 L
.424 .26345 L
.428 .25649 L
.432 .24965 L
.436 .24324 L
.44 .23753 L
.444 .23276 L
.448 .22909 L
.452 .22658 L
.456 .22523 L
.46 .22494 L
.464 .22553 L
.468 .22677 L
.472 .2284 L
.476 .23013 L
.48 .23171 L
.484 .23293 L
.488 .23365 L
.492 .23382 L
.496 .23348 L
.5 .23274 L
.504 .23178 L
.508 .23082 L
.512 .23008 L
.516 .22973 L
.52 .22988 L
.524 .2306 L
.528 .23181 L
.532 .23338 L
.536 .23511 L
.54 .23673 L
.544 .23798 L
.548 .23858 L
.552 .23829 L
.556 .23695 L
.56 .23445 L
.564 .23078 L
.568 .22603 L
.572 .22033 L
.576 .21392 L
.58 .20708 L
.584 .20013 L
.588 .19338 L
.592 .18714 L
.596 .1817 L
.6 .17727 L
Mistroke
.604 .174 L
.608 .17197 L
.612 .17119 L
.616 .17162 L
.62 .17313 L
.624 .17557 L
.628 .17878 L
.632 .18255 L
.636 .18672 L
.64 .1911 L
.644 .19553 L
.648 .19989 L
.652 .20407 L
.656 .20799 L
.66 .21158 L
.664 .21483 L
.668 .2177 L
.672 .22021 L
.676 .22237 L
.68 .22421 L
.684 .22574 L
.688 .22701 L
.692 .22805 L
.696 .22889 L
.7 .22957 L
.704 .2301 L
.708 .23052 L
.712 .23084 L
.716 .23109 L
.72 .23128 L
.724 .23142 L
.728 .23153 L
.732 .2316 L
.736 .23166 L
.74 .23171 L
.744 .23174 L
.748 .23176 L
.752 .23177 L
.756 .23178 L
.76 .23179 L
.764 .2318 L
.768 .2318 L
.772 .2318 L
.776 .2318 L
.78 .23181 L
.784 .23181 L
.788 .23181 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35316 L
.22 .35316 L
.224 .35316 L
.228 .35315 L
.232 .35315 L
.236 .35314 L
.24 .35314 L
.244 .35312 L
.248 .3531 L
.252 .35308 L
.256 .35304 L
.26 .35298 L
.264 .3529 L
.268 .3528 L
.272 .35264 L
.276 .35244 L
.28 .35216 L
.284 .35178 L
.288 .35127 L
.292 .3506 L
.296 .34971 L
.3 .34855 L
.304 .34707 L
.308 .34517 L
.312 .34276 L
.316 .33976 L
.32 .33605 L
.324 .3315 L
.328 .32601 L
.332 .31945 L
.336 .31173 L
.34 .30276 L
.344 .29248 L
.348 .28089 L
.352 .26804 L
.356 .25404 L
.36 .2391 L
.364 .22349 L
.368 .20762 L
.372 .19196 L
.376 .17708 L
.38 .1636 L
.384 .15219 L
.388 .14351 L
.392 .13816 L
.396 .13667 L
.4 .13943 L
Mistroke
.404 .14663 L
.408 .15827 L
.412 .17408 L
.416 .19355 L
.42 .21592 L
.424 .2402 L
.428 .26527 L
.432 .2899 L
.436 .31289 L
.44 .33317 L
.444 .3499 L
.448 .36255 L
.452 .37093 L
.456 .37526 L
.46 .37606 L
.464 .37409 L
.468 .37027 L
.472 .36551 L
.476 .36062 L
.48 .35623 L
.484 .35269 L
.488 .35014 L
.492 .3485 L
.496 .34758 L
.5 .34714 L
.504 .34702 L
.508 .34714 L
.512 .34758 L
.516 .3485 L
.52 .35014 L
.524 .35269 L
.528 .35623 L
.532 .36062 L
.536 .36551 L
.54 .37027 L
.544 .37409 L
.548 .37606 L
.552 .37526 L
.556 .37094 L
.56 .36255 L
.564 .3499 L
.568 .33317 L
.572 .31289 L
.576 .2899 L
.58 .26527 L
.584 .2402 L
.588 .21591 L
.592 .19355 L
.596 .17408 L
.6 .15827 L
Mistroke
.604 .14663 L
.608 .13943 L
.612 .13667 L
.616 .13815 L
.62 .1435 L
.624 .15219 L
.628 .1636 L
.632 .17708 L
.636 .19196 L
.64 .20762 L
.644 .22349 L
.648 .23909 L
.652 .25404 L
.656 .26804 L
.66 .28089 L
.664 .29248 L
.668 .30276 L
.672 .31173 L
.676 .31945 L
.68 .32601 L
.684 .3315 L
.688 .33605 L
.692 .33976 L
.696 .34276 L
.7 .34517 L
.704 .34707 L
.708 .34855 L
.712 .34971 L
.716 .3506 L
.72 .35127 L
.724 .35178 L
.728 .35216 L
.732 .35244 L
.736 .35264 L
.74 .3528 L
.744 .3529 L
.748 .35298 L
.752 .35304 L
.756 .35308 L
.76 .3531 L
.764 .35312 L
.768 .35314 L
.772 .35314 L
.776 .35315 L
.78 .35315 L
.784 .35316 L
.788 .35316 L
.792 .35316 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23176 L
.212 .23176 L
.216 .23176 L
.22 .23177 L
.224 .23177 L
.228 .23177 L
.232 .23177 L
.236 .23178 L
.24 .23179 L
.244 .2318 L
.248 .23181 L
.252 .23184 L
.256 .23187 L
.26 .23191 L
.264 .23198 L
.268 .23207 L
.272 .2322 L
.276 .23237 L
.28 .23261 L
.284 .23293 L
.288 .23335 L
.292 .23392 L
.296 .23466 L
.3 .23563 L
.304 .23688 L
.308 .23848 L
.312 .24049 L
.316 .24301 L
.32 .24613 L
.324 .24995 L
.328 .25456 L
.332 .26006 L
.336 .26654 L
.34 .27407 L
.344 .2827 L
.348 .29244 L
.352 .30323 L
.356 .31499 L
.36 .32753 L
.364 .34062 L
.368 .35393 L
.372 .36706 L
.376 .37956 L
.38 .39089 L
.384 .40049 L
.388 .40782 L
.392 .41233 L
.396 .41359 L
.4 .41125 L
Mistroke
.404 .40514 L
.408 .3953 L
.412 .38198 L
.416 .36562 L
.42 .3469 L
.424 .32664 L
.428 .30576 L
.432 .28525 L
.436 .26604 L
.44 .24898 L
.444 .23473 L
.448 .22377 L
.452 .21631 L
.456 .21231 L
.46 .21147 L
.464 .21326 L
.468 .21699 L
.472 .22185 L
.476 .22701 L
.48 .23171 L
.484 .23532 L
.488 .23745 L
.492 .23793 L
.496 .23688 L
.5 .23467 L
.504 .23181 L
.508 .22896 L
.512 .22674 L
.516 .2257 L
.52 .22618 L
.524 .22831 L
.528 .23192 L
.532 .23662 L
.536 .24178 L
.54 .24664 L
.544 .25036 L
.548 .25216 L
.552 .25132 L
.556 .24732 L
.56 .23986 L
.564 .2289 L
.568 .21465 L
.572 .19758 L
.576 .17837 L
.58 .15786 L
.584 .13699 L
.588 .11673 L
.592 .09801 L
.596 .08165 L
.6 .06832 L
Mistroke
.604 .05848 L
.608 .05238 L
.612 .05004 L
.616 .05129 L
.62 .05581 L
.624 .06313 L
.628 .07274 L
.632 .08407 L
.636 .09656 L
.64 .1097 L
.644 .12301 L
.648 .1361 L
.652 .14864 L
.656 .16039 L
.66 .17119 L
.664 .18092 L
.668 .18955 L
.672 .19709 L
.676 .20357 L
.68 .20907 L
.684 .21368 L
.688 .21749 L
.692 .22061 L
.696 .22313 L
.7 .22515 L
.704 .22675 L
.708 .228 L
.712 .22897 L
.716 .22971 L
.72 .23028 L
.724 .2307 L
.728 .23102 L
.732 .23126 L
.736 .23143 L
.74 .23156 L
.744 .23165 L
.748 .23171 L
.752 .23176 L
.756 .23179 L
.76 .23181 L
.764 .23183 L
.768 .23184 L
.772 .23185 L
.776 .23185 L
.78 .23186 L
.784 .23186 L
.788 .23186 L
.792 .23186 L
.796 .23186 L
.8 .23186 L
Mistroke
.804 .23186 L
.808 .23186 L
.812 .23186 L
.816 .23186 L
.82 .23186 L
.824 .23186 L
.828 .23186 L
.832 .23186 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool40002Ool00`00
Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Ao
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol037oo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00@007ooOomoo`@0009oo`80009oo`03001oogoo009oo`05001oogooOol00002Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`00
2goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo
0002Ool01000Oomoo`0017oo0P000goo00<007oo000017oo00@007ooOol000Aoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol0
00Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@0
07ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo
0P00>Woo00<007ooOol01Goo00<007ooOol0;Woo000LOol00`00Oomoo`0hOol00`00Oomoo`07Ool2
000^Ool001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00<007ooOol0100000=oo`00Ool00goo00<007ooOol00P000goo
00H007ooOomoo`00Ool30003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo
000LOol2000QOol20008Ool00`00Oomoo`15Ool001aoo`03001oogoo029oo`03001oogoo00Aoo`03
001oogoo04Ioo`0077oo0P008goo0P001Goo00<007ooOol0AWoo000LOol00`00Oomoo`0TOol01@00
Oomoogoo0000BGoo000;Ool20004Ool01000Oomoogoo1@000Woo0P009Goo1000BWoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`03001oogoo02Ioo`03001oogoo04Uoo`002Woo00@007ooOol0
00Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1b
Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001o
ogooOol0001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool0
1000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo
000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00
Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol0
0goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yo
o`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo
00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo
07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`002goo0P0017oo00<007ooOol00Woo0`00N7oo000:Ool01000Oomoo`001goo00D007ooOomo
o`0007Moo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04
001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002goo
0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P00
17oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool40003Ool2001cOol000Yoo`04001oogoo0007Ool00`00Oomo
o`04Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool2001cOol000]oo`80
00Yoo`8000=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`0UOol3000DOol2000d
Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8002Ioo`03001oo`0001Aoo`03001oo`0003=o
o`002Woo00@007ooOol000Yoo`05001oogooOol0000VOol01000Oomoo`004goo00@007ooOol003=o
o`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo02Aoo`05001oogooOol0000BOol0
1000Oomoo`00<goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`8002Eoo`05001oogooOol0
000BOol01@00Oomoogoo0000<Woo000:Ool01000Oomoo`0027oo00<007oo00000goo00<007ooOol0
97oo00D007ooOomoo`00015oo`03001oogoo009oo`03001oogoo031oo`002Woo00@007ooOol000Uo
o`8000=oo`8002Eoo`05001oogooOol0000AOol00`00Oomoo`02Ool00`00Oomoo`0`Ool000]oo`80
00]oo`05001oogooOol0000UOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00
Oomoo`0`Ool001aoo`8002Aoo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo009oo`03001o
ogoo031oo`0077oo00<007ooOol08goo00<007ooOol00goo00<007ooOol03Woo00<007ooOol00goo
00<007ooOol0;goo000;Ool20004Ool01000Oomoogoo1@000Woo0P008goo00<007ooOol017oo00<0
07ooOol03Woo00<007ooOol00goo00<007ooOol0;goo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`03001oogoo029oo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo
02moo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo029oo`03001oogoo
00Aoo`03001oogoo00eoo`03001oogoo00Eoo`03001oogoo02ioo`002Woo00@007ooOol000Yoo`04
001oogooOol2000>Ool30004Ool20009Ool40003Ool2000017oo001oogoo0P001Goo0`000goo0`00
17oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo00aoo`05001oogooOol00002Ool01000Oomoo`002Goo
0P000goo00<007ooOol00P0000Eoo`00Oomoo`0000Eoo`04001oogooOol20002Ool01@00Oomoo`00
Ool00P001Goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo
0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`80015oo`04001oogoo0002Ool00`00Oomoo`07Ool20003Ool01@00Oomoo`00Ool00P000Woo
00<007ooOol00goo00<007ooOol00Woo00@007ooOol0009oo`04001oo`000006Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool000]oo`8000Uoo`<000=oo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool2
0003Ool01@00Oomoo`00Ool00P000Woo00<007ooOol00goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001o
ogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009
Ool00`00Oomoo`02Ool01@00Oomoo`00Ool00P000Woo00<007ooOol00goo00@007ooOomoo`@000=o
o`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00
Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04
001oogoo0008Ool20004Ool01@00Oomoo`00Ool00P000Woo00<007ooOol00Woo0P000goo00<007oo
Ool017oo00<007ooOol00P000goo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
17oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2
0009Ool20005Ool20002Ool01000Ool000001Woo00@007ooOomoo`D000=oo`800003Ool007oo00=o
o`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P007goo0P002goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol0:goo000LOol00`00Oomoo`0LOol3000<Ool00`00Oomo
o`02Ool40004Ool00`00Oomoo`0:Ool2000[Ool001aoofT000aoo`0077oo00<007ooOol04Woo00<0
07ooOol04Woo00<007ooOol00Woo00<007oo00001Goo0P0000=oo`00Ool00Woo00<007ooOol04Woo
00<007ooOol04Woo00<007ooOol02Woo000LOol2000]Ool30006Ool3000jOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002goo0P0017oo
00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2001cOol000Yoo`04001oogoo000:Ool0
1@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=o
o`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo
0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo
000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo
00<007ooOol0LWoo000;Ool2000;Ool01@00Oomoogoo0000M7oo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P00?Goo0P00=7oo000:Ool01000
Oomoo`002Woo00D007ooOomoo`0003ioo`03001oo`0003=oo`000goo1@000Woo00@007ooOol000Mo
o`D0009oo`8003aoo`04001oogoo000cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<0
07ooOol0>goo00D007ooOomoo`00039oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8003ao
o`05001oogooOol0000bOol000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`0jOol00`00Oomo
o`02Ool00`00Oomoo`0`Ool000]oo`8000]oo`04001oogooOol2000kOol00`00Oomoo`02Ool00`00
Oomoo`0`Ool001aoo`03001oogoo03Yoo`03001oogoo00=oo`03001oogoo02moo`002goo0P0017oo
00@007ooOomoo`D0009oo`8003]oo`03001oogoo00=oo`03001oogoo02moo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool3
0003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0
009oo`04001oogoo0009Ool00`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol0
00Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00T007ooOomoo`00Ool007oo
00000Woo00@007oo000000Eoo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06
001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Yoo`05
001oogooOol0000BOol01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo000000Ioo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`00
0Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007oo000000Moo`05001oogooOol00002Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`002Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Ao
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo1000
0goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007ooOol0
00Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo0P001Goo00@007ooOol000Ao
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo0000
1Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P00
17oo0P001Woo00@007ooOomoo`D000=oo`800003Ool007oo00=oo`<000Aoo`8000Aoo`8000Ioo`<0
009oo`D000=oo`8000Ioo`0077oo0P00;Goo0P002Woo00<007ooOol027oo00<007ooOol0;7oo000L
Ool00`00Oomoo`0/Ool30009Ool00`00Oomoo`09Ool2000/Ool001aoofT000aoo`0077oo00D007oo
Oomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo1@000goo
00<007ooOol00Woo00D007ooOomoo`0000=oo`<00006Ool00000001oo`000goo00D007ooOomoo`00
00=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo0P007goo0P002goo00<007ooOol01goo0`00
>Woo000LOol00`00Oomoo`0OOol2000:Ool00`00Oomoo`08Ool00`00Oomoo`0iOol001aoo`80025o
o`03001oogoo00Moo`03001oogoo04Eoo`0077oo00<007ooOol087oo00<007ooOol01goo00<007oo
Ool0AGoo000;Ool20004Ool01000Oomoogoo1@000Woo0P008Woo00<007ooOol01Woo00<007ooOol0
AGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo025oo`03001oogoo00Ioo`03
001oogoo04Eoo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8002=oo`03001oogoo00Aoo`03
001oogoo04Ioo`002Woo00@007ooOol000Yoo`05001oogooOol0000TOol00`00Oomoo`04Ool00`00
Oomoo`16Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P008goo00<007ooOol017oo
00<007ooOol0AWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo029oo`03
001oogoo00Aoo`03001oogoo04Ioo`002goo0P002Goo0`000goo0P0097oo00<007ooOol00goo00<0
07ooOol0AWoo000LOol00`00Oomoo`0SOol00`00Oomoo`03Ool00`00Oomoo`16Ool000]oo`8000Ao
o`03001oogoo00=oo`<0009oo`8002Eoo`05001oogooOol00019Ool000Yoo`04001oogoo000:Ool0
1@00Oomoogoo00009Woo00D007ooOomoo`0004Uoo`002Woo00@007ooOol000Moo`D0009oo`8002Eo
o`05001oogooOol00019Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol097oo
00@007ooOol004Yoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8002Ioo`03001oo`0004Yo
o`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo02Eoo`<004Yoo`002goo0P002goo00@007oo
Oomoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001c
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03
001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1b
Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00
Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001c
Ool001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol0
0`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3720\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23178 L
.212 .23178 L
.216 .23178 L
.22 .23178 L
.224 .23178 L
.228 .23178 L
.232 .23179 L
.236 .23179 L
.24 .2318 L
.244 .23181 L
.248 .23183 L
.252 .23185 L
.256 .23188 L
.26 .23192 L
.264 .23198 L
.268 .23206 L
.272 .23217 L
.276 .23231 L
.28 .2325 L
.284 .23275 L
.288 .23308 L
.292 .2335 L
.296 .23403 L
.3 .2347 L
.304 .23554 L
.308 .23658 L
.312 .23786 L
.316 .23939 L
.32 .24122 L
.324 .24338 L
.328 .24588 L
.332 .24874 L
.336 .25197 L
.34 .25555 L
.344 .25945 L
.348 .26361 L
.352 .26796 L
.356 .27238 L
.36 .27675 L
.364 .2809 L
.368 .28467 L
.372 .28787 L
.376 .29032 L
.38 .29184 L
.384 .29229 L
.388 .29155 L
.392 .28958 L
.396 .28637 L
.4 .28199 L
Mistroke
.404 .27659 L
.408 .27038 L
.412 .26363 L
.416 .25663 L
.42 .24974 L
.424 .24328 L
.428 .23755 L
.432 .23278 L
.436 .22914 L
.44 .22669 L
.444 .22538 L
.448 .22509 L
.452 .22563 L
.456 .22674 L
.46 .22817 L
.464 .22967 L
.468 .23105 L
.472 .23218 L
.476 .23297 L
.48 .23342 L
.484 .23356 L
.488 .23345 L
.492 .23315 L
.496 .23274 L
.5 .23227 L
.504 .23177 L
.508 .23127 L
.512 .2308 L
.516 .23039 L
.52 .2301 L
.524 .22998 L
.528 .23012 L
.532 .23056 L
.536 .23135 L
.54 .23247 L
.544 .23385 L
.548 .23535 L
.552 .23677 L
.556 .23788 L
.56 .23842 L
.564 .23814 L
.568 .23684 L
.572 .2344 L
.576 .23076 L
.58 .22601 L
.584 .22028 L
.588 .21383 L
.592 .20694 L
.596 .19995 L
.6 .19319 L
Mistroke
.604 .18697 L
.608 .18157 L
.612 .17719 L
.616 .17397 L
.62 .172 L
.624 .17126 L
.628 .1717 L
.632 .17323 L
.636 .17567 L
.64 .17888 L
.644 .18265 L
.648 .18681 L
.652 .19118 L
.656 .1956 L
.66 .19995 L
.664 .20412 L
.668 .20802 L
.672 .2116 L
.676 .21483 L
.68 .2177 L
.684 .22021 L
.688 .22236 L
.692 .22419 L
.696 .22573 L
.7 .227 L
.704 .22804 L
.708 .22888 L
.712 .22956 L
.716 .23009 L
.72 .23051 L
.724 .23083 L
.728 .23108 L
.732 .23127 L
.736 .23142 L
.74 .23152 L
.744 .2316 L
.748 .23166 L
.752 .2317 L
.756 .23173 L
.76 .23176 L
.764 .23177 L
.768 .23178 L
.772 .23179 L
.776 .2318 L
.78 .2318 L
.784 .2318 L
.788 .2318 L
.792 .23181 L
.796 .23181 L
.8 .23181 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35316 L
.208 .35316 L
.212 .35316 L
.216 .35315 L
.22 .35315 L
.224 .35314 L
.228 .35313 L
.232 .35312 L
.236 .3531 L
.24 .35307 L
.244 .35303 L
.248 .35298 L
.252 .3529 L
.256 .35279 L
.26 .35264 L
.264 .35243 L
.268 .35214 L
.272 .35176 L
.276 .35125 L
.28 .35057 L
.284 .34968 L
.288 .34852 L
.292 .34703 L
.296 .34512 L
.3 .34272 L
.304 .33971 L
.308 .33599 L
.312 .33145 L
.316 .32597 L
.32 .31942 L
.324 .31172 L
.328 .30277 L
.332 .29252 L
.336 .28096 L
.34 .26814 L
.344 .25419 L
.348 .23929 L
.352 .22374 L
.356 .20793 L
.36 .19232 L
.364 .17746 L
.368 .16399 L
.372 .15255 L
.376 .1438 L
.38 .13836 L
.384 .13678 L
.388 .13944 L
.392 .14657 L
.396 .15813 L
.4 .17386 L
Mistroke
.404 .19323 L
.408 .21546 L
.412 .23959 L
.416 .26451 L
.42 .28903 L
.424 .31202 L
.428 .33245 L
.432 .3495 L
.436 .3626 L
.44 .37152 L
.444 .37632 L
.448 .37738 L
.452 .37537 L
.456 .37111 L
.46 .36558 L
.464 .35972 L
.468 .35438 L
.472 .35024 L
.476 .34769 L
.48 .34682 L
.484 .34747 L
.488 .3492 L
.492 .35146 L
.496 .35363 L
.5 .35518 L
.504 .35574 L
.508 .35518 L
.512 .35363 L
.516 .35146 L
.52 .3492 L
.524 .34747 L
.528 .34682 L
.532 .34769 L
.536 .35024 L
.54 .35438 L
.544 .35972 L
.548 .36558 L
.552 .37111 L
.556 .37537 L
.56 .37739 L
.564 .37632 L
.568 .37152 L
.572 .3626 L
.576 .3495 L
.58 .33245 L
.584 .31202 L
.588 .28903 L
.592 .26451 L
.596 .23959 L
.6 .21546 L
Mistroke
.604 .19322 L
.608 .17385 L
.612 .15812 L
.616 .14656 L
.62 .13944 L
.624 .13678 L
.628 .13836 L
.632 .14379 L
.636 .15254 L
.64 .16398 L
.644 .17746 L
.648 .19231 L
.652 .20792 L
.656 .22374 L
.66 .23929 L
.664 .25418 L
.668 .26814 L
.672 .28096 L
.676 .29251 L
.68 .30277 L
.684 .31172 L
.688 .31942 L
.692 .32597 L
.696 .33145 L
.7 .33599 L
.704 .33971 L
.708 .34272 L
.712 .34512 L
.716 .34703 L
.72 .34852 L
.724 .34968 L
.728 .35057 L
.732 .35125 L
.736 .35176 L
.74 .35215 L
.744 .35243 L
.748 .35264 L
.752 .35279 L
.756 .3529 L
.76 .35298 L
.764 .35303 L
.768 .35307 L
.772 .3531 L
.776 .35312 L
.78 .35313 L
.784 .35314 L
.788 .35315 L
.792 .35315 L
.796 .35316 L
.8 .35316 L
Mistroke
.804 .35316 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23176 L
.2 .23176 L
Mistroke
.204 .23176 L
.208 .23177 L
.212 .23177 L
.216 .23177 L
.22 .23177 L
.224 .23178 L
.228 .23179 L
.232 .2318 L
.236 .23181 L
.24 .23184 L
.244 .23187 L
.248 .23192 L
.252 .23198 L
.256 .23208 L
.26 .2322 L
.264 .23238 L
.268 .23262 L
.272 .23294 L
.276 .23337 L
.28 .23394 L
.284 .23468 L
.288 .23566 L
.292 .23691 L
.296 .23851 L
.3 .24053 L
.304 .24305 L
.308 .24617 L
.312 .24999 L
.316 .25459 L
.32 .26008 L
.324 .26656 L
.328 .27407 L
.332 .28268 L
.336 .29238 L
.34 .30313 L
.344 .31485 L
.348 .32735 L
.352 .34041 L
.356 .35369 L
.36 .3668 L
.364 .37928 L
.368 .39059 L
.372 .40019 L
.376 .40753 L
.38 .41208 L
.384 .4134 L
.388 .41116 L
.392 .40521 L
.396 .39554 L
.4 .38237 L
Mistroke
.404 .36613 L
.408 .34747 L
.412 .32718 L
.416 .3062 L
.42 .28554 L
.424 .26618 L
.428 .24903 L
.432 .23478 L
.436 .22392 L
.44 .21661 L
.444 .21274 L
.448 .21193 L
.452 .21356 L
.456 .2169 L
.46 .22117 L
.464 .22566 L
.468 .22977 L
.472 .23309 L
.476 .23542 L
.48 .23672 L
.484 .23711 L
.488 .23675 L
.492 .23587 L
.496 .23467 L
.5 .23328 L
.504 .23181 L
.508 .23035 L
.512 .22896 L
.516 .22775 L
.52 .22688 L
.524 .22652 L
.528 .2269 L
.532 .22821 L
.536 .23054 L
.54 .23386 L
.544 .23797 L
.548 .24246 L
.552 .24673 L
.556 .25007 L
.56 .2517 L
.564 .25089 L
.568 .24702 L
.572 .23971 L
.576 .22884 L
.58 .2146 L
.584 .19744 L
.588 .17809 L
.592 .15743 L
.596 .13645 L
.6 .11616 L
Mistroke
.604 .09749 L
.608 .08126 L
.612 .06809 L
.616 .05842 L
.62 .05246 L
.624 .05023 L
.628 .05155 L
.632 .0561 L
.636 .06343 L
.64 .07303 L
.644 .08435 L
.648 .09682 L
.652 .10994 L
.656 .12322 L
.66 .13627 L
.664 .14878 L
.668 .16049 L
.672 .17125 L
.676 .18095 L
.68 .18956 L
.684 .19707 L
.688 .20354 L
.692 .20904 L
.696 .21364 L
.7 .21745 L
.704 .22057 L
.708 .2231 L
.712 .22512 L
.716 .22672 L
.72 .22797 L
.724 .22894 L
.728 .22969 L
.732 .23026 L
.736 .23069 L
.74 .23101 L
.744 .23125 L
.748 .23142 L
.752 .23155 L
.756 .23164 L
.76 .23171 L
.764 .23176 L
.768 .23179 L
.772 .23181 L
.776 .23183 L
.78 .23184 L
.784 .23185 L
.788 .23185 L
.792 .23186 L
.796 .23186 L
.8 .23186 L
Mistroke
.804 .23186 L
.808 .23186 L
.812 .23186 L
.816 .23186 L
.82 .23186 L
.824 .23186 L
.828 .23186 L
.832 .23186 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool40002Ool00`00
Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Ao
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol037oo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00@007ooOomoo`D0009oo`800003Ool007oo00=oo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo
0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002
Ool01000Oomoo`0017oo0P000goo00<007ooOol00P000Woo100017oo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000L
Ool00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo
1@000goo0`001Goo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000kOol0
0`00Oomoo`05Ool2000^Ool001aoo`03001oogoo03Yoo`03001oogoo00Ioo`<002aoo`0077ooJ@00
37oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool00`00Ool000030002Ool00`00Oomoo`02Ool01@00Ool007oo00000goo00D007ooOomo
o`00009oo`<0009oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`80
021oo`8000Qoo`03001oogoo04Ioo`0077oo00<007ooOol087oo0P001Woo00<007ooOol0Agoo000L
Ool2000ROol20004Ool20019Ool001aoo`03001oogoo029oo`8000=oo`03001oogoo04Qoo`002goo
0P0017oo00@007ooOomoo`D0009oo`8002Aoo`@004]oo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool00`00Oomoo`0UOol00`00Oomoo`1:Ool000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2
001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00
Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool0
1000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uo
o`8000=oo`03001oogoo079oo`002goo0P002goo00@007ooOomoo`8007=oo`0077oo00<007ooOol0
LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
07=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03
001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo079oo`00
2goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009o
o`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`00
0goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`80
07=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo009oo`03001o
ogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo
07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03
001oogoo009oo`<007Qoo`002Woo00@007ooOol000Moo`05001oogooOol0001gOol000=oo`D0009o
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000]oo`8000Uoo`<000=oo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<0
00=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=o
o`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo10000goo0P00Lgoo000:Ool01000Oomoo`001goo00<007ooOol017oo00<007ooOol0LWoo
000:Ool01000Oomoo`0027oo00<007ooOol00goo0P00Lgoo000;Ool2000:Ool20003Ool00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol097oo0P005goo0`00<Woo000;Ool20004Ool00`00
Oomoo`03Ool30002Ool2000UOol00`00Ool0000FOol00`00Ool0000bOol000Yoo`04001oogoo000:
Ool01@00Oomoogoo00009Goo00@007ooOol001Eoo`04001oogoo000bOol000=oo`D0009oo`04001o
ogoo0007Ool50002Ool00`00Oomoo`0SOol01@00Oomoogoo000057oo00@007ooOol0039oo`002Woo
00@007ooOol000Moo`04001oogoo0003Ool2000TOol01@00Oomoogoo000057oo00D007ooOomoo`00
035oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo029oo`03001oogoo009oo`03
001oogoo019oo`05001oogooOol0000aOol000Yoo`04001oogoo0009Ool20003Ool2000SOol00`00
Oomoo`02Ool00`00Oomoo`0BOol01@00Oomoogoo0000<Goo000;Ool2000;Ool01@00Oomoogoo0000
97oo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol00goo00<007ooOol0;Woo000LOol2000S
Ool00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0^Ool001aoo`03001o
ogoo029oo`03001oogoo009oo`03001oogoo015oo`03001oogoo00=oo`03001oogoo02ioo`002goo
0P0017oo00@007ooOomoo`D0009oo`80029oo`03001oogoo00Aoo`03001oogoo011oo`03001oogoo
00=oo`03001oogoo02ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0QOol0
0`00Oomoo`04Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool00`00Oomoo`0^Ool000=oo`D0009oo`04
001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0QOol00`00Oomoo`04Ool00`00Oomoo`0?Ool0
0`00Oomoo`05Ool00`00Oomoo`0]Ool000Yoo`04001oogoo000:Ool01000Oomoogoo0P003Woo0`00
17oo0P002Goo0`0017oo0`000goo0P001Goo0`000goo0`0017oo0`0017oo1@000goo0P0017oo0P00
1Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo00aoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool02@00Oomoogoo001oo`00Ool00002Ool00`00Oomoo`020004Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo00@007oo
Ool0009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00800005Ool007ooOol00005Ool0
0`00Oomoo`03Ool00`00Ool00002Ool00`00Oomoo`020005Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`80
00Uoo`<000=oo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`0200001Goo001oogoo00001Goo00<007ooOol00goo00<007oo00000Woo00<007ooOol0
0P001Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`0027oo0P0017oo
00<007ooOol00P0000Eoo`00Oomoo`0000Eoo`04001oogooOol40003Ool00`00Oomoo`020003Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=o
o`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0007Ool30004
Ool00`00Oomoo`0200001Goo001oogoo000017oo0P000goo00<007oo000017oo00H007ooOol007oo
0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001o
o`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Qoo`03001oo`0000Eo
o`800004Ool007ooOol20006Ool01000Oomoogoo1@000goo0P000goo00<007ooOol00`0017oo0P00
17oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000NOol00`00Oomoo`09Ool00`00Oomoo`0=
Ool00`00Oomoo`09Ool2000[Ool001aoo`03001oogoo01]oo`<000]oo`03001oogoo009oo`<0009o
o`8000Aoo`03001oogoo00Yoo`<002Uoo`0077ooJ@0037oo000LOol00`00Oomoo`0BOol00`00Oomo
o`0BOol01000Oomoo`000Woo00<007ooOol01Goo0P0000Eoo`00Oomoo`0001Aoo`03001oogoo019o
o`03001oogoo00Yoo`0077oo0P00;7oo0P002Goo0`00>Goo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogooOol5
0002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0LWoo000:Ool0
1000Oomoo`002Goo00<007ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`00
07Aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001c
Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo
0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079o
o`002goo0P002goo00D007ooOomoo`0007Aoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
00]oo`8000Aoo`03001oogoo00=oo`<0009oo`8003ioo`<0039oo`002Woo00@007ooOol000Yoo`05
001oogooOol0000oOol00`00Ool0000bOol000=oo`D0009oo`04001oogoo0007Ool50002Ool2000m
Ool01000Oomoo`00<Woo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo03aoo`05
001oogooOol0000aOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2000mOol01@00Oomoogoo
0000<Goo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0?7oo00D007ooOomoo`00035oo`00
2goo0P002goo00@007ooOomoo`8003eoo`03001oogoo009oo`03001oogoo02ioo`0077oo00<007oo
Ool0>goo00<007ooOol00goo00<007ooOol0;Woo000;Ool20004Ool01000Oomoogoo1@000Woo0P00
?7oo00<007ooOol00goo00<007ooOol0;Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03
001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D0
00=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Uoo`03
001oogoo009oo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000Woo0P000Woo00@007ooOol000Eoo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Yoo`05001oogooOol0000BOol01000Oomo
o`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`03Ool00`00Ool00002Ool01000Oomoo`001Woo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`80015oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00=oo`03001oo`00009oo`03001o
ogoo008000Ioo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol0
17oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool01000Oomoogoo10000goo00<007ooOol00P000goo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;
Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0
009oo`04001oogoo0004Ool20003Ool00`00Ool00004Ool00`00Oomoo`020003Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo
0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04
001oogooOol50003Ool20002Ool01000Oomoogoo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo
0P001Woo000LOol2000/Ool2000=Ool00`00Oomoo`07Ool2000/Ool001aoo`03001oogoo02]oo`<0
00]oo`03001oogoo00Uoo`8002]oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007oo
Ool00Woo00D007ooOomoo`0000=oo`05001oogooOol00002Ool400000goo001oo`02Ool00`00Oomo
o`02Ool00`00Oomoo`020002Ool400001Goo001oo`00Ool00P000Woo00D007ooOomoo`0000=oo`03
001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03
001oogoo009oo`03001oogoo00Yoo`0077oo0P007Woo00<007ooOol02Goo00<007ooOol02Woo0`00
>Goo000LOol00`00Oomoo`0NOol00`00Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomoo`0hOol001ao
o`80021oo`03001oogoo00Moo`03001oogoo04Ioo`0077oo00<007ooOol07goo00<007ooOol01goo
00<007ooOol0AWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P008Goo00<007ooOol01Woo00<0
07ooOol0AWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo021oo`03001oogoo
00Ioo`03001oogoo04Ioo`002Woo00@007ooOol000Uoo`03001oogoo009oo`80025oo`03001oogoo
00Eoo`03001oogoo04Moo`002Woo00@007ooOol000Yoo`05001oogooOol0000SOol00`00Oomoo`04
Ool00`00Oomoo`17Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P008Woo00<007oo
Ool017oo00<007ooOol0Agoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo
025oo`03001oogoo00Aoo`03001oogoo04Moo`002goo0P002Goo0`000goo0P008goo00<007ooOol0
0Woo00<007ooOol0B7oo000LOol00`00Oomoo`0ROol00`00Oomoo`02Ool00`00Oomoo`18Ool000]o
o`8000Aoo`03001oogoo00=oo`<0009oo`8002=oo`03001oogoo009oo`03001oogoo04Qoo`002Woo
00@007ooOol000Yoo`05001oogooOol0000TOol00`00Oomoo`02Ool00`00Oomoo`18Ool000Yoo`04
001oogoo0007Ool50002Ool2000TOol01@00Oomoogoo0000BWoo000:Ool01000Oomoo`001goo00@0
07ooOol000=oo`03001oogoo02=oo`04001oogoo001;Ool000Yoo`04001oogoo0008Ool00`00Ool0
0003Ool2000UOol00`00Ool0001;Ool000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`0TOol2
001<Ool000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo
00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001o
ogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001c
Ool000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=o
o`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001o
ogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03
001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uo
o`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3760\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23178 L
.2 .23178 L
Mistroke
.204 .23178 L
.208 .23178 L
.212 .23178 L
.216 .23178 L
.22 .23179 L
.224 .23179 L
.228 .2318 L
.232 .23181 L
.236 .23183 L
.24 .23185 L
.244 .23188 L
.248 .23192 L
.252 .23198 L
.256 .23206 L
.26 .23217 L
.264 .23232 L
.268 .23251 L
.272 .23276 L
.276 .23309 L
.28 .23351 L
.284 .23404 L
.288 .23472 L
.292 .23556 L
.296 .2366 L
.3 .23787 L
.304 .2394 L
.308 .24123 L
.312 .24338 L
.316 .24588 L
.32 .24873 L
.324 .25195 L
.328 .25552 L
.332 .25941 L
.336 .26356 L
.34 .26789 L
.344 .2723 L
.348 .27665 L
.352 .2808 L
.356 .28456 L
.36 .28777 L
.364 .29023 L
.368 .29177 L
.372 .29224 L
.376 .29154 L
.38 .2896 L
.384 .28642 L
.388 .28208 L
.392 .27671 L
.396 .27052 L
.4 .26379 L
Mistroke
.404 .25682 L
.408 .24994 L
.412 .24347 L
.416 .23771 L
.42 .23288 L
.424 .22916 L
.428 .22661 L
.432 .22522 L
.436 .22488 L
.44 .22541 L
.444 .22656 L
.448 .22809 L
.452 .22972 L
.456 .23123 L
.46 .23242 L
.464 .2332 L
.468 .23354 L
.472 .23347 L
.476 .23311 L
.48 .23258 L
.484 .23204 L
.488 .23161 L
.492 .23136 L
.496 .23134 L
.5 .2315 L
.504 .23176 L
.508 .23203 L
.512 .23219 L
.516 .23217 L
.52 .23194 L
.524 .23151 L
.528 .23097 L
.532 .23044 L
.536 .23008 L
.54 .23001 L
.544 .23033 L
.548 .23111 L
.552 .2323 L
.556 .23379 L
.56 .23542 L
.564 .23694 L
.568 .2381 L
.572 .23863 L
.576 .2383 L
.58 .23692 L
.584 .23438 L
.588 .23067 L
.592 .22585 L
.596 .2201 L
.6 .21363 L
Mistroke
.604 .20676 L
.608 .19978 L
.612 .19305 L
.616 .18686 L
.62 .18148 L
.624 .17713 L
.628 .17395 L
.632 .172 L
.636 .1713 L
.64 .17177 L
.644 .17331 L
.648 .17577 L
.652 .17898 L
.656 .18275 L
.66 .1869 L
.664 .19126 L
.668 .19567 L
.672 .2 L
.676 .20416 L
.68 .20805 L
.684 .21162 L
.688 .21484 L
.692 .2177 L
.696 .2202 L
.7 .22235 L
.704 .22418 L
.708 .22572 L
.712 .22699 L
.716 .22803 L
.72 .22887 L
.724 .22954 L
.728 .23008 L
.732 .2305 L
.736 .23082 L
.74 .23108 L
.744 .23127 L
.748 .23141 L
.752 .23152 L
.756 .2316 L
.76 .23166 L
.764 .2317 L
.768 .23173 L
.772 .23176 L
.776 .23177 L
.78 .23178 L
.784 .23179 L
.788 .2318 L
.792 .2318 L
.796 .2318 L
.8 .2318 L
Mistroke
.804 .23181 L
.808 .23181 L
.812 .23181 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35316 L
.196 .35316 L
.2 .35316 L
Mistroke
.204 .35315 L
.208 .35315 L
.212 .35314 L
.216 .35313 L
.22 .35312 L
.224 .3531 L
.228 .35307 L
.232 .35303 L
.236 .35297 L
.24 .35289 L
.244 .35278 L
.248 .35263 L
.252 .35242 L
.256 .35213 L
.26 .35175 L
.264 .35123 L
.268 .35055 L
.272 .34965 L
.276 .34849 L
.28 .34699 L
.284 .34508 L
.288 .34267 L
.292 .33966 L
.296 .33595 L
.3 .33141 L
.304 .32593 L
.308 .31939 L
.312 .3117 L
.316 .30277 L
.32 .29255 L
.324 .28102 L
.328 .26825 L
.332 .25434 L
.336 .23949 L
.34 .224 L
.344 .20822 L
.348 .19264 L
.352 .17781 L
.356 .16434 L
.36 .15289 L
.364 .14411 L
.368 .13863 L
.372 .13697 L
.376 .13953 L
.38 .14651 L
.384 .15792 L
.388 .17348 L
.392 .19271 L
.396 .21484 L
.4 .23893 L
Mistroke
.404 .26388 L
.408 .2885 L
.412 .31162 L
.416 .3322 L
.42 .34936 L
.424 .36254 L
.428 .37148 L
.432 .37629 L
.436 .3774 L
.44 .37549 L
.444 .37144 L
.448 .36618 L
.452 .36061 L
.456 .35548 L
.46 .35134 L
.464 .34849 L
.468 .34702 L
.472 .34681 L
.476 .34759 L
.48 .34903 L
.484 .35081 L
.488 .35261 L
.492 .35421 L
.496 .35545 L
.5 .35622 L
.504 .35649 L
.508 .35622 L
.512 .35545 L
.516 .35421 L
.52 .35261 L
.524 .35081 L
.528 .34903 L
.532 .34759 L
.536 .34681 L
.54 .34702 L
.544 .34849 L
.548 .35134 L
.552 .35548 L
.556 .36061 L
.56 .36618 L
.564 .37144 L
.568 .37549 L
.572 .3774 L
.576 .37629 L
.58 .37148 L
.584 .36254 L
.588 .34936 L
.592 .3322 L
.596 .31162 L
.6 .2885 L
Mistroke
.604 .26388 L
.608 .23893 L
.612 .21484 L
.616 .1927 L
.62 .17348 L
.624 .15791 L
.628 .14651 L
.632 .13953 L
.636 .13697 L
.64 .13863 L
.644 .14411 L
.648 .15289 L
.652 .16434 L
.656 .17781 L
.66 .19264 L
.664 .20822 L
.668 .22399 L
.672 .23949 L
.676 .25434 L
.68 .26825 L
.684 .28102 L
.688 .29255 L
.692 .30277 L
.696 .3117 L
.7 .31939 L
.704 .32593 L
.708 .33141 L
.712 .33595 L
.716 .33966 L
.72 .34267 L
.724 .34508 L
.728 .34699 L
.732 .34849 L
.736 .34965 L
.74 .35055 L
.744 .35123 L
.748 .35175 L
.752 .35213 L
.756 .35242 L
.76 .35263 L
.764 .35278 L
.768 .35289 L
.772 .35297 L
.776 .35303 L
.78 .35307 L
.784 .3531 L
.788 .35312 L
.792 .35313 L
.796 .35314 L
.8 .35315 L
Mistroke
.804 .35315 L
.808 .35316 L
.812 .35316 L
.816 .35316 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23176 L
.188 .23176 L
.192 .23176 L
.196 .23177 L
.2 .23177 L
Mistroke
.204 .23177 L
.208 .23177 L
.212 .23178 L
.216 .23179 L
.22 .2318 L
.224 .23181 L
.228 .23184 L
.232 .23187 L
.236 .23192 L
.24 .23199 L
.244 .23208 L
.248 .23221 L
.252 .23239 L
.256 .23263 L
.26 .23295 L
.264 .23338 L
.268 .23396 L
.272 .23471 L
.276 .23569 L
.28 .23694 L
.284 .23855 L
.288 .24057 L
.292 .24309 L
.296 .24621 L
.3 .25003 L
.304 .25463 L
.308 .26011 L
.312 .26657 L
.316 .27407 L
.32 .28265 L
.324 .29232 L
.328 .30304 L
.332 .31472 L
.336 .32719 L
.34 .3402 L
.344 .35344 L
.348 .36652 L
.352 .37897 L
.356 .39027 L
.36 .39989 L
.364 .40726 L
.368 .41187 L
.372 .41327 L
.376 .41114 L
.38 .40528 L
.384 .3957 L
.388 .38262 L
.392 .36647 L
.396 .34788 L
.4 .32767 L
Mistroke
.404 .30675 L
.408 .28612 L
.412 .26674 L
.416 .24949 L
.42 .23508 L
.424 .22397 L
.428 .21639 L
.432 .21227 L
.436 .21129 L
.44 .21289 L
.444 .21637 L
.448 .22093 L
.452 .2258 L
.456 .23027 L
.46 .23381 L
.464 .23612 L
.468 .23709 L
.472 .23687 L
.476 .23576 L
.48 .23419 L
.484 .23257 L
.488 .23129 L
.492 .23058 L
.496 .23052 L
.5 .23101 L
.504 .23181 L
.508 .23262 L
.512 .2331 L
.516 .23304 L
.52 .23234 L
.524 .23105 L
.528 .22944 L
.532 .22786 L
.536 .22676 L
.54 .22654 L
.544 .22751 L
.548 .22981 L
.552 .23336 L
.556 .23783 L
.56 .24269 L
.564 .24726 L
.568 .25074 L
.572 .25234 L
.576 .25135 L
.58 .24724 L
.584 .23965 L
.588 .22855 L
.592 .21413 L
.596 .19689 L
.6 .17751 L
Mistroke
.604 .15688 L
.608 .13596 L
.612 .11574 L
.616 .09715 L
.62 .081 L
.624 .06792 L
.628 .05835 L
.632 .05249 L
.636 .05035 L
.64 .05175 L
.644 .05636 L
.648 .06373 L
.652 .07335 L
.656 .08466 L
.66 .0971 L
.664 .11018 L
.668 .12342 L
.672 .13644 L
.676 .1489 L
.68 .16058 L
.684 .17131 L
.688 .18098 L
.692 .18956 L
.696 .19706 L
.7 .20351 L
.704 .209 L
.708 .2136 L
.712 .21741 L
.716 .22053 L
.72 .22306 L
.724 .22508 L
.728 .22668 L
.732 .22794 L
.736 .22892 L
.74 .22967 L
.744 .23024 L
.748 .23068 L
.752 .231 L
.756 .23124 L
.76 .23142 L
.764 .23155 L
.768 .23164 L
.772 .23171 L
.776 .23176 L
.78 .23179 L
.784 .23181 L
.788 .23183 L
.792 .23184 L
.796 .23185 L
.8 .23185 L
Mistroke
.804 .23186 L
.808 .23186 L
.812 .23186 L
.816 .23186 L
.82 .23186 L
.824 .23186 L
.828 .23186 L
.832 .23186 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool00`00Ool00002
00000goo001oo`06Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001o
ogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol037oo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOomoo`@00005Ool00000001oo`020004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005
Ool000]oo`8000Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`04001oogooOol200000goo001oo`020004Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04
001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`80
00Ioo`04001oogooOol50003Ool40004Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006
Ool001aoo`8003aoo`8000Ioo`8002eoo`0077oo00<007ooOol0>goo00<007ooOol01Woo0`00:goo
000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`D000=oo`03001oogoo009oo`80009oo`05001oogooOol00003Ool01000
Oomoogoo1@000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo0P007goo0P001goo00<0
07ooOol0B7oo000LOol00`00Oomoo`0OOol20006Ool00`00Oomoo`18Ool001aoo`80025oo`8000Ao
o`8004Yoo`0077oo00<007ooOol08Goo0P000Woo0P00Bgoo000;Ool20004Ool01000Oomoogoo1@00
0Woo0P008goo1000C7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo02Aoo`03
001oogoo04]oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol0
00Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`00
0goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=o
o`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool50002Ool2
001cOol000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomo
o`0027oo00<007oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo
000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`00
1goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:
Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001c
Ool001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1b
Ool001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomo
o`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Mo
o`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00N7oo000:
Ool01000Oomoo`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`8007=oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool40003Ool2001cOol0
00Yoo`04001oogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool0
0`00Oomoo`03Ool2001cOol000]oo`8000Yoo`8000=oo`03001oogoo079oo`0077oo0P00Lgoo000L
Ool00`00Oomoo`0SOol2000JOol2000aOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8002=o
o`03001oo`0001Uoo`03001oo`00035oo`002Woo00@007ooOol000Yoo`05001oogooOol0000TOol0
1000Oomoo`0067oo00@007ooOol0031oo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001o
ogoo029oo`04001oogoo000GOol01@00Oomoogoo0000<7oo000:Ool01000Oomoo`001goo00@007oo
Ool000=oo`8002=oo`04001oogoo000GOol01@00Oomoogoo0000<7oo000:Ool01000Oomoo`0027oo
00<007oo00000goo00<007ooOol08Goo00<007ooOol00Woo00<007ooOol057oo00D007ooOomoo`00
031oo`002Woo00@007ooOol000Uoo`8000=oo`80029oo`03001oogoo009oo`03001oogoo01Aoo`05
001oogooOol0000`Ool000]oo`8000]oo`05001oogooOol0000SOol00`00Oomoo`02Ool00`00Oomo
o`0COol00`00Oomoo`03Ool00`00Oomoo`0]Ool001aoo`80029oo`03001oogoo009oo`03001oogoo
01=oo`03001oogoo00=oo`03001oogoo02eoo`0077oo00<007ooOol087oo00<007ooOol00goo00<0
07ooOol04goo00<007ooOol00goo00<007ooOol0;Goo000;Ool20004Ool01000Oomoogoo1@000Woo
0P008Goo00<007ooOol017oo00<007ooOol04Woo00<007ooOol017oo00<007ooOol0;7oo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`03001oogoo021oo`03001oogoo00Aoo`03001oogoo019o
o`03001oogoo00Aoo`03001oogoo02aoo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009o
o`03001oogoo021oo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo02ao
o`002Woo00@007ooOol000Yoo`04001oogooOol2000>Ool30004Ool20009Ool30004Ool20004Ool2
0005Ool30003Ool40003Ool200000goo001oo`02Ool50003Ool20004Ool20005Ool50002Ool30004
Ool20006Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo00D007oo
Oomoo`00009oo`04001oogoo0008Ool20004Ool01000Ool000000Woo00@007ooOol000Eoo`05001o
ogooOol00003Ool01000Oomoo`000Woo00<007oo00000goo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04001oogoo0002Ool00`00Oomoo`06
Ool20004Ool01000Ool000000Woo00@007ooOol000Eoo`03001oogoo00Aoo`80009oo`06001oogoo
001oo`0017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000;Ool20009Ool30003Ool00`00Oomoo`0@Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007oo000017oo00@007oo0000009oo`04001oogoo0005Ool00`00
Oomoo`04Ool20002Ool01P00Oomoo`00Ool000Eoo`05001oogooOol00002Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo
10000goo00@007ooOol000Moo`03001oo`0000Aoo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOomoo`@000=oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo009oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007oo
Ool037oo00<007ooOol017oo00@007ooOol000Ioo`04001oo`000004Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`8000=oo`04001oogoo0003Ool01000Oomoo`000Woo0`000goo00@007ooOol0009o
o`04001oogoo0002Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0
01aoo`03001oogoo00aoo`D000=oo`8000Moo`04001oogoo0005Ool30003Ool20006Ool01000Oomo
ogoo1@000goo0P0017oo00<007oo00000P0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo
000LOol2000MOol00`00Oomoo`09Ool00`00Oomoo`0?Ool00`00Oomoo`09Ool2000ZOol001aoo`03
001oogoo01Yoo`8000aoo`03001oogoo009oo`<000Aoo`8000Aoo`03001oogoo00Yoo`<002Qoo`00
77ooJ@0037oo000LOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Ool00002Ool00`00Oomoo`08
Ool00`00Oomoo`02000DOol00`00Oomoo`0BOol00`00Oomoo`0:Ool001aoo`8002Yoo`<000aoo`80
03Qoo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`03001oogoo079oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`00
2Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`00
07Aoo`002Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo
0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04
001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`05001oogooOol0001dOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool20010
Ool2000aOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000@7oo00<007oo0000<Goo0003Ool5
0002Ool01000Oomoo`001goo1@000Woo0P00?goo00@007ooOol0031oo`002Woo00@007ooOol000Mo
o`04001oogoo0003Ool00`00Oomoo`0mOol01@00Oomoogoo0000<7oo000:Ool01000Oomoo`0027oo
00<007oo00000goo0P00?Woo00D007ooOomoo`00031oo`002Woo00@007ooOol000Uoo`8000=oo`03
001oogoo03eoo`05001oogooOol0000`Ool000]oo`8000]oo`04001oogooOol2000mOol00`00Oomo
o`03Ool00`00Oomoo`0]Ool001aoo`03001oogoo03aoo`03001oogoo00=oo`03001oogoo02eoo`00
2goo0P0017oo00@007ooOomoo`D0009oo`8003eoo`03001oogoo00=oo`03001oogoo02eoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004
Ool20005Ool30003Ool40003Ool200000goo001oo`02Ool50003Ool20004Ool20005Ool50002Ool3
0004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool2000=Ool01@00Oomo
ogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00D007ooOomoo`0000=oo`04001oogoo0002Ool20004Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yo
o`04001oogoo000:Ool01@00Oomoogoo00004Woo00@007ooOol0009oo`03001oogoo00Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`80
00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol0
1000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo00001Goo00D007ooOomoo`00009oo`04001o
ogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01P00
Oomoo`00Ool0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001o
ogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P003Goo00<007ooOol0
17oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00@007oo
Ool000=oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`000Woo00@007ooOol0009oo`03
001oogoo009oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo
1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000=oo`03
001oogoo00<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P00:goo00<007oo
Ool03Woo00<007ooOol027oo00<007ooOol0:Goo000LOol00`00Oomoo`0YOol01000Ool000003Goo
00<007ooOol02Goo0P00:Woo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00@007ooOomoo`H0009oo`05001oogooOol00004Ool01P00Ool007oo
001oo`<0009oo`80009oo`80009oo`8000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001ao
o`8001aoo`8000]oo`03001oogoo00aoo`<003Qoo`0077oo00<007ooOol07Goo00<007ooOol027oo
00<007ooOol03Goo00<007ooOol0=goo000LOol2000NOol00`00Oomoo`08Ool00`00Oomoo`17Ool0
01aoo`03001oogoo01ioo`03001oogoo00Moo`03001oogoo04Moo`002goo0P0017oo00@007ooOomo
o`D0009oo`8001moo`03001oogoo00Ioo`03001oogoo04Qoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool00`00Oomoo`0OOol00`00Oomoo`05Ool00`00Oomoo`18Ool000Yoo`04001oogoo0009
Ool00`00Oomoo`02Ool2000POol00`00Oomoo`05Ool00`00Oomoo`18Ool000Yoo`04001oogoo000:
Ool01@00Oomoogoo00008Woo00<007ooOol017oo00<007ooOol0B7oo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`80025oo`03001oogoo00Aoo`03001oogoo04Qoo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`0POol00`00Oomoo`04Ool00`00Oomoo`18Ool000]o
o`8000Uoo`<000=oo`80025oo`03001oogoo00=oo`03001oogoo04Uoo`0077oo00<007ooOol08Goo
00<007ooOol00Woo00<007ooOol0BGoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000ROol0
0`00Oomoo`02Ool00`00Oomoo`19Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00008goo00<0
07ooOol00Woo00<007ooOol0BGoo000:Ool01000Oomoo`001goo1@000Woo0P008goo00@007ooOol0
04aoo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0ROol01000Oomoo`00C7oo
000:Ool01000Oomoo`0027oo00<007oo00000goo0P008goo00<007oo0000CGoo000:Ool01000Oomo
o`002Goo0P000goo00<007ooOol08goo0P00CGoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000L
Ool00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<0
07ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo
00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001o
ogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P00
2Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007oo
Ool00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`00
5goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3800\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23178 L
.188 .23178 L
.192 .23178 L
.196 .23178 L
.2 .23178 L
Mistroke
.204 .23178 L
.208 .23179 L
.212 .23179 L
.216 .2318 L
.22 .23181 L
.224 .23183 L
.228 .23185 L
.232 .23188 L
.236 .23193 L
.24 .23199 L
.244 .23207 L
.248 .23218 L
.252 .23232 L
.256 .23251 L
.26 .23277 L
.264 .23309 L
.268 .23352 L
.272 .23405 L
.276 .23473 L
.28 .23557 L
.284 .23661 L
.288 .23788 L
.292 .23941 L
.296 .24124 L
.3 .24338 L
.304 .24587 L
.308 .24872 L
.312 .25194 L
.316 .25549 L
.32 .25937 L
.324 .2635 L
.328 .26782 L
.332 .27222 L
.336 .27656 L
.34 .2807 L
.344 .28446 L
.348 .28767 L
.352 .29014 L
.356 .2917 L
.36 .2922 L
.364 .29152 L
.368 .28962 L
.372 .28648 L
.376 .28217 L
.38 .27684 L
.384 .27068 L
.388 .26397 L
.392 .257 L
.396 .2501 L
.4 .24361 L
Mistroke
.404 .2378 L
.408 .23294 L
.412 .22918 L
.416 .2266 L
.42 .22518 L
.424 .22482 L
.428 .22532 L
.432 .22646 L
.436 .22796 L
.44 .22957 L
.444 .23106 L
.448 .23227 L
.452 .23311 L
.456 .23354 L
.46 .23359 L
.464 .23334 L
.468 .2329 L
.472 .23238 L
.476 .23186 L
.48 .23144 L
.484 .23116 L
.488 .23104 L
.492 .23107 L
.496 .23122 L
.5 .23147 L
.504 .23177 L
.508 .23206 L
.512 .23231 L
.516 .23247 L
.52 .2325 L
.524 .23238 L
.528 .2321 L
.532 .23168 L
.536 .23117 L
.54 .23065 L
.544 .23021 L
.548 .22996 L
.552 .23001 L
.556 .23043 L
.56 .23126 L
.564 .23246 L
.568 .23395 L
.572 .23555 L
.576 .23705 L
.58 .23819 L
.584 .2387 L
.588 .23834 L
.592 .23693 L
.596 .23436 L
.6 .23061 L
Mistroke
.604 .22576 L
.608 .21996 L
.612 .21347 L
.616 .20657 L
.62 .1996 L
.624 .19289 L
.628 .18673 L
.632 .18139 L
.636 .17708 L
.64 .17394 L
.644 .17203 L
.648 .17135 L
.652 .17184 L
.656 .1734 L
.66 .17587 L
.664 .17908 L
.668 .18285 L
.672 .18699 L
.676 .19134 L
.68 .19574 L
.684 .20006 L
.688 .2042 L
.692 .20808 L
.696 .21164 L
.7 .21485 L
.704 .21771 L
.708 .2202 L
.712 .22235 L
.716 .22417 L
.72 .2257 L
.724 .22697 L
.728 .22801 L
.732 .22886 L
.736 .22953 L
.74 .23007 L
.744 .23049 L
.748 .23082 L
.752 .23107 L
.756 .23126 L
.76 .23141 L
.764 .23152 L
.768 .2316 L
.772 .23166 L
.776 .2317 L
.78 .23173 L
.784 .23175 L
.788 .23177 L
.792 .23178 L
.796 .23179 L
.8 .2318 L
Mistroke
.804 .2318 L
.808 .2318 L
.812 .2318 L
.816 .23181 L
.82 .23181 L
.824 .23181 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35316 L
.184 .35316 L
.188 .35316 L
.192 .35315 L
.196 .35315 L
.2 .35314 L
Mistroke
.204 .35313 L
.208 .35312 L
.212 .3531 L
.216 .35307 L
.22 .35303 L
.224 .35297 L
.228 .35289 L
.232 .35278 L
.236 .35262 L
.24 .35241 L
.244 .35212 L
.248 .35173 L
.252 .35121 L
.256 .35053 L
.26 .34963 L
.264 .34846 L
.268 .34695 L
.272 .34504 L
.276 .34263 L
.28 .33962 L
.284 .3359 L
.288 .33136 L
.292 .32589 L
.296 .31936 L
.3 .31169 L
.304 .30278 L
.308 .29258 L
.312 .28109 L
.316 .26836 L
.32 .25449 L
.324 .23969 L
.328 .22424 L
.332 .20851 L
.336 .19297 L
.34 .17817 L
.344 .16471 L
.348 .15325 L
.352 .14444 L
.356 .13889 L
.36 .13714 L
.364 .13958 L
.368 .14644 L
.372 .15771 L
.376 .17315 L
.38 .19227 L
.384 .21431 L
.388 .23834 L
.392 .26326 L
.396 .28788 L
.4 .31105 L
Mistroke
.404 .33172 L
.408 .34904 L
.412 .36242 L
.416 .3716 L
.42 .37664 L
.424 .37793 L
.428 .37611 L
.432 .37202 L
.436 .36661 L
.44 .3608 L
.444 .35541 L
.448 .35107 L
.452 .34815 L
.456 .34679 L
.46 .34684 L
.464 .34797 L
.468 .34973 L
.472 .35165 L
.476 .35331 L
.48 .35443 L
.484 .3549 L
.488 .35476 L
.492 .35423 L
.496 .35356 L
.5 .35303 L
.504 .35283 L
.508 .35303 L
.512 .35356 L
.516 .35423 L
.52 .35476 L
.524 .3549 L
.528 .35443 L
.532 .35331 L
.536 .35165 L
.54 .34973 L
.544 .34797 L
.548 .34684 L
.552 .34679 L
.556 .34815 L
.56 .35107 L
.564 .35541 L
.568 .3608 L
.572 .36661 L
.576 .37202 L
.58 .37611 L
.584 .37793 L
.588 .37664 L
.592 .3716 L
.596 .36242 L
.6 .34904 L
Mistroke
.604 .33172 L
.608 .31105 L
.612 .28788 L
.616 .26326 L
.62 .23834 L
.624 .21431 L
.628 .19226 L
.632 .17315 L
.636 .15771 L
.64 .14644 L
.644 .13958 L
.648 .13714 L
.652 .13889 L
.656 .14443 L
.66 .15325 L
.664 .16471 L
.668 .17816 L
.672 .19297 L
.676 .20851 L
.68 .22424 L
.684 .23969 L
.688 .25449 L
.692 .26835 L
.696 .28109 L
.7 .29258 L
.704 .30277 L
.708 .31168 L
.712 .31936 L
.716 .32588 L
.72 .33136 L
.724 .3359 L
.728 .33962 L
.732 .34263 L
.736 .34504 L
.74 .34695 L
.744 .34846 L
.748 .34963 L
.752 .35053 L
.756 .35121 L
.76 .35173 L
.764 .35212 L
.768 .35241 L
.772 .35262 L
.776 .35278 L
.78 .35289 L
.784 .35297 L
.788 .35303 L
.792 .35307 L
.796 .3531 L
.8 .35312 L
Mistroke
.804 .35313 L
.808 .35314 L
.812 .35315 L
.816 .35315 L
.82 .35316 L
.824 .35316 L
.828 .35316 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23176 L
.176 .23176 L
.18 .23176 L
.184 .23177 L
.188 .23177 L
.192 .23177 L
.196 .23177 L
.2 .23178 L
Mistroke
.204 .23179 L
.208 .2318 L
.212 .23182 L
.216 .23184 L
.22 .23187 L
.224 .23192 L
.228 .23199 L
.232 .23209 L
.236 .23222 L
.24 .23239 L
.244 .23264 L
.248 .23296 L
.252 .2334 L
.256 .23398 L
.26 .23473 L
.264 .23571 L
.268 .23697 L
.272 .23858 L
.276 .24061 L
.28 .24313 L
.284 .24626 L
.288 .25007 L
.292 .25466 L
.296 .26014 L
.3 .26658 L
.304 .27406 L
.308 .28262 L
.312 .29227 L
.316 .30296 L
.32 .3146 L
.324 .32702 L
.328 .33999 L
.332 .3532 L
.336 .36624 L
.34 .37867 L
.344 .38997 L
.348 .3996 L
.352 .407 L
.356 .41166 L
.36 .41313 L
.364 .41108 L
.368 .40532 L
.372 .39586 L
.376 .38291 L
.38 .36687 L
.384 .34837 L
.388 .32821 L
.392 .30729 L
.396 .28662 L
.4 .26715 L
Mistroke
.404 .24978 L
.408 .23524 L
.412 .22401 L
.416 .21633 L
.42 .21214 L
.424 .21109 L
.428 .21264 L
.432 .21605 L
.436 .22054 L
.44 .22534 L
.444 .22978 L
.448 .23338 L
.452 .23583 L
.456 .23708 L
.46 .2372 L
.464 .23645 L
.468 .23513 L
.472 .23357 L
.476 .23206 L
.48 .23083 L
.484 .23001 L
.488 .22966 L
.492 .22975 L
.496 .23022 L
.5 .23095 L
.504 .23181 L
.508 .23268 L
.512 .23341 L
.516 .23387 L
.52 .23397 L
.524 .23361 L
.528 .2328 L
.532 .23156 L
.536 .23006 L
.54 .2285 L
.544 .22718 L
.548 .22643 L
.552 .22655 L
.556 .22779 L
.56 .23025 L
.564 .23385 L
.568 .23829 L
.572 .24309 L
.576 .24758 L
.58 .25099 L
.584 .25253 L
.588 .25149 L
.592 .2473 L
.596 .23962 L
.6 .22839 L
Mistroke
.604 .21384 L
.608 .19648 L
.612 .17701 L
.616 .15633 L
.62 .13542 L
.624 .11525 L
.628 .09676 L
.632 .08072 L
.636 .06776 L
.64 .0583 L
.644 .05255 L
.648 .0505 L
.652 .05197 L
.656 .05663 L
.66 .06403 L
.664 .07365 L
.668 .08495 L
.672 .09738 L
.676 .11043 L
.68 .12363 L
.684 .1366 L
.688 .14903 L
.692 .16067 L
.696 .17136 L
.7 .18101 L
.704 .18957 L
.708 .19705 L
.712 .20349 L
.716 .20897 L
.72 .21356 L
.724 .21737 L
.728 .22049 L
.732 .22302 L
.736 .22505 L
.74 .22665 L
.744 .22792 L
.748 .2289 L
.752 .22965 L
.756 .23023 L
.76 .23066 L
.764 .23099 L
.768 .23123 L
.772 .23141 L
.776 .23154 L
.78 .23164 L
.784 .2317 L
.788 .23175 L
.792 .23179 L
.796 .23181 L
.8 .23183 L
Mistroke
.804 .23184 L
.808 .23185 L
.812 .23185 L
.816 .23186 L
.82 .23186 L
.824 .23186 L
.828 .23186 L
.832 .23186 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool00`00Oomoo`04
0007Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol037oo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Uo
o`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`8000=oo`03001oogoo00=oo`80009oo`8000=oo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo
00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`H0
009oo`800003Ool0000000=oo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo
0P00?Goo0P001goo00<007ooOol0:Woo000LOol00`00Oomoo`0lOol00`00Oomoo`07Ool2000ZOol0
01aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool0
1@00Oomoogoo00000Woo100000=oo`00Ool00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool50003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol2000NOol0
0`00Oomoo`06Ool00`00Oomoo`19Ool001aoo`03001oogoo01ioo`03001oogoo00Eoo`03001oogoo
04Uoo`0077oo0P0087oo0P0017oo00<007ooOol0BWoo000LOol00`00Oomoo`0POol01@00Oomoogoo
0000CGoo000;Ool20004Ool01000Oomoogoo1@000Woo0P008Woo1000CGoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`03001oogoo029oo`03001oogoo04eoo`002Woo00@007ooOol000Uoo`03
001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0
001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007Ool01000Oomo
o`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00Lgoo000:Ool0
1000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000L
Ool00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<0
07ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo
00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001o
ogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P00
2Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007oo
Ool00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`00
5goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
2goo0P0017oo00<007ooOol00Woo0`00N7oo000:Ool01000Oomoo`001goo00D007ooOomoo`0007Mo
o`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo
0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002goo0P002Goo
0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<0
07ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo079oo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool40003Ool2001cOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool2001cOol000]oo`8000Yoo`80
00=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`0ROol2000LOol2000`Ool000]o
o`8000Aoo`03001oogoo00=oo`<0009oo`80029oo`03001oo`0001]oo`03001oo`00031oo`002Woo
00@007ooOol000Yoo`05001oogooOol0000SOol01000Oomoo`006Woo00@007ooOol002moo`000goo
1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo025oo`04001oogoo000JOol01000Oomoo`00
;goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`80025oo`05001oogooOol0000JOol01000
Oomoo`00;goo000:Ool01000Oomoo`0027oo00<007oo00000goo00<007ooOol087oo00D007ooOomo
o`0001Uoo`03001oogoo009oo`03001oogoo02aoo`002Woo00@007ooOol000Uoo`8000=oo`80025o
o`05001oogooOol0000IOol00`00Oomoo`02Ool00`00Oomoo`0/Ool000]oo`8000]oo`05001oogoo
Ool0000ROol00`00Oomoo`02Ool00`00Oomoo`0FOol00`00Oomoo`02Ool00`00Oomoo`0/Ool001ao
o`80025oo`03001oogoo009oo`03001oogoo01Ioo`03001oogoo009oo`03001oogoo02aoo`0077oo
00<007ooOol07goo00<007ooOol00goo00<007ooOol05Woo00<007ooOol00Woo00<007ooOol0;7oo
000;Ool20004Ool01000Oomoogoo1@000Woo0P0087oo00<007ooOol00goo00<007ooOol05Goo00<0
07ooOol017oo00<007ooOol0:goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo
01moo`03001oogoo00=oo`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo02]oo`000goo1@00
0Woo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo01ioo`03001oogoo00Eoo`03001oogoo
01Aoo`03001oogoo00Aoo`03001oogoo02]oo`002Woo00@007ooOol000Yoo`04001oogooOol2000>
Ool30004Ool20008Ool40004Ool20004Ool20005Ool30003Ool3000017oo001oogoo0P000goo00<0
07oo000010000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo00aoo`05001oogooOol00002Ool01000Oomoo`001Woo00@0
07ooOol000Aoo`800005Ool007ooOol00002Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo0P00
00Eoo`00Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo00=oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol017oo00@007oo
Ool000Aoo`800005Ool007ooOol00002Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Goo0`000goo00<007ooOol047oo
00@007ooOol0009oo`03001oogoo00Aoo`04001oogoo0004Ool200001Goo001oogoo00000Woo00<0
07ooOol00goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00003Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00
Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0006Ool01000Oomoo`0017oo00@007oo0000
009oo`04001oogoo0005Ool01000Oomoogoo1@000Woo00@007ooOol000=oo`8000=oo`04001oogoo
0002Ool01000Oomoo`000Woo00<007ooOol00Woo00H007ooOomoo`00Ool40003Ool01000Oomoo`00
1Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`001Goo00<007ooOol00P0017oo
00@007oo0000009oo`04001oogoo0004Ool20003Ool01@00Oomoogoo00000Woo00@007ooOol000=o
o`8000=oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo00L007ooOomoo`00Ool0
0006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool20005Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Goo100017oo0P0017oo0P00
1Woo0`000Woo1@000goo0P001Woo000LOol2000LOol00`00Oomoo`09Ool00`00Oomoo`0BOol00`00
Oomoo`09Ool00`00Oomoo`0WOol001aoo`03001oogoo01Uoo`8000aoo`03001oogoo009oo`8000Mo
o`<000=oo`03001oogoo00Yoo`<002Moo`0077ooJ@0037oo000LOol00`00Oomoo`0BOol00`00Oomo
o`0BOol200000goo0000000<Ool01000Oomoo`0057oo00<007ooOol04Woo00<007ooOol02Woo000L
Ool2000YOol3000>Ool2000gOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`002goo0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0009Ool00`00
Oomoo`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol0
00Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001o
ogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo0000
0goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01@00
Oomoogoo0000M7oo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007oo
Ool00goo0`000Woo0P00@Goo0P00<7oo000:Ool01000Oomoo`002Woo00D007ooOomoo`00045oo`03
001oo`00031oo`000goo1@000Woo00@007ooOol000Moo`D0009oo`80041oo`04001oogoo000_Ool0
00Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0?goo00@007ooOol002moo`002Woo
00@007ooOol000Qoo`03001oo`0000=oo`80041oo`04001oogoo000_Ool000Yoo`04001oogoo0009
Ool20003Ool00`00Oomoo`0nOol00`00Oomoo`02Ool00`00Oomoo`0/Ool000]oo`8000]oo`04001o
ogooOol2000oOol00`00Oomoo`02Ool00`00Oomoo`0/Ool001aoo`03001oogoo03ioo`03001oogoo
009oo`03001oogoo02aoo`002goo0P0017oo00@007ooOomoo`D0009oo`8003ioo`03001oogoo00=o
o`03001oogoo02aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0=Ool30004
Ool20009Ool30004Ool20004Ool20005Ool30003Ool3000017oo001oogoo0P000Woo00<007ooOol0
1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`002Goo
00<007ooOol00Woo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool200001goo001oogoo001oo`00
00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo
00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Yoo`05001oogooOol0000BOol0
1000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`05Ool200001Goo001oogoo00000Woo00D007ooOomoo`0000Aoo`04001oogoo0002
Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool200001Goo001oogoo
00000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogooOol50002Ool01000Oomoo`000goo0P000goo00@007oo
Ool0009oo`04001oogoo0002Ool00`00Oomoo`02Ool01P00Oomoogoo001oo`@000=oo`04001oogoo
0005Ool000]oo`8000Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`05001oogooOol00002Ool01000Oomoo`000goo
0P000goo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`00
00Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`03001oogoo00=oo`80
00Aoo`8000Ioo`04001oogooOol50003Ool20004Ool00`00Ool000020004Ool20004Ool20006Ool3
0002Ool50003Ool20006Ool001aoo`8002Yoo`03001oogoo011oo`03001oogoo00Qoo`03001oogoo
02Qoo`0077oo00<007ooOol0:7oo00<007oo00004Goo00<007ooOol02Goo00<007ooOol09goo000L
OomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00@0
07ooOomoo`D000=oo`05001oogooOol00004Ool01000Oomoogoo1@000Woo0`000Woo0P000Woo00D0
07ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo0P006goo0P002goo00<007oo
Ool03Woo0`00=goo000LOol00`00Oomoo`0KOol2000:Ool00`00Oomoo`0@Ool00`00Oomoo`0eOol0
01aoo`8001eoo`03001oogoo00Qoo`03001oogoo04Qoo`0077oo00<007ooOol07Goo00<007ooOol0
1goo00<007ooOol0B7oo000;Ool20004Ool01000Oomoogoo1@000Woo0P007Woo00<007ooOol01Woo
00<007ooOol0BGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo01eoo`03001o
ogoo00Ioo`03001oogoo04Uoo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8001moo`03001o
ogoo00Eoo`03001oogoo04Uoo`002Woo00@007ooOol000Yoo`05001oogooOol0000POol00`00Oomo
o`05Ool00`00Oomoo`19Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P0087oo00<0
07ooOol00goo00<007ooOol0BWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo01moo`03001oogoo00=oo`03001oogoo04Yoo`002goo0P002Goo0`000goo0P0087oo00<007oo
Ool00goo00<007ooOol0BWoo000LOol00`00Oomoo`0POol00`00Oomoo`02Ool00`00Oomoo`1:Ool0
00]oo`8000Aoo`03001oogoo00=oo`<0009oo`80025oo`05001oogooOol0001=Ool000Yoo`04001o
ogoo000:Ool01@00Oomoogoo00008Woo00D007ooOomoo`0004eoo`002Woo00@007ooOol000Moo`D0
009oo`80025oo`05001oogooOol0001=Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo00<0
07ooOol08Goo00@007ooOol004eoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`80029oo`03
001oo`0004ioo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo029oo`8004ioo`002goo0P00
2goo00@007ooOomoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool3
0003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007oo
Ool000Qoo`03001oogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol0
0`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00Lgoo000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol3
0003Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00
Lgoo000GOol00`00Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomo
o`1gOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3840\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23178 L
.176 .23178 L
.18 .23178 L
.184 .23178 L
.188 .23178 L
.192 .23178 L
.196 .23179 L
.2 .23179 L
Mistroke
.204 .2318 L
.208 .23181 L
.212 .23183 L
.216 .23185 L
.22 .23188 L
.224 .23193 L
.228 .23199 L
.232 .23207 L
.236 .23218 L
.24 .23233 L
.244 .23252 L
.248 .23277 L
.252 .2331 L
.256 .23353 L
.26 .23406 L
.264 .23474 L
.268 .23558 L
.272 .23662 L
.276 .23789 L
.28 .23942 L
.284 .24125 L
.288 .24339 L
.292 .24587 L
.296 .24872 L
.3 .25192 L
.304 .25547 L
.308 .25933 L
.312 .26345 L
.316 .26775 L
.32 .27214 L
.324 .27647 L
.328 .2806 L
.332 .28436 L
.336 .28757 L
.34 .29005 L
.344 .29162 L
.348 .29215 L
.352 .2915 L
.356 .28963 L
.36 .28653 L
.364 .28226 L
.368 .27696 L
.372 .27083 L
.376 .26414 L
.38 .25717 L
.384 .25027 L
.388 .24376 L
.392 .23793 L
.396 .23302 L
.4 .22921 L
Mistroke
.404 .22657 L
.408 .22511 L
.412 .2247 L
.416 .22518 L
.42 .2263 L
.424 .22782 L
.428 .22947 L
.432 .23102 L
.436 .23228 L
.44 .23315 L
.444 .23359 L
.448 .23363 L
.452 .23334 L
.456 .23286 L
.46 .23231 L
.464 .2318 L
.468 .23143 L
.472 .23124 L
.476 .23121 L
.48 .23132 L
.484 .23149 L
.488 .23167 L
.492 .2318 L
.496 .23186 L
.5 .23184 L
.504 .23177 L
.508 .23171 L
.512 .23168 L
.516 .23173 L
.52 .23186 L
.524 .23204 L
.528 .23221 L
.532 .23232 L
.536 .2323 L
.54 .23211 L
.544 .23174 L
.548 .23124 L
.552 .23069 L
.556 .23021 L
.56 .22992 L
.564 .22995 L
.568 .23038 L
.572 .23125 L
.576 .23251 L
.58 .23404 L
.584 .23569 L
.588 .23721 L
.592 .23833 L
.596 .23882 L
.6 .23842 L
Mistroke
.604 .23696 L
.608 .23433 L
.612 .23053 L
.616 .22563 L
.62 .21981 L
.624 .2133 L
.628 .2064 L
.632 .19944 L
.636 .19274 L
.64 .1866 L
.644 .1813 L
.648 .17702 L
.652 .17392 L
.656 .17204 L
.66 .1714 L
.664 .17192 L
.668 .17349 L
.672 .17597 L
.676 .17918 L
.68 .18295 L
.684 .18708 L
.688 .19142 L
.692 .19581 L
.696 .20012 L
.7 .20424 L
.704 .20811 L
.708 .21166 L
.712 .21486 L
.716 .21771 L
.72 .22019 L
.724 .22234 L
.728 .22416 L
.732 .22569 L
.736 .22696 L
.74 .228 L
.744 .22884 L
.748 .22952 L
.752 .23006 L
.756 .23048 L
.76 .23081 L
.764 .23106 L
.768 .23126 L
.772 .2314 L
.776 .23151 L
.78 .23159 L
.784 .23165 L
.788 .2317 L
.792 .23173 L
.796 .23175 L
.8 .23177 L
Mistroke
.804 .23178 L
.808 .23179 L
.812 .2318 L
.816 .2318 L
.82 .2318 L
.824 .2318 L
.828 .23181 L
.832 .23181 L
.836 .23181 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35316 L
.172 .35316 L
.176 .35316 L
.18 .35315 L
.184 .35315 L
.188 .35314 L
.192 .35313 L
.196 .35312 L
.2 .3531 L
Mistroke
.204 .35307 L
.208 .35303 L
.212 .35297 L
.216 .35289 L
.22 .35277 L
.224 .35261 L
.228 .3524 L
.232 .35211 L
.236 .35172 L
.24 .35119 L
.244 .3505 L
.248 .3496 L
.252 .34843 L
.256 .34692 L
.26 .345 L
.264 .34258 L
.268 .33957 L
.272 .33585 L
.276 .33131 L
.28 .32584 L
.284 .31933 L
.288 .31167 L
.292 .30278 L
.296 .29261 L
.3 .28116 L
.304 .26846 L
.308 .25464 L
.312 .23989 L
.316 .22449 L
.32 .2088 L
.324 .1933 L
.328 .17852 L
.332 .16507 L
.336 .1536 L
.34 .14475 L
.344 .13915 L
.348 .13731 L
.352 .13965 L
.356 .14639 L
.36 .15752 L
.364 .17283 L
.368 .19182 L
.372 .21376 L
.376 .23772 L
.38 .26261 L
.384 .28726 L
.388 .31052 L
.392 .33133 L
.396 .34881 L
.4 .36236 L
Mistroke
.404 .3717 L
.408 .37687 L
.412 .37825 L
.416 .37649 L
.42 .37244 L
.424 .36704 L
.428 .36122 L
.432 .35579 L
.436 .35136 L
.44 .34832 L
.444 .34678 L
.448 .34661 L
.452 .34754 L
.456 .34916 L
.46 .35106 L
.464 .35287 L
.468 .3543 L
.472 .35519 L
.476 .35551 L
.48 .3553 L
.484 .35471 L
.488 .35391 L
.492 .35307 L
.496 .35234 L
.5 .35186 L
.504 .35169 L
.508 .35186 L
.512 .35234 L
.516 .35307 L
.52 .35391 L
.524 .35471 L
.528 .3553 L
.532 .35551 L
.536 .35519 L
.54 .3543 L
.544 .35287 L
.548 .35106 L
.552 .34916 L
.556 .34754 L
.56 .34661 L
.564 .34678 L
.568 .34832 L
.572 .35136 L
.576 .35579 L
.58 .36122 L
.584 .36704 L
.588 .37244 L
.592 .37649 L
.596 .37825 L
.6 .37687 L
Mistroke
.604 .3717 L
.608 .36236 L
.612 .34881 L
.616 .33133 L
.62 .31052 L
.624 .28726 L
.628 .26261 L
.632 .23772 L
.636 .21376 L
.64 .19181 L
.644 .17283 L
.648 .15752 L
.652 .14638 L
.656 .13965 L
.66 .13731 L
.664 .13914 L
.668 .14475 L
.672 .1536 L
.676 .16507 L
.68 .17852 L
.684 .1933 L
.688 .2088 L
.692 .22448 L
.696 .23989 L
.7 .25464 L
.704 .26846 L
.708 .28116 L
.712 .29261 L
.716 .30278 L
.72 .31167 L
.724 .31933 L
.728 .32584 L
.732 .33131 L
.736 .33585 L
.74 .33957 L
.744 .34258 L
.748 .345 L
.752 .34692 L
.756 .34843 L
.76 .3496 L
.764 .3505 L
.768 .35119 L
.772 .35172 L
.776 .35211 L
.78 .3524 L
.784 .35261 L
.788 .35277 L
.792 .35289 L
.796 .35297 L
.8 .35303 L
Mistroke
.804 .35307 L
.808 .3531 L
.812 .35312 L
.816 .35313 L
.82 .35314 L
.824 .35315 L
.828 .35315 L
.832 .35316 L
.836 .35316 L
.84 .35316 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23176 L
.164 .23176 L
.168 .23176 L
.172 .23177 L
.176 .23177 L
.18 .23177 L
.184 .23177 L
.188 .23178 L
.192 .23179 L
.196 .2318 L
.2 .23182 L
Mistroke
.204 .23184 L
.208 .23188 L
.212 .23193 L
.216 .23199 L
.22 .23209 L
.224 .23222 L
.228 .2324 L
.232 .23265 L
.236 .23298 L
.24 .23342 L
.244 .234 L
.248 .23475 L
.252 .23574 L
.256 .237 L
.26 .23862 L
.264 .24064 L
.268 .24317 L
.272 .2463 L
.276 .2501 L
.28 .25469 L
.284 .26016 L
.288 .26659 L
.292 .27406 L
.296 .28259 L
.3 .29221 L
.304 .30287 L
.308 .31447 L
.312 .32685 L
.316 .33979 L
.32 .35295 L
.324 .36597 L
.328 .37838 L
.332 .38967 L
.336 .3993 L
.34 .40673 L
.344 .41144 L
.348 .41298 L
.352 .41102 L
.356 .40537 L
.36 .39603 L
.364 .38318 L
.368 .36725 L
.372 .34883 L
.376 .32871 L
.38 .30782 L
.384 .28712 L
.388 .2676 L
.392 .25015 L
.396 .23548 L
.4 .22411 L
Mistroke
.404 .21627 L
.408 .21191 L
.412 .21074 L
.416 .2122 L
.42 .21559 L
.424 .22013 L
.428 .22505 L
.432 .22965 L
.436 .2334 L
.44 .23597 L
.444 .23724 L
.448 .23732 L
.452 .23646 L
.456 .23501 L
.46 .23337 L
.464 .23188 L
.468 .23079 L
.472 .23022 L
.476 .23016 L
.48 .23049 L
.484 .23102 L
.488 .23155 L
.492 .23194 L
.496 .23209 L
.5 .23202 L
.504 .23181 L
.508 .23161 L
.512 .23154 L
.516 .23169 L
.52 .23207 L
.524 .23261 L
.528 .23314 L
.532 .23347 L
.536 .23341 L
.54 .23284 L
.544 .23175 L
.548 .23026 L
.552 .22862 L
.556 .22717 L
.56 .22631 L
.564 .22639 L
.568 .22766 L
.572 .23023 L
.576 .23398 L
.58 .23858 L
.584 .24349 L
.588 .24804 L
.592 .25143 L
.596 .25289 L
.6 .25171 L
Mistroke
.604 .24736 L
.608 .23952 L
.612 .22815 L
.616 .21348 L
.62 .19602 L
.624 .1765 L
.628 .15581 L
.632 .13491 L
.636 .1148 L
.64 .09638 L
.644 .08044 L
.648 .0676 L
.652 .05825 L
.656 .0526 L
.66 .05064 L
.664 .05219 L
.668 .05689 L
.672 .06432 L
.676 .07396 L
.68 .08525 L
.684 .09766 L
.688 .11067 L
.692 .12384 L
.696 .13677 L
.7 .14916 L
.704 .16076 L
.708 .17142 L
.712 .18103 L
.716 .18957 L
.72 .19703 L
.724 .20346 L
.728 .20893 L
.732 .21352 L
.736 .21733 L
.74 .22045 L
.744 .22298 L
.748 .22501 L
.752 .22662 L
.756 .22789 L
.76 .22887 L
.764 .22963 L
.768 .23021 L
.772 .23065 L
.776 .23098 L
.78 .23122 L
.784 .2314 L
.788 .23154 L
.792 .23163 L
.796 .2317 L
.8 .23175 L
Mistroke
.804 .23179 L
.808 .23181 L
.812 .23183 L
.816 .23184 L
.82 .23185 L
.824 .23185 L
.828 .23186 L
.832 .23186 L
.836 .23186 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01@00Oomoo`00
Ool00P001goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogooOol40003Ool200000goo00000003Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]o
o`8000Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000Woo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000Woo0`000goo0P0000Aoo`00000000Aoo`8000Aoo`8000Ioo`<0009oo`D000=o
o`8000Ioo`0077oo0P00?goo00<007ooOol01Goo00<007ooOol0:Goo000LOol00`00Oomoo`0mOol0
0`00Oomoo`07Ool2000YOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009o
o`05001oogooOol00003Ool01P00Oomoogoo001oo`@0009oo`05001oogooOol00003Ool20003Ool0
1@00Oomoogoo00000goo00H007ooOomoo`00Ool40002Ool01@00Oomoogoo000017oo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol0
2Woo000LOol2000LOol20008Ool00`00Oomoo`1:Ool001aoo`03001oogoo01eoo`03001oogoo00Ao
o`03001oogoo04]oo`0077oo0P007Woo0P001Goo00<007ooOol0Bgoo000LOol00`00Oomoo`0OOol0
1@00Oomoogoo0000CWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P008Goo0`00Cgoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`03001oogoo025oo`03001oogoo04ioo`002Woo00@007oo
Ool000Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001oogooOol0001dOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomo
o`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@007ooOol000Yoo`05
001oogooOol0001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yoo`04001oogoo0007
Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007oo00000goo0P00
Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;Ool01000Oomoogoo
0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007oo
Ool00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03001oogoo079oo`00
2goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol0
00Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079o
o`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`00
5goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001o
ogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo07Moo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`002goo0P0017oo00<007ooOol00Woo0`00N7oo000:Ool01000Oomoo`001goo00D007oo
Oomoo`0007Moo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yo
o`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`00
2goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool40003Ool2001cOol000Yoo`04001oogoo0007Ool00`00
Oomoo`04Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool2001cOol000]o
o`8000Yoo`8000=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`0POol3000NOol2
000_Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`80025oo`03001oo`0001ioo`03001oo`00
02ioo`002Woo00@007ooOol000Yoo`05001oogooOol0000ROol00`00Ool0000MOol01000Oomoo`00
;Woo0003Ool50002Ool01000Oomoo`001goo1@000Woo00<007ooOol087oo00@007ooOol001aoo`04
001oogoo000^Ool000Yoo`04001oogoo0007Ool01000Oomoo`000goo0P0087oo00D007ooOomoo`00
01aoo`04001oogoo000^Ool000Yoo`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`0OOol0
1@00Oomoogoo00006goo00<007ooOol00Woo00<007ooOol0:goo000:Ool01000Oomoo`002Goo0P00
0goo0P0087oo00D007ooOomoo`0001]oo`03001oogoo009oo`03001oogoo02]oo`002goo0P002goo
00D007ooOomoo`00021oo`03001oogoo00=oo`03001oogoo01Qoo`03001oogoo009oo`03001oogoo
02]oo`0077oo0P007goo00<007ooOol00goo00<007ooOol067oo00<007ooOol00Woo00<007ooOol0
:goo000LOol00`00Oomoo`0NOol00`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`03Ool00`00
Oomoo`0ZOol000]oo`8000Aoo`04001oogooOol50002Ool2000NOol00`00Oomoo`04Ool00`00Oomo
o`0HOol00`00Oomoo`03Ool00`00Oomoo`0ZOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00<007ooOol07Goo00<007ooOol017oo00<007ooOol067oo00<007ooOol00goo00<007ooOol0:Woo
0003Ool50002Ool01000Oomoo`002Goo00<007ooOol00Woo00<007ooOol07Goo00<007ooOol017oo
00<007ooOol05goo00<007ooOol01Goo00<007ooOol0:Goo000:Ool01000Oomoo`002Woo00@007oo
Oomoo`8000ioo`<000Aoo`8000Moo`03001oo`000080009oo`04001oo`000004Ool20005Ool30003
Ool30002Ool01000Ool0000017oo1P000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`05001oogooOol00002Ool0
1000Oomoo`001Goo00D007ooOomoo`0000=oo`80009oo`04001oogoo0002Ool00`00Oomoo`03Ool0
1@00Oomoogoo00000goo00@007oo0000009oo`07001oogooOol007oo00000Woo00@007ooOol0009o
o`04001oogoo0002Ool00`00Oomoo`03Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo00@007ooOol0009o
o`03001oogoo00=oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo00Eoo`04001oo`000002Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool20009
Ool30003Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`0000Ao
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007oo0000009oo`03001oogoo
009oo`04001oogoo0003Ool01000Oomoo`000Woo00@007ooOol000Moo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0004Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol4000017oo001o
o`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04
Ool01000Oomoo`0017oo00@007ooOomoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P00
0goo00<007ooOol00Woo00<007oo00000Woo00<007ooOol00Woo0P000Woo00@007ooOol0009oo`04
001oogoo0002Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001ao
o`03001oogoo00aoo`D000=oo`8000Aoo`03001oogoo00=oo`03001oogoo00=oo`8000Aoo`8000Io
o`04001oogooOol60002Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool0
01aoo`8001Yoo`8000]oo`03001oogoo01Aoo`03001oogoo00Uoo`8002Moo`0077oo00<007ooOol0
5goo0`0037oo00<007ooOol00Woo0P002Goo0`000goo00<007ooOol02goo0P009Woo000LOomY000<
Ool001aoo`03001oogoo019oo`03001oogoo019oo`03001oo`0000moo`@001=oo`03001oogoo019o
o`03001oogoo00Yoo`0077oo0P00:7oo0`0047oo0`00=Goo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`04001oogooOol5
0002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol0LWoo000:Ool0
1000Oomoo`002Goo00<007ooOol00Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`00
07Aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001c
Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo
0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079o
o`002goo0P002goo00D007ooOomoo`0007Aoo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
00]oo`8000Aoo`03001oogoo00=oo`<0009oo`80049oo`8002moo`002Woo00@007ooOol000Yoo`05
001oogooOol00012Ool200000goo001oo`0]Ool000=oo`D0009oo`04001oogoo0007Ool50002Ool2
0011Ool01000Oomoo`00;Woo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001oogoo041o
o`04001oogoo000^Ool000Yoo`04001oogoo0008Ool00`00Ool00003Ool20010Ool01@00Oomoogoo
0000;Woo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0?goo00<007ooOol00Woo00<007oo
Ool0:goo000;Ool2000;Ool01000Oomoogoo0P00@7oo00<007ooOol00Woo00<007ooOol0:goo000L
Ool00`00Oomoo`0oOol00`00Oomoo`03Ool00`00Oomoo`0ZOol000]oo`8000Aoo`04001oogooOol5
0002Ool20010Ool00`00Oomoo`03Ool00`00Oomoo`0ZOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`000goo
0`000goo00<007oo000010000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo0003Ool50002
Ool01000Oomoo`002Goo00<007ooOol00Woo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000
Ool000000Woo00L007ooOomoo`00Ool00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo00=oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Yoo`05001oogooOol0000BOol01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Ool000000Woo00D007ooOomo
o`00009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000A
Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`05Ool01000Ool000000Woo00D007ooOomoo`0000=oo`05001oogooOol00002
Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000
Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo1000
0Woo0P000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
17oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool2000=Ool0
0`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003
Ool00`00Oomoo`03Ool20002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo
00aoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol60002Ool20006
Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`8002Qoo`8001Aoo`03001o
ogoo00Qoo`03001oogoo02Moo`0077oo00<007ooOol09goo00<007oo00004goo00<007ooOol02Goo
0P009goo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00<007oo00001P000goo00D007ooOomoo`0000=oo`80009oo`@00003Ool007oo009oo`<0
0005Ool007oo001oo`020002Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol2000JOol2
000;Ool00`00Oomoo`0AOol00`00Ool0000eOol001aoo`03001oogoo01Yoo`8000Yoo`03001oogoo
019oo`03001oogoo03Aoo`0077oo0P0077oo00<007ooOol01goo00<007ooOol0BWoo000LOol00`00
Oomoo`0KOol00`00Oomoo`07Ool00`00Oomoo`1:Ool000]oo`8000Aoo`04001oogooOol50002Ool2
000MOol00`00Oomoo`06Ool00`00Oomoo`1:Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00<007ooOol077oo00<007ooOol01Woo00<007ooOol0BWoo000:Ool01000Oomoo`002Goo00<007oo
Ool00Woo0P007Woo00<007ooOol017oo00<007ooOol0Bgoo000:Ool01000Oomoo`002Woo00D007oo
Oomoo`0001moo`03001oogoo00Aoo`03001oogoo04]oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool2000NOol00`00Oomoo`04Ool00`00Oomoo`1;Ool000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol07Goo00<007ooOol017oo00<007ooOol0Bgoo000;Ool20009Ool3
0003Ool2000OOol00`00Oomoo`03Ool00`00Oomoo`1;Ool001aoo`03001oogoo01ioo`03001oogoo
00=oo`03001oogoo04]oo`002goo0P0017oo00<007ooOol00goo0`000Woo0P0087oo00D007ooOomo
o`0004ioo`002Woo00@007ooOol000Yoo`05001oogooOol0000QOol01@00Oomoogoo0000CWoo000:
Ool01000Oomoo`001goo1@000Woo0P0087oo00D007ooOomoo`0004ioo`002Woo00@007ooOol000Mo
o`04001oogoo0003Ool00`00Oomoo`0POol00`00Ool0001?Ool000Yoo`04001oogoo0008Ool00`00
Ool00003Ool2000QOol00`00Ool0001?Ool000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`0P
Ool3001?Ool000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo0P00
17oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04
001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2
001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`80
00=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001c
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03
001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Mo
o`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`80
07Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3880\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23178 L
.164 .23178 L
.168 .23178 L
.172 .23178 L
.176 .23178 L
.18 .23178 L
.184 .23179 L
.188 .23179 L
.192 .2318 L
.196 .23181 L
.2 .23183 L
Mistroke
.204 .23185 L
.208 .23189 L
.212 .23193 L
.216 .23199 L
.22 .23207 L
.224 .23218 L
.228 .23233 L
.232 .23253 L
.236 .23278 L
.24 .23311 L
.244 .23354 L
.248 .23407 L
.252 .23475 L
.256 .2356 L
.26 .23664 L
.264 .23791 L
.268 .23944 L
.272 .24125 L
.276 .24339 L
.28 .24587 L
.284 .24871 L
.288 .2519 L
.292 .25544 L
.296 .25929 L
.3 .2634 L
.304 .26769 L
.308 .27206 L
.312 .27638 L
.316 .2805 L
.32 .28426 L
.324 .28747 L
.328 .28996 L
.332 .29155 L
.336 .2921 L
.34 .29148 L
.344 .28965 L
.348 .28658 L
.352 .28235 L
.356 .27709 L
.36 .27099 L
.364 .26431 L
.368 .25735 L
.372 .25044 L
.376 .24391 L
.38 .23804 L
.384 .23309 L
.388 .22923 L
.392 .22655 L
.396 .22504 L
.4 .2246 L
Mistroke
.404 .22506 L
.408 .22618 L
.412 .2277 L
.416 .22936 L
.42 .23093 L
.424 .23222 L
.428 .23313 L
.432 .2336 L
.436 .23367 L
.44 .23342 L
.444 .23296 L
.448 .23241 L
.452 .23189 L
.456 .23147 L
.46 .23121 L
.464 .23112 L
.468 .23118 L
.472 .23134 L
.476 .23156 L
.48 .23177 L
.484 .23195 L
.488 .23205 L
.492 .23208 L
.496 .23202 L
.5 .23191 L
.504 .23177 L
.508 .23163 L
.512 .23152 L
.516 .23146 L
.52 .23148 L
.524 .23159 L
.528 .23176 L
.532 .23198 L
.536 .23219 L
.54 .23235 L
.544 .23241 L
.548 .23233 L
.552 .23207 L
.556 .23166 L
.56 .23114 L
.564 .23059 L
.568 .23013 L
.572 .22988 L
.576 .22994 L
.58 .23041 L
.584 .23131 L
.588 .23259 L
.592 .23415 L
.596 .23581 L
.6 .23733 L
Mistroke
.604 .23845 L
.608 .23892 L
.612 .23848 L
.616 .23698 L
.62 .23431 L
.624 .23046 L
.628 .22552 L
.632 .21966 L
.636 .21313 L
.64 .20622 L
.644 .19926 L
.648 .19258 L
.652 .18648 L
.656 .18121 L
.66 .17697 L
.664 .1739 L
.668 .17206 L
.672 .17145 L
.676 .17199 L
.68 .17358 L
.684 .17607 L
.688 .17928 L
.692 .18304 L
.696 .18717 L
.7 .1915 L
.704 .19587 L
.708 .20017 L
.712 .20428 L
.716 .20814 L
.72 .21168 L
.724 .21487 L
.728 .21771 L
.732 .22019 L
.736 .22233 L
.74 .22415 L
.744 .22568 L
.748 .22695 L
.752 .22799 L
.756 .22883 L
.76 .22951 L
.764 .23005 L
.768 .23047 L
.772 .2308 L
.776 .23106 L
.78 .23125 L
.784 .2314 L
.788 .23151 L
.792 .23159 L
.796 .23165 L
.8 .2317 L
Mistroke
.804 .23173 L
.808 .23175 L
.812 .23177 L
.816 .23178 L
.82 .23179 L
.824 .2318 L
.828 .2318 L
.832 .2318 L
.836 .2318 L
.84 .23181 L
.844 .23181 L
.848 .23181 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35316 L
.16 .35316 L
.164 .35316 L
.168 .35315 L
.172 .35315 L
.176 .35314 L
.18 .35313 L
.184 .35312 L
.188 .3531 L
.192 .35307 L
.196 .35302 L
.2 .35296 L
Mistroke
.204 .35288 L
.208 .35277 L
.212 .35261 L
.216 .35239 L
.22 .3521 L
.224 .3517 L
.228 .35117 L
.232 .35048 L
.236 .34957 L
.24 .34839 L
.244 .34688 L
.248 .34496 L
.252 .34254 L
.256 .33952 L
.26 .3358 L
.264 .33127 L
.268 .3258 L
.272 .3193 L
.276 .31165 L
.28 .30279 L
.284 .29264 L
.288 .28122 L
.292 .26857 L
.296 .25479 L
.3 .24008 L
.304 .22473 L
.308 .20909 L
.312 .19362 L
.316 .17887 L
.32 .16543 L
.324 .15395 L
.328 .14507 L
.332 .13941 L
.336 .13749 L
.34 .13972 L
.344 .14633 L
.348 .15733 L
.352 .17251 L
.356 .19137 L
.36 .21321 L
.364 .23711 L
.368 .26198 L
.372 .28666 L
.376 .30999 L
.38 .33091 L
.384 .34853 L
.388 .36225 L
.392 .37177 L
.396 .37711 L
.4 .37863 L
Mistroke
.404 .37697 L
.408 .37296 L
.412 .36753 L
.416 .36161 L
.42 .35604 L
.424 .35145 L
.428 .34826 L
.432 .34661 L
.436 .34641 L
.44 .34737 L
.444 .34906 L
.448 .35105 L
.452 .35291 L
.456 .35433 L
.46 .35514 L
.464 .35533 L
.468 .35501 L
.472 .35438 L
.476 .35367 L
.48 .35306 L
.484 .35269 L
.488 .35258 L
.492 .35268 L
.496 .35289 L
.5 .35308 L
.504 .35316 L
.508 .35308 L
.512 .35289 L
.516 .35268 L
.52 .35258 L
.524 .35269 L
.528 .35306 L
.532 .35367 L
.536 .35438 L
.54 .35501 L
.544 .35533 L
.548 .35514 L
.552 .35433 L
.556 .35291 L
.56 .35105 L
.564 .34906 L
.568 .34737 L
.572 .34641 L
.576 .34661 L
.58 .34826 L
.584 .35145 L
.588 .35604 L
.592 .36161 L
.596 .36753 L
.6 .37296 L
Mistroke
.604 .37697 L
.608 .37863 L
.612 .37711 L
.616 .37177 L
.62 .36225 L
.624 .34853 L
.628 .33091 L
.632 .30999 L
.636 .28666 L
.64 .26198 L
.644 .23711 L
.648 .21321 L
.652 .19137 L
.656 .1725 L
.66 .15733 L
.664 .14633 L
.668 .13972 L
.672 .13748 L
.676 .1394 L
.68 .14507 L
.684 .15395 L
.688 .16543 L
.692 .17887 L
.696 .19362 L
.7 .20909 L
.704 .22473 L
.708 .24008 L
.712 .25479 L
.716 .26857 L
.72 .28122 L
.724 .29264 L
.728 .30278 L
.732 .31165 L
.736 .3193 L
.74 .3258 L
.744 .33127 L
.748 .3358 L
.752 .33952 L
.756 .34254 L
.76 .34496 L
.764 .34688 L
.768 .34839 L
.772 .34957 L
.776 .35048 L
.78 .35117 L
.784 .3517 L
.788 .3521 L
.792 .35239 L
.796 .35261 L
.8 .35277 L
Mistroke
.804 .35288 L
.808 .35296 L
.812 .35302 L
.816 .35307 L
.82 .3531 L
.824 .35312 L
.828 .35313 L
.832 .35314 L
.836 .35315 L
.84 .35315 L
.844 .35316 L
.848 .35316 L
.852 .35316 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23176 L
.148 .23176 L
.152 .23176 L
.156 .23176 L
.16 .23177 L
.164 .23177 L
.168 .23177 L
.172 .23177 L
.176 .23178 L
.18 .23179 L
.184 .2318 L
.188 .23182 L
.192 .23184 L
.196 .23188 L
.2 .23193 L
Mistroke
.204 .232 L
.208 .2321 L
.212 .23223 L
.216 .23241 L
.22 .23266 L
.224 .23299 L
.228 .23343 L
.232 .23401 L
.236 .23478 L
.24 .23577 L
.244 .23704 L
.248 .23865 L
.252 .24068 L
.256 .24321 L
.26 .24634 L
.264 .25014 L
.268 .25473 L
.272 .26019 L
.276 .26661 L
.28 .27405 L
.284 .28257 L
.288 .29215 L
.292 .30278 L
.296 .31434 L
.3 .32669 L
.304 .33958 L
.308 .35271 L
.312 .3657 L
.316 .37808 L
.32 .38937 L
.324 .39901 L
.328 .40646 L
.332 .41122 L
.336 .41283 L
.34 .41096 L
.344 .40542 L
.348 .39618 L
.352 .38345 L
.356 .36762 L
.36 .34928 L
.364 .32923 L
.368 .30835 L
.372 .28764 L
.376 .26806 L
.38 .2505 L
.384 .2357 L
.388 .22418 L
.392 .21619 L
.396 .21171 L
.4 .21043 L
Mistroke
.404 .21184 L
.408 .21521 L
.412 .21977 L
.416 .22473 L
.42 .2294 L
.424 .23323 L
.428 .23589 L
.432 .23727 L
.436 .23745 L
.44 .23669 L
.444 .2353 L
.448 .23367 L
.452 .23212 L
.456 .2309 L
.46 .23015 L
.464 .22989 L
.468 .23008 L
.472 .23057 L
.476 .23121 L
.48 .23184 L
.484 .23235 L
.488 .23265 L
.492 .23272 L
.496 .23256 L
.5 .23223 L
.504 .23181 L
.508 .23139 L
.512 .23107 L
.516 .23091 L
.52 .23097 L
.524 .23127 L
.528 .23178 L
.532 .23242 L
.536 .23306 L
.54 .23355 L
.544 .23373 L
.548 .23348 L
.552 .23273 L
.556 .23151 L
.56 .22996 L
.564 .22832 L
.568 .22694 L
.572 .22617 L
.576 .22636 L
.58 .22774 L
.584 .2304 L
.588 .23423 L
.592 .23889 L
.596 .24385 L
.6 .24842 L
Mistroke
.604 .25179 L
.608 .25319 L
.612 .25192 L
.616 .24744 L
.62 .23945 L
.624 .22793 L
.628 .21313 L
.632 .19557 L
.636 .17599 L
.64 .15527 L
.644 .1344 L
.648 .11434 L
.652 .09601 L
.656 .08017 L
.66 .06744 L
.664 .05821 L
.668 .05266 L
.672 .05079 L
.676 .0524 L
.68 .05716 L
.684 .06462 L
.688 .07426 L
.692 .08554 L
.696 .09793 L
.7 .11091 L
.704 .12404 L
.708 .13693 L
.712 .14928 L
.716 .16085 L
.72 .17147 L
.724 .18106 L
.728 .18957 L
.732 .19702 L
.736 .20344 L
.74 .2089 L
.744 .21348 L
.748 .21729 L
.752 .22041 L
.756 .22295 L
.76 .22498 L
.764 .22659 L
.768 .22786 L
.772 .22885 L
.776 .22961 L
.78 .2302 L
.784 .23064 L
.788 .23097 L
.792 .23122 L
.796 .2314 L
.8 .23153 L
Mistroke
.804 .23163 L
.808 .2317 L
.812 .23175 L
.816 .23178 L
.82 .23181 L
.824 .23183 L
.828 .23184 L
.832 .23185 L
.836 .23185 L
.84 .23186 L
.844 .23186 L
.848 .23186 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo0P001Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogooOol40003Ool01@00Ool00000Ool00P0000=oo`00Ool00Woo00@007oo
Ool0009oo`04001oogoo0002Ool00`00Oomoo`02Ool01P00Oomoogoo001oo`@000=oo`04001oogoo
0005Ool000]oo`8000Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`@0009oo`<000=oo`04001o
ogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P0017oo1@0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool20010Ool00`00Oomoo`05Ool2000YOol001aoo`03001oogoo03moo`03001oogoo00Ioo`<002Mo
o`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=o
o`04001oogooOol50003Ool01`00Oomoogoo001oo`00009oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00<007ooOol0100000=oo`00Ool00Woo00<007ooOol00Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000L
Ool2000KOol20008Ool00`00Oomoo`1;Ool001aoo`03001oogoo01]oo`8000Ioo`03001oogoo04ao
o`0077oo0P007Goo0P0017oo0P00CWoo000LOol00`00Oomoo`0MOol20003Ool00`00Oomoo`1=Ool0
00]oo`8000Aoo`04001oogooOol50002Ool2000OOol4001@Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00<007ooOol087oo00<007ooOol0Cgoo000:Ool01000Oomoo`002Goo00<007ooOol0
0Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo
00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`00
2Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo
0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001o
ogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool2001cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool00`00Oomoo`04Ool2001cOol000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1b
Ool000]oo`8000Yoo`8000=oo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomo
o`02Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qo
o`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003
Ool2001cOol001aoo`03001oogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool0
0`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00
Oomoo`1gOol001Ioo`8007Uoo`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004
Ool00`00Oomoo`02Ool3001hOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000Mgoo0003Ool5
0002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<0
00=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000;Ool20009Ool30003Ool0
0`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02
Ool30003Ool2001cOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo
0003Ool50002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`@000=oo`8007=oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`03001oogoo
079oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`8007=oo`002goo0P002Woo0P000goo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo01moo`80025oo`8002ioo`002goo0P0017oo
00<007ooOol00goo0`000Woo0P0087oo00<007oo000087oo00<007oo0000;Goo000:Ool01000Oomo
o`002Woo00D007ooOomoo`00025oo`03001oo`0001moo`04001oogoo000]Ool000=oo`D0009oo`04
001oogoo0007Ool50002Ool00`00Oomoo`0NOol01@00Oomoogoo00007Woo00@007ooOol002eoo`00
2Woo00@007ooOol000Moo`04001oogoo0003Ool2000OOol01@00Oomoogoo00007Woo00D007ooOomo
o`0002aoo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo01eoo`03001oogoo009o
o`03001oogoo01aoo`05001oogooOol0000/Ool000Yoo`04001oogoo0009Ool20003Ool2000NOol0
0`00Oomoo`02Ool00`00Oomoo`0LOol01@00Oomoogoo0000;7oo000;Ool2000;Ool01@00Oomoogoo
00007goo00<007ooOol00Woo00<007ooOol06goo00<007ooOol00goo00<007ooOol0:Goo000LOol2
000NOol00`00Oomoo`02Ool00`00Oomoo`0KOol00`00Oomoo`03Ool00`00Oomoo`0YOol001aoo`03
001oogoo01eoo`03001oogoo00=oo`03001oogoo01Yoo`03001oogoo00=oo`03001oogoo02Uoo`00
2goo0P0017oo00@007ooOomoo`D0009oo`8001eoo`03001oogoo00Aoo`03001oogoo01Yoo`03001o
ogoo00=oo`03001oogoo02Uoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0L
Ool00`00Oomoo`04Ool00`00Oomoo`0JOol00`00Oomoo`03Ool00`00Oomoo`0YOol000=oo`D0009o
o`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0LOol00`00Oomoo`04Ool00`00Oomoo`0I
Ool00`00Oomoo`05Ool00`00Oomoo`0XOol000Yoo`04001oogoo000:Ool01000Oomoogoo0P003Woo
0`0017oo0P001Goo00@007ooOomoo`<00004Ool007ooOol20004Ool20005Ool30003Ool30003Ool3
0005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol037oo00D007ooOomoo`00009oo`04001oogoo0004Ool00`00
Oomoo`02Ool01000Oomoogoo0P000Woo00@007ooOol0009oo`03001oogoo00=oo`05001oogooOol0
0003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`80015oo`04001oogoo0002Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool01000Oomoogoo0P000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`03Ool20004Ool01000Oomoo`000Woo00@007ooOol000Ioo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Uoo`<000=oo`03001oogoo
011oo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoogoo0P000Woo00@0
07ooOol0009oo`03001oogoo00=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool0
0`00Ool00003Ool01000Oomoo`000Woo00@007ooOol000Moo`03001oogoo00Aoo`04001oogoo0002
Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0003Ool00`00Oomoo`03Ool01000
Oomoogoo0P000Woo00@007ooOol0009oo`03001oogoo00=oo`04001oogooOol40003Ool01000Oomo
o`0017oo0P000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02Ool01P00Oomoogoo
001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo
0002Ool20004Ool20003Ool20002Ool01000Oomoo`000Woo00<007ooOol00Woo0P000goo00<007oo
Ool017oo00@007ooOol000Aoo`05001oo`00Ool00002Ool01000Oomoo`000Woo00@007ooOol000Ao
o`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P00
0goo00<007ooOol017oo00H007ooOomoo`00Ool20004Ool20006Ool01000Oomoogoo1@0000=oo`00
Ool00P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000IOol2000:
Ool00`00Oomoo`0GOol00`00Oomoo`09Ool2000VOol001aoo`03001oogoo01Ioo`8000eoo`04001o
ogooOol3000<Ool20004Ool00`00Oomoo`0:Ool3000TOol001aoofT000aoo`0077oo00<007ooOol0
4Woo00<007ooOol047oo00@007oo0000015oo`800003Ool007oo015oo`03001oogoo019oo`03001o
ogoo00Yoo`0077oo0P009goo0P004goo0`00=7oo000LOol00`00Oomoo`0WOol00`00Oomoo`0BOol0
0`00Oomoo`0cOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`04001oogooOol50002Ool2001cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00<007ooOol0LWoo000:Ool01000Oomoo`002Goo00<007ooOol00Woo0P00Lgoo000:Ool01000Oomo
o`002Woo00D007ooOomoo`0007Aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001c
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool3
0003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00
Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo000:Ool0
1000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`001goo00@007ooOol000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`8007=oo`002Woo00@007ooOol000Uo
o`8000=oo`03001oogoo079oo`002goo0P002goo00D007ooOomoo`0007Aoo`0077oo0P00Lgoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8004=oo`8002ioo`00
2Woo00@007ooOol000Yoo`05001oogooOol00013Ool200000goo001oo`0/Ool000=oo`D0009oo`04
001oogoo0007Ool50002Ool20012Ool01000Oomoo`00;Goo000:Ool01000Oomoo`001goo00@007oo
Ool000=oo`03001oogoo045oo`05001oogooOol0000/Ool000Yoo`04001oogoo0008Ool00`00Ool0
0003Ool20012Ool01@00Oomoogoo0000;7oo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0
@Goo00D007ooOomoo`0002aoo`002goo0P002goo00@007ooOomoo`80045oo`03001oogoo00=oo`03
001oogoo02Uoo`0077oo00<007ooOol0@7oo00<007ooOol00goo00<007ooOol0:Goo000;Ool20004
Ool01000Oomoogoo1@000Woo0P00@Goo00<007ooOol00goo00<007ooOol0:Goo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eo
o`<000=oo`<000Aoo`8000Aoo`H000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`000goo
1@000Woo00@007ooOol000Uoo`03001oogoo009oo`8000eoo`05001oogooOol00002Ool01000Oomo
o`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`03001oogoo009oo`80009oo`04001oogoo0002Ool01000Oomoo`000Woo00<0
07ooOol00goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`002Woo00D007ooOomoo`00019oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`02Ool00`00Ool00004Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P004Goo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`03001oo`0000=oo`04001oogoo
0002Ool01000Oomoo`001goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000Oomoo`002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007oo
Ool000Aoo`80009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo00H007ooOomo
o`00Ool40003Ool01000Oomoo`001Goo000;Ool20009Ool30003Ool2000=Ool00`00Oomoo`04Ool0
1000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04
Ool01000Oomoo`0017oo0P000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02Ool0
1`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yo
o`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50002Ool30006Ool30004Ool20004Ool2
0006Ool30002Ool50003Ool20006Ool001aoo`8002Moo`8001Moo`03001oogoo00Moo`8002Moo`00
77oo00<007ooOol09Woo0`005Goo00<007ooOol02Goo0P009Woo000LOomY000<Ool001aoo`05001o
ogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo1P000Woo00D007ooOomoo`0000=o
o`07001oogoo001oo`00Ool010000Woo0`0000=oo`0000000`000Woo0P0000Aoo`00Ool000=oo`03
001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03
001oogoo009oo`03001oogoo00Yoo`0077oo0P006Goo0P002Woo00<007ooOol057oo00<007oo0000
=7oo000LOol00`00Oomoo`0IOol00`00Oomoo`08Ool00`00Oomoo`0EOol00`00Oomoo`0cOol001ao
o`8001]oo`03001oogoo00Moo`03001oogoo04]oo`0077oo00<007ooOol06Woo00<007ooOol01goo
00<007ooOol0Bgoo000;Ool20004Ool01000Oomoogoo1@000Woo0P0077oo00<007ooOol01Woo00<0
07ooOol0Bgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo01]oo`03001oogoo
00Ioo`03001oogoo04]oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8001aoo`03001oogoo
00Eoo`03001oogoo04aoo`002Woo00@007ooOol000Yoo`05001oogooOol0000NOol00`00Oomoo`04
Ool00`00Oomoo`1<Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P007Goo00<007oo
Ool017oo00<007ooOol0C7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo
01aoo`03001oogoo00Aoo`03001oogoo04aoo`002goo0P002Goo0`000goo0P007Woo00<007ooOol0
0goo00<007ooOol0C7oo000LOol00`00Oomoo`0MOol00`00Oomoo`02Ool00`00Oomoo`1=Ool000]o
o`8000Aoo`03001oogoo00=oo`<0009oo`8001ioo`03001oogoo009oo`03001oogoo04eoo`002Woo
00@007ooOol000Yoo`05001oogooOol0000OOol00`00Oomoo`02Ool00`00Oomoo`1=Ool000Yoo`04
001oogoo0007Ool50002Ool2000OOol01@00Oomoogoo0000Cgoo000:Ool01000Oomoo`001goo00@0
07ooOol000=oo`03001oogoo01ioo`04001oogoo001@Ool000Yoo`04001oogoo0008Ool00`00Ool0
0003Ool2000POol00`00Ool0001@Ool000Yoo`04001oogoo0009Ool20003Ool00`00Oomoo`0OOol2
001AOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo
00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001o
ogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001c
Ool000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`1bOol000]oo`8000Yoo`8000=o
o`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Qoo`<000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool20009Ool30003Ool2001cOol001aoo`03001o
ogoo079oo`005Woo0`000goo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03
001oogoo009oo`8007=oo`005goo00<007ooOol0Mgoo000GOol00`00Oomoo`1gOol001Ioo`8007Uo
o`005goo00<007ooOol0Mgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3920\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23178 L
.152 .23178 L
.156 .23178 L
.16 .23178 L
.164 .23178 L
.168 .23178 L
.172 .23179 L
.176 .23179 L
.18 .2318 L
.184 .23181 L
.188 .23183 L
.192 .23185 L
.196 .23189 L
.2 .23193 L
Mistroke
.204 .23199 L
.208 .23208 L
.212 .23219 L
.216 .23234 L
.22 .23253 L
.224 .23279 L
.228 .23312 L
.232 .23355 L
.236 .23409 L
.24 .23477 L
.244 .23561 L
.248 .23665 L
.252 .23792 L
.256 .23945 L
.26 .24126 L
.264 .2434 L
.268 .24587 L
.272 .2487 L
.276 .25188 L
.28 .25541 L
.284 .25924 L
.288 .26334 L
.292 .26762 L
.296 .27198 L
.3 .27629 L
.304 .28041 L
.308 .28416 L
.312 .28738 L
.316 .28987 L
.32 .29148 L
.324 .29205 L
.328 .29146 L
.332 .28966 L
.336 .28663 L
.34 .28244 L
.344 .27721 L
.348 .27114 L
.352 .26448 L
.356 .25753 L
.36 .25062 L
.364 .24406 L
.368 .23816 L
.372 .23317 L
.376 .22926 L
.38 .22653 L
.384 .22498 L
.388 .2245 L
.392 .22493 L
.396 .22604 L
.4 .22757 L
Mistroke
.404 .22925 L
.408 .23085 L
.412 .23218 L
.416 .23313 L
.42 .23363 L
.424 .23373 L
.428 .23348 L
.432 .23301 L
.436 .23245 L
.44 .2319 L
.444 .23147 L
.448 .2312 L
.452 .23112 L
.456 .23119 L
.46 .23136 L
.464 .23158 L
.468 .23177 L
.472 .23191 L
.476 .23198 L
.48 .23197 L
.484 .23191 L
.488 .23184 L
.492 .23178 L
.496 .23175 L
.5 .23175 L
.504 .23177 L
.508 .23179 L
.512 .23179 L
.516 .23176 L
.52 .2317 L
.524 .23163 L
.528 .23157 L
.532 .23156 L
.536 .23162 L
.54 .23176 L
.544 .23195 L
.548 .23217 L
.552 .23234 L
.556 .23241 L
.56 .23233 L
.564 .23207 L
.568 .23164 L
.572 .2311 L
.576 .23054 L
.58 .23007 L
.584 .22982 L
.588 .22991 L
.592 .23041 L
.596 .23135 L
.6 .23267 L
Mistroke
.604 .23427 L
.608 .23594 L
.612 .23747 L
.616 .23858 L
.62 .23902 L
.624 .23855 L
.628 .237 L
.632 .23428 L
.636 .23038 L
.64 .2254 L
.644 .21951 L
.648 .21295 L
.652 .20604 L
.656 .19909 L
.66 .19243 L
.664 .18636 L
.668 .18112 L
.672 .17692 L
.676 .17389 L
.68 .17208 L
.684 .1715 L
.688 .17206 L
.692 .17367 L
.696 .17617 L
.7 .17938 L
.704 .18314 L
.708 .18726 L
.712 .19158 L
.716 .19594 L
.72 .20022 L
.724 .20432 L
.728 .20817 L
.732 .2117 L
.736 .21488 L
.74 .21771 L
.744 .22019 L
.748 .22232 L
.752 .22414 L
.756 .22566 L
.76 .22693 L
.764 .22797 L
.768 .22882 L
.772 .2295 L
.776 .23004 L
.78 .23046 L
.784 .23079 L
.788 .23105 L
.792 .23125 L
.796 .23139 L
.8 .23151 L
Mistroke
.804 .23159 L
.808 .23165 L
.812 .2317 L
.816 .23173 L
.82 .23175 L
.824 .23177 L
.828 .23178 L
.832 .23179 L
.836 .2318 L
.84 .2318 L
.844 .2318 L
.848 .2318 L
.852 .23181 L
.856 .23181 L
.86 .23181 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35316 L
.148 .35316 L
.152 .35316 L
.156 .35315 L
.16 .35315 L
.164 .35314 L
.168 .35313 L
.172 .35312 L
.176 .35309 L
.18 .35306 L
.184 .35302 L
.188 .35296 L
.192 .35288 L
.196 .35276 L
.2 .3526 L
Mistroke
.204 .35238 L
.208 .35208 L
.212 .35168 L
.216 .35116 L
.22 .35046 L
.224 .34954 L
.228 .34836 L
.232 .34685 L
.236 .34492 L
.24 .34249 L
.244 .33947 L
.248 .33575 L
.252 .33122 L
.256 .32576 L
.26 .31927 L
.264 .31164 L
.268 .30279 L
.272 .29268 L
.276 .28129 L
.28 .26867 L
.284 .25494 L
.288 .24028 L
.292 .22497 L
.296 .20937 L
.3 .19395 L
.304 .17922 L
.308 .16579 L
.312 .1543 L
.316 .14539 L
.32 .13967 L
.324 .13767 L
.328 .13979 L
.332 .14628 L
.336 .15715 L
.34 .17219 L
.344 .19093 L
.348 .21268 L
.352 .2365 L
.356 .26135 L
.36 .28605 L
.364 .30944 L
.368 .33048 L
.372 .34825 L
.376 .36215 L
.38 .37184 L
.384 .37735 L
.388 .379 L
.392 .37742 L
.396 .37343 L
.4 .36798 L
Mistroke
.404 .36199 L
.408 .35632 L
.412 .35162 L
.416 .34831 L
.42 .34656 L
.424 .34626 L
.428 .34715 L
.432 .34881 L
.436 .35079 L
.44 .3527 L
.444 .35421 L
.448 .35514 L
.452 .35547 L
.456 .35526 L
.46 .35468 L
.464 .35392 L
.468 .35318 L
.472 .35261 L
.476 .35228 L
.48 .35222 L
.484 .3524 L
.488 .35272 L
.492 .35311 L
.496 .35347 L
.5 .35371 L
.504 .3538 L
.508 .35371 L
.512 .35347 L
.516 .35311 L
.52 .35272 L
.524 .3524 L
.528 .35222 L
.532 .35228 L
.536 .35261 L
.54 .35318 L
.544 .35392 L
.548 .35468 L
.552 .35526 L
.556 .35547 L
.56 .35514 L
.564 .35421 L
.568 .3527 L
.572 .35079 L
.576 .34881 L
.58 .34715 L
.584 .34626 L
.588 .34656 L
.592 .34831 L
.596 .35162 L
.6 .35632 L
Mistroke
.604 .36199 L
.608 .36798 L
.612 .37343 L
.616 .37742 L
.62 .379 L
.624 .37735 L
.628 .37184 L
.632 .36215 L
.636 .34825 L
.64 .33048 L
.644 .30944 L
.648 .28605 L
.652 .26135 L
.656 .2365 L
.66 .21267 L
.664 .19093 L
.668 .17219 L
.672 .15715 L
.676 .14628 L
.68 .13979 L
.684 .13766 L
.688 .13966 L
.692 .14538 L
.696 .15429 L
.7 .16579 L
.704 .17922 L
.708 .19394 L
.712 .20937 L
.716 .22497 L
.72 .24028 L
.724 .25494 L
.728 .26867 L
.732 .28129 L
.736 .29268 L
.74 .30279 L
.744 .31164 L
.748 .31927 L
.752 .32576 L
.756 .33122 L
.76 .33575 L
.764 .33947 L
.768 .34249 L
.772 .34492 L
.776 .34685 L
.78 .34836 L
.784 .34954 L
.788 .35046 L
.792 .35116 L
.796 .35168 L
.8 .35208 L
Mistroke
.804 .35238 L
.808 .3526 L
.812 .35276 L
.816 .35288 L
.82 .35296 L
.824 .35302 L
.828 .35306 L
.832 .35309 L
.836 .35312 L
.84 .35313 L
.844 .35314 L
.848 .35315 L
.852 .35315 L
.856 .35316 L
.86 .35316 L
.864 .35316 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23176 L
.136 .23176 L
.14 .23176 L
.144 .23177 L
.148 .23177 L
.152 .23177 L
.156 .23177 L
.16 .23177 L
.164 .23178 L
.168 .23179 L
.172 .2318 L
.176 .23182 L
.18 .23184 L
.184 .23188 L
.188 .23193 L
.192 .232 L
.196 .2321 L
.2 .23224 L
Mistroke
.204 .23242 L
.208 .23267 L
.212 .233 L
.216 .23345 L
.22 .23403 L
.224 .2348 L
.228 .23579 L
.232 .23707 L
.236 .23868 L
.24 .24072 L
.244 .24325 L
.248 .24638 L
.252 .25018 L
.256 .25476 L
.26 .26021 L
.264 .26662 L
.268 .27405 L
.272 .28254 L
.276 .2921 L
.28 .30269 L
.284 .31422 L
.288 .32653 L
.292 .33938 L
.296 .35247 L
.3 .36543 L
.304 .37779 L
.308 .38906 L
.312 .39871 L
.316 .4062 L
.32 .411 L
.324 .41268 L
.328 .4109 L
.332 .40546 L
.336 .39634 L
.34 .38372 L
.344 .36798 L
.348 .34974 L
.352 .32974 L
.356 .30888 L
.36 .28815 L
.364 .26851 L
.368 .25086 L
.372 .23593 L
.376 .22427 L
.38 .21614 L
.384 .21152 L
.388 .21013 L
.392 .21145 L
.396 .2148 L
.4 .21937 L
Mistroke
.404 .22439 L
.408 .22916 L
.412 .23311 L
.416 .23589 L
.42 .23738 L
.424 .23763 L
.428 .23687 L
.432 .23547 L
.436 .23378 L
.44 .23216 L
.444 .23089 L
.448 .23013 L
.452 .22989 L
.456 .23011 L
.46 .23064 L
.464 .23127 L
.468 .23185 L
.472 .23226 L
.476 .23243 L
.48 .2324 L
.484 .23223 L
.488 .23201 L
.492 .23182 L
.496 .23173 L
.5 .23174 L
.504 .23181 L
.508 .23188 L
.512 .23189 L
.516 .2318 L
.52 .23162 L
.524 .2314 L
.528 .23123 L
.532 .23119 L
.536 .23137 L
.54 .23177 L
.544 .23236 L
.548 .23299 L
.552 .23351 L
.556 .23373 L
.56 .2335 L
.564 .23273 L
.568 .23146 L
.572 .22985 L
.576 .22816 L
.58 .22675 L
.584 .226 L
.588 .22625 L
.592 .22773 L
.596 .23052 L
.6 .23447 L
Mistroke
.604 .23923 L
.608 .24426 L
.612 .24883 L
.616 .25217 L
.62 .2535 L
.624 .25211 L
.628 .24749 L
.632 .23936 L
.636 .22769 L
.64 .21277 L
.644 .19512 L
.648 .17547 L
.652 .15474 L
.656 .13389 L
.66 .11389 L
.664 .09564 L
.668 .07991 L
.672 .06729 L
.676 .05817 L
.68 .05272 L
.684 .05094 L
.688 .05262 L
.692 .05743 L
.696 .06491 L
.7 .07456 L
.704 .08583 L
.708 .0982 L
.712 .11115 L
.716 .12424 L
.72 .1371 L
.724 .1494 L
.728 .16093 L
.732 .17153 L
.736 .18109 L
.74 .18958 L
.744 .19701 L
.748 .20341 L
.752 .20886 L
.756 .21345 L
.76 .21725 L
.764 .22037 L
.768 .22291 L
.772 .22494 L
.776 .22656 L
.78 .22784 L
.784 .22883 L
.788 .22959 L
.792 .23018 L
.796 .23062 L
.8 .23096 L
Mistroke
.804 .23121 L
.808 .23139 L
.812 .23153 L
.816 .23162 L
.82 .2317 L
.824 .23175 L
.828 .23178 L
.832 .23181 L
.836 .23183 L
.84 .23184 L
.844 .23185 L
.848 .23185 L
.852 .23186 L
.856 .23186 L
.86 .23186 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo100017oo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogooOol40003Ool00`00Oomoo`02000017oo000000000goo00@007ooOol0
009oo`04001oogoo0002Ool00`00Oomoo`02Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005
Ool000]oo`8000Uoo`<000=oo`8000eoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oo`000003Ool20003Ool0
1000Oomoo`000Woo00@007ooOol0009oo`03001oogoo009oo`07001oogooOol007oo00001Woo00@0
07ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P00
1Woo00@007ooOomoo`D000=oo`8000Eoo`@000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Io
o`0077oo0P00@Goo0P001Woo0P00:7oo000LOol00`00Oomoo`10Ool00`00Oomoo`06Ool3000VOol0
01aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool0
1000Oomoogoo1@000goo00@007ooOomoo`8000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00@007ooOomoo`D000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo0P006Woo0P001goo
0P00CWoo000LOol00`00Oomoo`0JOol20006Ool00`00Oomoo`1=Ool001aoo`8001aoo`8000Aoo`80
04moo`0077oo00<007ooOol077oo0P000goo00<007ooOol0CWoo000;Ool20004Ool01000Oomoogoo
1@000Woo0P007Woo1000DGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo079o
o`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol000Yoo`05001o
ogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo
000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8007=oo`002Woo00@0
07ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool50002Ool2001cOol000Yo
o`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<0
07oo00000goo0P00Lgoo000:Ool01000Oomoo`002Goo0P000goo00<007ooOol0LWoo000;Ool2000;
Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03001oogoo009oo`<0
00=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo10000goo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000:Ool01000Oomo
o`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:Ool20003Ool2001cOol001aoo`03
001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000LOol00`00Oomoo`1bOol001Ioo`<0
00=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001c
Ool001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000FOol2001iOol001Moo`03001oogoo
07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00N7oo000:Ool01000Oomo
o`001goo00D007ooOomoo`0007Moo`000goo1@000Woo00@007ooOol000Moo`05001oogooOol00002
Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`8007=oo`002goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo0P00Lgoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool40003Ool2001cOol000Yoo`04001o
ogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Oomoo`03
Ool2001cOol000]oo`8000Yoo`8000=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`0NOol2000SOol3000/Ool000]oo`8000Aoo`03001oogoo00=oo`<0009oo`8001ioo`04001oogoo
000ROol00`00Ool0000/Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00007goo00@007ooOol0
029oo`03001oo`0002aoo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo01eoo`04
001oogoo000QOol01@00Oomoogoo0000:goo000:Ool01000Oomoo`001goo00@007ooOol000=oo`80
01ioo`04001oogoo000QOol01@00Oomoogoo0000:goo000:Ool01000Oomoo`0027oo00<007oo0000
0goo00<007ooOol077oo00<007ooOol00Woo00<007ooOol07Woo00D007ooOomoo`0002]oo`002Woo
00@007ooOol000Uoo`8000=oo`8001eoo`03001oogoo009oo`03001oogoo01ioo`05001oogooOol0
000[Ool000]oo`8000]oo`05001oogooOol0000NOol00`00Oomoo`02Ool00`00Oomoo`0MOol00`00
Oomoo`03Ool00`00Oomoo`0XOol001aoo`8001eoo`03001oogoo009oo`03001oogoo01eoo`03001o
ogoo00=oo`03001oogoo02Qoo`0077oo00<007ooOol06goo00<007ooOol017oo00<007ooOol077oo
00<007ooOol00goo00<007ooOol0:7oo000;Ool20004Ool01000Oomoogoo1@000Woo0P0077oo00<0
07ooOol017oo00<007ooOol077oo00<007ooOol017oo00<007ooOol09goo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`03001oogoo01]oo`03001oogoo00Aoo`03001oogoo01aoo`03001oogoo
00Aoo`03001oogoo02Moo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo
01]oo`03001oogoo00Aoo`03001oogoo01aoo`03001oogoo00Aoo`03001oogoo02Moo`002Woo00@0
07ooOol000Yoo`04001oogooOol2000>Ool30004Ool20004Ool00`00Oomoo`02Ool40003Ool20004
Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol037oo00D007ooOomoo`00
009oo`04001oogoo0003Ool00`00Oomoo`03Ool00`00Ool00002Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`05001oogooOol00003Ool00`00Oomoo`0200000goo001oo`04Ool200001Goo001oogoo
00000Woo00@007ooOol0009oo`03001oogoo00=oo`06001oogoo001oo`000goo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomo
o`000Woo00D007ooOomoo`0000Eoo`03001oo`00009oo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol01Goo00<007ooOol00P0000=oo`00Ool01Goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool20009
Ool30003Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oo`00009oo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00<007ooOol00P0000=oo`00Ool01Goo
0P000goo00@007ooOol0009oo`04001oogoo0007Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`000Woo00<007ooOol017oo00H007ooOol0
07oo0002Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOomoo`@000=oo`800003Ool007oo
00=oo`03001oogoo0080009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool4
0003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01@00Oomoo`00Ool0
0P001Goo0P000Woo00<007oo00000Woo00@007ooOol0009oo`03001oogoo009oo`8000=oo`03001o
ogoo00Aoo`800003Ool007oo00=oo`03001oogoo0080009oo`04001oogoo0002Ool01000Oomoo`00
17oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool50003Ool2
0002Ool00`00Oomoo`05Ool01000Oomoo`000Woo0P0017oo0P001Woo00@007ooOomoo`D0009oo`<0
00Ioo`@000=oo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P005goo0P002goo00<0
07ooOol06Goo00<007ooOol02Goo0P009Goo000LOol00`00Oomoo`0EOol2000=Ool01000Oomoogoo
0`003Woo0P0017oo00<007ooOol02goo0P008goo000LOomY000<Ool001aoo`03001oogoo019oo`03
001oogoo00moo`04001oogoo000COol20002Ool00`00Oomoo`0>Ool00`00Oomoo`0BOol00`00Oomo
o`0:Ool001aoo`8002Eoo`<001Eoo`<003=oo`0077oo00<007ooOol09Goo00<007ooOol05Goo00<0
07ooOol0<Woo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000;Ool2
0004Ool01000Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03
001oogoo079oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`002Woo00@007ooOol0
00Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`00
0goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007oo
Ool00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`002Woo00@0
07ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool2
0003Ool00`00Oomoo`1bOol000]oo`8000]oo`05001oogooOol0001dOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool20014Ool3000/Ool000Yo
o`04001oogoo000:Ool01@00Oomoogoo0000AGoo00<007oo0000;7oo0003Ool50002Ool01000Oomo
o`001goo1@000Woo0P00A7oo00@007ooOol002]oo`002Woo00@007ooOol000Moo`04001oogoo0003
Ool00`00Oomoo`12Ool01@00Oomoogoo0000:goo000:Ool01000Oomoo`0027oo00<007oo00000goo
0P00@goo00D007ooOomoo`0002]oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo049oo`05
001oogooOol0000[Ool000]oo`8000]oo`04001oogooOol20012Ool00`00Oomoo`03Ool00`00Oomo
o`0XOol001aoo`03001oogoo045oo`03001oogoo00=oo`03001oogoo02Qoo`002goo0P0017oo00@0
07ooOomoo`D0009oo`80049oo`03001oogoo00=oo`03001oogoo02Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003
Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009o
o`04001oogoo0009Ool00`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`05001o
ogoo001oo`020005Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomo
ogoo00004Woo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00D007ooOol007oo008000Eoo`8000Aoo`04001oogoo0002
Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool00`00Oomoo`020000
0goo001oo`05Ool20003Ool01000Oomoo`000Woo00@007ooOol000Moo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool037oo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOomoo`@000=oo`800003Ool007oo00=oo`05001oo`00Ool00002Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Goo
0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000
Oomoo`0017oo0P000goo00<007ooOol017oo0P0000=oo`00Ool00goo00<007ooOol00P000Woo00@0
07ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001ao
o`03001oogoo00aoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`8002Ioo`80
01Qoo`03001oogoo00Uoo`03001oogoo02Aoo`0077oo00<007ooOol097oo00@007oo000001Moo`03
001oogoo00Uoo`8002Eoo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo
00D007ooOomoo`0000=oo`D000=oo`05001oogooOol00003Ool00`00Ool00002Ool50002Ool20003
Ool00`00Ool000030002Ool20002Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol2000G
Ool2000;Ool00`00Oomoo`0FOol00`00Ool0000cOol001aoo`03001oogoo01Qoo`03001oogoo00Qo
o`03001oogoo01Moo`8003=oo`0077oo0P006Woo00<007ooOol01goo00<007ooOol0C7oo000LOol0
0`00Oomoo`0IOol00`00Oomoo`07Ool00`00Oomoo`1<Ool000]oo`8000Aoo`04001oogooOol50002
Ool2000JOol00`00Oomoo`06Ool00`00Oomoo`1=Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00<007ooOol06Woo00<007ooOol01Goo00<007ooOol0CGoo000:Ool01000Oomoo`002Goo00<0
07ooOol00Woo0P006goo00<007ooOol01Goo00<007ooOol0CGoo000:Ool01000Oomoo`002Woo00D0
07ooOomoo`0001eoo`03001oogoo00Aoo`03001oogoo04eoo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool2000LOol00`00Oomoo`04Ool00`00Oomoo`1=Ool000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol06goo00<007ooOol017oo00<007ooOol0CGoo000;Ool20009
Ool30003Ool2000LOol00`00Oomoo`04Ool00`00Oomoo`1=Ool001aoo`03001oogoo01aoo`03001o
ogoo009oo`03001oogoo04ioo`002goo0P0017oo00<007ooOol00goo0`000Woo0P007Goo00<007oo
Ool00Woo00<007ooOol0CWoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0001ioo`03001oogoo
009oo`03001oogoo04ioo`002Woo00@007ooOol000Moo`D0009oo`8001ioo`04001oogoo001AOol0
00Yoo`04001oogoo0007Ool01000Oomoo`000goo00<007ooOol07Goo00@007ooOol0055oo`002Woo
00@007ooOol000Qoo`03001oo`0000=oo`8001ioo`800003Ool007oo051oo`002Woo00@007ooOol0
00Uoo`8000=oo`03001oogoo01ioo`80059oo`002goo0P002goo00@007ooOomoo`8007=oo`0077oo
00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001oogoo00=oo`03001o
ogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol000]oo`8000Aoo`03
001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`80
07=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uo
o`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol001Moo`03001oogoo
009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`1gOol001Mo
o`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(3960\)], "Print",
  CellLabel->"From In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23177 m
.008 .23177 L
.012 .23177 L
.016 .23177 L
.02 .23177 L
.024 .23177 L
.028 .23177 L
.032 .23177 L
.036 .23177 L
.04 .23177 L
.044 .23177 L
.048 .23177 L
.052 .23177 L
.056 .23177 L
.06 .23177 L
.064 .23177 L
.068 .23177 L
.072 .23177 L
.076 .23177 L
.08 .23177 L
.084 .23177 L
.088 .23177 L
.092 .23177 L
.096 .23177 L
.1 .23177 L
.104 .23177 L
.108 .23177 L
.112 .23177 L
.116 .23177 L
.12 .23177 L
.124 .23177 L
.128 .23177 L
.132 .23177 L
.136 .23178 L
.14 .23178 L
.144 .23178 L
.148 .23178 L
.152 .23178 L
.156 .23178 L
.16 .23179 L
.164 .23179 L
.168 .2318 L
.172 .23181 L
.176 .23183 L
.18 .23186 L
.184 .23189 L
.188 .23193 L
.192 .232 L
.196 .23208 L
.2 .23219 L
Mistroke
.204 .23234 L
.208 .23254 L
.212 .2328 L
.216 .23313 L
.22 .23356 L
.224 .2341 L
.228 .23478 L
.232 .23562 L
.236 .23666 L
.24 .23793 L
.244 .23946 L
.248 .24127 L
.252 .2434 L
.256 .24587 L
.26 .24869 L
.264 .25186 L
.268 .25538 L
.272 .2592 L
.276 .26329 L
.28 .26755 L
.284 .2719 L
.288 .2762 L
.292 .28031 L
.296 .28406 L
.3 .28728 L
.304 .28979 L
.308 .29141 L
.312 .292 L
.316 .29144 L
.32 .28967 L
.324 .28668 L
.328 .28252 L
.332 .27733 L
.336 .27128 L
.34 .26464 L
.344 .2577 L
.348 .25079 L
.352 .24421 L
.356 .23828 L
.36 .23325 L
.364 .2293 L
.368 .22652 L
.372 .22491 L
.376 .2244 L
.38 .2248 L
.384 .2259 L
.388 .22744 L
.392 .22914 L
.396 .23077 L
.4 .23213 L
Mistroke
.404 .23311 L
.408 .23365 L
.412 .23377 L
.416 .23354 L
.42 .23308 L
.424 .23251 L
.428 .23195 L
.432 .2315 L
.436 .23121 L
.44 .2311 L
.444 .23115 L
.448 .23131 L
.452 .23153 L
.456 .23174 L
.46 .23191 L
.464 .232 L
.468 .23203 L
.472 .23198 L
.476 .2319 L
.48 .2318 L
.484 .23171 L
.488 .23165 L
.492 .23163 L
.496 .23165 L
.5 .2317 L
.504 .23177 L
.508 .23183 L
.512 .23188 L
.516 .2319 L
.52 .23188 L
.524 .23183 L
.528 .23174 L
.532 .23164 L
.536 .23156 L
.54 .23151 L
.544 .23153 L
.548 .23163 L
.552 .23179 L
.556 .232 L
.56 .23222 L
.564 .23238 L
.568 .23243 L
.572 .23233 L
.576 .23204 L
.58 .2316 L
.584 .23104 L
.588 .23047 L
.592 .23001 L
.596 .22978 L
.6 .22989 L
Mistroke
.604 .23042 L
.608 .23139 L
.612 .23275 L
.616 .23438 L
.62 .23607 L
.624 .23761 L
.628 .23871 L
.632 .23912 L
.636 .23861 L
.64 .23701 L
.644 .23424 L
.648 .2303 L
.652 .22527 L
.656 .21935 L
.66 .21278 L
.664 .20587 L
.668 .19893 L
.672 .19228 L
.676 .18624 L
.68 .18104 L
.684 .17687 L
.688 .17388 L
.692 .17211 L
.696 .17155 L
.7 .17214 L
.704 .17376 L
.708 .17626 L
.712 .17948 L
.716 .18324 L
.72 .18735 L
.724 .19166 L
.728 .19601 L
.732 .20028 L
.736 .20437 L
.74 .20819 L
.744 .21171 L
.748 .21489 L
.752 .21771 L
.756 .22018 L
.76 .22231 L
.764 .22413 L
.768 .22565 L
.772 .22692 L
.776 .22796 L
.78 .22881 L
.784 .22949 L
.788 .23003 L
.792 .23045 L
.796 .23079 L
.8 .23104 L
Mistroke
.804 .23124 L
.808 .23139 L
.812 .2315 L
.816 .23159 L
.82 .23165 L
.824 .23169 L
.828 .23173 L
.832 .23175 L
.836 .23177 L
.84 .23178 L
.844 .23179 L
.848 .23179 L
.852 .2318 L
.856 .2318 L
.86 .2318 L
.864 .23181 L
.868 .23181 L
.872 .23181 L
.876 .23181 L
.88 .23181 L
.884 .23181 L
.888 .23181 L
.892 .23181 L
.896 .23181 L
.9 .23181 L
.904 .23181 L
.908 .23181 L
.912 .23181 L
.916 .23181 L
.92 .23181 L
.924 .23181 L
.928 .23181 L
.932 .23181 L
.936 .23181 L
.94 .23181 L
.944 .23181 L
.948 .23181 L
.952 .23181 L
.956 .23181 L
.96 .23181 L
.964 .23181 L
.968 .23181 L
.972 .23181 L
.976 .23181 L
.98 .23181 L
.984 .23181 L
.988 .23181 L
.992 .23181 L
.996 .23181 L
1 .23181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.353162 0.441453 [
[.2 .34066 -6 -9 ]
[.2 .34066 6 0 ]
[.4 .34066 -9 -9 ]
[.4 .34066 9 0 ]
[.6 .34066 -9 -9 ]
[.6 .34066 9 0 ]
[.8 .34066 -9 -9 ]
[.8 .34066 9 0 ]
[1 .34066 -9 -9 ]
[1 .34066 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .08829 -24 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -24 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .44145 -18 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .35316 m
.2 .35941 L
s
[(50)] .2 .34066 0 1 Mshowa
.4 .35316 m
.4 .35941 L
s
[(100)] .4 .34066 0 1 Mshowa
.6 .35316 m
.6 .35941 L
s
[(150)] .6 .34066 0 1 Mshowa
.8 .35316 m
.8 .35941 L
s
[(200)] .8 .34066 0 1 Mshowa
1 .35316 m
1 .35941 L
s
[(250)] 1 .34066 0 1 Mshowa
.125 Mabswid
.04 .35316 m
.04 .35691 L
s
.08 .35316 m
.08 .35691 L
s
.12 .35316 m
.12 .35691 L
s
.16 .35316 m
.16 .35691 L
s
.24 .35316 m
.24 .35691 L
s
.28 .35316 m
.28 .35691 L
s
.32 .35316 m
.32 .35691 L
s
.36 .35316 m
.36 .35691 L
s
.44 .35316 m
.44 .35691 L
s
.48 .35316 m
.48 .35691 L
s
.52 .35316 m
.52 .35691 L
s
.56 .35316 m
.56 .35691 L
s
.64 .35316 m
.64 .35691 L
s
.68 .35316 m
.68 .35691 L
s
.72 .35316 m
.72 .35691 L
s
.76 .35316 m
.76 .35691 L
s
.84 .35316 m
.84 .35691 L
s
.88 .35316 m
.88 .35691 L
s
.92 .35316 m
.92 .35691 L
s
.96 .35316 m
.96 .35691 L
s
.25 Mabswid
0 .35316 m
1 .35316 L
s
0 0 m
.00625 0 L
s
[(-0.8)] -0.0125 0 1 0 Mshowa
0 .08829 m
.00625 .08829 L
s
[(-0.6)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(-0.4)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(-0.2)] -0.0125 .26487 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(0.2)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.4)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .02207 m
.00375 .02207 L
s
0 .04415 m
.00375 .04415 L
s
0 .06622 m
.00375 .06622 L
s
0 .11036 m
.00375 .11036 L
s
0 .13244 m
.00375 .13244 L
s
0 .15451 m
.00375 .15451 L
s
0 .19865 m
.00375 .19865 L
s
0 .22073 m
.00375 .22073 L
s
0 .2428 m
.00375 .2428 L
s
0 .28694 m
.00375 .28694 L
s
0 .30902 m
.00375 .30902 L
s
0 .33109 m
.00375 .33109 L
s
0 .37523 m
.00375 .37523 L
s
0 .39731 m
.00375 .39731 L
s
0 .41938 m
.00375 .41938 L
s
0 .46353 m
.00375 .46353 L
s
0 .4856 m
.00375 .4856 L
s
0 .50767 m
.00375 .50767 L
s
0 .55182 m
.00375 .55182 L
s
0 .57389 m
.00375 .57389 L
s
0 .59596 m
.00375 .59596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35316 m
.008 .35316 L
.012 .35316 L
.016 .35316 L
.02 .35316 L
.024 .35316 L
.028 .35316 L
.032 .35316 L
.036 .35316 L
.04 .35316 L
.044 .35316 L
.048 .35316 L
.052 .35316 L
.056 .35316 L
.06 .35316 L
.064 .35316 L
.068 .35316 L
.072 .35316 L
.076 .35316 L
.08 .35316 L
.084 .35316 L
.088 .35316 L
.092 .35316 L
.096 .35316 L
.1 .35316 L
.104 .35316 L
.108 .35316 L
.112 .35316 L
.116 .35316 L
.12 .35316 L
.124 .35316 L
.128 .35316 L
.132 .35316 L
.136 .35316 L
.14 .35316 L
.144 .35315 L
.148 .35315 L
.152 .35314 L
.156 .35313 L
.16 .35311 L
.164 .35309 L
.168 .35306 L
.172 .35302 L
.176 .35296 L
.18 .35287 L
.184 .35275 L
.188 .35259 L
.192 .35237 L
.196 .35207 L
.2 .35167 L
Mistroke
.204 .35114 L
.208 .35043 L
.212 .34952 L
.216 .34833 L
.22 .34681 L
.224 .34488 L
.228 .34245 L
.232 .33943 L
.236 .33571 L
.24 .33118 L
.244 .32573 L
.248 .31924 L
.252 .31162 L
.256 .3028 L
.26 .29271 L
.264 .28135 L
.268 .26877 L
.272 .25508 L
.276 .24047 L
.28 .22521 L
.284 .20966 L
.288 .19427 L
.292 .17956 L
.296 .16615 L
.3 .15465 L
.304 .1457 L
.308 .13993 L
.312 .13785 L
.316 .13987 L
.32 .14624 L
.324 .15698 L
.328 .17188 L
.332 .1905 L
.336 .21214 L
.34 .2359 L
.344 .26072 L
.348 .28543 L
.352 .3089 L
.356 .33004 L
.36 .34797 L
.364 .36204 L
.368 .3719 L
.372 .37757 L
.376 .37935 L
.38 .37786 L
.384 .37392 L
.388 .36845 L
.392 .3624 L
.396 .35662 L
.4 .35179 L
Mistroke
.404 .34834 L
.408 .34646 L
.412 .34607 L
.416 .34691 L
.42 .34858 L
.424 .35061 L
.428 .35259 L
.432 .35418 L
.436 .35518 L
.44 .35553 L
.444 .35532 L
.448 .35471 L
.452 .35393 L
.456 .35319 L
.46 .35263 L
.464 .35235 L
.468 .35234 L
.472 .35254 L
.476 .35284 L
.48 .35313 L
.484 .35333 L
.488 .3534 L
.492 .35337 L
.496 .35328 L
.5 .35319 L
.504 .35315 L
.508 .35319 L
.512 .35328 L
.516 .35337 L
.52 .3534 L
.524 .35333 L
.528 .35313 L
.532 .35284 L
.536 .35254 L
.54 .35234 L
.544 .35235 L
.548 .35263 L
.552 .35319 L
.556 .35393 L
.56 .35471 L
.564 .35532 L
.568 .35553 L
.572 .35518 L
.576 .35418 L
.58 .35259 L
.584 .35061 L
.588 .34858 L
.592 .34691 L
.596 .34607 L
.6 .34646 L
Mistroke
.604 .34834 L
.608 .35179 L
.612 .35662 L
.616 .3624 L
.62 .36845 L
.624 .37392 L
.628 .37786 L
.632 .37935 L
.636 .37757 L
.64 .3719 L
.644 .36204 L
.648 .34797 L
.652 .33004 L
.656 .3089 L
.66 .28543 L
.664 .26071 L
.668 .2359 L
.672 .21214 L
.676 .1905 L
.68 .17188 L
.684 .15697 L
.688 .14623 L
.692 .13987 L
.696 .13784 L
.7 .13992 L
.704 .1457 L
.708 .15464 L
.712 .16614 L
.716 .17956 L
.72 .19426 L
.724 .20965 L
.728 .22521 L
.732 .24047 L
.736 .25508 L
.74 .26877 L
.744 .28135 L
.748 .29271 L
.752 .3028 L
.756 .31162 L
.76 .31924 L
.764 .32573 L
.768 .33118 L
.772 .33571 L
.776 .33943 L
.78 .34245 L
.784 .34488 L
.788 .34681 L
.792 .34833 L
.796 .34952 L
.8 .35043 L
Mistroke
.804 .35114 L
.808 .35167 L
.812 .35207 L
.816 .35237 L
.82 .35259 L
.824 .35275 L
.828 .35287 L
.832 .35296 L
.836 .35302 L
.84 .35306 L
.844 .35309 L
.848 .35311 L
.852 .35313 L
.856 .35314 L
.86 .35315 L
.864 .35315 L
.868 .35316 L
.872 .35316 L
.876 .35316 L
.88 .35316 L
.884 .35316 L
.888 .35316 L
.892 .35316 L
.896 .35316 L
.9 .35316 L
.904 .35316 L
.908 .35316 L
.912 .35316 L
.916 .35316 L
.92 .35316 L
.924 .35316 L
.928 .35316 L
.932 .35316 L
.936 .35316 L
.94 .35316 L
.944 .35316 L
.948 .35316 L
.952 .35316 L
.956 .35316 L
.96 .35316 L
.964 .35316 L
.968 .35316 L
.972 .35316 L
.976 .35316 L
.98 .35316 L
.984 .35316 L
.988 .35316 L
.992 .35316 L
.996 .35316 L
1 .35316 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.231763 0.386271 [
[.2 .21926 -6 -9 ]
[.2 .21926 6 0 ]
[.4 .21926 -9 -9 ]
[.4 .21926 9 0 ]
[.6 .21926 -9 -9 ]
[.6 .21926 9 0 ]
[.8 .21926 -9 -9 ]
[.8 .21926 9 0 ]
[1 .21926 -9 -9 ]
[1 .21926 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .23176 m
.2 .23801 L
s
[(50)] .2 .21926 0 1 Mshowa
.4 .23176 m
.4 .23801 L
s
[(100)] .4 .21926 0 1 Mshowa
.6 .23176 m
.6 .23801 L
s
[(150)] .6 .21926 0 1 Mshowa
.8 .23176 m
.8 .23801 L
s
[(200)] .8 .21926 0 1 Mshowa
1 .23176 m
1 .23801 L
s
[(250)] 1 .21926 0 1 Mshowa
.125 Mabswid
.04 .23176 m
.04 .23551 L
s
.08 .23176 m
.08 .23551 L
s
.12 .23176 m
.12 .23551 L
s
.16 .23176 m
.16 .23551 L
s
.24 .23176 m
.24 .23551 L
s
.28 .23176 m
.28 .23551 L
s
.32 .23176 m
.32 .23551 L
s
.36 .23176 m
.36 .23551 L
s
.44 .23176 m
.44 .23551 L
s
.48 .23176 m
.48 .23551 L
s
.52 .23176 m
.52 .23551 L
s
.56 .23176 m
.56 .23551 L
s
.64 .23176 m
.64 .23551 L
s
.68 .23176 m
.68 .23551 L
s
.72 .23176 m
.72 .23551 L
s
.76 .23176 m
.76 .23551 L
s
.84 .23176 m
.84 .23551 L
s
.88 .23176 m
.88 .23551 L
s
.92 .23176 m
.92 .23551 L
s
.96 .23176 m
.96 .23551 L
s
.25 Mabswid
0 .23176 m
1 .23176 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.4)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.2)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.4)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.8)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23176 m
.008 .23176 L
.012 .23176 L
.016 .23176 L
.02 .23176 L
.024 .23176 L
.028 .23176 L
.032 .23176 L
.036 .23176 L
.04 .23176 L
.044 .23176 L
.048 .23176 L
.052 .23176 L
.056 .23176 L
.06 .23176 L
.064 .23176 L
.068 .23176 L
.072 .23176 L
.076 .23176 L
.08 .23176 L
.084 .23176 L
.088 .23176 L
.092 .23176 L
.096 .23176 L
.1 .23176 L
.104 .23176 L
.108 .23176 L
.112 .23176 L
.116 .23176 L
.12 .23176 L
.124 .23176 L
.128 .23176 L
.132 .23177 L
.136 .23177 L
.14 .23177 L
.144 .23177 L
.148 .23178 L
.152 .23178 L
.156 .23179 L
.16 .2318 L
.164 .23182 L
.168 .23185 L
.172 .23188 L
.176 .23193 L
.18 .23201 L
.184 .23211 L
.188 .23224 L
.192 .23243 L
.196 .23268 L
.2 .23302 L
Mistroke
.204 .23346 L
.208 .23405 L
.212 .23482 L
.216 .23582 L
.22 .2371 L
.224 .23872 L
.228 .24076 L
.232 .24329 L
.236 .24642 L
.24 .25022 L
.244 .2548 L
.248 .26024 L
.252 .26663 L
.256 .27404 L
.26 .28251 L
.264 .29205 L
.268 .30261 L
.272 .3141 L
.276 .32637 L
.28 .33918 L
.284 .35224 L
.288 .36516 L
.292 .3775 L
.296 .38877 L
.3 .39842 L
.304 .40593 L
.308 .41078 L
.312 .41253 L
.316 .41084 L
.32 .4055 L
.324 .39648 L
.328 .38397 L
.332 .36835 L
.336 .35018 L
.34 .33024 L
.344 .30941 L
.348 .28867 L
.352 .26897 L
.356 .25122 L
.36 .23617 L
.364 .22437 L
.368 .21609 L
.372 .21133 L
.376 .20983 L
.38 .21108 L
.384 .21439 L
.388 .21898 L
.392 .22406 L
.396 .22891 L
.4 .23297 L
Mistroke
.404 .23586 L
.408 .23744 L
.412 .23776 L
.416 .23705 L
.42 .23566 L
.424 .23396 L
.428 .2323 L
.432 .23098 L
.436 .23014 L
.44 .22984 L
.444 .23 L
.448 .23048 L
.452 .23112 L
.456 .23175 L
.46 .23224 L
.464 .23252 L
.468 .23257 L
.472 .23243 L
.476 .23218 L
.48 .2319 L
.484 .23164 L
.488 .23147 L
.492 .23142 L
.496 .23148 L
.5 .23162 L
.504 .23181 L
.508 .23201 L
.512 .23215 L
.516 .23221 L
.52 .23215 L
.524 .23199 L
.528 .23173 L
.532 .23144 L
.536 .23119 L
.54 .23106 L
.544 .23111 L
.548 .23139 L
.552 .23188 L
.556 .2325 L
.56 .23314 L
.564 .23363 L
.568 .23379 L
.572 .23348 L
.576 .23265 L
.58 .23132 L
.584 .22967 L
.588 .22797 L
.592 .22658 L
.596 .22587 L
.6 .22619 L
Mistroke
.604 .22777 L
.608 .23066 L
.612 .23471 L
.616 .23957 L
.62 .24465 L
.624 .24924 L
.628 .25255 L
.632 .2538 L
.636 .2523 L
.64 .24754 L
.644 .23926 L
.648 .22745 L
.652 .21241 L
.656 .19466 L
.66 .17496 L
.664 .15421 L
.668 .13338 L
.672 .11344 L
.676 .09528 L
.68 .07965 L
.684 .06714 L
.688 .05813 L
.692 .05279 L
.696 .05109 L
.7 .05284 L
.704 .05769 L
.708 .0652 L
.712 .07486 L
.716 .08612 L
.72 .09847 L
.724 .11139 L
.728 .12445 L
.732 .13726 L
.736 .14953 L
.74 .16102 L
.744 .17158 L
.748 .18111 L
.752 .18958 L
.756 .19699 L
.76 .20339 L
.764 .20883 L
.768 .21341 L
.772 .21721 L
.776 .22033 L
.78 .22287 L
.784 .22491 L
.788 .22653 L
.792 .22781 L
.796 .2288 L
.8 .22957 L
Mistroke
.804 .23016 L
.808 .23061 L
.812 .23095 L
.816 .2312 L
.82 .23139 L
.824 .23152 L
.828 .23162 L
.832 .23169 L
.836 .23174 L
.84 .23178 L
.844 .23181 L
.848 .23182 L
.852 .23184 L
.856 .23185 L
.86 .23185 L
.864 .23186 L
.868 .23186 L
.872 .23186 L
.876 .23186 L
.88 .23186 L
.884 .23186 L
.888 .23186 L
.892 .23186 L
.896 .23186 L
.9 .23186 L
.904 .23186 L
.908 .23186 L
.912 .23186 L
.916 .23186 L
.92 .23186 L
.924 .23186 L
.928 .23186 L
.932 .23186 L
.936 .23186 L
.94 .23186 L
.944 .23186 L
.948 .23186 L
.952 .23186 L
.956 .23186 L
.96 .23186 L
.964 .23186 L
.968 .23186 L
.972 .23186 L
.976 .23186 L
.98 .23186 L
.984 .23186 L
.988 .23186 L
.992 .23186 L
.996 .23186 L
1 .23186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00goo0`000Woo
0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`0007Aoo`000goo1@000Woo00@007ooOol0
00Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo0003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04001oogoo0009Ool20003Ool0
0`00Oomoo`1bOol000]oo`8000]oo`04001oogooOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00@007ooOomoo`D0009oo`8007=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00004Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007oo00000P000goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo00aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool00`00Oomoo`0300000goo00000003Ool0
1000Oomoo`000Woo00@007ooOol0009oo`03001oogoo009oo`06001oogooOol007oo10000goo00@0
07ooOol000Eoo`002goo0P002Goo0`000goo0P003Goo00<007ooOol017oo00@007ooOol000Qoo`80
00Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00<007ooOol00P00
0goo0P000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02Ool01`00Oomoogoo001o
o`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=oo`8000Yoo`03001oogoo00=o
o`8000Aoo`8000Ioo`04001oogooOol50003Ool30005Ool30004Ool20004Ool20006Ool30002Ool5
0003Ool20006Ool001aoo`80049oo`8000Moo`03001oogoo02Eoo`0077oo00<007ooOol0@Goo00<0
07ooOol01goo0P009Goo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000goo00<007oo00000`000Woo00D007ooOomoo`0000=oo`03001oogoo009oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00H007ooOomoo`00Ool40002Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool00`00Oomoo`0:Ool001aoo`8001Uoo`8000Moo`8004moo`0077oo00<007ooOol06Goo00<007oo
Ool01Goo00<007ooOol0CWoo000LOol2000KOol20004Ool00`00Oomoo`1?Ool001aoo`03001oogoo
01]oo`03001oogoo009oo`03001oogoo04moo`002goo0P0017oo00@007ooOomoo`D0009oo`8001eo
o`@0059oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0009Ool00`00Oomoo`02Ool2001cOol000Yoo`04001oogoo000:Ool01@00Oomoogoo0000M7oo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007oo
Ool0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2001cOol000Yoo`04001oogoo000:Ool0
1@00Oomoogoo0000M7oo000:Ool01000Oomoo`001goo1@000Woo0P00Lgoo000:Ool01000Oomoo`00
1goo00@007ooOol000=oo`03001oogoo079oo`002Woo00@007ooOol000Qoo`03001oo`0000=oo`80
07=oo`002Woo00@007ooOol000Uoo`8000=oo`03001oogoo079oo`002goo0P002goo00@007ooOomo
o`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool2001cOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002Woo00@007ooOol000Qoo`03001o
ogoo00=oo`03001oogoo079oo`002goo0P002Woo0P000goo0P00Lgoo000LOol00`00Oomoo`1bOol0
00]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo
000:Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000]oo`8000Uoo`<000=oo`8007=oo`0077oo00<007ooOol0LWoo000FOol30003Ool2001cOol0
01Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00
Oomoo`1gOol001Moo`03001oogoo07Moo`005Woo0P00NGoo000GOol00`00Oomoo`1gOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<007Qoo`002Woo00@007ooOol000Moo`05001o
ogooOol0001gOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:
Ool01000Oomoo`0027oo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2001cOol0
00]oo`8000Uoo`<000=oo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo10000goo0P00Lgoo000:Ool01000Oomoo`001goo00<0
07ooOol017oo00<007ooOol0LWoo000:Ool01000Oomoo`0027oo00<007ooOol00goo0P00Lgoo000;
Ool2000:Ool20003Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol07Goo0P009Woo
0P00:goo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000MOol00`00Ool0000UOol00`00Ool0
000[Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00007Woo00@007ooOol002Aoo`03001oo`00
02]oo`000goo1@000Woo00@007ooOol000Moo`D0009oo`03001oogoo01aoo`04001oogoo000SOol0
1@00Oomoogoo0000:Woo000:Ool01000Oomoo`001goo00@007ooOol000=oo`8001aoo`05001oogoo
Ool0000SOol01@00Oomoogoo0000:Woo000:Ool01000Oomoo`0027oo00<007oo00000goo00<007oo
Ool06goo00<007ooOol00Woo00<007ooOol087oo00<007ooOol00Woo00<007ooOol09goo000:Ool0
1000Oomoo`002Goo0P000goo0P0077oo00<007ooOol00Woo00<007ooOol087oo00<007ooOol00Woo
00<007ooOol09goo000;Ool2000;Ool01@00Oomoogoo00007Goo00<007ooOol00Woo00<007ooOol0
87oo00<007ooOol00Woo00<007ooOol09goo000LOol2000LOol00`00Oomoo`02Ool00`00Oomoo`0P
Ool00`00Oomoo`02Ool00`00Oomoo`0WOol001aoo`03001oogoo01Yoo`03001oogoo00=oo`03001o
ogoo01moo`03001oogoo00=oo`03001oogoo02Moo`002goo0P0017oo00@007ooOomoo`D0009oo`80
01]oo`03001oogoo00=oo`03001oogoo01moo`03001oogoo00Aoo`03001oogoo02Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`0JOol00`00Oomoo`03Ool00`00Oomoo`0OOol0
0`00Oomoo`04Ool00`00Oomoo`0VOol000=oo`D0009oo`04001oogoo0009Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`05Ool00`00Oomoo`0NOol00`00Oomoo`04Ool00`00Oomoo`0VOol0
00Yoo`04001oogoo000:Ool01000Oomoogoo0P003Woo0`0017oo0P000goo00<007ooOol00goo0`00
17oo0P0017oo0P001Goo0`000goo0`0017oo0`0017oo1@000goo0P0017oo0P001Goo1@000Woo0`00
17oo0P001Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00aoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo0P000goo00@007ooOol0009oo`04001o
ogoo0005Ool01@00Oomoogoo00000goo00D007ooOol007oo008000Eoo`04001oo`000002Ool01000
Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool2000AOol01000Oomoo`000Woo00@0
07ooOol000Ioo`8000=oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00D007oo
Ool007oo008000Ioo`8000=oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00=oo`002goo0P002Goo0`000goo00<007ooOol047oo00@007ooOol0
009oo`03001oo`0000Moo`8000=oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00D007ooOol007oo008000Moo`80009oo`04001oogoo0002Ool01000Oomoo`001goo00<007ooOol0
17oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00H007ooOol007oo0007
Ool00`00Ool00002Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000
Ool0000017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomo
o`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomo
o`020007Ool200001Goo001oogoo00000Woo00@007ooOol0009oo`03001oogoo009oo`8000=oo`03
001oogoo00Aoo`04001oo`000004Ool01000Oomoogoo0P0000Eoo`00Oomoo`00009oo`04001oogoo
0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`03001oogoo00aoo`D000=o
o`<000Uoo`03001oo`0000=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool3000017oo
001oogoo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol2000FOol2000;Ool00`00Oomo
o`0LOol00`00Oomoo`09Ool00`00Oomoo`0ROol001aoo`03001oogoo01Aoo`8000aoo`03001oogoo
009oo`<0011oo`<000=oo`03001oogoo00]oo`80029oo`0077ooJ@0037oo000LOol00`00Oomoo`0B
Ool00`00Oomoo`0>Ool00`00Ool00002000COol00`00Ool00002Ool00`00Oomoo`0=Ool00`00Oomo
o`0BOol00`00Oomoo`0:Ool001aoo`8002Aoo`<001Qoo`80039oo`0077oo00<007ooOol097oo00<0
07ooOol067oo00<007ooOol0<7oo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000;Ool20004Ool01000Oomoogoo1@000Woo0P00Lgoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`03001oogoo079oo`002Woo00@007ooOol000Uoo`03001oogoo009oo`8007=oo`00
2Woo00@007ooOol000Yoo`05001oogooOol0001dOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2goo0P002Goo0`000goo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`002goo
0P0017oo00<007ooOol00goo0`000Woo0P00Lgoo000:Ool01000Oomoo`002Woo00D007ooOomoo`00
07Aoo`002Woo00@007ooOol000Moo`D0009oo`8007=oo`002Woo00@007ooOol000Moo`04001oogoo
0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0008Ool00`00Ool00003Ool2001cOol000Yoo`04
001oogoo0009Ool20003Ool00`00Oomoo`1bOol000]oo`8000]oo`05001oogooOol0001dOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool20016
Ool2000[Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000AWoo00<007oo0000:goo0003Ool5
0002Ool01000Oomoo`001goo1@000Woo0P00AGoo00@007ooOol002Yoo`002Woo00@007ooOol000Mo
o`04001oogoo0003Ool00`00Oomoo`13Ool01@00Oomoogoo0000:Woo000:Ool01000Oomoo`0027oo
00<007oo00000goo0P00A7oo00D007ooOomoo`0002Yoo`002Woo00@007ooOol000Uoo`8000=oo`03
001oogoo04=oo`03001oogoo009oo`03001oogoo02Moo`002goo0P002goo00@007ooOomoo`8004Ao
o`03001oogoo009oo`03001oogoo02Moo`0077oo00<007ooOol0@goo00<007ooOol00Woo00<007oo
Ool09goo000;Ool20004Ool01000Oomoogoo1@000Woo0P00@goo00<007ooOol00goo00<007ooOol0
9goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00eoo`<000Aoo`8000Uoo`<0
00Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`<000Aoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<0
00Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Uoo`03001oogoo009oo`8000eoo`05001oogoo
Ool00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
1@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`800005Ool007ooOol00002Ool0
1000Oomoo`000Woo00<007ooOol00goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007oo
Ool00goo000:Ool01000Oomoo`002Woo00D007ooOomoo`00019oo`04001oogoo0002Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`04Ool20003Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo0P004Goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00D007ooOol007oo008000Moo`05001oogooOol00002Ool0
1000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0<Ool40003Ool01000Oomo
o`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo
00@007oo000000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001o
ogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Goo0`000goo0P003Goo00<007ooOol0
17oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007oo
Ool017oo00@007oo000000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Ao
o`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo00<007ooOol037oo1@000goo0P00
2Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`@000=oo`8000Ao
o`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo0P009Goo00<007ooOol06Woo00<007ooOol027oo
00<007ooOol08goo000LOol00`00Oomoo`0SOol00`00Ool0000KOol00`00Oomoo`09Ool00`00Oomo
o`0ROol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol0
0002Ool60003Ool01@00Oomoogoo00000goo00<007ooOol00Woo0`0000=oo`00Ool00`000goo00@0
07ooOomoo`<00005Ool00000001oo`020002Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`80
01Ioo`8000]oo`03001oogoo01Qoo`<0039oo`0077oo00<007ooOol05Woo0P002Woo00<007ooOol0
6Goo0P00<Woo000LOol2000HOol00`00Oomoo`08Ool00`00Oomoo`1=Ool001aoo`03001oogoo01Qo
o`03001oogoo00Moo`03001oogoo04eoo`002goo0P0017oo00@007ooOomoo`D0009oo`8001Uoo`03
001oogoo00Ioo`03001oogoo04ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomo
o`0IOol00`00Oomoo`05Ool00`00Oomoo`1>Ool000Yoo`04001oogoo0009Ool00`00Oomoo`02Ool2
000JOol00`00Oomoo`05Ool00`00Oomoo`1>Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo0000
6goo00<007ooOol01Goo00<007ooOol0CWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`8001]oo`03001oogoo00=oo`03001oogoo04moo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`0JOol00`00Oomoo`03Ool00`00Oomoo`1?Ool000]oo`8000Uoo`<000=oo`80
01]oo`03001oogoo00=oo`03001oogoo04moo`0077oo00<007ooOol06goo00<007ooOol00Woo00<0
07ooOol0Cgoo000;Ool20004Ool00`00Oomoo`03Ool30002Ool2000LOol00`00Oomoo`02Ool00`00
Oomoo`1?Ool000Yoo`04001oogoo000:Ool01@00Oomoogoo00007Goo00<007ooOol00Woo00<007oo
Ool0Cgoo000:Ool01000Oomoo`001goo1@000Woo0P0077oo00D007ooOomoo`00059oo`002Woo00@0
07ooOol000Moo`04001oogoo0003Ool00`00Oomoo`0LOol01000Oomoo`00DWoo000:Ool01000Oomo
o`0027oo00<007oo00000goo0P007Goo0`00Dgoo000:Ool01000Oomoo`002Goo0P000goo00<007oo
Ool07Goo0P00Dgoo000;Ool2000;Ool01000Oomoogoo0P00Lgoo000LOol00`00Oomoo`1bOol000]o
o`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:
Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol0
17oo0P00Lgoo000:Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0LWoo000;Ool2000:
Ool20003Ool2001cOol001aoo`03001oogoo079oo`002goo0P0017oo00<007ooOol00Woo0`000goo
0P00Lgoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo0008Ool30003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo0P002Goo0`000goo0P00Lgoo000L
Ool00`00Oomoo`1bOol001Ioo`<000=oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo
000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo07Moo`005goo00<007ooOol0Mgoo000F
Ool2001iOol001Moo`03001oogoo07Moo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> {-69.508, \
-0.993188, 2.41938, 0.0250537}, {{3.4375, 141.062}, {185.938, 100.875}} -> \
{-69.508, -3.29444, 2.41938, 0.021922}, {{3.4375, 141.062}, {92.375, 7.25}} -> \
{-69.508, -5.68293, 2.41938, 0.0250537}}],

Cell[BoxData[
    \(4000\)], "Print",
  CellLabel->"From In[34]:="],

Cell[BoxData[
    \({6148.233333333333`\ Second, Null}\)], "Output",
  CellLabel->"Out[34]="],

Cell[BoxData[
    \("Fertig !"\)], "Print",
  CellLabel->"From In[34]:="]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3 selected Plots from the Animation", "Subsection",
  PageBreakAbove->True],

Cell["\<\
Two wires without coupling are simulated, each of which is carrying \
a left and right travelling component of the initial pulse; the first two \
diagrams show u and i of the same, namely the first wire, the third diagram \
displays the voltage of the second wire. The current is scaled up by a factor \
that it numerically gets roughly the same size as the voltage. The pulses \
have broken up in two parts that run apart. Edges of pulses with gradients of \
voltages and currents of equal sign move right, those with gradients of \
opposite sign move left. \
\>", "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006d0003Ga000`40O003h00Oogoo]Goo003oOone
Ool00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00
ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOone
Ool00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00
ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOone
Ool00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00
ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo001FOol0
0`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol0
0`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol2
003oOomMOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomo
o`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol2003oOomM
Ool005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomL
Ool005Ioo`03001oogoo0?mooeaoo`008goo10003Woo0`0047oo1`001goo00<007ooOol0ogooG7oo
000QOol8000;Ool5000?Ool70007Ool2003oOomMOol0025oo`8000Aoo`8000]oo`D0019oo`8000Uo
o`03001oogoo0?mooeaoo`0087oo0P001Woo0P002Woo1@004Woo0P002Goo00<007ooOol0ogooG7oo
000POol20006Ool2000;Ool3000COol20009Ool00`00Oomoo`3oOomLOol000aoo`d000Ioo`8000Qo
o`8001Qoo``000Moo`03001oogoo0?mooeaoo`0037oo3@001Woo0P0027oo0P0067oo30001goo00<0
07ooOol0ogooG7oo000<Ool=0006Ool20008Ool2000HOol20006Ool200000goo001oo`06Ool3003o
OomLOol001moo`8000Qoo`8001Uoo`8000Eoo`8000Uoo`03001oogoo0?mooeaoo`007goo0P0027oo
0P006Goo0`0017oo0P002Goo00<007ooOol0ogooG7oo000OOol20008Ool2000JOol20004Ool20009
Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001]oo`8000=oo`8000Uoo`03001oogoo0?mooeao
o`007goo0P0027oo0P006goo0`000Woo0P002Goo00<007ooOol0ogooG7oo000POol20006Ool2000M
Ool20002Ool20009Ool2003oOomMOol0021oo`8000Ioo`8001ioo`800003Ool0000000Uoo`03001o
ogoo0?mooeaoo`008Goo0P0017oo0P0087oo10002Goo00<007ooOol0ogooG7oo000QOol8000POol4
0009Ool00`00Oomoo`3oOomLOol002=oo`@002=oo`<000Uoo`03001oogoo0?mooeaoo`00EWoo00<0
07ooOol0ogooG7oo001FOol2003oOomMOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0
ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`008goo10003Woo0`00
2Woo300027oo00<007ooOol0ogooG7oo000QOol8000;Ool50009Ool<0008Ool2003oOomMOol0025o
o`8000Aoo`8000]oo`D000Yoo`<000Ioo`8000Qoo`03001oogoo0?mooeaoo`0087oo0P001Woo0P00
2Woo1@002goo0`003goo00<007ooOol0ogooG7oo000POol20006Ool2000;Ool3000=Ool3000>Ool0
0`00Oomoo`3oOomLOol000aoo`d000Ioo`8000Qoo`8001]oo`<000eoo`03001oogoo02ioo`H000io
o`@001eoo`X000]oo`@000ioo`@001=oo`X000Uoo`H000ioo`@0015oo``000]oo`@000ioo`@0019o
o``000Uoo`H000ioo`@0019oo`0037oo3@001Woo0P0027oo0P0077oo0`0037oo00<007ooOol0;7oo
2P002Woo20006goo2P002Goo20002Woo20004Goo2P001goo2P002Woo20003goo30002Goo20002Woo
200047oo30001goo2P002Woo200047oo000<Ool=0006Ool20008Ool2000MOol3000;Ool3000/Ool3
0005Ool30009Ool20004Ool2000OOol2000=Ool20004Ool2000:Ool20004Ool2000EOol2000;Ool3
0005Ool30009Ool20004Ool2000@Ool30006Ool20009Ool20004Ool2000:Ool20004Ool2000AOol3
0006Ool20007Ool30005Ool30009Ool20004Ool2000@Ool001moo`8000Qoo`8001ioo`<000Yoo`03
001oogoo03Eoo`8000Qoo`8000Ioo`8001ioo`8000aoo`8000Ioo`8000Qoo`8000Ioo`8001Aoo`80
01Aoo`8000Qoo`8000Ioo`80011oo`<000moo`8000Ioo`8000Qoo`8000Ioo`80015oo`<001Moo`80
00Qoo`8000Ioo`8000moo`007goo0P0027oo0P007goo0`002Goo00<007ooOol0=Woo0P001goo0P00
1Woo0P007Woo0P0037oo0P001Woo0P0027oo0P001Woo0P0057oo0P005Goo0P001goo0P001Woo0P00
4Goo0`003Woo0P001Woo0P0027oo0P001Woo0P004Woo0`005goo0P001goo0P001Woo0P003goo000O
Ool20008Ool2000POol20009Ool00`00Oomoo`0fOol20006Ool20008Ool2000MOol2000;Ool20008
Ool20006Ool20008Ool2000COol2000EOol20006Ool20008Ool2000AOol3000<Ool20008Ool20006
Ool20008Ool2000BOol3000FOol20006Ool20008Ool2000>Ool001moo`8000Qoo`80025oo`8000Qo
o`03001oogoo03Ioo`8000Ioo`8000Qoo`8001eoo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8001=o
o`8001Eoo`8000Ioo`8000Qoo`80019oo`<000]oo`8000Qoo`8000Ioo`8000Qoo`8001=oo`<001Eo
o`8000Ioo`8000Qoo`8000ioo`007goo0P0027oo0P008Goo0P0027oo00<007ooOol0=Woo0P001Woo
0P0027oo0P007Goo0P002goo0P0027oo0P001Woo0P0027oo0P004goo0P005Goo0P001Woo0P0027oo
0P004goo0`002Woo0P0027oo0P001Woo0P0027oo0P0057oo0`0057oo0P001Woo0P0027oo0P003Woo
000POol20006Ool2000IOol20007Ool20008Ool2000gOol20006Ool20008Ool2000MOol2000;Ool2
0008Ool20006Ool20008Ool2000COol2000EOol20006Ool20008Ool2000DOol30009Ool20008Ool2
0006Ool20008Ool2000EOol3000COol20006Ool20008Ool2000>Ool0021oo`8000Ioo`8001Uoo`<0
00Ioo`8000Qoo`03001oogoo03Eoo`8000Moo`8000Qoo`8001eoo`8000]oo`8000Qoo`8000Ioo`80
00Qoo`8001=oo`8001Aoo`8000Moo`8000Qoo`8001Eoo`<000Qoo`8000Qoo`8000Ioo`8000Qoo`80
01Ioo`<0015oo`8000Moo`8000Qoo`8000ioo`008Goo0P0017oo0P006Woo100017oo0P002Goo00<0
07ooOol0;Goo0P001Goo0`001goo0P0027oo0P007Goo0P002goo0P0027oo0P001Woo0P0027oo0P00
4goo0P0037oo0P001Goo0`001goo0P0027oo0P005Woo0P0027oo0P0027oo0P001Woo0P0027oo0P00
5goo0P002Goo0P001Goo0`001goo0P0027oo0P003Woo000QOol8000KOol8000:Ool00`00Oomoo`0]
Ool90008Ool20008Ool2000MOol2000;Ool20008Ool20006Ool20008Ool2000COol2000<Ool90008
Ool20008Ool2000GOol20007Ool20008Ool20006Ool20008Ool2000HOol20008Ool90008Ool20008
Ool2000>Ool002=oo`@001moo`D000]oo`03001oogoo02eoo`800003Ool0000000<000Uoo`8000Qo
o`8001eoo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8001=oo`8000aoo`800003Ool0000000<000Uo
o`8000Qoo`8001Moo`8000Moo`8000Qoo`8000Ioo`8000Qoo`8001Qoo`8000Qoo`800003Ool00000
00<000Uoo`8000Qoo`8000ioo`00EWoo00<007ooOol0;Goo0P0047oo0P001Woo0P007Woo0P0037oo
0P001Woo0P0027oo0P001Woo0P0057oo0P0037oo0P0047oo0P001Woo0P003goo0P001goo0P0027oo
0P001Woo0P0027oo0P001Woo0P0047oo0P001goo0P0027oo0P0047oo0P001Woo0P003goo001FOol2
000^Ool2000@Ool20006Ool2000NOol2000<Ool20006Ool20008Ool20006Ool2000DOol2000<Ool2
000@Ool20006Ool2000?Ool30006Ool20008Ool20006Ool20008Ool20006Ool2000@Ool30006Ool2
0008Ool2000@Ool20006Ool2000?Ool005Ioo`03001oogoo02eoo`80015oo`8000Aoo`8001]oo`<0
0003Ool0000000eoo`8000Aoo`8000Yoo`8000Aoo`80015oo`<00003Ool0000000aoo`80015oo`80
00Aoo`80011oo`@000Aoo`8000Yoo`8000Aoo`8000Yoo`8000Aoo`80015oo`@000Aoo`8000Uoo`80
015oo`8000Aoo`80011oo`00EWoo00<007ooOol0;Goo2P002Goo20006goo1P003Goo20002Woo2000
4Goo1P0037oo2P002Goo20004Goo20002goo20002Woo20004Woo20002Woo2P002Goo200047oo001F
Ool00`00Oomoo`0]Ool:000;Ool4000POol3000?Ool4000>Ool4000FOol3000<Ool:000;Ool4000E
Ool5000>Ool4000>Ool4000FOol5000;Ool:000;Ool4000BOol005Ioo`03001oogoo0?mooeaoo`00
EWoo00<007ooOol0ogooG7oo001FOol2003oOomMOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<0
07ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<0
07ooOol0ogooG7oo001FOooo000j000UOol005Ioo`03001oogoo00Uoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001o
ogoo00Yoo`03001oogoo009oo`D0009oo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo00L0009oo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`04001oogoo
Ool50004Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0SOol005Io
o`03001oogoo03]oo`03001oogoo02eoo`03001oogoo00aoo`03001oogoo01Qoo`03001oogoo00Eo
o`03001oogoo01Qoo`03001oogoo00aoo`03001oogoo02aoo`03001oogoo03aoo`03001oogoo02=o
o`00EWoo00<007ooOol0K7oo00<007ooOol09Goo00<007ooOol01goo00<007ooOol097oo0P00U7oo
001FOol00`00Oomoo`1]Ool00`00Oomoo`0SOol00`00Oomoo`09Ool00`00Oomoo`0ROol00`00Oomo
o`2DOol005Ioo`03001oogoo06ioo`03001oogoo025oo`03001oogoo00Yoo`03001oogoo025oo`03
001oogoo09Eoo`00EWoo0P00L7oo00<007ooOol07goo00<007ooOol037oo00<007ooOol087oo00<0
07ooOol0UGoo001FOol00`00Oomoo`1`Ool00`00Oomoo`0NOol00`00Oomoo`0=Ool00`00Oomoo`0N
Ool00`00Oomoo`2FOol005Ioo`03001oogoo071oo`03001oogoo01eoo`03001oogoo00moo`03001o
ogoo01eoo`03001oogoo09Ioo`00EWoo00<007ooOol0LGoo00<007ooOol077oo00<007ooOol03goo
00<007ooOol077oo00<007ooOol0Ugoo001FOol00`00Oomoo`1aOol00`00Oomoo`0KOol00`00Oomo
o`0AOol00`00Oomoo`0KOol00`00Oomoo`2GOol005Ioo`03001oogoo075oo`03001oogoo01]oo`03
001oogoo015oo`03001oogoo01]oo`03001oogoo09Moo`00EWoo0P00Lgoo00<007ooOol06Woo00<0
07ooOol04Goo00<007ooOol06Woo00<007ooOol0V7oo001FOol00`00Oomoo`1bOol00`00Oomoo`0I
Ool00`00Oomoo`0COol00`00Oomoo`0HOol00`00Oomoo`2IOol005Ioo`03001oogoo079oo`03001o
ogoo01Uoo`03001oogoo01=oo`03001oogoo01Qoo`03001oogoo09Uoo`00EWoo00<007ooOol0LWoo
00<007ooOol06Goo00<007ooOol04goo00<007ooOol067oo00<007ooOol0VGoo001FOol00`00Oomo
o`1cOol00`00Oomoo`0GOol00`00Oomoo`0DOol00`00Oomoo`0GOol00`00Oomoo`2JOol002=oo`@0
00ioo`<000Yoo``000Qoo`03001oogoo07=oo`03001oogoo01Moo`03001oogoo01Eoo`03001oogoo
01Ioo`03001oogoo09Yoo`008Goo20002goo1@002Goo300027oo0P00M7oo00<007ooOol05goo00<0
07ooOol05Goo00<007ooOol05Woo00<007ooOol0VWoo000QOol20004Ool2000;Ool5000:Ool30006
Ool20008Ool00`00Oomoo`1dOol00`00Oomoo`0EOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00
Oomoo`2JOol0021oo`8000Ioo`8000Yoo`D000]oo`<000moo`03001oogoo07Aoo`03001oogoo01Eo
o`03001oogoo01Ioo`03001oogoo01Eoo`03001oogoo09]oo`0087oo0P001Woo0P002goo0`003Goo
0`003Woo00<007ooOol0MGoo00<007ooOol057oo00<007ooOol05goo00<007ooOol057oo00<007oo
Ool0Vgoo000OOol20008Ool2000KOol3000=Ool00`00Oomoo`1eOol00`00Oomoo`0COol00`00Oomo
o`0HOol00`00Oomoo`0DOol00`00Oomoo`2KOol001moo`8000Qoo`8001aoo`<000aoo`03001oogoo
07Eoo`03001oogoo01=oo`03001oogoo01Qoo`03001oogoo01Aoo`03001oogoo09]oo`007goo0P00
27oo0P007Goo0`002goo0`00MWoo00<007ooOol04Woo00<007ooOol06Goo00<007ooOol04Woo00<0
07ooOol0W7oo000OOol20008Ool2000NOol3000:Ool00`00Oomoo`1fOol00`00Oomoo`0BOol00`00
Oomoo`0IOol00`00Oomoo`0BOol00`00Oomoo`2LOol001moo`8000Qoo`8001moo`<000Uoo`03001o
ogoo07Ioo`03001oogoo019oo`03001oogoo01Uoo`03001oogoo019oo`03001oogoo09aoo`007goo
0P0027oo0P0087oo0P002Goo00<007ooOol0MWoo00<007ooOol04Goo00<007ooOol06goo00<007oo
Ool04Goo00<007ooOol0W7oo000OOol20008Ool2000QOol20008Ool00`00Oomoo`1fOol00`00Oomo
o`0AOol00`00Oomoo`0KOol00`00Oomoo`0@Ool00`00Oomoo`2MOol001moo`8000Qoo`80025oo`80
00Qoo`03001oogoo07Moo`03001oogoo011oo`03001oogoo01]oo`03001oogoo011oo`03001oogoo
09eoo`0087oo0P001Woo0P006Goo0P001goo0P0027oo0P00N7oo00<007ooOol047oo00<007ooOol0
6goo00<007ooOol047oo00<007ooOol0WGoo000POol20006Ool2000IOol30006Ool20008Ool00`00
Oomoo`1gOol00`00Oomoo`0@Ool00`00Oomoo`0KOol00`00Oomoo`0?Ool00`00Oomoo`2NOol0025o
o`8000Aoo`8001Yoo`@000Aoo`8000Uoo`03001oogoo07Moo`03001oogoo011oo`03001oogoo01]o
o`03001oogoo00moo`03001oogoo09ioo`008Goo20006goo20002Woo00<007ooOol0Mgoo00<007oo
Ool03goo00<007ooOol07Goo00<007ooOol03Woo00<007ooOol0WWoo000SOol4000OOol5000;Ool0
0`00Oomoo`1gOol00`00Oomoo`0?Ool00`00Oomoo`0MOol00`00Oomoo`0>Ool00`00Oomoo`2NOol0
05Ioo`03001oogoo07Qoo`03001oogoo00ioo`03001oogoo01eoo`03001oogoo00eoo`03001oogoo
09moo`00EWoo0P00NGoo00<007ooOol03Woo00<007ooOol07Goo00<007ooOol03Goo00<007ooOol0
Wgoo001FOol00`00Oomoo`1hOol00`00Oomoo`0=Ool00`00Oomoo`0NOol00`00Oomoo`0=Ool00`00
Oomoo`2OOol005Ioo`03001oogoo07Qoo`03001oogoo00eoo`03001oogoo01ioo`03001oogoo00eo
o`03001oogoo09moo`00EWoo00<007ooOol0NGoo00<007ooOol037oo00<007ooOol07goo00<007oo
Ool037oo00<007ooOol0Wgoo001FOol00`00Oomoo`1iOol00`00Oomoo`0;Ool00`00Oomoo`0POol0
0`00Oomoo`0;Ool00`00Oomoo`2POol002=oo`@000ioo`<0011oo`L000Moo`03001oogoo07Uoo`03
001oogoo00]oo`03001oogoo021oo`03001oogoo00]oo`03001oogoo0:1oo`008Goo20002goo1@00
3goo1`001goo0P00Ngoo00<007ooOol02Woo00<007ooOol087oo00<007ooOol02goo00<007ooOol0
X7oo000QOol20004Ool2000;Ool5000BOol20009Ool00`00Oomoo`1jOol00`00Oomoo`0:Ool00`00
Oomoo`0QOol00`00Oomoo`0:Ool00`00Oomoo`2POol0021oo`8000Ioo`8000Yoo`D0019oo`8000Uo
o`03001oogoo07Yoo`03001oogoo00Yoo`03001oogoo025oo`03001oogoo00Yoo`03001oogoo0:1o
o`0087oo0P001Woo0P002goo0`004goo0P002Goo00<007ooOol0NWoo00<007ooOol02Goo00<007oo
Ool08Woo00<007ooOol02Woo00<007ooOol0X7oo000OOol20008Ool2000HOol<0007Ool00`00Oomo
o`1kOol00`00Oomoo`08Ool00`00Oomoo`0SOol00`00Oomoo`08Ool00`00Oomoo`2QOol001moo`80
00Qoo`8001Qoo``000Moo`03001oogoo07]oo`03001oogoo00Qoo`03001oogoo02=oo`03001oogoo
00Qoo`03001oogoo0:5oo`007goo0P0027oo0P0067oo0P001Woo0P0000=oo`00Ool01Woo0`00Ngoo
00<007ooOol027oo00<007ooOol08goo00<007ooOol027oo00<007ooOol0XGoo000OOol20008Ool2
000IOol20005Ool20009Ool00`00Oomoo`1kOol00`00Oomoo`08Ool00`00Oomoo`0SOol00`00Oomo
o`08Ool00`00Oomoo`2QOol001moo`8000Qoo`8001Uoo`<000Aoo`8000Uoo`03001oogoo07]oo`03
001oogoo00Moo`03001oogoo02Eoo`03001oogoo00Moo`03001oogoo0:5oo`007goo0P0027oo0P00
6Woo0P0017oo0P002Goo00<007ooOol0O7oo00<007ooOol01Woo00<007ooOol09Goo00<007ooOol0
1Woo00<007ooOol0XWoo000OOol20008Ool2000KOol20003Ool20009Ool00`00Oomoo`1lOol00`00
Oomoo`06Ool00`00Oomoo`0UOol00`00Oomoo`06Ool00`00Oomoo`2ROol001moo`8000Qoo`8001]o
o`<0009oo`8000Uoo`03001oogoo07aoo`03001oogoo00Ioo`03001oogoo02Eoo`03001oogoo00Io
o`03001oogoo0:9oo`0087oo0P001Woo0P007Goo0P000Woo0P002Goo00<007ooOol0O7oo00<007oo
Ool01Woo00<007ooOol09Goo00<007ooOol01Goo00<007ooOol0Xgoo000POol20006Ool2000NOol2
00000goo00000009Ool2001nOol00`00Oomoo`04Ool00`00Oomoo`0WOol00`00Oomoo`04Ool00`00
Oomoo`2SOol0025oo`8000Aoo`80021oo`@000Uoo`03001oogoo07eoo`03001oogoo00Aoo`03001o
ogoo02Moo`03001oogoo00=oo`03001oogoo0:Aoo`008Goo200087oo10002Goo00<007ooOol0OGoo
00<007ooOol017oo00<007ooOol09goo00<007ooOol00goo00<007ooOol0Y7oo000SOol4000SOol3
0009Ool00`00Oomoo`1nOol00`00Oomoo`02Ool00`00Oomoo`0YOol01@00Oomoogoo0000Ygoo001F
Ool00`00Oomoo`1oOol01000Oomoo`00;7oo0P000Woo00<007ooOol0YGoo001FOol00`00Oomoo`20
Ool2000_Ool2002XOol005Ioo`800?mooeeoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomo
o`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo000SOol4000>Ool3
000?Ool5000:Ool00`00Oomoo`3oOomLOol0025oo`P000]oo`D000aoo`P000Uoo`800?mooeeoo`00
8Goo0P0017oo0P002goo1@0037oo0P0017oo0`0027oo00<007ooOol0ogooG7oo000POol20006Ool2
000:Ool5000;Ool20006Ool30007Ool00`00Oomoo`3oOomLOol0021oo`8000Ioo`8000]oo`<000]o
o`8000Qoo`8000Moo`03001oogoo0?mooeaoo`007goo0P0027oo0P0067oo0P0027oo0P001goo00<0
07ooOol0ogooG7oo000OOol20008Ool2000HOol20008Ool20007Ool00`00Oomoo`3oOomLOol001mo
o`8000Qoo`8001Qoo`8000Qoo`8000Moo`<00?mooeaoo`007goo0P0027oo0P0067oo0`001Woo0`00
1goo00<007ooOol0ogooG7oo000OOol20008Ool2000HOol40004Ool30008Ool00`00Oomoo`3oOomL
Ool001moo`8000Qoo`8001Qoo`800003Ool0000000D000Uoo`03001oogoo0?mooeaoo`007goo0P00
27oo0P006Goo00<007ooOol01@002Woo00<007ooOol0ogooG7oo000OOol20008Ool2000IOol2000@
Ool00`00Oomoo`3oOomLOol0021oo`8000Ioo`8001Yoo`<000moo`800?mooeeoo`0087oo0P001Woo
0P006goo0`003Woo00<007ooOol0ogooG7oo000QOol20004Ool2000MOol3000=Ool00`00Oomoo`3o
OomLOol0025oo`P001ioo`P000Moo`03001oogoo0?mooeaoo`008goo10008Woo1P001goo00<007oo
Ool0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`800?mooeeoo`00EWoo00<007ooOol0ogoo
G7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogoo
G7oo000SOol4000>Ool3000>Ool6000:Ool00`00Oomoo`3oOomLOol0025oo`P000]oo`D000aoo`P0
00Uoo`800?mooeeoo`008Goo0P0017oo0P002goo1@002goo0`0017oo0`0027oo00<007ooOol0ogoo
G7oo000POol20006Ool2000:Ool5000:Ool30006Ool30007Ool00`00Oomoo`3oOomLOol0021oo`80
00Ioo`8000]oo`<000]oo`8000Qoo`8000Moo`03001oogoo0?mooeaoo`007goo0P0027oo0P0067oo
0P0027oo0P001goo00<007ooOol0ogooG7oo000OOol20008Ool2000HOol20008Ool20007Ool00`00
Oomoo`3oOomLOol001moo`8000Qoo`8001Qoo`<000Ioo`<000Moo`<00?mooeaoo`007goo0P0027oo
0P006Goo0`0017oo0`0027oo00<007ooOol0ogooG7oo000OOol20008Ool2000JOol80009Ool00`00
Oomoo`3oOomLOol001moo`8000Qoo`8001Yoo`P000Uoo`03001oogoo0?mooeaoo`007goo0P0027oo
0P006Goo0`0017oo0`0027oo00<007ooOol0ogooG7oo000OOol20008Ool2000HOol20008Ool20007
Ool00`00Oomoo`3oOomLOol0021oo`8000Ioo`8001Uoo`8000Qoo`8000Moo`800?mooeeoo`0087oo
0P001Woo0P006Goo0P0027oo0P001goo00<007ooOol0ogooG7oo000QOol20004Ool2000KOol30004
Ool40007Ool00`00Oomoo`3oOomLOol0025oo`P001]oo`X000Qoo`03001oogoo0?mooeaoo`008goo
10007goo1P002Woo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`800?mooeeo
o`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeao
o`00EWoo00<007ooOol0ogooG7oo0014Ool:0008Ool00`00Oomoo`3oOomLOol004Aoo`X000Qoo`80
0?mooeeoo`00B7oo0P0037oo00<007ooOol0ogooG7oo0018Ool2000<Ool00`00Oomoo`3oOomLOol0
04Qoo`8000aoo`03001oogoo0?mooeaoo`00B7oo0P0037oo00<007ooOol0ogooG7oo0018Ool2000<
Ool00`00Oomoo`3oOomLOol004Qoo`8000aoo`<00?mooeaoo`00B7oo0P00ogooJgoo0018Ool2003o
Oom[Ool004Qoo`800?moof]oo`00B7oo0P00ogooJgoo0018Ool2003oOom[Ool004Qoo`800?moof]o
o`00B7oo0P00ogooJgoo0014Ool300000goo0000003oOom[Ool004Aoo`H00?moof]oo`00Agoo0`00
ogooJgoo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOone
Ool00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00
ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOone
Ool00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00
ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOone
Ool00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00
ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOone
Ool00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00
ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOone
Ool00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00
ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOone
Ool00?mookEoo`00ogoo]Goo003oOoneOol002=oo`@000ioo`<000ioo`H00?moofUoo`008Goo2000
2goo1@0037oo2000ogooJ7oo000QOol20004Ool2000;Ool5000;Ool30004Ool3003oOomWOol0021o
o`8000Ioo`8000Yoo`D000Yoo`<000Ioo`<00?moofIoo`0087oo0P001Woo0P002goo0`002goo0P00
27oo0P00ogooIWoo000<Ool=0006Ool20008Ool2000HOol20008Ool2003oOomVOol000aoo`d000Io
o`8000Qoo`8001Qoo`8000Qoo`800?moofIoo`0037oo3@001Woo0P0027oo0P0067oo0`001Woo0`00
1goo0`00ogooG7oo000OOol20008Ool2000IOol30004Ool30008Ool00`00Oomoo`3oOomLOol001mo
o`8000Qoo`8001Yoo`P000Uoo`03001oogoo0?mooeaoo`007goo0P0027oo0P006Woo20002Goo00<0
07ooOol0ogooG7oo000OOol20008Ool2000IOol30004Ool30008Ool00`00Oomoo`3oOomLOol001mo
o`8000Qoo`8001Qoo`8000Qoo`8000Moo`03001oogoo0?mooeaoo`0087oo0P001Woo0P006Goo0P00
27oo0P001goo0P00ogooGGoo000POol20006Ool2000IOol20008Ool20007Ool00`00Oomoo`3oOomL
Ool0025oo`8000Aoo`8001]oo`<000Aoo`@000Moo`03001oogoo0?mooeaoo`008Goo20006goo2P00
27oo00<007ooOol0ogooG7oo000SOol4000OOol6000:Ool00`00Oomoo`3oOomLOol005Ioo`03001o
ogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol2003oOomMOol005Ioo`03001oogoo0?mo
oeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mo
oeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol002=oo`@000ioo`<000mo
o`D000Yoo`800?mooeeoo`008Goo20002goo1@0037oo20002Goo00<007ooOol0ogooG7oo000QOol2
0004Ool2000;Ool5000<Ool20004Ool30008Ool00`00Oomoo`3oOomLOol0021oo`8000Ioo`8000Yo
o`D000]oo`8000Ioo`<000Moo`03001oogoo0?mooeaoo`0087oo0P001Woo0P002goo0`002goo0P00
27oo0P001goo00<007ooOol0ogooG7oo000<Ool=0006Ool20008Ool2000HOol20008Ool20007Ool0
0`00Oomoo`3oOomLOol000aoo`d000Ioo`8000Qoo`8001Qoo`8000Qoo`8000Moo`03001oogoo0?mo
oeaoo`0037oo3@001Woo0P0027oo0P0067oo0P0027oo0P001goo0`00ogooG7oo000OOol20008Ool2
000HOol30006Ool30007Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001Qoo`@000Aoo`<000Qo
o`03001oogoo0?mooeaoo`007goo0P0027oo0P0067oo0P0000=oo`0000001@002Goo00<007ooOol0
ogooG7oo000OOol20008Ool2000IOol00`00Oomoo`05000:Ool00`00Oomoo`3oOomLOol001moo`80
00Qoo`8001Uoo`80011oo`03001oogoo0?mooeaoo`0087oo0P001Woo0P006Woo0`003goo00<007oo
Ool0ogooG7oo000POol20006Ool2000KOol3000>Ool2003oOomMOol0025oo`8000Aoo`8001eoo`<0
00eoo`03001oogoo0?mooeaoo`008Goo20007Woo20001goo00<007ooOol0ogooG7oo000SOol4000R
Ool60007Ool00`00Oomoo`3oOomLOol005Ioo`03001oogoo081oo`800=Uoo`00EWoo00<007ooOol0
P7oo0P00fGoo001FOol00`00Oomoo`1oOol01000Oomoo`00f7oo001FOol20020Ool01000Oomoo`00
f7oo001FOol00`00Oomoo`1nOol00`00Oomoo`02Ool00`00Oomoo`3EOol005Ioo`03001oogoo07eo
o`03001oogoo00=oo`03001oogoo0=Eoo`00EWoo00<007ooOol0OGoo00<007ooOol017oo00<007oo
Ool0e7oo001FOol00`00Oomoo`1mOol00`00Oomoo`04Ool00`00Oomoo`3DOol005Ioo`03001oogoo
07aoo`03001oogoo00Eoo`03001oogoo0=Aoo`00EWoo00<007ooOol0O7oo00<007ooOol01Woo00<0
07ooOol0dgoo000SOol4000>Ool3000@Ool70007Ool2001mOol00`00Oomoo`06Ool00`00Oomoo`3C
Ool0025oo`P000]oo`D000moo`L000Moo`03001oogoo07aoo`03001oogoo00Ioo`03001oogoo0==o
o`008Goo0P0017oo0P002goo1@004Woo0P002Goo00<007ooOol0O7oo00<007ooOol01Woo00<007oo
Ool0dgoo000POol20006Ool2000:Ool5000BOol20009Ool00`00Oomoo`1kOol00`00Oomoo`07Ool0
0`00Oomoo`3COol0021oo`8000Ioo`8000]oo`<001=oo`8000Uoo`03001oogoo07]oo`03001oogoo
00Moo`03001oogoo0==oo`0037oo3@001Woo0P0027oo0P0067oo30001goo00<007ooOol0Ngoo00<0
07ooOol027oo00<007ooOol0dWoo000<Ool=0006Ool20008Ool2000HOol<0007Ool00`00Oomoo`1k
Ool00`00Oomoo`08Ool00`00Oomoo`3BOol000aoo`d000Ioo`8000Qoo`8001Qoo`8000Ioo`800003
Ool007oo00Ioo`<007]oo`03001oogoo00Qoo`03001oogoo0=9oo`007goo0P0027oo0P006Goo0P00
1Goo0P002Goo00<007ooOol0Ngoo00<007ooOol027oo00<007ooOol0dWoo000OOol20008Ool2000I
Ool30004Ool20009Ool00`00Oomoo`1jOol00`00Oomoo`09Ool00`00Oomoo`3BOol001moo`8000Qo
o`8001Yoo`8000Aoo`8000Uoo`03001oogoo07Yoo`03001oogoo00Uoo`03001oogoo0=9oo`007goo
0P0027oo0P006goo0P000goo0P002Goo00<007ooOol0NWoo00<007ooOol02Woo00<007ooOol0dGoo
000OOol20008Ool2000KOol30002Ool20009Ool00`00Oomoo`1jOol00`00Oomoo`0:Ool00`00Oomo
o`3AOol0021oo`8000Ioo`8001eoo`80009oo`8000Uoo`03001oogoo07Yoo`03001oogoo00Yoo`03
001oogoo0=5oo`0087oo0P001Woo0P007Woo0P0000=oo`0000002Goo0P00NWoo00<007ooOol02goo
00<007ooOol0dGoo000QOol20004Ool2000POol40009Ool00`00Oomoo`1iOol00`00Oomoo`0;Ool0
0`00Oomoo`3AOol0025oo`P0021oo`@000Uoo`03001oogoo07Uoo`03001oogoo00aoo`03001oogoo
0=1oo`008goo10008goo0`002Goo00<007ooOol0N7oo00<007ooOol03Goo00<007ooOol0d7oo001F
Ool00`00Oomoo`1hOol00`00Oomoo`0=Ool00`00Oomoo`3@Ool005Ioo`03001oogoo07Qoo`03001o
ogoo00ioo`03001oogoo0<moo`00EWoo0P00NGoo00<007ooOol03Woo00<007ooOol0cgoo001FOol0
0`00Oomoo`1hOol00`00Oomoo`0>Ool00`00Oomoo`3?Ool005Ioo`03001oogoo07Moo`03001oogoo
00moo`03001oogoo0<moo`00EWoo00<007ooOol0Mgoo00<007ooOol03goo00<007ooOol0cgoo001F
Ool00`00Oomoo`1gOol00`00Oomoo`0@Ool00`00Oomoo`3>Ool005Ioo`03001oogoo07Moo`03001o
ogoo011oo`03001oogoo0<ioo`00EWoo00<007ooOol0Mgoo00<007ooOol047oo00<007ooOol0cWoo
000SOol4000>Ool3000:Ool<0008Ool2001hOol00`00Oomoo`0@Ool00`00Oomoo`3>Ool0025oo`P0
00]oo`D000Uoo``000Qoo`03001oogoo07Moo`03001oogoo011oo`03001oogoo0<ioo`008Goo0P00
17oo0P002goo1@002Woo0`001Woo0P0027oo00<007ooOol0MWoo00<007ooOol04Goo00<007ooOol0
cWoo000POol20006Ool2000:Ool5000;Ool3000?Ool00`00Oomoo`1fOol00`00Oomoo`0AOol00`00
Oomoo`3>Ool0021oo`8000Ioo`8000]oo`<000eoo`<000ioo`03001oogoo07Ioo`03001oogoo019o
o`03001oogoo0<eoo`0037oo3@001Woo0P0027oo0P006goo0`003Goo00<007ooOol0MWoo00<007oo
Ool04Woo00<007ooOol0cGoo000<Ool=0006Ool20008Ool2000LOol3000<Ool00`00Oomoo`1fOol0
0`00Oomoo`0BOol00`00Oomoo`3=Ool000aoo`d000Ioo`8000Qoo`8001eoo`<000]oo`<007Ioo`03
001oogoo019oo`03001oogoo0<eoo`007goo0P0027oo0P007Woo0`002Woo00<007ooOol0MGoo00<0
07ooOol04goo00<007ooOol0cGoo000OOol20008Ool2000OOol30009Ool00`00Oomoo`0^Ool6000>
Ool4000MOol:0008Ool00`00Oomoo`04000>Ool4000COol:0009Ool6000>Ool4000AOol<000;Ool4
000>Ool4000BOol<0009Ool6000>Ool4000BOol001moo`8000Qoo`80021oo`8000Uoo`03001oogoo
02aoo`X000Yoo`P001]oo`X000Qoo`T000Yoo`P0015oo`X000Moo`X000Yoo`P000moo``000Uoo`P0
00Yoo`P0011oo``000Moo`X000Yoo`P0011oo`007goo0P0027oo0P008Goo0P0027oo00<007ooOol0
;7oo0`001Goo0`002Goo0P0017oo0P007goo0P0037oo0`0017oo0P002Woo0P000Woo00@007oo0000
01Eoo`8000]oo`<000Eoo`<000Uoo`8000Aoo`80011oo`<000Ioo`8000Uoo`8000Aoo`8000Yoo`80
00Aoo`80015oo`<000Ioo`8000Moo`<000Eoo`<000Uoo`8000Aoo`80011oo`007goo0P0027oo0P00
8Goo0P0027oo00<007ooOol0=Goo0P0027oo0P001Woo0P007Woo0P002goo0`001Woo0P0027oo0P00
0goo00<007ooOol00P0057oo0P0057oo0P0027oo0P001Woo0P0047oo0`003goo0P001Woo0P0027oo
0P001Woo0P004Goo0`005goo0P0027oo0P001Woo0P003goo000POol20006Ool2000IOol20007Ool2
0008Ool00`00Oomoo`0fOol20007Ool20006Ool2000NOol2000;Ool30006Ool20008Ool20003Ool0
0`00Oomoo`02000DOol2000EOol20007Ool20006Ool2000AOol3000>Ool20006Ool20008Ool20006
Ool2000BOol3000GOol20007Ool20006Ool2000?Ool0021oo`8000Ioo`8001Uoo`<000Ioo`8000Qo
o`8003Moo`8000Ioo`8000Qoo`8001eoo`8000]oo`8000Qoo`8000Ioo`8000Aoo`04001oogooOol2
000COol2000EOol20006Ool20008Ool2000AOol3000<Ool20008Ool20006Ool20008Ool2000BOol3
000FOol20006Ool20008Ool2000>Ool0025oo`8000Aoo`8001Yoo`@000Aoo`8000Uoo`03001oogoo
03Ioo`8000Ioo`8000Qoo`8001eoo`8000Yoo`<000Qoo`8000Ioo`8000Eoo`03001oogoo008001=o
o`8001Eoo`8000Ioo`8000Qoo`80019oo`<000]oo`8000Qoo`8000Ioo`8000Qoo`8001=oo`<001Eo
o`8000Ioo`8000Qoo`8000ioo`008Goo20006goo20002Woo00<007ooOol0=Woo0P001Woo0P0027oo
0P007Goo0P002Woo0`0027oo0P001Woo0P001Goo00<007ooOol00P004goo0P005Goo0P001Woo0P00
27oo0P004goo0`002Woo0P0027oo0P001Woo0P0027oo0P0057oo0`0057oo0P001Woo0P0027oo0P00
3Woo000SOol4000OOol5000;Ool00`00Oomoo`0fOol20006Ool20008Ool2000MOol2000:Ool30008
Ool20006Ool20005Ool00`00Oomoo`02000COol2000EOol20006Ool20008Ool2000DOol30009Ool2
0008Ool20006Ool20008Ool2000EOol3000COol20006Ool20008Ool2000>Ool005Ioo`03001oogoo
03Eoo`8000Moo`8000Qoo`8001eoo`8000Uoo`04001oo`000008Ool20006Ool20006Ool01000Ool0
00004goo0P0057oo0P001goo0P0027oo0P005Goo0`0027oo0P0027oo0P001Woo0P0027oo0P005Woo
0`004Goo0P001goo0P0027oo0P003Woo001FOol00`00Oomoo`0]Ool20005Ool30007Ool20008Ool2
000MOol20009Ool01000Ool0000027oo0P001Woo0P001Woo00@007oo000001=oo`8000aoo`8000Eo
o`<000Moo`8000Qoo`8001Ioo`8000Qoo`8000Qoo`8000Ioo`8000Qoo`8001Moo`8000Uoo`8000Eo
o`<000Moo`8000Qoo`8000ioo`00EWoo00<007ooOol0;Goo2@0027oo0P0027oo0P007Goo0P002Goo
00@007oo000000Qoo`8000Ioo`8000Ioo`04001oo`00000COol2000<Ool90008Ool20008Ool2000G
Ool20007Ool20008Ool20006Ool20008Ool2000HOol20008Ool90008Ool20008Ool2000>Ool005Io
o`8002ioo`800003Ool0000000<000Uoo`8000Qoo`8001eoo`8000Uoo`04001oo`000008Ool20006
Ool20007Ool3000COol2000<Ool200000goo000000030009Ool20008Ool2000GOol20007Ool20008
Ool20006Ool20008Ool2000HOol20008Ool200000goo000000030009Ool20008Ool2000>Ool005Io
o`03001oogoo02eoo`80011oo`8000Ioo`8001ioo`8000Qoo`04001oogooOol20006Ool20008Ool2
0006Ool2000DOol2000<Ool2000@Ool20006Ool2000?Ool20007Ool20008Ool20006Ool20008Ool2
0006Ool2000@Ool20007Ool20008Ool2000@Ool20006Ool2000?Ool005Ioo`03001oogoo02eoo`80
011oo`8000Ioo`8001ioo`8000Qoo`04001oogooOol20006Ool20008Ool20006Ool2000DOol2000<
Ool2000@Ool20006Ool2000?Ool30006Ool20008Ool20006Ool20008Ool20006Ool2000@Ool30006
Ool20008Ool2000@Ool20006Ool2000?Ool005Ioo`03001oogoo02eoo`80015oo`8000Aoo`8001]o
o`<00003Ool0000000Qoo`03001oogoo009oo`8000Aoo`8000Yoo`8000Aoo`80015oo`<00003Ool0
000000aoo`80015oo`8000Aoo`80011oo`@000Aoo`8000Yoo`8000Aoo`8000Yoo`8000Aoo`80015o
o`@000Aoo`8000Uoo`80015oo`8000Aoo`80011oo`00EWoo00<007ooOol0;Goo2P002Goo20006goo
1P001goo00<007ooOol00goo20002Woo2@0047oo1P0037oo2P002Goo20004Goo20002goo20002Woo
20004Woo20002Woo2P002Goo200047oo001FOol00`00Oomoo`0]Ool:000;Ool4000POol30007Ool0
0`00Oomoo`05Ool4000>Ool40002Ool00`00Oomoo`0AOol3000<Ool:000;Ool4000EOol5000>Ool4
000>Ool4000FOol5000;Ool:000;Ool4000BOol005Ioo`03001oogoo071oo`03001oogoo01eoo`03
001oogoo0<Qoo`00EWoo0P00L7oo00<007ooOol07goo00<007ooOol0agoo001FOol00`00Oomoo`1^
Ool00`00Oomoo`0QOol00`00Oomoo`36Ool005Ioo`03001oogoo06eoo`03001oogoo02=oo`03001o
ogoo0<Eoo`00EWoo00<007ooOol0KGoo00<007ooOol08goo00<007ooOol0aGoo001FOol00`00Oomo
o`1/Ool00`00Oomoo`0UOol00`00Oomoo`34Ool005Ioo`03001oogoo06Uoo`<002Uoo`03001oogoo
0<=oo`00EWoo00<007ooOol0IGoo1000;Goo0`00`Woo001FOooo000j000UOol005Ioo`03001oogoo
00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo00Yoo`03001oogoo00Eoo`<00003Ool007oo00]oo`03001oogoo00Uoo`03001o
ogoo00Uoo`04001oogooOol20007Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool0
0`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool0
0`00Oomoo`0SOol005Ioo`03001oogoo03]oo`03001oogoo03aoo`03001oogoo021oo`03001oogoo
01Qoo`03001oogoo00aoo`03001oogoo02aoo`03001oogoo03aoo`03001oogoo02=oo`00EWoo00<0
07ooOol0WWoo00<007ooOol097oo0P00U7oo001FOol00`00Oomoo`2OOol00`00Oomoo`0ROol00`00
Oomoo`2DOol005Ioo`03001oogoo09moo`03001oogoo029oo`03001oogoo09Aoo`00EWoo00<007oo
Ool0X7oo00<007ooOol087oo00<007ooOol0UGoo001FOol2002QOol00`00Oomoo`0POol00`00Oomo
o`2EOol005Ioo`03001oogoo0:5oo`03001oogoo01ioo`03001oogoo09Ioo`00EWoo00<007ooOol0
XWoo00<007ooOol07Goo00<007ooOol0UWoo001FOol00`00Oomoo`2ROol00`00Oomoo`0LOol00`00
Oomoo`2GOol005Ioo`03001oogoo0:=oo`03001oogoo01]oo`03001oogoo09Moo`00EWoo00<007oo
Ool0Xgoo00<007ooOol06goo00<007ooOol0Ugoo001FOol00`00Oomoo`2SOol00`00Oomoo`0JOol0
0`00Oomoo`2HOol005Ioo`800:Aoo`03001oogoo01Yoo`03001oogoo09Qoo`00EWoo00<007ooOol0
Y7oo00<007ooOol067oo00<007ooOol0VGoo001FOol00`00Oomoo`2TOol00`00Oomoo`0HOol00`00
Oomoo`2IOol005Ioo`03001oogoo0:Aoo`03001oogoo01Qoo`03001oogoo09Uoo`00EWoo00<007oo
Ool0Y7oo00<007ooOol05goo00<007ooOol0VWoo001FOol00`00Oomoo`2TOol00`00Oomoo`0GOol0
0`00Oomoo`2JOol002=oo`@000ioo`<000Yoo``000Qoo`800:Ioo`03001oogoo01Ioo`03001oogoo
09Yoo`008Goo20002goo1@002Goo300027oo00<007ooOol0YGoo00<007ooOol05Woo00<007ooOol0
VWoo000QOol20004Ool2000;Ool5000:Ool30006Ool20008Ool00`00Oomoo`2UOol00`00Oomoo`0E
Ool00`00Oomoo`2KOol0021oo`8000Ioo`8000Yoo`D000]oo`<000moo`03001oogoo0:Eoo`03001o
ogoo01Eoo`03001oogoo09]oo`0087oo0P001Woo0P002goo0`003Goo0`003Woo00<007ooOol0YWoo
00<007ooOol057oo00<007ooOol0Vgoo000OOol20008Ool2000KOol3000=Ool00`00Oomoo`2VOol0
0`00Oomoo`0DOol00`00Oomoo`2KOol001moo`8000Qoo`8001aoo`<000aoo`03001oogoo0:Ioo`03
001oogoo01Aoo`03001oogoo09]oo`007goo0P0027oo0P007Goo0`002goo0`00Ygoo00<007ooOol0
4goo00<007ooOol0Vgoo000OOol20008Ool2000NOol3000:Ool00`00Oomoo`2WOol00`00Oomoo`0B
Ool00`00Oomoo`2LOol001moo`8000Qoo`8001moo`<000Uoo`03001oogoo0:Moo`03001oogoo019o
o`03001oogoo09aoo`007goo0P0027oo0P0087oo0P002Goo00<007ooOol0Ygoo00<007ooOol04Woo
00<007ooOol0W7oo000OOol20008Ool2000QOol20008Ool00`00Oomoo`2WOol00`00Oomoo`0BOol0
0`00Oomoo`2LOol001moo`8000Qoo`80025oo`8000Qoo`03001oogoo0:Qoo`03001oogoo011oo`03
001oogoo09eoo`0087oo0P001Woo0P006Goo0P001goo0P0027oo00<007ooOol0Z7oo00<007ooOol0
47oo00<007ooOol0WGoo000POol20006Ool2000IOol30006Ool20008Ool2002YOol00`00Oomoo`0@
Ool00`00Oomoo`2MOol0025oo`8000Aoo`8001Yoo`@000Aoo`8000Uoo`03001oogoo0:Qoo`03001o
ogoo00moo`03001oogoo09ioo`008Goo20006goo20002Woo00<007ooOol0Z7oo00<007ooOol03goo
00<007ooOol0WWoo000SOol4000OOol5000;Ool00`00Oomoo`2XOol00`00Oomoo`0?Ool00`00Oomo
o`2NOol005Ioo`03001oogoo0:Uoo`03001oogoo00ioo`03001oogoo09ioo`00EWoo00<007ooOol0
ZGoo00<007ooOol03Woo00<007ooOol0WWoo001FOol00`00Oomoo`2YOol00`00Oomoo`0=Ool00`00
Oomoo`2OOol005Ioo`800:Yoo`03001oogoo00eoo`03001oogoo09moo`00EWoo00<007ooOol0ZGoo
00<007ooOol03Goo00<007ooOol0Wgoo001FOol00`00Oomoo`2YOol00`00Oomoo`0=Ool00`00Oomo
o`2OOol005Ioo`03001oogoo0:Uoo`03001oogoo00eoo`03001oogoo09moo`00EWoo00<007ooOol0
ZWoo00<007ooOol037oo00<007ooOol0Wgoo001FOol00`00Oomoo`2ZOol00`00Oomoo`0<Ool00`00
Oomoo`2OOol005Ioo`03001oogoo0:Yoo`03001oogoo00]oo`03001oogoo0:1oo`008goo10003Woo
0`0047oo1`001goo0P00Zgoo00<007ooOol02goo00<007ooOol0X7oo000QOol8000;Ool5000?Ool7
0007Ool00`00Oomoo`2ZOol00`00Oomoo`0;Ool00`00Oomoo`2POol0025oo`8000Aoo`8000]oo`D0
019oo`8000Uoo`03001oogoo0:Yoo`03001oogoo00]oo`03001oogoo0:1oo`0087oo0P001Woo0P00
2Woo1@004Woo0P002Goo00<007ooOol0Zgoo00<007ooOol02Woo00<007ooOol0X7oo000POol20006
Ool2000;Ool3000COol20009Ool00`00Oomoo`2[Ool00`00Oomoo`0:Ool00`00Oomoo`2POol001mo
o`8000Qoo`8001Qoo``000Moo`03001oogoo0:]oo`03001oogoo00Yoo`03001oogoo0:1oo`007goo
0P0027oo0P0067oo30001goo00<007ooOol0[7oo00<007ooOol027oo00<007ooOol0XGoo000OOol2
0008Ool2000HOol20006Ool200000goo001oo`06Ool3002/Ool00`00Oomoo`08Ool00`00Oomoo`2Q
Ool001moo`8000Qoo`8001Uoo`8000Eoo`8000Uoo`03001oogoo0:aoo`03001oogoo00Qoo`03001o
ogoo0:5oo`007goo0P0027oo0P006Goo0`0017oo0P002Goo00<007ooOol0[7oo00<007ooOol027oo
00<007ooOol0XGoo000OOol20008Ool2000JOol20004Ool20009Ool00`00Oomoo`2/Ool00`00Oomo
o`08Ool00`00Oomoo`2QOol001moo`8000Qoo`8001]oo`8000=oo`8000Uoo`03001oogoo0:eoo`03
001oogoo00Moo`03001oogoo0:5oo`007goo0P0027oo0P006goo0`000Woo0P002Goo00<007ooOol0
[Goo00<007ooOol01Woo00<007ooOol0XWoo000POol20006Ool2000MOol20002Ool20009Ool00`00
Oomoo`2]Ool00`00Oomoo`06Ool00`00Oomoo`2ROol0021oo`8000Ioo`8001ioo`800003Ool00000
00Uoo`800:ioo`03001oogoo00Ioo`03001oogoo0:9oo`008Goo0P0017oo0P0087oo10002Goo00<0
07ooOol0[Goo00<007ooOol01Woo00<007ooOol0XWoo000QOol8000POol40009Ool00`00Oomoo`2^
Ool00`00Oomoo`04Ool00`00Oomoo`2SOol002=oo`@002=oo`<000Uoo`03001oogoo0:ioo`03001o
ogoo00Aoo`03001oogoo0:=oo`00EWoo00<007ooOol0[Woo00<007ooOol00goo00<007ooOol0Y7oo
001FOol00`00Oomoo`2^Ool00`00Oomoo`03Ool00`00Oomoo`2TOol005Ioo`03001oogoo0:moo`03
001oogoo009oo`03001oogoo0:Aoo`00EWoo0P00/7oo00D007ooOomoo`000:Moo`00EWoo00<007oo
Ool0/7oo00@007ooOol00:Moo`00EWoo00<007ooOol0/Goo0P00Z7oo001FOol00`00Oomoo`3oOomL
Ool005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomL
Ool005Ioo`800?mooeeoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Io
o`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Io
o`03001oogoo0?mooeaoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mo
okEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo
003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mo
okEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo
003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mo
okEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo
003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mo
okEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo
003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mo
okEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo
003oOoneOol00?mookEoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Io
o`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Io
o`03001oogoo0?mooeaoo`00EWoo0P00ogooGGoo001FOol00`00Oomoo`3oOomLOol005Ioo`03001o
ogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001o
ogoo0?mooeaoo`00EWoo0P00ogooGGoo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mo
oeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol002=oo`@000ioo`<0011o
o`L000Moo`03001oogoo0?mooeaoo`008Goo20002goo1@003goo1`001goo0P00ogooGGoo000QOol2
0004Ool2000;Ool5000BOol20009Ool00`00Oomoo`3oOomLOol0021oo`8000Ioo`8000Yoo`D0019o
o`8000Uoo`03001oogoo0?mooeaoo`0087oo0P001Woo0P002goo0`004goo0P002Goo00<007ooOol0
ogooG7oo000<Ool=0006Ool20008Ool2000HOol<0007Ool00`00Oomoo`3oOomLOol000aoo`d000Io
o`8000Qoo`8001Qoo``000Moo`03001oogoo0?mooeaoo`0037oo3@001Woo0P0027oo0P0067oo0P00
1Woo0P0000=oo`00Ool01Woo0`00ogooG7oo000OOol20008Ool2000IOol20005Ool20009Ool00`00
Oomoo`3oOomLOol001moo`8000Qoo`8001Uoo`<000Aoo`8000Uoo`03001oogoo0?mooeaoo`007goo
0P0027oo0P006Woo0P0017oo0P002Goo00<007ooOol0ogooG7oo000OOol20008Ool2000KOol20003
Ool20009Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001]oo`<0009oo`8000Uoo`03001oogoo
0?mooeaoo`0087oo0P001Woo0P007Goo0P000Woo0P002Goo0P00ogooGGoo000POol20006Ool2000N
Ool200000goo00000009Ool00`00Oomoo`3oOomLOol0025oo`8000Aoo`80021oo`@000Uoo`03001o
ogoo0?mooeaoo`008Goo200087oo10002Goo00<007ooOol0ogooG7oo000SOol4000SOol30009Ool0
0`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo0P00ogooGGoo001FOol00`00Oomo
o`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomo
o`3oOomLOol002=oo`@000ioo`<000Yoo``000Qoo`03001oogoo0?mooeaoo`008Goo20002goo1@00
2Goo300027oo0P00ogooGGoo000QOol20004Ool2000;Ool5000:Ool30006Ool20008Ool00`00Oomo
o`3oOomLOol0021oo`8000Ioo`8000Yoo`D000]oo`<000moo`03001oogoo0?mooeaoo`0087oo0P00
1Woo0P002goo0`003Goo0`003Woo00<007ooOol0ogooG7oo000<Ool=0006Ool20008Ool2000KOol3
000=Ool00`00Oomoo`3oOomLOol000aoo`d000Ioo`8000Qoo`8001aoo`<000aoo`03001oogoo02io
o`H000ioo`@001eoo`X000]oo`@000ioo`@001=oo`X000Uoo`H000ioo`@0015oo``000]oo`@000io
o`@0019oo``000Uoo`H000ioo`@0019oo`0037oo3@001Woo0P0027oo0P007Goo0`002goo0`00;7oo
2P002Woo20006goo2P002Goo20002Woo20004Goo2P001goo2P002Woo20003goo30002Goo20002Woo
200047oo30001goo2P002Woo200047oo000OOol20008Ool2000NOol3000:Ool00`00Oomoo`0/Ool3
0005Ool30009Ool20004Ool2000OOol2000=Ool20004Ool2000:Ool20004Ool2000EOol2000;Ool3
0005Ool30009Ool20004Ool2000@Ool30006Ool20009Ool20004Ool2000:Ool20004Ool2000AOol3
0006Ool20007Ool30005Ool30009Ool20004Ool2000@Ool001moo`8000Qoo`8001moo`<000Uoo`03
001oogoo03Eoo`8000Qoo`8000Ioo`8001ioo`8000aoo`8000Ioo`8000Qoo`8000Ioo`8001Aoo`80
01Aoo`8000Qoo`8000Ioo`80011oo`<000moo`8000Ioo`8000Qoo`8000Ioo`80015oo`<001Moo`80
00Qoo`8000Ioo`8000moo`007goo0P0027oo0P0087oo0P002Goo00<007ooOol0=Woo0P001goo0P00
1Woo0P007Woo0P0037oo0P001Woo0P0027oo0P001Woo0P0057oo0P005Goo0P001goo0P001Woo0P00
4Goo0`003Woo0P001Woo0P0027oo0P001Woo0P004Woo0`005goo0P001goo0P001Woo0P003goo000O
Ool20008Ool2000QOol20008Ool00`00Oomoo`0fOol20006Ool20008Ool2000MOol2000;Ool20008
Ool20006Ool20008Ool2000COol2000EOol20006Ool20008Ool2000AOol3000<Ool20008Ool20006
Ool20008Ool2000BOol3000FOol20006Ool20008Ool2000>Ool001moo`8000Qoo`80025oo`8000Qo
o`03001oogoo03Ioo`8000Ioo`8000Qoo`8001eoo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8001=o
o`8001Eoo`8000Ioo`8000Qoo`80019oo`<000]oo`8000Qoo`8000Ioo`8000Qoo`8001=oo`<001Eo
o`8000Ioo`8000Qoo`8000ioo`0087oo0P001Woo0P006Goo0P001goo0P0027oo0P00=goo0P001Woo
0P0027oo0P007Goo0P002goo0P0027oo0P001Woo0P0027oo0P004goo0P005Goo0P001Woo0P0027oo
0P004goo0`002Woo0P0027oo0P001Woo0P0027oo0P0057oo0`0057oo0P001Woo0P0027oo0P003Woo
000POol20006Ool2000IOol30006Ool20008Ool00`00Oomoo`0fOol20006Ool20008Ool2000MOol2
000;Ool20008Ool20006Ool20008Ool2000COol2000EOol20006Ool20008Ool2000DOol30009Ool2
0008Ool20006Ool20008Ool2000EOol3000COol20006Ool20008Ool2000>Ool0025oo`8000Aoo`80
01Yoo`@000Aoo`8000Uoo`03001oogoo03Eoo`8000Moo`8000Qoo`8001eoo`8000]oo`8000Qoo`80
00Ioo`8000Qoo`8001=oo`8001Aoo`8000Moo`8000Qoo`8001Eoo`<000Qoo`8000Qoo`8000Ioo`80
00Qoo`8001Ioo`<0015oo`8000Moo`8000Qoo`8000ioo`008Goo20006goo20002Woo00<007ooOol0
;Goo0P001Goo0`001goo0P0027oo0P007Goo0P002goo0P0027oo0P001Woo0P0027oo0P004goo0P00
37oo0P001Goo0`001goo0P0027oo0P005Woo0P0027oo0P0027oo0P001Woo0P0027oo0P005goo0P00
2Goo0P001Goo0`001goo0P0027oo0P003Woo000SOol4000OOol5000;Ool00`00Oomoo`0]Ool90008
Ool20008Ool2000MOol2000;Ool20008Ool20006Ool20008Ool2000COol2000<Ool90008Ool20008
Ool2000GOol20007Ool20008Ool20006Ool20008Ool2000HOol20008Ool90008Ool20008Ool2000>
Ool005Ioo`03001oogoo02eoo`800003Ool0000000<000Uoo`8000Qoo`8001eoo`8000]oo`8000Qo
o`8000Ioo`8000Qoo`8001=oo`8000aoo`800003Ool0000000<000Uoo`8000Qoo`8001Moo`8000Mo
o`8000Qoo`8000Ioo`8000Qoo`8001Qoo`8000Qoo`800003Ool0000000<000Uoo`8000Qoo`8000io
o`00EWoo0P00;Woo0P0047oo0P001Woo0P007Woo0P0037oo0P001Woo0P0027oo0P001Woo0P0057oo
0P0037oo0P0047oo0P001Woo0P003goo0P001goo0P0027oo0P001Woo0P0027oo0P001Woo0P0047oo
0P001goo0P0027oo0P0047oo0P001Woo0P003goo001FOol00`00Oomoo`0]Ool2000@Ool20006Ool2
000NOol2000<Ool20006Ool20008Ool20006Ool2000DOol2000<Ool2000@Ool20006Ool2000?Ool3
0006Ool20008Ool20006Ool20008Ool20006Ool2000@Ool30006Ool20008Ool2000@Ool20006Ool2
000?Ool005Ioo`03001oogoo02eoo`80015oo`8000Aoo`8001]oo`<00003Ool0000000eoo`8000Ao
o`8000Yoo`8000Aoo`80015oo`<00003Ool0000000aoo`80015oo`8000Aoo`80011oo`@000Aoo`80
00Yoo`8000Aoo`8000Yoo`8000Aoo`80015oo`@000Aoo`8000Uoo`80015oo`8000Aoo`80011oo`00
EWoo00<007ooOol0;Goo2P002Goo20006goo1P003Goo20002Woo20004Goo1P0037oo2P002Goo2000
4Goo20002goo20002Woo20004Woo20002Woo2P002Goo200047oo001FOol00`00Oomoo`0]Ool:000;
Ool4000POol3000?Ool4000>Ool4000FOol3000<Ool:000;Ool4000EOol5000>Ool4000>Ool4000F
Ool5000;Ool:000;Ool4000BOol005Ioo`03001oogoo0?mooeaoo`00EWoo0P00ogooGGoo001FOol0
0`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol0
0`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWooo`00>P009Goo001FOol00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Ool000050004Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`070002Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`02Ool60002Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`0:Ool00`00Oomoo`0SOol005Ioo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03
001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Eoo`<00003Ool007oo00]oo`03001oogoo00Uoo`03001oogoo00Yoo`03001oo`0000Mo
o`03001oo`0000aoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo008000Qoo`03001oogoo
00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo02=oo`00EWoo00<007ooOol0K7oo00<0
07ooOol09Goo00<007ooOol01goo00<007ooOol097oo0P00U7oo001FOol00`00Oomoo`1]Ool00`00
Oomoo`0SOol00`00Oomoo`09Ool00`00Oomoo`0ROol00`00Oomoo`2DOol005Ioo`03001oogoo06eo
o`03001oogoo029oo`03001oogoo00Yoo`03001oogoo029oo`03001oogoo09Aoo`00EWoo0P00Kgoo
0P008Goo00<007ooOol037oo00<007ooOol087oo00<007ooOol0UGoo001FOol00`00Oomoo`1`Ool0
0`00Oomoo`0NOol00`00Oomoo`0=Ool00`00Oomoo`0NOol00`00Oomoo`2FOol005Ioo`03001oogoo
071oo`03001oogoo01eoo`03001oogoo00moo`03001oogoo01eoo`03001oogoo09Ioo`00EWoo00<0
07ooOol0LGoo00<007ooOol077oo00<007ooOol03goo00<007ooOol077oo00<007ooOol0Ugoo001F
Ool00`00Oomoo`1aOol00`00Oomoo`0KOol00`00Oomoo`0AOol00`00Oomoo`0KOol00`00Oomoo`2G
Ool005Ioo`03001oogoo075oo`03001oogoo01]oo`03001oogoo015oo`03001oogoo01]oo`03001o
ogoo09Moo`00EWoo0P00Lgoo00<007ooOol06Woo00<007ooOol04Goo00<007ooOol06Woo00<007oo
Ool0V7oo001FOol00`00Oomoo`1bOol00`00Oomoo`0JOol00`00Oomoo`0AOol00`00Oomoo`0IOol0
0`00Oomoo`2IOol005Ioo`03001oogoo079oo`03001oogoo01Uoo`03001oogoo01=oo`03001oogoo
01Qoo`03001oogoo09Uoo`00EWoo00<007ooOol0LWoo00<007ooOol06Goo00<007ooOol04goo00<0
07ooOol067oo00<007ooOol0VGoo001FOol00`00Oomoo`1cOol00`00Oomoo`0HOol00`00Oomoo`0C
Ool00`00Oomoo`0GOol00`00Oomoo`2JOol005Ioo`03001oogoo07=oo`03001oogoo01Moo`03001o
ogoo01Aoo`03001oogoo01Moo`03001oogoo09Yoo`008goo10003Woo0`002Woo300027oo00<007oo
Ool0Lgoo00<007ooOol05goo00<007ooOol05Goo00<007ooOol05Woo00<007ooOol0VWoo000QOol8
000;Ool50009Ool<0008Ool2001eOol00`00Oomoo`0EOol00`00Oomoo`0FOol00`00Oomoo`0FOol0
0`00Oomoo`2JOol0025oo`8000Aoo`8000]oo`D000Yoo`<000Ioo`8000Qoo`03001oogoo07Aoo`03
001oogoo01Eoo`03001oogoo01Ioo`03001oogoo01Eoo`03001oogoo09]oo`0087oo0P001Woo0P00
2Woo1@002goo0`003goo00<007ooOol0MGoo00<007ooOol057oo00<007ooOol05goo00<007ooOol0
57oo00<007ooOol0Vgoo000POol20006Ool2000;Ool3000=Ool3000>Ool00`00Oomoo`1eOol00`00
Oomoo`0COol00`00Oomoo`0HOol00`00Oomoo`0DOol00`00Oomoo`2KOol001moo`8000Qoo`8001]o
o`<000eoo`03001oogoo07Eoo`03001oogoo01=oo`03001oogoo01Qoo`03001oogoo01Aoo`03001o
ogoo09]oo`007goo0P0027oo0P0077oo0`0037oo00<007ooOol0MWoo00<007ooOol04Woo00<007oo
Ool06Goo00<007ooOol04Woo00<007ooOol0W7oo000OOol20008Ool2000MOol3000;Ool3001fOol0
0`00Oomoo`0BOol00`00Oomoo`0IOol00`00Oomoo`0BOol00`00Oomoo`2LOol001moo`8000Qoo`80
01ioo`<000Yoo`03001oogoo07Ioo`03001oogoo019oo`03001oogoo01Uoo`03001oogoo019oo`03
001oogoo09aoo`007goo0P0027oo0P007goo0`002Goo00<007ooOol0MWoo00<007ooOol04Goo00<0
07ooOol06goo00<007ooOol04Goo00<007ooOol0W7oo000OOol20008Ool2000POol20009Ool00`00
Oomoo`1fOol00`00Oomoo`0AOol00`00Oomoo`0KOol00`00Oomoo`0@Ool00`00Oomoo`2MOol001mo
o`8000Qoo`80025oo`8000Qoo`03001oogoo07Moo`03001oogoo011oo`03001oogoo01]oo`03001o
ogoo011oo`03001oogoo09eoo`007goo0P0027oo0P008Goo0P0027oo00<007ooOol0Mgoo00<007oo
Ool047oo00<007ooOol06goo00<007ooOol047oo00<007ooOol0WGoo000POol20006Ool2000IOol2
0007Ool20008Ool2001hOol00`00Oomoo`0@Ool00`00Oomoo`0KOol00`00Oomoo`0?Ool00`00Oomo
o`2NOol0021oo`8000Ioo`8001Uoo`<000Ioo`8000Qoo`03001oogoo07Moo`03001oogoo011oo`03
001oogoo01]oo`03001oogoo00moo`03001oogoo09ioo`008Goo0P0017oo0P006Woo100017oo0P00
2Goo00<007ooOol0Mgoo00<007ooOol03goo00<007ooOol07Goo00<007ooOol03Woo00<007ooOol0
WWoo000QOol8000KOol8000:Ool00`00Oomoo`1gOol00`00Oomoo`0?Ool00`00Oomoo`0MOol00`00
Oomoo`0>Ool00`00Oomoo`2NOol002=oo`@001moo`D000]oo`03001oogoo07Qoo`03001oogoo00io
o`03001oogoo01eoo`03001oogoo00eoo`03001oogoo09moo`00EWoo00<007ooOol0N7oo00<007oo
Ool03Woo00<007ooOol07Goo00<007ooOol03Goo00<007ooOol0Wgoo001FOol2001iOol00`00Oomo
o`0=Ool00`00Oomoo`0NOol00`00Oomoo`0=Ool00`00Oomoo`2OOol005Ioo`03001oogoo07Qoo`03
001oogoo00eoo`03001oogoo01ioo`03001oogoo00eoo`03001oogoo09moo`00EWoo00<007ooOol0
NGoo00<007ooOol037oo00<007ooOol07goo00<007ooOol037oo00<007ooOol0Wgoo001FOol00`00
Oomoo`1iOol00`00Oomoo`0;Ool00`00Oomoo`0POol00`00Oomoo`0;Ool00`00Oomoo`2POol005Io
o`03001oogoo07Uoo`03001oogoo00]oo`03001oogoo021oo`03001oogoo00]oo`03001oogoo0:1o
o`008goo10003Woo0`0047oo1`001goo00<007ooOol0NWoo00<007ooOol02Woo00<007ooOol087oo
00<007ooOol02goo00<007ooOol0X7oo000QOol8000;Ool5000?Ool70007Ool2001kOol00`00Oomo
o`0:Ool00`00Oomoo`0QOol00`00Oomoo`0:Ool00`00Oomoo`2POol0025oo`8000Aoo`8000]oo`D0
019oo`8000Uoo`03001oogoo07Yoo`03001oogoo00Yoo`03001oogoo025oo`03001oogoo00Yoo`03
001oogoo0:1oo`0087oo0P001Woo0P002Woo1@004Woo0P002Goo00<007ooOol0NWoo00<007ooOol0
2Goo00<007ooOol08Woo00<007ooOol02Woo00<007ooOol0X7oo000POol20006Ool2000;Ool3000C
Ool20009Ool00`00Oomoo`1kOol00`00Oomoo`08Ool00`00Oomoo`0SOol00`00Oomoo`08Ool00`00
Oomoo`2QOol001moo`8000Qoo`8001Qoo``000Moo`03001oogoo07]oo`03001oogoo00Qoo`03001o
ogoo02=oo`03001oogoo00Qoo`03001oogoo0:5oo`007goo0P0027oo0P0067oo30001goo00<007oo
Ool0Ngoo00<007ooOol027oo00<007ooOol08goo00<007ooOol027oo00<007ooOol0XGoo000OOol2
0008Ool2000HOol20006Ool200000goo001oo`06Ool3001kOol00`00Oomoo`08Ool00`00Oomoo`0S
Ool00`00Oomoo`08Ool00`00Oomoo`2QOol001moo`8000Qoo`8001Uoo`8000Eoo`8000Uoo`03001o
ogoo07]oo`03001oogoo00Moo`03001oogoo02Eoo`03001oogoo00Moo`03001oogoo0:5oo`007goo
0P0027oo0P006Goo0`0017oo0P002Goo00<007ooOol0O7oo00<007ooOol01Woo00<007ooOol09Goo
00<007ooOol01Woo00<007ooOol0XWoo000OOol20008Ool2000JOol20004Ool20009Ool00`00Oomo
o`1lOol00`00Oomoo`06Ool00`00Oomoo`0UOol00`00Oomoo`06Ool00`00Oomoo`2ROol001moo`80
00Qoo`8001]oo`8000=oo`8000Uoo`03001oogoo07aoo`03001oogoo00Ioo`03001oogoo02Eoo`03
001oogoo00Ioo`03001oogoo0:9oo`007goo0P0027oo0P006goo0`000Woo0P002Goo00<007ooOol0
O7oo00<007ooOol01Woo00<007ooOol09Goo00<007ooOol01Goo00<007ooOol0Xgoo000POol20006
Ool2000MOol20002Ool20009Ool2001nOol00`00Oomoo`04Ool00`00Oomoo`0WOol00`00Oomoo`04
Ool00`00Oomoo`2SOol0021oo`8000Ioo`8001ioo`800003Ool0000000Uoo`03001oogoo07eoo`03
001oogoo00Aoo`03001oogoo02Moo`03001oogoo00=oo`03001oogoo0:Aoo`008Goo0P0017oo0P00
87oo10002Goo00<007ooOol0OGoo00<007ooOol017oo00<007ooOol09goo00<007ooOol00goo00<0
07ooOol0Y7oo000QOol8000POol40009Ool00`00Oomoo`1nOol00`00Oomoo`02Ool00`00Oomoo`0Y
Ool01@00Oomoogoo0000Ygoo000SOol4000SOol30009Ool00`00Oomoo`1oOol01000Oomoo`00;7oo
0P000Woo00<007ooOol0YGoo001FOol00`00Oomoo`20Ool2000_Ool2002XOol005Ioo`800?mooeeo
o`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeao
o`00EWoo00<007ooOol0ogooG7oo000SOol4000>Ool3000?Ool5000:Ool00`00Oomoo`3oOomLOol0
025oo`P000]oo`D000aoo`P000Uoo`800?mooeeoo`008Goo0P0017oo0P002goo1@0037oo0P0017oo
0`0027oo00<007ooOol0ogooG7oo000POol20006Ool2000:Ool5000;Ool20006Ool30007Ool00`00
Oomoo`3oOomLOol0021oo`8000Ioo`8000]oo`<000]oo`8000Qoo`8000Moo`03001oogoo0?mooeao
o`007goo0P0027oo0P0067oo0P0027oo0P001goo00<007ooOol0ogooG7oo000OOol20008Ool2000H
Ool20008Ool20007Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001Qoo`8000Qoo`8000Moo`<0
0?mooeaoo`007goo0P0027oo0P0067oo0`001Woo0`001goo00<007ooOol0ogooG7oo000OOol20008
Ool2000HOol40004Ool30008Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001Qoo`800003Ool0
000000D000Uoo`03001oogoo0?mooeaoo`007goo0P0027oo0P006Goo00<007ooOol01@002Woo00<0
07ooOol0ogooG7oo000OOol20008Ool2000IOol2000@Ool00`00Oomoo`3oOomLOol0021oo`8000Io
o`8001Yoo`<000moo`800?mooeeoo`0087oo0P001Woo0P006goo0`003Woo00<007ooOol0ogooG7oo
000QOol20004Ool2000MOol3000=Ool00`00Oomoo`3oOomLOol0025oo`P001ioo`P000Moo`03001o
ogoo0?mooeaoo`008goo10008Woo1P001goo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomL
Ool005Ioo`800?mooeeoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Io
o`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo000SOol4000>Ool3000>Ool6000:Ool0
0`00Oomoo`3oOomLOol0025oo`P000]oo`D000aoo`P000Uoo`800?mooeeoo`008Goo0P0017oo0P00
2goo1@002goo0`0017oo0`0027oo00<007ooOol0ogooG7oo000POol20006Ool2000:Ool5000:Ool3
0006Ool30007Ool00`00Oomoo`3oOomLOol0021oo`8000Ioo`8000]oo`<000]oo`8000Qoo`8000Mo
o`03001oogoo0?mooeaoo`007goo0P0027oo0P0067oo0P0027oo0P001goo00<007ooOol0ogooG7oo
000OOol20008Ool2000HOol20008Ool20007Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001Qo
o`<000Ioo`<000Moo`<00?mooeaoo`007goo0P0027oo0P006Goo0`0017oo0`0027oo00<007ooOol0
ogooG7oo000OOol20008Ool2000JOol80009Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001Yo
o`P000Uoo`03001oogoo0?mooeaoo`007goo0P0027oo0P006Goo0`0017oo0`0027oo00<007ooOol0
ogooG7oo000OOol20008Ool2000HOol20008Ool20007Ool00`00Oomoo`3oOomLOol0021oo`8000Io
o`8001Uoo`8000Qoo`8000Moo`800?mooeeoo`0087oo0P001Woo0P006Goo0P0027oo0P001goo00<0
07ooOol0ogooG7oo000QOol20004Ool2000KOol30004Ool40007Ool00`00Oomoo`3oOomLOol0025o
o`P001]oo`X000Qoo`03001oogoo0?mooeaoo`008goo10007goo1P002Woo00<007ooOol0ogooG7oo
001FOol00`00Oomoo`3oOomLOol005Ioo`800?mooeeoo`00EWoo00<007ooOol0ogooG7oo001FOol0
0`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo0014Ool:
0008Ool00`00Oomoo`3oOomLOol004Aoo`X000Qoo`800?mooeeoo`00B7oo0P0037oo00<007ooOol0
ogooG7oo0018Ool2000<Ool00`00Oomoo`3oOomLOol004Qoo`8000aoo`03001oogoo0?mooeaoo`00
B7oo0P0037oo00<007ooOol0ogooG7oo0018Ool2000<Ool00`00Oomoo`3oOomLOol004Qoo`8000ao
o`<00?mooeaoo`00B7oo0P00ogooJgoo0018Ool2003oOom[Ool004Qoo`800?moof]oo`00B7oo0P00
ogooJgoo0018Ool2003oOom[Ool004Qoo`800?moof]oo`00B7oo0P00ogooJgoo0014Ool300000goo
0000003oOom[Ool004Aoo`H00?moof]oo`00Agoo0`00ogooJgoo003oOoneOol00?mookEoo`00ogoo
]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol0
0?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo
]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol0
0?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo
]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol0
0?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo
]Goo003oOoneOol00001\
\>"], "Graphics",
  CellLabel->"From In[83]:=",
  Evaluatable->False,
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "The upper wire has a short at the left and is open at the right end, the \
second wire (diagram at the bottom) is terminated left with ",
  Cell[BoxData[
      \(TraditionalForm\`Z\_l\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`Z\_0\)]],
  "/2 and right with ",
  Cell[BoxData[
      \(TraditionalForm\`Z\_r\)]],
  " = 2 ",
  Cell[BoxData[
      \(TraditionalForm\`Z\_0\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`Z\_0\)]],
  "is the impedance ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(L/C\)\)]],
  " of the wire. These boundary conditions cause reflection and transmission \
at either end of the wires."
}], "Text",
  PageBreakAbove->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006d0003Ga000`40O003h00Oogoo]Goo003oOone
Ool00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00
ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOone
Ool00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00
ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOone
Ool00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00
ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo001FOol0
0`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol0
0`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol2
003oOomMOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomo
o`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol2003oOomM
Ool005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomL
Ool005Ioo`03001oogoo0?mooeaoo`008goo10003Woo0`0047oo1`001goo00<007ooOol0ogooG7oo
000QOol8000;Ool5000?Ool70007Ool2003oOomMOol0025oo`8000Aoo`8000]oo`D0019oo`8000Uo
o`03001oogoo0?mooeaoo`0087oo0P001Woo0P002Woo1@004Woo0P002Goo00<007ooOol0ogooG7oo
000POol20006Ool2000;Ool3000COol20009Ool00`00Oomoo`3oOomLOol000aoo`d000Ioo`8000Qo
o`8001Qoo``000Moo`03001oogoo0?mooeaoo`0037oo3@001Woo0P0027oo0P0067oo30001goo00<0
07ooOol0ogooG7oo000<Ool=0006Ool20008Ool2000HOol20006Ool200000goo001oo`06Ool3003o
OomLOol001moo`8000Qoo`8001Uoo`8000Eoo`8000Uoo`03001oogoo0?mooeaoo`007goo0P0027oo
0P006Goo0`0017oo0P002Goo00<007ooOol0ogooG7oo000OOol20008Ool2000JOol20004Ool20009
Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001]oo`8000=oo`8000Uoo`03001oogoo0?mooeao
o`007goo0P0027oo0P006goo0`000Woo0P002Goo00<007ooOol0ogooG7oo000POol20006Ool2000M
Ool20002Ool20009Ool2003oOomMOol0021oo`8000Ioo`8001ioo`800003Ool0000000Uoo`03001o
ogoo0?mooeaoo`008Goo0P0017oo0P0087oo10002Goo00<007ooOol0ogooG7oo000QOol8000POol4
0009Ool00`00Oomoo`3oOomLOol002=oo`@002=oo`<000Uoo`03001oogoo0?mooeaoo`00EWoo00<0
07ooOol0ogooG7oo001FOol2003oOomMOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0
ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`008goo10003Woo0`00
2Woo300027oo00<007ooOol0ogooG7oo000QOol8000;Ool50009Ool<0008Ool2003oOomMOol0025o
o`8000Aoo`8000]oo`D000Yoo`<000Ioo`8000Qoo`03001oogoo0?mooeaoo`0087oo0P001Woo0P00
2Woo1@002goo0`003goo00<007ooOol0ogooG7oo000POol20006Ool2000;Ool3000=Ool3000>Ool0
0`00Oomoo`3oOomLOol000aoo`d000Ioo`8000Qoo`8001]oo`<000eoo`03001oogoo02ioo`H000io
o`@001eoo`X000]oo`@000ioo`@001=oo`X000Uoo`H000ioo`@0015oo``000]oo`@000ioo`@0019o
o``000Uoo`H000ioo`@0019oo`0037oo3@001Woo0P0027oo0P0077oo0`0037oo00<007ooOol0;7oo
2P002Woo20006goo2P002Goo20002Woo20004Goo2P001goo2P002Woo20003goo30002Goo20002Woo
200047oo30001goo2P002Woo200047oo000<Ool=0006Ool20008Ool2000MOol3000;Ool3000/Ool3
0005Ool30009Ool20004Ool2000OOol2000=Ool20004Ool2000:Ool20004Ool2000EOol2000;Ool3
0005Ool30009Ool20004Ool2000@Ool30006Ool20009Ool20004Ool2000:Ool20004Ool2000AOol3
0006Ool20007Ool30005Ool30009Ool20004Ool2000@Ool001moo`8000Qoo`8001ioo`<000Yoo`03
001oogoo03Eoo`8000Qoo`8000Ioo`8001ioo`8000aoo`8000Ioo`8000Qoo`8000Ioo`8001Aoo`80
01Aoo`8000Qoo`8000Ioo`80011oo`<000moo`8000Ioo`8000Qoo`8000Ioo`80015oo`<001Moo`80
00Qoo`8000Ioo`8000moo`007goo0P0027oo0P007goo0`002Goo00<007ooOol0=Woo0P001goo0P00
1Woo0P007Woo0P0037oo0P001Woo0P0027oo0P001Woo0P0057oo0P005Goo0P001goo0P001Woo0P00
4Goo0`003Woo0P001Woo0P0027oo0P001Woo0P004Woo0`005goo0P001goo0P001Woo0P003goo000O
Ool20008Ool2000POol20009Ool00`00Oomoo`0fOol20006Ool20008Ool2000MOol2000;Ool20008
Ool20006Ool20008Ool2000COol2000EOol20006Ool20008Ool2000AOol3000<Ool20008Ool20006
Ool20008Ool2000BOol3000FOol20006Ool20008Ool2000>Ool001moo`8000Qoo`80025oo`8000Qo
o`03001oogoo03Ioo`8000Ioo`8000Qoo`8001eoo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8001=o
o`8001Eoo`8000Ioo`8000Qoo`80019oo`<000]oo`8000Qoo`8000Ioo`8000Qoo`8001=oo`<001Eo
o`8000Ioo`8000Qoo`8000ioo`007goo0P0027oo0P008Goo0P0027oo00<007ooOol0=Woo0P001Woo
0P0027oo0P007Goo0P002goo0P0027oo0P001Woo0P0027oo0P004goo0P005Goo0P001Woo0P0027oo
0P004goo0`002Woo0P0027oo0P001Woo0P0027oo0P0057oo0`0057oo0P001Woo0P0027oo0P003Woo
000POol20006Ool2000IOol20007Ool20008Ool2000gOol20006Ool20008Ool2000MOol2000;Ool2
0008Ool20006Ool20008Ool2000COol2000EOol20006Ool20008Ool2000DOol30009Ool20008Ool2
0006Ool20008Ool2000EOol3000COol20006Ool20008Ool2000>Ool0021oo`8000Ioo`8001Uoo`<0
00Ioo`8000Qoo`03001oogoo03Eoo`8000Moo`8000Qoo`8001eoo`8000]oo`8000Qoo`8000Ioo`80
00Qoo`8001=oo`8001Aoo`8000Moo`8000Qoo`8001Eoo`<000Qoo`8000Qoo`8000Ioo`8000Qoo`80
01Ioo`<0015oo`8000Moo`8000Qoo`8000ioo`008Goo0P0017oo0P006Woo100017oo0P002Goo00<0
07ooOol0;Goo0P001Goo0`001goo0P0027oo0P007Goo0P002goo0P0027oo0P001Woo0P0027oo0P00
4goo0P0037oo0P001Goo0`001goo0P0027oo0P005Woo0P0027oo0P0027oo0P001Woo0P0027oo0P00
5goo0P002Goo0P001Goo0`001goo0P0027oo0P003Woo000QOol8000KOol8000:Ool00`00Oomoo`0]
Ool90008Ool20008Ool2000MOol2000;Ool20008Ool20006Ool20008Ool2000COol2000<Ool90008
Ool20008Ool2000GOol20007Ool20008Ool20006Ool20008Ool2000HOol20008Ool90008Ool20008
Ool2000>Ool002=oo`@001moo`D000]oo`03001oogoo02eoo`800003Ool0000000<000Uoo`8000Qo
o`8001eoo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8001=oo`8000aoo`800003Ool0000000<000Uo
o`8000Qoo`8001Moo`8000Moo`8000Qoo`8000Ioo`8000Qoo`8001Qoo`8000Qoo`800003Ool00000
00<000Uoo`8000Qoo`8000ioo`00EWoo00<007ooOol0;Goo0P0047oo0P001Woo0P007Woo0P0037oo
0P001Woo0P0027oo0P001Woo0P0057oo0P0037oo0P0047oo0P001Woo0P003goo0P001goo0P0027oo
0P001Woo0P0027oo0P001Woo0P0047oo0P001goo0P0027oo0P0047oo0P001Woo0P003goo001FOol2
000^Ool2000@Ool20006Ool2000NOol2000<Ool20006Ool20008Ool20006Ool2000DOol2000<Ool2
000@Ool20006Ool2000?Ool30006Ool20008Ool20006Ool20008Ool20006Ool2000@Ool30006Ool2
0008Ool2000@Ool20006Ool2000?Ool005Ioo`03001oogoo02eoo`80015oo`8000Aoo`8001]oo`<0
0003Ool0000000eoo`8000Aoo`8000Yoo`8000Aoo`80015oo`<00003Ool0000000aoo`80015oo`80
00Aoo`80011oo`@000Aoo`8000Yoo`8000Aoo`8000Yoo`8000Aoo`80015oo`@000Aoo`8000Uoo`80
015oo`8000Aoo`80011oo`00EWoo00<007ooOol0;Goo2P002Goo20006goo1P003Goo20002Woo2000
4Goo1P0037oo2P002Goo20004Goo20002goo20002Woo20004Woo20002Woo2P002Goo200047oo001F
Ool00`00Oomoo`0]Ool:000;Ool4000POol3000?Ool4000>Ool4000FOol3000<Ool:000;Ool4000E
Ool5000>Ool4000>Ool4000FOol5000;Ool:000;Ool4000BOol005Ioo`03001oogoo0?mooeaoo`00
EWoo00<007ooOol0ogooG7oo001FOol2003oOomMOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<0
07ooOol03Woo1000ogooBWoo001FOol00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`3oOom7
Ool005Ioo`03001oogoo00aoo`03001oogoo00Aoo`<00?moodIoo`00EWoo00<007ooOol037oo00<0
07ooOol01goo0P00ogooA7oo001FOooo000j000UOol005Ioo`03001oogoo00Uoo`03001oo`0000Yo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Eoo`H000=oo`8000Ioo`03001oogoo00Yoo`03001oogoo02=oo`00EWoo00<007oo
Ool02goo00<007ooOol0;Goo00<007ooOol0?7oo00<007ooOol0>goo00<007ooOol0>goo00<007oo
Ool0:Goo00<007ooOol047oo00<007ooOol08goo001FOol00`00Oomoo`0:Ool00`00Oomoo`3oOolF
Ool00`00Oomoo`0fOol005Ioo`03001oogoo00Uoo`03001oogoo0?mooaQoo`03001oogoo03Eoo`00
EWoo00<007ooOol02Goo00<007ooOol0ogoo67oo00<007ooOol0=Goo001FOol2000:Ool00`00Oomo
o`3oOolIOol00`00Oomoo`0dOol005Ioo`03001oogoo00Qoo`03001oogoo0?mooa]oo`03001oogoo
03=oo`00EWoo00<007ooOol027oo00<007ooOol0ogoo6goo00<007ooOol0<goo001FOol00`00Oomo
o`08Ool00`00Oomoo`3oOolLOol00`00Oomoo`0bOol005Ioo`03001oogoo00Qoo`03001oogoo0?mo
oaaoo`03001oogoo039oo`00EWoo00<007ooOol01goo00<007ooOol0ogoo7Goo00<007ooOol0<Woo
001FOol20008Ool00`00Oomoo`3oOolMOol00`00Oomoo`0bOol005Ioo`03001oogoo00Moo`03001o
ogoo0?mooaioo`03001oogoo035oo`00EWoo00<007ooOol01goo00<007ooOol0ogoo7Woo00<007oo
Ool0<Goo001FOol00`00Oomoo`06Ool00`00Oomoo`3oOolOOol00`00Oomoo`0aOol005Ioo`03001o
ogoo00Ioo`03001oogoo0?mooamoo`03001oogoo035oo`008goo10003Woo0`002Woo300027oo00<0
07ooOol01Woo00<007ooOol0ogoo7goo00<007ooOol0<Goo000QOol8000;Ool50009Ool<0008Ool2
0007Ool00`00Oomoo`3oOolOOol00`00Oomoo`0aOol0025oo`8000Aoo`8000]oo`D000Yoo`<000Io
o`8000Qoo`03001oogoo00Eoo`03001oogoo0?moob5oo`03001oogoo031oo`0087oo0P001Woo0P00
2Woo1@002goo0`003goo00<007ooOol01Goo00<007ooOol0ogoo8Goo00<007ooOol0<7oo000POol2
0006Ool2000;Ool3000=Ool3000>Ool00`00Oomoo`05Ool00`00Oomoo`3oOolQOol00`00Oomoo`0`
Ool001moo`8000Qoo`8001]oo`<000eoo`03001oogoo00Aoo`03001oogoo0?moob9oo`03001oogoo
031oo`007goo0P0027oo0P0077oo0`0037oo00<007ooOol017oo00<007ooOol0ogoo8Woo00<007oo
Ool0<7oo000OOol20008Ool2000MOol3000;Ool30004Ool00`00Oomoo`3oOolSOol00`00Oomoo`0_
Ool001moo`8000Qoo`8001ioo`<000Yoo`03001oogoo00=oo`03001oogoo0?moobAoo`03001oogoo
02moo`007goo0P0027oo0P007goo0`002Goo00<007ooOol00goo00<007ooOol0ogoo97oo00<007oo
Ool0;goo000OOol20008Ool2000POol20009Ool00`00Oomoo`03Ool00`00Oomoo`3oOolUOol00`00
Oomoo`0^Ool001moo`8000Qoo`80025oo`8000Qoo`03001oogoo00=oo`03001oogoo0?moobEoo`03
001oogoo02ioo`007goo0P0027oo0P008Goo0P0027oo00<007ooOol00goo00<007ooOol0ogoo9Goo
00<007ooOol0;Woo000POol20006Ool2000IOol20007Ool20008Ool20003Ool00`00Oomoo`3oOolV
Ool00`00Oomoo`0^Ool0021oo`8000Ioo`8001Uoo`<000Ioo`8000Qoo`03001oogoo009oo`03001o
ogoo0?moobIoo`03001oogoo02ioo`008Goo0P0017oo0P006Woo100017oo0P002Goo00<007ooOol0
0Woo00<007ooOol0ogoo9Woo00<007ooOol0;Woo000QOol8000KOol8000:Ool00`00Oomoo`02Ool0
0`00Oomoo`3oOolWOol00`00Oomoo`0]Ool002=oo`@001moo`D000]oo`05001oogooOol0003oOolZ
Ool00`00Oomoo`0]Ool005Ioo`05001oogooOol0003oOolZOol00`00Oomoo`0]Ool005Ioo`800003
Ool007oo0?moobYoo`03001oogoo02eoo`00EWoo00<007oo0000ogoo;7oo00<007ooOol0;Goo001F
Ool00`00Ool0003oOol/Ool00`00Oomoo`0]Ool005Ioo`800?moobeoo`03001oogoo02eoo`00EWoo
00<007ooOol0ogoo;7oo00<007ooOol0;Goo000SOol4000>Ool3000@Ool70007Ool00`00Oomoo`3o
Ool]Ool00`00Oomoo`0/Ool0025oo`P000]oo`D000moo`L000Moo`800?moobioo`03001oogoo02ao
o`008Goo0P0017oo0P002goo1@004Woo0P002Goo00<007ooOol0ogoo;Goo00<007ooOol0;7oo000P
Ool20006Ool2000:Ool5000BOol20009Ool00`00Oomoo`3oOol]Ool00`00Oomoo`0/Ool0021oo`80
00Ioo`8000]oo`<001=oo`8000Uoo`03001oogoo0?moobeoo`03001oogoo02aoo`007goo0P0027oo
0P0067oo30001goo00<007ooOol0ogoo;Goo00<007ooOol0;7oo000OOol20008Ool2000HOol<0007
Ool00`00Oomoo`3oOol]Ool00`00Oomoo`0/Ool001moo`8000Qoo`8001Qoo`8000Ioo`800003Ool0
07oo00Ioo`<00?moobeoo`03001oogoo02aoo`007goo0P0027oo0P006Goo0P001Goo0P002Goo00<0
07ooOol0ogoo;Woo00<007ooOol0:goo000OOol20008Ool2000IOol30004Ool20009Ool00`00Oomo
o`3oOol^Ool00`00Oomoo`0[Ool001moo`8000Qoo`8001Yoo`8000Aoo`8000Uoo`03001oogoo0?mo
obioo`03001oogoo02]oo`007goo0P0027oo0P006goo0P000goo0P002Goo00<007ooOol0ogoo;Woo
00<007ooOol0:goo000OOol20008Ool2000KOol30002Ool20009Ool00`00Oomoo`3oOol^Ool00`00
Oomoo`0[Ool0021oo`8000Ioo`8001eoo`80009oo`8000Uoo`03001oogoo0?moobioo`03001oogoo
02]oo`0087oo0P001Woo0P007Woo0P0000=oo`0000002Goo0P00ogoo<7oo00<007ooOol0:Woo000Q
Ool20004Ool2000POol40009Ool00`00Oomoo`3oOol_Ool00`00Oomoo`0ZOol0025oo`P0021oo`@0
00Uoo`03001oogoo0?moobmoo`03001oogoo02Yoo`008goo10008goo0`002Goo00<007ooOol0ogoo
<7oo00<007ooOol0:Goo001FOol00`00Oomoo`3oOol`Ool00`00Oomoo`0YOol005Ioo`03001oogoo
0?mooc1oo`03001oogoo02Uoo`00EWoo0P00ogoo<Goo00<007ooOol0:Goo001FOol00`00Oomoo`3o
Ool`Ool00`00Oomoo`0YOol005Ioo`03001oogoo0?mooc5oo`03001oogoo02Qoo`00EWoo00<007oo
Ool0ogoo<Goo00<007ooOol0:7oo001FOol00`00Oomoo`3oOolaOol00`00Oomoo`0XOol002=oo`@0
00ioo`<000moo`D000Yoo`03001oogoo0?mooc5oo`03001oogoo02Qoo`008Goo20002goo1@0037oo
20002Goo0P00ogoo<Woo00<007ooOol0:7oo000QOol20004Ool2000;Ool5000<Ool20004Ool30008
Ool00`00Oomoo`3oOolaOol00`00Oomoo`0XOol0021oo`8000Ioo`8000Yoo`D000]oo`8000Ioo`<0
00Moo`03001oogoo0?mooc5oo`03001oogoo02Qoo`0087oo0P001Woo0P002goo0`002goo0P0027oo
0P001goo00<007ooOol0ogoo<Woo00<007ooOol09goo000OOol20008Ool2000HOol20008Ool20007
Ool00`00Oomoo`3oOolbOol00`00Oomoo`0WOol001moo`8000Qoo`8001Qoo`8000Qoo`8000Moo`03
001oogoo0?mooc9oo`03001oogoo02Moo`007goo0P0027oo0P0067oo0P0027oo0P001goo0`00ogoo
<Woo00<007ooOol09goo000OOol20008Ool2000HOol30006Ool30007Ool00`00Oomoo`3oOolbOol0
0`00Oomoo`0WOol001moo`8000Qoo`8001Qoo`@000Aoo`<000Qoo`03001oogoo0?mooc=oo`03001o
ogoo02Ioo`007goo0P0027oo0P0067oo0P0000=oo`0000001@002Goo00<007ooOol0ogoo<goo00<0
07ooOol09Woo000OOol20008Ool2000IOol00`00Oomoo`05000:Ool00`00Oomoo`3oOoldOol00`00
Oomoo`0UOol001moo`8000Qoo`8001Uoo`80011oo`03001oogoo0?moocEoo`03001oogoo02Aoo`00
87oo0P001Woo0P006Woo0`003goo0P00ogoo=goo00<007ooOol08goo000POol20006Ool2000KOol3
000>Ool00`00Oomoo`3oOomLOol0025oo`8000Aoo`8001eoo`<000eoo`03001oogoo0?mooeaoo`00
8Goo20007Woo20001goo00<007ooOol0ogooG7oo000SOol4000ROol60007Ool00`00Oomoo`3oOomL
Ool005Ioo`03001oogoo0?mooeaoo`00EWoo0P00ogooGGoo001FOol00`00Oomoo`3oOomLOol005Io
o`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol002=o
o`@000ioo`<000ioo`H000Yoo`03001oogoo0?mooeaoo`008Goo20002goo1@0037oo20002Goo0P00
ogooGGoo000QOol20004Ool2000;Ool5000;Ool30004Ool30008Ool00`00Oomoo`3oOomLOol0021o
o`8000Ioo`8000Yoo`D000Yoo`<000Ioo`<000Moo`03001oogoo0?mooeaoo`0087oo0P001Woo0P00
2goo0`002goo0P0027oo0P001goo00<007ooOol0ogooG7oo000OOol20008Ool2000HOol20008Ool2
0007Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001Qoo`8000Qoo`8000Moo`03001oogoo0?mo
oeaoo`007goo0P0027oo0P0067oo0`001Woo0`001goo0`00ogooG7oo000OOol20008Ool2000IOol3
0004Ool30008Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001Yoo`P000Uoo`03001oogoo0?mo
oeaoo`007goo0P0027oo0P006Woo20002Goo00<007ooOol0ogooG7oo000OOol20008Ool2000IOol3
0004Ool30008Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001Qoo`8000Qoo`8000Moo`03001o
ogoo0?mooeaoo`0087oo0P001Woo0P006Goo0P0027oo0P001goo0P00ogooGGoo000POol20006Ool2
000IOol20008Ool20007Ool00`00Oomoo`3oOomLOol0025oo`8000Aoo`8001]oo`<000Aoo`@000Mo
o`03001oogoo0?mooeaoo`008Goo20006goo2P0027oo00<007ooOol0ogooG7oo000SOol4000OOol6
000:Ool00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo0P00ogooGGoo001FOol0
0`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol0
0`00Oomoo`3oOomLOol004Aoo`X000Qoo`03001oogoo0?mooeaoo`00A7oo2P0027oo0P00ogooGGoo
0018Ool2000<Ool00`00Oomoo`3oOomLOol004Qoo`8000aoo`03001oogoo0?mooeaoo`00B7oo0P00
37oo00<007ooOol0ogooG7oo0018Ool2000<Ool00`00Oomoo`3oOomLOol004Qoo`8000aoo`03001o
ogoo0?mooeaoo`00B7oo0P0037oo0`00ogooG7oo0018Ool2003oOom[Ool004Qoo`800?moof]oo`00
B7oo0P00ogooJgoo0018Ool2003oOom[Ool004Qoo`800?moof]oo`00B7oo0P00ogooJgoo0018Ool2
003oOom[Ool004Aoo`<00003Ool000000?moof]oo`00A7oo1P00ogooJgoo0017Ool3003oOom[Ool0
0?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo
]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol0
0?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo
]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol0
0?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo
]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol0
0?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo
]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol0
0?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo
]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol0
0?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo
]Goo003oOoneOol00?mookEoo`008goo10003Woo0`003Woo1P00ogooJGoo000QOol8000;Ool5000<
Ool8003oOomXOol0025oo`8000Aoo`8000]oo`D000]oo`<000Aoo`<00?moofMoo`0087oo0P001Woo
0P002Woo1@002Woo0`001Woo0`00ogooIWoo000POol20006Ool2000;Ool3000;Ool20008Ool2003o
OomVOol000aoo`d000Ioo`8000Qoo`8001Qoo`8000Qoo`800?moofIoo`0037oo3@001Woo0P0027oo
0P0067oo0P0027oo0P00ogooIWoo000<Ool=0006Ool20008Ool2000HOol30006Ool30007Ool30004
Ool00`00Oomoo`3oOomEOol001moo`8000Qoo`8001Uoo`<000Aoo`<000Qoo`03001oogoo00Aoo`03
001oogoo0?mooeEoo`007goo0P0027oo0P006Woo20002Goo00<007ooOol017oo00<007ooOol0ogoo
EGoo000OOol20008Ool2000JOol80009Ool00`00Oomoo`04Ool00`00Oomoo`3oOomEOol001moo`80
00Qoo`8001Uoo`<000Aoo`<000Qoo`03001oogoo00Aoo`03001oogoo0?mooeEoo`007goo0P0027oo
0P0067oo0P0027oo0P001goo00<007ooOol017oo00<007ooOol0ogooEGoo000POol20006Ool2000I
Ool20008Ool20007Ool20005Ool00`00Oomoo`3oOomEOol0021oo`8000Ioo`8001Uoo`8000Qoo`80
00Moo`03001oogoo00Aoo`03001oogoo0?mooeEoo`008Goo0P0017oo0P006goo0`0017oo10001goo
00<007ooOol017oo00<007ooOol0ogooEGoo000QOol8000KOol:0008Ool00`00Oomoo`04Ool00`00
Oomoo`3oOomEOol002=oo`@001moo`H000Yoo`03001oogoo00Eoo`03001oogoo0?mooeAoo`00EWoo
00<007ooOol01Goo00<007ooOol0ogooE7oo001FOol00`00Oomoo`05Ool00`00Oomoo`3oOomDOol0
05Ioo`8000Ioo`03001oogoo0?mooeAoo`00EWoo00<007ooOol01Goo00<007ooOol0ogooE7oo001F
Ool00`00Oomoo`05Ool00`00Oomoo`3oOomDOol005Ioo`03001oogoo00Eoo`03001oogoo0?mooeAo
o`00EWoo00<007ooOol01Woo00<007ooOol0ogooDgoo001FOol00`00Oomoo`06Ool00`00Oomoo`3o
OomCOol005Ioo`03001oogoo00Ioo`03001oogoo0?mooe=oo`008goo10003Woo0`003goo1@002Woo
0P001goo00<007ooOol0ogooDgoo000QOol8000;Ool5000<Ool80009Ool00`00Oomoo`06Ool00`00
Oomoo`3oOomCOol0025oo`8000Aoo`8000]oo`D000aoo`8000Aoo`<000Qoo`03001oogoo00Ioo`03
001oogoo0?mooe=oo`0087oo0P001Woo0P002Woo1@002goo0P001Woo0`001goo00<007ooOol01Woo
00<007ooOol0ogooDgoo000POol20006Ool2000;Ool3000;Ool20008Ool20007Ool00`00Oomoo`06
Ool00`00Oomoo`3oOomCOol000aoo`d000Ioo`8000Qoo`8001Qoo`8000Qoo`8000Moo`03001oogoo
00Ioo`03001oogoo0?mooe=oo`0037oo3@001Woo0P0027oo0P0067oo0P0027oo0P001goo00<007oo
Ool01goo00<007ooOol0ogooDWoo000<Ool=0006Ool20008Ool2000HOol20008Ool20007Ool30007
Ool00`00Oomoo`3oOomBOol001moo`8000Qoo`8001Qoo`<000Ioo`<000Moo`03001oogoo00Moo`03
001oogoo0?mooe9oo`007goo0P0027oo0P0067oo100017oo0`0027oo00<007ooOol01goo00<007oo
Ool0ogooDWoo000OOol20008Ool2000HOol200000goo000000050009Ool00`00Oomoo`07Ool00`00
Oomoo`3oOomBOol001moo`8000Qoo`8001Uoo`03001oogoo00D000Yoo`03001oogoo00Moo`03001o
ogoo0?mooe9oo`007goo0P0027oo0P006Goo0P0047oo00<007ooOol01goo00<007ooOol0ogooDWoo
000POol20006Ool2000JOol3000?Ool00`00Oomoo`07Ool00`00Oomoo`3oOomBOol0021oo`8000Io
o`8001]oo`<000ioo`8000Qoo`03001oogoo0?mooe9oo`008Goo0P0017oo0P007Goo0`003Goo00<0
07ooOol01goo00<007ooOol0ogooDWoo000QOol8000NOol80007Ool00`00Oomoo`07Ool00`00Oomo
o`3oOomBOol002=oo`@0029oo`H000Moo`03001oogoo00Moo`03001oogoo0?mooe9oo`00EWoo00<0
07ooOol01goo00<007ooOol0ogooDWoo001FOol00`00Oomoo`08Ool00`00Oomoo`3oOomAOol005Io
o`03001oogoo00Qoo`03001oogoo0?mooe5oo`00EWoo0P002Goo00<007ooOol0ogooDGoo001FOol0
0`00Oomoo`08Ool00`00Oomoo`3oOomAOol005Ioo`03001oogoo00Qoo`03001oogoo0?mooe5oo`00
EWoo00<007ooOol027oo00<007ooOol0ogooDGoo001FOol00`00Oomoo`08Ool00`00Oomoo`3oOomA
Ool005Ioo`03001oogoo00Qoo`03001oogoo0?mooe5oo`00EWoo00<007ooOol027oo00<007ooOol0
ogooDGoo000SOol4000>Ool3000@Ool70007Ool20009Ool00`00Oomoo`3oOomAOol0025oo`P000]o
o`D000moo`L000Moo`03001oogoo00Qoo`03001oogoo0?mooe5oo`008Goo0P0017oo0P002goo1@00
4Woo0P002Goo00<007ooOol027oo00<007ooOol0ogooDGoo000POol20006Ool2000:Ool5000BOol2
0009Ool00`00Oomoo`08Ool00`00Oomoo`3oOomAOol0021oo`8000Ioo`8000]oo`<001=oo`8000Uo
o`03001oogoo00Uoo`03001oogoo0?mooe1oo`0037oo3@001Woo0P0027oo0P0067oo30001goo00<0
07ooOol02Goo00<007ooOol0ogooD7oo000<Ool=0006Ool20008Ool2000HOol<0007Ool00`00Oomo
o`09Ool00`00Oomoo`3oOom@Ool000aoo`d000Ioo`8000Qoo`8001Qoo`8000Ioo`800003Ool007oo
00Ioo`<000Uoo`03001oogoo0?mooe1oo`007goo0P0027oo0P006Goo0P001Goo0P002Goo00<007oo
Ool02Goo00<007ooOol0ogooD7oo000OOol20008Ool2000IOol30004Ool20009Ool00`00Oomoo`09
Ool00`00Oomoo`3oOom@Ool001moo`8000Qoo`8001Yoo`8000Aoo`8000Uoo`03001oogoo00Uoo`03
001oogoo0?mooe1oo`007goo0P0027oo0P006goo0P000goo0P002Goo00<007ooOol02Goo00<007oo
Ool0ogooD7oo000OOol20008Ool2000KOol30002Ool20009Ool00`00Oomoo`09Ool00`00Oomoo`3o
Oom@Ool0021oo`8000Ioo`8001eoo`80009oo`8000Uoo`03001oogoo00Uoo`03001oogoo0?mooe1o
o`0087oo0P001Woo0P007Woo0P0000=oo`0000002Goo0P002goo00<007ooOol0ogooCgoo000QOol2
0004Ool2000POol40009Ool00`00Oomoo`0:Ool00`00Oomoo`3oOom?Ool0025oo`P0021oo`@000Uo
o`03001oogoo00Yoo`03001oogoo0?moodmoo`008goo10008goo0`002Goo00<007ooOol02Woo00<0
07ooOol0ogooCgoo001FOol00`00Oomoo`0:Ool00`00Oomoo`3oOom?Ool005Ioo`03001oogoo00]o
o`03001oogoo0?moodioo`00EWoo0P0037oo00<007ooOol0ogooCWoo001FOol00`00Oomoo`0;Ool0
0`00Oomoo`3oOom>Ool005Ioo`03001oogoo00]oo`03001oogoo0?moodioo`00EWoo00<007ooOol0
2goo00<007ooOol0ogooCWoo001FOol00`00Oomoo`0;Ool00`00Oomoo`3oOom>Ool005Ioo`03001o
ogoo00]oo`03001oogoo0?moodioo`00EWoo00<007ooOol037oo00<007ooOol0ogooCGoo000SOol4
000>Ool3000:Ool<0008Ool2000=Ool00`00Oomoo`3oOom=Ool0025oo`P000]oo`D000Uoo``000Qo
o`03001oogoo00aoo`03001oogoo0?moodeoo`008Goo0P0017oo0P002goo1@002Woo0`001Woo0P00
27oo00<007ooOol037oo00<007ooOol0ogooCGoo000POol20006Ool2000:Ool5000;Ool3000?Ool0
0`00Oomoo`0<Ool00`00Oomoo`3oOom=Ool0021oo`8000Ioo`8000]oo`<000eoo`<000ioo`03001o
ogoo00aoo`03001oogoo0?moodeoo`0037oo3@001Woo0P0027oo0P006goo0`003Goo00<007ooOol0
37oo00<007ooOol0ogooCGoo000<Ool=0006Ool20008Ool2000LOol3000<Ool00`00Oomoo`0<Ool0
0`00Oomoo`3oOom=Ool000aoo`d000Ioo`8000Qoo`8001eoo`<000]oo`<000aoo`03001oogoo0?mo
odeoo`007goo0P0027oo0P007Woo0`002Woo00<007ooOol03Goo00<007ooOol0ogooC7oo000OOol2
0008Ool2000OOol30009Ool00`00Oomoo`0=Ool00`00Oomoo`0NOol6000>Ool4000MOol:000;Ool4
000>Ool4000COol:0009Ool6000>Ool4000AOol<000;Ool4000>Ool4000BOol<0009Ool6000>Ool4
000BOol001moo`8000Qoo`80021oo`8000Uoo`03001oogoo00eoo`03001oogoo01aoo`X000Yoo`P0
01]oo`X000Uoo`P000Yoo`P0015oo`X000Moo`X000Yoo`P000moo``000Uoo`P000Yoo`P0011oo``0
00Moo`X000Yoo`P0011oo`007goo0P0027oo0P008Goo0P0027oo00<007ooOol03Goo00<007ooOol0
77oo0`001Goo0`002Goo0P0017oo0P007goo0P003Goo0P0017oo0P002Woo0P0017oo0P005Goo0P00
2goo0`001Goo0`002Goo0P0017oo0P0047oo0`001Woo0P002Goo0P0017oo0P002Woo0P0017oo0P00
4Goo0`001Woo0P001goo0`001Goo0`002Goo0P0017oo0P0047oo000OOol20008Ool2000QOol20008
Ool00`00Oomoo`0=Ool00`00Oomoo`0UOol20008Ool20006Ool2000NOol2000<Ool20006Ool20008
Ool20006Ool2000DOol2000DOol20008Ool20006Ool2000@Ool3000?Ool20006Ool20008Ool20006
Ool2000AOol3000GOol20008Ool20006Ool2000?Ool0021oo`8000Ioo`8001Uoo`8000Moo`8000Qo
o`03001oogoo00eoo`03001oogoo02Ioo`8000Moo`8000Ioo`8001ioo`8000aoo`8000Ioo`8000Qo
o`8000Ioo`8001Aoo`8001Eoo`8000Moo`8000Ioo`80015oo`<000ioo`8000Ioo`8000Qoo`8000Io
o`80019oo`<001Moo`8000Moo`8000Ioo`8000moo`0087oo0P001Woo0P006Goo0`001Woo0P0027oo
0P003Woo00<007ooOol09Woo0P001Woo0P0027oo0P007Goo0P002goo0P0027oo0P001Woo0P0027oo
0P004goo0P005Goo0P001Woo0P0027oo0P004Goo0`0037oo0P0027oo0P001Woo0P0027oo0P004Woo
0`005Woo0P001Woo0P0027oo0P003Woo000QOol20004Ool2000JOol40004Ool20009Ool00`00Oomo
o`0>Ool00`00Oomoo`0UOol20006Ool20008Ool2000MOol2000;Ool20008Ool20006Ool20008Ool2
000COol2000EOol20006Ool20008Ool2000BOol3000;Ool20008Ool20006Ool20008Ool2000COol3
000EOol20006Ool20008Ool2000>Ool0025oo`P001]oo`P000Yoo`03001oogoo00ioo`03001oogoo
02Eoo`8000Ioo`8000Qoo`8001eoo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8001=oo`8001Eoo`80
00Ioo`8000Qoo`8001=oo`<000Yoo`8000Qoo`8000Ioo`8000Qoo`8001Aoo`<001Aoo`8000Ioo`80
00Qoo`8000ioo`008goo10007goo1@002goo00<007ooOol03Woo00<007ooOol09Goo0P001Woo0P00
27oo0P007Goo0P002goo0P0027oo0P001Woo0P0027oo0P004goo0P005Goo0P001Woo0P0027oo0P00
57oo0`002Goo0P0027oo0P001Woo0P0027oo0P005Goo0`004goo0P001Woo0P0027oo0P003Woo001F
Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol20007Ool20008Ool2000MOol2000;Ool20008Ool20006
Ool20008Ool2000COol2000DOol20007Ool20008Ool2000EOol30008Ool20008Ool20006Ool20008
Ool2000FOol3000AOol20007Ool20008Ool2000>Ool005Ioo`03001oogoo00moo`03001oogoo01]o
o`8000Eoo`<000Moo`8000Qoo`8001eoo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8001=oo`8000ao
o`8000Eoo`<000Moo`8000Qoo`8001Ioo`8000Qoo`8000Qoo`8000Ioo`8000Qoo`8001Moo`8000Uo
o`8000Eoo`<000Moo`8000Qoo`8000ioo`00EWoo00<007ooOol03goo00<007ooOol06goo2@0027oo
0P0027oo0P007Goo0P002goo0P0027oo0P001Woo0P0027oo0P004goo0P0037oo2@0027oo0P0027oo
0P005goo0P001goo0P0027oo0P001Woo0P0027oo0P0067oo0P0027oo2@0027oo0P0027oo0P003Woo
001FOol2000@Ool00`00Oomoo`0KOol200000goo000000030009Ool20008Ool2000MOol2000;Ool2
0008Ool20006Ool20008Ool2000COol2000<Ool200000goo000000030009Ool20008Ool2000GOol2
0007Ool20008Ool20006Ool20008Ool2000HOol20008Ool200000goo000000030009Ool20008Ool2
000>Ool005Ioo`03001oogoo011oo`03001oogoo01Yoo`80011oo`8000Ioo`8001ioo`8000aoo`80
00Ioo`8000Qoo`8000Ioo`8001Aoo`8000aoo`80011oo`8000Ioo`8000moo`8000Moo`8000Qoo`80
00Ioo`8000Qoo`8000Ioo`80011oo`8000Moo`8000Qoo`80011oo`8000Ioo`8000moo`00EWoo00<0
07ooOol047oo00<007ooOol06Woo0P0047oo0P001Woo0P007Woo0P0037oo0P001Woo0P0027oo0P00
1Woo0P0057oo0P0037oo0P0047oo0P001Woo0P003goo0`001Woo0P0027oo0P001Woo0P0027oo0P00
1Woo0P0047oo0`001Woo0P0027oo0P0047oo0P001Woo0P003goo001FOol00`00Oomoo`0AOol00`00
Oomoo`0IOol2000AOol20004Ool2000KOol300000goo0000000=Ool20004Ool2000:Ool20004Ool2
000AOol300000goo0000000<Ool2000AOol20004Ool2000@Ool40004Ool2000:Ool20004Ool2000:
Ool20004Ool2000AOol40003Ool30009Ool2000AOol20004Ool2000@Ool005Ioo`03001oogoo015o
o`03001oogoo01Uoo`X000Uoo`P001]oo`H000eoo`P000Yoo`P0015oo`H000aoo`X000Uoo`P0015o
o`P000]oo`P000Yoo`P0019oo`P00003Ool007oo00Moo`X000Uoo`P0011oo`00EWoo00<007ooOol0
4Goo00<007ooOol06Goo2P002goo100087oo0`003goo10003Woo10005Woo0`0037oo2P002goo1000
5Goo1@003Woo10003Woo10005Woo1@000goo0P001Woo2P002goo10004Woo001FOol00`00Oomoo`0B
Ool00`00Oomoo`3oOol=Ool00`00Oomoo`06Ool00`00Oomoo`0^Ool005Ioo`8001=oo`03001oogoo
0?moo`eoo`03001oogoo00Ioo`03001oogoo02ioo`00EWoo00<007ooOol04Woo00<007ooOol0ogoo
2goo0P002Woo00<007ooOol0;Goo001FOol00`00Oomoo`0COol00`00Oomoo`3oOol9Ool00`00Oomo
o`0:Ool00`00Oomoo`0]Ool005Ioo`03001oogoo01Aoo`800?moo`Qoo`03001oogoo00aoo`03001o
ogoo02aoo`00EWoo00<007ooOol05Woo0P00ogoo1Goo00<007ooOol03Goo00<007ooOol0;7oo001F
Ool00`00Oomoo`0HOol3003oOol2000AOol2000/Ool005Ioo`03001oogoo01]oo`D00?Moo`<001Eo
o`03001oogoo02Uoo`00EWooo`00>P009Goo001FOol00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`06Ool20002Ool00`00Oomoo`0SOol005Ioo`03001o
ogoo03]oo`03001oogoo03aoo`03001oogoo03]oo`03001oogoo03]oo`03001oogoo03aoo`03001o
ogoo02=oo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo
0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol2003oOomMOol005Ioo`03001oogoo0?mooeao
o`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeao
o`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`800?mooeeoo`00EWoo
00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo
00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol002=oo`@000ioo`<000Yoo``000Qoo`80
0?mooeeoo`008Goo20002goo1@002Goo300027oo00<007ooOol0ogooG7oo000QOol20004Ool2000;
Ool5000:Ool30006Ool20008Ool00`00Oomoo`3oOomLOol0021oo`8000Ioo`8000Yoo`D000]oo`<0
00moo`03001oogoo0?mooeaoo`0087oo0P001Woo0P002goo0`003Goo0`003Woo00<007ooOol0ogoo
G7oo000OOol20008Ool2000KOol3000=Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001aoo`<0
00aoo`03001oogoo0?mooeaoo`007goo0P0027oo0P007Goo0`002goo0`00ogooG7oo000OOol20008
Ool2000NOol3000:Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001moo`<000Uoo`03001oogoo
0?mooeaoo`007goo0P0027oo0P0087oo0P002Goo00<007ooOol0ogooG7oo000OOol20008Ool2000Q
Ool20008Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`80025oo`8000Qoo`03001oogoo0?mooeao
o`0087oo0P001Woo0P006Goo0P001goo0P0027oo00<007ooOol0ogooG7oo000POol20006Ool2000I
Ool30006Ool20008Ool2003oOomMOol0025oo`8000Aoo`8001Yoo`@000Aoo`8000Uoo`03001oogoo
0?mooeaoo`008Goo20006goo20002Woo00<007ooOol0ogooG7oo000SOol4000OOol5000;Ool00`00
Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00
Oomoo`3oOomLOol005Ioo`800?mooeeoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3o
OomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3o
OomLOol005Ioo`03001oogoo0?mooeaoo`008goo10003Woo0`0047oo1`001goo0P00ogooGGoo000Q
Ool8000;Ool5000?Ool70007Ool00`00Oomoo`3oOomLOol0025oo`8000Aoo`8000]oo`D0019oo`80
00Uoo`03001oogoo0?mooeaoo`0087oo0P001Woo0P002Woo1@004Woo0P002Goo00<007ooOol0ogoo
G7oo000POol20006Ool2000;Ool3000COol20009Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`80
01Qoo``000Moo`03001oogoo0?mooeaoo`007goo0P0027oo0P0067oo30001goo00<007ooOol0ogoo
G7oo000OOol20008Ool2000HOol20006Ool200000goo001oo`06Ool3003oOomLOol001moo`8000Qo
o`8001Uoo`8000Eoo`8000Uoo`03001oogoo0?mooeaoo`007goo0P0027oo0P006Goo0`0017oo0P00
2Goo00<007ooOol0ogooG7oo000OOol20008Ool2000JOol20004Ool20009Ool00`00Oomoo`3oOomL
Ool001moo`8000Qoo`8001]oo`8000=oo`8000Uoo`03001oogoo0?mooeaoo`007goo0P0027oo0P00
6goo0`000Woo0P002Goo00<007ooOol0ogooG7oo000POol20006Ool2000MOol20002Ool20009Ool0
0`00Oomoo`3oOomLOol0021oo`8000Ioo`8001ioo`800003Ool0000000Uoo`800?mooeeoo`008Goo
0P0017oo0P0087oo10002Goo00<007ooOol0ogooG7oo000QOol8000POol40009Ool00`00Oomoo`3o
OomLOol002=oo`@002=oo`<000Uoo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001F
Ool00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo0P00ogooGGoo001FOol00`00
Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00
Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol2003o
OomMOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3o
OomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3o
OomLOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEo
o`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003o
OoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEo
o`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003o
OoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEo
o`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003o
OoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEo
o`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003o
OoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEo
o`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003o
OoneOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3o
OomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3o
OomLOol005Ioo`800?mooeeoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol0
05Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol0
05Ioo`800?mooeeoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03
001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo000SOol4000>Ool3000@Ool70007Ool00`00
Oomoo`3oOomLOol0025oo`P000]oo`D000moo`L000Moo`800?mooeeoo`008Goo0P0017oo0P002goo
1@004Woo0P002Goo00<007ooOol0ogooG7oo000POol20006Ool2000:Ool5000BOol20009Ool00`00
Oomoo`3oOomLOol0021oo`8000Ioo`8000]oo`<001=oo`8000Uoo`03001oogoo0?mooeaoo`0037oo
3@001Woo0P0027oo0P0067oo30001goo00<007ooOol0ogooG7oo000<Ool=0006Ool20008Ool2000H
Ool<0007Ool00`00Oomoo`3oOomLOol000aoo`d000Ioo`8000Qoo`8001Qoo`8000Ioo`800003Ool0
07oo00Ioo`<00?mooeaoo`007goo0P0027oo0P006Goo0P001Goo0P002Goo00<007ooOol0ogooG7oo
000OOol20008Ool2000IOol30004Ool20009Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001Yo
o`8000Aoo`8000Uoo`03001oogoo0?mooeaoo`007goo0P0027oo0P006goo0P000goo0P002Goo00<0
07ooOol0ogooG7oo000OOol20008Ool2000KOol30002Ool20009Ool00`00Oomoo`3oOomLOol0021o
o`8000Ioo`8001eoo`80009oo`8000Uoo`800?mooeeoo`0087oo0P001Woo0P007Woo0P0000=oo`00
00002Goo00<007ooOol0ogooG7oo000QOol20004Ool2000POol40009Ool00`00Oomoo`3oOomLOol0
025oo`P0021oo`@000Uoo`03001oogoo0?mooeaoo`008goo10008goo0`002Goo00<007ooOol0ogoo
G7oo001FOol00`00Oomoo`3oOomLOol005Ioo`800?mooeeoo`00EWoo00<007ooOol0ogooG7oo001F
Ool00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo000S
Ool4000>Ool3000:Ool<0008Ool00`00Oomoo`3oOomLOol0025oo`P000]oo`D000Uoo``000Qoo`80
0?mooeeoo`008Goo0P0017oo0P002goo1@002Woo0`001Woo0P0027oo00<007ooOol0ogooG7oo000P
Ool20006Ool2000:Ool5000;Ool3000?Ool00`00Oomoo`3oOomLOol0021oo`8000Ioo`8000]oo`<0
00eoo`<000ioo`03001oogoo0?mooeaoo`0037oo3@001Woo0P0027oo0P006goo0`003Goo00<007oo
Ool0ogooG7oo000<Ool=0006Ool20008Ool2000LOol3000<Ool00`00Oomoo`0^Ool6000>Ool4000M
Ool:000;Ool4000>Ool4000COol:0009Ool6000>Ool4000AOol<000;Ool4000>Ool4000BOol<0009
Ool6000>Ool4000BOol000aoo`d000Ioo`8000Qoo`8001eoo`<000]oo`<002aoo`X000Yoo`P001]o
o`X000Uoo`P000Yoo`P0015oo`X000Moo`X000Yoo`P000moo``000Uoo`P000Yoo`P0011oo``000Mo
o`X000Yoo`P0011oo`007goo0P0027oo0P007Woo0`002Woo00<007ooOol0;7oo0`001Goo0`002Goo
0P0017oo0P007goo0P003Goo0P0017oo0P002Woo0P0017oo0P005Goo0P002goo0`001Goo0`002Goo
0P0017oo0P0047oo0`001Woo0P002Goo0P0017oo0P002Woo0P0017oo0P004Goo0`001Woo0P001goo
0`001Goo0`002Goo0P0017oo0P0047oo000OOol20008Ool2000OOol30009Ool00`00Oomoo`0eOol2
0008Ool20006Ool2000NOol2000<Ool20006Ool20008Ool20006Ool2000DOol2000DOol20008Ool2
0006Ool2000@Ool3000?Ool20006Ool20008Ool20006Ool2000AOol3000GOol20008Ool20006Ool2
000?Ool001moo`8000Qoo`80021oo`8000Uoo`03001oogoo03Ioo`8000Moo`8000Ioo`8001ioo`80
00aoo`8000Ioo`8000Qoo`8000Ioo`8001Aoo`8001Eoo`8000Moo`8000Ioo`80015oo`<000ioo`80
00Ioo`8000Qoo`8000Ioo`80019oo`<001Moo`8000Moo`8000Ioo`8000moo`007goo0P0027oo0P00
8Goo0P0027oo00<007ooOol0=Woo0P001Woo0P0027oo0P007Goo0P002goo0P0027oo0P001Woo0P00
27oo0P004goo0P005Goo0P001Woo0P0027oo0P004Goo0`0037oo0P0027oo0P001Woo0P0027oo0P00
4Woo0`005Woo0P001Woo0P0027oo0P003Woo000OOol20008Ool2000QOol20008Ool00`00Oomoo`0f
Ool20006Ool20008Ool2000MOol2000;Ool20008Ool20006Ool20008Ool2000COol2000EOol20006
Ool20008Ool2000BOol3000;Ool20008Ool20006Ool20008Ool2000COol3000EOol20006Ool20008
Ool2000>Ool0021oo`8000Ioo`8001Uoo`8000Moo`8000Qoo`8003Moo`8000Ioo`8000Qoo`8001eo
o`8000]oo`8000Qoo`8000Ioo`8000Qoo`8001=oo`8001Eoo`8000Ioo`8000Qoo`8001=oo`<000Yo
o`8000Qoo`8000Ioo`8000Qoo`8001Aoo`<001Aoo`8000Ioo`8000Qoo`8000ioo`0087oo0P001Woo
0P006Goo0`001Woo0P0027oo00<007ooOol0=Woo0P001Woo0P0027oo0P007Goo0P002goo0P0027oo
0P001Woo0P0027oo0P004goo0P005Goo0P001Woo0P0027oo0P0057oo0`002Goo0P0027oo0P001Woo
0P0027oo0P005Goo0`004goo0P001Woo0P0027oo0P003Woo000QOol20004Ool2000JOol40004Ool2
0009Ool00`00Oomoo`09Ool4000XOol20007Ool20008Ool2000MOol2000;Ool20008Ool20006Ool2
0008Ool2000COol2000DOol20007Ool20008Ool2000EOol30008Ool20008Ool20006Ool20008Ool2
000FOol3000AOol20007Ool20008Ool2000>Ool0025oo`P001]oo`P000Yoo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo01eoo`8000Eoo`<000Moo`8000Qoo`8001eoo`8000]oo`8000Qoo`80
00Ioo`8000Qoo`8001=oo`8000aoo`8000Eoo`<000Moo`8000Qoo`8001Ioo`8000Qoo`8000Qoo`80
00Ioo`8000Qoo`8001Moo`8000Uoo`8000Eoo`<000Moo`8000Qoo`8000ioo`008goo10007goo1@00
2goo00<007ooOol01goo00<007ooOol00goo00<007ooOol07Goo2@0027oo0P0027oo0P007Goo0P00
2goo0P0027oo0P001Woo0P0027oo0P004goo0P0037oo2@0027oo0P0027oo0P005goo0P001goo0P00
27oo0P001Woo0P0027oo0P0067oo0P0027oo2@0027oo0P0027oo0P003Woo001FOol00`00Oomoo`07
Ool00`00Oomoo`04Ool00`00Oomoo`0LOol200000goo000000030009Ool20008Ool2000MOol2000;
Ool20008Ool20006Ool20008Ool2000COol2000<Ool200000goo000000030009Ool20008Ool2000G
Ool20007Ool20008Ool20006Ool20008Ool2000HOol20008Ool200000goo000000030009Ool20008
Ool2000>Ool005Ioo`8000Ioo`8000Qoo`03001oogoo01]oo`80011oo`8000Ioo`8001ioo`8000ao
o`8000Ioo`8000Qoo`8000Ioo`8001Aoo`8000aoo`80011oo`8000Ioo`8000moo`8000Moo`8000Qo
o`8000Ioo`8000Qoo`8000Ioo`80011oo`8000Moo`8000Qoo`80011oo`8000Ioo`8000moo`00EWoo
00<007ooOol017oo00<007ooOol02Goo00<007ooOol06Woo0P0047oo0P001Woo0P007Woo0P0037oo
0P001Woo0P0027oo0P001Woo0P0057oo0P0037oo0P0047oo0P001Woo0P003goo0`001Woo0P0027oo
0P001Woo0P0027oo0P001Woo0P0047oo0`001Woo0P0027oo0P0047oo0P001Woo0P003goo001FOol0
0`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`0JOol2000AOol20004Ool2000KOol300000goo
0000000=Ool20004Ool2000:Ool20004Ool2000AOol300000goo0000000<Ool2000AOol20004Ool2
000@Ool40004Ool2000:Ool20004Ool2000:Ool20004Ool2000AOol40004Ool20009Ool2000AOol2
0004Ool2000@Ool005Ioo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo01Uoo`X000Uoo`P0
01]oo`H000eoo`P000Yoo`P0015oo`H000aoo`X000Uoo`P0015oo`P000]oo`P000Yoo`P0019oo`P0
00Yoo`X000Uoo`P0011oo`00EWoo00<007ooOol00goo00<007ooOol037oo00<007ooOol067oo2P00
2goo100087oo0`003goo10003Woo10005Woo0`0037oo2P002goo10005Goo1@003Woo10003Woo1000
5Woo1@002goo2P002goo10004Woo001FOol00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`3o
Oom7Ool005Ioo`8000=oo`03001oogoo00ioo`03001oogoo0?moodIoo`00EWoo00<007ooOol00Woo
00<007ooOol03Woo00<007ooOol0ogooAWoo001FOol01@00Oomoogoo00004Woo0P00ogooAWoo001F
Ool01000Oomoo`005Goo00<007ooOol0ogoo@goo001FOol00`00Ool0000GOol00`00Oomoo`3oOom2
Ool005Ioo`03001oo`0001Qoo`<00?mood5oo`00EWooo`00>P009Goo001FOol00`00Oomoo`09Ool0
0`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool0
0`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool0
0`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool0
0`00Oomoo`09Ool00`00Oomoo`0;000;Ool00`00Oomoo`0:Ool00`00Oomoo`0SOol005Ioo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001o
ogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001o
ogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`8000Yoo`03001oogoo00Yoo`03001oogoo02=o
o`00EWoo00<007ooOol0ogoo7goo0`00>Woo001FOol00`00Oomoo`3oOolQOol00`00Oomoo`0hOol0
05Ioo`03001oogoo0?moob9oo`03001oogoo03Moo`00EWoo0P00ogoo8goo00<007ooOol0=goo001F
Ool00`00Oomoo`3oOolSOol00`00Oomoo`0fOol005Ioo`03001oogoo0?moob=oo`03001oogoo03Io
o`00EWoo00<007ooOol0ogoo97oo00<007ooOol0=Goo001FOol00`00Oomoo`3oOolTOol00`00Oomo
o`0eOol005Ioo`03001oogoo0?moobAoo`03001oogoo03Eoo`00EWoo0P00ogoo9Woo00<007ooOol0
=7oo001FOol00`00Oomoo`3oOolUOol00`00Oomoo`0dOol005Ioo`03001oogoo0?moobIoo`03001o
ogoo03=oo`00EWoo00<007ooOol0ogoo9Woo00<007ooOol0<goo001FOol00`00Oomoo`3oOolVOol0
0`00Oomoo`0cOol005Ioo`03001oogoo0?moobIoo`03001oogoo03=oo`008goo10003Woo0`002Woo
300027oo00<007ooOol0ogoo9goo00<007ooOol0<Woo000QOol8000;Ool50009Ool<0008Ool2003o
OolXOol00`00Oomoo`0bOol0025oo`8000Aoo`8000]oo`D000Yoo`<000Ioo`8000Qoo`03001oogoo
0?moobMoo`03001oogoo039oo`0087oo0P001Woo0P002Woo1@002goo0`003goo00<007ooOol0ogoo
9goo00<007ooOol0<Woo000POol20006Ool2000;Ool3000=Ool3000>Ool00`00Oomoo`3oOolWOol0
0`00Oomoo`0bOol001moo`8000Qoo`8001]oo`<000eoo`03001oogoo0?moobMoo`03001oogoo039o
o`007goo0P0027oo0P0077oo0`0037oo00<007ooOol0ogoo:7oo00<007ooOol0<Goo000OOol20008
Ool2000MOol3000;Ool3003oOolXOol00`00Oomoo`0aOol001moo`8000Qoo`8001ioo`<000Yoo`03
001oogoo0?moobQoo`03001oogoo035oo`007goo0P0027oo0P007goo0`002Goo00<007ooOol0ogoo
:7oo00<007ooOol0<Goo000OOol20008Ool2000POol20009Ool00`00Oomoo`3oOolXOol00`00Oomo
o`0aOol001moo`8000Qoo`80025oo`8000Qoo`03001oogoo0?moobQoo`03001oogoo035oo`007goo
0P0027oo0P008Goo0P0027oo00<007ooOol0ogoo:7oo00<007ooOol0<Goo000POol20006Ool2000I
Ool20007Ool20008Ool2003oOolYOol00`00Oomoo`0aOol0021oo`8000Ioo`8001Uoo`<000Ioo`80
00Qoo`03001oogoo0?moobUoo`03001oogoo031oo`008Goo0P0017oo0P006Woo100017oo0P002Goo
00<007ooOol0ogoo:Goo00<007ooOol0<7oo000QOol8000KOol8000:Ool00`00Oomoo`3oOolYOol0
0`00Oomoo`0`Ool002=oo`@001moo`D000]oo`03001oogoo0?moobUoo`03001oogoo031oo`00EWoo
00<007ooOol0ogoo:Goo00<007ooOol0<7oo001FOol2003oOolZOol00`00Oomoo`0`Ool005Ioo`03
001oogoo0?moobYoo`03001oogoo02moo`00EWoo00<007ooOol0ogoo:Woo00<007ooOol0;goo001F
Ool00`00Oomoo`3oOolZOol00`00Oomoo`0_Ool005Ioo`03001oogoo0?moobYoo`03001oogoo02mo
o`008goo10003Woo0`0047oo1`001goo00<007ooOol0ogoo:Woo00<007ooOol0;goo000QOol8000;
Ool5000?Ool70007Ool2003oOol/Ool00`00Oomoo`0^Ool0025oo`8000Aoo`8000]oo`D0019oo`80
00Uoo`03001oogoo0?moob]oo`03001oogoo02ioo`0087oo0P001Woo0P002Woo1@004Woo0P002Goo
00<007ooOol0ogoo:goo00<007ooOol0;Woo000POol20006Ool2000;Ool3000COol20009Ool00`00
Oomoo`3oOol[Ool00`00Oomoo`0^Ool001moo`8000Qoo`8001Qoo``000Moo`03001oogoo0?moob]o
o`03001oogoo02ioo`007goo0P0027oo0P0067oo30001goo00<007ooOol0ogoo:goo00<007ooOol0
;Woo000OOol20008Ool2000HOol20006Ool200000goo001oo`06Ool3003oOol[Ool00`00Oomoo`0^
Ool001moo`8000Qoo`8001Uoo`8000Eoo`8000Uoo`03001oogoo0?moob]oo`03001oogoo02ioo`00
7goo0P0027oo0P006Goo0`0017oo0P002Goo00<007ooOol0ogoo;7oo00<007ooOol0;Goo000OOol2
0008Ool2000JOol20004Ool20009Ool00`00Oomoo`3oOol/Ool00`00Oomoo`0]Ool001moo`8000Qo
o`8001]oo`8000=oo`8000Uoo`03001oogoo0?moobaoo`03001oogoo02eoo`007goo0P0027oo0P00
6goo0`000Woo0P002Goo00<007ooOol0ogoo;7oo00<007ooOol0;Goo000POol20006Ool2000MOol2
0002Ool20009Ool2003oOol]Ool00`00Oomoo`0]Ool0021oo`8000Ioo`8001ioo`800003Ool00000
00Uoo`03001oogoo0?moobaoo`03001oogoo02eoo`008Goo0P0017oo0P0087oo10002Goo00<007oo
Ool0ogoo;7oo00<007ooOol0;Goo000QOol8000POol40009Ool00`00Oomoo`3oOol/Ool00`00Oomo
o`0]Ool002=oo`@002=oo`<000Uoo`03001oogoo0?moobaoo`03001oogoo02eoo`00EWoo00<007oo
Ool0ogoo;7oo00<007ooOol0;Goo001FOol2003oOol]Ool00`00Oomoo`0]Ool005Ioo`03001oogoo
0?moobeoo`03001oogoo02aoo`00EWoo00<007ooOol0ogoo;Goo00<007ooOol0;7oo001FOol00`00
Oomoo`3oOol]Ool00`00Oomoo`0/Ool005Ioo`03001oogoo0?moobeoo`03001oogoo02aoo`008goo
10003Woo0`003goo1@002Woo00<007ooOol0ogoo;Goo00<007ooOol0;7oo000QOol8000;Ool5000<
Ool80009Ool2003oOol^Ool00`00Oomoo`0/Ool0025oo`8000Aoo`8000]oo`D000aoo`8000Aoo`<0
00Qoo`03001oogoo0?moobeoo`03001oogoo02aoo`0087oo0P001Woo0P002Woo1@002goo0P001Woo
0`001goo00<007ooOol0ogoo;Goo00<007ooOol0;7oo000POol20006Ool2000;Ool3000;Ool20008
Ool20007Ool00`00Oomoo`3oOol]Ool00`00Oomoo`0/Ool001moo`8000Qoo`8001Qoo`8000Qoo`80
00Moo`03001oogoo0?moobeoo`03001oogoo02aoo`007goo0P0027oo0P0067oo0P0027oo0P001goo
00<007ooOol0ogoo;Goo00<007ooOol0;7oo000OOol20008Ool2000HOol20008Ool20007Ool3003o
Ool^Ool00`00Oomoo`0[Ool001moo`8000Qoo`8001Qoo`<000Ioo`<000Moo`03001oogoo0?moobio
o`03001oogoo02]oo`007goo0P0027oo0P0067oo100017oo0`0027oo00<007ooOol0ogoo;Woo00<0
07ooOol0:goo000OOol20008Ool2000HOol200000goo000000050009Ool00`00Oomoo`3oOol^Ool0
0`00Oomoo`0[Ool001moo`8000Qoo`8001Uoo`03001oogoo00D000Yoo`03001oogoo0?moobioo`03
001oogoo02]oo`007goo0P0027oo0P006Goo0P0047oo00<007ooOol0ogoo;Woo00<007ooOol0:goo
000POol20006Ool2000JOol3000?Ool2003oOol_Ool00`00Oomoo`0[Ool0021oo`8000Ioo`8001]o
o`<000ioo`03001oogoo0?moobioo`03001oogoo02]oo`008Goo0P0017oo0P007Goo0`003Goo00<0
07ooOol0ogoo;Woo00<007ooOol0:goo000QOol8000NOol80007Ool00`00Oomoo`3oOol_Ool00`00
Oomoo`0ZOol002=oo`@0029oo`H000Moo`03001oogoo0?moobmoo`03001oogoo02Yoo`00EWoo00<0
07ooOol0ogoo;goo00<007ooOol0:Woo001FOol2003oOol`Ool00`00Oomoo`0ZOol005Ioo`03001o
ogoo0?moobmoo`03001oogoo02Yoo`00EWoo00<007ooOol0ogoo<7oo00<007ooOol0:Goo001FOol0
0`00Oomoo`3oOol`Ool00`00Oomoo`0YOol005Ioo`03001oogoo0?mooc1oo`03001oogoo02Uoo`00
8goo10003Woo0`003Woo1P002Woo00<007ooOol0ogoo<7oo00<007ooOol0:Goo000QOol8000;Ool5
000<Ool80009Ool2003oOolaOol00`00Oomoo`0YOol0025oo`8000Aoo`8000]oo`D000]oo`<000Ao
o`<000Qoo`03001oogoo0?mooc1oo`03001oogoo02Uoo`0087oo0P001Woo0P002Woo1@002Woo0`00
1Woo0`001goo00<007ooOol0ogoo<7oo00<007ooOol0:Goo000POol20006Ool2000;Ool3000;Ool2
0008Ool20007Ool00`00Oomoo`3oOol`Ool00`00Oomoo`0YOol001moo`8000Qoo`8001Qoo`8000Qo
o`8000Moo`03001oogoo0?mooc5oo`03001oogoo02Qoo`007goo0P0027oo0P0067oo0P0027oo0P00
1goo00<007ooOol0ogoo<Goo00<007ooOol0:7oo000OOol20008Ool2000HOol30006Ool30007Ool3
003oOolaOol00`00Oomoo`0XOol001moo`8000Qoo`8001Uoo`<000Aoo`<000Qoo`03001oogoo0?mo
oc5oo`03001oogoo02Qoo`007goo0P0027oo0P006Woo20002Goo00<007ooOol0ogoo<Goo00<007oo
Ool0:7oo000OOol20008Ool2000JOol80009Ool00`00Oomoo`3oOolaOol00`00Oomoo`0XOol001mo
o`8000Qoo`8001Uoo`<000Aoo`<000Qoo`03001oogoo0?mooc5oo`03001oogoo02Qoo`007goo0P00
27oo0P0067oo0P0027oo0P001goo00<007ooOol0ogoo<Goo00<007ooOol0:7oo000POol20006Ool2
000IOol20008Ool20007Ool2003oOolbOol00`00Oomoo`0XOol0021oo`8000Ioo`8001Uoo`8000Qo
o`8000Moo`03001oogoo0?mooc9oo`03001oogoo02Moo`008Goo0P0017oo0P006goo0`0017oo1000
1goo00<007ooOol0ogoo<Woo00<007ooOol09goo000QOol8000KOol:0008Ool00`00Oomoo`3oOolb
Ool00`00Oomoo`0WOol002=oo`@001moo`H000Yoo`03001oogoo0?mooc9oo`03001oogoo02Moo`00
EWoo00<007ooOol0ogoo<Woo00<007ooOol09goo001FOol2003oOolcOol00`00Oomoo`0WOol005Io
o`03001oogoo0?mooc9oo`03001oogoo02Moo`00EWoo00<007ooOol0ogoo<goo00<007ooOol09Woo
001FOol00`00Oomoo`3oOolcOol00`00Oomoo`0VOol005Ioo`03001oogoo0?mooc=oo`03001oogoo
02Ioo`00A7oo2P0027oo00<007ooOol0ogoo<goo00<007ooOol09Woo0014Ool:0008Ool2003oOole
Ool00`00Oomoo`0UOol004Qoo`8000aoo`03001oogoo0?moocAoo`03001oogoo02Eoo`00B7oo0P00
37oo00<007ooOol0ogoo=Goo00<007ooOol097oo0018Ool2000<Ool00`00Oomoo`3oOoleOol00`00
Oomoo`0TOol004Qoo`8000aoo`03001oogoo0?moocIoo`03001oogoo02=oo`00B7oo0P0037oo00<0
07ooOol0ogooG7oo0018Ool2000<Ool3003oOomLOol004Qoo`800?moof]oo`00B7oo0P00ogooJgoo
0018Ool2003oOom[Ool004Qoo`800?moof]oo`00B7oo0P00ogooJgoo0018Ool2003oOom[Ool004Qo
o`800?moof]oo`00A7oo0`0000=oo`000000ogooJgoo0014Ool6003oOom[Ool004Moo`<00?moof]o
o`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003o
OoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEo
o`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003o
OoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEo
o`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003o
OoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEo
o`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo0000\
\>"], "Graphics",
  CellLabel->"From In[83]:=",
  Evaluatable->False,
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Now the reflected pulses have changed direction, the amplitude of the \
pulses on the second wire is reduced to (",
  Cell[BoxData[
      \(TraditionalForm\`Z\_x\)]],
  "\[NonBreakingSpace]-\[NonBreakingSpace]",
  Cell[BoxData[
      \(TraditionalForm\`Z\_0\)]],
  ")\[NonBreakingSpace]/\[NonBreakingSpace](",
  Cell[BoxData[
      \(TraditionalForm\`Z\_x\)]],
  " +\[NonBreakingSpace]",
  Cell[BoxData[
      \(TraditionalForm\`Z\_0\)]],
  ") of the original. "
}], "Text",
  PageBreakAbove->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006d0003Ga000`40O003h00Oogoo]Goo003oOone
Ool00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00
ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOone
Ool00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00
ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOone
Ool00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00
ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo001FOol0
0`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol0
0`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol2
003oOomMOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomo
o`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol2003oOomM
Ool005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomL
Ool005Ioo`03001oogoo0?mooeaoo`008goo10003Woo0`0047oo1`001goo00<007ooOol0ogooG7oo
000QOol8000;Ool5000?Ool70007Ool2003oOomMOol0025oo`8000Aoo`8000]oo`D0019oo`8000Uo
o`03001oogoo0?mooeaoo`0087oo0P001Woo0P002Woo1@004Woo0P002Goo00<007ooOol0ogooG7oo
000POol20006Ool2000;Ool3000COol20009Ool00`00Oomoo`3oOomLOol000aoo`d000Ioo`8000Qo
o`8001Qoo``000Moo`03001oogoo0?mooeaoo`0037oo3@001Woo0P0027oo0P0067oo30001goo00<0
07ooOol0ogooG7oo000<Ool=0006Ool20008Ool2000HOol20006Ool200000goo001oo`06Ool3003o
OomLOol001moo`8000Qoo`8001Uoo`8000Eoo`8000Uoo`03001oogoo0?mooeaoo`007goo0P0027oo
0P006Goo0`0017oo0P002Goo00<007ooOol0ogooG7oo000OOol20008Ool2000JOol20004Ool20009
Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001]oo`8000=oo`8000Uoo`03001oogoo0?mooeao
o`007goo0P0027oo0P006goo0`000Woo0P002Goo00<007ooOol0ogooG7oo000POol20006Ool2000M
Ool20002Ool20009Ool2003oOomMOol0021oo`8000Ioo`8001ioo`800003Ool0000000Uoo`03001o
ogoo0?mooeaoo`008Goo0P0017oo0P0087oo10002Goo00<007ooOol0ogooG7oo000QOol8000POol4
0009Ool00`00Oomoo`3oOomLOol002=oo`@002=oo`<000Uoo`03001oogoo0?mooeaoo`00EWoo00<0
07ooOol0ogooG7oo001FOol2003oOomMOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0
ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`008goo10003Woo0`00
2Woo300027oo00<007ooOol0ogooG7oo000QOol8000;Ool50009Ool<0008Ool2003oOomMOol0025o
o`8000Aoo`8000]oo`D000Yoo`<000Ioo`8000Qoo`03001oogoo0?mooeaoo`0087oo0P001Woo0P00
2Woo1@002goo0`003goo00<007ooOol0ogooG7oo000POol20006Ool2000;Ool3000=Ool3000>Ool0
0`00Oomoo`3oOomLOol000aoo`d000Ioo`8000Qoo`8001]oo`<000eoo`03001oogoo02ioo`H000io
o`@001eoo`X000]oo`@000ioo`@001=oo`X000Uoo`H000ioo`@0015oo``000]oo`@000ioo`@0019o
o``000Uoo`H000ioo`@0019oo`0037oo3@001Woo0P0027oo0P0077oo0`0037oo00<007ooOol0;7oo
2P002Woo20006goo2P002Goo20002Woo20004Goo2P001goo2P002Woo20003goo30002Goo20002Woo
200047oo30001goo2P002Woo200047oo000<Ool=0006Ool20008Ool2000MOol3000;Ool3000/Ool3
0005Ool30009Ool20004Ool2000OOol2000=Ool20004Ool2000:Ool20004Ool2000EOol2000;Ool3
0005Ool30009Ool20004Ool2000@Ool30006Ool20009Ool20004Ool2000:Ool20004Ool2000AOol3
0006Ool20007Ool30005Ool30009Ool20004Ool2000@Ool001moo`8000Qoo`8001ioo`<000Yoo`03
001oogoo03Eoo`8000Qoo`8000Ioo`8001ioo`8000aoo`8000Ioo`8000Qoo`8000Ioo`8001Aoo`80
01Aoo`8000Qoo`8000Ioo`80011oo`<000moo`8000Ioo`8000Qoo`8000Ioo`80015oo`<001Moo`80
00Qoo`8000Ioo`8000moo`007goo0P0027oo0P007goo0`002Goo00<007ooOol0=Woo0P001goo0P00
1Woo0P007Woo0P0037oo0P001Woo0P0027oo0P001Woo0P0057oo0P005Goo0P001goo0P001Woo0P00
4Goo0`003Woo0P001Woo0P0027oo0P001Woo0P004Woo0`005goo0P001goo0P001Woo0P003goo000O
Ool20008Ool2000POol20009Ool00`00Oomoo`0fOol20006Ool20008Ool2000MOol2000;Ool20008
Ool20006Ool20008Ool2000COol2000EOol20006Ool20008Ool2000AOol3000<Ool20008Ool20006
Ool20008Ool2000BOol3000FOol20006Ool20008Ool2000>Ool001moo`8000Qoo`80025oo`8000Qo
o`03001oogoo03Ioo`8000Ioo`8000Qoo`8001eoo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8001=o
o`8001Eoo`8000Ioo`8000Qoo`80019oo`<000]oo`8000Qoo`8000Ioo`8000Qoo`8001=oo`<001Eo
o`8000Ioo`8000Qoo`8000ioo`007goo0P0027oo0P008Goo0P0027oo00<007ooOol0=Woo0P001Woo
0P0027oo0P001Woo10004goo0P002goo0P0027oo0P001Woo0P0027oo0P004goo0P005Goo0P001Woo
0P0027oo0P004goo0`002Woo0P0027oo0P001Woo0P0027oo0P0057oo0`0057oo0P001Woo0P0027oo
0P003Woo000POol20006Ool2000IOol20007Ool20008Ool2000gOol20006Ool20008Ool20005Ool0
0`00Oomoo`02Ool00`00Oomoo`0@Ool2000;Ool20008Ool20006Ool20008Ool2000COol2000EOol2
0006Ool20008Ool2000DOol30009Ool20008Ool20006Ool20008Ool2000EOol3000COol20006Ool2
0008Ool2000>Ool0021oo`8000Ioo`8001Uoo`<000Ioo`8000Qoo`03001oogoo03Eoo`8000Moo`80
00Qoo`8000Aoo`03001oogoo00Aoo`80011oo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8001=oo`80
01Aoo`8000Moo`8000Qoo`8001Eoo`<000Qoo`8000Qoo`8000Ioo`8000Qoo`8001Ioo`<0015oo`80
00Moo`8000Qoo`8000ioo`008Goo0P0017oo0P006Woo100017oo0P002Goo00<007ooOol0;Goo0P00
1Goo0`001goo0P0027oo0P000goo00<007ooOol01goo00<007ooOol03Goo0P002goo0P0027oo0P00
1Woo0P0027oo0P004goo0P0037oo0P001Goo0`001goo0P0027oo0P005Woo0P0027oo0P0027oo0P00
1Woo0P0027oo0P005goo0P002Goo0P001Goo0`001goo0P0027oo0P003Woo000QOol8000KOol8000:
Ool00`00Oomoo`0]Ool90008Ool20008Ool20002Ool00`00Oomoo`09Ool00`00Oomoo`0<Ool2000;
Ool20008Ool20006Ool20008Ool2000COol2000<Ool90008Ool20008Ool2000GOol20007Ool20008
Ool20006Ool20008Ool2000HOol20008Ool90008Ool20008Ool2000>Ool002=oo`@001moo`D000]o
o`03001oogoo02eoo`800003Ool0000000<000Uoo`8000Qoo`800003Ool007oo00aoo`03001oogoo
00]oo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8001=oo`8000aoo`800003Ool0000000<000Uoo`80
00Qoo`8001Moo`8000Moo`8000Qoo`8000Ioo`8000Qoo`8001Qoo`8000Qoo`800003Ool0000000<0
00Uoo`8000Qoo`8000ioo`00EWoo00<007ooOol0;Goo0P0047oo0P001Woo0P000Woo00<007ooOol0
2goo00<007ooOol02goo0P0037oo0P001Woo0P0027oo0P001Woo0P0057oo0P0037oo0P0047oo0P00
1Woo0P003goo0P001goo0P0027oo0P001Woo0P0027oo0P001Woo0P0047oo0P001goo0P0027oo0P00
47oo0P001Woo0P003goo001FOol2000^Ool2000@Ool20006Ool200000goo001oo`0>Ool2000;Ool2
000<Ool20006Ool20008Ool20006Ool2000DOol2000<Ool2000@Ool20006Ool2000?Ool30006Ool2
0008Ool20006Ool20008Ool20006Ool2000@Ool30006Ool20008Ool2000@Ool20006Ool2000?Ool0
05Ioo`03001oogoo02eoo`80015oo`8000Aoo`80009oo`03001oogoo00moo`03001oogoo00Aoo`<0
0003Ool0000000eoo`8000Aoo`8000Yoo`8000Aoo`80015oo`<00003Ool0000000aoo`80015oo`80
00Aoo`80011oo`@000Aoo`8000Yoo`8000Aoo`8000Yoo`8000Aoo`80015oo`@000Aoo`8000Uoo`80
015oo`8000Aoo`80011oo`00EWoo00<007ooOol0;Goo2P002Goo200000=oo`00Ool04Goo00<007oo
Ool017oo1P003Goo20002Woo20004Goo1P0037oo2P002Goo20004Goo20002goo20002Woo20004Woo
20002Woo2P002Goo200047oo001FOol00`00Oomoo`0]Ool:000;Ool40003Ool00`00Oomoo`0AOol0
0`00Oomoo`06Ool3000?Ool4000>Ool4000FOol3000<Ool:000;Ool4000EOol5000>Ool4000>Ool4
000FOol5000;Ool:000;Ool4000BOol005Ioo`03001oogoo04Qoo`03001oogoo01=oo`03001oogoo
0?Yoo`00EWoo00<007ooOol0B7oo00<007ooOol04goo00<007ooOol0nWoo001FOol20018Ool00`00
Oomoo`0EOol2003jOol005Ioo`03001oogoo04Ioo`03001oogoo01Qoo`03001oogoo0?Moo`00EWoo
00<007ooOol0AGoo00<007ooOol06Woo00<007ooOol0mWoo001FOol00`00Oomoo`15Ool00`00Oomo
o`0KOol3003eOol005Ioo`03001oogoo04Aoo`03001oogoo01moo`800?=oo`00EWoo00<007ooOol0
@Woo0P0097oo1000RGoo1000HWoo001FOooo000j000UOol005Ioo`03001oogoo00Uoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Qoo`L000Moo`03001oogoo00Uoo`03
001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`P000Eoo`03001oogoo
00Uoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo02=oo`00EWoo00<0
07ooOol0>goo00<007ooOol0?7oo00<007ooOol0>goo00<007ooOol04Goo0P008Woo00<007ooOol0
0goo00<007ooOol0?7oo00<007ooOol08goo001FOol00`00Oomoo`3>Ool3000OOol00`00Oomoo`1X
Ool005Ioo`03001oogoo0=5oo`03001oogoo01]oo`03001oogoo06Uoo`00EWoo00<007ooOol0dWoo
00<007ooOol06Woo00<007ooOol0JGoo001FOol2003DOol2000IOol00`00Oomoo`1ZOol005Ioo`03
001oogoo0=Eoo`03001oogoo01Eoo`03001oogoo06]oo`00EWoo00<007ooOol0eWoo00<007ooOol0
4goo00<007ooOol0K7oo001FOol00`00Oomoo`3FOol00`00Oomoo`0COol00`00Oomoo`1/Ool005Io
o`03001oogoo0=Moo`03001oogoo015oo`03001oogoo06eoo`00EWoo00<007ooOol0f7oo00<007oo
Ool047oo00<007ooOol0KGoo001FOol2003JOol00`00Oomoo`0>Ool00`00Oomoo`1^Ool005Ioo`03
001oogoo0=Yoo`03001oogoo00eoo`03001oogoo06ioo`00EWoo00<007ooOol0fgoo00<007ooOol0
2goo00<007ooOol0Kgoo001FOol00`00Oomoo`3KOol00`00Oomoo`0:Ool00`00Oomoo`1`Ool005Io
o`03001oogoo0=aoo`03001oogoo00Qoo`03001oogoo075oo`008goo10003Woo0`002Woo300027oo
00<007ooOol0gGoo0P0027oo00<007ooOol0LGoo000QOol8000;Ool50009Ool<0008Ool2003POol0
0`00Oomoo`04Ool00`00Oomoo`1bOol0025oo`8000Aoo`8000]oo`D000Yoo`<000Ioo`8000Qoo`03
001oogoo0>1oo`800004Ool00000001eOol0021oo`8000Ioo`8000Yoo`D000]oo`<000moo`03001o
ogoo0>9oo`03001oogoo07Ioo`0087oo0P001Woo0P002goo0`003Goo0`003Woo00<007ooOol0ogoo
G7oo000OOol20008Ool2000KOol3000=Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001aoo`<0
00aoo`03001oogoo0?mooeaoo`007goo0P0027oo0P007Goo0`002goo0`00ogooG7oo000OOol20008
Ool2000NOol3000:Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001moo`<000Uoo`03001oogoo
0?mooeaoo`007goo0P0027oo0P0087oo0P002Goo00<007ooOol0ogooG7oo000OOol20008Ool2000Q
Ool20008Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`80025oo`8000Qoo`03001oogoo0?mooeao
o`0087oo0P001Woo0P006Goo0P001goo0P0027oo0P00ogooGGoo000POol20006Ool2000IOol30006
Ool20008Ool00`00Oomoo`3oOomLOol0025oo`8000Aoo`8001Yoo`@000Aoo`8000Uoo`03001oogoo
0?mooeaoo`008Goo20006goo20002Woo00<007ooOol0ogooG7oo000SOol4000OOol5000;Ool00`00
Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo0P00ogooGGoo001FOol00`00Oomoo`3o
OomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3o
OomLOol002=oo`@000ioo`<0011oo`L000Moo`03001oogoo0?mooeaoo`008Goo20002goo1@003goo
1`001goo0P00ogooGGoo000QOol20004Ool2000;Ool5000BOol20009Ool00`00Oomoo`3oOomLOol0
021oo`8000Ioo`8000Yoo`D0019oo`8000Uoo`03001oogoo0?mooeaoo`0087oo0P001Woo0P002goo
0`004goo0P002Goo00<007ooOol0ogooG7oo000OOol20008Ool2000HOol<0007Ool00`00Oomoo`3o
OomLOol001moo`8000Qoo`8001Qoo``000Moo`03001oogoo0?mooeaoo`007goo0P0027oo0P0067oo
0P001Woo0P0000=oo`00Ool01Woo0`00ogooG7oo000OOol20008Ool2000IOol20005Ool20009Ool0
0`00Oomoo`3oOomLOol001moo`8000Qoo`8001Uoo`<000Aoo`8000Uoo`03001oogoo0?mooeaoo`00
7goo0P0027oo0P006Woo0P0017oo0P002Goo00<007ooOol0ogooG7oo000OOol20008Ool2000KOol2
0003Ool20009Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001]oo`<0009oo`8000Uoo`03001o
ogoo0?mooeaoo`0087oo0P001Woo0P007Goo0P000Woo0P002Goo00<007ooOol0ogooG7oo000POol2
0006Ool2000NOol200000goo00000009Ool2003oOomMOol0025oo`8000Aoo`80021oo`@000Uoo`03
001oogoo0?mooeaoo`008Goo200087oo10002Goo00<007ooOol0ogooG7oo000SOol4000SOol30009
Ool00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001F
Ool2003oOomMOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00
Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`008goo10003Woo0`003goo1@002Woo00<007oo
Ool0ogooG7oo000QOol8000;Ool5000<Ool80009Ool2003oOomMOol0025oo`8000Aoo`8000]oo`D0
00aoo`8000Aoo`<000Qoo`03001oogoo0?mooeaoo`0087oo0P001Woo0P002Woo1@002goo0P001Woo
0`001goo00<007ooOol0ogooG7oo000POol20006Ool2000;Ool3000;Ool20008Ool20007Ool00`00
Oomoo`3oOomLOol001moo`8000Qoo`8001Qoo`8000Qoo`8000Moo`03001oogoo0?mooeaoo`007goo
0P0027oo0P0067oo0P0027oo0P001goo00<007ooOol0ogooG7oo000OOol20008Ool2000HOol20008
Ool20007Ool3003oOomLOol001moo`8000Qoo`8001Qoo`<000Ioo`<000Moo`03001oogoo0?mooeao
o`007goo0P0027oo0P0067oo100017oo0`0027oo00<007ooOol0ogooG7oo000OOol20008Ool2000H
Ool200000goo000000050009Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001Uoo`03001oogoo
00D000Yoo`03001oogoo0?mooeaoo`007goo0P0027oo0P006Goo0P0047oo00<007ooOol0ogooG7oo
000POol20006Ool2000JOol3000?Ool2003oOomMOol0021oo`8000Ioo`8001]oo`<000ioo`03001o
ogoo0?mooeaoo`008Goo0P0017oo0P007Goo0`003Goo00<007ooOol0ogooG7oo000QOol8000NOol8
0007Ool00`00Oomoo`3oOomLOol002=oo`@0029oo`H000Moo`03001oogoo0?mooeaoo`00EWoo00<0
07ooOol0ogooG7oo001FOol2003oOomMOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0
ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`008goo10003Woo0`00
3Woo1P002Woo00<007ooOol0ogooG7oo000QOol8000;Ool5000<Ool80009Ool2003oOomMOol0025o
o`8000Aoo`8000]oo`D000]oo`<000Aoo`<000Qoo`03001oogoo0?mooeaoo`0087oo0P001Woo0P00
2Woo1@002Woo0`001Woo0`001goo00<007ooOol0ogooG7oo000POol20006Ool2000;Ool3000;Ool2
0008Ool20007Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001Qoo`8000Qoo`8000Moo`03001o
ogoo0?mooeaoo`007goo0P0027oo0P0067oo0P0027oo0P001goo00<007ooOol0ogooG7oo000OOol2
0008Ool2000HOol30006Ool30007Ool3003oOomLOol001moo`8000Qoo`8001Uoo`<000Aoo`<000Qo
o`03001oogoo0?mooeaoo`007goo0P0027oo0P006Woo20002Goo00<007ooOol0ogooG7oo000OOol2
0008Ool2000JOol80009Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001Uoo`<000Aoo`<000Qo
o`03001oogoo0?mooeaoo`007goo0P0027oo0P0067oo0P0027oo0P001goo00<007ooOol0ogooG7oo
000POol20006Ool2000IOol20008Ool20007Ool2003oOomMOol0021oo`8000Ioo`8001Uoo`8000Qo
o`8000Moo`03001oogoo0?mooeaoo`008Goo0P0017oo0P006goo0`0017oo10001goo00<007ooOol0
ogooG7oo000QOol8000KOol:0008Ool00`00Oomoo`3oOomLOol002=oo`@001moo`H000Yoo`03001o
ogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol2003oOomMOol005Ioo`03001oogoo0?mo
oeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mo
oeaoo`00A7oo2P0027oo00<007ooOol0ogooG7oo0014Ool:0008Ool2003oOomMOol004Qoo`8000ao
o`03001oogoo0?mooeaoo`00B7oo0P0037oo00<007ooOol0ogooG7oo0018Ool2000<Ool00`00Oomo
o`3oOomLOol004Qoo`8000aoo`03001oogoo0?mooeaoo`00B7oo0P0037oo00<007ooOol0ogooG7oo
0018Ool2000<Ool3003oOomLOol004Qoo`800?moof]oo`00B7oo0P00ogooJgoo0018Ool2003oOom[
Ool004Qoo`800?moof]oo`00B7oo0P00ogooJgoo0018Ool2003oOom[Ool004Qoo`800?moof]oo`00
A7oo0`0000=oo`000000ogooJgoo0014Ool6003oOom[Ool004Moo`<00?moof]oo`00ogoo]Goo003o
OoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEo
o`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003o
OoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEo
o`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003o
OoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEo
o`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003o
OoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEo
o`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003o
OoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEo
o`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003o
OoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEo
o`00ogoo]Goo000SOol4000>Ool3000>Ool6003oOomYOol0025oo`P000]oo`D000aoo`P00?moofQo
o`008Goo0P0017oo0P002goo1@002goo0`0017oo0`00ogooIgoo000POol20006Ool2000:Ool5000:
Ool30006Ool3003oOomVOol0021oo`8000Ioo`8000]oo`<000]oo`8000Qoo`800?moofIoo`0037oo
3@001Woo0P0027oo0P0067oo0P0027oo0P00ogooIWoo000<Ool=0006Ool20008Ool2000HOol20008
Ool2003oOomVOol000aoo`d000Ioo`8000Qoo`8001Qoo`<000Ioo`<000Moo`<00?mooeaoo`007goo
0P0027oo0P006Goo0`0017oo0`0027oo00<007ooOol0ogooG7oo000OOol20008Ool2000JOol80009
Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001Yoo`P000Uoo`03001oogoo0?mooeaoo`007goo
0P0027oo0P006Goo0`0017oo0`0027oo00<007ooOol0ogooG7oo000OOol20008Ool2000HOol20008
Ool20007Ool00`00Oomoo`3oOomLOol0021oo`8000Ioo`8001Uoo`8000Qoo`8000Moo`800?mooeeo
o`0087oo0P001Woo0P006Goo0P0027oo0P001goo00<007ooOol0ogooG7oo000QOol20004Ool2000K
Ool30004Ool40007Ool00`00Oomoo`3oOomLOol0025oo`P001]oo`X000Qoo`03001oogoo0?mooeao
o`008goo10007goo1P002Woo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03
001oogoo0?mooeaoo`00EWoo0P00ogooGGoo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo
0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo
0?mooeaoo`00EWoo00<007ooOol0ogooG7oo000SOol4000>Ool3000?Ool5000:Ool2003oOomMOol0
025oo`P000]oo`D000aoo`P000Uoo`03001oogoo0?mooeaoo`008Goo0P0017oo0P002goo1@0037oo
0P0017oo0`0027oo00<007ooOol0ogooG7oo000POol20006Ool2000:Ool5000;Ool20006Ool30007
Ool00`00Oomoo`3oOomLOol0021oo`8000Ioo`8000]oo`<000]oo`8000Qoo`8000Moo`03001oogoo
0?mooeaoo`0037oo3@001Woo0P0027oo0P0067oo0P0027oo0P001goo00<007ooOol0ogooG7oo000<
Ool=0006Ool20008Ool2000HOol20008Ool20007Ool00`00Oomoo`3oOomLOol000aoo`d000Ioo`80
00Qoo`8001Qoo`8000Qoo`8000Moo`<00?mooeaoo`007goo0P0027oo0P0067oo0`001Woo0`001goo
00<007ooOol0ogooG7oo000OOol20008Ool2000HOol40004Ool30008Ool00`00Oomoo`3oOomLOol0
01moo`8000Qoo`8001Qoo`800003Ool0000000D000Uoo`03001oogoo0?mooeaoo`007goo0P0027oo
0P006Goo00<007ooOol01@002Woo00<007ooOol0ogooG7oo000OOol20008Ool2000IOol2000@Ool0
0`00Oomoo`3oOomLOol0021oo`8000Ioo`8001Yoo`<000moo`03001oogoo0?mooeaoo`0087oo0P00
1Woo0P006goo0`003Woo0P00ogooGGoo000QOol20004Ool2000MOol3000=Ool00`00Oomoo`3oOomL
Ool0025oo`P001ioo`P000Moo`03001oogoo0?mooeaoo`008goo10008Woo1P001goo00<007ooOol0
ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0
ogooG7oo001FOol2001AOol4002=Ool4001fOol005Ioo`03001oogoo051oo`04001oogoo002=Ool0
1000Oomoo`00MWoo001FOol00`00Oomoo`1?Ool00`00Oomoo`02Ool00`00Oomoo`29Ool00`00Oomo
o`02Ool00`00Oomoo`1cOol005Ioo`03001oogoo04moo`03001oogoo009oo`03001oogoo08Uoo`03
001oogoo009oo`03001oogoo07=oo`00EWoo00<007ooOol0Cgoo00<007ooOol00goo00<007ooOol0
Qgoo00<007ooOol00goo00<007ooOol0Lgoo001FOol00`00Oomoo`1?Ool00`00Oomoo`03Ool00`00
Oomoo`27Ool00`00Oomoo`03Ool00`00Oomoo`1cOol005Ioo`03001oogoo04ioo`03001oogoo00Ao
o`03001oogoo08Moo`03001oogoo00Aoo`03001oogoo079oo`008goo10003Woo0`0047oo1`001goo
0P00Cgoo00<007ooOol01Goo00<007ooOol0QGoo00<007ooOol01Goo00<007ooOol0LWoo000QOol8
000;Ool5000?Ool70007Ool00`00Oomoo`1>Ool00`00Oomoo`05Ool00`00Oomoo`25Ool00`00Oomo
o`05Ool00`00Oomoo`1bOol0025oo`8000Aoo`8000]oo`D0019oo`8000Uoo`03001oogoo04ioo`03
001oogoo00Ioo`03001oogoo08=oo`03001oogoo00Ioo`03001oogoo079oo`0087oo0P001Woo0P00
2Woo1@004Woo0P002Goo00<007ooOol0CGoo00<007ooOol01goo00<007ooOol0Pgoo00<007ooOol0
1goo00<007ooOol0LGoo000POol20006Ool2000;Ool3000COol20009Ool00`00Oomoo`1=Ool00`00
Oomoo`07Ool00`00Oomoo`23Ool00`00Oomoo`07Ool00`00Oomoo`1aOol000aoo`d000Ioo`8000Qo
o`8001Qoo``000Moo`03001oogoo04eoo`03001oogoo00Qoo`03001oogoo085oo`03001oogoo00Qo
o`03001oogoo075oo`0037oo3@001Woo0P0027oo0P0067oo30001goo00<007ooOol0CGoo00<007oo
Ool027oo00<007ooOol0PGoo00<007ooOol027oo00<007ooOol0LGoo000<Ool=0006Ool20008Ool2
000HOol20006Ool200000goo001oo`06Ool3001<Ool00`00Oomoo`09Ool00`00Oomoo`21Ool00`00
Oomoo`09Ool00`00Oomoo`1`Ool001moo`8000Qoo`8001Uoo`8000Eoo`8000Uoo`03001oogoo04ao
o`03001oogoo00Uoo`03001oogoo085oo`03001oogoo00Uoo`03001oogoo071oo`007goo0P0027oo
0P006Goo0`0017oo0P002Goo00<007ooOol0C7oo00<007ooOol02Goo00<007ooOol0PGoo00<007oo
Ool02Goo00<007ooOol0L7oo000OOol20008Ool2000JOol20004Ool20009Ool00`00Oomoo`1;Ool0
0`00Oomoo`0;Ool00`00Oomoo`1oOol00`00Oomoo`0;Ool00`00Oomoo`1_Ool001moo`8000Qoo`80
01]oo`8000=oo`8000Uoo`03001oogoo04]oo`03001oogoo00]oo`03001oogoo07moo`03001oogoo
00]oo`03001oogoo06moo`007goo0P0027oo0P006goo0`000Woo0P002Goo00<007ooOol0Bgoo00<0
07ooOol02goo00<007ooOol0Ogoo00<007ooOol02goo00<007ooOol0Kgoo000POol20006Ool2000M
Ool20002Ool20009Ool00`00Oomoo`1;Ool00`00Oomoo`0;Ool00`00Oomoo`1oOol00`00Oomoo`0;
Ool00`00Oomoo`1_Ool0021oo`8000Ioo`8001ioo`800003Ool0000000Uoo`8004aoo`03001oogoo
00]oo`03001oogoo07moo`03001oogoo00]oo`03001oogoo06moo`008Goo0P0017oo0P0087oo1000
2Goo00<007ooOol0BWoo00<007ooOol037oo00<007ooOol0Ogoo00<007ooOol037oo00<007ooOol0
KWoo000QOol8000POol40009Ool00`00Oomoo`1:Ool00`00Oomoo`0=Ool00`00Oomoo`1mOol00`00
Oomoo`0=Ool00`00Oomoo`1^Ool002=oo`@002=oo`<000Uoo`03001oogoo04Yoo`03001oogoo00eo
o`03001oogoo07eoo`03001oogoo00eoo`03001oogoo06ioo`00EWoo00<007ooOol0BWoo00<007oo
Ool03Goo00<007ooOol0OGoo00<007ooOol03Goo00<007ooOol0KWoo001FOol00`00Oomoo`1:Ool0
0`00Oomoo`0=Ool00`00Oomoo`1mOol00`00Oomoo`0=Ool00`00Oomoo`1^Ool005Ioo`8004]oo`03
001oogoo00ioo`03001oogoo07]oo`03001oogoo00ioo`03001oogoo06ioo`00EWoo00<007ooOol0
BWoo00<007ooOol03Woo00<007ooOol0Ngoo00<007ooOol03Woo00<007ooOol0KWoo001FOol00`00
Oomoo`1:Ool00`00Oomoo`0>Ool00`00Oomoo`1kOol00`00Oomoo`0>Ool00`00Oomoo`1^Ool005Io
o`03001oogoo04Uoo`03001oogoo011oo`03001oogoo07Uoo`03001oogoo011oo`03001oogoo06eo
o`00EWoo00<007ooOol0BGoo00<007ooOol047oo00<007ooOol0NGoo00<007ooOol047oo00<007oo
Ool0KGoo001FOol00`00Oomoo`19Ool00`00Oomoo`0@Ool00`00Oomoo`1iOol00`00Oomoo`0@Ool0
0`00Oomoo`1]Ool005Ioo`03001oogoo04Uoo`03001oogoo015oo`03001oogoo07Moo`03001oogoo
015oo`03001oogoo06eoo`008goo10003Woo0`002Woo300027oo0P00BWoo00<007ooOol04Goo00<0
07ooOol0Mgoo00<007ooOol04Goo00<007ooOol0KGoo000QOol8000;Ool50009Ool<0008Ool00`00
Oomoo`19Ool00`00Oomoo`0AOol00`00Oomoo`1gOol00`00Oomoo`0AOol00`00Oomoo`1]Ool0025o
o`8000Aoo`8000]oo`D000Yoo`<000Ioo`8000Qoo`03001oogoo04Uoo`03001oogoo015oo`03001o
ogoo07Moo`03001oogoo015oo`03001oogoo06eoo`0087oo0P001Woo0P002Woo1@002goo0`003goo
00<007ooOol0BGoo00<007ooOol04Goo00<007ooOol0Mgoo00<007ooOol04Goo00<007ooOol0KGoo
000POol20006Ool2000;Ool3000=Ool3000>Ool00`00Oomoo`18Ool00`00Oomoo`0COol00`00Oomo
o`1eOol00`00Oomoo`0COol00`00Oomoo`1/Ool000aoo`d000Ioo`8000Qoo`8001]oo`<000eoo`03
001oogoo04Qoo`03001oogoo01=oo`03001oogoo07Eoo`03001oogoo01=oo`03001oogoo06aoo`00
37oo3@001Woo0P0027oo0P0077oo0`0037oo00<007ooOol0B7oo00<007ooOol04goo00<007ooOol0
MGoo00<007ooOol04goo00<007ooOol0K7oo000<Ool=0006Ool20008Ool2000MOol3000;Ool30018
Ool00`00Oomoo`0COol00`00Oomoo`1eOol00`00Oomoo`0COol00`00Oomoo`1/Ool001moo`8000Qo
o`8001ioo`<000Yoo`03001oogoo04Qoo`03001oogoo01=oo`03001oogoo07Eoo`03001oogoo01=o
o`03001oogoo06aoo`007goo0P0027oo0P007goo0`002Goo00<007ooOol0;Woo1P003Woo10000Woo
00<007ooOol057oo00@007ooOomoo`X000]oo`@000ioo`@001=oo`X000Uoo`H000ioo`@000Uoo`03
001oogoo00Eoo``000=oo`03001oogoo00Eoo`@000ioo`@0019oo``000Uoo`H000ioo`@0019oo`00
7goo0P0027oo0P0087oo0P002Goo00<007ooOol0;7oo2P002Woo20005goo00@007ooOomoo`X000Uo
o`P000Yoo`P0015oo`X000Moo`X000Yoo`P000Moo`03001oogoo00Eoo``000Aoo`03001oogoo009o
o`P000Yoo`P0011oo``000Moo`X000Yoo`P0011oo`007goo0P0027oo0P008Goo0P0027oo00<007oo
Ool0;7oo0`001Goo0`002Goo0P0017oo0P005goo00<007ooOol01Goo0P003Goo0P0017oo0P002Woo
0P0017oo0P005Goo0P002goo0`001Goo0`002Goo0P0017oo0P001goo00<007ooOol01Woo0`001Woo
0P0017oo00<007ooOol00Woo0P0017oo0P002Woo0P0017oo0P004Goo0`001Woo0P001goo0`001Goo
0`002Goo0P0017oo0P0047oo000OOol20008Ool2000QOol20008Ool00`00Oomoo`0eOol20008Ool2
0006Ool2000FOol00`00Oomoo`05Ool2000<Ool20006Ool20008Ool20006Ool2000DOol2000DOol2
0008Ool20006Ool20006Ool00`00Oomoo`07Ool3000;Ool01000Oomoogoo0P001Woo0P0027oo0P00
1Woo0P004Goo0`005goo0P0027oo0P001Woo0P003goo000POol20006Ool2000IOol20007Ool20008
Ool00`00Oomoo`0fOol20007Ool20005Ool3000GOol00`00Oomoo`04Ool2000<Ool20006Ool20008
Ool20006Ool2000DOol2000EOol20007Ool20006Ool20005Ool00`00Oomoo`09Ool3000;Ool00`00
Oomoo`020006Ool20008Ool20006Ool2000BOol3000GOol20007Ool20006Ool2000?Ool0021oo`80
00Ioo`8001Uoo`<000Ioo`8000Qoo`8003Moo`8000Ioo`8000Ioo`04001oo`00000FOol00`00Oomo
o`04Ool2000;Ool20008Ool20006Ool20008Ool2000COol2000EOol20006Ool20008Ool20004Ool0
0`00Oomoo`0:Ool3000:Ool01000Ool0000027oo0P001Woo0P0027oo0P004Woo0`005Woo0P001Woo
0P0027oo0P003Woo000QOol20004Ool2000JOol40004Ool20009Ool00`00Oomoo`0fOol20006Ool2
0006Ool01000Ool000005goo00<007ooOol00goo0P002goo0P0027oo0P001Woo0P0027oo0P004goo
0P005Goo0P001Woo0P0027oo0P000goo00<007ooOol037oo0`002Goo00@007oo000000Qoo`8000Io
o`8000Qoo`8001=oo`<001Eoo`8000Ioo`8000Qoo`8000ioo`008Goo20006goo20002Woo00<007oo
Ool0=Woo0P001Woo0P001Woo00@007oo000001Moo`03001oogoo00=oo`8000]oo`8000Qoo`8000Io
o`8000Qoo`8001=oo`8001Eoo`8000Ioo`8000Qoo`8000=oo`03001oogoo00eoo`<000Qoo`04001o
o`000008Ool20006Ool20008Ool2000DOol3000DOol20006Ool20008Ool2000>Ool002=oo`@001mo
o`D000]oo`03001oogoo03Ioo`8000Ioo`8000Ioo`04001oo`00000HOol00`00Oomoo`02Ool2000;
Ool20008Ool20006Ool20008Ool2000COol2000EOol20006Ool20008Ool20002Ool00`00Oomoo`0?
Ool30007Ool01000Ool0000027oo0P001Woo0P0027oo0P005Goo0`004goo0P001Woo0P0027oo0P00
3Woo001FOol00`00Oomoo`0eOol20007Ool20005Ool00`00Oomoo`02000HOol00`00Oomoo`02Ool2
000;Ool20008Ool20006Ool20008Ool2000COol2000DOol20007Ool20008Ool20002Ool00`00Oomo
o`0@Ool30007Ool30008Ool20006Ool20008Ool2000FOol3000AOol20007Ool20008Ool2000>Ool0
05Ioo`03001oogoo02eoo`8000Eoo`<000Moo`8000Eoo`03001oogoo008001Qoo`03001oogoo009o
o`8000]oo`8000Qoo`8000Ioo`8000Qoo`8001=oo`8000aoo`8000Eoo`<000Moo`8000Qoo`80009o
o`03001oogoo015oo`8000Moo`<000Qoo`8000Ioo`8000Qoo`8001Moo`8000Uoo`8000Eoo`<000Mo
o`8000Qoo`8000ioo`00EWoo00<007ooOol0;Goo2@0027oo0P001Goo00<007ooOol00P006Goo00@0
07ooOomoo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8001=oo`8000aoo`T000Qoo`8000Qoo`800003
Ool007oo01Aoo`8000Ioo`<000Qoo`8000Ioo`8000Qoo`8001Qoo`8000Qoo`T000Qoo`8000Qoo`80
00ioo`00EWoo0P00;Woo0P0000=oo`0000000`002Goo0P001Goo00<007ooOol00P006Goo00@007oo
Oomoo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8001=oo`8000aoo`800003Ool0000000<000Uoo`80
00Qoo`800003Ool007oo01Aoo`8000Ioo`<000Qoo`8000Ioo`8000Qoo`8001Qoo`8000Qoo`800003
Ool0000000<000Uoo`8000Qoo`8000ioo`00EWoo00<007ooOol0;Goo0P0047oo0P0017oo00@007oo
000001Yoo`04001oogooOol2000<Ool20006Ool20008Ool20006Ool2000DOol2000<Ool2000@Ool2
0006Ool20002Ool00`00Oomoo`0:Ool20007Ool20006Ool01000Ool000001Woo0P0027oo0P001Woo
0P0047oo0P001goo0P0027oo0P0047oo0P001Woo0P003goo001FOol00`00Oomoo`0]Ool2000@Ool2
0004Ool01000Ool000006goo00<007ooOol00P0037oo0P001Woo0P0027oo0P001Woo0P0057oo0P00
37oo0P0047oo0P001Woo0P0000=oo`00Ool037oo0`001Woo0P001Woo00@007oo000000Ioo`8000Qo
o`8000Ioo`80011oo`<000Ioo`8000Qoo`80011oo`8000Ioo`8000moo`00EWoo00<007ooOol0;Goo
0P004Goo0P000goo0`006goo0`0000=oo`0000003Goo0P0017oo0P002Woo0P0017oo0P004Goo0`00
00=oo`00000037oo0P004Goo0P0017oo0P000Woo00<007ooOol02goo100017oo0P001goo00<007oo
Ool00P0017oo0P002Woo0P0017oo0P004Goo100017oo0P002Goo0P004Goo0P0017oo0P0047oo001F
Ool00`00Oomoo`0]Ool:0009Ool8000KOol6000=Ool8000:Ool8000AOol6000<Ool:0009Ool80000
0goo001oo`0>Ool80009Ool00`00Ool00007000:Ool8000BOol8000:Ool:0009Ool8000@Ool005Io
o`03001oogoo02eoo`X000]oo`@0021oo`<000moo`@000ioo`@001Ioo`<000aoo`X000]oo`@0009o
o`03001oogoo011oo`D000Yoo`04001oogooOol4000>Ool4000FOol5000;Ool:000;Ool4000BOol0
05Ioo`03001oogoo04Aoo`03001oogoo01moo`03001oogoo06Eoo`03001oogoo01moo`03001oogoo
06Qoo`00EWoo0P00AGoo00<007ooOol087oo00<007ooOol0Hgoo00<007ooOol087oo00<007ooOol0
J7oo001FOol00`00Oomoo`14Ool00`00Oomoo`0POol00`00Oomoo`1SOol00`00Oomoo`0POol00`00
Oomoo`1XOol005Ioo`03001oogoo04=oo`03001oogoo029oo`03001oogoo065oo`03001oogoo029o
o`03001oogoo06Moo`00EWoo00<007ooOol0@goo00<007ooOol08goo0P00Ggoo0P009Goo00<007oo
Ool0Igoo001FOol00`00Oomoo`13Ool00`00Oomoo`0UOol00`00Oomoo`1KOol00`00Oomoo`0UOol0
0`00Oomoo`1WOol005Ioo`03001oogoo04=oo`03001oogoo02Ioo`8005Uoo`8002Qoo`03001oogoo
06Moo`00EWoo00<007ooOol0<Goo1P002goo00<007ooOol0:Goo1`00Bgoo1`00:goo00<007ooOol0
2Goo1P00Egoo001FOooo000j000UOol005Ioo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo00Yoo`03001oogoo00Qoo`8000Eoo`03001oogoo00Aoo`03001oogoo00Uoo`03
001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Ioo`04001oogoo0003Ool00`00Oomoo`06Ool0
0`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0SOol0
05Ioo`03001oogoo03]oo`03001oogoo009oo`03001oogoo03Moo`03001oogoo03]oo`03001oogoo
03Uoo`03001oo`00009oo`03001oogoo03Uoo`03001oogoo02=oo`00EWoo00<007ooOol0?7oo0P00
00=oo`00Ool0]7oo00@007oo0000069oo`00EWoo00<007ooOol0?Woo00<007ooOol0]Goo00<007oo
Ool0HWoo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo0P00ogooGGoo
001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo
001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo
001FOol2003oOomMOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol0
0`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo000SOol4
000>Ool3000:Ool<0008Ool2003oOomMOol0025oo`P000]oo`D000Uoo``000Qoo`03001oogoo0?mo
oeaoo`008Goo0P0017oo0P002goo1@002Woo0`001Woo0P0027oo00<007ooOol0ogooG7oo000POol2
0006Ool2000:Ool5000;Ool3000?Ool00`00Oomoo`3oOomLOol0021oo`8000Ioo`8000]oo`<000eo
o`<000ioo`03001oogoo0?mooeaoo`007goo0P0027oo0P006goo0`003Goo00<007ooOol0ogooG7oo
000OOol20008Ool2000LOol3000<Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001eoo`<000]o
o`<00?mooeaoo`007goo0P0027oo0P007Woo0`002Woo00<007ooOol0ogooG7oo000OOol20008Ool2
000OOol30009Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`80021oo`8000Uoo`03001oogoo0?mo
oeaoo`007goo0P0027oo0P008Goo0P0027oo00<007ooOol0ogooG7oo000OOol20008Ool2000QOol2
0008Ool00`00Oomoo`3oOomLOol0021oo`8000Ioo`8001Uoo`8000Moo`8000Qoo`03001oogoo0?mo
oeaoo`0087oo0P001Woo0P006Goo0`001Woo0P0027oo0P00ogooGGoo000QOol20004Ool2000JOol4
0004Ool20009Ool00`00Oomoo`3oOomLOol0025oo`P001]oo`P000Yoo`03001oogoo0?mooeaoo`00
8goo10007goo1@002goo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001o
ogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol2003oOomMOol005Ioo`03001oogoo0?mo
oeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mo
oeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol002=oo`@000ioo`<0011o
o`L000Moo`800?mooeeoo`008Goo20002goo1@003goo1`001goo00<007ooOol0ogooG7oo000QOol2
0004Ool2000;Ool5000BOol20009Ool00`00Oomoo`3oOomLOol0021oo`8000Ioo`8000Yoo`D0019o
o`8000Uoo`03001oogoo0?mooeaoo`0087oo0P001Woo0P002goo0`004goo0P002Goo00<007ooOol0
ogooG7oo000OOol20008Ool2000HOol<0007Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001Qo
o``000Moo`03001oogoo0?mooeaoo`007goo0P0027oo0P0067oo0P001Woo0P0000=oo`00Ool01Woo
0`00ogooG7oo000OOol20008Ool2000IOol20005Ool20009Ool00`00Oomoo`3oOomLOol001moo`80
00Qoo`8001Uoo`<000Aoo`8000Uoo`03001oogoo0?mooeaoo`007goo0P0027oo0P006Woo0P0017oo
0P002Goo00<007ooOol0ogooG7oo000OOol20008Ool2000KOol20003Ool20009Ool00`00Oomoo`3o
OomLOol001moo`8000Qoo`8001]oo`<0009oo`8000Uoo`03001oogoo0?mooeaoo`0087oo0P001Woo
0P007Goo0P000Woo0P002Goo00<007ooOol0ogooG7oo000POol20006Ool2000NOol200000goo0000
0009Ool2003oOomMOol0025oo`8000Aoo`80021oo`@000Uoo`03001oogoo0?mooeaoo`008Goo2000
87oo10002Goo00<007ooOol0ogooG7oo000SOol4000SOol30009Ool00`00Oomoo`3oOomLOol005Io
o`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Io
o`800?mooeeoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001o
ogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001o
ogoo0?mooeaoo`00EWoo0P00ogooGGoo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mo
oeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mo
oeaoo`00EWoo00<007ooOol0ogooG7oo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mo
okEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo
003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mo
okEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo
003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mo
okEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo
003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mo
okEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo
003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mo
okEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo
003oOoneOol00?mookEoo`00ogoo]Goo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mo
oeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mo
oeaoo`00EWoo00<007ooOol0ogooG7oo001FOol2003oOomMOol005Ioo`03001oogoo0?mooeaoo`00
EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00
EWoo00<007ooOol0ogooG7oo001FOol2003oOomMOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<0
07ooOol0DGoo0P00ogoo2Goo001FOol00`00Oomoo`1@Ool01000Oomoo`00ogoo27oo001FOol00`00
Oomoo`1@Ool01000Oomoo`00ogoo27oo000SOol4000>Ool3000@Ool70007Ool00`00Oomoo`1?Ool0
0`00Oomoo`02Ool00`00Oomoo`3oOol5Ool0025oo`P000]oo`D000moo`L000Moo`80051oo`03001o
ogoo009oo`03001oogoo0?moo`Eoo`008Goo0P0017oo0P002goo1@004Woo0P002Goo00<007ooOol0
CWoo00<007ooOol017oo00<007ooOol0ogoo17oo000POol20006Ool2000:Ool5000BOol20009Ool0
0`00Oomoo`1>Ool00`00Oomoo`04Ool00`00Oomoo`3oOol4Ool0021oo`8000Ioo`8000]oo`<001=o
o`8000Uoo`03001oogoo04ioo`03001oogoo00Eoo`03001oogoo0?moo`=oo`0037oo3@001Woo0P00
27oo0P0067oo30001goo00<007ooOol0CWoo00<007ooOol01Goo00<007ooOol0ogoo0goo000<Ool=
0006Ool20008Ool2000HOol<0007Ool00`00Oomoo`1=Ool00`00Oomoo`07Ool00`00Oomoo`3oOol2
Ool000aoo`d000Ioo`8000Qoo`8001Qoo`8000Ioo`800003Ool007oo00Ioo`<004eoo`03001oogoo
00Moo`03001oogoo0?moo`9oo`007goo0P0027oo0P006Goo0P001Goo0P002Goo00<007ooOol0CGoo
00<007ooOol01goo00<007ooOol0ogoo0Woo000OOol20008Ool2000IOol30004Ool20009Ool00`00
Oomoo`1=Ool00`00Oomoo`08Ool00`00Oomoo`3oOol1Ool001moo`8000Qoo`8001Yoo`8000Aoo`80
00Uoo`03001oogoo04aoo`03001oogoo00Uoo`03001oogoo0?moo`5oo`007goo0P0027oo0P006goo
0P000goo0P002Goo00<007ooOol0C7oo00<007ooOol02Goo00<007ooOol0ogoo0Goo000OOol20008
Ool2000KOol30002Ool20009Ool00`00Oomoo`1<Ool00`00Oomoo`09Ool00`00Oomoo`3oOol1Ool0
021oo`8000Ioo`8001eoo`80009oo`8000Uoo`8004aoo`03001oogoo00]oo`03001oogoo0?moo`00
87oo0P001Woo0P007Woo0P0000=oo`0000002Goo00<007ooOol0Bgoo00<007ooOol02goo00<007oo
Ool0ogoo000QOol20004Ool2000POol40009Ool00`00Oomoo`1;Ool00`00Oomoo`0;Ool00`00Oomo
o`3oOol0025oo`P0021oo`@000Uoo`03001oogoo04]oo`03001oogoo00]oo`03001oogoo0?moo`00
8goo10008goo0`002Goo00<007ooOol0BWoo00<007ooOol03Goo00<007ooOol0oWoo001FOol00`00
Oomoo`1:Ool00`00Oomoo`0=Ool00`00Oomoo`3nOol005Ioo`8004]oo`03001oogoo00eoo`03001o
ogoo0?ioo`00EWoo00<007ooOol0BWoo00<007ooOol03Woo00<007ooOol0oGoo001FOol00`00Oomo
o`1:Ool00`00Oomoo`0>Ool00`00Oomoo`3mOol005Ioo`03001oogoo04Yoo`03001oogoo00ioo`03
001oogoo0?eoo`00EWoo00<007ooOol0BGoo00<007ooOol047oo00<007ooOol0o7oo000SOol4000>
Ool3000:Ool<0008Ool00`00Oomoo`19Ool00`00Oomoo`0@Ool00`00Oomoo`3lOol0025oo`P000]o
o`D000Uoo``000Qoo`8004Yoo`03001oogoo011oo`03001oogoo0?aoo`008Goo0P0017oo0P002goo
1@002Woo0`001Woo0P0027oo00<007ooOol0BGoo00<007ooOol04Goo00<007ooOol0ngoo000POol2
0006Ool2000:Ool5000;Ool3000?Ool00`00Oomoo`19Ool00`00Oomoo`0AOol00`00Oomoo`3kOol0
021oo`8000Ioo`8000]oo`<000eoo`<000ioo`03001oogoo04Uoo`03001oogoo015oo`03001oogoo
0?]oo`0037oo3@001Woo0P0027oo0P006goo0`003Goo00<007ooOol0B7oo00<007ooOol04Woo00<0
07ooOol0ngoo000<Ool=0006Ool20008Ool2000LOol3000<Ool00`00Oomoo`0^Ool6000>Ool40002
Ool00`00Oomoo`0COol00`00Oomoo`02Ool:000;Ool4000>Ool4000COol:0009Ool6000>Ool4000A
Ool<000;Ool4000>Ool4000BOol<0009Ool6000>Ool4000BOol000aoo`d000Ioo`8000Qoo`8001eo
o`<000]oo`<002aoo`X000Yoo`T001Eoo`03001oogoo009oo`X000Uoo`P000Yoo`P0015oo`X000Mo
o`X000Yoo`P000moo``000Uoo`P000Yoo`P0011oo``000Moo`X000Yoo`P0011oo`007goo0P0027oo
0P007Woo0`002Woo00<007ooOol0;7oo0`001Goo0`002Goo0P0017oo0`005Goo00<007ooOol01Woo
0P003Goo0P0017oo0P002Woo0P0017oo0P005Goo0P002goo0`001Goo0`002Goo0P0017oo0P0047oo
0`001Woo0P002Goo0P0017oo0P002Woo0P0017oo0P004Goo0`001Woo0P001goo0`001Goo0`002Goo
0P0017oo0P0047oo000OOol20008Ool2000OOol30009Ool00`00Oomoo`0eOol20008Ool20006Ool2
000EOol00`00Oomoo`06Ool2000<Ool20006Ool20008Ool20006Ool2000DOol2000DOol20008Ool2
0006Ool2000@Ool3000?Ool20006Ool20008Ool20006Ool2000AOol3000GOol20008Ool20006Ool2
000?Ool001moo`8000Qoo`80021oo`8000Uoo`03001oogoo03Ioo`8000Moo`8000Ioo`8001Ioo`03
001oogoo00Eoo`8000aoo`8000Ioo`8000Qoo`8000Ioo`8001Aoo`8001Eoo`8000Moo`8000Ioo`80
015oo`<000ioo`8000Ioo`8000Qoo`8000Ioo`80019oo`<001Moo`8000Moo`8000Ioo`8000moo`00
7goo0P0027oo0P008Goo0P0027oo00<007ooOol0=Woo0P001Woo0P001goo0`005Goo00<007ooOol0
1Goo0P002goo0P0027oo0P001Woo0P0027oo0P004goo0P005Goo0P001Woo0P0027oo0P004Goo0`00
37oo0P0027oo0P001Woo0P0027oo0P004Woo0`005Woo0P001Woo0P0027oo0P003Woo000OOol20008
Ool2000QOol20008Ool00`00Oomoo`0fOol20006Ool20007Ool3000EOol00`00Oomoo`05Ool2000;
Ool20008Ool20006Ool20008Ool2000COol2000EOol20006Ool20008Ool2000BOol3000;Ool20008
Ool20006Ool20008Ool2000COol3000EOol20006Ool20008Ool2000>Ool0021oo`8000Ioo`8001Uo
o`8000Moo`8000Qoo`8003Moo`8000Ioo`8000Ioo`04001oo`00000FOol00`00Oomoo`04Ool2000;
Ool20008Ool20006Ool20008Ool2000COol2000EOol20006Ool20008Ool2000COol3000:Ool20008
Ool20006Ool20008Ool2000DOol3000DOol20006Ool20008Ool2000>Ool0021oo`8000Ioo`8001Uo
o`<000Ioo`8000Qoo`03001oogoo03Ioo`8000Ioo`8000Ioo`04001oo`00000FOol00`00Oomoo`04
Ool2000;Ool20008Ool20006Ool20008Ool2000COol2000EOol20006Ool20008Ool2000DOol30009
Ool20008Ool20006Ool20008Ool2000EOol3000COol20006Ool20008Ool2000>Ool0025oo`8000Ao
o`8001Yoo`@000Aoo`8000Uoo`03001oogoo03Eoo`8000Moo`8000Ioo`04001oo`00000GOol00`00
Oomoo`03Ool2000;Ool20008Ool20006Ool20008Ool2000COol2000DOol20007Ool20008Ool2000E
Ool30008Ool20008Ool20006Ool20008Ool2000FOol3000AOol20007Ool20008Ool2000>Ool0025o
o`P001]oo`P000Yoo`03001oogoo02eoo`8000Eoo`<000Moo`8000Ioo`04001oo`00000GOol00`00
Oomoo`03Ool2000;Ool20008Ool20006Ool20008Ool2000COol2000<Ool20005Ool30007Ool20008
Ool2000FOol20008Ool20008Ool20006Ool20008Ool2000GOol20009Ool20005Ool30007Ool20008
Ool2000>Ool002=oo`@001moo`D000]oo`03001oogoo02eoo`T000Qoo`8000Ioo`04001oo`00000H
Ool00`00Oomoo`02Ool2000;Ool20008Ool20006Ool20008Ool2000COol2000<Ool90008Ool20008
Ool2000GOol20007Ool20008Ool20006Ool20008Ool2000HOol20008Ool90008Ool20008Ool2000>
Ool005Ioo`03001oogoo02eoo`800003Ool0000000<000Uoo`8000Eoo`03001oogoo008001Qoo`03
001oogoo009oo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8001=oo`8000aoo`800003Ool0000000<0
00Uoo`8000Qoo`8001Moo`8000Moo`8000Qoo`8000Ioo`8000Qoo`8001Qoo`8000Qoo`800003Ool0
000000<000Uoo`8000Qoo`8000ioo`00EWoo0P00;Woo0P0047oo0P0017oo00@007oo000001Uoo`03
001oogoo009oo`8000aoo`8000Ioo`8000Qoo`8000Ioo`8001Aoo`8000aoo`80011oo`8000Ioo`80
00moo`8000Moo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`80011oo`8000Moo`8000Qoo`80011oo`80
00Ioo`8000moo`00EWoo00<007ooOol0;Goo0P0047oo0P0017oo00@007oo000001Yoo`04001oogoo
Ool2000<Ool20006Ool20008Ool20006Ool2000DOol2000<Ool2000@Ool20006Ool2000?Ool30006
Ool20008Ool20006Ool20008Ool20006Ool2000@Ool30006Ool20008Ool2000@Ool20006Ool2000?
Ool005Ioo`03001oogoo02eoo`80015oo`8000=oo`<001]oo`<00003Ool0000000eoo`8000Aoo`80
00Yoo`8000Aoo`80015oo`<00003Ool0000000aoo`80015oo`8000Aoo`80011oo`@000Aoo`8000Yo
o`8000Aoo`8000Yoo`8000Aoo`80015oo`@000Aoo`8000Uoo`80015oo`8000Aoo`80011oo`00EWoo
00<007ooOol0;Goo2P002Goo20006goo1P003Goo20002Woo20004Goo1P0037oo2P002Goo20004Goo
20002goo20002Woo20004Woo20002Woo2P002Goo200047oo001FOol00`00Oomoo`0]Ool:000;Ool4
000NOol5000?Ool4000>Ool4000FOol3000<Ool:000;Ool4000EOol5000>Ool4000>Ool4000FOol5
000;Ool:000;Ool4000BOol005Ioo`03001oogoo04Aoo`03001oogoo01moo`03001oogoo0?9oo`00
EWoo0P00AGoo00<007ooOol07goo00<007ooOol0lWoo001FOol00`00Oomoo`14Ool00`00Oomoo`0P
Ool00`00Oomoo`3aOol005Ioo`03001oogoo04Aoo`03001oogoo025oo`03001oogoo0?1oo`00EWoo
00<007ooOol0@goo00<007ooOol08goo0P00RWoo0`00Hgoo001FOol00`00Oomoo`13Ool00`00Oomo
o`0UOol00`00Oomoo`26Ool01000Oomoogoo0P00HGoo001FOol00`00Oomoo`13Ool00`00Oomoo`0V
Ool40024Ool00`00Oomoo`03Ool00`00Oomoo`1NOol005Ioool003X002Eoo`00EWoo00<007ooOol0
2Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01Woo0`0000=oo`00Ool027oo00<007oo
00001Goo00<007ooOol017oo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007oo
Ool02Goo00<007ooOol00Woo2P002Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol01Woo
00@007ooOol000Moo`L000Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001o
ogoo02=oo`00EWoo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo
00<007ooOol027oo0P001Goo00<007ooOol017oo00<007ooOol02Goo00<007ooOol02Woo00<007oo
Ool02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol00P0027oo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol01Goo00D007ooOomoo`0000aoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo02=oo`00EWoo00<007ooOol0>goo0`0000=o
o`000000R7oo0P009Woo00<007ooOol0Igoo001FOol00`00Oomoo`0nOol00`00Oomoo`2:Ool00`00
Oomoo`0SOol00`00Oomoo`1WOol005Ioo`03001oogoo0<aoo`03001oogoo029oo`03001oogoo06Mo
o`00EWoo0P00cWoo00<007ooOol087oo00<007ooOol0J7oo001FOol00`00Oomoo`3>Ool00`00Oomo
o`0OOol00`00Oomoo`1XOol005Ioo`03001oogoo0<moo`03001oogoo01ioo`03001oogoo06Qoo`00
EWoo00<007ooOol0d7oo00<007ooOol07Goo00<007ooOol0J7oo001FOol00`00Oomoo`3@Ool00`00
Oomoo`0LOol00`00Oomoo`1YOol005Ioo`03001oogoo0=5oo`03001oogoo01]oo`03001oogoo06Uo
o`00EWoo0P00dWoo00<007ooOol06goo00<007ooOol0JGoo001FOol00`00Oomoo`3AOol00`00Oomo
o`0KOol00`00Oomoo`1YOol005Ioo`03001oogoo0=9oo`03001oogoo01Yoo`03001oogoo06Uoo`00
EWoo00<007ooOol0dWoo00<007ooOol06Woo00<007ooOol0JGoo001FOol00`00Oomoo`3COol00`00
Oomoo`0HOol00`00Oomoo`1ZOol005Ioo`03001oogoo0==oo`03001oogoo01Qoo`03001oogoo06Yo
o`008goo10003Woo0`002Woo300027oo00<007ooOol0dgoo00<007ooOol067oo00<007ooOol0JWoo
000QOol8000;Ool50009Ool<0008Ool2003EOol00`00Oomoo`0GOol00`00Oomoo`1ZOol0025oo`80
00Aoo`8000]oo`D000Yoo`<000Ioo`8000Qoo`03001oogoo0=Aoo`03001oogoo01Ioo`03001oogoo
06]oo`0087oo0P001Woo0P002Woo1@002goo0`003goo00<007ooOol0eGoo00<007ooOol05Goo00<0
07ooOol0Jgoo000POol20006Ool2000;Ool3000=Ool3000>Ool00`00Oomoo`3EOol00`00Oomoo`0E
Ool00`00Oomoo`1[Ool001moo`8000Qoo`8001]oo`<000eoo`03001oogoo0=Ioo`03001oogoo01=o
o`03001oogoo06aoo`007goo0P0027oo0P0077oo0`0037oo00<007ooOol0eWoo00<007ooOol04goo
00<007ooOol0K7oo000OOol20008Ool2000MOol3000;Ool3003FOol00`00Oomoo`0COol00`00Oomo
o`1/Ool001moo`8000Qoo`8001ioo`<000Yoo`03001oogoo0=Ioo`03001oogoo01=oo`03001oogoo
06aoo`007goo0P0027oo0P007goo0`002Goo00<007ooOol0egoo00<007ooOol04Woo00<007ooOol0
K7oo000OOol20008Ool2000POol20009Ool00`00Oomoo`3GOol00`00Oomoo`0AOol00`00Oomoo`1]
Ool001moo`8000Qoo`80025oo`8000Qoo`03001oogoo0=Moo`03001oogoo015oo`03001oogoo06eo
o`007goo0P0027oo0P008Goo0P0027oo00<007ooOol0egoo00<007ooOol04Goo00<007ooOol0KGoo
000POol20006Ool2000IOol20007Ool20008Ool2003HOol00`00Oomoo`0AOol00`00Oomoo`1]Ool0
021oo`8000Ioo`8001Uoo`<000Ioo`8000Qoo`03001oogoo0=Qoo`03001oogoo011oo`03001oogoo
06eoo`008Goo0P0017oo0P006Woo100017oo0P002Goo00<007ooOol0f7oo00<007ooOol047oo00<0
07ooOol0KGoo000QOol8000KOol8000:Ool00`00Oomoo`3HOol00`00Oomoo`0?Ool00`00Oomoo`1^
Ool002=oo`@001moo`D000]oo`03001oogoo0=Uoo`03001oogoo00ioo`03001oogoo06ioo`00EWoo
00<007ooOol0fGoo00<007ooOol03Woo00<007ooOol0KWoo001FOol2003KOol00`00Oomoo`0=Ool0
0`00Oomoo`1^Ool005Ioo`03001oogoo0=Yoo`03001oogoo00eoo`03001oogoo06ioo`00EWoo00<0
07ooOol0fWoo00<007ooOol03Goo00<007ooOol0KWoo001FOol00`00Oomoo`3KOol00`00Oomoo`0<
Ool00`00Oomoo`1^Ool005Ioo`03001oogoo0=]oo`03001oogoo00]oo`03001oogoo06moo`008goo
10003Woo0`0047oo1`001goo00<007ooOol0fgoo00<007ooOol02goo00<007ooOol0Kgoo000QOol8
000;Ool5000?Ool70007Ool2003LOol00`00Oomoo`0;Ool00`00Oomoo`1_Ool0025oo`8000Aoo`80
00]oo`D0019oo`8000Uoo`03001oogoo0=]oo`03001oogoo00]oo`03001oogoo06moo`0087oo0P00
1Woo0P002Woo1@004Woo0P002Goo00<007ooOol0g7oo00<007ooOol02Goo00<007ooOol0L7oo000P
Ool20006Ool2000;Ool3000COol20009Ool00`00Oomoo`3LOol00`00Oomoo`09Ool00`00Oomoo`1`
Ool001moo`8000Qoo`8001Qoo``000Moo`03001oogoo0=aoo`03001oogoo00Uoo`03001oogoo071o
o`007goo0P0027oo0P0067oo30001goo00<007ooOol0g7oo00<007ooOol027oo00<007ooOol0LGoo
000OOol20008Ool2000HOol20006Ool200000goo001oo`06Ool3003MOol00`00Oomoo`07Ool00`00
Oomoo`1aOol001moo`8000Qoo`8001Uoo`8000Eoo`8000Uoo`03001oogoo0=eoo`03001oogoo00Mo
o`03001oogoo075oo`007goo0P0027oo0P006Goo0`0017oo0P002Goo00<007ooOol0gGoo00<007oo
Ool01Woo00<007ooOol0LWoo000OOol20008Ool2000JOol20004Ool20009Ool00`00Oomoo`3NOol0
0`00Oomoo`05Ool00`00Oomoo`1bOol001moo`8000Qoo`8001]oo`8000=oo`8000Uoo`03001oogoo
0=ioo`03001oogoo00Eoo`03001oogoo079oo`007goo0P0027oo0P006goo0`000Woo0P002Goo00<0
07ooOol0ggoo00<007ooOol017oo00<007ooOol0LWoo000POol20006Ool2000MOol20002Ool20009
Ool2003POol00`00Oomoo`03Ool00`00Oomoo`1cOol0021oo`8000Ioo`8001ioo`800003Ool00000
00Uoo`03001oogoo0>1oo`03001oogoo009oo`03001oogoo07=oo`008Goo0P0017oo0P0087oo1000
2Goo00<007ooOol0h7oo00<007ooOol00Woo00<007ooOol0Lgoo000QOol8000POol40009Ool00`00
Oomoo`3QOol01000Ool00000MWoo000SOol4000SOol30009Ool00`00Oomoo`3ROol00`00Oomoo`1f
Ool005Ioo`03001oogoo0?mooeaoo`00EWoo0P00ogooGGoo001FOol00`00Oomoo`3oOomLOol005Io
o`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00Oomoo`3oOomLOol002=o
o`@000ioo`<000moo`D000Yoo`03001oogoo0?mooeaoo`008Goo20002goo1@0037oo20002Goo0P00
ogooGGoo000QOol20004Ool2000;Ool5000<Ool20004Ool30008Ool00`00Oomoo`3oOomLOol0021o
o`8000Ioo`8000Yoo`D000]oo`8000Ioo`<000Moo`03001oogoo0?mooeaoo`0087oo0P001Woo0P00
2goo0`002goo0P0027oo0P001goo00<007ooOol0ogooG7oo000OOol20008Ool2000HOol20008Ool2
0007Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001Qoo`8000Qoo`8000Moo`03001oogoo0?mo
oeaoo`007goo0P0027oo0P0067oo0P0027oo0P001goo0`00ogooG7oo000OOol20008Ool2000HOol3
0006Ool30007Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001Qoo`@000Aoo`<000Qoo`03001o
ogoo0?mooeaoo`007goo0P0027oo0P0067oo0P0000=oo`0000001@002Goo00<007ooOol0ogooG7oo
000OOol20008Ool2000IOol00`00Oomoo`05000:Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`80
01Uoo`80011oo`03001oogoo0?mooeaoo`0087oo0P001Woo0P006Woo0`003goo0P00ogooGGoo000P
Ool20006Ool2000KOol3000>Ool00`00Oomoo`3oOomLOol0025oo`8000Aoo`8001eoo`<000eoo`03
001oogoo0?mooeaoo`008Goo20007Woo20001goo00<007ooOol0ogooG7oo000SOol4000ROol60007
Ool00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo0P00ogooGGoo001FOol00`00
Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007ooOol0ogooG7oo001FOol00`00
Oomoo`3oOomLOol002=oo`@000ioo`<000ioo`H000Yoo`03001oogoo0?mooeaoo`008Goo20002goo
1@0037oo20002Goo0P00ogooGGoo000QOol20004Ool2000;Ool5000;Ool30004Ool30008Ool00`00
Oomoo`3oOomLOol0021oo`8000Ioo`8000Yoo`D000Yoo`<000Ioo`<000Moo`03001oogoo0?mooeao
o`0087oo0P001Woo0P002goo0`002goo0P0027oo0P001goo00<007ooOol0ogooG7oo000OOol20008
Ool2000HOol20008Ool20007Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001Qoo`8000Qoo`80
00Moo`03001oogoo0?mooeaoo`007goo0P0027oo0P0067oo0`001Woo0`001goo0`00ogooG7oo000O
Ool20008Ool2000IOol30004Ool30008Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001Yoo`P0
00Uoo`03001oogoo0?mooeaoo`007goo0P0027oo0P006Woo20002Goo00<007ooOol0ogooG7oo000O
Ool20008Ool2000IOol30004Ool30008Ool00`00Oomoo`3oOomLOol001moo`8000Qoo`8001Qoo`80
00Qoo`8000Moo`03001oogoo0?mooeaoo`0087oo0P001Woo0P006Goo0P0027oo0P001goo0P00ogoo
GGoo000POol20006Ool2000IOol20008Ool20007Ool00`00Oomoo`3oOomLOol0025oo`8000Aoo`80
01]oo`<000Aoo`@000Moo`03001oogoo0?mooeaoo`008Goo20006goo2P0027oo00<007ooOol0ogoo
G7oo000SOol4000OOol6000:Ool00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo
0P00ogooGGoo001FOol00`00Oomoo`3oOomLOol005Ioo`03001oogoo0?mooeaoo`00EWoo00<007oo
Ool0ogooG7oo001FOol00`00Oomoo`3oOomLOol004Aoo`X000Qoo`03001oogoo0?mooeaoo`00A7oo
2P0027oo0P00ogooGGoo0018Ool2000<Ool00`00Oomoo`3oOomLOol004Qoo`8000aoo`03001oogoo
0?mooeaoo`00B7oo0P0037oo00<007ooOol0ogooG7oo0018Ool2000<Ool00`00Oomoo`3oOomLOol0
04Qoo`8000aoo`03001oogoo0?mooeaoo`00B7oo0P0037oo0`00ogooG7oo0018Ool2003oOom[Ool0
04Qoo`800?moof]oo`00B7oo0P00ogooJgoo0018Ool2003oOom[Ool004Qoo`800?moof]oo`00B7oo
0P00ogooJgoo0018Ool2003oOom[Ool004Aoo`<00003Ool000000?moof]oo`00A7oo1P00ogooJgoo
0017Ool3003oOom[Ool00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOone
Ool00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00
ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOone
Ool00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00
ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOone
Ool00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00
ogoo]Goo003oOoneOol00?mookEoo`00ogoo]Goo003oOoneOol00?mookEoo`00\
\>"], "Graphics",
  CellLabel->"From In[83]:=",
  Evaluatable->False,
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The simulated pulses demonstrate the expected behaviour including \
reflection at the wire boundaries. To understand any real situation the \
parameters entering the telegraph equation, specifically the capacities and \
inductances of the configuration of conductors should be known precisely  \
(the calculations of the next sections reach an accuracy of a few %  \[Dash] \
tested with coax and other geometries \[Dash]).\
\>", "Text",
  PageBreakBelow->Automatic]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerical Calculation of Capacities and Inductances", "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell["Capacities", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Definition of Capacitance, Coefficients of Induction and \
Coefficients of Capacity\
\>", "Subsubsection"],

Cell[TextData[{
  "In a system of n conductors the equations relating the 'induced' charge on \
one conductor to the potentials (U\[NonBreakingSpace]or\[NonBreakingSpace]\
\[Phi]) of all others (",
  StyleBox["Ref. 5",
    FontWeight->"Bold"],
  ", p.318) read"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`Q\_1\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_11\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`U\_1\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_12\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`U\_2\)]],
  " + ... + ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_\(1  n\)\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`U\_n\)]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`Q\_2\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_21\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`U\_1\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_22\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`U\_2\)]],
  " + ... + ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_\(2  n\)\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`U\_n\)]],
  "\n      \[VerticalEllipsis]\n",
  Cell[BoxData[
      \(TraditionalForm\`Q\_n\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_n1\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`U\_1\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_n2\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`U\_2\)]],
  " + ... + ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_nn\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`U\_n\)]],
  ","
}], "NumberedEquation"],

Cell[TextData[{
  "where the ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_ij\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_ji\)]],
  "  (i\[NotEqual]j) are called '",
  StyleBox["coefficients of induction",
    FontSlant->"Italic"],
  "', ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_ii\)]],
  " is the ",
  StyleBox["capacitance",
    FontSlant->"Italic"],
  " of conductor i. \nThe values of the ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\)]],
  " are constants depending on geometry ",
  StyleBox["only",
    FontSlant->"Italic"],
  ", that means on the shapes and the arrangement of the conductors. Add"
}], "Text"],

Cell[TextData[{
  "0 = ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_i1\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`U\_i\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_i2\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`U\_i\)]],
  "+ ...+ ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_\(i, i - 1\)\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`U\_i\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_\(i, i + 1\)\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`U\_i\)]],
  " + ... + ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_in\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`U\_i\)]],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_i1\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`U\_i\)]],
  " - ... - ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_in\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`U\_i\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "to equation i of (21), and they can be reshuffled to contain  Maxwells \
'coefficients of capacity'\n (",
  StyleBox["Teilkapazit\[ADoubleDot]ten",
    FontSlant->"Italic"],
  "):"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`Q\_1\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`C\_10\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`U\_1\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`C\_12\)]],
  "*(",
  Cell[BoxData[
      \(TraditionalForm\`U\_1 - U\_2\)]],
  ") + ... + ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\(1  n\)\)]],
  "*",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            FormBox[\(U\_1\),
              "TraditionalForm"], "-", 
            FormBox[\(U\_n\),
              "TraditionalForm"]}], ")"}], TraditionalForm]]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`Q\_2\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`C\_21\)]],
  "*",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            FormBox[\(U\_2\),
              "TraditionalForm"], "-", 
            FormBox[\(U\_1\),
              "TraditionalForm"]}], ")"}], TraditionalForm]]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`C\_20\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`U\_2\)]],
  " + ... + ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\(2  n\)\)]],
  "*",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            FormBox[\(U\_2\),
              "TraditionalForm"], "-", 
            FormBox[\(U\_n\),
              "TraditionalForm"]}], ")"}], TraditionalForm]]],
  "\n      \[VerticalEllipsis]\n",
  Cell[BoxData[
      \(TraditionalForm\`Q\_n\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`C\_n1\)]],
  "*",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            FormBox[\(U\_n\),
              "TraditionalForm"], "-", 
            FormBox[\(U\_1\),
              "TraditionalForm"]}], ")"}], TraditionalForm]]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`C\_n2\)]],
  "*",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            FormBox[\(U\_n\),
              "TraditionalForm"], "-", 
            FormBox[\(U\_2\),
              "TraditionalForm"]}], ")"}], TraditionalForm]]],
  " + ... + ",
  Cell[BoxData[
      \(TraditionalForm\`C\_n0\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`U\_n\)]],
  "."
}], "NumberedEquation"],

Cell["\<\
The coefficients of capacity are connected to the coefficients of \
induction through the following equations:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`C\_i0\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(k = 1\)\%n C\&~\_ik\)]],
  "\n\n",
  Cell[BoxData[
      \(TraditionalForm\`C\_ik\)]],
  " = - ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_ik\)]],
  "         (i\[NotEqual]k). \n "
}], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`C\_i0\)]],
  " is known as 'stray capacity', the part that corresponds to the field that \
goes to the 'outside', where the fieldlines connect to the surrounding \
ground. Now the meaning of the term 'capacitance' defined above also becomes \
clear: the capacitance of conductor i is the sum of its stray capacity plus \
all its coefficients of capacity with the other conductors of the system.\n\t \
 The procedure outlined below finds the ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_ik\)]],
  " of a given configuration. We then use (24) to calculate the coefficients \
of capacity, a combination of which (according to the mode of operation) is \
to be put into (3)."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Determination of the Coefficients of Induction in a System of \
Linear Conductors\
\>", "Subsubsection"],

Cell[TextData[{
  "Consider a system of conductors within a volume V filled with dielectric \
material  (",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\_r\)]],
  "\[NotEqual]1) and/or empty space. The potential energy of the conductors, \
being fixed at certain potentials ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_i\)]],
  ", may then be written as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`W\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(i = 1\)\%n\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(j = 1\)\%n C\&~\_ij\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_i\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_j\)]],
  "."
}], "NumberedEquation"],

Cell["\<\
The induced charges will produce an electric field, whose shape is \
a consequence of the given geometry, and whose energy amounts to\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`W\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\[Integral]\_V\%\ \)\ \(\(D\)\(\ \)\)\&\
\[RightVector]\[CenterDot]E\&\[RightVector] \[DifferentialD]V\)]],
  "."
}], "NumberedEquation"],

Cell[TextData[{
  "The energy of a charged system of conductors is thus stored in the \
electric field between them. This offers a neat way to calculate the \
capacitances and coefficients of induction of the configuration from the \
electric field without quantitative information about the charge \
distribution,  \[Dash] once the field is known (",
  StyleBox["Ref. 6",
    FontWeight->"Bold"],
  ", p.53). The capacitance per unit length ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_ii'\)]],
  " of the linear conductor i pops out of (25) and (26), if we integrate over \
the plane perpendicular to the conductor the electric field corresponding to \
the boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_i\)]],
  "=1 and all other ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_k\)]],
  "= 0 :"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_ii'\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Integral]\_A\%\ \)\ \(\[Epsilon]\_r\) \(\
\[Epsilon]\_0\) \(\(E\)\(\ \)\)\&\[RightVector]\_i\[CenterDot]\(\(E\)\(\ \)\)\
\&\[RightVector]\_i \[DifferentialD]x \[DifferentialD]y\)]]
}], "NumberedEquation"],

Cell["\<\
After the capacitances the coefficients of induction may be \
obtained from\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_ij'\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  "( ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Integral]\_A\%\ \)\ \(\[Epsilon]\_r\) \(\
\[Epsilon]\_0\) \(\(E\)\(\ \)\)\&\[RightVector]\_ij\[CenterDot]\(\(E\)\(\ \
\)\)\&\[RightVector]\_ij \[DifferentialD]x \[DifferentialD]y\)]],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_ii'\)]],
  "- ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_jj'\)]],
  "),"
}], "NumberedEquation"],

Cell[TextData[{
  "by considering pairs of conductors, where the indices of ",
  Cell[BoxData[
      \(TraditionalForm\`E\&\[RightVector]\)]],
  " point to the two conductors, whose potentials are then set to 1. From \
(27) and (28) it is clear that the presence of any additional conductor will \
change the field and will consequently have an effect on every other \
capacity."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Discrete Form of Gauss's Law with Dielectrics", "Subsubsection"],

Cell["\<\
It remains to determine the electrical field. In the volume outside \
the conductors there are no free charges, here the field obeys this form of \
Gauss's Law\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\&\[RightVector]\)]],
  "\[CenterDot]",
  Cell[BoxData[
      \(TraditionalForm\`D\&\[RightVector]\)]],
  "  = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\&\[RightVector]\)]],
  "\[CenterDot]",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  Cell[BoxData[
      \(TraditionalForm\`E\&\[RightVector]\)]],
  " = 0"
}], "NumberedEquation"],

Cell[TextData[{
  "with \[Epsilon] = ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon]\_r\) \[Epsilon]\_0\)]],
  ". As the field is the negative gradient of the potential \[Phi], (29) \
reads with a space dependent ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  "(x,y)"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\&\[RightVector]\)]],
  "\[CenterDot]",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  Cell[BoxData[
      \(TraditionalForm\`E\&\[RightVector]\)]],
  " = - (",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\&\[RightVector]\)]],
  "\[Epsilon] \[CenterDot]",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\&\[RightVector]\)]],
  "\[Phi] + \[Epsilon]\[CapitalDelta]\[Phi]) = 0."
}], "NumberedEquation"],

Cell[TextData[{
  "The terms containing the first derivatives act as additional sources to \
the Laplace equation that appears \nin (30).\n\tThe potential \[Phi](x,y) is \
mapped onto a grid with ",
  Cell[BoxData[
      \(TraditionalForm\`u\_\(i, j\)\)]],
  " = \[Phi](i \[CapitalDelta]x, j \[CapitalDelta]y). In the iterative \
relaxation process used for elliptic pde's (",
  StyleBox["Ref. 3",
    FontWeight->"Bold"],
  ", p.821) the Laplace operator \[CapitalDelta] is discretized by the \
prescription that each point is updated with the average of its four \
neighbors. ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Epsilon]\_\(i, j\)\)\)\)]],
  " is either 1 (for vacuum or air) or equal to the relative dielectric \
constant of the material at the location of the corresponding grid point. \n\t\
Discretize first derivatives like (to second order for symmetry reasons, \
\[Dash] first order would be shifted to up and right) :"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_x\ f\_\(i, j\)\)]],
  " = ",
  Cell[BoxData[
      FormBox[
        FractionBox[
          RowBox[{" ", 
            FormBox[\(f\_\(i, j + 1\) - f\_\(i, j - 1\)\),
              "TraditionalForm"]}], \(2  \[CapitalDelta]\)], 
        TraditionalForm]]],
  ","
}], "NumberedEquation"],

Cell[TextData[{
  "that means, any structure, in order to be correctly included, must \
comprise at least two grid points. This is the 'resolution' of this \
simulation.\n\tThe following update procedure is applied many times to each \
grid point starting from actually any initial matrix ",
  Cell[BoxData[
      \(TraditionalForm\`u\_\(i, j\)\)]],
  ", until the result no longer changes:"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`u\_\(i, j\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_\(i + 1, j\)\  + \ u\_\(i - 1, j\)\  + \ \
u\_\(i, j + 1\)\  + \ u\_\(i, j - 1\)\)\/4\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon]\_\(i, j + 1\)\  - \ \[Epsilon]\_\(i, j \
- 1\)\)\/\(16  \[Epsilon]\_\(i, j\)\)\)]],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`u\_\(i, j + 1\) - \ u\_\(i, j - 1\)\)]],
  ") + ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon]\_\(i + 1, j\)\  - \ \[Epsilon]\_\(i - \
1, j\)\)\/\(16  \[Epsilon]\_\(i, j\)\)\)]],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`u\_\(i + 1, j\) - \ u\_\(i - 1, j\)\)]],
  ")"
}], "NumberedEquation"],

Cell[TextData[{
  "If the values at the boundaries are completely specified, a unique \
solution for u will be found slowly propagating into the plane from the fixed \
boundaries. The number of iterations and hence the calculation time is \
proportional to the difference of the arbitrary initial matrix and the final \
result. The distribution of the ",
  Cell[BoxData[
      \(TraditionalForm\`u\_\(i, j\)\)]],
  ", the relaxation converges to, is characterized by the boundary values and \
the Laplace operator, which enforces the sum of the curvatures (\[Tilde] to \
second derivative in space) in x and y direction to be zero. That means, \
either both are zero (a piece of a plane surface) or both have opposite sign \
and equal size (saddle form). The presence of dielectrics reveals itself by a \
sudden jump of the gradient to lower values (see code example below)."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Code  (Parallel Plate Capacitor)"
}], "Subsection",
  PageBreakAbove->True],

Cell["RAM requirements: Front End 10 MB, Kernel 10 MB", "Text"],

Cell["\<\
A grid of 80 x 40 points is set up. In all of the following we have \
to keep in mind, how a grid matrix is mapped onto a rectangular coordinate \
system: the column index j marks the x-axis, increasing row numbers i proceed \
in negative y-direction.
\tTwo conducting planes forming a capacitor are placed within a grounded \
rectangle, between the planes a dielectric area is defined.\
\>", "Text"],

Cell[CellGroupData[{

Cell["set up matrix:", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
m defines a matrix of operators that tell, how the point i,j on the \
grid is to be updated (32), v1 and v2 define the fixed potential on conductor \
1and 2 (the warnings on Part specification are harmless...).\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
v1=1.;v2=0.;(* potential of the electrodes 1 and 2 *)
nz=40; (* # of rows of the grid, divisible by 2 *)
ns=80; (* # of columns of the grid, divisible by 2 *)
u=.;m=.;m=Array[u,{nz,ns}];a=Array[u,{nz,ns}];
mb=Table[0,{nz},{ns}];
\[Epsilon]=Table[1,{i,1,nz},{j,1,ns}];
eps=4;
exl=20;exr=39;eyd=20;eyu=28; (* dielectric area *)
Do[Do[\[Epsilon][[i,j]]=eps,{i,eyd,eyu}],{j,exl,exr}];
Do[Do[a[[i,j]]=u[[i,j]],{j,1,ns}],{i,1,nz}]
Do[Do[
m[[i,j]]:=Evaluate[0.25(a[[i-1,j]]+a[[i,j-1]]+
a[[i+1,j]]+a[[i,j+1]])+0.0625/\[Epsilon][[i,j]]((\[Epsilon][[i,j+1]]-\
\[Epsilon][[i,j-1]])(a[[i,j+1]]-a[[i,j-1]])+(\[Epsilon][[i+1,j]]-\[Epsilon][[\
i-1,j]])(a[[i+1,j]]-a[[i-1,j]]))],
{j,2,ns-1}],{i,2,nz-1}]\
\>", "Input",
  CellLabel->"In[1]:=",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}},
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(Part::"partd" \(\(:\)\(\ \)\) 
      "Part specification \!\(u \[LeftDoubleBracket] \(\(1, 1\)\) \
\[RightDoubleBracket]\) is longer than depth of object."\)], "Message",
  CellLabel->"From In[1]:="],

Cell[BoxData[
    \(Part::"partd" \(\(:\)\(\ \)\) 
      "Part specification \!\(u \[LeftDoubleBracket] \(\(1, 1\)\) \
\[RightDoubleBracket]\) is longer than depth of object."\)], "Message",
  CellLabel->"From In[1]:="],

Cell[BoxData[
    \(Part::"partd" \(\(:\)\(\ \)\) 
      "Part specification \!\(u \[LeftDoubleBracket] \(\(1, 2\)\) \
\[RightDoubleBracket]\) is longer than depth of object."\)], "Message",
  CellLabel->"From In[1]:="],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Part :: \"partd\"\) will be suppressed during \
this calculation."\)], "Message",
  CellLabel->"From In[1]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["boundary conditions:", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[{
    \(Do[m[\([1, j]\)] := 0. , {j, 1, ns}]\), "\[IndentingNewLine]", 
    \(Do[m[\([nz, j]\)] := 0. , {j, 1, ns}]\), "\[IndentingNewLine]", 
    \(Do[m[\([i, 1]\)] := 0. , {i, 1, nz}]\), "\[IndentingNewLine]", 
    \(Do[m[\([i, ns]\)] := 0. , {i, 1, nz}]\)}], "Input",
  CellLabel->"In[11]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell["\<\
Set location of the conductors in the operator matrix, also stored \
in mask mb :\
\>", "Text"],

Cell["\<\
xl1=20;xr1=39;yd1=16;yu1=17;xl2=20;xr2=39;yd2=30;yu2=31;
Do[Do[{m[[i,j]]:=v1;mb[[i,j]]=1;},{j,xl1,xr1}],{i,yd1,yu1}]
Do[Do[{m[[i,j]]:=v2;mb[[i,j]]=1;},{j,xl2,xr2}],{i,yd2,yu2}]\
\>", "Input",
  CellLabel->"In[15]:=",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}},
  Background->GrayLevel[0.849989]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p1 = 
        ListPlot3D[\[Epsilon] - 1, ViewPoint \[Rule] {3. , 1. , 1. }, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(p2 = 
        ListPlot3D[mb, ViewPoint \[Rule] {3. , 1. , 1. }, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(Show[p1, p2, DisplayFunction \[Rule] $DisplayFunction]\)}], "Input",
  CellLabel->"In[18]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P00022A000`40O003h00OogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooj1oo`L000Yoo`@00:eoo`00ogooogooX7oo1`0027oo2000Zgoo003oOoooOonSOol2000:Ool2
0004Ool2002[Ool00?mooomooj=oo`8000Uoo`8000Ioo`800:Yoo`00ogooogooXgoo0P002Goo0P00
1Woo0P00ZWoo003oOoooOonKOol<0006Ool20008Ool2002YOol00?mooomooi]oo``000Ioo`8000Qo
o`800:Uoo`00ogooogooVgoo0P001Woo0P0000=oo`00Ool01Goo0P0027oo0P00ZGoo003oOoooOonL
Ool20005Ool20008Ool20008Ool2002YOol00?mooomooiaoo`<000Aoo`8000Qoo`8000Qoo`800:Uo
o`00ogooogooWGoo0P0017oo0P0027oo0P0027oo0P00ZGoo003oOoooOonNOol20003Ool20008Ool2
0008Ool2002YOol00?mooomooiioo`<0009oo`8000Qoo`8000Qoo`800:Uoo`00ogooogooWgoo0P00
0Woo0P002Goo0P001Woo0P00ZWoo003oOoooOonPOol200000goo00000009Ool20006Ool2002ZOol0
0?mooomooj5oo`@000Yoo`8000Aoo`800:]oo`00ogooogooXGoo10002Woo2000Zgoo003oOoooOonR
Ool3000<Ool4002]Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogoo0Woo1@003Woo1000ogooBWoo003oOoooOol9000:Ool8003oOom8Ool0
0?moooioo`@000Aoo`<000Uoo`8000Aoo`800?moodQoo`00ogoooWoo0P001goo0`001goo0P001Woo
0P00ogooAgoo003oOoooOol9Ool20007Ool20006Ool2003oOom7Ool00?mooomoo`Uoo`8000Ioo`80
00Qoo`800?moodIoo`00ogooogoo2Goo0P001Woo0P0027oo0P00ogooAWoo003oOoooOol8Ool30006
Ool20008Ool2003oOom6Ool00?mooomoo`Moo`<000Moo`8000Qoo`8009Yoo`D00:Ioo`00ogooogoo
17oo1@0027oo0P0027oo0P00Tgoo1`0017oo00<007ooOol0Y7oo003oOoooOol4Ool40009Ool20008
Ool2002<Ool7000;Ool2002UOol00?mooomoo`Moo`8000Qoo`8000Qoo`8008Eoo`L0009oo`03001o
ogoo00eoo`800:Eoo`00ogooogoo27oo0P001goo0P0027oo0P00OWoo1`002Goo00<007ooOol03Goo
00<007oo0000Y7oo003oOoooOol8Ool20008Ool20006Ool2001hOol7000@Ool00`00Oomoo`0=Ool0
0`00Ool0002TOol00?mooomoo`8000Ioo`8000Qoo`8000Ioo`80071oo`P001Moo`03001oogoo00eo
o`04001oogoo002SOol00?mooomoo`<000Aoo`<000Uoo`8000Aoo`8006Yoo`L001moo`03001oogoo
00eoo`04001oogoo002SOol00?mooomoo`5oo`P000Yoo`P006=oo`L000Ioo`03001oogoo01eoo`03
001oogoo00eoo`05001oogooOol0002ROol00?mooomoo`9oo`D000ioo`@005ioo`L000eoo`03001o
ogoo02eoo`05001oogooOol0002ROol00?mooomoog1oo`L001Aoo`03001oogoo02eoo`03001oogoo
009oo`03001oogoo09moo`00ogooogooJGoo1`00Bgoo00<007ooOol00Woo00<007ooOol0Wgoo003o
OoooOomQOol80002Ool00`00Oomoo`1=Ool00`00Oomoo`03Ool00`00Oomoo`2NOol00?moofYoo``0
00]oo`@00=Aoo`L000Yoo`03001oogoo04eoo`03001oogoo00=oo`03001oogoo09ioo`00ogooJWoo
30002Goo2000bgoo1`004Goo00<007ooOol0CWoo00<007ooOol00goo00<007ooOol0WGoo003oOom[
Ool30006Ool20009Ool20004Ool20034Ool7001GOol5000=Ool00`00Oomoo`03Ool00`00Oomoo`2M
Ool00?moofaoo`<000moo`8000Ioo`800;aoo`P005Ioo`L000A7?`03001oogoo00]oo`03001oogoo
00Aoo`03001oogoo09aoo`00ogooKGoo0`003Woo0P001Woo0P00]Goo1`001goo00<007ooOol0CGoo
1`0034Lo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol0Vgoo003oOom^Ool3000<Ool20008
Ool2002/Ool8000>Ool00`00Oomoo`18Ool50003Acl00`00Acm7?`0>Acl00`00Oomoo`09Ool00`00
Oomoo`05Ool00`00Oomoo`2KOol00?moofmoo`<000]oo`8000Qoo`800:Eoo`L001Ioo`03001oogoo
04=oo`D000Q7?`030017?dLo00I7?`D000=7?`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo
09Yoo`00ogooL7oo0`002Woo0P0027oo0P00WWoo1`00G7oo1`003TLo00<004LoAcl01@002DLo00<0
07ooOol027oo00<007ooOol01Woo00<007ooOol0VWoo003oOomaOol30009Ool20008Ool2002GOol7
0005Ool00`00Oomoo`1COol80004Acl00`00Acm7?`0>Acl3000>Acl00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`2IOol00?moog9oo`<000Qoo`8000Qoo`80091oo`L000aoo`03001oogoo04]o
o`P000e7?`030017?dLo0097?`L000A7?`030017?dLo00m7?`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo09Uoo`00ogooLgoo0P0027oo0P0027oo0P00RGoo1`004goo00<007ooOol0@goo2000
14Lo00<004LoAcl03dLo100034Lo00<004LoAcl00TLo200014Lo00<007ooOol01goo00<007ooOol0
27oo00<007ooOol0V7oo003oOomdOol20007Ool20008Ool20021Ool8001HOol8000=Acl00`00Acm7
?`02Acl80004Acl00`00Acm7?`0>Acl4000=Acl00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomo
o`2HOol00?moogAoo`8000Moo`8000Qoo`8007Yoo`L000Aoo`03001oogoo059oo`L000A7?`030017
?dLo00m7?`@000e7?`040017?dLoAcl80004Acl00`00Acm7?`0?Acl00`00Oomoo`05Ool00`00Oomo
o`09Ool00`00Oomoo`2GOol00?moof]oo`8000Moo`8000Qoo`8000Ioo`8007Aoo`L000]oo`03001o
ogoo04Yoo`P000a7?`030017?dLo0097?`P000A7?`030017?dLo00i7?`@000e7?`030017?dLo0097
?`P000A7?`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo09Moo`00ogooJgoo0`001Woo0P00
27oo0P001Woo0P00KGoo1`004Woo00<007ooOol0@Woo200014Lo00<004LoAcl03TLo10003DLo00<0
04LoAcl00TLo1`0014Lo00<004LoAcl03dLo10003DLo00<007ooOol017oo00<007ooOol02Woo00<0
07ooOol0UWoo003oOom[Ool40004Ool2000:Ool20004Ool2001WOol7000IOol00`00Oomoo`0jOol8
000=Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0?Acl4000<Acl00`00Acm7?`02Acl80004Acl0
0`00Acm7?`0>Acl00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`2FOol00?moofaoo`P000]o
o`P0061oo`L00003Ool007oo01eoo`03001oogoo03=oo`L000E7?`030017?dLo00i7?`@000a7?`03
0017?dLo0097?`P000A7?`030017?dLo00i7?`@000e7?`030017?dLo0097?`L000A7?`03001oogoo
00Aoo`03001oogoo00]oo`03001oogoo09Eoo`00ogooKWoo1@003Woo1000FWoo200027oo00<007oo
Ool0BWoo20003DLo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo10003DLo00<004LoAcl00TLo
1`0014Lo00<004LoAcl03dLo100034Lo00<007ooOol00goo00<007ooOol02goo00<007ooOol0UGoo
003oOooHOol7000@Ool00`00Oomoo`13Ool70004Acl00`00Acm7?`0?Acl4000<Acl00`00Acm7?`02
Acl70004Acl00`00Acm7?`0?Acl4000<Acl00`00Acm7?`02Acl80004Acl00`00Acm7?`0>Acl00`00
Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`2DOol00=ioo`X000]oo`@00=Uoo`L001Moo`03001o
ogoo03]oo`P000a7?`030017?dLo0097?`P000A7?`030017?dLo00i7?`@000a7?`030017?dLo0097
?`P000A7?`030017?dLo00i7?`@000e7?`030017?dLo0097?`L000A7?`03001oogoo009oo`03001o
ogoo00aoo`03001oogoo09Aoo`00gWoo2P002Goo2000d7oo1`0000=oo`00Ool0DWoo1`0014Lo00<0
04LoAcl03TLo10003DLo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo10003DLo00<004LoAcl0
0TLo1`0014Lo00<004LoAcl03dLo100034Lo00D007ooOomoo`0000moo`03001oogoo09=oo`00hWoo
0P003Goo0P0017oo0P00bGoo1`0027oo00<007ooOol0BGoo200034Lo00<004LoAcl00TLo1`0014Lo
00<004LoAcl03dLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03dLo100034Lo00<004Lo
Acl00TLo200014Lo00<004LoAcl03TLo00@007ooOol000moo`03001oogoo09=oo`00hWoo0P0037oo
0P001Woo0P00`Goo1`003Woo00<007ooOol0@Woo200014Lo00<004LoAcl03TLo100034Lo00<004Lo
Acl00TLo200014Lo00<004LoAcl03TLo100034Lo00<004LoAcl00TLo200014Lo00<004LoAcl03TLo
10003DLo00@004LoAcm7?`P000A7?`04001oogoo000@Ool00`00Oomoo`2BOol00>9oo`8000aoo`80
00Ioo`800;Uoo`P001Eoo`03001oogoo03Yoo`P000e7?`030017?dLo0097?`L000A7?`030017?dLo
00i7?`@000e7?`030017?dLo0097?`L000A7?`030017?dLo00i7?`@000e7?`030017?dLo0097?`L0
00A7?`030017?dLo00i7?`@000e7?`03001oo`00011oo`03001oogoo099oo`00hWoo0P002goo0P00
27oo0P00/Goo2000DWoo1`0014Lo00<004LoAcl03dLo100034Lo00<004LoAcl00TLo1`0014Lo00<0
04LoAcl03dLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03dLo100034Lo00<004LoAcl0
0TLo1`0014Lo00<004LoAcl03TLo00<007oo00004Goo00<007ooOol0TGoo003ROol2000;Ool20008
Ool2002ZOol70007Ool00`00Oomoo`1:Ool6000<Acl00`00Acm7?`07Acl50002Acl00`00Acm7?`0>
Acl4000<Acl00`00Acm7?`06Acl50003Acl00`00Acm7?`0>Acl4000<Acl00`00Acm7?`06Acl50003
Acl00`00Acm7?`0>Acl4000<Acl00`00Acm7?`06Acl50002Acl00`00Ool0000AOol00`00Oomoo`2A
Ool00>9oo`8000]oo`8000Qoo`800:=oo`L000ioo`03001oogoo04Eoo`D00097?`030017?dLo00i7
?`040017?dLoAcl50008Acl00`00Acm7?`06Acl50002Acl00`00Acm7?`0=Acl01000Acm7?dLo1@00
2DLo00<004LoAcl01TLo1@000TLo00<004LoAcl03DLo00@004LoAcm7?`D000Q7?`030017?dLo00I7
?`D000=7?`030017?dLo00e7?`040017?dLoAcl50008Acl2000BOol00`00Oomoo`2@Ool00>9oo`80
00]oo`8000Qoo`8009aoo`L001Eoo`03001oogoo041oo`D000Q7?`030017?dLo00Y7?`040017?dLo
Acl3000=Acl01000Acm7?dLo1@0024Lo00<004LoAcl02DLo00@004LoAcm7?`<000i7?`040017?dLo
Acl50008Acl00`00Acm7?`09Acl01000Acm7?dLo0`003TLo00<004LoAcl01@002DLo00<004LoAcl0
2DLo00@004LoAcm7?`<000e7?`03001oo`00015oo`03001oogoo091oo`00hWoo0P002goo0P0027oo
0P00UGoo1`00F7oo1`003TLo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo0`003DLo00<004Lo
Acl00TLo1`001DLo00<004LoAcl03TLo0`003DLo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo
0`003TLo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo0P004Woo00<007ooOol0Sgoo003ROol2
000;Ool20008Ool2002=Ool80005Ool00`00Oomoo`1@Ool70005Acl00`00Acm7?`0>Acl4000<Acl0
0`00Acm7?`02Acl70004Acl00`00Acm7?`0>Acl4000=Acl00`00Acm7?`02Acl70004Acl00`00Acm7
?`0>Acl4000<Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0?Acl4000<Acl00`00Acm7?`02Acl7
0004Acl2000BOol00`00Oomoo`2?Ool00>9oo`8000]oo`8000Qoo`8008Ioo`L000eoo`03001oogoo
04Uoo`L000e7?`030017?dLo0097?`L000A7?`030017?dLo00i7?`@000a7?`030017?dLo0097?`L0
00A7?`030017?dLo00m7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00i7?`@000a7?`03
0017?dLo0097?`P000A7?`030017?dLo00i7?`@000a7?`03001oogoo015oo`03001oogoo08ioo`00
hWoo0P002goo0P0027oo0P00Ogoo1`0057oo00<007ooOol0@Woo1`0014Lo00<004LoAcl03TLo1000
34Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo100034Lo00<004LoAcl00TLo200014Lo00<0
04LoAcl03TLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo10003DLo00@004LoAcm7
?`P000A7?`030017?dLo00e7?`80019oo`03001oogoo08ioo`00hWoo0P0037oo0P001Woo0P00NGoo
1`00F7oo200034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo100034Lo00<004LoAcl00TLo
1`0014Lo00<004LoAcl03TLo10003DLo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo100034Lo
00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo10003DLo00@004LoAcm7?`P000=7?`8001=oo`03
001oogoo08eoo`00hWoo0P0037oo0P001Woo0P00LWoo1`001Goo00<007ooOol0D7oo1`0014Lo00<0
04LoAcl03TLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo100034Lo00<004LoAcl0
0TLo1`001DLo00<004LoAcl03TLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo1000
34Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo10002dLo00<004Lo00004Woo00<007ooOol0
SGoo003NOol300000goo0000000=Ool20004Ool2001/Ool7000<Ool00`00Oomoo`18Ool8000<Acl0
0`00Acm7?`02Acl70004Acl00`00Acm7?`0>Acl4000<Acl00`00Acm7?`02Acl70005Acl00`00Acm7
?`0=Acl4000=Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0>Acl4000<Acl00`00Acm7?`02Acl7
0004Acl00`00Acm7?`0>Acl4000<Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0<Acl00`00Acl0
000COol00`00Oomoo`2<Ool00=ioo`H000eoo`P006Eoo`L001=oo`03001oogoo045oo`L000A7?`03
0017?dLo00i7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00i7?`@000e7?`030017?dLo
0097?`L000A7?`030017?dLo00i7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00i7?`@0
00a7?`030017?dLo0097?`L000A7?`030017?dLo00i7?`@000a7?`030017?dLo0097?`L00097?`03
0017?`0001Aoo`03001oogoo08]oo`00hGoo0`003goo1000Ggoo20006Woo00<007ooOol0>Goo2000
34Lo00<004LoAcl00TLo1`001DLo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`001DLo00<0
04LoAcl03TLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo100034Lo00<004LoAcl0
0TLo1`0014Lo00<004LoAcl03TLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo1000
2DLo00@004LoAcl001=oo`03001oogoo08]oo`00ogooD7oo1`001Woo00<007ooOol06Goo00<007oo
Ool0<Woo1`001DLo00<004LoAcl03DLo10003DLo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo
10003DLo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo100034Lo00<004LoAcl00TLo1`0014Lo
00<004LoAcl03TLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo100034Lo00<004Lo
Acl00TLo1`0014Lo00<004LoAcl02TLo00D004LoAcm7?`0001=oo`03001oogoo08Yoo`00I7oo1000
h7oo1`003Goo00<007ooOol0Agoo1`003DLo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo1000
34Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo100034Lo00<004LoAcl00TLo1`0014Lo00<0
04LoAcl03TLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo100034Lo00<004LoAcl0
0TLo1`0014Lo00<004LoAcl03TLo100034Lo00<004LoAcl00TLo20000dLo00<007ooOol04Goo00<0
07ooOol0RWoo001ROol8003GOol7000DOol00`00Oomoo`10Ool70004Acl00`00Acm7?`0>Acl4000<
Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0>Acl4000<Acl00`00Acm7?`02Acl70004Acl00`00
Acm7?`0>Acl4000<Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0>Acl4000<Acl00`00Acm7?`02
Acl70004Acl00`00Acm7?`0>Acl4000<Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0>Acl40007
Acl00`00Acm7?`02Acl00`00Oomoo`0AOol00`00Oomoo`29Ool0069oo`8000Aoo`800=1oo`L005Io
o`P000a7?`030017?dLo0097?`L000A7?`030017?dLo00i7?`@000a7?`030017?dLo0097?`L000A7
?`030017?dLo00i7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00i7?`@000a7?`030017
?dLo0097?`L000A7?`030017?dLo00i7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00i7
?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00Q7?`030017?dLo00=7?`03001oogoo011o
o`03001oogoo08Uoo`00HGoo0P001Woo0P00b7oo1`001Goo00<007ooOol0CWoo1`001DLo00<004Lo
Acl03DLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo100034Lo00<004LoAcl00TLo
1`0014Lo00<004LoAcl03TLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo100034Lo
00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo100034Lo00<004LoAcl00TLo1`0014Lo00<004Lo
Acl03TLo100034Lo00<004LoAcl00TLo1`0014Lo00<007ooOol04Goo00<007ooOol0R7oo001QOol2
0006Ool20030Ool8000<Ool00`00Oomoo`17Ool7000=Acl00`00Acm7?`02Acl70004Acl00`00Acm7
?`0=Acl4000<Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0>Acl4000<Acl00`00Acm7?`02Acl7
0004Acl00`00Acm7?`0>Acl4000<Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0>Acl4000<Acl0
0`00Acm7?`02Acl70004Acl00`00Acm7?`0>Acl4000<Acl00`00Acm7?`02Acl70004Acl00`00Acm7
?`0>Acl40005Acl00`00Acm7?`04Acl00`00Oomoo`0@Ool00`00Oomoo`28Ool0061oo`8000Qoo`80
0;Qoo`L001Aoo`03001oogoo041oo`L000A7?`030017?dLo00i7?`@000a7?`030017?dLo0097?`L0
00A7?`030017?dLo00e7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00i7?`@000a7?`03
0017?dLo0097?`L000A7?`030017?dLo00i7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo
00i7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00i7?`@000a7?`040017?dLoAcl80004
Acl00`00Acm7?`06Acl00`00Acm7?`04Acl00`00Oomoo`0AOol00`00Oomoo`27Ool0061oo`8000Qo
o`800;5oo`L005Moo`L000a7?`030017?dLo0097?`L000A7?`030017?dLo00i7?`@000a7?`030017
?dLo0097?`L000A7?`030017?dLo00e7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00i7
?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00i7?`@000a7?`030017?dLo0097?`L000A7
?`030017?dLo00i7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00e7?`@000e7?`040017
?dLoAcl70004Acl00`00Oomoo`0AOol00`00Oomoo`27Ool0061oo`8000Qoo`800:Yoo`L000Ioo`03
001oogoo04ioo`L000A7?`030017?dLo00e7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo
00i7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00e7?`@000a7?`030017?dLo0097?`L0
00A7?`030017?dLo00i7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00i7?`@000a7?`03
0017?dLo0097?`L000A7?`030017?dLo00i7?`@000a7?`040017?dLoAcl70004Acl00`00Acm7?`0>
Acl40004Acl00`00Acm7?`05Acl00`00Oomoo`0AOol00`00Oomoo`26Ool0061oo`8000Qoo`800:=o
o`L000eoo`03001oogoo04Ioo`P000a7?`030017?dLo0097?`L000A7?`030017?dLo00e7?`@000a7
?`030017?dLo0097?`L000A7?`030017?dLo00i7?`@000a7?`030017?dLo0097?`L000A7?`030017
?dLo00e7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00i7?`@000a7?`030017?dLo0097
?`L000A7?`030017?dLo00i7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00e7?`@000a7
?`030017?dLo0097?`L000A7?`030017?dLo00E7?`030017?dLo00I7?`03001oogoo011oo`03001o
ogoo08Ioo`00H7oo0P0027oo0P00W7oo1`0057oo00<007ooOol0?goo1`0014Lo00<004LoAcl03TLo
100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`0014Lo
00<004LoAcl03TLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004Lo
Acl00TLo1`0014Lo00<004LoAcl03TLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo
100034Lo00@004LoAcm7?`L000A7?`030017?dLo00i7?`@000a7?`030017?dLo0097?`L000A7?`03
001oogoo015oo`03001oogoo08Eoo`00H7oo0P0027oo0P00U7oo2000DWoo2`0034Lo00<004LoAcl0
0TLo1`001TLo00<004LoAcl034Lo100034Lo00<004LoAcl00TLo1`001DLo00<004LoAcl034Lo1000
34Lo00<004LoAcl00TLo1`001DLo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`001DLo00<0
04LoAcl034Lo100034Lo00<004LoAcl00TLo1`001DLo00<004LoAcl03DLo100034Lo00<004LoAcl0
0TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`001DLo00<004LoAcl03DLo1000
0TLo00<004LoAcl01dLo00<007ooOol047oo00<007ooOol0QGoo001POol20008Ool2002=Ool70007
Ool00`00Oomoo`16Ool:0009Acl00`00Acm7?`0<Acl4000>Acl70009Acl00`00Acm7?`0<Acl4000=
Acl70009Acl00`00Acm7?`0<Acl4000=Acl80008Acl00`00Acm7?`0=Acl4000=Acl70009Acl00`00
Acm7?`0<Acl4000=Acl80008Acl00`00Acm7?`0=Acl4000<Acl80008Acl00`00Acm7?`0=Acl4000=
Acl80007Acl00`00Acm7?`03Acl01000Acm7?`001dLo00<007ooOol047oo00<007ooOol0Q7oo001P
Ool20008Ool20026Ool7000>Ool00`00Oomoo`0oOol70004Acl00`00Acm7?`0=Acl70009Acl00`00
Acm7?`02Acl70004Acl00`00Acm7?`0>Acl70009Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0>
Acl70009Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0=Acl80008Acl00`00Acm7?`02Acl70004
Acl00`00Acm7?`0>Acl70008Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0>Acl80008Acl00`00
Acm7?`02Acl70003Acl00`00Acm7?`0>Acl80008Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0=
Acl80008Acl00`00Oomoo`0@Ool00`00Oomoo`24Ool0065oo`8000Ioo`80081oo`L001Eoo`03001o
ogoo03Qoo`L000a7?`030017?dLo0097?`L000A7?`030017?dLo00e7?`@000a7?`030017?dLo0097
?`L000A7?`030017?dLo00i7?`@000]7?`030017?dLo0097?`L000A7?`030017?dLo00i7?`@000a7
?`030017?dLo0097?`L000A7?`030017?dLo00e7?`@000a7?`030017?dLo0097?`L000A7?`030017
?dLo00e7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00i7?`@000]7?`030017?dLo0097
?`L000A7?`030017?dLo00i7?`@000a7?`040017?dLoAcl70004Acl00`00Acm7?`02Acl00`00Acm7
?`09Acl00`00Oomoo`0@Ool00`00Oomoo`23Ool0065oo`8000Ioo`8007Uoo`P004moo`L000A7?`03
0017?dLo00e7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00e7?`@000a7?`030017?dLo
0097?`L000A7?`030017?dLo00e7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00i7?`@0
00a7?`030017?dLo0097?`L000=7?`030017?dLo00i7?`@000a7?`030017?dLo0097?`L000=7?`03
0017?dLo00i7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00e7?`@000a7?`030017?dLo
0097?`L000A7?`030017?dLo00e7?`@000a7?`040017?dLoAcl80004Acl00`00Oomoo`0@Ool00`00
Oomoo`23Ool0069oo`8000Aoo`8007=oo`L000Moo`03001oogoo04Ioo`L000a7?`030017?dLo0097
?`L000A7?`030017?dLo00e7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00e7?`@000a7
?`030017?dLo0097?`L000A7?`030017?dLo00e7?`@000a7?`030017?dLo0097?`L000A7?`030017
?dLo00i7?`@000]7?`030017?dLo0097?`L000A7?`030017?dLo00i7?`@000]7?`030017?dLo0097
?`L000A7?`030017?dLo00i7?`@000a7?`030017?dLo0097?`L000=7?`030017?dLo00i7?`@000a7
?`030017?dLo0097?`L000=7?`030017?dLo00i7?`D000]7?`03001oogoo011oo`03001oogoo089o
o`00HWoo2000Jgoo20003Woo00<007ooOol0?goo1`0014Lo00<004LoAcl03DLo100034Lo00<004Lo
Acl00TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo
100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`0014Lo
00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004Lo
Acl00TLo1`0014Lo00<004LoAcl03TLo10002dLo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo
10002dLo00<004LoAcl00TLo1`0014Lo00D004LoAcm7?`0000a7?`03001oogoo00moo`03001oogoo
089oo`00I7oo1000IWoo1`005Woo00<007ooOol0>7oo1`0034Lo00<004LoAcl00TLo1`0014Lo00<0
04LoAcl03DLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl0
0TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo1000
34Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`000dLo00<0
04LoAcl03TLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl0
0TLo1`0014Lo00<004LoAcl03DLo100034Lo00D004LoAcl004Lo00L000A7?`03001oogoo011oo`03
001oogoo085oo`00agoo1`000Woo00<007ooOol067oo00<007ooOol0<Goo1`0014Lo00<004LoAcl0
3DLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`00
14Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo100034Lo00<0
04LoAcl00TLo1`000dLo00<004LoAcl03TLo100034Lo00<004LoAcl00TLo1`000dLo00<004LoAcl0
3TLo10002dLo00<004LoAcl00TLo1`0014Lo00<004LoAcl03TLo100034Lo00@004LoAcm7?`L000A7
?`030017?dLo00i7?`@000a7?`040017?dLoAcl70004Acl00`00Acm7?`0>Acl4000<Acl00`00Oomo
o`0?Ool00`00Oomoo`21Ool00<1oo`L000Uoo`03001oogoo01Qoo`03001oogoo02Yoo`L000a7?`03
0017?dLo0097?`L000A7?`030017?dLo00e7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo
00e7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00e7?`@000a7?`030017?dLo0097?`L0
00=7?`030017?dLo00i7?`@000]7?`030017?dLo0097?`L000A7?`030017?dLo00i7?`@000]7?`03
0017?dLo0097?`L000A7?`030017?dLo00e7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo
00e7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00e7?`@000a7?`030017?dLo0097?`L0
00A7?`030017?`0000e7?`03001oogoo011oo`03001oogoo081oo`00^Goo1`0047oo00<007ooOol0
?Woo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo1000
34Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`000dLo00<0
04LoAcl03TLo10002dLo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl0
0TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo1000
34Lo00<004LoAcl00TLo1`000dLo00<004LoAcl03TLo100034Lo00<004LoAcl00TLo1`000dLo00<0
04LoAcl03TLo100034Lo0P000TLo1`0014Lo00<007ooOol047oo00<007ooOol0P7oo002bOol7001A
Ool7000<Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0=Acl4000<Acl00`00Acm7?`02Acl70004
Acl00`00Acm7?`0=Acl4000<Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0>Acl4000;Acl00`00
Acm7?`02Acl70004Acl00`00Acm7?`0=Acl4000<Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0=
Acl4000<Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0>Acl4000<Acl00`00Acm7?`02Acl70003
Acl00`00Acm7?`0>Acl4000;Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0>Acl4000;Acl00`00
Acm7?`02Acl70004Acl00`00Acm7?`0=Acl4000<Acl00`00Oomoo`0@Ool00`00Oomoo`1oOol00:Yo
o`P000=oo`03001oogoo04]oo`L000A7?`030017?dLo00e7?`@000a7?`030017?dLo0097?`L000A7
?`030017?dLo00e7?`@000a7?`030017?dLo0097?`L000=7?`030017?dLo00i7?`@000]7?`030017
?dLo0097?`L000A7?`030017?dLo00e7?`@000a7?`030017?dLo0097?`L000A7?`030017?dLo00e7
?`@000a7?`030017?dLo0097?`L000=7?`030017?dLo00i7?`@000]7?`030017?dLo0097?`L000A7
?`030017?dLo00i7?`@000]7?`030017?dLo0097?`L000A7?`030017?dLo00e7?`@000a7?`030017
?dLo0097?`L000A7?`030017?dLo00e7?`@000a7?`030017?dLo0097?`L000=7?`8000m7?`03001o
ogoo00moo`03001oogoo07moo`00Xgoo1`002goo00<007ooOol0A7oo1`0034Lo00<004LoAcl00TLo
1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo10002dLo
00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`0014Lo00<004Lo
Acl03DLo100034Lo00<004LoAcl00TLo1`000dLo00<004LoAcl03TLo10002dLo00<004LoAcl00TLo
1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo100034Lo
00<004LoAcl00TLo1`000dLo00<004LoAcl03TLo100034Lo00@004LoAcm7?`L000A7?`030017?dLo
00i7?`@000]7?`030017?dLo0097?`L000A7?`03001oogoo011oo`03001oogoo07ioo`00W7oo1`00
4Woo00<007ooOol0?Goo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`0014Lo00<0
04LoAcl03DLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl034Lo100034Lo00<004LoAcl0
0TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo1000
2dLo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`0014Lo00<0
04LoAcl03DLo100034Lo00<004LoAcl00TLo1`000dLo00<004LoAcl03TLo10002dLo00<004LoAcl0
0TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl034Lo1@00
34Lo00<007ooOol03goo00<007ooOol0OWoo002EOol7001COol6000<Acl00`00Acm7?`02Acl70004
Acl00`00Acm7?`0=Acl4000<Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0=Acl4000<Acl01000
Acm7?dLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo
100034Lo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`0014Lo
00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`000dLo00<004LoAcl03TLo10002dLo00<004Lo
Acl00TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`000dLo00<004LoAcl03TLo
100034Lo00@004LoAcm7?`L000=7?`8000m7?`03001oogoo011oo`03001oogoo07eoo`00SWoo1`00
1Goo00<007ooOol0Bgoo1`0014Lo00<004LoAcl034Lo100034Lo00<004LoAcl00TLo1`0014Lo00<0
04LoAcl03DLo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo0`0034Lo00<004LoAcl0
0TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`000dLo00<004LoAcl03TLo1000
2dLo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`000dLo00<0
04LoAcl03TLo10002dLo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl0
0TLo1`000dLo00<004LoAcl03TLo10002dLo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo1000
2TLo00<004Lo000014Lo1`000dLo00<007ooOol04Goo00<007ooOol0O7oo0027Ool7000<Ool00`00
Oomoo`14Ool7000<Acl01000Acm7?dLo1`001DLo00<004LoAcl034Lo100034Lo00<004LoAcl00TLo
1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo100034Lo
00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo10002dLo00<004LoAcl00TLo1`0014Lo00<004Lo
Acl03DLo100034Lo00<004LoAcl00TLo1`000dLo00<004LoAcl03TLo10002dLo00<004LoAcl00TLo
1`0014Lo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`000dLo00<004LoAcl03TLo10002dLo
00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo100034Lo00@004LoAcm7?`L000A7?`030017?dLo
00]7?`030017?dLo00@000]7?`03001oogoo011oo`03001oogoo07aoo`00Ogoo20004goo00<007oo
Ool0?Goo1`0014Lo00<004LoAcl03DLo0`003DLo00@004LoAcm7?`L000A7?`030017?dLo00e7?`@0
00a7?`030017?dLo0097?`L000A7?`030017?dLo00e7?`@000]7?`030017?dLo0097?`L000A7?`03
0017?dLo00e7?`@000a7?`030017?dLo0097?`L000=7?`030017?dLo00e7?`@000a7?`030017?dLo
0097?`L000A7?`030017?dLo00e7?`@000]7?`030017?dLo0097?`L000A7?`030017?dLo00e7?`@0
00a7?`030017?dLo0097?`L000=7?`030017?dLo00i7?`@000]7?`030017?dLo0097?`L000A7?`03
0017?dLo00e7?`@000a7?`040017?dLoAcl70004Acl00`00Acm7?`0=Acl4000<Acl00`00Acm7?`02
Acl700001DLo0017?dLo00003dLo00<007ooOol047oo00<007ooOol0Ngoo001hOol8001@Ool:000<
Acl00`00Acm7?`02Acl70005Acl00`00Acm7?`0<Acl3000<Acl00`00Acm7?`02Acl70005Acl00`00
Acm7?`0<Acl4000<Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0<Acl4000<Acl00`00Acm7?`02
Acl70005Acl00`00Acm7?`0<Acl4000;Acl00`00Acm7?`02Acl70005Acl00`00Acm7?`0<Acl4000<
Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0<Acl4000<Acl00`00Acm7?`02Acl70004Acl00`00
Acm7?`0=Acl4000;Acl00`00Acm7?`02Acl70005Acl00`00Acm7?`0<Acl4000<Acl00`00Acm7?`02
Acl70004Acl00`00Acm7?`0<Acl4000<Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0=Acl40008
Acl01@00Acm7?dLo00000dLo1`0014Lo00<007ooOol047oo00<007ooOol0Ngoo001aOol70007Ool0
0`00Oomoo`14Ool:0008Acl2000=Acl4000=Acl70009Acl00`00Acm7?`0;Acl4000=Acl70009Acl0
0`00Acm7?`0<Acl4000<Acl70009Acl00`00Acm7?`0<Acl4000=Acl70008Acl00`00Acm7?`0<Acl4
000=Acl70008Acl00`00Acm7?`0=Acl4000<Acl70009Acl00`00Acm7?`0<Acl4000<Acl80008Acl0
0`00Acm7?`0<Acl4000=Acl70008Acl00`00Acm7?`0=Acl4000<Acl70008Acl00`00Acm7?`0=Acl4
000<Acl80007Acl00`00Acm7?`09Acl01000Acm7?dLo100034Lo00<007ooOol047oo00<007ooOol0
NWoo001ZOol7000>Ool00`00Oomoo`0mOol70004Acl00`00Acm7?`0=Acl70008Acl00`00Acm7?`02
Acl70004Acl00`00Acm7?`0=Acl70008Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0=Acl70009
Acl01000Acm7?dLo1`0014Lo00<004LoAcl03DLo1`002DLo00<004LoAcl00TLo1`000dLo00<004Lo
Acl03DLo1`002DLo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo200024Lo00<004LoAcl00TLo
1`0014Lo00<004LoAcl03DLo1`0024Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo1`0024Lo
00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo20001dLo00<004LoAcl00TLo1`0014Lo00<004Lo
Acl03DLo200024Lo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo20000dLo00<004LoAcl00TLo
00<004LoAcl00TLo1`000dLo00<007ooOol047oo00<007ooOol0NWoo001SOol7000EOol00`00Oomo
o`0fOol7000<Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0<Acl4000<Acl00`00Acm7?`02Acl7
0004Acl00`00Acm7?`0<Acl4000<Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0=Acl3000<Acl0
0`00Acm7?`02Acl70004Acl00`00Acm7?`0=Acl4000;Acl00`00Acm7?`02Acl70004Acl00`00Acm7
?`0=Acl4000;Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0=Acl4000<Acl00`00Acm7?`02Acl7
0003Acl00`00Acm7?`0=Acl4000<Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl4000<Acl0
0`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl4000<Acl00`00Acm7?`02Acl70003Acl00`00Acm7
?`0>Acl4000;Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`08Acl00`00Acm7?`03Acl4000;Acl0
0`00Oomoo`0@Ool00`00Oomoo`1iOol005aoo`L0009oo`03001oogoo04Uoo`L000E7?`030017?dLo
00a7?`@000a7?`040017?dLoAcl70005Acl00`00Acm7?`0<Acl4000<Acl01000Acm7?dLo1`001DLo
00<004LoAcl034Lo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl034Lo100034Lo00<004Lo
Acl00TLo1`000dLo00<004LoAcl03DLo100034Lo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo
100034Lo00<004LoAcl00TLo1`000dLo00<004LoAcl03TLo10002dLo00<004LoAcl00TLo1`000dLo
00<004LoAcl03TLo10002dLo00<004LoAcl00TLo1`000dLo00<004LoAcl03TLo10002dLo00<004Lo
Acl00TLo1`000dLo00<004LoAcl03TLo10002dLo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo
10002dLo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo00<007ooOol03goo00<007ooOol0NGoo
001HOol40009Ool00`00Oomoo`13Ool6000=Acl01000Acm7?dLo1`0014Lo00<004LoAcl03DLo0`00
3DLo00@004LoAcm7?`L000A7?`030017?dLo00e7?`<000e7?`040017?dLoAcl70004Acl00`00Acm7
?`0=Acl4000<Acl01000Acm7?dLo1`0014Lo00<004LoAcl03DLo10002dLo00<004LoAcl00TLo1`00
14Lo00<004LoAcl03DLo10002dLo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo10002dLo00<0
04LoAcl00TLo1`0014Lo00<004LoAcl03DLo10002dLo00<004LoAcl00TLo1`0014Lo00<004LoAcl0
3DLo10002dLo00<004LoAcl00TLo1`0014Lo00<004LoAcl03DLo10002dLo00<004LoAcl00TLo1`00
14Lo00<004LoAcl03DLo100034Lo00@004LoAcm7?`L000A7?`030017?dLo00e7?`@000E7?`030017
?dLo00A7?`040017?dLoAcl70004Acl00`00Oomoo`0@Ool00`00Oomoo`1hOol005Qoo`03001oo`00
00Uoo`03001oogoo03eoo`L000A7?`030017?dLo00e7?`<000a7?`030017?dLo0097?`L000A7?`03
0017?dLo00e7?`<000a7?`030017?dLo0097?`L000A7?`030017?dLo00e7?`<000a7?`030017?dLo
0097?`L000A7?`030017?dLo00e7?`<000a7?`030017?dLo0097?`L000A7?`030017?dLo00a7?`@0
00a7?`030017?dLo0097?`L000A7?`030017?dLo00a7?`@000a7?`030017?dLo0097?`L000=7?`03
0017?dLo00e7?`@000a7?`030017?dLo0097?`L000=7?`030017?dLo00e7?`@000a7?`030017?dLo
0097?`L000=7?`030017?dLo00e7?`@000a7?`030017?dLo0097?`L000=7?`030017?dLo00e7?`@0
00a7?`030017?dLo0097?`L000=7?`030017?dLo00e7?`@000a7?`040017?dLoAcl70004Acl00`00
Acm7?`06Acl00`00Acm7?`04Acl4000<Acl00`00Oomoo`0?Ool00`00Oomoo`1hOol0049oo`@0019o
o`04001oogoo0008Ool00`00Oomoo`0fOol7000<Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0<
Acl4000<Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0<Acl4000<Acl00`00Acm7?`02Acl70004
Acl00`00Acm7?`0<Acl4000<Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl4000<Acl01000
Acm7?dLo1`0014Lo00<004LoAcl03DLo100034Lo00@004LoAcm7?`L000A7?`030017?dLo00e7?`@0
00]7?`030017?dLo0097?`L000A7?`030017?dLo00e7?`@000]7?`030017?dLo0097?`L000A7?`03
0017?dLo00e7?`@000]7?`030017?dLo0097?`L000=7?`030017?dLo00i7?`@000]7?`030017?dLo
0097?`L000=7?`030017?dLo00i7?`@000]7?`030017?dLo0097?`L000=7?`030017?dLo00e7?`@0
00a7?`030017?dLo0097?`L000=7?`030017?dLo00e7?`03001oogoo011oo`03001oogoo07Moo`00
@7oo200047oo00@007ooOomoo`8000Ioo`03001oogoo02moo`L000E7?`030017?dLo00a7?`@000a7
?`040017?dLoAcl70005Acl00`00Acm7?`0<Acl4000<Acl01000Acm7?dLo1`0014Lo00<004LoAcl0
3DLo100034Lo00@004LoAcm7?`L000A7?`030017?dLo00e7?`@000]7?`030017?dLo0097?`L000A7
?`030017?dLo00e7?`<000a7?`030017?dLo0097?`L000A7?`030017?dLo00e7?`<000a7?`030017
?dLo0097?`L000=7?`030017?dLo00e7?`@000a7?`030017?dLo0097?`L000=7?`030017?dLo00e7
?`@000a7?`030017?dLo0097?`L000=7?`030017?dLo00e7?`@000]7?`030017?dLo0097?`L000A7
?`030017?dLo00e7?`@000]7?`030017?dLo0097?`L000A7?`030017?dLo00e7?`@000]7?`030017
?dLo0097?`L000=7?`030017?dLo00i7?`@000=7?`030017?dLo00E7?`030017?dLo0097?`L000=7
?`03001oogoo011oo`03001oogoo07Moo`00@7oo0P0017oo0P0047oo00<007ooOol00goo00<007oo
Ool0;goo1P003DLo00@004LoAcm7?`L000E7?`030017?dLo00a7?`<000e7?`040017?dLoAcl70004
Acl00`00Acm7?`0=Acl3000<Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0=Acl3000<Acl00`00
Acm7?`02Acl70004Acl00`00Acm7?`0<Acl4000<Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=
Acl4000<Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl4000;Acl00`00Acm7?`02Acl70004
Acl00`00Acm7?`0=Acl4000;Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0>Acl4000;Acl00`00
Acm7?`02Acl70003Acl00`00Acm7?`0=Acl4000<Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=
Acl4000<Acl01000Acm7?dLo1`0014Lo00<004LoAcl03DLo10002dLo00<004LoAcl00TLo1`0014Lo
00<004LoAcl014Lo00<004LoAcl01TLo10002dLo00<007ooOol047oo00<007ooOol0MWoo000oOol2
0006Ool2000?Ool00`00Ool000020002Ool00`00Oomoo`0WOol70005Acl00`00Acm7?`0<Acl3000=
Acl01000Acm7?dLo1`0014Lo00<004LoAcl03DLo0`0034Lo00<004LoAcl00TLo1`0014Lo00<004Lo
Acl034Lo100034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl034Lo100034Lo00@004LoAcm7?`L0
00A7?`030017?dLo00e7?`@000]7?`030017?dLo0097?`L000A7?`030017?dLo00e7?`@000]7?`03
0017?dLo0097?`L000=7?`030017?dLo00e7?`@000a7?`030017?dLo0097?`L000=7?`030017?dLo
00e7?`@000]7?`030017?dLo0097?`L000A7?`030017?dLo00e7?`@000]7?`030017?dLo0097?`L0
00=7?`030017?dLo00i7?`@000]7?`030017?dLo0097?`L000=7?`030017?dLo00e7?`@000a7?`03
0017?dLo0097?`L000=7?`030017?dLo00e7?`@000a7?`040017?dLoAcl70004Acl00`00Acm7?`0=
Acl00`00Oomoo`0?Ool00`00Oomoo`1fOol003moo`8000Ioo`8000ioo`<000Ioo`8001ioo`T000e7
?`040017?dLoAcl70005Acl00`00Acm7?`0<Acl3000<Acl00`00Acm7?`02Acl70005Acl00`00Acm7
?`0;Acl4000<Acl01000Acm7?dLo1`001DLo0P003DLo100034Lo00@004LoAcm7?`L000E7?`030017
?dLo00a7?`<000a7?`030017?dLo0097?`L000E7?`030017?dLo00]7?`@000a7?`030017?dLo0097
?`L000A7?`030017?dLo00a7?`@000]7?`030017?dLo0097?`L000E7?`030017?dLo00a7?`@000]7
?`030017?dLo0097?`L000A7?`030017?dLo00a7?`@000a7?`030017?dLo0097?`L000A7?`030017
?dLo00a7?`@000]7?`030017?dLo0097?`L000E7?`030017?dLo00a7?`@000]7?`030017?dLo0097
?`L000A7?`030017?dLo00e7?`@000]7?`030017?dLo0097?`L000A7?`030017?dLo00a7?`@00097
?`030017?dLo00M7?`040017?dLoAcl70004Acl00`00Oomoo`0@Ool00`00Oomoo`1eOol003ioo`80
00Qoo`8000ioo`03001oogoo00Moo`03001oogoo01Aoo`L000Q7?`030017?dLo00a7?`<000e7?`L0
00U7?`030017?dLo00]7?`@000e7?`L000Q7?`8000e7?`<000i7?`L000Q7?`030017?dLo00a7?`<0
00e7?`L000U7?`030017?dLo00]7?`@000e7?`L000Q7?`030017?dLo00a7?`@000a7?`L000U7?`03
0017?dLo00]7?`@000e7?`L000Q7?`030017?dLo00a7?`@000a7?`L000U7?`030017?dLo00a7?`@0
00a7?`L000Q7?`030017?dLo00a7?`@000e7?`L000Q7?`030017?dLo00a7?`@000a7?`P000M7?`03
0017?dLo00e7?`@000a7?`L000Q7?`030017?dLo0097?`030017?dLo00M7?`@000a7?`03001oogoo
00moo`03001oogoo07Eoo`00?Woo0P0027oo0P003Goo00<007ooOol02Goo0P005Goo00<004LoAcl0
34Lo1`002DLo00@004LoAcm7?`L000E7?`030017?dLo00a7?`L000Q7?`8000=7?`L000A7?`030017
?dLo00e7?`L000Q7?`030017?dLo0097?`L000A7?`030017?dLo00a7?`L000U7?`040017?dLoAcl7
0004Acl00`00Acm7?`0=Acl70008Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl70008Acl0
0`00Acm7?`02Acl70004Acl00`00Acm7?`0=Acl70008Acl00`00Acm7?`02Acl70003Acl00`00Acm7
?`0=Acl70008Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0=Acl70008Acl00`00Acm7?`02Acl7
0003Acl00`00Acm7?`0=Acl70008Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0=Acl70008Acl0
0`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl80007Acl00`00Acm7?`02Acl70004Acl00`00Acm7
?`0=Acl70008Acl00`00Acm7?`02Acl70003Acl00`00Oomoo`0@Ool00`00Oomoo`1dOol003ioo`80
00Qoo`8000eoo`03001oogoo00]oo`03001oogoo01=oo`040017?dLoAcl70005Acl00`00Acm7?`0<
Acl3000=Acl01000Acm7?dLo1`0014Lo00<004LoAcl03DLo0`0034Lo00<004LoAcl00TLo1`0014Lo
00<004LoAcl034Lo100034Lo00@004LoAcm7?`L000A7?`030017?dLo00e7?`<000a7?`030017?dLo
0097?`L000=7?`030017?dLo00e7?`@000]7?`030017?dLo0097?`L000A7?`030017?dLo00a7?`@0
00a7?`030017?dLo0097?`L000=7?`030017?dLo00e7?`@000]7?`030017?dLo0097?`L000A7?`03
0017?dLo00a7?`@000a7?`030017?dLo0097?`L000=7?`030017?dLo00e7?`@000]7?`030017?dLo
0097?`L000=7?`030017?dLo00e7?`@000a7?`030017?dLo0097?`L000=7?`030017?dLo00e7?`@0
00]7?`030017?dLo0097?`L000=7?`030017?dLo00e7?`@000a7?`040017?dLoAcl70004Acl00`00
Acm7?`02Acl00`00Acm7?`08Acl4000;Acl00`00Oomoo`0?Ool00`00Oomoo`1dOol003ioo`8000Qo
o`8000eoo`03001oogoo00aoo`03001oogoo01=oo`<000e7?`040017?dLoAcl70005Acl00`00Acm7
?`0<Acl3000<Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0<Acl4000<Acl01000Acm7?dLo1`00
14Lo00<004LoAcl03DLo0`0034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl034Lo10002dLo00<0
04LoAcl00TLo1`0014Lo00<004LoAcl034Lo100034Lo00@004LoAcm7?`L000A7?`030017?dLo00e7
?`@000]7?`030017?dLo0097?`L000=7?`030017?dLo00e7?`@000a7?`040017?dLoAcl70004Acl0
0`00Acm7?`0=Acl4000;Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl4000;Acl00`00Acm7
?`02Acl70003Acl00`00Acm7?`0>Acl4000;Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl4
000;Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl4000<Acl01000Acm7?dLo1`0014Lo00<0
04LoAcl03DLo00<007ooOol03goo00<007ooOol0Lgoo000nOol20008Ool2000=Ool00`00Oomoo`0=
Ool2000EOol00`00Acm7?`0<Acl3000=Acl01000Acm7?dLo1`0014Lo00<004LoAcl034Lo100034Lo
00@004LoAcm7?`L000A7?`030017?dLo00e7?`<000a7?`030017?dLo0097?`L000A7?`030017?dLo
00a7?`@000a7?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl4000<Acl01000Acm7?dLo1`0014Lo
00<004LoAcl03DLo0`0034Lo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo10002dLo00<004Lo
Acl00TLo1`0014Lo00<004LoAcl03DLo0`0034Lo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo
10002dLo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo10002dLo00<004LoAcl00TLo1`0014Lo
00<004LoAcl03DLo10002dLo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo10002dLo00<004Lo
Acl00TLo1`000dLo00<004LoAcl03DLo1@002dLo00@004LoAcm7?`L000A7?`03001oogoo00moo`03
001oogoo07=oo`00?Woo0P0027oo0P003Goo00<007ooOol03goo00<007ooOol04goo00@004LoAcm7
?`L000A7?`030017?dLo00e7?`<000a7?`040017?dLoAcl70005Acl00`00Acm7?`0<Acl3000<Acl0
0`00Acm7?`02Acl70004Acl00`00Acm7?`0<Acl4000<Acl01000Acm7?dLo1`0014Lo00<004LoAcl0
3DLo0`0034Lo00@004LoAcm7?`L000A7?`030017?dLo00e7?`<000a7?`030017?dLo0097?`L000=7
?`030017?dLo00e7?`@000]7?`030017?dLo0097?`L000A7?`030017?dLo00a7?`@000a7?`030017
?dLo0097?`L000=7?`030017?dLo00e7?`@000]7?`030017?dLo0097?`L000=7?`030017?dLo00e7
?`@000]7?`030017?dLo0097?`L000=7?`030017?dLo00e7?`@000a7?`040017?dLoAcl70004Acl0
0`00Acm7?`0=Acl4000;Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl4000;Acl00`00Acm7
?`02Acl70003Acl01@00Acm7?dLo00002dLo100034Lo00<007ooOol03goo00<007ooOol0LWoo000n
Ool20008Ool2000=Ool00`00Oomoo`0@Ool00`00Oomoo`0COol3000<Acl00`00Acm7?`02Acl70004
Acl00`00Acm7?`0<Acl3000=Acl01000Acm7?dLo1`0014Lo00<004LoAcl034Lo100034Lo00@004Lo
Acm7?`L000A7?`030017?dLo00e7?`<000a7?`030017?dLo0097?`L000=7?`030017?dLo00e7?`<0
00a7?`030017?dLo0097?`L000A7?`030017?dLo00a7?`@000]7?`030017?dLo0097?`L000A7?`03
0017?dLo00a7?`@000a7?`040017?dLoAcl70004Acl00`00Acm7?`0=Acl4000;Acl00`00Acm7?`02
Acl70003Acl00`00Acm7?`0=Acl4000;Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl4000;
Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl4000<Acl01000Acm7?dLo1`0014Lo00<004Lo
Acl03DLo10002dLo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo10002dLo00D004LoAcl004Lo
00L000=7?`030017?dLo00e7?`03001oogoo00moo`03001oogoo079oo`00?Woo0P0027oo0P003Goo
00<007ooOol04Goo0P005Goo00<004LoAcl02dLo100034Lo00@004LoAcm7?`L000E7?`8000e7?`<0
00a7?`040017?dLoAcl70005Acl2000=Acl3000<Acl00`00Acm7?`02Acl70005Acl00`00Acm7?`0;
Acl4000;Acl00`00Acm7?`02Acl70005Acl00`00Acm7?`0;Acl4000<Acl01000Acm7?dLo1`001DLo
00<004LoAcl02dLo100034Lo00@004LoAcm7?`L000E7?`030017?dLo00a7?`<000a7?`030017?dLo
0097?`L000A7?`030017?dLo00a7?`@000]7?`030017?dLo0097?`L000A7?`030017?dLo00a7?`@0
00]7?`030017?dLo0097?`L000A7?`030017?dLo00a7?`@000]7?`030017?dLo0097?`L000A7?`03
0017?dLo00a7?`@000a7?`040017?dLoAcl70004Acl00`00Acm7?`0=Acl4000;Acl00`00Acm7?`02
Acl70004Acl00`00Acm7?`0<Acl4000;Acl00`00Acm7?`02Acl70004Acl00`00Oomoo`0?Ool00`00
Oomoo`1aOol003moo`8000Ioo`8000ioo`03001oogoo01=oo`03001oogoo01=oo`L000Q7?`8000e7
?`<000i7?`L000Q7?`030017?dLo00]7?`<000i7?`L000Q7?`030017?dLo00]7?`@000e7?`L000Q7
?`030017?dLo00]7?`@000e7?`L000Q7?`030017?dLo00a7?`<000e7?`L000Q7?`030017?dLo00a7
?`<000e7?`L000Q7?`030017?dLo00a7?`@000a7?`L000Q7?`030017?dLo00a7?`@000a7?`L000Q7
?`030017?dLo00a7?`@000a7?`L000Q7?`030017?dLo00a7?`@000a7?`L000Q7?`030017?dLo00a7
?`@000a7?`P000M7?`030017?dLo00e7?`@000a7?`L000M7?`030017?`0000e7?`@000a7?`03001o
ogoo00ioo`03001oogoo075oo`00?goo0P001Woo0P003Woo00<007ooOol057oo00<007ooOol057oo
00<004LoAcl034Lo1`0024Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl034Lo1`0024Lo00<004Lo
Acl00TLo1`0014Lo00<004LoAcl034Lo1`0024Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl034Lo
1`0024Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl034Lo1`0024Lo00<004LoAcl00TLo1`0014Lo
00<004LoAcl034Lo1`0024Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl034Lo1`0024Lo00<004Lo
Acl00TLo1`000dLo00<004LoAcl03DLo1`0024Lo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo
1`0024Lo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo1`0024Lo00<004LoAcl00TLo1`000dLo
00<004LoAcl03DLo1`0024Lo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo20001dLo00<004Lo
Acl00TLo1`0014Lo00<004LoAcl034Lo20001dLo00<004LoAcl00TLo1`0014Lo00<007ooOol03goo
00<007ooOol0L7oo0010Ool20004Ool2000?Ool00`00Oomoo`0EOol2000EOol01000Acm7?dLo1`00
14Lo00<004LoAcl034Lo100034Lo00@004LoAcm7?`L000A7?`030017?dLo00a7?`@000a7?`040017
?dLoAcl70004Acl00`00Acm7?`0<Acl4000<Acl01000Acm7?dLo1`0014Lo00<004LoAcl034Lo1000
34Lo00@004LoAcm7?`L000A7?`030017?dLo00a7?`@000a7?`040017?dLoAcl70004Acl00`00Acm7
?`0<Acl4000<Acl01000Acm7?dLo1`0014Lo00<004LoAcl034Lo10002dLo00<004LoAcl00TLo1`00
14Lo00<004LoAcl034Lo10002dLo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo10002dLo00<0
04LoAcl00TLo1`000dLo00<004LoAcl03DLo10002dLo00<004LoAcl00TLo1`000dLo00<004LoAcl0
3DLo10002dLo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo100034Lo00@004LoAcm7?`L000=7
?`8000i7?`@000a7?`03001oogoo00ioo`03001oogoo071oo`00@7oo20003goo00<007ooOol05goo
00<007ooOol04goo0`0034Lo00@004LoAcm7?`L000E7?`030017?dLo00a7?`<000a7?`040017?dLo
Acl70005Acl00`00Acm7?`0<Acl3000<Acl01000Acm7?dLo1`0014Lo00<004LoAcl03DLo0`0034Lo
00@004LoAcm7?`L000A7?`030017?dLo00e7?`<000a7?`040017?dLoAcl70004Acl00`00Acm7?`0=
Acl3000<Acl01000Acm7?dLo1`0014Lo00<004LoAcl03DLo0`0034Lo00@004LoAcm7?`L000A7?`03
0017?dLo00a7?`@000a7?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl4000;Acl00`00Acm7?`02
Acl70003Acl00`00Acm7?`0=Acl4000;Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl4000;
Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl4000;Acl00`00Acm7?`02Acl70003Acl00`00
Acm7?`0=Acl4000;Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl00`00Oomoo`0?Ool00`00
Oomoo`1_Ool0049oo`@0015oo`03001oogoo01Qoo`03001oogoo01=oo`030017?dLo00a7?`<000e7
?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl3000=Acl01000Acm7?dLo1`0014Lo00<004LoAcl0
34Lo0`0034Lo00<004LoAcl00TLo1`0014Lo00<004LoAcl034Lo0`0034Lo00<004LoAcl00TLo1`00
0dLo00<004LoAcl03DLo0`0034Lo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo0`0034Lo00<0
04LoAcl00TLo1`000dLo00<004LoAcl03DLo0`0034Lo00@004LoAcm7?`L000A7?`030017?dLo00e7
?`<000a7?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl4000;Acl00`00Acm7?`02Acl70003Acl0
0`00Acm7?`0=Acl4000;Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl4000;Acl00`00Acm7
?`02Acl70003Acl00`00Acm7?`0=Acl4000;Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0<Acl5
000;Acl00`00Acm7?`02Acl70003Acl00`00Oomoo`0?Ool00`00Oomoo`1_Ool005Ioo`@001Uoo`80
01Aoo`040017?dLoAcl70005Acl00`00Acm7?`0<Acl3000<Acl01000Acm7?dLo1`001DLo00<004Lo
Acl034Lo0`0034Lo00@004LoAcm7?`L000A7?`030017?dLo00a7?`@000a7?`040017?dLoAcl70004
Acl00`00Acm7?`0<Acl4000;Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0<Acl4000;Acl00`00
Acm7?`02Acl70003Acl00`00Acm7?`0=Acl4000;Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=
Acl3000<Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl3000<Acl01000Acm7?dLo1`0014Lo
00<004LoAcl034Lo10002dLo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo10002dLo00<004Lo
Acl00TLo1`000dLo00<004LoAcl03DLo10002dLo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo
10002dLo00<004LoAcl00TLo1`000TLo0P003dLo10002dLo00<007ooOol03goo00<007ooOol0KWoo
001GOol00`00Oomoo`0KOol00`00Oomoo`0BOol3000=Acl01000Acm7?dLo1`001DLo00<004LoAcl0
2dLo0`003DLo00@004LoAcm7?`L000E7?`030017?dLo00]7?`<000a7?`040017?dLoAcl70005Acl0
0`00Acm7?`0<Acl3000<Acl01000Acm7?dLo1`001DLo00<004LoAcl02dLo100034Lo00@004LoAcm7
?`L000E7?`030017?dLo00]7?`@000]7?`030017?dLo0097?`L000E7?`030017?dLo00]7?`@000]7
?`030017?dLo0097?`L000A7?`030017?dLo00a7?`@000]7?`030017?dLo0097?`L000A7?`030017
?dLo00a7?`<000a7?`040017?dLoAcl70005Acl00`00Acm7?`0;Acl4000;Acl00`00Acm7?`02Acl7
0004Acl00`00Acm7?`0<Acl4000;Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0<Acl4000;Acl0
0`00Acm7?`02Acl70004Acl00`00Acm7?`0<Acl40009Acl00`00Acl00003Acl70004Acl00`00Acm7
?`0=Acl00`00Oomoo`0>Ool00`00Oomoo`1^Ool005Moo`03001oogoo01aoo`8001Aoo`8000e7?`<0
00e7?`L000Q7?`030017?dLo00a7?`<000e7?`L000Q7?`030017?dLo00]7?`<000e7?`L000U7?`03
0017?dLo00]7?`<000e7?`L000Q7?`030017?dLo00a7?`<000e7?`L000Q7?`030017?dLo00]7?`@0
00e7?`L000Q7?`030017?dLo00]7?`@000a7?`L000Q7?`030017?dLo00a7?`@000a7?`L000Q7?`03
0017?dLo00a7?`<000e7?`L000M7?`030017?dLo00a7?`@000a7?`L000Q7?`030017?dLo00a7?`@0
00a7?`L000Q7?`030017?dLo00a7?`@000a7?`L000M7?`030017?dLo00E7?`030017?dLo0097?`03
0017?`0000<000a7?`P000M7?`03001oogoo00moo`03001oogoo06eoo`00EWoo00<007ooOol07goo
00<007ooOol04goo1`0024Lo00@004LoAcm7?`L000A7?`030017?dLo00a7?`L000U7?`040017?dLo
Acl70004Acl00`00Acm7?`0<Acl70008Acl01000Acm7?dLo1`001DLo00<004LoAcl034Lo1`0024Lo
00@004LoAcm7?`L000A7?`030017?dLo00a7?`L000Q7?`030017?dLo0097?`L000A7?`030017?dLo
00a7?`L000Q7?`030017?dLo0097?`L000=7?`030017?dLo00e7?`L000Q7?`040017?dLoAcl70004
Acl00`00Acm7?`0<Acl70008Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl70008Acl00`00
Acm7?`02Acl70003Acl00`00Acm7?`0<Acl70008Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=
Acl70008Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl70007Acl00`00Acm7?`02Acl70004
Acl00`00Acm7?`0<Acl70005Acl01000Acm7?`0014Lo1`000dLo00<004LoAcl03DLo00<007ooOol0
3goo00<007ooOol0K7oo001FOol00`00Oomoo`0POol00`00Oomoo`0COol00`00Acm7?`0<Acl3000<
Acl01000Acm7?dLo1`001DLo00<004LoAcl034Lo0`0034Lo00@004LoAcm7?`L000A7?`030017?dLo
00a7?`<000e7?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl3000<Acl01000Acm7?dLo1`0014Lo
00<004LoAcl034Lo100034Lo00@004LoAcm7?`L000A7?`030017?dLo00a7?`@000]7?`030017?dLo
0097?`L000=7?`030017?dLo00e7?`<000a7?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl4000;
Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl4000;Acl01000Acm7?dLo1`000dLo00<004Lo
Acl03DLo10002dLo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo10002dLo00<004LoAcl00TLo
1`000dLo00<004LoAcl034Lo100034Lo00@004LoAcm7?`L000=7?`030017?dLo00U7?`040017?dLo
Acl4000;Acl00`00Acm7?`02Acl70003Acl00`00Oomoo`0?Ool00`00Oomoo`1/Ool005Ioo`03001o
ogoo025oo`8001Aoo`040017?dLoAcl70005Acl00`00Acm7?`0;Acl3000=Acl01000Acm7?dLo1`00
14Lo00<004LoAcl034Lo0`0034Lo00@004LoAcm7?`L000A7?`030017?dLo00e7?`<000a7?`040017
?dLoAcl70004Acl00`00Acm7?`0<Acl3000<Acl01000Acm7?dLo1`0014Lo00<004LoAcl03DLo0`00
34Lo00@004LoAcm7?`L000A7?`030017?dLo00a7?`@000]7?`030017?dLo0097?`L000=7?`030017
?dLo00e7?`<000a7?`040017?dLoAcl70003Acl00`00Acm7?`0=Acl4000;Acl00`00Acm7?`02Acl7
0003Acl00`00Acm7?`0=Acl3000;Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl4000;Acl0
0`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl4000;Acl01000Acm7?dLo1`000dLo00<004LoAcl0
3DLo10002dLo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo10002dLo00<007ooOol03goo00<0
07ooOol0Jgoo001FOol00`00Oomoo`0SOol00`00Oomoo`0BOol3000=Acl01000Acm7?dLo1P001DLo
00<004LoAcl034Lo0`0034Lo00@004LoAcm7?`L000A7?`030017?dLo00a7?`<000a7?`030017?dLo
0097?`L000=7?`030017?dLo00e7?`<000a7?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl3000<
Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl3000<Acl01000Acm7?dLo1`0014Lo00<004Lo
Acl034Lo10002dLo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo0`002dLo00<004LoAcl00TLo
1`000dLo00<004LoAcl03DLo10002dLo00<004LoAcl00TLo1`000dLo00<004LoAcl034Lo10002dLo
00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo10002dLo00<004LoAcl00TLo1`000dLo00<004Lo
Acl034Lo10002dLo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo10001TLo00<004LoAcl00TLo
00<004LoAcl00TLo1`000dLo00<004LoAcl034Lo00<007ooOol03goo00<007ooOol0Jgoo001FOol0
0`00Oomoo`0TOol00`00Oomoo`0COol2000=Acl3000<Acl01000Acm7?dLo1`001DLo00<004LoAcl0
2dLo0`0034Lo00@004LoAcm7?`L000E7?`030017?dLo00]7?`@000]7?`030017?dLo0097?`L000E7
?`030017?dLo00]7?`<000a7?`040017?dLoAcl70005Acl00`00Acm7?`0;Acl4000;Acl00`00Acm7
?`02Acl70004Acl00`00Acm7?`0<Acl3000<Acl01000Acm7?dLo1`001DLo00<004LoAcl02dLo1000
2dLo00<004LoAcl00TLo1`0014Lo00<004LoAcl02dLo10002dLo00<004LoAcl00TLo1`0014Lo00<0
04LoAcl034Lo10002dLo00@004LoAcm7?`L000A7?`030017?dLo00a7?`@000]7?`030017?dLo0097
?`L000A7?`030017?dLo00a7?`@000]7?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl4000;Acl0
0`00Acm7?`02Acl70003Acl00`00Acm7?`07Acl00`00Acm7?`03Acl4000;Acl01000Acm7?dLo1`00
14Lo00<007ooOol03goo00<007ooOol0JWoo001FOol00`00Oomoo`0UOol2000EOol70008Acl00`00
Acm7?`0;Acl3000=Acl70008Acl00`00Acm7?`0;Acl3000=Acl70008Acl00`00Acm7?`0;Acl4000=
Acl70008Acl00`00Acm7?`0;Acl3000=Acl70008Acl00`00Acm7?`0;Acl4000<Acl70008Acl00`00
Acm7?`0<Acl3000=Acl70007Acl00`00Acm7?`0<Acl4000<Acl70008Acl00`00Acm7?`0;Acl4000<
Acl70008Acl00`00Acm7?`0<Acl3000<Acl70008Acl00`00Acm7?`0<Acl4000<Acl70007Acl00`00
Acm7?`05Acl00`00Acm7?`04Acl4000<Acl70008Acl00`00Acm7?`0<Acl4000;Acl800000dLo0017
?`04Acl00`00Acm7?`05Acl00`00Acm7?`04Acl4000<Acl00`00Oomoo`0>Ool00`00Oomoo`1ZOol0
05Ioo`03001oogoo02Moo`03001oogoo01=oo`030017?dLo00a7?`L000Q7?`040017?dLoAcl70004
Acl00`00Acm7?`0<Acl70008Acl01000Acm7?dLo1`0014Lo00<004LoAcl034Lo1`0024Lo00<004Lo
Acl00TLo1`0014Lo00<004LoAcl034Lo1`0024Lo00@004LoAcm7?`L000A7?`030017?dLo00a7?`L0
00Q7?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl70008Acl00`00Acm7?`02Acl70003Acl00`00
Acm7?`0<Acl70008Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl70008Acl01000Acm7?dLo
1`000dLo00<004LoAcl03DLo1`0024Lo00@004LoAcm7?`L000=7?`030017?dLo00e7?`L000Q7?`03
0017?dLo0097?`L000=7?`030017?dLo00a7?`L000Q7?`030017?dLo0097?`L000=7?`030017?dLo
00e7?`L000M7?`030017?dLo0097?`L000=7?`030017?dLo00I7?`030017?dLo00A7?`L000Q7?`03
0017?dLo0097?`L000=7?`03001oogoo00moo`03001oogoo06Uoo`00EWoo00<007ooOol0:7oo00<0
07ooOol04goo00@004LoAcm7?`L000A7?`030017?dLo00a7?`<000a7?`040017?dLoAcl70004Acl0
0`00Acm7?`0<Acl3000<Acl01000Acm7?dLo1`0014Lo00<004LoAcl034Lo100034Lo00@004LoAcm7
?`L000A7?`030017?dLo00a7?`<000a7?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl3000<Acl0
1000Acm7?dLo1`0014Lo00<004LoAcl034Lo10002dLo00@004LoAcm7?`L000A7?`030017?dLo00a7
?`@000]7?`030017?dLo0097?`L000=7?`030017?dLo00e7?`<000]7?`030017?dLo0097?`L000=7
?`030017?dLo00e7?`<000]7?`030017?dLo0097?`L000=7?`030017?dLo00e7?`@000]7?`040017
?dLoAcl70003Acl00`00Acm7?`0=Acl4000;Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0<Acl4
000;Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl4000;Acl00`00Oomoo`0>Ool00`00Oomo
o`1YOol005Ioo`03001oogoo02Uoo`8001Aoo`<000a7?`040017?dLoAcl70004Acl00`00Acm7?`0<
Acl3000<Acl01000Acm7?dLo1`0014Lo00<004LoAcl034Lo0`0034Lo00@004LoAcm7?`L000A7?`03
0017?dLo00e7?`<000a7?`040017?dLoAcl70003Acl00`00Acm7?`0=Acl3000<Acl01000Acm7?dLo
1`0014Lo00<004LoAcl034Lo0`0034Lo00@004LoAcm7?`L000A7?`030017?dLo00a7?`<000a7?`04
0017?dLoAcl70004Acl00`00Acm7?`0<Acl4000;Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0<
Acl4000;Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0<Acl4000;Acl00`00Acm7?`02Acl70003
Acl00`00Acm7?`0=Acl3000;Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl4000;Acl01000
Acm7?dLo1`000dLo00<004LoAcl03DLo10000dLo00<004LoAcl01DLo00@004LoAcm7?`L000A7?`03
0017?dLo00a7?`03001oogoo00moo`03001oogoo06Qoo`00EWoo00<007ooOol0:goo00<007ooOol0
4Woo00<004LoAcl034Lo0`0034Lo00@004LoAcm7?`L000A7?`030017?dLo00a7?`<000a7?`040017
?dLoAcl70004Acl00`00Acm7?`0<Acl3000<Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl3
000;Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0=Acl3000<Acl01000Acm7?dLo1`000dLo00<0
04LoAcl03DLo0`0034Lo00@004LoAcm7?`L000=7?`030017?dLo00e7?`<000a7?`040017?dLoAcl7
0003Acl00`00Acm7?`0=Acl4000;Acl01000Acm7?dLo1`000dLo00<004LoAcl03DLo10002dLo00@0
04LoAcm7?`L000=7?`030017?dLo00e7?`@000]7?`030017?dLo0097?`L000=7?`030017?dLo00a7
?`@000]7?`030017?dLo0097?`L000=7?`030017?dLo00a7?`@000]7?`030017?dLo0097?`L000=7
?`030017?dLo00A7?`030017?dLo00E7?`@000a7?`040017?dLoAcl70003Acl00`00Oomoo`0?Ool0
0`00Oomoo`1XOol005Ioo`03001oogoo02aoo`03001oogoo019oo`040017?dLoAcl70005Acl00`00
Acm7?`0;Acl3000<Acl01000Acm7?dLo1`001DLo00<004LoAcl02dLo0`0034Lo00@004LoAcm7?`L0
00E7?`030017?dLo00]7?`@000]7?`030017?dLo0097?`L000A7?`030017?dLo00]7?`@000]7?`03
0017?dLo0097?`L000A7?`030017?dLo00a7?`<000]7?`030017?dLo0097?`L000A7?`030017?dLo
00a7?`<000]7?`030017?dLo0097?`L000A7?`030017?dLo00a7?`<000]7?`030017?dLo0097?`L0
00A7?`030017?dLo00a7?`<000]7?`030017?dLo0097?`L000A7?`030017?dLo00a7?`<000]7?`03
0017?dLo0097?`L000A7?`030017?dLo00a7?`@000]7?`040017?dLoAcl70004Acl00`00Acm7?`0<
Acl4000;Acl01000Acm7?dLo1`0014Lo00<004LoAcl034Lo10002dLo00@004LoAcm7?`L000A7?`03
0017?dLo00a7?`@000]7?`03001oogoo00moo`03001oogoo06Moo`00EWoo00<007ooOol0;Goo0P00
4goo0`003DLo1`0024Lo0P0034Lo0`003DLo1`0024Lo00<004LoAcl02dLo0`003DLo1`0024Lo00<0
04LoAcl02dLo100034Lo1`0024Lo00<004LoAcl02dLo100034Lo1`0024Lo00<004LoAcl02dLo1000
34Lo1`0024Lo00<004LoAcl02dLo100034Lo1`0024Lo00<004LoAcl02dLo100034Lo1`0024Lo00<0
04LoAcl02dLo100034Lo1`0024Lo00<004LoAcl02dLo100034Lo1`0024Lo00<004LoAcl02dLo1000
34Lo1`0024Lo00<004LoAcl02dLo100034Lo1`0024Lo00<004LoAcl02dLo10000dLo00<004LoAcl0
1TLo1`001dLo00<004LoAcl01DLo00<004LoAcl014Lo00<007ooOol03goo00<007ooOol0Igoo001E
Ool4000_Ool00`00Oomoo`0BOol20003Acl60005Acl00`00Acm7?`0<Acl60008Acl20003Acl60005
Acl00`00Acm7?`0;Acl70008Acl01000Acm7?dLo1`0014Lo00<004LoAcl034Lo1`0024Lo00@004Lo
Acm7?`L000A7?`030017?dLo00a7?`L000Q7?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl70008
Acl01000Acm7?dLo1`0014Lo00<004LoAcl034Lo1`0024Lo00@004LoAcm7?`L000A7?`030017?dLo
00a7?`L000Q7?`040017?dLoAcl70003Acl00`00Acm7?`0=Acl70008Acl01000Acm7?dLo1`000dLo
00<004LoAcl03DLo1`001dLo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo1`001dLo00<004Lo
Acl00TLo1`000dLo00<004LoAcl03DLo1`001dLo00<004LoAcl00TLo1`000dLo00<004LoAcl03DLo
1`001dLo00<004LoAcl00TLo1`000dLo00<004LoAcl034Lo1`0024Lo00<007ooOol03goo00<007oo
Ool0IWoo001FOol00`00Oomoo`0`Ool00`00Oomoo`0COol3000<Acl01000Acm7?dLo1`0014Lo00<0
04LoAcl034Lo0`0034Lo00@004LoAcm7?`H000E7?`030017?dLo00]7?`<000a7?`040017?dLoAcl7
0004Acl00`00Acm7?`0<Acl3000<Acl01000Acm7?dLo1`0014Lo00<004LoAcl034Lo0`0034Lo00@0
04LoAcm7?`L000A7?`030017?dLo00a7?`<000a7?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl3
000<Acl01000Acm7?dLo1`000dLo00<004LoAcl03DLo0`002dLo00<004LoAcl00TLo1`000dLo00<0
04LoAcl03DLo0`002dLo00<004LoAcl00TLo1`000dLo00<004LoAcl034Lo10002dLo00<004LoAcl0
0TLo1`000dLo00<004LoAcl034Lo10002dLo00<004LoAcl00TLo1`000dLo00<004LoAcl034Lo1000
2dLo00<004LoAcl00TLo1`000dLo00<004LoAcl034Lo100000=7?`00Acl024Lo00@004LoAcm7?`L0
00=7?`030017?dLo00e7?`03001oogoo00ioo`03001oogoo06Ioo`00EWoo00<007ooOol0<Goo0P00
57oo00<004LoAcl034Lo0`0034Lo00@004LoAcm7?`L000A7?`030017?dLo00a7?`<000a7?`040017
?dLoAcl60004Acl00`00Acm7?`0<Acl3000<Acl01000Acm7?dLo1`0014Lo00<004LoAcl034Lo0`00
34Lo00@004LoAcm7?`L000A7?`030017?dLo00a7?`<000a7?`040017?dLoAcl70004Acl00`00Acm7
?`0<Acl3000<Acl01000Acm7?dLo1`000dLo00<004LoAcl03DLo0`002dLo00<004LoAcl00TLo1`00
0dLo00<004LoAcl034Lo10002dLo00<004LoAcl00TLo1`000dLo00<004LoAcl034Lo10002dLo00@0
04LoAcm7?`L000=7?`030017?dLo00e7?`@000]7?`040017?dLoAcl70003Acl00`00Acm7?`0=Acl4
000;Acl01000Acm7?dLo1`000dLo00<004LoAcl03DLo10002dLo00@004LoAcm7?`L000=7?`030017
?dLo0097?`030017?dLo00M7?`@000]7?`030017?dLo0097?`L000=7?`03001oogoo00moo`03001o
ogoo06Eoo`00EGoo00<007ooOol0=7oo00<007ooOol04Woo00@004LoAcm7?`L000E7?`030017?dLo
00]7?`<000a7?`040017?dLoAcl70005Acl00`00Acm7?`0;Acl3000;Acl01000Acm7?dLo1`001DLo
00<004LoAcl02dLo0`0034Lo00@004LoAcm7?`L000E7?`030017?dLo00]7?`<000a7?`040017?dLo
Acl70005Acl00`00Acm7?`0;Acl3000<Acl01000Acm7?dLo1`0014Lo00<004LoAcl034Lo0`002dLo
00<004LoAcl00TLo1`0014Lo00<004LoAcl02dLo10002dLo00@004LoAcm7?`L000E7?`030017?dLo
00]7?`@000]7?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl3000;Acl00`00Acm7?`02Acl70004
Acl00`00Acm7?`0<Acl3000;Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0;Acl4000;Acl00`00
Acm7?`02Acl70003Acl00`00Acm7?`05Acl00`00Acm7?`04Acl4000;Acl01000Acm7?dLo1`0014Lo
00<004LoAcl034Lo10002dLo00<007ooOol03Woo00<007ooOol0IGoo001EOol00`00Oomoo`0eOol2
000COol3000=Acl70008Acl00`00Acm7?`0;Acl3000=Acl70008Acl00`00Acm7?`0:Acl3000=Acl7
0008Acl00`00Acm7?`0;Acl3000=Acl70008Acl00`00Acm7?`0;Acl3000=Acl70007Acl00`00Acm7
?`0<Acl3000<Acl70008Acl00`00Acm7?`0;Acl4000<Acl70008Acl00`00Acm7?`0;Acl3000=Acl7
0007Acl00`00Acm7?`0<Acl3000<Acl70008Acl00`00Acm7?`0;Acl4000<Acl70007Acl00`00Acm7
?`05Acl00`00Acm7?`04Acl4000<Acl70007Acl00`00Acm7?`0<Acl4000;Acl70008Acl00`00Acm7
?`0;Acl5000;Acl70007Acl00`00Acm7?`05Acl00`00Acm7?`04Acl00`00Oomoo`0?Ool00`00Oomo
o`1TOol005Eoo`03001oogoo03Moo`03001oogoo019oo`040017?dLoAcl70004Acl00`00Acm7?`0<
Acl70008Acl01000Acm7?dLo1`0014Lo00<004LoAcl034Lo1P0024Lo00@004LoAcm7?`L000A7?`03
0017?dLo00a7?`L000Q7?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl70008Acl01000Acm7?dLo
1`000dLo00<004LoAcl034Lo1`0024Lo00@004LoAcm7?`L000A7?`030017?dLo00a7?`L000Q7?`04
0017?dLoAcl70003Acl00`00Acm7?`0=Acl70007Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0<
Acl70008Acl01000Acm7?dLo1`000dLo00<004LoAcl03DLo1`001dLo00<004LoAcl00TLo1`000dLo
00<004LoAcl034Lo1`0024Lo00<004LoAcl00TLo1`000dLo00<004LoAcl034Lo1`001dLo00<004Lo
Acl00TLo1`000dLo00<004LoAcl03DLo1`001dLo00D004LoAcl004Lo00L000=7?`030017?dLo00a7
?`L000Q7?`03001oogoo00ioo`03001oogoo06Aoo`00EGoo00<007ooOol0>7oo00<007ooOol04Woo
0`0034Lo00@004LoAcm7?`L000A7?`030017?dLo00a7?`<000a7?`040017?dLoAcl70004Acl00`00
Acm7?`0;Acl3000<Acl01000Acm7?dLo1`0014Lo00<004LoAcl034Lo0`0034Lo00@004LoAcm7?`L0
00A7?`030017?dLo00a7?`<000]7?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl3000<Acl01000
Acm7?dLo1`000dLo00<004LoAcl03DLo0`002dLo00<004LoAcl00TLo1`000dLo00<004LoAcl034Lo
10002dLo00@004LoAcm7?`L000=7?`030017?dLo00e7?`<000]7?`030017?dLo0097?`L000=7?`03
0017?dLo00a7?`@000]7?`040017?dLoAcl70003Acl00`00Acm7?`0=Acl4000;Acl01000Acm7?dLo
1`000dLo00<004LoAcl034Lo10002dLo00<004LoAcl00TLo1`000dLo00<004LoAcl034Lo10002dLo
00@004LoAcm7?`L000=7?`030017?dLo00e7?`03001oogoo00ioo`03001oogoo06=oo`00EGoo00<0
07ooOol0>Goo0P0057oo0P0034Lo0`0034Lo00@004LoAcm7?`L000E7?`030017?dLo00]7?`<000a7
?`040017?dLoAcl60005Acl00`00Acm7?`0;Acl3000<Acl01000Acm7?dLo1`001DLo00<004LoAcl0
2dLo0`0034Lo00@004LoAcm7?`L000A7?`030017?dLo00]7?`<000a7?`040017?dLoAcl70005Acl0
0`00Acm7?`0;Acl3000;Acl00`00Acm7?`02Acl70004Acl00`00Acm7?`0;Acl4000;Acl01000Acm7
?dLo1`0014Lo00<004LoAcl034Lo0`002dLo00<004LoAcl00TLo1`0014Lo00<004LoAcl02dLo1000
2dLo00@004LoAcm7?`L000A7?`030017?dLo00a7?`<000]7?`030017?dLo0097?`L000A7?`030017
?dLo00]7?`@000]7?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl4000;Acl01000Acm7?dLo1`00
0dLo00<004Lo00001DLo00<004LoAcl014Lo10002dLo00<004LoAcl00TLo1`000dLo00<007ooOol0
3Woo00<007ooOol0Hgoo001EOol00`00Oomoo`0kOol00`00Oomoo`0COol60008Acl00`00Acm7?`0;
Acl3000=Acl70008Acl00`00Acm7?`0;Acl3000<Acl70008Acl00`00Acm7?`0;Acl3000=Acl70008
Acl00`00Acm7?`0;Acl3000<Acl70008Acl00`00Acm7?`0;Acl3000=Acl70007Acl00`00Acm7?`0;
Acl4000<Acl70008Acl00`00Acm7?`0;Acl3000<Acl70008Acl00`00Acm7?`0;Acl4000<Acl70007
Acl00`00Acm7?`0<Acl3000<Acl70008Acl00`00Acm7?`0;Acl4000<Acl70007Acl00`00Acm7?`0<
Acl3000<Acl70007Acl00`00Acm7?`05Acl00`00Acm7?`04Acl4000;Acl70008Acl00`00Acm7?`0<
Acl4000;Acl00`00Oomoo`0>Ool00`00Oomoo`1ROol005Eoo`03001oogoo03aoo`03001oogoo01=o
o`030017?dLo00]7?`L000Q7?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl70008Acl01000Acm7
?dLo1P0014Lo00<004LoAcl034Lo1`0024Lo00@004LoAcm7?`L000A7?`030017?dLo00a7?`L000M7
?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl70008Acl01000Acm7?dLo1`000dLo00<004LoAcl0
34Lo1`0024Lo00@004LoAcm7?`L000=7?`030017?dLo00e7?`L000M7?`040017?dLoAcl70004Acl0
0`00Acm7?`0<Acl70007Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0<Acl70008Acl01000Acm7
?dLo1`000dLo00<004LoAcl03DLo1`001dLo00<004LoAcl00TLo1`000dLo00<004LoAcl034Lo1`00
1dLo00<004LoAcl00TLo1`000dLo00<004LoAcl034Lo1`0024Lo00@004LoAcm7?`L000=7?`8000i7
?`L000M7?`030017?dLo0097?`L000=7?`03001oogoo00ioo`03001oogoo069oo`00EGoo00<007oo
Ool0?Goo0P0057oo00@004LoAcm7?`H000E7?`030017?dLo00]7?`<000a7?`040017?dLoAcl70004
Acl00`00Acm7?`0<Acl3000;Acl01000Acm7?dLo1`0014Lo00<004LoAcl034Lo0`0034Lo00@004Lo
Acm7?`L000=7?`030017?dLo00a7?`<000a7?`040017?dLoAcl70003Acl00`00Acm7?`0=Acl3000;
Acl01000Acm7?dLo1`0014Lo00<004LoAcl034Lo0`002dLo00<004LoAcl00TLo1`000dLo00<004Lo
Acl034Lo0`0034Lo00@004LoAcm7?`L000=7?`030017?dLo00a7?`@000]7?`040017?dLoAcl70003
Acl00`00Acm7?`0=Acl3000;Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0<Acl4000;Acl01000
Acm7?dLo1`000dLo00<004LoAcl034Lo10002dLo00@004LoAcm7?`L000=7?`030017?dLo00e7?`<0
00]7?`030017?dLo0097?`L000=7?`030017?dLo00a7?`@000]7?`03001oogoo00ioo`03001oogoo
065oo`00EGoo00<007ooOol0?goo00<007ooOol04Woo0`0034Lo00@004LoAcm7?`H000A7?`030017
?dLo00a7?`<000a7?`040017?dLoAcl70004Acl00`00Acm7?`0;Acl3000<Acl01000Acm7?dLo1`00
14Lo00<004LoAcl034Lo0`002dLo00@004LoAcm7?`L000A7?`030017?dLo00a7?`<000]7?`030017
?dLo0097?`L000=7?`030017?dLo00a7?`<000a7?`040017?dLoAcl70003Acl00`00Acm7?`0<Acl4
000;Acl01000Acm7?dLo1`000dLo00<004LoAcl03DLo0`002dLo00@004LoAcm7?`L000A7?`030017
?dLo00a7?`<000]7?`030017?dLo0097?`L000=7?`030017?dLo00a7?`@000]7?`040017?dLoAcl7
0003Acl00`00Acm7?`0<Acl4000;Acl01000Acm7?dLo1`000dLo00<004LoAcl03DLo0`002dLo00<0
04LoAcl00TLo1`000dLo00<004LoAcl02dLo1@002dLo00@004LoAcm7?`L000=7?`030017?dLo00a7
?`03001oogoo00ioo`03001oogoo065oo`00EGoo00<007ooOol0@7oo00<007ooOol04goo00<004Lo
Acl02dLo0`002dLo00@004LoAcm7?`L000E7?`030017?dLo00]7?`<000a7?`040017?dLoAcl60005
Acl00`00Acm7?`0;Acl3000<Acl01000Acm7?dLo1`0014Lo00<004LoAcl02dLo0`0034Lo00@004Lo
Acm7?`L000E7?`030017?dLo00Y7?`@000]7?`040017?dLoAcl70005Acl00`00Acm7?`0;Acl3000;
Acl01000Acm7?dLo1`001DLo00<004LoAcl02dLo0`002dLo00<004LoAcl00TLo1`0014Lo00<004Lo
Acl02dLo0`0034Lo00@004LoAcm7?`L000A7?`030017?dLo00]7?`@000]7?`040017?dLoAcl70004
Acl00`00Acm7?`0<Acl3000;Acl01000Acm7?dLo1`0014Lo00<004LoAcl034Lo0`002dLo00<004Lo
Acl00TLo1`000dLo00<004LoAcl01DLo00<004LoAcl014Lo10002dLo00@004LoAcm7?`L00097?`80
00M7?`030017?dLo00A7?`@000]7?`040017?dLoAcl70004Acl00`00Oomoo`0>Ool00`00Oomoo`1P
Ool005Eoo`03001oogoo045oo`8001Aoo`L000Q7?`030017?dLo00Y7?`<000e7?`L000Q7?`030017
?dLo00]7?`<000a7?`L000Q7?`030017?dLo00]7?`<000a7?`L000Q7?`030017?dLo00]7?`<000e7
?`H000Q7?`030017?dLo00]7?`<000e7?`L000M7?`030017?dLo00]7?`<000e7?`L000M7?`030017
?dLo00]7?`@000a7?`L000M7?`030017?dLo00a7?`<000a7?`L000M7?`030017?dLo00a7?`<000a7
?`L000M7?`030017?dLo00E7?`030017?dLo00A7?`<000a7?`L000M7?`030017?dLo00E7?`030017
?dLo00A7?`@000]7?`L000Q7?`030017?dLo00]7?`@000U7?`030017?`0000H000Q7?`030017?dLo
00]7?`@000a7?`03001oogoo00eoo`03001oogoo061oo`00EGoo0`00@goo00<007ooOol04Woo00<0
04LoAcl034Lo1P0024Lo0P000dLo1P0014Lo00<004LoAcl034Lo1`0024Lo00@004LoAcm7?`H000A7
?`030017?dLo00a7?`L000Q7?`040017?dLoAcl60004Acl00`00Acm7?`0<Acl70008Acl01000Acm7
?dLo1`000dLo00<004LoAcl034Lo1`0024Lo00@004LoAcm7?`L000=7?`030017?dLo00a7?`L000Q7
?`040017?dLoAcl70003Acl00`00Acm7?`0<Acl70008Acl01000Acm7?dLo1`000dLo00<004LoAcl0
34Lo1`0024Lo00@004LoAcm7?`L000=7?`030017?dLo00a7?`L000Q7?`040017?dLoAcl70003Acl0
0`00Acm7?`0<Acl70008Acl01000Acm7?dLo1`000dLo00<004LoAcl034Lo1`0024Lo00@004LoAcm7
?`L000=7?`030017?dLo00e7?`L000M7?`040017?dLoAcl7000014Lo0017?`003dLo1`001dLo00<0
04LoAcl00TLo1`000dLo00<007ooOol03Woo00<007ooOol0Ggoo001DOol20016Ool00`00Oomoo`0B
Ool01000Acm7?dLo1`0014Lo00<004LoAcl034Lo0`002dLo00@004LoAcm7?`L000A7?`030017?dLo
00a7?`<000]7?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl3000;Acl01000Acm7?dLo1`0014Lo
00<004LoAcl034Lo0`002dLo00@004LoAcm7?`L000A7?`030017?dLo00a7?`<000]7?`040017?dLo
Acl70004Acl00`00Acm7?`0<Acl3000;Acl01000Acm7?dLo1`000dLo00<004LoAcl03DLo0`002dLo
00@004LoAcm7?`L000=7?`030017?dLo00e7?`<000]7?`040017?dLoAcl70003Acl00`00Acm7?`0=
Acl3000;Acl01000Acm7?dLo1`000dLo00<004LoAcl03DLo0`002dLo00@004LoAcm7?`L000=7?`03
0017?dLo00e7?`<000]7?`030017?dLo0097?`L000=7?`030017?dLo00a7?`<000Q7?`040017?dLo
0004Acl70003Acl00`00Acm7?`0<Acl4000;Acl00`00Oomoo`0=Ool00`00Oomoo`1OOol005Eoo`03
001oogoo04Eoo`8001=oo`<000a7?`040017?dLoAcl70005Acl00`00Acm7?`0:Acl3000<Acl01000
Acm7?dLo1`001DLo00<004LoAcl02TLo0`0034Lo00@004LoAcm7?`L000A7?`030017?dLo00]7?`<0
00a7?`040017?dLoAcl70004Acl00`00Acm7?`0;Acl3000<Acl01000Acm7?dLo1`0014Lo00<004Lo
Acl02dLo0`0034Lo00@004LoAcm7?`L000A7?`030017?dLo00]7?`<000]7?`030017?dLo0097?`L0
00A7?`030017?dLo00]7?`<000]7?`030017?dLo0097?`L000A7?`030017?dLo00]7?`<000]7?`03
0017?dLo0097?`L000A7?`030017?dLo00]7?`<000]7?`030017?dLo0097?`L000=7?`030017?dLo
00E7?`030017?dLo00A7?`<000]7?`030017?dLo0097?`L000=7?`030017?dLo00E7?`030017?dLo
00A7?`@000]7?`040017?dLoAcl70003Acl00`00Acm7?`05Acl01000Acm7?`000dLo10002dLo00@0
04LoAcm7?`L000=7?`030017?dLo00E7?`030017?dLo00A7?`03001oogoo00ioo`03001oogoo05io
o`00EGoo00<007ooOol0Agoo00<007ooOol04Woo00<004LoAcl02dLo0`003DLo1P0024Lo00<004Lo
Acl02dLo0`003DLo1P0024Lo00<004LoAcl02dLo0`0034Lo1`0024Lo00<004LoAcl02dLo0`0034Lo
1`0024Lo00<004LoAcl02dLo0`0034Lo1`0024Lo00<004LoAcl02dLo0`0034Lo1`001dLo00<004Lo
Acl02dLo100034Lo1`001dLo00<004LoAcl02dLo100034Lo1`001dLo00<004LoAcl02dLo100034Lo
1`001dLo00<004LoAcl02dLo10002dLo1`0024Lo00<004LoAcl02dLo10002dLo1`001dLo00<004Lo
Acl01DLo00<004LoAcl014Lo10002dLo1`000dLo00D004LoAcm7?`0000M7?`030017?dLo00A7?`@0
00]7?`L000M7?`03001oogoo00ioo`03001oogoo05ioo`00E7oo00<007ooOol0BGoo0P004goo1`00
24Lo00@004LoAcm7?`L000A7?`030017?dLo00]7?`L000Q7?`040017?dLoAcl70003Acl00`00Acm7
?`0<Acl70008Acl01000Acm7?dLo1P0014Lo00<004LoAcl034Lo1`001dLo00@004LoAcm7?`L000A7
?`030017?dLo00a7?`L000M7?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl70007Acl01000Acm7
?dLo1`000dLo00<004LoAcl034Lo1`0024Lo00@004LoAcm7?`L000=7?`030017?dLo00a7?`L000Q7
?`040017?dLoAcl70003Acl00`00Acm7?`0<Acl70007Acl00`00Acm7?`02Acl70003Acl00`00Acm7
?`0<Acl70007Acl01000Acm7?dLo1`000dLo00<004LoAcl03DLo1`001dLo00@004LoAcm7?`L000=7
?`030017?dLo00a7?`L000Q7?`040017?dLoAcl70003Acl00`00Acm7?`07Acl00`00Acm7?`02Acl7
0007Acl00`00Acm7?`02Acl70003Acl00`00Acm7?`0<Acl00`00Oomoo`0>Ool00`00Oomoo`1MOol0
05Aoo`03001oogoo04]oo`03001oogoo019oo`030017?dLo00]7?`<000a7?`040017?dLoAcl60004
Acl00`00Acm7?`0<Acl3000;Acl01000Acm7?dLo1`0014Lo00<004LoAcl034Lo0`002dLo00@004Lo
Acm7?`L000A7?`030017?dLo00]7?`<000a7?`040017?dLoAcl70003Acl00`00Acm7?`0<Acl3000<
Acl01000Acm7?dLo1`000dLo00<004LoAcl034Lo0`002dLo00@004LoAcm7?`L000A7?`030017?dLo
00a7?`<000]7?`040017?dLoAcl70003Acl00`00Acm7?`0=Acl3000;Acl01000Acm7?dLo1`000dLo
00<004LoAcl034Lo10002dLo00@004LoAcm7?`L000=7?`030017?dLo00a7?`<000]7?`030017?dLo
0097?`L000=7?`030017?dLo00a7?`<000]7?`040017?dLoAcl70003Acl00`00Acm7?`0=Acl3000;
Acl01000Acm7?dLo1`000dLo00<004LoAcl034Lo10002dLo00@004LoAcm7?`L000=7?`03001oogoo
00moo`03001oogoo05aoo`00E7oo00<007ooOol0C7oo00<007ooOol04Woo00@004LoAcm7?`H000E7
?`030017?dLo00]7?`<000]7?`040017?dLoAcl70005Acl00`00Acm7?`0:Acl3000<Acl01000Acm7
?dLo1`0014Lo00<004LoAcl02dLo0`0034Lo00@004LoAcm7?`H000E7?`030017?dLo00]7?`<000]7
?`040017?dLoAcl70005Acl00`00Acm7?`0;Acl3000;Acl01000Acm7?dLo1`0014Lo00<004LoAcl0
2dLo0`0034Lo00@004LoAcm7?`L000A7?`030017?dLo00]7?`<000]7?`030017?dLo0097?`L000A7
?`030017?dLo00]7?`<000]7?`040017?dLoAcl70004Acl00`00Acm7?`0<Acl3000;Acl01000Acm7
?dLo1`0014Lo00<004LoAcl02dLo10002dLo00@004LoAcm7?`L000A7?`030017?dLo00]7?`<000]7
?`030017?dLo0097?`L000=7?`030017?dLo00E7?`030017?dLo00A7?`<000E7?`030017?dLo00=7
?`040017?dLoAcl70004Acl00`00Acm7?`0;Acl4000;Acl00`00Oomoo`0>Ool00`00Oomoo`1LOol0
05Aoo`03001oogoo04eoo`8001=oo`<000a7?`L000Q7?`030017?dLo00Y7?`<000e7?`H000Q7?`03
0017?dLo00]7?`<000a7?`L000Q7?`030017?dLo00]7?`<000a7?`L000Q7?`030017?dLo00Y7?`<0
00e7?`L000M7?`030017?dLo00]7?`<000a7?`L000Q7?`030017?dLo00]7?`<000a7?`L000M7?`03
0017?dLo00]7?`@000a7?`L000M7?`030017?dLo00]7?`<000a7?`L000M7?`030017?dLo00E7?`03
0017?dLo00A7?`<000a7?`L000M7?`030017?dLo00]7?`@000a7?`L000M7?`030017?dLo00]7?`@0
00]7?`L000M7?`030017?dLo00E7?`030017?dLo00A7?`<000a7?`L000M7?`030017?dLo00]7?`03
001oogoo00moo`03001oogoo05]oo`00E7oo00<007ooOol0Cgoo00<007ooOol04Woo00@004LoAcm7
?`H000A7?`030017?dLo00a7?`H000Q7?`040017?dLoAcl70004Acl00`00Acm7?`0;Acl70008Acl0
1000Acm7?dLo1P0014Lo00<004LoAcl034Lo1`001dLo00@004LoAcm7?`L000A7?`030017?dLo00a7
?`H000Q7?`040017?dLoAcl70003Acl00`00Acm7?`0<Acl70007Acl01000Acm7?dLo1`0014Lo00<0
04LoAcl034Lo1`001dLo00@004LoAcm7?`L000=7?`030017?dLo00a7?`L000M7?`030017?dLo0097
?`L000=7?`030017?dLo00a7?`L000M7?`040017?dLoAcl70003Acl00`00Acm7?`0<Acl70008Acl0
1000Acm7?dLo1`000dLo00<004LoAcl034Lo1`001dLo00<004LoAcl00TLo1`000dLo00<004LoAcl0
34Lo1`001dLo00@004LoAcm7?`L000=7?`030017?dLo00a7?`P000I7?`030017?dLo0097?`L000=7
?`030017?dLo00a7?`L000M7?`03001oogoo00ioo`03001oogoo05]oo`00E7oo00<007ooOol0D7oo
00<007ooOol04Woo0`002dLo00@004LoAcm7?`L000E7?`030017?dLo00Y7?`<000a7?`040017?dLo
Acl60005Acl00`00Acm7?`0;Acl3000;Acl01000Acm7?dLo1`001DLo00<004LoAcl02TLo0`0034Lo
00@004LoAcm7?`L000A7?`030017?dLo00]7?`<000]7?`040017?dLoAcl70005Acl00`00Acm7?`0:
Acl3000<Acl01000Acm7?dLo1`0014Lo00<004LoAcl02dLo0`002dLo00@004LoAcm7?`L000A7?`03
0017?dLo00]7?`@000]7?`040017?dLoAcl70004Acl00`00Acm7?`0;Acl3000;Acl01000Acm7?dLo
1`0014Lo00<004LoAcl034Lo0`002dLo00@004LoAcm7?`L000A7?`030017?dLo00]7?`@000]7?`04
0017?dLoAcl70003Acl00`00Acm7?`05Acl00`00Acm7?`04Acl3000;Acl01000Acm7?dLo1`0014Lo
00<004LoAcl00dLo00<004LoAcl01DLo10002dLo00@004LoAcm7?`L000=7?`030017?dLo00E7?`03
0017?dLo00A7?`03001oogoo00ioo`03001oogoo05Yoo`00E7oo00<007ooOol0DGoo0P0057oo00<0
04LoAcl02TLo0`003DLo1P0024Lo00<004LoAcl02dLo0`0034Lo1`0024Lo00<004LoAcl02TLo0`00
3DLo1P0024Lo00<004LoAcl02dLo0`0034Lo1`001dLo00<004LoAcl02dLo0`003DLo1P0024Lo00<0
04LoAcl02dLo0`0034Lo1`001dLo00<004LoAcl02dLo0`0034Lo1`0024Lo00<004LoAcl02dLo0`00
34Lo1`001dLo00<004LoAcl02dLo0`0034Lo1`001dLo00<004LoAcl01DLo00<004LoAcl014Lo0`00
34Lo1`001U7e00<005hdGS@01Uhd1TLo10002dLo1`001dLo00<004LoAcl01DLo00<004LoAcl014Lo
0`0034Lo1`001dLo00<004LoAcl02dLo10002dLo1`001dLo00<007ooOol03Woo00<007ooOol0FWoo
001DOol00`00Oomoo`1COol00`00Oomoo`0BOol60008Acl01000Acm7?dLo1`0014Lo00<004LoAcl0
2dLo1`0024Lo00@004LoAcm7?`H000A7?`030017?dLo00a7?`H000Q7?`040017?dLoAcl70003Acl0
0`00Acm7?`0<Acl70007Acl01000Acm7?dLo1`0014Lo00<004LoAcl02dLo1`0024Lo00@004LoAcm7
?`L000=7?`030017?dLo00a7?`L000M7?`040017?dLoAcl70003Acl00`00Acm7?`0<Acl70007Acl0
1000Acm7?dLo1`0014Lo00<004LoAcl034Lo1`001dLo00@004LoAcm7?`L000=7?`030017?dLo00a7
?`L000M7?`040017?dLoAcl70003Acl00`00Acm7?`0<Acl70007Acl00`00Acm7?`02Acl70003NXD0
0`00DOEAm@0:DOD00`00GSAN=00<GS@20003Acl70003Acl00`00Acm7?`0<Acl70007Acl00`00Acm7
?`02Acl70003Acl00`00Acm7?`03Acl00`00Acm7?`06Acl70007Acl01000Acm7?dLo1`000dLo00<0
04LoAcl034Lo00<007ooOol03Woo00<007ooOol0FGoo001DOol00`00Oomoo`1DOol00`00Oomoo`0B
Ool00`00Acm7?`0;Acl3000<Acl01000Acm7?dLo1P0014Lo00<004LoAcl034Lo0`002dLo00@004Lo
Acm7?`L000=7?`030017?dLo00a7?`<000]7?`040017?dLoAcl70004Acl00`00Acm7?`0;Acl3000<
Acl01000Acm7?dLo1P0014Lo00<004LoAcl034Lo0`002dLo00@004LoAcm7?`L000=7?`030017?dLo
00a7?`<000]7?`040017?dLoAcl70003Acl00`00Acm7?`0<Acl3000<Acl01000Acm7?dLo1`000dLo
00<004LoAcl034Lo0`002dLo00@004LoAcm7?`L000=7?`030017?dLo00a7?`<000]7?`040017?dLo
Acl70003Acl00`00Acm7?`0<Acl4000:NXD00`00DOEAm@0:DOD00`00GSAN=00<GS@00`00Og400002
000;Acl01000Acm7?dLo1`000dLo00<004LoAcl034Lo10002dLo00@004LoAcm7?`L000=7?`030017
?dLo00a7?`<000]7?`040017?dLoAcl70003Acl00`00Oomoo`0>Ool00`00Oomoo`1IOol005Aoo`03
001oogoo05Eoo`8001=oo`040017?dLoAcl60005Acl00`00Acm7?`0;Acl3000;Acl01000Acm7?dLo
1`001DLo00<004LoAcl02TLo0`002dLo00@004LoAcm7?`L000E7?`030017?dLo00Y7?`<000a7?`04
0017?dLoAcl60005Acl00`00Acm7?`0;Acl3000;Acl01000Acm7?dLo1`0014Lo00<004LoAcl02dLo
0`002dLo00@004LoAcm7?`L000A7?`030017?dLo00]7?`<000]7?`040017?dLoAcl70005Acl00`00
Acm7?`0;Acl3000;Acl01000Acm7?dLo1`0014Lo00<004LoAcl02dLo0`002dLo00@004LoAcm7?`L0
00A7?`030017?dLo00]7?`<000]7?`040017?dLoAcl70003GS@>NXD00`00DOEAm@0:DOD00`00GSAN
=00<GS@00`00Og400007Acl00`00Acm7?`04Acl3000;Acl01000Acm7?dLo1`0014Lo00<004LoAcl0
2dLo100000=7?`00Acl024Lo00@004LoAcm7?`L000=7?`030017?dLo00]7?`@000]7?`03001oogoo
00ioo`03001oogoo05Qoo`00E7oo00<007ooOol0Egoo00<007ooOol04Goo0`0034Lo1`0024Lo00<0
04LoAcl02TLo0`003DLo1P0024Lo00<004LoAcl02TLo0`003DLo1P0024Lo00<004LoAcl02dLo0`00
34Lo1`001dLo00<004LoAcl02dLo0`0034Lo1`001dLo00<004LoAcl02dLo0`0034Lo1`0024Lo00<0
04LoAcl02TLo0`003DLo1`001dLo00<004LoAcl02dLo0`0034Lo1`001dLo00<004LoAcl02dLo0`00
34Lo1`001dLo00<004LoAcl02dLo0`002Uhd3WZ500<0057eDOD02U7e00<005hdGS@02ehd00<007ma
Og4020001dLo00<004LoAcl01DLo00<004LoAcl014Lo0`0034Lo1`001dLo00D004LoAcm7?`0000U7
?`@000]7?`L000M7?`030017?dLo00]7?`03001oogoo00ioo`03001oogoo05Qoo`00E7oo0`00F7oo
00<007ooOol04Woo00@004LoAcm7?`H000A7?`030017?dLo00a7?`H000Q7?`040017?dLoAcl70003
Acl00`00Acm7?`0<Acl60008Acl01000Acm7?dLo1`0014Lo00<004LoAcl02dLo1`001dLo00@004Lo
Acm7?`L000A7?`030017?dLo00]7?`L000Q7?`040017?dLoAcl60004Acl00`00Acm7?`0;Acl70008
Acl01000Acm7?dLo1P0014Lo00<004LoAcl034Lo1P0024Lo00@004LoAcm7?`L000=7?`030017?dLo
00a7?`L000M7?`040017?dLoAcl70003Acl00`00Acm7?`0<Acl70007Acl01000Acm7?dLo1`000dLo
00<004LoAcl034Lo1`001U7D00<005hdGS@02ehd3GZ500<0057eDOD02U7e00<005hdGS@02ehd00<0
07maOg400P003TLo1`001dLo00<004LoAcl00TLo1`000dLo00<004LoAcl034Lo1`001TLo00<004Lo
Acl00TLo1`000dLo00<004LoAcl034Lo1`001dLo00<007ooOol03Woo00<007ooOol0Egoo001COol2
001KOol2000COol3000;Acl01000Acm7?dLo1`001DLo00<004LoAcl02TLo0`002dLo00@004LoAcm7
?`L000E7?`030017?dLo00Y7?`<000a7?`040017?dLoAcl60005Acl00`00Acm7?`0:Acl3000<Acl0
1000Acm7?dLo1P001DLo00<004LoAcl02dLo0`002dLo00@004LoAcm7?`H000E7?`030017?dLo00]7
?`<000]7?`040017?dLoAcl70004Acl00`00Acm7?`0;Acl3000;Acl01000Acm7?dLo1`0014Lo00<0
04LoAcl02dLo0`002dLo00@004LoAcm7?`L000A7?`030017?dLo00]7?`<000]7?`040017?dLoAcl7
0003DM@00`00DMAAe00:DM@00`00GSAN=00;GS@=NXD00`00DOEAm@0:DOD00`00GSAN=00;GS@01000
Og4007ma0P000dLo1`0014Lo00<004LoAcl02dLo10002dLo00@004LoAcm7?`L000=7?`040017?dLo
000:Acl4000;Acl01000Acm7?dLo1`000dLo00<004LoAcl01DLo00<004LoAcl014Lo00<007ooOol0
3Goo00<007ooOol0Egoo001DOol00`00Oomoo`1KOol00`00Oomoo`0BOol00`00Acm7?`0:Acl3000=
Acl60008Acl00`00Acm7?`0:Acl3000=Acl60008Acl00`00Acm7?`0;Acl3000<Acl60008Acl00`00
Acm7?`0;Acl3000<Acl70007Acl00`00Acm7?`0;Acl3000<Acl70007Acl00`00Acm7?`0;Acl3000<
Acl70007Acl00`00Acm7?`0;Acl3000<Acl70007Acl00`00Acm7?`0;Acl3000<Acl70007Acl00`00
Acm7?`0;Acl3000:DM@00`00DMAAe00:DM@00`00GSAN=00;GS@=NXD00`00DOEAm@0:DOD00`00GSAN
=00;GS@01P00Og4007ma001oL@<000a7?`L000M7?`030017?dLo00]7?`@000]7?`L000M7?`030017
?dLo00]7?`@000]7?`L000M7?`03001oogoo00ioo`03001oogoo05Ioo`00E7oo00<007ooOol0G7oo
0P004goo1P0024Lo00@004LoAcm7?`L000A7?`030017?dLo00]7?`H000Q7?`040017?dLoAcl70004
Acl00`00Acm7?`0;Acl70007Acl01000Acm7?dLo1`000dLo00<004LoAcl034Lo1`001dLo00@004Lo
Acm7?`L000=7?`030017?dLo00a7?`L000M7?`040017?dLoAcl70003Acl00`00Acm7?`0<Acl70007
Acl01000Acm7?dLo1`000dLo00<004LoAcl034Lo1`001dLo00@004LoAcm7?`L000=7?`030017?dLo
00a7?`L000M7?`040017?dLoAcl70003Acl00`00Acm7?`0<Acl70006DM@00`00DMAAe00:DM@00`00
DMAAe00:DM@00`00GSAN=00;GS@=NXD00`00DOEAm@0:DOD00`00GSAN=00;GS@01000Og4000000Wma
0P000dLo1`000dLo00<004LoAcl034Lo1`001dLo00@004LoAcm7?`L000=7?`030017?`0000a7?`L0
00M7?`040017?dLoAcl70003Acl00`00Acm7?`0<Acl00`00Oomoo`0=Ool00`00Oomoo`1FOol005=o
o`03001oogoo05moo`03001oogoo015oo`030017?dLo00]7?`<000a7?`040017?dLoAcl60004Acl0
0`00Acm7?`0;Acl3000<Acl01000Acm7?dLo1P0014Lo00<004LoAcl02dLo0`002dLo00@004LoAcm7
?`L000A7?`030017?dLo00]7?`<000]7?`040017?dLoAcl70003Acl00`00Acm7?`0<Acl3000;Acl0
1000Acm7?dLo1`000dLo00<004LoAcl034Lo0`002dLo00@004LoAcm7?`L000=7?`030017?dLo00a7
?`<000]7?`040017?dLoAcl70003Acl00`00Acm7?`0<Acl3000;Acl01000Acm7?dLo1`000e7D00<0
057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<005hdGS@035hd37Z500<0057eDOD02e7e
00<005hdGS@02Uhd00@007ma0000009oL@03001oL@00008000]7?`040017?dLoAcl70003Acl00`00
Acm7?`0<Acl3000;Acl20002Acl70003Acl00`00Acm7?`0<Acl3000;Acl01000Acm7?dLo1`000dLo
00<007ooOol03Woo00<007ooOol0EGoo001COol00`00Oomoo`1POol00`00Oomoo`0AOol01000Acm7
?dLo1P001DLo00<004LoAcl02dLo0`002dLo00@004LoAcm7?`H000E7?`030017?dLo00]7?`<000]7
?`040017?dLoAcl60005Acl00`00Acm7?`0:Acl3000<Acl01000Acm7?dLo1P001DLo00<004LoAcl0
2TLo0`002dLo00@004LoAcm7?`L000E7?`030017?dLo00Y7?`<000]7?`040017?dLoAcl70004Acl0
0`00Acm7?`0;Acl3000;Acl01000Acm7?dLo1`0014Lo00<004LoAcl02dLo0`002dLo00@004LoAcm7
?`L000A7?`030017?dLo00]7?`<000YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YA
e003001N=5hd00aN=0ajQ@03001AmE7e00]Am@03001N=5hd00YN=004001oL@000002Og400`00Og40
0007Acl00`00Acm7?`04Acl3000;Acl01000Acm7?dLo1`000dLo00<004LoAcl02dLo10002dLo00@0
04LoAcm7?`L000=7?`030017?dLo00]7?`@000]7?`03001oogoo00eoo`03001oogoo05Eoo`00Dgoo
00<007ooOol0HGoo0P004Woo0`0034Lo1`0024Lo00<004LoAcl02TLo0`0034Lo1`001dLo00<004Lo
Acl02dLo0`0034Lo1P0024Lo00<004LoAcl02dLo0`0034Lo1P0024Lo00<004LoAcl02TLo0`003DLo
1P0024Lo00<004LoAcl02TLo0`0034Lo1`001dLo00<004LoAcl02dLo0`0034Lo1`001dLo00<004Lo
Acl02dLo0`0034Lo1`001U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057D
DM@02U7D00<005hdGS@035hd37Z500<0057eDOD02e7e00<005hdGS@02Ehd00<007maOg400P0000Ao
L@00Og5oL@P000M7?`030017?dLo00]7?`@000]7?`L000M7?`030017?dLo00]7?`@000]7?`L000M7
?`030017?dLo00]7?`03001oogoo00ioo`03001oogoo05Aoo`00Dgoo00<007ooOol0Hgoo00<007oo
Ool04Goo00@004LoAcm7?`H000A7?`030017?dLo00a7?`H000Q7?`040017?dLoAcl60004Acl00`00
Acm7?`0;Acl70008Acl01000Acm7?dLo1P0014Lo00<004LoAcl02dLo1`001dLo00@004LoAcm7?`L0
00=7?`030017?dLo00a7?`H000Q7?`040017?dLoAcl70003Acl00`00Acm7?`0<Acl60008Acl01000
Acm7?dLo1P0014Lo00<004LoAcl02dLo1`001dLo00@004LoAcm7?`L000=7?`030017?dLo00a7?`L0
00M7?`040017?dLoAcl70003DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00
DMAAe00:DM@00`00DMAAe00:DM@00`00GSAN=00<GS@<NXD00`00DOEAm@0;DOD00`00GSAN=009GS@0
1`00Og4007ma001oL@00009oL@8000i7?`L000M7?`040017?dLoAcl70003Acl00`00Acm7?`0;Acl8
0007Acl01000Acm7?dLo1`000dLo00<004LoAcl034Lo1`001TLo00<007ooOol03Woo00<007ooOol0
E7oo001COol00`00Oomoo`1TOol00`00Oomoo`0AOol3000;Acl01000Acm7?dLo1`001DLo00<004Lo
Acl02TLo0`002dLo00@004LoAcm7?`H000E7?`030017?dLo00]7?`<000]7?`040017?dLoAcl60005
Acl00`00Acm7?`0:Acl3000;Acl01000Acm7?dLo1`0014Lo00<004LoAcl02dLo0`002dLo00@004Lo
Acm7?`L000A7?`030017?dLo00]7?`<000]7?`040017?dLoAcl60005Acl00`00Acm7?`0:Acl3000;
Acl01000Acm7?dLo1`0014Lo00<004LoAcl02dLo0`002U7D00<0057DDM@02U7D00<0057DDM@02U7D
00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<005hdGS@035hd00<007Z5NXD02WZ5
00<0057eDOD02U7e00<005hdGS@02Ehd00X007ma001oL@00Og4007ma001oL@8000=7?`L000A7?`03
0017?dLo00]7?`<000]7?`040017?dLoAcl70002Acl20007Acl00`00Acm7?`04Acl3000;Acl01000
Acm7?dLo1`000dLo00<004LoAcl02dLo00<007ooOol03Woo00<007ooOol0Dgoo001COol00`00Oomo
o`1UOol2000COol00`00Acm7?`0:Acl3000=Acl60008Acl00`00Acm7?`0:Acl3000<Acl70007Acl0
0`00Acm7?`0;Acl3000<Acl60008Acl00`00Acm7?`0:Acl3000<Acl70007Acl00`00Acm7?`0;Acl3
000<Acl70007Acl00`00Acm7?`0;Acl3000<Acl60008Acl00`00Acm7?`0:Acl3000<Acl70006DM@0
0`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@0
0`00DMAAe00:DM@00`00GSAN=00<GS@00`00NXEjQ@0:NXD00`00DOEAm@0:DOD00`00GSAN=009GS@0
3000Og4007ma001oL@00Og4007ma001oL@<000a7?`L000I7?`030017?dLo00E7?`030017?dLo00A7
?`<000U7?`030017?`0000H000M7?`030017?dLo00]7?`@000]7?`L000I7?`03001oogoo00ioo`03
001oogoo05=oo`00Dgoo00<007ooOol0Igoo00<007ooOol04Goo1P0024Lo00@004LoAcm7?`L000=7
?`030017?dLo00a7?`H000Q7?`040017?dLoAcl60004Acl00`00Acm7?`0;Acl70007Acl01000Acm7
?dLo1`000dLo00<004LoAcl034Lo1P0024Lo00@004LoAcm7?`H000A7?`030017?dLo00]7?`L000M7
?`040017?dLoAcl70003Acl00`00Acm7?`0<Acl70007Acl01000Acm7?dLo1`000dLo00<004LoAcl0
34Lo1P001dLo00@004LoAcm7?`L000=Ae003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YA
e003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001N=5hd00aN
=003001jQGZ500YjQ@03001AmE7e00YAm@03001N=5hd00UN=004001oL@000002Og401000Og400000
0Wma00<004LoAcl00TLo1`000dLo00<004LoAcl02dLo1`001dLo00@004LoAcm7?`L00004Acl004Lo
000>Acl70007Acl01000Acm7?dLo1`000dLo00<004LoAcl02dLo00<007ooOol03Woo00<007ooOol0
DWoo001COol00`00Oomoo`1XOol00`00Oomoo`0BOol00`00Acm7?`0:Acl3000;Acl01000Acm7?dLo
1`001DLo00<004LoAcl02TLo0`002dLo00@004LoAcm7?`H000E7?`030017?dLo00Y7?`<000]7?`04
0017?dLoAcl70004Acl00`00Acm7?`0;Acl3000;Acl01000Acm7?dLo1P001DLo00<004LoAcl02TLo
0`002dLo00@004LoAcm7?`L000A7?`030017?dLo00]7?`<000]7?`040017?dLoAcl70004Acl00`00
Acm7?`0:Acl3000:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:
DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00GSAN=00<GS@00`00NXEjQ@0:
NXD00`00DOEAm@0:DOD00`00GSAN=009GS@01000Og4000000Wma00@007ma0000009oL@D000]7?`03
0017?dLo00L000A7?`030017?dLo00]7?`<000Q7?`040017?dLo0003Acl70003Acl00`00Acm7?`05
Acl00`00Acm7?`04Acl3000;Acl00`00Acm7?`070004Acl00`00Oomoo`0=Ool00`00Oomoo`1BOol0
03Yoo`X000moo`03001oogoo06Uoo`8001=oo`H000Q7?`030017?dLo00Y7?`<000e7?`H000Q7?`03
0017?dLo00Y7?`<000a7?`H000Q7?`030017?dLo00Y7?`<000a7?`L000M7?`030017?dLo00]7?`<0
00a7?`H000Q7?`030017?dLo00Y7?`<000a7?`L000M7?`030017?dLo00]7?`<000a7?`H000Ink@03
001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003
001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001N=5hd00]N=003001o;Wl^00]jQ@03
001AmE7e00YAm@03001N=5hd00QN=003001oLGma0080009oL@04001oL@000002Og43000=Acl3000<
Acl70006Acl00`00Acm7?`05Acl01000Acm7?`000dLo0`002dLo1`001dLo00<004LoAcl02dLo0`00
34Lo00<007ooOol03Goo00<007ooOol0DGoo000jOol:000?Ool00`00Oomoo`1[Ool00`00Oomoo`0A
Ool00`00Acm7?`0;Acl60008Acl01000Acm7?dLo1`000dLo00<004LoAcl034Lo1P0024Lo00@004Lo
Acm7?`H000A7?`030017?dLo00]7?`H000Q7?`040017?dLoAcl60004Acl00`00Acm7?`0;Acl70007
Acl01000Acm7?dLo1`000dLo00<004LoAcl034Lo1P0024Lo00@004LoAcm7?`H000A7?`030017?dLo
00]7?`L000M7?`040017?dLoAcl70003Acl<O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAA
e00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAA
e00:DM@00`00GSAN=00;GS@00`00Obio;P0;NXD00`00DOEAm@0:DOD00`00GSAN=008GS@01`00Og40
07ma001oL@00009oL@800005Og4007ma001oL@070007Acl01000Acm7?dLo1`000dLo00<004LoAcl0
2dLo1`000dLo00D004LoAcm7?`0000=7?`L000=7?`030017?dLo00a7?`L000I7?`030017?dLo0097
?`L000=7?`03001oogoo00eoo`03001oogoo055oo`00?Woo0P004goo00<007ooOol0K7oo00<007oo
Ool04Goo00@004LoAcm7?`H000E7?`030017?dLo00Y7?`<000]7?`040017?dLoAcl70004Acl00`00
Acm7?`0;Acl3000;Acl01000Acm7?dLo1P001DLo00<004LoAcl02TLo0`002dLo00@004LoAcm7?`H0
00E7?`030017?dLo00Y7?`<000]7?`040017?dLoAcl70004Acl00`00Acm7?`0;Acl3000;Acl01000
Acm7?dLo1P0014Lo00<004LoAcl02dLo0`002TLo37k]00<0057DDM@02U7D00<0057DDM@02U7D00<0
057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0
057DDM@02U7D00<005hdGS@02ehd00<007l^Obh02gZ500<0057eDOD02U7e00<005hdGS@025hd0100
07ma001oL@00Og4007ma001oL@00Og4007ma001oL@8000e7?`<000]7?`030017?dLo00L000A7?`03
0017?dLo00I7?`030017?dLo0097?`<000]7?`040017?dLoAcl70003Acl00`00Acm7?`0;Acl4000;
Acl00`00Oomoo`0=Ool00`00Oomoo`1@Ool003ioo`80019oo`H006]oo`80019oo`<000a7?`H000Q7
?`030017?dLo00Y7?`<000a7?`L000M7?`030017?dLo00]7?`<000a7?`H000Q7?`030017?dLo00Y7
?`<000a7?`H000Q7?`030017?dLo00Y7?`<000a7?`L000M7?`030017?dLo00]7?`<000]7?`L000M7
?`030017?dLo00U7?`ank@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D
00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001N=5hd
00]N=003001o;P0000]jQ@03001AmE7e00YAm@03001N=5hd00QN=00<001oL@00Og4007ma001oL@00
Og4007ma0P000Wma00<007ma00001P001TLo00<004LoAcl02dLo0`0034Lo1`0000=7?`00Acl00dLo
00<004LoAcl01DLo00<004LoAcl014Lo0`002dLo1`001dLo00<004LoAcl02dLo00<007ooOol03Goo
00<007ooOol0D7oo000nOol2000COol00`00Oomoo`1_Ool00`00Oomoo`0AOol01000Acm7?dLo1P00
1DLo00<004LoAcl02TLo1P0024Lo00@004LoAcm7?`H000E7?`030017?dLo00Y7?`L000M7?`040017
?dLoAcl70004Acl00`00Acm7?`0;Acl60008Acl01000Acm7?dLo1P0014Lo00<004LoAcl02dLo1P00
24Lo00@004LoAcm7?`H000E7?`030017?dLo00Y7?`L000M7?`040017?dLoAcl60003DOD00`00GSEN
=@06GSD6Acl70004Acl<O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAA
e00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00GSAN
=00;GS@00`00Obh0000;NXD00`00DOEAm@0:DOD00`00GSAN=008GS@01000Og4000000Wma00H007ma
001oL@00Og420002Og400`00Og40000=Acl70007Acl01000Acm7?dLo1`000dLo00<004LoAcl01DLo
00<004LoAcl00dLo1`001dLo00@004LoAcm7?`L000=7?`030017?dLo00E7?`030017?dLo00A7?`L0
00I7?`03001oogoo00ioo`03001oogoo04moo`00?Woo0P004goo00<007ooOol0L7oo0P004Woo0`00
34Lo1P0024Lo00<004LoAcl02TLo0`0034Lo1P0024Lo00<004LoAcl02TLo0`0034Lo1`001dLo00<0
04LoAcl02dLo0`002dLo1`001dLo00<004LoAcl02dLo0`0034Lo1P001dLo00<004LoAcl02dLo0`00
2E7e00<005heGSD035he0P002DLo37k]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D
00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D
00<005hdGS@02ehd00@007l^001o;PYjQ@03001AmE7e00YAm@03001N=5hd00QN=004001oL@000002
Og401000Og4000000Wma0P0000AoL@00Og5oL@P000M7?`030017?dLo00]7?`<000]7?`P000I7?`03
0017?dLo00]7?`<000]7?`L000M7?`030017?dLo00]7?`03001oogoo00eoo`03001oogoo04moo`00
?Woo0P004goo00<007ooOol0LWoo00<007ooOol04Goo00@004LoAcm7?`H000A7?`030017?dLo00]7
?`H000Q7?`040017?dLoAcl60004Acl00`00Acm7?`0;Acl60008Acl01000Acm7?dLo1P0014Lo00<0
04LoAcl02dLo1`001dLo00@004LoAcm7?`H000A7?`030017?dLo00]7?`L000M7?`040017?dLoAcl7
0003Acl00`00Acm7?`0;Acl70006OZX00`00DOEAm@09DOD00`00GSEN=@0<GSD00`00Oe<000060002
Acl<O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAA
e00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00GSAN=00:GS@01000Obh0
07l^2WZ500<0057eDOD02U7e00<005hdGS@01ehd00<007maOg400P000Wma00@007ma0000009oL@80
0004Og4007maOg42000>Acl70006Acl01000Acm7?dLo1`000dLo00<004LoAcl014Lo00<004LoAcl0
1DLo1`001TLo00@004LoAcm7?`L000=7?`030017?dLo00a7?`L000I7?`03001oogoo00ioo`03001o
ogoo04ioo`00?Woo0P004Woo00<007ooOol0M7oo00<007ooOol04Goo0`002dLo00@004LoAcm7?`H0
00E7?`030017?dLo00Y7?`<000]7?`040017?dLoAcl60005Acl00`00Acm7?`0:Acl3000;Acl01000
Acm7?dLo1P001DLo00<004LoAcl02TLo0`002dLo00@004LoAcm7?`H000E7?`030017?dLo00Y7?`<0
00]7?`040017?dLoAcl60003Acl=OZX00`00DOEAm@09DOD00`00GSEN=@0<GSD01@00Oe<007mC0000
1TLo37k]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057D
DM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<005hdGS@02Uhd00@007l^
001o;PYjQ@03001AmE7e00YAm@03001N=5hd00MN=007001oL@00Og4007ma00000Wma0P0000UoL@00
Og4007ma001oL@00Og400P000dLo1`000dLo00<004LoAcl02dLo0`002dLo00@004LoAcm7?`L000=7
?`030017?dLo00]7?`<000]7?`040017?dLoAcl70003Acl00`00Acm7?`0;Acl00`00Oomoo`0>Ool0
0`00Oomoo`1=Ool003ioo`80019oo`03001oogoo07Eoo`8001=oo`030017?dLo00Y7?`<000a7?`H0
00Q7?`030017?dLo00Y7?`<000a7?`H000Q7?`030017?dLo00Y7?`<000a7?`H000Q7?`030017?dLo
00Y7?`<000a7?`H000M7?`030017?dLo00]7?`<000U7?`enZP03001AmE7e00UAm@03001N=Ehe00]N
=@04001oDgmC0002Oe<600000dLoO^enk@09O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAA
e00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAA
e00;DM@00`00GSAN=00:GS@01000Obh007l^2WZ500<0057eDOD02U7e00<005hdGS@01ehd01H007ma
001oL@00Og4007ma001oL@00Og4007ma001oL@00Og4007ma001oL@<000]7?`L000M7?`030017?dLo
00]7?`<00097?`030017?dLo00I7?`L000M7?`030017?dLo00]7?`<000]7?`L000I7?`03001oogoo
00ioo`03001oogoo04eoo`00?Woo0P004Woo00<007ooOol0Mgoo00<007ooOol04Goo1P0024Lo00@0
04LoAcm7?`H000A7?`030017?dLo00]7?`H000Q7?`040017?dLoAcl60003Acl00`00Acm7?`0<Acl6
0008Acl01000Acm7?dLo1P000dLo00<004LoAcl034Lo1P001dLo00@004LoAcm7?`L000=7?`030017
?dLo00]7?`L000M7?`040017?dLoAcl700000dLoOZYnZP0:OZX00`00DOEAm@09DOD00`00GSEN=@0;
GSD01000Oe=oD`000WmC00<004LoAcl014Lo2gk]00<0057DDM@02U7D00<0057DDM@02U7D00<0057D
DM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057D
DM@02e7D00<005hdGS@02Uhd00D007l^001o;P0000UjQ@03001AmE7e00YAm@03001N=5hd00MN=00<
001oL@00Og4007ma001oL@00Og4007ma0P000Wma00@007ma0000009oL@040017?dLoAcl70003Acl0
0`00Acm7?`0<Acl70006Acl01000Acm7?dLo1`000dLo00<004LoAcl034Lo1`001TLo00@004LoAcm7
?`L000=7?`030017?dLo00]7?`03001oogoo00ioo`03001oogoo04aoo`00?Woo0P004Woo00<007oo
Ool0N7oo00<007ooOol04Woo00<004LoAcl02TLo0`002dLo00@004LoAcm7?`H000E7?`030017?dLo
00Y7?`<000Y7?`040017?dLoAcl70004Acl00`00Acm7?`0;Acl3000:Acl01000Acm7?dLo1`0014Lo
00<004LoAcl02TLo0`002dLo00@004LoAcm7?`H000E7?`030017?dLo00Y7?`<000Q7?`anZP03001A
mE7e00UAm@03001N=Ehe00]N=@03001oD`0000=oD`8000=7?`8000]nk@03001Ae57D00YAe003001A
e57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001A
e57D00]Ae003001Ae57D00YAe003001N=5hd00YN=005001o;P00Obh00009NXD00`00DOEAm@0;DOD0
0`00GSAN=006GS@03000Og4007ma001oL@00Og4007ma001oL@80009oL@04001oL@000002Og44000;
Acl01000Acm7?dLo1`000dLo00<004LoAcl02dLo0`000TLo00<004LoAcl01TLo00@004LoAcm7?`L0
00=7?`030017?dLo00]7?`<000]7?`030017?dLo00L000A7?`03001oogoo00eoo`03001oogoo04ao
o`00?Woo0P004Woo00<007ooOol0NGoo0P004goo1P0024Lo00<004LoAcl02TLo0`0034Lo1P001dLo
00<004LoAcl02TLo0`0034Lo1`001dLo00<004LoAcl02TLo0`0034Lo1P0024Lo00<004LoAcl02TLo
0`0034Lo1P0024Lo00<004LoAcl01TLo37jZ00<0057eDOD02E7e00<005heGSD02ehe00<007mC0000
0gmC00<007mC00000P000TLo2gk]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0
057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0
05hdGS@02Uhd00D007l^001o;P0000UjQ@03001AmE7e00]Am@03001N=5hd00IN=004001oL@000002
Og401000Og4000000Wma0P0000AoL@00Og5oL@80009oL@<000e7?`<000]7?`L000M7?`050017?dLo
Acl00009Acl3000;Acl70006Acl00`00Acm7?`0;Acl3000<Acl00`00Oomoo`0=Ool00`00Oomoo`1;
Ool003ioo`80019oo`03001oogoo07]oo`03001oogoo019oo`030017?dLo00Y7?`H000M7?`040017
?dLoAcl70004Acl00`00Acm7?`0:Acl60008Acl01000Acm7?dLo1P001DLo00<004LoAcl02TLo1P00
24Lo00@004LoAcm7?`H000E7?`030017?dLo00Y7?`H000Q7?`040017?dLoAcl60004Acl00`00Acm7
?`0;Acl60002Acl<OZX00`00DOEAm@09DOD00`00GSEN=@0;GSD00`00Oe<00002Oe<00`00Oe=oD`02
0003Acl;O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00
DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00GSAN=00:GS@01@00
Obh007l^00002GZ500<0057eDOD02e7e00<005hdGS@01Uhd00@007ma0000009oL@04001oL@000002
Og42000017ma001oLGma0P0000EoL@00Og4007ma00L000I7?`040017?dLoAcl70004Acl00`00Acm7
?`0;Acl70006Acl01000Acm7?dLo1`000dLo00<004LoAcl02dLo1`001dLo00@004LoAcm7?`L000=7
?`03001oogoo00eoo`03001oogoo04]oo`00?Woo0P004Woo00<007ooOol0O7oo00<007ooOol04Woo
1P001dLo00<004LoAcl02TLo0`0034Lo1P0024Lo00<004LoAcl02TLo0`0034Lo1P0024Lo00<004Lo
Acl02TLo0`0034Lo1P001dLo00<004LoAcl02dLo0`002dLo1`001dLo00<004LoAcl014Lo37jZ00<0
057eDOD02E7e00<005heGSD02Uhe00@007mCOe<0009oD`05001oDgmC001oD`03000;O^d00`00DMAA
e00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAA
e00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00GSAN=00:GS@01P00Obh007l^001o;PQjQ@03
001AmE7e00]Am@03001N=5hd00EN=00;001oL@00Og4007ma001oL@00Og400002Og42000037ma001o
L@00Og4007ma001oL@00Og4000e7?`<000a7?`L000I7?`040017?dLo000:Acl3000;Acl70007Acl0
0`00Acm7?`0;Acl3000;Acl00`00Oomoo`0=Ool00`00Oomoo`1:Ool003ioo`80019oo`03001oogoo
07eoo`8001=oo`030017?dLo00Y7?`H000Q7?`040017?dLoAcl60004Acl00`00Acm7?`0;Acl60008
Acl01000Acm7?dLo1P0014Lo00<004LoAcl02dLo1P001dLo00@004LoAcm7?`L000=7?`030017?dLo
00]7?`L000M7?`040017?dLoAcl60004Acl00`00Acm7?`0;Acl600000dLoOZYnZP09OZX00`00DOEA
m@09DOD00`00GSEN=@0:GSD01000Oe=oD`000WmC00D007mCOe<007mC00800003AcmnkGk]00Unk@03
001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003
001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00YAe003001N=5hd00YN=006001o;P00Obh007l^
27Z500<0057eDOD02e7e00<005hdGS@01Ehd01H007ma001oL@00Og4007ma001oL@00Og4007ma001o
L@00Og4007ma001oL@80009oL@P000M7?`040017?dLoAcl70003Acl00`00Acm7?`0;Acl70006Acl0
1000Acm7?dLo1`000dLo00<004LoAcl034Lo1`001TLo00@004LoAcm7?`L000=7?`03001oogoo00eo
o`03001oogoo04Yoo`00>Woo0`0000=oo`0000004Woo00<007ooOol0Ogoo00<007ooOol04Goo00@0
04LoAcm7?`D000E7?`030017?dLo00Y7?`<000]7?`040017?dLoAcl60005Acl00`00Acm7?`0:Acl3
000;Acl01000Acm7?dLo1P0014Lo00<004LoAcl02TLo0`002dLo00@004LoAcm7?`H000E7?`030017
?dLo00Y7?`<000]7?`040017?dLoAcl60004Acl00`00Acm7?`03Acl;OZX00`00DOEAm@09DOD00`00
GSEN=@0:GSD00`00Oe<00003Oe<00`00Oe<00002Oe<00`00Oe<0000;O^d00`00DMAAe00:DM@00`00
DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00
DMAAe00:DM@00`00DMAAe00:DM@00`00GSAN=00:GS@01P00Obh007l^001o;PQjQ@03001AmE7e00]A
m@03001N=5hd00EN=00B001oL@00Og4007ma001oL@00Og4007ma001oL@00Og4007ma0P000Wma0P00
0Wma0`003DLo0`002dLo00<004LoAcl01`000dLo00<004Lo00002dLo0`002dLo00@004LoAcm7?`L0
00=7?`030017?dLo00]7?`<000]7?`03001oogoo00eoo`03001oogoo04Uoo`00>Woo1P004Woo00<0
07ooOol0P7oo00<007ooOol04Goo0`002dLo1P0024Lo00<004LoAcl02TLo0`0034Lo1P001dLo00<0
04LoAcl02dLo0`002dLo1P0024Lo00<004LoAcl02TLo0`0034Lo1P001dLo00<004LoAcl02dLo0`00
2dLo1@002gjZ00<0057eDOD02E7e00<005heGSD02Uhe00<007mC00000gmC00<007mC00000WmC00<0
07mC00002gk]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0
057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<005hdGS@02Uhd00H0
07l^001o;P00Obh8NXD00`00DOEAm@0;DOD00`00GSAN=005GS@03000Og4007ma001oL@00Og4007ma
001oL@80009oL@04001oL@000002Og4200001Gma001oL@00Og401`001TLo00<004LoAcl02dLo0`00
2dLo1`001dLo00<004LoAcl02dLo0`002dLo1`001TLo00<004LoAcl02dLo00<007ooOol03Goo00<0
07ooOol0BGoo000mOol3000BOol00`00Oomoo`21Ool2000BOol01000Acm7?dLo1P001DLo00<004Lo
Acl02TLo1P0024Lo00@004LoAcm7?`H000A7?`030017?dLo00Y7?`L000M7?`040017?dLoAcl60005
Acl00`00Acm7?`0:Acl60007Acl01000Acm7?dLo1`0014Lo00<004LoAcl02TLo1`001dLo00@004Lo
Acm7?`H000A7?`040017?dLoAcl;OZX00`00DOEAm@09DOD00`00GSEN=@0:GSD00`00Oe<00002Oe<0
1P00Oe=oD`00Oe<0009oD`03001nkGk]00Unk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D
00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D
00YAe003001N=5hd00YN=007001o;P00Obh007l^00001gZ500<0057eDOD02e7e00<005hdGS@01Ehd
00@007ma0000009oL@04001oL@000002Og420002Og401000Og4000000Wma0P0000IoL@00Og4007ma
000=Acl70006Acl01000Acm7?dLo1`0014Lo00<004LoAcl02dLo1`001TLo00@004LoAcm7?`L000=7
?`030017?dLo00]7?`L000I7?`03001oogoo00ioo`03001oogoo04Qoo`00DGoo1000Pgoo00<007oo
Ool047oo0`0034Lo1P0024Lo00<004LoAcl02TLo0`002dLo1P0024Lo00<004LoAcl02TLo0`0034Lo
1P001dLo00<004LoAcl02TLo0`0034Lo1P0024Lo00<004LoAcl02TLo0`002dLo10002WjZ00<0057e
DOD02E7e00<005heGSD02Ehe00@007mCOe<0009oD`06001oDgmC001oD`000WmC00<007k]O^d02Gk]
00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D
00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<005hdGS@02Uhd00L007l^001o;P00
Obh00007NXD00`00DOEAm@0;DOD00`00GSAN=005GS@01000Og4000000Wma00@007ma0000009oL@80
000;Og4007ma001oL@00Og4007ma001oL@020002Og480007Acl00`00Acm7?`0:Acl3000;Acl80006
Acl00`00Acm7?`0;Acl3000;Acl70006Acl00`00Acm7?`0;Acl00`00Oomoo`0=Ool00`00Oomoo`18
Ool0059oo`03001oogoo08Aoo`03001oogoo015oo`040017?dLoAcl60004Acl00`00Acm7?`0;Acl6
0007Acl01000Acm7?dLo1P0014Lo00<004LoAcl02dLo1P0024Lo00@004LoAcm7?`H000=7?`030017
?dLo00]7?`H000Q7?`040017?dLoAcl60003Acl00`00Acm7?`0<Acl60007Acl01000Acm7?dLo1P00
14Lo00<004LoAcl02WjZ00<0057eDOD02E7e00<005heGSD02Ehe00@007mCOe<0009oD`09001oDgmC
001oD`00Oe<007mC00]nk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D
00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001N=5hd
00YN=007001o;P00Obh007l^00001gZ500<0057eDOD02e7e00<005hdGS@015hd00D007ma001oL@00
009oL@800004Og4007maOg4200002gma001oL@00Og4007ma001oL@00Og400P000Wma0P003TLo1P00
1dLo00@004LoAcm7?`L00097?`8000e7?`L000I7?`040017?dLoAcl70003Acl00`00Acm7?`0;Acl7
0006Acl00`00Oomoo`0>Ool00`00Oomoo`17Ool0059oo`03001oogoo08Eoo`80019oo`<000]7?`04
0017?dLoAcl60004Acl00`00Acm7?`0:Acl3000;Acl01000Acm7?dLo1P001DLo00<004LoAcl02TLo
0`002TLo00@004LoAcm7?`H000E7?`030017?dLo00Y7?`<000Y7?`040017?dLoAcl70004Acl00`00
Acm7?`0:Acl3000;Acl00`00AcmnZP09OZX00`00DOEAm@09DOD00`00GSEN=@09GSD00`00Oe<00003
Oe<00`00Oe<00002Oe<01000Oe<007mC2gk]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@0
2U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@0
2U7D00<005hdGS@02Uhd00L007l^001o;P00Obh00008NXD00`00DOEAm@0:DOD00`00GSAN=004GS@0
5P00Og4007ma001oL@00Og4007ma001oL@00Og4007ma001oL@00Og4007ma0P000Wma0P0000=oL@00
Og400P000dLo1`000dLo00<004LoAcl02dLo0`002DLo00<004Lo00000TLo1`000dLo00<004LoAcl0
2dLo0`002dLo00<004LoAcl01`000dLo00<004LoAcl02dLo00<007ooOol03Goo00<007ooOol0Agoo
001BOol00`00Oomoo`27Ool00`00Oomoo`0AOol00`00Acm7?`0:Acl3000;Acl60008Acl00`00Acm7
?`0:Acl3000<Acl60007Acl00`00Acm7?`0:Acl3000<Acl60007Acl00`00Acm7?`0:Acl3000<Acl6
0007Acl00`00Acm7?`0;Acl00`00OZYnZP08OZX00`00DOEAm@0:DOD00`00GSEN=@08GSD00`00Oe<0
0003Oe<00`00Oe<00002Oe<01000Oe<007mC2gk]00<0057DDM@02U7D00<0057DDM@02U7D00<0057D
DM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057D
DM@02U7D00<005hdGS@02Uhd00H007l^001o;P00Obh20007NXD00`00DOEAm@0:DOD00`00GSAN=004
GS@05P00Og4007ma001oL@00Og4007ma001oL@00Og4007ma001oL@00Og4007ma0P000Wma0P0000Eo
L@00Og4007ma00<000]7?`L000I7?`030017?dLo00U7?`030017?`00008000]7?`L000I7?`030017
?dLo00]7?`<000]7?`L000I7?`03001oogoo00ioo`03001oogoo04Ioo`00DGoo00<007ooOol0RGoo
0P004Woo1P0024Lo00@004LoAcm7?`D000E7?`030017?dLo00Y7?`H000Q7?`040017?dLoAcl60004
Acl00`00Acm7?`0:Acl60008Acl01000Acm7?dLo1P0014Lo00<004LoAcl02TLo1P0024Lo00@004Lo
Acm7?`H000A7?`030017?dLo00Y7?`L000M7?`YnZP03001AmE7e00YAm@03001N=Ehe00QN=@03001o
D`00009oD`06001oDgmC001oD`000WmC00<007mC00002Wk]00<0057DDM@02U7D00<0057DDM@02U7D
00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D
00<0057DDM@02U7D00<005hdGS@02Uhd00H007l^001o;P00Obh20007NXD00`00DOEAm@0:DOD00`00
GSAN=004GS@03000Og4007ma001oL@00Og4007ma001oL@80009oL@04001oL@000002Og4200001Gma
001oL@00Og400P000Wma00@004LoAcm7?`L000=7?`030017?dLo00]7?`L000A7?`030017?`0000=7
?`L000A7?`030017?dLo00Y7?`L000I7?`040017?dLoAcl70004Acl00`00Acm7?`0:Acl00`00Oomo
o`0=Ool00`00Oomoo`16Ool0055oo`03001oogoo08]oo`03001oogoo015oo`030017?dLo00Y7?`<0
00]7?`H000Q7?`030017?dLo00Y7?`<000]7?`H000Q7?`030017?dLo00Y7?`<000]7?`H000Q7?`03
0017?dLo00Y7?`<000]7?`H000Q7?`030017?dLo00Y7?`YnZP03001AmE7e00UAm@03001N=Ehe00QN
=@03001oD`00009oD`06001oDgmC001oD`000WmC00<007mC00002Wk]00<0057DDM@02U7D00<0057D
DM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057D
DM@02U7D00<0057DDM@02U7D00<005hdGS@02Ehd00L007l^Obh007l^001o;P020007NXD00`00DOEA
m@0:DOD00`00GSAN=004GS@01000Og4000000Wma00H007ma001oL@00Og420002Og401000Og400000
0Wma0P0000EoL@00Og4007ma0080009oL@@000]7?`L000M7?`030017?dLo00M7?`030017?dLo00<0
00a7?`H000M7?`030017?dLo00Y7?`<000a7?`H000M7?`03001oogoo00eoo`03001oogoo04Eoo`00
DGoo00<007ooOol0S7oo00<007ooOol04Goo1P001dLo00@004LoAcm7?`H000E7?`030017?dLo00Y7
?`H000M7?`040017?dLoAcl60005Acl00`00Acm7?`0:Acl60007Acl01000Acm7?dLo1P001DLo00<0
04LoAcl02TLo1P001dLo00@004LoAcm7?`H000E7?`030017?dLo00Y7?`H000I7?`YnZP03001AmE7e
00UAm@03001N=Ehe00MN=@04001oDgmC0002Oe<02000Oe=oD`00Oe<007mC0002Oe<00`00O^enk@08
O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:
DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00GSAN=009GS@01`00Obio;P00
Obh007l^008000MjQ@03001AmE7e00YAm@03001N=5hd00AN=0800006Og4007maOg4007ma0P000Wma
0P0000]oL@00Og4007ma001oL@00Og4007ma0080009oL@80009oL@<000=7?`H000A7?`030017?dLo
00]7?`H000=7?`050017?dLoAcl00003Acl70003Acl00`00Acm7?`0;Acl60007Acl01000Acm7?dLo
1`000dLo00<004LoAcl02dLo00<007ooOol037oo00<007ooOol0AGoo001AOol00`00Oomoo`2=Ool2
000COol00`00Acm7?`09Acl3000<Acl60007Acl00`00Acm7?`0:Acl3000<Acl60007Acl00`00Acm7
?`0:Acl3000<Acl60007Acl00`00Acm7?`0:Acl3000<Acl60007Acl00`00Acm7?`08Acl:OZX00`00
DOEAm@09DOD00`00GSEN=@07GSD01000Oe=oD`000WmC00<007mC00000WmC00<007mC00000WmC00<0
07k]O^d027k]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0
057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<005hdGS@02Ehd00L0
07l^Obh007l^001o;P0200000gl^NXEjQ@04NXD00`00DOEAm@0:DOD00`00GSAN=003GS@01@00Og40
07ma00000Wma0P0000AoL@00Og5oL@80000;Og4007ma001oL@00Og4007ma001oL@020002Og420000
1Gma001oL@00Og400`002dLo1`001TLo00<004LoAcl01TLo00<004LoAcl00TLo0`002dLo1`001TLo
00<004LoAcl02dLo0`002dLo1`001TLo00<007ooOol03Goo00<007ooOol0A7oo001AOol00`00Oomo
o`2?Ool00`00Oomoo`0AOol60007Acl01000Acm7?dLo1P0014Lo00<004LoAcl02TLo1P0024Lo00@0
04LoAcm7?`H000=7?`030017?dLo00]7?`H000Q7?`040017?dLoAcl60003Acl00`00Acm7?`0;Acl6
0008Acl01000Acm7?dLo1P000dLo00<004LoAcl02dLo1P0014Lo2WjZ00<0057eDOD02E7e00<005he
GSD01ehe00<007mC00000gmC00<007mC00000WmC00H007mC001oD`00Oe<:O^d00`00DMAAe00:DM@0
0`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@0
0`00DMAAe00:DM@00`00DMAAe00:DM@00`00GSAN=009GS@00`00Obh00002Obh01@00Obh00000Obh0
1WZ500<0057eDOD02U7e00<005hdGS@00ehd01H007ma001oL@00Og4007ma001oL@00Og4007ma001o
L@00Og4007ma001oL@80009oL@80000:Og4007ma001oL@00Og4007ma0003Acl70003Acl00`00Acm7
?`0;Acl700000dLo0017?`03Acl01000Acm7?dLo1`000dLo00<004LoAcl02dLo1`001TLo00@004Lo
Acm7?`L000=7?`030017?dLo00]7?`03001oogoo00aoo`03001oogoo04Aoo`00DGoo00<007ooOol0
T7oo00<007ooOol04Goo00<004LoAcl02TLo0`002dLo00@004LoAcm7?`D000E7?`030017?dLo00Y7
?`<000Y7?`040017?dLoAcl60005Acl00`00Acm7?`0:Acl3000:Acl01000Acm7?dLo1P0014Lo00<0
04LoAcl02dLo0`002TLo00@004LoAcm7?`H000A7?`030017?dLo00M7?`UnZP03001AmE7e00UAm@03
001N=Ehe00MN=@03001oD`0000=oD`05001oD`00Oe<00002Oe<01000Oe<007mC2Wk]00<0057DDM@0
2U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@0
2U7D00<0057DDM@02U7D00<0057DDM@02U7D00<005hdGS@02Ehd00<007l^00000Wl^0P0000=o;P00
Obh01WZ500<0057eDOD02e7e00<005hdGS@00Uhd01H007ma001oL@00Og4007ma001oL@00Og4007ma
001oL@00Og4007ma001oL@80009oL@800005Og4007ma001oL@020002Og44000;Acl00`00Acm7?`07
0003Acl00`00Acm7?`05Acl00`00Acm7?`03Acl3000;Acl00`00Acm7?`070003Acl00`00Acm7?`0;
Acl3000;Acl00`00Acm7?`070003Acl00`00Oomoo`0=Ool00`00Oomoo`13Ool0055oo`03001oogoo
095oo`80019oo`H000Q7?`030017?dLo00Y7?`<000]7?`H000M7?`030017?dLo00Y7?`<000a7?`H0
00M7?`030017?dLo00Y7?`<000]7?`L000M7?`030017?dLo00Y7?`<000]7?`H000=7?`UnZP03001A
mE7e00UAm@03001N=Ehe00MN=@03001oD`00009oD`06001oDgmC001oD`000WmC00@007mC001oD`Yn
k@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YA
e003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001N=5hd00UN=00:001o;P00Obh0
07l^001o;P00Obh6NXD00`00DOEAm@0;DOD00`00GSAN=002GS@03000Og4007ma001oL@00Og4007ma
001oL@80009oL@04001oL@000002Og4200001Gma001oL@00Og400P000Wma0P000Wma00<004Lo0000
34Lo0`002dLo20001DLo00<004LoAcl02dLo0`002dLo1`001TLo00<004LoAcl02dLo0`002dLo00<0
07ooOol037oo00<007ooOol0@goo001AOol00`00Oomoo`2COol00`00Oomoo`0AOol00`00Acm7?`0:
Acl60007Acl01000Acm7?dLo1P001DLo00<004LoAcl02DLo1P0024Lo00@004LoAcm7?`H000A7?`03
0017?dLo00Y7?`H000Q7?`040017?dLoAcl50005Acl00`00Acm7?`0:Acl60007Acl01000Acm7?dLo
1P0014Lo00<004LoAcl01DLo2GjZ00<0057eDOD02E7e00<005heGSD01Uhe00@007mCOe<0009oD`08
001oDgmC001oD`00Oe<0009oD`03001oDgk]00Unk@03001Ae57D00YAe003001Ae57D00YAe003001A
e57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001A
e57D00YAe003001N=5hd00UN=00;001o;P00Obh007l^001o;P00Obh00005NXD00`00DOEAm@0;DOD0
0`00GSAN=002GS@03000Og4007ma001oL@00Og4007ma001oL@80009oL@04001oL@000002Og420000
1Gma001oL@00Og400P000Wma0P0000=oL@00DM<00TLo1P001dLo00@004LoAcm7?`H000A7?`030017
?dLo00=7?`030017?dLo00A7?`L000I7?`040017?dLoAcl70003Acl00`00Acm7?`0;Acl70006Acl0
1000Acm7?dLo1`000dLo00<007ooOol03Goo00<007ooOol0@Woo001AOol00`00Oomoo`2DOol00`00
Oomoo`0AOol60007Acl00`00Acm7?`0:Acl3000<Acl60007Acl00`00Acm7?`0:Acl3000;Acl60008
Acl00`00Acm7?`0:Acl3000;Acl60007Acl00`00Acm7?`0:Acl3000;Acl70009OZX00`00DOEAm@09
DOD00`00GSEN=@06GSD01000Oe=oD`000WmC00<007mC00000WmC00<007mC00000WmC00<007mCO^d0
2Gk]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@0
2U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<005hdGS@02Ehd00/007l^001o
;P00Obh007l^001o;P0000EjQ@03001AmE7e00]Am@03001N=5hd009N=0800006Og4007maOg4007ma
0P000Wma0P0000IoL@00Og4007ma0002Og4200000gma00000002Og420002Og4200000gma001Ad`02
Acl00`00Acm7?`0;Acl3000;Acl60007Acl00`00Acm7?`0:Acl3000;Acl70006Acl00`00Acm7?`0;
Acl3000;Acl00`00Oomoo`0<Ool00`00Oomoo`12Ool0055oo`03001oogoo09Eoo`8001=oo`030017
?dLo00U7?`H000Q7?`040017?dLoAcl60004Acl00`00Acm7?`0:Acl60007Acl01000Acm7?dLo1P00
1DLo00<004LoAcl02TLo1P001dLo00@004LoAcm7?`H000A7?`030017?dLo00Y7?`H000M7?`040017
?dLoAcl60005Acl00`00Acm7?`02Acl9OZX00`00DOEAm@09DOD00`00GSEN=@06GSD00`00Oe<00003
Oe<00`00Oe<00002Oe<01@00Oe<007mC00000WmC2Wk]00<0057DDM@02U7D00<0057DDM@02U7D00<0
057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0
057DDM@02U7D00<005hdGS@02Ehd00/007l^001o;P00Obh007l^001o;P0000EjQ@03001AmE7e00]A
m@03001N=5hd009N=0800004Og4007maOg42000017ma001oLGma0P0000]oL@00Og4007ma001oL@00
Og4007ma0080009oL@800007Og4007ma001oL@00DM<00dLo1`001TLo00@004LoAcm7?`L000=7?`03
0017?dLo0097?`030017?dLo00I7?`H000M7?`040017?dLoAcl60004Acl00`00Acm7?`0:Acl70006
Acl01000Acm7?dLo1`000dLo00<007ooOol03Goo00<007ooOol0@Goo001AOol00`00Oomoo`2GOol0
0`00Oomoo`0AOol60007Acl00`00Acm7?`0:Acl3000;Acl60008Acl00`00Acm7?`09Acl3000<Acl6
0007Acl00`00Acm7?`0:Acl3000;Acl60007Acl00`00Acm7?`0:Acl3000<Acl50008OZX00`00DOEA
m@09DOD00`00GSEN=@06GSD00`00Oe<00003Oe<01@00Oe<007mC00000WmC00<007mC00000WmC2Wk]
00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D
00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<005hdGS@02Ehd00/007l^001o;P00
Obh007l^001o;P0000EjQ@03001AmE7e00]Am@0N001N=5hdGS@007ma001oL@00Og4007ma001oL@00
Og4007ma001oL@00Og4007ma001oL@00Og4007ma0P0000YoL@00Og4007ma001oL@00Og4000E7?`03
0017?dLo00Y7?`<000]7?`L000I7?`030017?dLo00]7?`<000]7?`H000I7?`030017?dLo00]7?`<0
00]7?`03001oogoo00aoo`03001oogoo045oo`00DGoo0`00V7oo00<007ooOol04Goo00<004LoAcl0
2TLo1P001dLo00@004LoAcm7?`H000E7?`030017?dLo00Y7?`H000M7?`040017?dLoAcl60004Acl0
0`00Acm7?`0:Acl60007Acl01000Acm7?dLo1P001DLo00<004LoAcl02DLo1P0024Lo00@004LoAcm7
?`H000A7?`040017?dLoAcl8OZX00`00DOEAm@09DOD00`00GSEN=@06GSD00`00Oe<00002Oe<01P00
Oe=oD`00Oe<0009oD`03001oD`00009oD`Ynk@03001Ae57D00]Ae003001Ae57D00YAe003001Ae57D
00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D
00YAe003001N=5hd00UN=006001o;P00Obh007l^0P000Wl^00<007l^NXD00gZ500<0057eDOD02e7e
01X005hdGSAN=000Og4007ma001oL@00Og4007ma001oL@00Og4007ma001oL@00Og4007ma0P000Wma
0P0000YoL@00Og4007ma001oL@00Og4000I7?`H000M7?`040017?dLoAcl60003Acl01@00Acm7?dLo
00002DLo1`001TLo00@004LoAcm7?`L000=7?`030017?dLo00A7?`030017?dLo00=7?`L000I7?`04
0017?dLoAcl70003Acl00`00Oomoo`0=Ool00`00Oomoo`10Ool0051oo`8009]oo`80019oo`H000Q7
?`030017?dLo00U7?`<000a7?`H000M7?`030017?dLo00Y7?`<000]7?`H000M7?`030017?dLo00Y7
?`<000a7?`H000M7?`030017?dLo00Y7?`<000]7?`<000QnZP03001AmE7e00UAm@03001N=Ehe00EN
=@04001oDgmC0002Oe<02000Oe=oD`00Oe<007mC0002Oe<00`00Oe<0000:O^d00`00DMAAe00;DM@0
0`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@0
0`00DMAAe00:DM@00`00DMAAe00:DM@00`00GSAN=009GS@01P00Obh007l^001o;P80009o;P03001o
;WZ500=jQ@03001AmE7e00]Am@0@001N=5hdGS@007ma001oL@00Og4007ma001oL@00Og420002Og40
1000Og4000000Wma0P000Wma0P0000=oL@0000000Wma0P000Wma00<004LoAcl014Lo00<004LoAcl0
2dLo0`002TLo1`001TLo00<004LoAcl02dLo0`002dLo1P001dLo00<004LoAcl02TLo0`002dLo00<0
07ooOol037oo00<007ooOol0@7oo001AOol00`00Oomoo`2KOol00`00Oomoo`0AOol00`00Acm7?`0:
Acl60007Acl01000Acm7?dLo1P0014Lo00<004LoAcl02TLo1P001dLo00@004LoAcm7?`H000E7?`03
0017?dLo00U7?`H000Q7?`040017?dLoAcl60004Acl00`00Acm7?`0:Acl60007Acl01000Acm7?dLo
1P0014Lo00<004LoOZX01gjZ00<0057eDOD02E7e00<005heGSD01Ehe00@007mCOe<0009oD`08001o
DgmC001oD`00Oe<0009oD`03001oD`0000]nk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D
00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D
00YAe003001N=5hd00UN=006001o;P00Obh007l^0P0000Ao;P00Obio;PAjQ@03001AmE7e00]Am@0@
001N=5hdGS@007ma001oL@00Og4007ma001oL@00Og420002Og401000Og4000000Wma0P0000EoL@00
Og4007ma0080009oL@800003Og40057C00M7?`L000I7?`040017?dLoAcl60004Acl00`00Acl0000:
Acl70006Acl01000Acm7?dLo1`000dLo00<004LoAcl02dLo1P001dLo00@004LoAcm7?`H000=7?`03
001oogoo00eoo`03001oogoo03moo`00DGoo00<007ooOol0W7oo0P004Woo1P001dLo00<004LoAcl0
2TLo0`002dLo1P0024Lo00<004LoAcl02DLo0`0034Lo1P001dLo00<004LoAcl02TLo0`002dLo1P00
1dLo00<004LoAcl02TLo0`002dLo0P001gjZ00<0057eDOD02E7e00<005heGSD01Ehe00<007mC0000
0gmC00<007mC00000WmC00D007mC001oD`00009oD`03001oDgk]00Unk@03001Ae57D00YAe003001A
e57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001A
e57D00YAe003001Ae57D00YAe003001N=5hd00UN=006001o;P00Obh007l^0P0000Ao;P00Obio;PAj
Q@03001AmE7e00]Am@04001N=5hdGS@200001Wma001oLGma001oL@80009oL@800006Og4007ma001o
L@000Wma0P0000EoL@00Og4007ma0080009oL@800004Og40057C0006Acl00`00Acm7?`0;Acl3000;
Acl60007Acl00`00Acm7?`0:Acl3000;Acl70006Acl00`00Acm7?`0;Acl3000:Acl00`00Oomoo`0<
Ool00`00Oomoo`0oOol0051oo`03001oogoo09moo`03001oogoo015oo`030017?dLo00U7?`H000Q7
?`040017?dLoAcl50005Acl00`00Acm7?`0:Acl60007Acl01000Acm7?dLo1P0014Lo00<004LoAcl0
2TLo1P001dLo00@004LoAcm7?`H000A7?`030017?dLo00Y7?`H000M7?`040017?dLoAcl60004Acl0
0`00OZYnZP05OZX00`00DOEAm@09DOD00`00GSEN=@05GSD00`00Oe<00003Oe<00`00Oe<00002Oe<0
1@00Oe<007mC00000WmC00<007mCO^d02Gk]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@0
2U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@0
2U7D00<005hdGS@02Ehd00H007l^001o;P00Obh200001Gl^001o;P00Obh00gZ500<0057eDOD02e7e
00@005hdGSAN=0800004Og4007maOg42000017ma001oLGma0P0000]oL@00Og4007ma001oL@00Og40
07ma0080009oL@800006Og4007ma001oL@000dLo00<004LoAcl00dLo1`001TLo00@004LoAcm7?`L0
00=7?`030017?`0000]7?`H000I7?`040017?dLoAcl70003Acl00`00Acm7?`0;Acl70006Acl01000
Acm7?dLo1P000dLo00<007ooOol03Goo00<007ooOol0?Woo001@Ool00`00Oomoo`2POol00`00Oomo
o`0AOol60007Acl00`00Acm7?`0:Acl3000;Acl60007Acl00`00Acm7?`0:Acl3000;Acl60007Acl0
0`00Acm7?`0:Acl3000;Acl60007Acl00`00Acm7?`0:Acl3000;Acl7OZX00`00DOEAm@09DOD00`00
GSEN=@05GSD00`00Oe<00002Oe<01P00Oe=oD`00Oe<0009oD`03001oD`00009oD`03001oDgk]00Un
k@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YA
e003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001N=5hd00UN=006001o;P00Obh0
07l^0P0000Eo;P00Obh007l^00=jQ@03001AmE7e00]Am@08001N=5hd001oL@00Og40009oL@800004
Og4007maOg4200002gma001oL@00Og4007ma001oL@00Og400P000Wma0P0000EoL@00Og4007ma00@0
00M7?`030017?dLo00Y7?`<000]7?`L000I7?`030017?dLo00A7?`030017?dLo00=7?`<000]7?`L0
00I7?`030017?dLo00]7?`<000Y7?`03001oogoo00eoo`03001oogoo03eoo`00D7oo00<007ooOol0
XGoo0P004Woo00<004LoAcl02TLo1P001dLo00@004LoAcm7?`H000A7?`030017?dLo00Y7?`H000M7
?`040017?dLoAcl60004Acl00`00Acm7?`0:Acl60007Acl01000Acm7?dLo1P0014Lo00<004LoAcl0
2TLo1P001dLo00@004LoAcm7?`H000=7?`MnZP03001AmE7e00UAm@03001N=Ehe00AN=@04001oDgmC
0002Oe<01P00Oe=oD`00Oe<0009oD`03001oD`00009oD`03001oDgk]00Unk@03001Ae57D00YAe003
001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003
001Ae57D00YAe003001Ae57D00YAe003001N=5hd00UN=006001o;P00Obh007l^0P0000Eo;P00Obh0
07l^00=jQ@03001AmE7e00]Am@0I001N=5hd001oL@00Og4007ma001oL@00Og4007ma001oL@00Og40
07ma001oL@00Og400P000Wma0P0000YoL@00Og4007ma001oL@00Og4000]7?`H000M7?`040017?dLo
Acl60003Acl2000<Acl60007Acl01000Acm7?dLo1P000dLo00<004LoAcl02dLo1`001TLo00@004Lo
Acm7?`H000=7?`03001oogoo00eoo`03001oogoo03eoo`00D7oo00<007ooOol0Xgoo00<007ooOol0
47oo1P0024Lo00<004LoAcl02DLo0`002dLo1P0024Lo00<004LoAcl02DLo0`002dLo1P0024Lo00<0
04LoAcl02DLo0`002dLo1P0024Lo00<004LoAcl02DLo0`002DLo1gjZ00<0057eDOD02E7e00<005he
GSD015he00@007mCOe<0009oD`08001oDgmC001oD`00Oe<0009oD`03001oD`00009oD`Ynk@03001A
e57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001A
e57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001N=5hd00UN=006001o;P00Obh007l^0P00
00Eo;P00Obh007l^00=jQ@03001AmE7e00]Am@0E001N=5hd001oL@00Og4007ma001oL@00Og4007ma
001oL@00Og4007ma0080009oL@80009oL@800009Og4007ma001oL@00Og4007ma00H000I7?`030017
?dLo00]7?`<000Y7?`L000I7?`030017?dLo00]7?`<000Y7?`L000I7?`030017?dLo00]7?`<000Y7
?`03001oogoo00eoo`03001oogoo03aoo`00D7oo00<007ooOol0Y7oo00<007ooOol04Goo00<004Lo
Acl02TLo1P001dLo00@004LoAcm7?`D000E7?`030017?dLo00Y7?`H000M7?`040017?dLoAcl50005
Acl00`00Acm7?`0:Acl60007Acl01000Acm7?dLo1@001DLo00<004LoAcl02TLo1P001dLo00@004Lo
Acm7?`D00097?`InZP03001AmE7e00UAm@03001N=Ehe00AN=@03001oD`0000=oD`03001oD`00009o
D`03001oD`00009oD`03001oD`00009oD`Ynk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D
00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D
00]Ae003001N=5hd00QN=006001o;P00Obh007l^0P0000Eo;P00Obh007l^00=jQ@03001AmE7e00]A
m@0?001N=5hd001oL@00Og4007ma001oL@00Og4007ma0080009oL@800004Og4007maOg4200001Gma
001oL@00Og400P000Wma0P0000=oL@00DM<034Lo1`001TLo00@004LoAcm7?`H000=7?`8000a7?`L0
00I7?`040017?dLoAcl60004Acl00`00Acm7?`0:Acl70006Acl01000Acm7?dLo1P0014Lo00<007oo
Ool037oo00<007ooOol0?7oo001@Ool00`00Oomoo`2UOol2000BOol60007Acl00`00Acm7?`0:Acl3
000;Acl60007Acl00`00Acm7?`0:Acl3000;Acl60007Acl00`00Acm7?`0:Acl3000;Acl60007Acl0
0`00Acm7?`0:Acl30007Acl6OZX00`00DOEAm@09DOD00`00GSEN=@04GSD00`00Oe<00003Oe<00`00
Oe<00002Oe<01@00Oe<007mC00000WmC00<007mC00002Wk]00<0057DDM@02U7D00<0057DDM@02U7D
00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D
00<0057DDM@02e7D00<005hdGS@025hd00H007l^001o;P00Obh200001Wl^001o;P00Obh0009jQ@03
001AmE7e00]Am@03001N=5hd0080009oL@08001oL@00Og4007ma001oL@80009oL@800004Og4007ma
Og4200001Gma001oL@00Og400P000Wma0P0000=oL@00DM<01P001dLo00<004LoAcl02TLo0`002DLo
00<004Lo00001@001dLo00<004LoAcl02TLo0`002dLo1P001TLo00<004LoAcl02dLo0`002dLo00<0
07ooOol037oo00<007ooOol0>goo001@Ool00`00Oomoo`2WOol00`00Oomoo`0AOol00`00Acm7?`09
Acl60007Acl01000Acm7?dLo1P0014Lo00<004LoAcl02TLo1P001dLo00@004LoAcm7?`H000A7?`03
0017?dLo00Y7?`H000M7?`040017?dLoAcl60004Acl00`00Acm7?`0:Acl60007Acl01000Acm7?dLo
1@001WjZ00<0057eDOD02E7e00<005heGSD015he00<007mC00000WmC00H007mCOe<007mC0002Oe<0
0`00Oe<00002Oe<00`00Oe<0000:O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@0
0`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@0
0`00GSAN=008GS@01P00Obh007l^001o;P800003Obh007l^00800004ObijQGZ5000=DOD00`00GSAN
=002000017ma001oLGma0P0000AoL@00Og5oL@80000;Og4007ma001oL@00Og4007ma001oL@020002
Og42000027ma001oL@00Og4004Lo000=Acl60006Acl01000Acm7?dLo1`0000A7?`00Acl000e7?`H0
00I7?`040017?dLoAcl70003Acl00`00Acm7?`04Acl00`00Acm7?`03Acl70006Acl01000Acm7?dLo
1`000dLo00<007ooOol037oo00<007ooOol0>goo001@Ool00`00Oomoo`2XOol00`00Oomoo`0AOol6
0007Acl00`00Acm7?`09Acl3000;Acl60008Acl00`00Acm7?`09Acl3000;Acl60007Acl00`00Acm7
?`0:Acl3000;Acl60007Acl00`00Acm7?`0:Acl30005Acl6OZX00`00DOEAm@09DOD00`00GSEN=@04
GSD00`00Oe<00002Oe<01P00Oe=oD`00Oe<0009oD`03001oD`00009oD`03001oD`0000Ynk@03001A
e57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001A
e57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001N=5hd00QN=006001o;P00Obh007l^0P00
00=o;P00Obh00P0000Eo;WZ5NXEjQ@0000aAm@07001N=000Og4007ma00000Wma0P0000AoL@00Og5o
L@80000;Og4007ma001oL@00Og4007ma001oL@020002Og4200001Wma001oL@00Og400097?`L000I7
?`030017?dLo00A7?`030017?dLo00=7?`<000Q7?`030017?dLo00L000I7?`030017?dLo00A7?`03
0017?dLo00=7?`<000]7?`H000I7?`030017?dLo00]7?`<000]7?`03001oogoo00aoo`03001oogoo
03Yoo`00D7oo00<007ooOol0ZGoo0P004Woo00<004LoAcl02TLo1P001dLo00@004LoAcm7?`D000E7
?`030017?dLo00Y7?`H000M7?`040017?dLoAcl50005Acl00`00Acm7?`09Acl60007Acl01000Acm7
?dLo1P0014Lo00<004LoAcl02TLo1P001dLo00@004LoAcm7?`<000InZP03001AmE7e00UAm@03001N
=Ehe00=N=@04001oDgmC0002Oe<02000Oe=oD`00Oe<007mC0002Oe<00`00Oe<00002Oe<00`00O^en
k@08O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAA
e00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00GSAN=008GS@01P00Obh0
07l^001o;P800003Obh007l^00800005ObijQGZ5NXD0000=DOD200005Gma001oL@00Og4007ma001o
L@00Og4007ma001oL@00Og4007ma001oL@020002Og4200002Wma001oL@00Og4007ma001oL@000dLo
00<004LoAcl02TLo1P001dLo00@004LoAcm7?`L00097?`030017?dLo00]7?`H000I7?`040017?dLo
Acl70003Acl00`00Acm7?`04Acl00`00Acm7?`03Acl70006Acl01000Acm7?dLo1`000dLo00<007oo
Ool037oo00<007ooOol0>Woo001@Ool00`00Oomoo`2[Ool00`00Oomoo`0@Ool60007Acl00`00Acm7
?`0:Acl3000;Acl60007Acl00`00Acm7?`0:Acl3000;Acl60007Acl00`00Acm7?`09Acl3000;Acl6
0007Acl00`00Acm7?`0:Acl30004Acl5OZX00`00DOEAm@09DOD00`00GSEN=@03GSD01000Oe=oD`00
0WmC00<007mC00000WmC00<007mC00000WmC00<007mC00000WmC00<007k]O^d027k]00<0057DDM@0
2U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@0
2U7D00<0057DDM@02U7D00<0057DDM@02e7D00<005hdGS@025hd00H007l^001o;P00Obh200000gl^
001o;P0200001Gl^001jQGZ500003E7e0P0001EoL@00Og4007ma001oL@00Og4007ma001oL@00Og40
07ma001oL@00Og400P000Wma0P0000YoL@00Og4007ma001oL@00Og4000A7?`H000I7?`030017?dLo
00]7?`<000I7?`040017?dLoAcl70006Acl00`00Acm7?`04Acl00`00Acm7?`03Acl3000;Acl60007
Acl00`00Acm7?`0:Acl3000;Acl00`00Oomoo`0<Ool00`00Oomoo`0iOol0051oo`03001oogoo0:ao
o`03001oogoo015oo`030017?dLo00U7?`H000M7?`040017?dLoAcl60004Acl00`00Acm7?`0:Acl6
0007Acl01000Acm7?dLo1P0014Lo00<004LoAcl02TLo1P001dLo00@004LoAcm7?`D000A7?`030017
?dLo00Y7?`H000M7?`040017?dLoAcl20005OZX00`00DOEAm@09DOD00`00GSEN=@03GSD00`00Oe<0
0003Oe<00`00Oe<00002Oe<01@00Oe<007mC00000WmC00@007mC001oD`Ynk@03001Ae57D00YAe003
001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003
001Ae57D00YAe003001Ae57D00]Ae003001N=5hd00MN=007001o;Wl^001o;P00Obh00P0000=o;P00
Obh00P0000Eo;P00NXEjQ@0000eAm@80000;Og4007ma001oL@00Og4007ma001oL@020002Og420000
17ma001oLGma0P0000EoL@00Og4007ma0080009oL@800004Og40057C0003Acl00`00Acm7?`04Acl0
0`00Acm7?`03Acl70006Acl01000Acm7?dLo1P0014Lo00<004LoAcl02TLo1P001dLo00@004LoAcm7
?`H000=7?`030017?dLo00]7?`H000I7?`040017?dLoAcl70003Acl00`00Oomoo`0<Ool00`00Oomo
o`0iOol0051oo`<00:eoo`80019oo`H000M7?`030017?dLo00U7?`<000]7?`H000M7?`030017?dLo
00Y7?`<000]7?`H000M7?`030017?dLo00Y7?`<000Y7?`H000M7?`030017?dLo00Y7?`<00097?`En
ZP03001AmE7e00UAm@03001N=Ehe00=N=@03001oD`0000=oD`05001oD`00Oe<00002Oe<00`00Oe<0
0002Oe<01000Oe<007mC2Wk]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057D
DM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<005hd
GS@01ehd00D007l^Obh007l^00800005Obh007l^001o;P0200001Gl^001jQGZ500003E7e0`000Wma
00@007ma0000009oL@04001oL@000002Og42000017ma001oLGma0P0000EoL@00Og4007ma0080009o
L@800003Og4004Lo00E7?`H000M7?`030017?dLo00Y7?`<000E7?`030017?dLo00=7?`H000I7?`03
0017?dLo00]7?`<000Y7?`L000I7?`030017?dLo00A7?`030017?dLo00=7?`<000]7?`03001oogoo
00aoo`03001oogoo03Qoo`00Cgoo0P00/Goo00<007ooOol047oo00<004LoAcl02TLo1P001dLo00@0
04LoAcm7?`D000E7?`030017?dLo00U7?`H000M7?`040017?dLoAcl60004Acl00`00Acm7?`0:Acl6
0007Acl01000Acm7?dLo1@001DLo00<004LoAcl02DLo1P001dLo00@004LoAcm7?`EnZP03001AmE7e
00UAm@03001N=Ehe00=N=@03001oD`00009oD`06001oDgmC001oD`000WmC00<007mC00000WmC00@0
07mC001oD`Ynk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003
001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001N=5hd00MN=005
001o;Wl^001o;P0200001Gl^001o;P00Obh00P0000Eo;P00NXEjQ@0000eAm@<00004Og4007maOg42
000017ma001oLGma0P0000]oL@00Og4007ma001oL@00Og4007ma0080009oL@800005Og4007ma001o
L@040004Acl00`00Acm7?`0:Acl60006Acl01000Acm7?dLo1`000dLo00<004LoAcl014Lo00<004Lo
Acl00dLo1`001TLo00@004LoAcm7?`H000=7?`030017?dLo00]7?`H000I7?`040017?dLoAcl70003
Acl00`00Oomoo`0<Ool00`00Oomoo`0hOol0051oo`03001oogoo0;1oo`80015oo`H000M7?`030017
?dLo00Y7?`<000]7?`H000M7?`030017?dLo00U7?`<000]7?`H000M7?`030017?dLo00Y7?`<000]7
?`H000M7?`030017?dLo00U7?`<00003AcmnZWjZ009nZP03001AmE7e00UAm@03001N=Ehe009N=@04
001oDgmC0002Oe<02000Oe=oD`00Oe<007mC0002Oe<02000Oe=oD`00Oe<007mC0009O^d00`00DMAA
e00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAA
e00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00GSAN=007GS@00`00Obh00002Obh200001Gl^
001o;P00Obh00P0000Eo;P00ObijQ@0000eAm@<00004Og4007maOg42000017ma001oLGma0P0000]o
L@00Og4007ma001oL@00Og4007ma0080009oL@800006Og4007ma001oL@0024Lo1P001TLo00<004Lo
Acl014Lo00<004LoAcl00dLo0`0014Lo00<004LoAcl014Lo1P001dLo00<004LoAcl02TLo0`002TLo
1`001TLo00<004LoAcl014Lo00<004LoAcl00dLo0`002dLo00<007ooOol037oo00<007ooOol0=goo
001@Ool00`00Oomoo`2bOol00`00Oomoo`0@Ool00`00Acm7?`09Acl60007Acl01000Acm7?dLo1P00
14Lo00<004LoAcl02TLo1P001dLo00@004LoAcm7?`D000E7?`030017?dLo00U7?`H000M7?`040017
?dLoAcl60004Acl00`00Acm7?`0:Acl60006Acl00`00Acm7?`04OZX00`00DOEAm@09DOD00`00GSEN
=@02GSD01000Oe=oD`000WmC00<007mC00000WmC00<007mC00000WmC00<007mC00000WmC00<007mC
00002Gk]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057D
DM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<005hdGS@01ehd00<007l^
00000Wl^0P0000Eo;P00Obh007l^00800005Obh007l^NXD0000=DOD05P00Og4007ma001oL@00Og40
07ma001oL@00Og4007ma001oL@00Og4007ma0P000Wma0P0000UoL@00Og4007ma001oL@00Og401P00
0dLo00<004LoAcl014Lo00<004LoAcl00dLo1P001dLo00@004LoAcm7?`H000=7?`030017?dLo00]7
?`H000I7?`040017?dLoAcl60004Acl00`00Acm7?`0:Acl60006Acl01000Acm7?dLo1`000dLo00<0
07ooOol037oo00<007ooOol0=goo001?Ool00`00Oomoo`2dOol00`00Oomoo`0@Ool60007Acl00`00
Acm7?`09Acl3000;Acl60007Acl00`00Acm7?`0:Acl3000;Acl60006Acl00`00Acm7?`0:Acl3000;
Acl60007Acl00`00Acm7?`09Acl20004OZX00`00DOEAm@09DOD00`00GSEN=@02GSD00`00Oe<00003
Oe<00`00Oe<00002Oe<01@00Oe<007mC00000WmC00H007mCOe<007mC0009O^d00`00DMAAe00:DM@0
0`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@0
0`00DMAAe00:DM@00`00DMAAe00;DM@00`00GSAN=007GS@03000Obh007l^001o;P00Obh007l^001o
;P800005Obh007l^NXD0000=DOD05P00Og4007ma001oL@00Og4007ma001oL@00Og4007ma001oL@00
Og4007ma0P000Wma0P0000YoL@00Og4007ma001oL@00Og4000U7?`H000M7?`030017?dLo00Y7?`<0
0097?`030017?dLo00E7?`L000I7?`030017?dLo00A7?`030017?dLo00=7?`<000]7?`H000I7?`03
0017?dLo00A7?`030017?dLo00=7?`<000]7?`03001oogoo00Moo`H003Qoo`00Cgoo00<007ooOol0
]Goo0P004Woo00<004LoAcl02DLo1P0024Lo1P001dLo00<004LoAcl02DLo1P0024Lo1P001dLo00<0
04LoAcl02DLo1P0024Lo1P001dLo00<004LoAcl02TLo1P001dLo17jZ00<0057eDOD02E7e00<005he
GSD00Uhe00<007mC00000gmC00D007mC001oD`00009oD`03001oD`00009oD`03001oD`00009oD`03
001nkGk]00Mnk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003
001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001N=5hd00MN=00<
001o;P00Obh007l^001o;P00Obh007l^0P0000Eo;P00ObijQ@0000YAm@@0000;Og4007ma001oL@00
Og4007ma001oL@020002Og42000017ma001oLGma0P0000EoL@00Og4007ma0080009oL@03001oL@00
00D000I7?`030017?dLo00]7?`H000M7?`H000M7?`030017?dLo00Y7?`H000M7?`L000I7?`030017
?dLo00A7?`030017?dLo00=7?`H000M7?`L000Ioo`X000Eoo`03001oogoo03Ioo`00Cgoo00<007oo
Ool0]goo00<007ooOol047oo1P001TLo00@004LoAcm7?`H000A7?`030017?dLo00Y7?`H000M7?`04
0017?dLoAcl50004Acl00`00Acm7?`0:Acl60007Acl01000Acm7?dLo1@0014Lo00<004LoAcl02TLo
1P001dLo00@004LoAcm7?`D000=7?`AnZP03001AmE7e00UAm@03001N=Ehe009N=@03001oD`00009o
D`06001oDgmC001oD`000WmC00<007mC00000WmC00<007mC00000WmC00<007k]O^d01gk]00<0057D
DM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057D
DM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<005hdGS@01ehd00`007l^001o;P00Obh007l^
001o;P00Obh200000gl^001o;P020003DOD70003@el20002Og401000Og4000000Wma00@007ma0000
009oL@800004Og4007maOg4200001Gma001oL@00Og400P000Wma0P0000=oL@00Acl014Lo00<004Lo
Acl00dLo1`001TLo00@004LoAcm7?`H000=7?`050017?dLoAcl00009Acl60006Acl01000Acm7?dLo
1P000dLo00<004LoAcl02dLo1P001TLo00@004LoAcm7?`H000Moo`T000moo`03001oogoo03Ioo`00
Cgoo00<007ooOol0^7oo00<007ooOol047oo00<004LoAcl02DLo0`002dLo1P001dLo00<004LoAcl0
2TLo0`002TLo1P001dLo00<004LoAcl02TLo0`002TLo1P001dLo00<004LoAcl02TLo0`002DLo0gjZ
00<0057eDOD02E7e00D005heGSEN=@00009oD`04001oDgmC0002Oe<01@00Oe<007mC00000WmC00T0
07mCOe<007mC001oD`00Oe<02Gk]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0
057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0
05hdGS@01ehd00`007l^001o;P00Obh007l^001o;P00Obh200000gl^001o;P05000;@el01@00Og5o
L@00Og400P0000AoL@00Og5oL@80000;Og4007ma001oL@00Og4007ma001oL@020002Og4200001Gma
001oL@00Og401P001dLo00<004LoAcl02TLo0`002TLo1`001TLo00<004LoAcl014Lo00<004LoAcl0
0dLo0`002TLo1`001TLo00<004LoAcl014Lo00<004LoAcl00dLo0`000goo2P0067oo00<007ooOol0
=Woo001?Ool00`00Oomoo`2iOol2000AOol60007Acl01000Acm7?dLo1@001DLo00<004LoAcl02DLo
1P001dLo00@004LoAcm7?`D000E7?`030017?dLo00U7?`H000M7?`040017?dLoAcl50005Acl00`00
Acm7?`09Acl60007Acl01000Acm7?dLo1P0000E7?gjZOZYnZP0000aAm@04001N=Ehe0002Oe<01P00
Oe=oD`00Oe<0009oD`03001oD`00009oD`09001oDgmC001oD`00Oe<007mC00Unk@03001Ae57D00YA
e003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]A
e003001Ae57D00YAe003001Ae57D00YAe003001N=5hd00MN=006001o;P00Obh007l^0P000Wl^00L0
07l^000007l^001o;P03000=@el00`00Og400002Og42000017ma001oLGma0P0000]oL@00Og4007ma
001oL@00Og4007ma0080009oL@800005Og4007ma001oL@02000<Acl60006Acl01000Acm7?dLo1P00
14Lo00<004Lo00002TLo1P001TLo00@004LoAcm7?`H000A7?`030017?dLo00Y7?`H0009oo`X0029o
o`03001oogoo03Ioo`00Cgoo00<007ooOol0^goo00<007ooOol047oo00<004LoAcl02DLo0`002dLo
1P001dLo00<004LoAcl02DLo0`002dLo1P001TLo00<004LoAcl02TLo0`002dLo1P001TLo00<004Lo
Acl02TLo0`001dLo0gjZ00<0057eDOD02U7e00H005heGSD007mC0003Oe<00`00Oe<00002Oe<01@00
Oe<007mC00000WmC00L007mCOe<007mC001oD`09O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00
DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00
DMAAe00:DM@00`00GSAN=007GS@01P00Obh007l^001o;P80009o;P07001o;P00001o;P00Obh00P00
00=o;P0000001@001d=O0P000Wma0P0000AoL@00Og5oL@800007Og4007ma001oL@00Og400P000Wma
0P0000]oL@00Og4007ma001oL@00Og4004Lo00H000I7?`030017?dLo00A7?`030017?dLo00=7?`<0
00]7?`H000I7?`030017?dLo00A7?`030017?dLo00=7?`<000]7?`H000Aoo`X002aoo`03001oogoo
03Ioo`00Cgoo00<007ooOol0_7oo00<007ooOol047oo1P001TLo00@004LoAcm7?`H000A7?`030017
?dLo00Y7?`H000I7?`040017?dLoAcl60004Acl00`00Acm7?`09Acl60007Acl01000Acm7?dLo1P00
14Lo00<004LoAcl02DLo1P001dLo00@004LoAcm7?`D000AnZP03001AmE7e00UAm@06001N=Ehe001o
D`000gmC00D007mC001oD`00009oD`03001oD`00009oD`07001oDgmC001oD`00Oe<02Gk]00<0057D
DM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057D
DM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<005hdGS@01ehd00H007l^001o;P00Obh20000
17l^001o;Wl^0P0000=o;P00Obh00P0000=o;P0000003D=O018007ma001oL@00Og4007ma001oL@00
Og4007ma001oL@00Og420002Og42000037ma001oL@00Og4007ma001oL@00Acl000I7?`030017?dLo
00=7?`H000M7?`040017?dLoAcl60003Acl20005Acl00`00Acm7?`03Acl60006Acl01000Acm7?dLo
1`000goo2P00=Woo00<007ooOol0=Woo001?Ool00`00Oomoo`2mOol2000AOol00`00Acm7?`09Acl3
000;Acl60007Acl00`00Acm7?`09Acl3000;Acl60007Acl00`00Acm7?`09Acl3000;Acl60007Acl0
0`00Acm7?`09Acl30006Acl3OZX00`00DOEAm@09DOD01P00GSEN=@00Oe<0009oD`06001oDgmC001o
D`000WmC00<007mC00000WmC00<007mC00000WmC00<007mCO^d027k]00<0057DDM@02U7D00<0057D
DM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057D
DM@02U7D00<0057DDM@02U7D00<005hdGS@01ehd00H007l^001o;P00Obh2000017l^001o;Wl^0P00
00=o;P00Obh00P0000=o;P00Obh01`001d=O0P0000UoL@00Og4007ma001oL@00Og400P0000AoL@00
Og5oL@800005Og4007ma001oL@020002Og401000Og4000000dLo1P001TLo00<004LoAcl02dLo0`00
2TLo1P001TLo00<004LoAcl014Lo00<004LoAcl00dLo0`0000=oo`0000001`00@7oo00<007ooOol0
=Woo001?Ool00`00Oomoo`2oOol00`00Oomoo`0?Ool60008Acl60007Acl00`00Acm7?`09Acl60008
Acl60006Acl00`00Acm7?`0:Acl60007Acl60007Acl00`00Acm7?`0:Acl60007Acl600001DLoOZYn
ZWjZ00002e7e00H005heGSD007mC0002Oe<02000Oe=oD`00Oe<007mC0002Oe<01P00Oe=oD`00Oe<0
009oD`03001oDgk]00Qnk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D
00YAe003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00YAe003001N=5hd
00MN=006001o;P00Obh007l^0P0000Uo;P00Obh007l^001o;P00Obh00P0000Ao;P00Obh000M3G`03
0013Gd=O00A3G`80009oL@04001oL@000002Og42000017ma001oLGma0P0000EoL@00Og4007ma0080
009oL@04001oL@000003Acl00`00Acm7?`04Acl00`00Acm7?`03Acl70007Acl60006Acl00`00Acm7
?`04Acl00`00Acm7?`03Acl@0019Ool00`00Oomoo`0fOol004moo`03001oogoo0<1oo`03001oogoo
011oo`040017?dLoAcl50004Acl00`00Acm7?`0:Acl60006Acl01000Acm7?dLo1P0014Lo00<004Lo
Acl02DLo1P001dLo00@004LoAcm7?`D000E7?`030017?dLo00U7?`H000M7?`040017?dLoAcl50004
Acl00`00Acm7?`03Acl3OZX00`00DOEAm@09DOD00`00GSD00002Oe<01000Oe=oD`000WmC00D007mC
001oD`00009oD`08001oDgmC001oD`00Oe<0009oD`Unk@03001Ae57D00YAe003001Ae57D00YAe003
001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003
001Ae57D00YAe003001N=5hd00MN=006001o;P00Obh007l^0P0000Uo;P00Obh007l^001o;P00Obh0
0P0000=o;P00Obh020001d=O0P000Wma00@007ma0000009oL@800004Og4007maOg4200000gma0000
0002Og420002Og4200000gma0017?`03Acl60007Acl01000Acm7?dLo1P000dLo00<004LoAcl014Lo
00<004LoAcl00TLo1`000Woo2P00Dgoo00<007ooOol0=Woo001?Ool00`00Oomoo`31Ool2000AOol3
000:Acl60007Acl00`00Acm7?`09Acl3000;Acl60007Acl00`00Acm7?`09Acl3000;Acl60006Acl0
0`00Acm7?`0:Acl3000:Acl50003OZX00`00DOEAm@09DOD00`00GSD00002Oe<01P00Oe=oD`00Oe<0
009oD`05001oD`00Oe<00002Oe<02000Oe=oD`00Oe<007mC0009O^d00`00DMAAe00:DM@00`00DMAA
e00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAA
e00:DM@00`00DMAAe00:DM@00`00GSAN=007GS@01P00Obh007l^001o;P800009Obh007l^001o;P00
Obh007l^00800003Obh007l^00<000e3G`03001oL@00009oL@80000;Og4007ma001oL@00Og4007ma
001oL@020002Og4200001Wma001oL@00Og4000E7?`030017?dLo00Y7?`<000Y7?`H000Aoo`X005io
o`03001oogoo03Eoo`00Cgoo00<007ooOol0`goo00<007ooOol03goo00@004LoAcm7?`D000E7?`03
0017?dLo00U7?`H000M7?`040017?dLoAcl50004Acl00`00Acm7?`0:Acl60006Acl01000Acm7?dLo
1P0014Lo00<004LoAcl02DLo1P001dLo00@004LoAcm7?`D000A7?`040017?dLoAcl3OZX00`00DOEA
m@09DOD01@00GSD007mC00000gmC00<007mC00000WmC00D007mC001oD`00009oD`08001oDgmC001o
D`00Oe<000Unk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003
001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00YAe003001N=5hd00MN=006
001o;P00Obh007l^0P0000Uo;P00Obh007l^001o;P00Obh00P0000=o;P00Obh00P0000=o;P000000
1@001d=O0P000Wma0P0000]oL@00Og4007ma001oL@00Og4007ma0080000:Og4007ma001oL@00Og40
07ma0006Acl60006Acl01000Acm7?dLo1P0017oo2@000Woo00<007ooOol0Hgoo00<007ooOol0=Goo
001>Ool40034Ool2000@Ool3000;Acl60006Acl00`00Acm7?`0:Acl3000:Acl60007Acl00`00Acm7
?`09Acl3000;Acl60006Acl00`00Acm7?`0:Acl3000:Acl40002OZX00`00DOEAm@09DOD01@00GSD0
07mC00000gmC00D007mC001oD`00009oD`03001oD`00009oD`03001oD`00009oD`04001oD`00Oe<8
O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:
DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00GSAN=007GS@01P00Obh007l^
001o;P800005Obh007l^001o;P020002Obh200000gl^001o;P0200000gl^0000000=@el01P00Og40
07ma001oL@80009oL@04001oL@000002Og4200002Wma001oL@00Og4007ma001oL@001TLo00<004Lo
Acl014Lo00<004LoAcl00dLo3@002goo00<007ooOol0Hgoo00<007ooOol0=Goo001?Ool00`00Oomo
o`36Ool00`00Oomoo`0?Ool60007Acl00`00Acm7?`09Acl60008Acl60007Acl00`00Acm7?`09Acl6
0007Acl60007Acl00`00Acm7?`09Acl60008Acl60007Acl01@00AcmnZWjZ00002e7e00D005he001o
D`00009oD`06001oDgmC001oD`000WmC00<007mC00000WmC00<007mC00000WmC00@007mC001oD`Qn
k@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YA
e003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00YAe003001N=5hd00MN=006001o;P00Obh0
07l^0P0000Eo;P00Obh007l^0080009o;P800003Obh007l^00800003Obh007l^00L000M3G`800003
Og4007ma0080009oL@04001oL@000002Og4200000gma00000002Og401`00Og4007ma0017?`0000E7
?`l001Eoo`03001oogoo06=oo`03001oogoo03Eoo`00Cgoo00<007ooOol0agoo00<007ooOol047oo
00<004LoAcl02DLo1P001dLo00@004LoAcm7?`D000A7?`030017?dLo00Y7?`H000I7?`040017?dLo
Acl50005Acl00`00Acm7?`09Acl60007Acl01000Acm7?dLo1@0014Lo00<004LoAcl02TLo00@007jZ
OZX000]Am@80009oD`04001oDgmC0002Oe<01@00Oe<007mC00000WmC00P007mCOe<007mC001oD`00
0WmC00<007mCO^d01gk]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@0
2U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<005hdGS@0
1ehd00H007l^001o;P00Obh200001Gl^001o;P00Obh00P0000Mo;P00Obh007l^001o;P02000017l^
001o;P001d=O00<004=O@el014=O0P000Wma0P0000AoL@00Og5oL@800005Og4007ma001oL@020002
Og400`00Og40000300000goo00000008000OOol00`00Oomoo`1SOol00`00Oomoo`0eOol004ioo`03
001oogoo0<Uoo`80015oo`H000M7?`030017?dLo00U7?`<000Y7?`H000M7?`030017?dLo00U7?`<0
00]7?`H000I7?`030017?dLo00Y7?`<000Y7?`H000M7?`9nZP03001AmE7e00UAm@80009oD`06001o
DgmC001oD`000WmC00<007mC00000WmC00P007mCOe<007mC001oD`000WmC00<007mCO^d01gk]00<0
057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0
057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<005hdGS@01ehd00H007l^001o;P00Obh2
00001Gl^001o;P00Obh00P0000Mo;P00Obh007l^001o;P0200000gl^001o;P080007@el20002Og42
000017ma001oLGma0P0000EoL@00Og4007ma0080009oL@03001oL@0000@002Uoo`03001oogoo06=o
o`03001oogoo03Eoo`00CWoo00<007ooOol0bgoo00<007ooOol03goo00<004LoAcl02TLo1P001dLo
1P001dLo00<004LoAcl02DLo1P001dLo1P001dLo00<004LoAcl02DLo1P0024Lo1P001TLo00<004Lo
Acl02TLo00=nZP00DOD02U7e0P0000=oD`00Oe<00WmC00<007mC00000WmC00D007mC001oD`00009o
D`08001oDgmC001oD`00Oe<0009oD`Qnk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YA
e003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00YA
e003001N=5hd00MN=006001o;P00Obh007l^0P0000Eo;P00Obh007l^00800007Obh007l^001o;P00
Obh00P0000=o;P00Obh00P003T=O00`007ma001oL@00Og4007ma001oL@00Og420002Og4200001Wma
001oL@00Og4002aoo`03001oogoo06=oo`03001oogoo03Eoo`00CWoo00<007ooOol0c7oo00<007oo
Ool03goo1P001dLo00@004LoAcm7?`D000A7?`030017?dLo00Y7?`H000I7?`040017?dLoAcl50005
Acl00`00Acm7?`09Acl60006Acl01000Acm7?dLo1P0014Lo00<004LoAcl02DLo1P001TLo00=nZP00
DOD02U7e0P0000=oD`00Oe<00WmC00D007mC001oD`00009oD`03001oD`00009oD`08001oDgmC001o
D`00Oe<0009oD`Qnk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YA
e003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00YAe003001N=5hd00MN
=004001o;P00Obh200001Gl^001o;P00Obh00P0000Uo;P00Obh007l^001o;P00Obh00P0000=o;P00
Obh00`000d=O1`0014=O0P0000UoL@00Og4007ma001oL@00Og400P000Wma0P0000IoL@00Og4007ma
000/Ool00`00Oomoo`1SOol00`00Oomoo`0eOol004ioo`03001oogoo0<eoo`80015oo`030017?dLo
00U7?`<000Y7?`H000M7?`030017?dLo00U7?`<000]7?`H000I7?`030017?dLo00U7?`<000]7?`H0
00I7?`030017?dLo00Q7?`03OZX0057e00YAm@800005Oe<007mCOe<00002Oe<00`00Oe<00002Oe<0
0`00Oe<00002Oe<00`00Oe<00002Oe<01@00Oe<007mC000027k]00<0057DDM@02U7D00<0057DDM@0
2U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@0
2U7D00<0057DDM@02U7D00<005hdGS@01ehd00@007l^001o;P800005Obh007l^001o;P0200002Gl^
001o;P00Obh007l^001o;P0200000gl^001o;P02000017l^0000000034=O0P000Wma00@007ma0000
009oL@80000:Og4007ma001oL@00Og4007ma000/Ool00`00Oomoo`1SOol00`00Oomoo`0eOol004io
o`03001oogoo0<moo`03001oogoo00moo`H000M7?`H000M7?`030017?dLo00U7?`H000M7?`H000M7
?`030017?dLo00U7?`H000Q7?`H000I7?`030017?dLo00U7?`H000A7?`03OZX0057e00YAm@04001o
DgmC0002Oe<02000Oe=oD`00Oe<007mC0002Oe<01P00Oe=oD`00Oe<0009oD`05001oD`00Oe<00008
O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:
DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00GSAN=006GS@01@00Obio;P00
Obh00P0000Eo;P00Obh007l^00800009Obh007l^001o;P00Obh007l^00800003Obh007l^00800003
Obh0000000=3G`L000=3G`80009oL@04001oL@000002Og4200002Wma001oL@00Og4007ma001oL@00
;7oo00<007ooOol0Hgoo00<007ooOol0=Goo001>Ool00`00Oomoo`3@Ool00`00Oomoo`0?Ool01000
Acm7?dLo1@001DLo00<004LoAcl02DLo1P001TLo00@004LoAcm7?`D000E7?`030017?dLo00U7?`H0
00I7?`040017?dLoAcl60004Acl00`00Acm7?`09Acl60006Acl01000Acm7?dLo1@0000=nZP00DOD0
2U7e00@007mCOe<0009oD`03001oD`00009oD`03001oD`00009oD`08001oDgmC001oD`00Oe<0009o
D`03001oD`0000Qnk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YA
e003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001N=5hd00IN
=005001o;Wl^001o;P0200001Gl^001o;P00Obh00P0000Mo;P00Obh007l^001o;P0200001Gl^001o
;P00Obh00P0000=o;P0000000`002d=O00<007ma00000Wma0P0000EoL@00Og4007ma0080009oL@04
001oL@00000]Ool00`00Oomoo`1SOol00`00Oomoo`0eOol004ioo`03001oogoo0=5oo`80011oo`<0
00]7?`H000I7?`030017?dLo00U7?`<000]7?`H000I7?`030017?dLo00U7?`<000]7?`H000I7?`03
0017?dLo00U7?`<000I7?`03001AmE7e00=Am@L00003Oe<007mC009oD`03001oD`00009oD`05001o
D`00Oe<00003Oe<01`00Oe<007mC001oD`00009oD`03001nkGk]00Ink@03001Ae57D00YAe003001A
e57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00YAe003001A
e57D00YAe003001Ae57D00YAe003001N=5hd00IN=003001o;P00009o;P800005Obh007l^001o;P02
00001gl^001o;P00Obh007l^00800005Obh007l^001o;P02000017l^000000000d=O1`0014=O0P00
0Wma0P0000EoL@00Og4007ma0080009oL@04001oL@00000]Ool00`00Oomoo`1SOol00`00Oomoo`0e
Ool004ioo`03001oogoo0==oo`03001oogoo011oo`H000I7?`030017?dLo00U7?`H000M7?`H000M7
?`030017?dLo00U7?`H000M7?`H000M7?`030017?dLo00U7?`H000M7?`H00003Acl0000000@000M3
G`8000=oD`05001oD`00Oe<00002Oe<00`00Oe<00002Oe<02000Oe=oD`00Oe<007mC0002Oe<00`00
O^enk@06O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00
DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00GSAN=006GS@00`00
Obh00002Obh200001Gl^001o;P00Obh00P0000Mo;P00Obh007l^001o;P0200001Gl^001o;P00Obh0
0P0000Ao;P00001o;P<000a3G`06001oL@00Og4007ma0P000Wma0P0000IoL@00Og4007ma000]Ool0
0`00Oomoo`1SOol00`00Oomoo`0eOol003=oo``000moo`03001oogoo0=Aoo`03001oogoo011oo`03
0017?dLo00U7?`H000I7?`040017?dLoAcl50005Acl00`00Acm7?`09Acl60006Acl01000Acm7?dLo
1@001DLo00<004LoAcl02DLo1P001TLo00@004LoAcm7?`D000A7?`030017?dLo00A7?`030013Gd=O
00Y3G`800007Oe<007mCOe<007mC00000WmC00<007mC00000WmC00P007mCOe<007mC001oD`000WmC
00<007k]O^d01Wk]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D
00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<005hdGS@01Uhd
00`007l^001o;P00Obh007l^001o;P00Obh200001gl^001o;P00Obh007l^00800005Obh007l^001o
;P02000017l^000007l^0P000d=O1`0014=O0P0000=oL@00Og400P000Wma0P0000IoL@00Og4007ma
000]Ool00`00Oomoo`1SOol00`00Oomoo`0eOol003=oo``000moo`03001oogoo0=Eoo`80015oo`H0
00I7?`030017?dLo00U7?`<000]7?`H000I7?`030017?dLo00U7?`<000]7?`H000I7?`030017?dLo
00U7?`<000Y7?`H00003Acl0000000@000Q3G`80009oD`05001oD`00Oe<00002Oe<01P00Oe=oD`00
Oe<0009oD`06001oD`00Oe<007mC27k]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D
00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D
00<005hdGS@01Uhd00`007l^001o;P00Obh007l^001o;P00Obh200000gl^001o;P020002Obh20000
1Gl^001o;P00Obh00P0000Io;P00001o;P00DM@3000<@el20002Og4200002Wma001oL@00Og4007ma
001oL@00;Goo00<007ooOol0Hgoo00<007ooOol0=Goo000dOol30006Ool2000?Ool00`00Oomoo`3G
Ool00`00Oomoo`0?Ool00`00Acm7?`09Acl60008Acl60006Acl00`00Acm7?`09Acl60007Acl60007
Acl00`00Acm7?`09Acl60007Acl60006Acl00`00Acm7?`04Acl00`00@em3G`0;@el00`00Oe<00002
Oe<00`00Oe<00002Oe<01P00Oe=oD`00Oe<0009oD`06001oD`00Oe<007mC27k]00<0057DDM@02U7D
00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D
00<0057DDM@02U7D00<0057DDM@02e7D00<005hdGS@01Ehd00`007l^001o;P00Obh007l^001o;P00
Obh200000gl^001o;P0200002Gl^001o;P00Obh007l^001o;P02000027l^000007l^001Ae7oo0003
@el70003@el20002Og4200002Wma001oL@00Og4007ma001oL@00;Goo00<007ooOol0Hgoo00<007oo
Ool0=Goo000eOol3000FOol00`00Oomoo`3HOol00`00Oomoo`0?Ool60007Acl01000Acm7?dLo1@00
14Lo00<004LoAcl02DLo1P001TLo00@004LoAcm7?`D000E7?`030017?dLo00U7?`H000I7?`040017
?dLoAcl50004Acl00`00Acm7?`09Acl600000dLo000000050007@el20002Oe<01@00Oe<007mC0000
0gmC00D007mC001oD`00009oD`05001oD`00Oe<00007O^d00`00DMAAe00:DM@00`00DMAAe00:DM@0
0`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@0
0`00DMAAe00;DM@00`00GSAN=005GS@03000Obh007l^001o;P00Obh007l^001o;P800003Obh007l^
00800007Obh007l^001o;P00Obh00P0000=o;P00Obh00P0000=o;P00DM@00Woo0`002d=O00H007ma
001oL@00Og420002Og401000Og400000;Woo00<007ooOol0Hgoo00<007ooOol0=Goo000fOol3000D
Ool6003GOol2000AOol00`00Acm7?`09Acl3000:Acl60006Acl00`00Acm7?`09Acl3000;Acl60006
Acl00`00Acm7?`09Acl3000:Acl60007Acl00`00Acm7?`03Acl00`00@em3G`0;@el00`00Oe<00002
Oe<00`00Oe<00002Oe<02000Oe=oD`00Oe<007mC0002Oe<00`00Oe<00007O^d00`00DMAAe00:DM@0
0`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@0
0`00DMAAe00:DM@00`00DMAAe00;DM@00`00GSAN=005GS@03000Obh007l^001o;P00Obh007l^001o
;P800003Obh007l^00800007Obh007l^001o;P00Obh00P0000=o;P00Obh00P0000=o;P00DM@00Woo
00@004=O@em3G`L000A3G`800003Og4007ma0080009oL@04001oL@00000^Ool00`00Oomoo`1SOol0
0`00Oomoo`0eOol003Moo`<001Aoo`03001oogoo0=]oo`03001oogoo00moo`H000M7?`H000I7?`03
0017?dLo00U7?`H000Q7?`H000I7?`030017?dLo00U7?`H000M7?`H000I7?`030017?dLo00Y7?`d0
00M3G`80009oD`03001oD`00009oD`08001oDgmC001oD`00Oe<0009oD`03001oD`0000Mnk@03001A
e57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001A
e57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001N=5hd00EN=006001o;P00Obh007l^0P00
0Wl^00L007l^000007l^001o;P0200001gl^001o;P00Obh007l^00800003Obh007l^00800003Obh0
057D00=oo`<000a3G`80009oL@800004Og4007maOg42000^Ool00`00Oomoo`1SOol00`00Oomoo`0e
Ool003Qoo`<001=oo`03001oogoo0=aoo`80011oo`040017?dLoAcl50004Acl00`00Acm7?`09Acl6
0006Acl01000Acm7?dLo1P0014Lo00<004LoAcl02DLo1P001TLo00@004LoAcm7?`D000A7?`030017
?dLo00U7?`H000M7?`040017?dLoAcl4000<@el00`00Oe<00002Oe<01P00Oe=oD`00Oe<0009oD`05
001oD`00Oe<00002Oe<00`00O^enk@05O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:
DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;
DM@00`00GSAN=005GS@01P00Obh007l^001o;P80009o;P07001o;P00001o;P00Obh00P0000=o;P00
Obh00P000Wl^0P0000=o;P00Obh00P0000=o;P00DM@017oo00@004=O@em3G`L000=3G`80009oL@80
0006Og4007ma001oL@00;Woo00<007ooOol0I7oo00<007ooOol0=7oo000iOol3000AOol00`00Oomo
o`3OOol00`00Oomoo`0>Ool3000:Acl60006Acl00`00Acm7?`09Acl3000;Acl60006Acl00`00Acm7
?`09Acl3000:Acl60006Acl00`00Acm7?`0:Acl30004Acl60007@el20002Oe<01P00Oe=oD`00Oe<0
009oD`05001oD`00Oe<00002Oe<00`00O^enk@05O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00
DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00
DMAAe00;DM@00`00GSAN=005GS@01P00Obh007l^001o;P800004Obh007l^Obh200000gl^001o;P02
00000gl^001o;P020002Obh200000gl^001o;P0200000gl^001Ae005Ool3000;@el02`00Og4007ma
001oL@00Og4007ma0000;Woo00<007ooOol0I7oo00<007ooOol0=7oo000jOol3000@Ool00`00Oomo
o`3POol00`00Oomoo`0?Ool60007Acl00`00Acm7?`08Acl60008Acl60006Acl00`00Acm7?`09Acl6
0007Acl60006Acl00`00Acm7?`09Acl60008Acl7000<@el00`00Oe<00003Oe<01@00Oe<007mC0000
0WmC00H007mC001oD`00Oe<7O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00
DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00
GSAN=005GS@01P00Obh007l^001o;P800009Obh007l^001o;P00Obh007l^00800003Obh007l^0080
0007Obh007l^001o;P00Obh00P0000=o;P00Ool01Woo1`001d=O0P0000QoL@00Og4007ma001oL@00
;Woo00<007ooOol0I7oo00<007ooOol0=7oo000kOol3000?Ool00`00Oomoo`3QOol2000AOol00`00
Acm7?`09Acl50008Acl60006Acl00`00Acm7?`09Acl60007Acl60006Acl00`00Acm7?`09Acl60007
Acl60007Acl00`00Acm7?`03Acl60007@el20003Oe<01@00Oe<007mC00000WmC00H007mC001oD`00
Oe<7O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAA
e00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00GSAN=005GS@01P00Obh0
07l^001o;P800009Obh007l^001o;P00Obh007l^00800003Obh007l^00800007Obh007l^001o;P00
Obh00P0000=o;P00Ool01goo00<004=O@el02d=O0P000Wma00@007ma000002moo`03001oogoo06Ao
o`03001oogoo03Aoo`00?7oo0P003goo00<007ooOol0hgoo00<007ooOol03goo1P001TLo00@004Lo
Acm7?`D000A7?`030017?dLo00U7?`H000I7?`040017?dLoAcl50004Acl00`00Acm7?`09Acl60006
Acl01000Acm7?dLo1@0014Lo00<004LoAcl02TLo1`0034=O0P0000UoD`00Oe=oD`00Oe<007mC0000
0WmC00@007mC001oD`Mnk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D
00]Ae003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001N=5hd
00EN=006001o;P00Obh007l^0P0000Uo;P00Obh007l^001o;P00Obh00P0000=o;P00Obh00P0000Mo
;P00Obh007l^001o;P0200000gl^001oo`08Ool70006@el20002Og401000Og400000;goo00<007oo
Ool0I7oo00<007ooOol0=7oo000mOol2000>Ool00`00Oomoo`3TOol00`00Oomoo`0?Ool00`00Acm7
?`09Acl3000:Acl60006Acl00`00Acm7?`09Acl3000:Acl60006Acl00`00Acm7?`09Acl3000:Acl6
0007Acl00`00Acm7?`03Acl60008@el20002Oe<01@00Oe<007mC00000WmC00@007mC001oD`Mnk@03
001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003
001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001N=5hd00EN=006001o;P00Obh007l^
0P0000Uo;P00Obh007l^001o;P00Obh00P0000=o;P00Obh00P0000Mo;P00Obh007l^001o;P020000
0gl^001oo`09Ool00`00@em3G`0:@el00`00Og400002Og42000_Ool00`00Oomoo`1TOol00`00Oomo
o`0dOol003eoo`8000ioo`03001oogoo0>Eoo`80011oo`H000M7?`H000I7?`030017?dLo00U7?`H0
00M7?`H000I7?`030017?dLo00U7?`H000M7?`H000I7?`030017?dLo00Y7?`L000e3G`03001oD`00
009oD`05001oD`00Oe<00002Oe<00`00Oe=nk@06O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00
DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00
DMAAe00;DM@00`00GSAN=005GS@01P00Obh007l^001o;P800005Obh007l^001o;P020002Obh20000
0gl^001o;P0200000gl^001o;P020002Obh200000gl^001oo`0:Ool60007@el20002Og42000_Ool0
0`00Oomoo`1TOol00`00Oomoo`0dOol003Aoo`8000Moo`8000ioo`03001oogoo0>Moo`03001oogoo
00moo`H000I7?`030017?dLo00U7?`H000M7?`H000I7?`030017?dLo00U7?`H000M7?`H000I7?`03
0017?dLo00U7?`H000M7?`d000M3G`80009oD`05001oD`00Oe<00002Oe<00`00Oe=nk@06O^d00`00
DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00
DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00GSAN=005GS@01P00Obh007l^001o;P80
0005Obh007l^001o;P020002Obh200000gl^001o;P0200000gl^001o;P020002Obh200000gl^001o
o`0:Ool00`00@em3G`0;@el01@00Og4007ma0000;goo00<007ooOol0I7oo00<007ooOol0=7oo000d
Ool30006Ool2000>Ool00`00Oomoo`3XOol00`00Oomoo`0?Ool00`00Acm7?`09Acl60006Acl01000
Acm7?dLo1@0014Lo00<004LoAcl02DLo1P001TLo00@004LoAcm7?`D000A7?`030017?dLo00U7?`H0
00I7?`040017?dLoAcl50003Ool8000=@el00`00Oe<00002Oe<01@00Oe<007mC00000WmC1gk]00<0
057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0
057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<005hdGS@01Ehd00H007l^001o;P00Obh2
00001Gl^001o;P00Obh00P0000Mo;P00Obh007l^001o;P0200000gl^001o;P0200001Wl^001o;P00
Obh000aoo`L000M3G`800003Og4007oo02moo`03001oogoo06=oo`03001oogoo03Aoo`00=7oo1000
17oo0P003goo00<007ooOol0jGoo0P0047oo1P001TLo00<004LoAcl02DLo0`002TLo1P001TLo00<0
04LoAcl02DLo0`002TLo1P001TLo00<004LoAcl02DLo2`0027oo1`001d=O0P0000MoD`00Oe=oD`00
Oe<00002Oe<7O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@0
0`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00GSAN=005GS@0
1000Obh007l^0P0000Mo;P00Obh007l^001o;P0200001gl^001o;P00Obh007l^00800003Obh007l^
00800006Obh007l^001o;P003Goo00<004=O@el02d=O0P00<Goo00<007ooOol0Hgoo00<007ooOol0
=7oo000eOol8000@Ool00`00Oomoo`3[Ool00`00Oomoo`0?Ool00`00Acm7?`08Acl60008Acl50007
Acl00`00Acm7?`08Acl60007Acl60006Acl00`00Acm7?`09Acl=000COol00`00@em3G`0:@el30002
Oe<01@00Oe<007mC00001gk]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057D
DM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<005hd
GS@01Ehd00@007l^001o;P800007Obh007l^001o;P00Obh00P0000Mo;P00Obh007l^001o;P020000
0gl^001o;P0200001Wl^001o;P00Obh000ioo`L000I3G`80035oo`03001oogoo06=oo`03001oogoo
03Aoo`00=goo1@004Goo00<007ooOol0k7oo00<007ooOol03goo1@0024Lo1P001TLo00<004LoAcl0
2DLo1@0024Lo1@001dLo00<004LoAcl024Lo3P007Woo1P0024=O00<007mC00000WmC00@007mC001o
D`Ink@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D
00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001N=5hd00EN=004001o;P00
Obh200001gl^001o;P00Obh007l^00800007Obh007l^001o;P00Obh00P0000=o;P00Obh00P0000Io
;P00Obh007l^000>Ool00`00@em3G`0;@el00`00Oomoo`0_Ool00`00Oomoo`1SOol00`00Oomoo`0d
Ool004eoo`03001oogoo0>eoo`80011oo`040017?dLoAcl50004Acl00`00Acm7?`09Acl60006Acl0
1000Acm7?dLo1@0014Lo00<004LoAcl02DLo3P00:Goo00@004=O@em3G`H000A3G`80009oD`04001o
D`00Oe<6O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00
DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00GSAN=005GS@01000
Obh007l^0P0000Mo;P00Obh007l^001o;P0200001gl^001o;P00Obh007l^00800003Obh007l^0080
0003Obh007l^00800003DMAoogoo00eoo`L003Qoo`03001oogoo06=oo`03001oogoo03Aoo`00CGoo
0`00kgoo00<007ooOol03Woo0`002TLo1P001TLo00<004LoAcl02DLo0`002TLo3`00=7oo0`002d=O
00<007mC00000WmC00<007mCO^d01Gk]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D
00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D
00<005hdGS@015hd00D007l^Obh007l^00800007Obh007l^001o;P00Obh00P0000Mo;P00Obh007l^
001o;P0200000gl^001o;P0200000gl^001o;P0200000e7DOomoo`1<Ool00`00Oomoo`1SOol00`00
Oomoo`0dOol004aoo`800?9oo`80011oo`H000I7?`030017?dLo00U7?`H000M7?`H00003Ool00000
00P003ioo`040013Gd=O@el60004@el20002Oe<00`00Oe=nk@05O^d00`00DMAAe00:DM@00`00DMAA
e00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAA
e00;DM@00`00DMAAe00:DM@00`00GSAN=004GS@01@00Obio;P00Obh00P0000Eo;P00Obh007l^0080
0007Obh007l^001o;P00Obh00P0000Eo;P00Obh007l^00800003Obh007l^00800003DMAoogoo04ao
o`03001oogoo06=oo`03001oogoo03Aoo`00CGoo00<007ooOol0lWoo00<007ooOol03Woo00<004Lo
Acl02DLo1P001dLo1P000Woo2P00BGoo0`002d=O00<007mC00000WmC1Wk]00<0057DDM@02U7D00<0
057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0
057DDM@02e7D00<0057DDM@02U7D00<005hdGS@015hd00D007l^Obh007l^00800005Obh007l^001o
;P0200001gl^001o;P00Obh007l^00800005Obh007l^001o;P0200000gl^001o;P0200000e7DOomo
o`1<Ool00`00Oomoo`1SOol00`00Oomoo`0dOol004aoo`03001oogoo0?Aoo`03001oogoo00ioo`H0
00M7?`H000=oo`X005Eoo`H000M3G`80009oD`Ink@03001Ae57D00YAe003001Ae57D00YAe003001A
e57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001A
e57D00YAe003001N=5hd00AN=003001o;P00009o;P800005Obh007l^001o;P0200001gl^001o;P00
Obh007l^00800005Obh007l^001o;P0200000gl^001o;P0200000e7DOomoo`1<Ool00`00Oomoo`1S
Ool00`00Oomoo`0dOol004aoo`03001oogoo0?Eoo`80011oo`040017?dLoAcl500000goo00000008
001POol00`00@em3G`0:@el00`00Oe<00006O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAA
e00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAA
e00:DM@00`00GSAN=004GS@00`00Obh00002Obh200001Gl^001o;P00Obh00P0000Mo;P00Obh007l^
001o;P0200001Gl^001o;P00Obh00P0000=o;P00Obh00P0000=Ae7ooOol0C7oo00<007ooOol0Hgoo
00<007ooOol0=7oo001<Ool00`00Oomoo`3gOol00`00Oomoo`0>Ool9001[Ool60007@el20006O^d0
0`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@0
0`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00GSAN=004GS@03000Obh007l^001o
;P00Obh007l^001o;P800007Obh007l^001o;P00Obh00P0000Eo;P00Obh007l^00800003Obh007l^
00800003DMAoogoo04aoo`03001oogoo06Aoo`03001oogoo03=oo`00C7oo00<007ooOol0n7oo00<0
07ooOol00goo2P00MGoo00<004=O@el02T=O00<007k]O^d017k]00<0057DDM@02U7D00<0057DDM@0
2U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@0
2U7D00<0057DDM@02U7D00<005hdGS@015hd00`007l^001o;P00Obh007l^001o;P00Obh200001gl^
001o;P00Obh007l^00800005Obh007l^001o;P0200001Wl^000007l^001Ae4ioo`03001oogoo06Ao
o`03001oogoo03=oo`00C7oo00<007ooOol0nGoo1@00P7oo1P001d=O1Wk]00<0057DDM@02U7D00<0
057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0
057DDM@02U7D00<0057DDM@02U7D00<005hdGS@015hd00`007l^001o;P00Obh007l^001o;P00Obh2
00001gl^001o;P00Obh007l^00800003Obh007l^00800003Obh007l^00800003Obh0057D04Uoo`H0
06Ioo`03001oogoo03=oo`00C7oo00<007ooOol0nGoo00<007ooOol0Pgoo00<004=O@el02D=O1Wk]
00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D
00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<005hdGS@015hd00`007l^001o;P00
Obh007l^001o;P00Obh200000gl^001o;P020002Obh200000gl^001o;P0200000gl^001o;P020000
0gl^001Ae00oOol:0005Ool00`00Oomoo`1TOol00`00Oomoo`0cOol004aoo`03001oogoo0?Uoo`03
001oogoo08Aoo`H000E3G`Ink@03001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00YAe003001A
e57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00YAe003001N
=5hd00AN=006001o;P00Obh007l^0P000Wl^00L007l^000007l^001o;P0200001gl^001o;P00Obh0
07l^00800003Obh007l^00800003Obh007oo03Aoo`/0011oo`03001oogoo06=oo`03001oogoo03=o
o`00C7oo00<007ooOol0nGoo00<007ooOol0QGoo00<004=O@el01d=O1Wk]00<0057DDM@02e7D00<0
057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0
057DDM@02U7D00<0057DDM@02U7D00<005hdGS@015hd00H007l^001o;P00Obh20002Obh01`00Obh0
0000Obh007l^00800007Obh007l^001o;P00Obh00P0000=o;P00Obh00P0000=o;P00Ool0:Woo2P00
77oo00<007ooOol0HWoo00<007ooOol0<goo001<Ool00`00Oomoo`3iOol00`00Oomoo`26Ool60004
@el6O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAA
e00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00GSAN=004GS@01P00Obh0
07l^001o;P800004Obh007l^Obh200000gl^001o;P0200001gl^001o;P00Obh007l^00800003Obh0
07l^00800003Obh007oo021oo`X002Moo`03001oogoo065oo`03001oogoo03=oo`00C7oo00<007oo
Ool0nGoo00<007ooOol0Qgoo00@004=O@em3G`D000Ink@03001Ae57D00YAe003001Ae57D00YAe003
001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003
001Ae57D00YAe003001N=5hd00AN=006001o;P00Obh007l^0P0000Uo;P00Obh007l^001o;P00Obh0
0P0000Mo;P00Obh007l^001o;P0200000gl^001o;P0200000gl^001oo`0FOol:000aOol00`00Oomo
o`1QOol00`00Oomoo`0cOol004aoo`03001oogoo0?Uoo`03001oogoo08Qoo`<000E3G`Ink@03001A
e57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001A
e57D00]Ae003001Ae57D00YAe003001Ae57D00YAe003001N=5hd00AN=006001o;P00Obh007l^0P00
00Uo;P00Obh007l^001o;P00Obh00P0000=o;P00Obh00P000Wl^0P0000=o;P00Obh00P0000=o;P00
Ool02goo2`00?7oo00<007ooOol0H7oo00<007ooOol0<goo001<Ool00`00Oomoo`3iOol00`00Oomo
o`2:Ool60006O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@0
0`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00GSAN=004GS@0
1P00Obh007l^001o;P800009Obh007l^001o;P00Obh007l^00800003Obh007l^0080009o;P800003
Obh007l^00800004Obh007ooOol:0018Ool00`00Oomoo`1OOol00`00Oomoo`0cOol004aoo`03001o
ogoo0?Uoo`03001oogoo08]oo`030013Gd=O0093G`Ink@03001Ae57D00YAe003001Ae57D00YAe003
001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003
001Ae57D00YAe003001N=5hd00AN=006001o;P00Obh007l^0P0000Uo;P00Obh007l^001o;P00Obh0
0P0000=o;P00Obh00P0000=o;P00Obh02P00DWoo00<007ooOol0Ggoo00<007ooOol0<goo001;Ool4
003iOol00`00Oomoo`2<Ool40006O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@0
0`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@0
0`00GSAN=004GS@01P00Obh007l^001o;P800005Obh007l^001o;P020002Obh;00000gl^001o;P02
00000gl^001oo`1DOol00`00Oomoo`1NOol00`00Oomoo`0cOol004aoo`03001oogoo0?Uoo`03001o
ogoo091oo`Ink@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003
001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00YAe003001N=5hd00AN=004
001o;P00Obh?00000gl^001o;P0200001gl^001o;P00Obh007l^00800003Obh007oo05Eoo`03001o
ogoo05eoo`03001oogoo03=oo`00Bgoo00<007ooOol0nWoo00<007ooOol0T7oo1Wk]00<0057DDM@0
2U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@0
2e7D00<0057DDM@02U7D00<0057DDM@02e7D00<005hd00002@0000Mo;P00Obh007l^001o;P020000
1gl^001o;P00Obh007l^00800007Obh007l^001o;P00Obh00P0000=o;P00Ool0EWoo00<007ooOol0
G7oo00<007ooOol0<goo001;Ool00`00Oomoo`3jOol00`00Oomoo`2@Ool6O^d00`00DMAAe00:DM@0
0`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@0
0`00DMAAe00:DM@00`00DMAAe003DM@:0004GS@01000Obh007l^0P0000Mo;P00Obh007l^001o;P02
00001gl^001o;P00Obh007l^00800003Obh007l^0080009o;P800003Obh007oo05Ioo`03001oogoo
05aoo`03001oogoo03=oo`00Bgoo00<007ooOol0nWoo00<007ooOol0T7oo1Wk]00<0057DDM@02U7D
00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D
00<0057DDM@01U7D2P00257D00<005hdGS@00ehd00@007l^001o;P800007Obh007l^001o;P00Obh0
0P0000Mo;P00Obh007l^001o;P0200000gl^001o;P0200001Wl^001o;P00Obh005Qoo`03001oogoo
05]oo`03001oogoo03=oo`00Bgoo00<007ooOol0nWoo00<007ooOol0T7oo1Wk]00<0057DDM@02U7D
00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02E7D
2`00157D00<0057DDM@02e7D00<005hdGS@00ehd00@007l^001o;P800007Obh007l^001o;P00Obh0
0P0000Mo;P00Obh007l^001o;P0200000gl^001o;P0200001Wl^001o;P00Obh005Uoo`03001oogoo
05Yoo`03001oogoo03=oo`00Bgoo00<007ooOol0nWoo00<007ooOol0T7oo1Wk]00<0057DDM@02U7D
00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057D00002@00
0U7D00<0057DDM@02U7D00<0057DDM@02e7D00<005hdGS@00ehd00@007l^001o;P800007Obh007l^
001o;P00Obh00P0000Mo;P00Obh007l^001o;P0200000gl^001o;P0200001Wl^001o;P00Obh005Uo
o`03001oogoo05Yoo`03001oogoo03=oo`00Bgoo00<007ooOol0nWoo00<007ooOol0T7oo1Wk]00<0
057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@00U7D2P00
357D00<0057DDM@02U7D00<0057DDM@02e7D00<005hdGS@00ehd00@007l^001o;P800007Obh007l^
001o;P00Obh00P0000Mo;P00Obh007l^001o;P0200000gl^001o;P0200001Wl^001o;P00Obh005Yo
o`03001oogoo05Uoo`03001oogoo03=oo`00Bgoo00<007ooOol0nWoo00<007ooOol0T7oo1Wk]00<0
057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@01E7D2P00257D00<0057DDM@0
2e7D00<0057DDM@02U7D00<0057DDM@02e7D00<005hdGS@00Uhd00D007l^Obh007l^00800007Obh0
07l^001o;P00Obh00P0000Eo;P00Obh007l^00800005Obh007l^001o;P0200000gl^001o;P020000
0e7DOomoo`1IOol00`00Oomoo`1IOol00`00Oomoo`0bOol004]oo`03001oogoo0?Yoo`03001oogoo
095oo`Enk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00QAe0X000EAe003001Ae57D00YA
e003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae003001N=5hd009N=005001o;Wl^001o
;P0200001gl^001o;P00Obh007l^00800005Obh007l^001o;P0200001Gl^001o;P00Obh00P0000=o
;P00Obh00P0000=Ae7ooOol0FWoo00<007ooOol0F7oo00<007ooOol0<Woo001;Ool00`00Oomoo`3j
Ool00`00Oomoo`2AOol5O^d00`00DMAAe00:DM@00`00DMAAe00:DM@;0002DM@00`00DMAAe00:DM@0
0`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00GSAN=002GS@0
1@00Obio;P00Obh00P0000Mo;P00Obh007l^001o;P0200001Gl^001o;P00Obh00P0000Eo;P00Obh0
07l^00800003Obh007l^00800003DMAoogoo05Yoo`03001oogoo05Qoo`03001oogoo039oo`00Bgoo
00<007ooOol0nGoo00<007ooOol0TWoo1Gk]00<0057DDM@02U7D00<0057DDM@02`00357D00<0057D
DM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02e7D00<005hd
GS@00Uhd00<007l^00000Wl^0P0000Mo;P00Obh007l^001o;P0200001Gl^001o;P00Obh00P0000Eo
;P00Obh007l^00800003Obh007l^00800003DMAoogoo05]oo`03001oogoo05Moo`03001oogoo039o
o`00Bgoo00<007ooOol0nGoo00<007ooOol0TWoo1Gk]00<0057DDM@00e7D2P002U7D00<0057DDM@0
2U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@0
2e7D00<005hdGS@00Uhd00<007l^00000Wl^0P0000Eo;P00Obh007l^00800007Obh007l^001o;P00
Obh00P0000Eo;P00Obh007l^00800003Obh007l^00800003DMAoogoo05aoo`03001oogoo05Ioo`03
001oogoo039oo`00Bgoo00<007ooOol0nGoo00<007ooOol0TWoo00=nk@00000020001e7D00<0057D
DM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057D
DM@02U7D00<0057DDM@02e7D00<005hdGS@00Uhd00`007l^001o;P00Obh007l^001o;P00Obh20000
1gl^001o;P00Obh007l^00800003Obh007l^00800005Obh007l^001o;P02001OOol00`00Oomoo`1F
Ool00`00Oomoo`0bOol004]oo`03001oogoo0?Uoo`03001oogoo08Qoo`/000Ank@03001Ae57D00YA
e003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]A
e003001Ae57D00YAe003001Ae57D00]Ae003001N=5hd009N=00<001o;P00Obh007l^001o;P00Obh0
07l^0P0000Mo;P00Obh007l^001o;P0200000gl^001o;P0200001Gl^001o;P00Obh00P00H7oo00<0
07ooOol0EGoo00<007ooOol0<Woo001;Ool3003iOol00`00Oomoo`1nOol:000:Ool5O^d00`00DMAA
e00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAA
e00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00GSAN=002GS@03000Obh007l^001o;P00Obh0
07l^001o;P800007Obh007l^001o;P00Obh00P0000=o;P00Obh00P0000Eo;P00Obh007l^0080065o
o`03001oogoo05Aoo`03001oogoo039oo`00BWoo0P00ngoo00<007ooOol0M7oo2P0057oo1Gk]00<0
057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0
057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<005hdGS@00Uhd00H007l^001o;P00Obh2
0002Obh02`00Obh00000Obh007l^001o;P00Obh00P0000=o;P00Obh00P0000Eo;P00Obh007l^0080
069oo`03001oogoo05=oo`03001oogoo039oo`00BWoo00<007ooOol0nWoo00<007ooOol0JWoo2P00
7Woo1Gk]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057D
DM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<005hdGS@00Uhd00H007l^
001o;P00Obh20002Obh01`00Obh00000Obh007l^0080009o;P800003Obh007l^00800005Obh007l^
001o;P02001ROol00`00Oomoo`1COol00`00Oomoo`0bOol004Yoo`03001oogoo0?Yoo`03001oogoo
05moo`/002Qoo`Enk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]A
e003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001N=5hd009N
=006001o;P00Obh007l^0P0000Ao;P00Obio;P800003Obh007l^0080009o;P800003Obh007l^0080
0005Obh007l^001o;P02001SOol00`00Oomoo`1BOol00`00Oomoo`0bOol004Yoo`03001oogoo0?Yo
o`03001oogoo05Eoo`X003=oo`Enk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003
001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003
001N=5hd009N=006001o;P00Obh007l^0P0000Ao;P00Obio;P800003Obh007l^00800007Obh007l^
001o;P00Obh00P0000=o;P00Obh00P0000=o;P00Ool0Hgoo00<007ooOol0DGoo00<007ooOol0<Woo
001:Ool00`00Oomoo`3jOol00`00Oomoo`1;Ool:000mOol5O^d00`00DMAAe00:DM@00`00DMAAe00:
DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:
DM@00`00DMAAe00;DM@00`00GSAN=002GS@01P00Obh007l^001o;P800009Obh007l^001o;P00Obh0
07l^00800007Obh007l^001o;P00Obh00P0000=o;P00Obh00P0000=o;P00Ool0I7oo00<007ooOol0
D7oo00<007ooOol0<Woo001:Ool00`00Oomoo`3jOol00`00Oomoo`11Ool:0017Ool5O^d00`00DMAA
e00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAA
e00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00GSAN=002GS@01P00Obh007l^001o;P800009
Obh007l^001o;P00Obh007l^00800007Obh007l^001o;P00Obh00P0000=o;P00Obh00P0000=o;P00
Ool0I7oo00<007ooOol0D7oo00<007ooOol0<Woo001:Ool00`00Oomoo`3jOol00`00Oomoo`0fOol;
001AOol5O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00
DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00GSAN=002GS@01000
Obh007l^0P0000]o;P00Obh007l^001o;P00Obh007l^00800003Obh007l^0080009o;P800003Obh0
07l^00800003Obh007oo06Eoo`03001oogoo04moo`03001oogoo039oo`00BWoo00<007ooOol0nWoo
00<007ooOol0;7oo2P00GGoo17k]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0
057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0
05hdGS@00Uhd00@007l^001o;P800007Obh007l^001o;P00Obh00P000Wl^0P0000=o;P00Obh00P00
0Wl^0P0000=o;P00Obh00P0000=o;P00Ool0IWoo00<007ooOol0CWoo00<007ooOol0<Woo001:Ool0
0`00Oomoo`3jOol00`00Oomoo`0ROol:001WOol4O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00
DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00
DMAAe00;DM@00`00GSAN=002GS@01000Obh007l^0P0000Mo;P00Obh007l^001o;P020002Obh20000
0gl^001o;P0200001gl^001o;P00Obh007l^00800003Obh007oo06Ioo`03001oogoo04ioo`03001o
ogoo039oo`00BWoo00<007ooOol0nWoo00<007ooOol067oo2P00LGoo17k]00<0057DDM@02U7D00<0
057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0
057DDM@02U7D00<0057DDM@02e7D00<005hdGS@00Uhd00@007l^001o;P800007Obh007l^001o;P00
Obh00P0000Mo;P00Obh007l^001o;P0200001gl^001o;P00Obh007l^00800003Obh007oo06Moo`03
001oogoo04eoo`03001oogoo039oo`00BWoo00<007ooOol0nWoo00<007ooOol03Goo2`00Ngoo17k]
00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D
00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<005hdGS@00Uhd00@007l^001o;P80
0007Obh007l^001o;P00Obh00P0000Mo;P00Obh007l^001o;P0200001gl^001o;P00Obh007l^0080
0003Obh007oo06Qoo`03001oogoo04eoo`03001oogoo035oo`00BWoo00<007ooOol0nWoo00<007oo
Ool00goo2P00QWoo17k]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@0
2e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<005hdGS@0
0Uhd00@007l^001o;P800007Obh007l^001o;P00Obh00P0000Mo;P00Obh007l^001o;P0200001gl^
001o;P00Obh007l^00800003Obh007oo06Uoo`03001oogoo04aoo`03001oogoo035oo`00BWoo00<0
07ooOol0mWoo2P00T7oo17k]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057D
DM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<005hd
GS@00Uhd00@007l^001o;P800007Obh007l^001o;P00Obh00P0000Mo;P00Obh007l^001o;P020000
0gl^001o;P020002Obh200000gl^001oo`1YOol00`00Oomoo`1<Ool00`00Oomoo`0aOol004Yoo`03
001oogoo0>aoo`X000Aoo`03001oogoo09=oo`Ank@03001Ae57D00YAe003001Ae57D00YAe003001A
e57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001A
e57D00YAe003001N=5hd009N=004001o;P00Obh200001gl^001o;P00Obh007l^00800007Obh007l^
001o;P00Obh00P0000=o;P00Obh00P000Wl^0P0000=o;P00Ool0JWoo00<007ooOol0Bgoo00<007oo
Ool0<Goo001:Ool00`00Oomoo`3QOol;000>Ool00`00Oomoo`2COol4O^d00`00DMAAe00:DM@00`00
DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00
DMAAe00:DM@00`00DMAAe00:DM@00`00GSAN=002GS@01000Obh007l^0P0000Mo;P00Obh007l^001o
;P0200001gl^001o;P00Obh007l^00800003Obh007l^00800006Obh007l^001o;P00K7oo00<007oo
Ool0BWoo00<007ooOol0<Goo0019Ool4003GOol:000IOol00`00Oomoo`2COol4O^d00`00DMAAe00:
DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;
DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00GSAN=002GS@01000Obh007l^0P0000Mo;P00Obh0
07l^001o;P0200001Gl^001o;P00Obh00P0000Eo;P00Obh007l^00800006Obh007l^001o;P00K7oo
00<007ooOol0BWoo00<007ooOol0<Goo0019Ool00`00Oomoo`3>Ool:000SOol00`00Oomoo`2COol4
O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:
DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@01@00GSAN=5hd00000Wl^00/007l^
000007l^001o;P00Obh007l^00800005Obh007l^001o;P0200001Gl^001o;P00Obh00P0000Io;P00
Obh007l^001]Ool00`00Oomoo`19Ool00`00Oomoo`0aOol004Uoo`03001oogoo0<Aoo`X002eoo`03
001oogoo09=oo`Ank@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]A
e003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00YAe005001N=5hdGS@0
0002Obh02`00Obh00000Obh007l^001o;P00Obh00P0000Eo;P00Obh007l^00800005Obh007l^001o
;P0200000gl^001o;P02001_Ool00`00Oomoo`18Ool00`00Oomoo`0aOol004Uoo`03001oogoo0;Uo
o`/003Moo`03001oogoo09=oo`Ank@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003
001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00YAe007
001N=5hdGS@007l^00000Wl^0P0000Mo;P00Obh007l^001o;P0200001Gl^001o;P00Obh00P0000Eo
;P00Obh007l^00800003Obh007l^0080071oo`03001oogoo04Moo`03001oogoo035oo`00BGoo00<0
07ooOol0[goo2P00@Woo00<007ooOol0Tgoo17k]00<0057DDM@02U7D00<0057DDM@02U7D00<0057D
DM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057D
DM@02U7D00L005hdGSAN=000Obh00002Obh200001gl^001o;P00Obh007l^00800005Obh007l^001o
;P0200001Gl^001o;P00Obh00P0000=o;P00Obh00P00L7oo00<007ooOol0Agoo00<007ooOol0<Goo
0019Ool00`00Oomoo`2UOol:001<Ool00`00Oomoo`2COol4O^d00`00DMAAe00:DM@00`00DMAAe00:
DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:
DM@00`00DMAAe00:DM@04P00GSAN=5hd001o;P00Obh007l^001o;P00Obh007l^001o;P800005Obh0
07l^001o;P0200000gl^001o;P0200001Gl^001o;P00Obh00P00LGoo00<007ooOol0AWoo00<007oo
Ool0<Goo0019Ool00`00Oomoo`2KOol:001FOol00`00Oomoo`2DOol3O^d00`00DMAAe00:DM@00`00
DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00
DMAAe00:DM@00`00DMAAe00:DM@04P00GSAN=5hd001o;P00Obh007l^001o;P00Obh007l^001o;P80
0005Obh007l^001o;P0200000gl^001o;P0200001Gl^001o;P00Obh00P00LWoo00<007ooOol0AGoo
00<007ooOol0<Goo0019Ool00`00Oomoo`2AOol:001POol00`00Oomoo`2DOol3O^d00`00DMAAe00:
DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;
DM@00`00DMAAe00:DM@00`00DMAAe00;DM@03`00GSAN=000Obh007l^001o;P00Obh007l^001o;P02
00001gl^001o;P00Obh007l^00800003Obh007l^00800005Obh007l^001o;P02001cOol00`00Oomo
o`14Ool00`00Oomoo`0aOol004Uoo`03001oogoo08Ioo`/006Yoo`03001oogoo09Aoo`=nk@03001A
e57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001A
e57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae00?001N=5hd001o;P00Obh007l^001o;P00Obh0
07l^00800007Obh007l^001o;P00Obh00P0000=o;P00Obh00P0000Eo;P00Obh007l^008007=oo`03
001oogoo04Aoo`03001oogoo035oo`00BGoo00<007ooOol0O7oo2P00MGoo00<007ooOol0U7oo0gk]
00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D
00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02e7D00T005hdGS@007l^001o;P00Obh00P00
0Wl^00/007l^000007l^001o;P00Obh007l^00800003Obh007l^00800005Obh007l^001o;P02001d
Ool00`00Oomoo`13Ool00`00Oomoo`0aOol004Uoo`03001oogoo079oo`X007moo`03001oogoo09Ao
o`=nk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D
00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae009001N=5hd001o;P00Obh007l^
0080009o;P0;001o;P00001o;P00Obh007l^001o;P0200000gl^001o;P0200001Gl^001o;P00Obh0
0P00MGoo00<007ooOol0@Woo00<007ooOol0<Goo000bOol5000BOol00`00Oomoo`1XOol:0029Ool0
0`00Oomoo`2DOol3O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;
DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;DM@02@00GSAN=000
Obh007l^001o;P02000017l^001o;Wl^0P0000Mo;P00Obh007l^001o;P0200000gl^001o;P020000
1Gl^001o;P00Obh00P00MGoo00<007ooOol0@Woo00<007ooOol0<Goo000`Ool9000@Ool00`00Oomo
o`1MOol;002COol00`00Oomoo`2DOol3O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:
DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;
DM@01`00GSAN=000Obh007l^0080000;Obh007l^001o;P00Obh007l^001o;P020002Obh200000gl^
001o;P0200001Gl^001o;P00Obh00P00MWoo00<007ooOol0@Goo00<007ooOol0<Goo000_Ool40004
Ool3000?Ool00`00Oomoo`1COol:002NOol00`00Oomoo`2DOol3O^d00`00DMAAe00:DM@00`00DMAA
e00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAA
e00:DM@00`00DMAAe00;DM@01`00GSAN=000Obh007l^0080000;Obh007l^001o;P00Obh007l^001o
;P020002Obh200000gl^001o;P0200001Gl^001o;P00Obh00P00Mgoo00<007ooOol0@Goo00<007oo
Ool0<7oo000_Ool20007Ool3000>Ool00`00Oomoo`19Ool:002XOol00`00Oomoo`2DOol3O^d00`00
DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00
DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;DM@01`00GSAN=000Obh007l^0080000;Obh007l^
001o;P00Obh007l^001o;P0200001gl^001o;P00Obh007l^00800005Obh007l^001o;P02001hOol0
0`00Oomoo`10Ool00`00Oomoo`0`Ool003Uoo`8000ioo`03001oo`00008003eoo`X00;9oo`03001o
ogoo09Aoo`=nk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003
001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae007001N=5hd001o;P00
Obh00P0000Mo;P00Obh007l^001o;P020002Obh200001gl^001o;P00Obh007l^00800005Obh007l^
001o;P02001hOol00`00Oomoo`10Ool00`00Oomoo`0`Ool003Uoo`8000eoo`<003Eoo`/00;aoo`03
001oogoo09Aoo`=nk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]A
e003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae007001N=5hd001o
;P00Obh00P0000Mo;P00Obh007l^001o;P020002Obh200001gl^001o;P00Obh007l^00800005Obh0
07l^001o;P02001iOol00`00Oomoo`0oOol00`00Oomoo`0`Ool003Uoo`8000eoo`03001oogoo02]o
o`X00<Moo`03001oogoo09Aoo`=nk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003
001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae007
001N=5hd001o;P00Obh00P0000Mo;P00Obh007l^001o;P0200001gl^001o;P00Obh007l^0080009o
;P800003Obh007l^00800003Obh007oo07Uoo`03001oogoo03ioo`03001oogoo031oo`00>7oo0`00
3Goo00<007ooOol08Goo2P00d7oo00<007ooOol0UGoo0gk]00<0057DDM@02U7D00<0057DDM@02U7D
00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D
00<0057DDM@02e7D00L005hdGS@007l^001o;P0200001gl^001o;P00Obh007l^00800007Obh007l^
001o;P00Obh00P000Wl^0P0000=o;P00Obh00P0000=o;P00Ool0NGoo00<007ooOol0?Woo00<007oo
Ool0<7oo000gOol3000>Ool00`00Oomoo`0GOol:003JOol00`00Oomoo`2EOol3O^d00`00DMAAe00:
DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;
DM@00`00DMAAe00:DM@00`00DMAAe00;DM@01`00GSAN=000Obh007l^00800007Obh007l^001o;P00
Obh00P0000Mo;P00Obh007l^001o;P0200001gl^001o;P00Obh007l^00800003Obh007oo07Yoo`03
001oogoo03eoo`03001oogoo031oo`00=7oo1@003goo00<007ooOol037oo2`00i7oo00<007ooOol0
UWoo0Wk]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057D
DM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02e7D00L005hdGS@007l^001o;P02
00001gl^001o;P00Obh007l^00800007Obh007l^001o;P00Obh00P0000Mo;P00Obh007l^001o;P02
00000gl^001oo`1kOol00`00Oomoo`0lOol00`00Oomoo`0`Ool003Aoo`@0011oo`03001oogoo009o
o`X00>moo`03001oogoo09Ioo`9nk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003
001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae007
001N=5hd001o;P00Obh00P0000Mo;P00Obh007l^001o;P0200001gl^001o;P00Obh007l^00800007
Obh007l^001o;P00Obh00P0000=o;P00Ool0O7oo00<007ooOol0>goo00<007ooOol0<7oo000gOol2
000?Ool50003Ool00`00Oomoo`3cOol00`00Oomoo`2FOol2O^d00`00DMAAe00:DM@00`00DMAAe00:
DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:
DM@00`00DMAAe00;DM@01`00GSAN=000Obh007l^00800007Obh007l^001o;P00Obh00P0000Mo;P00
Obh007l^001o;P0200001gl^001o;P00Obh007l^00800003Obh007oo07aoo`03001oogoo03]oo`03
001oogoo031oo`00>7oo0P0047oo0P0017oo00<007ooOol0lgoo00<007ooOol0UWoo0Wk]00<0057D
DM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057D
DM@02e7D00<0057DDM@02U7D00<0057DDM@02e7D00L005hdGS@007l^001o;P0200001gl^001o;P00
Obh007l^00800005Obh007l^001o;P0200001Gl^001o;P00Obh00P000Wl^0P0000=o;P00Ool0OGoo
00<007ooOol0>Woo00<007ooOol0<7oo000hOol2000BOol200000goo001oo`3eOol00`00Oomoo`2F
Ool2O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAA
e00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00GS@00002Obh02`00Obh0
0000Obh007l^001o;P00Obh00P0000Eo;P00Obh007l^00800005Obh007l^001o;P0200001Wl^001o
;P00Obh007moo`03001oogoo03Uoo`03001oogoo031oo`00<7oo0P001Woo0P0057oo0P00mWoo00<0
07ooOol0UWoo0Wk]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D
00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02e7D00<005hd00000Wl^
00/007l^000007l^001o;P00Obh007l^00800005Obh007l^001o;P0200001Gl^001o;P00Obh00P00
00Io;P00Obh007l^001oOol00`00Oomoo`0iOol00`00Oomoo`0`Ool0031oo`<000Aoo`<001Eoo`<0
0?Aoo`03001oogoo09Ioo`9nk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001A
e57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae003001N
=000009o;P0;001o;P00001o;P00Obh007l^001o;P0200001Gl^001o;P00Obh00P0000Eo;P00Obh0
07l^00800006Obh007l^001o;P00P7oo00<007ooOol0>7oo00<007ooOol0<7oo000aOol8000IOol2
003bOol00`00Oomoo`2FOol2O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00
DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;DM@01@00
GS@007l^00000Wl^0P0000Mo;P00Obh007l^001o;P0200001Gl^001o;P00Obh00P0000Eo;P00Obh0
07l^00800003Obh007l^0080089oo`03001oogoo03Moo`03001oogoo031oo`00<Woo1@007Goo0P00
l7oo00<007ooOol0UWoo0Wk]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057D
DM@02e7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02e7D00D005hd
001o;P00009o;P800007Obh007l^001o;P00Obh00P0000Eo;P00Obh007l^00800003Obh007l^0080
0005Obh007l^001o;P020023Ool00`00Oomoo`0fOol00`00Oomoo`0`Ool005Ioo`800>ioo`03001o
ogoo09Ioo`9nk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003
001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae00@001N=000Obh007l^
001o;P00Obh007l^001o;P00Obh200001Gl^001o;P00Obh00P0000=o;P00Obh00P0000Eo;P00Obh0
07l^008008=oo`03001oogoo03Ioo`03001oogoo031oo`00F7oo0P00k7oo00<007ooOol0UWoo0Wk]
00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D
00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02e7D010005hd001o;P00Obh007l^001o;P00
Obh007l^001o;P800005Obh007l^001o;P0200000gl^001o;P0200001Gl^001o;P00Obh00P00Q7oo
00<007ooOol0=Goo00<007ooOol0<7oo001JOol2003ZOol00`00Oomoo`2FOol2O^d00`00DMAAe00:
DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;
DM@00`00DMAAe00:DM@00`00DMAAe00;DM@04000GS@007l^001o;P00Obh007l^001o;P00Obh007l^
0P0000Eo;P00Obh007l^00800003Obh007l^00800005Obh007l^001o;P020025Ool00`00Oomoo`0d
Ool00`00Oomoo`0`Ool005aoo`8000Eoo`03001oogoo0>1oo`03001oogoo09Ioo`9nk@03001Ae57D
00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D
00]Ae003001Ae57D00YAe003001Ae57D00]Ae008001N=000Obh007l^001o;P80009o;P04001o;P00
Obh200001Gl^001o;P00Obh00P0000=o;P00Obh00P0000Eo;P00Obh007l^008008Ioo`03001oogoo
03Aoo`03001oogoo02moo`00GWoo0P000goo00<007ooOol0h7oo00<007ooOol0UWoo0Wk]00<0057D
DM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057D
DM@02e7D00<0057DDM@02U7D00<0057DDM@02e7D00H005hd001o;P00Obh200001Wl^001o;Wl^001o
;P800007Obh007l^001o;P00Obh00P0000=o;P00Obh00P0000Eo;P00Obh007l^008008Ioo`03001o
ogoo03Aoo`03001oogoo02moo`00H7oo0`00hgoo00<007ooOol0Ugoo0Wk]00<0057DDM@02U7D00<0
057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0
057DDM@02U7D00<0057DDM@02e7D00H005hd001o;P00Obh2000017l^001o;P000Wl^0P0000Mo;P00
Obh007l^001o;P0200000gl^001o;P0200001Gl^001o;P00Obh00P00Qgoo00<007ooOol0<goo00<0
07ooOol0;goo001ROol2003ROol00`00Oomoo`2GOol2O^d00`00DMAAe00:DM@00`00DMAAe00:DM@0
0`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@0
0`00DMAAe00;DM@01P00GS@007l^001o;P80000?Obh007l^001o;P00Obh007l^001o;P00Obh007l^
00800003Obh007l^00800005Obh007l^001o;P020028Ool00`00Oomoo`0bOol00`00Oomoo`0_Ool0
06Aoo`800>1oo`03001oogoo09Moo`9nk@03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YA
e003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00]A
e006001N=000Obh007l^0P0000mo;P00Obh007l^001o;P00Obh007l^001o;P00Obh00P0000=o;P00
Obh00P0000Eo;P00Obh007l^008008Qoo`03001oogoo039oo`03001oogoo02moo`00IWoo0P00gWoo
00<007ooOol0Ugoo0Wk]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@0
2U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00H005hd001o
;P00Obh200003gl^001o;P00Obh007l^001o;P00Obh007l^001o;P0200000gl^001o;P0200001Gl^
001o;P00Obh00P00RGoo00<007ooOol0<Goo00<007ooOol0;goo001XOol2003LOol00`00Oomoo`2G
Ool2O^d00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAA
e00:DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@01P00GS@007l^001o;P800007
Obh007l^001o;P00Obh00P000Wl^0P000Wl^0P0000=o;P00Obh00P0000Eo;P00Obh007l^008008Yo
o`03001oogoo031oo`03001oogoo02moo`00JWoo0P00fWoo00<007ooOol0Ugoo0Wk]00<0057DDM@0
2U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@0
2U7D00<0057DDM@02U7D00<0057DDM@02e7D00H005hd001o;P00Obh200001gl^001o;P00Obh007l^
0080009o;P800007Obh007l^001o;P00Obh00P0000Eo;P00Obh007l^008008]oo`03001oogoo02mo
o`03001oogoo02moo`00K7oo0P00f7oo00<007ooOol0Ugoo0Wk]00<0057DDM@02U7D00<0057DDM@0
2U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@0
2e7D00<0057DDM@02U7D00H005hd001o;P00Obh200001gl^001o;P00Obh007l^0080000;Obh007l^
001o;P00Obh007l^001o;P0200001Gl^001o;P00Obh00P00Rgoo00<007ooOol0;goo00<007ooOol0
;goo001^Ool20005Ool00`00Oomoo`3>Ool00`00Oomoo`2GOol2O^d00`00DMAAe00:DM@00`00DMAA
e00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAA
e00;DM@00`00DMAAe00:DM@01P00GS@007l^001o;P800007Obh007l^001o;P00Obh00P0000]o;P00
Obh007l^001o;P00Obh007l^00800005Obh007l^001o;P02002<Ool00`00Oomoo`0^Ool00`00Oomo
o`0_Ool0071oo`8000=oo`03001oogoo0<ioo`03001oogoo09Moo`9nk@03001Ae57D00YAe003001A
e57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae003001A
e57D00YAe003001Ae57D00]Ae0800003Obh007l^00800007Obh007l^001o;P00Obh00P0000]o;P00
Obh007l^001o;P00Obh007l^00800005Obh007l^001o;P02002=Ool00`00Oomoo`0]Ool00`00Oomo
o`0_Ool0079oo`04001oogoo003@Ool00`00Oomoo`2GOol2O^d00`00DMAAe00:DM@00`00DMAAe00:
DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:
DM@00`00DMAAe00;DM@200000gl^001o;P0200001gl^001o;P00Obh007l^00800007Obh007l^001o
;P00Obh00P000Wl^0P0000Eo;P00Obh007l^008008eoo`03001oogoo02eoo`03001oogoo02moo`00
@Woo1P003Goo10006Woo0`00d7oo00<007ooOol0Ugoo0Wk]00<0057DDM@02U7D00<0057DDM@02U7D
00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D
00<0057DDM@02e7D0P0000=o;P00Obh00P0000Mo;P00Obh007l^001o;P0200001gl^001o;P00Obh0
07l^0080009o;P800005Obh007l^001o;P02002>Ool00`00Oomoo`0/Ool00`00Oomoo`0_Ool0045o
o`P000Yoo`P001Yoo`800<moo`03001oogoo09Moo`9nk@03001Ae57D00YAe003001Ae57D00YAe003
001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003
001Ae57D00]Ae0800003Obh007l^00800007Obh007l^001o;P00Obh00P0000Mo;P00Obh007l^001o
;P0200002Gl^001o;P00Obh007l^001o;P02002?Ool00`00Oomoo`0[Ool00`00Oomoo`0_Ool0041o
o`<000Aoo`<000Uoo`8000Aoo`8001aoo`800<eoo`03001oogoo09Moo`9nk@03001Ae57D00YAe003
001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae003
001Ae57D00YAe003001Ae57D00]Ae0800003Obh007l^00800007Obh007l^001o;P00Obh00P0000Eo
;P00Obh007l^00800009Obh007l^001o;P00Obh007l^00800003Obh007oo08moo`03001oogoo02Yo
o`03001oogoo02moo`00?goo0`001Woo0`001goo0P001Woo0P007Goo0P00bgoo00<007ooOol0Ugoo
0Wk]00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@0
2U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02e7D0P0000=o;P00Obh00P0000Mo;P00
Obh007l^001o;P0200001Gl^001o;P00Obh00P0000Uo;P00Obh007l^001o;P00Obh00P0000=o;P00
Ool0Sgoo00<007ooOol0:Woo00<007ooOol0;goo000oOol20008Ool20007Ool20006Ool2000OOol2
0039Ool00`00Oomoo`2HOol00gk]001Ae00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAA
e00;DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;DM@01@00Obio
;P00Obh00P0000Mo;P00Obh007l^001o;P0200001Gl^001o;P00Obh00P0000Eo;P00Obh007l^0080
009o;P800003Obh007oo091oo`03001oogoo02Uoo`03001oogoo02moo`00?goo0P0027oo0P001Woo
0P0027oo0P0087oo0P00agoo00<007ooOol0V7oo00=nk@00DM@02e7D00<0057DDM@02U7D00<0057D
DM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057D
DM@02e7D00D007l^Obh007l^00800007Obh007l^001o;P00Obh00P0000Eo;P00Obh007l^00800005
Obh007l^001o;P0200001Wl^001o;P00Obh0099oo`03001oogoo02Qoo`03001oogoo02moo`00?goo
0P0027oo0P001Woo0P0027oo0P008Woo0P001Goo00<007ooOol0_Goo00<007ooOol0V7oo00=nk@00
DM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057D
DM@02e7D00<0057DDM@02U7D00<0057DDM@02e7D00<007l^00000Wl^0P0000Mo;P00Obh007l^001o
;P0200001Gl^001o;P00Obh00P0000=o;P00Obh00P0000Qo;P00Obh007l^001o;P00Tgoo00<007oo
Ool0:7oo00<007ooOol0;Woo000oOol30006Ool30006Ool20008Ool2000TOol20003Ool00`00Oomo
o`2mOol00`00Oomoo`2HOol00gk]001Ae00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAA
e00;DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00Obh0
0002Obh200001gl^001o;P00Obh007l^00800005Obh007l^001o;P0200000gl^001o;P02000027l^
001o;P00Obh007l^002COol00`00Oomoo`0XOol00`00Oomoo`0^Ool0041oo`<000Aoo`<000Moo`80
00Qoo`8002Ioo`800003Ool007oo0;ioo`03001oogoo09Qoo`03O^d0057D00]Ae003001Ae57D00YA
e003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YA
e003001Ae57D00]Ae00>001o;P00Obh007l^001o;P00Obh007l^001o;P800005Obh007l^001o;P02
00000gl^001o;P0200001Gl^001o;P00Obh00P00UGoo00<007ooOol09goo00<007ooOol0;Woo0011
Ool80008Ool20008Ool2000XOol2002oOol00`00Oomoo`2HOol00gk]001Ae00;DM@00`00DMAAe00:
DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:
DM@00`00DMAAe00;DM@03P00Obh007l^001o;P00Obh007l^001o;P00Obh200001Gl^001o;P00Obh0
0P0000=o;P00Obh00P0000Eo;P00Obh007l^008009Ioo`03001oogoo02Ioo`03001oogoo02ioo`00
@Goo200027oo0P0027oo0P00:Woo0P00_Goo00<007ooOol0V7oo00=nk@00DM@02e7D00<0057DDM@0
2U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@0
2U7D00<0057DDM@02e7D00@007l^001o;P80009o;P06001o;P00Obh007l^0P0000Eo;P00Obh007l^
00800003Obh007l^00800005Obh007l^001o;P02002FOol00`00Oomoo`0VOol00`00Oomoo`0^Ool0
041oo`<000Aoo`<000Moo`8000Qoo`8002aoo`800;Yoo`03001oogoo09Uoo`03O^d0057D00]Ae003
001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae003
001Ae57D00YAe003001Ae57D00]Ae004001o;P00Obh2000027l^001o;Wl^001o;P00Obh200001Gl^
001o;P00Obh00P0000=o;P00Obh00P0000Eo;P00Obh007l^008009Moo`03001oogoo02Eoo`03001o
ogoo02ioo`00?goo0P0027oo0P001Woo0P0027oo0P00;Woo0P00^7oo00<007ooOol0VGoo00=nk@00
DM@02e7D00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057D
DM@02e7D00<0057DDM@02U7D00<0057DDM@02e7D00@007l^001o;P800008Obh007l^Obh007l^001o
;P800005Obh007l^001o;P0200000gl^001o;P0200001Gl^001o;P00Obh00P00V7oo00<007ooOol0
97oo00<007ooOol0;Woo000oOol20008Ool20007Ool20006Ool2000aOol20009Ool00`00Oomoo`2Z
Ool00`00Oomoo`2IOol00gk]001Ae00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;
DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAAe00;DM@01000Obh007l^
0P0000Ao;P00Obh0009o;P09001o;P00001o;P00Obh007l^00800003Obh007l^00800005Obh007l^
001o;P02002IOol00`00Oomoo`0SOol00`00Oomoo`0^Ool003moo`8000Qoo`8000Moo`8000Ioo`80
03=oo`8000Moo`03001oogoo0:Yoo`03001oogoo09Uoo`03O^d0057D00]Ae003001Ae57D00YAe003
001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003
001Ae57D00]Ae004001o;P00Obh200001Wl^001o;P00Obh0009o;P800005Obh007l^001o;P020000
0gl^001o;P0200001Gl^001o;P00Obh00P00VGoo00<007ooOol08goo00<007ooOol0;Woo0010Ool3
0004Ool40008Ool20004Ool2000fOol20005Ool00`00Oomoo`2ZOol00`00Oomoo`2IOol00gk]001A
e00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:DM@00`00DMAA
e00;DM@00`00DMAAe00:DM@00`00DMAAe004DM@800000gl^001o;P0200003gl^001o;P00Obh007l^
001o;P00Obh007l^001o;P0200000gl^001o;P0200001Gl^001o;P00Obh00P00VWoo00<007ooOol0
8Woo00<007ooOol0;Woo0010Ool:0009Ool8000hOol20002Ool00`00Oomoo`2[Ool00`00Oomoo`2I
Ool00gk]001Ae00;DM@00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe00;DM@00`00DMAAe00:
DM@00`00DMAAe00;DM@00`00DMAAe007DM@:0008>el200004Wl^000007l^001o;P00Obh007l^001o
;P00Obh007l^001o;P800003Obh007l^00800005Obh007l^001o;P02002KOol00`00Oomoo`0QOol0
0`00Oomoo`0^Ool0049oo`H000eoo`@003aoo`<00:eoo`03001oogoo09Uoo`03O^d0057D00]Ae003
001Ae57D00YAe003001Ae57D00YAe003001Ae57D00]Ae003001Ae57D00YAe003001Ae57D00]Ae003
001Ae57D00L000@kG`03000kGc]O00`kG`0;001o;P00001o;P00Obh007l^001o;P020002Obh01000
Obh007l^0P0000=o;P00Obh00P0000Eo;P00Obh007l^008009]oo`03001oogoo025oo`03001oogoo
02ioo`00Ugoo0P00[7oo00<007ooOol0VWoo00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@0
2U7D00<0057DDM@02e7D00<0057DDM@02U7D00<0057DDM@0157D2P0033]O1`0023]O0`0000Mo;P00
Obh007l^001o;P020002Obh01000Obh007l^0P0000=o;P00Obh00P0000Eo;P00Obh007l^008009ao
o`03001oogoo021oo`03001oogoo02ioo`00VGoo0P00ZWoo00<007ooOol0VWoo00<0057DDM@02U7D
00<0057DDM@02U7D00<0057DDM@02U7D00<0057DDM@02e7D00<0057DDM@0157D3@002C]O1`001c]O
00<003]O>el033]O0P0000Mo;P00Obh007l^001o;P0200001Wl^001o;Wl^001o;P800003Obh007l^
00800005Obh007l^001o;P02002MOol00`00Oomoo`0OOol00`00Oomoo`0^Ool009]oo`800:Qoo`03
001oogoo09Yoo`03001Ae57D00YAe003001Ae57D00YAe003001Ae57D00YAe003001Ae57D00AAe0h0
00PkG`L000PkG`03000kGc]O00/kG`L000PkG`08001o;P00Obh007l^001o;P800004Obh007l^0002
Obh200000gl^001o;P0200001Gl^001o;P00Obh00P00WWoo00<007ooOol07Woo00<007ooOol0;Woo
002MOol2002VOol00`00Oomoo`2JOol00`00DMAAe00:DM@00`00DMAAe00:DM@00`00DMAAe004DM@=
0009>el70007>el00`00>elkG`0<>el70008>el70007>el200001Gl^001o;P00Obh00P0000]o;P00
Obh007l^001o;P00Obh007l^00800005Obh007l^001o;P02002NOol00`00Oomoo`0NOol00`00Oomo
o`0^Ool009moo`800:Aoo`03001oogoo09Yoo`03001Ae57D00YAe003001Ae57D00AAe0d000LkG`03
000kGc]O008kG`L000@kG`03000kGc]O00/kG`L000LkG`03000kGc]O008kG`L000@kG`03000kGc]O
00/kG`06001o;P00Obh007l^0P0000]o;P00Obh007l^001o;P00Obh007l^00800005Obh007l^001o
;P02002OOol00`00Oomoo`0MOol00`00Oomoo`0^Ool00:5oo`8000Eoo`03001oogoo09Yoo`03001o
ogoo09Yoo`03001Ae57D00AAe0d000LkG`03000kGc]O00/kG`@000`kG`L000LkG`03000kGc]O00/k
G`@000`kG`L000LkG`800003Obh007l^0080000;Obh007l^001o;P00Obh007l^001o;P0200001Gl^
001o;P00Obh00P00X7oo00<007ooOol077oo00<007ooOol0;Woo002SOol20003Ool00`00Oomoo`2J
Ool00`00Oomoo`2JOol70007>el00`00>elkG`0;>el70008>el70008>el00`00>elkG`0;>el70008
>el70008>el00`00>elkG`0;>el300002Wl^000007l^001o;P00Obh007l^0P000Wl^0P0000Eo;P00
Obh007l^00800:1oo`03001oogoo01aoo`03001oogoo02ioo`00YGoo0P0000=oo`00Ool0Vgoo00<0
07ooOol0Vgoo00<003]O>el02c]O1`0023]O1`0023]O00<003]O>el02c]O1`0023]O1`001c]O00<0
03]O>el033]O1`0023]O00T007l^000007l^001o;P00Obh00P0000Ao;P00Obio;P800005Obh007l^
001o;P02002QOol00`00Oomoo`0LOol00`00Oomoo`0]Ool00:Moo`8009aoo`03001oogoo09aoo`L0
00PkG`L000LkG`03000kGc]O00`kG`L000PkG`L000LkG`03000kGc]O00/kG`L000PkG`L000PkG`<0
0005Obh007l^001o;P0200002gl^001o;P00Obh007l^001o;P00Obh00P00XWoo00<007ooOol06goo
00<007ooOol0;Goo002YOol2002JOol00`00Oomoo`2NOol70007>el00`00>elkG`0;>el70009>el7
0007>el00`00>elkG`0;>el70008>el70007>el00`00>elkG`0<>el200001Gl^001o;P00Obh00P00
00]o;P00Obh007l^001o;P00Obh007l^00800:=oo`03001oogoo01Yoo`03001oogoo02eoo`00Zgoo
0P00V7oo00<007ooOol0Wgoo00<003]O>el02c]O1`0023]O1`0023]O00<003]O>el02c]O1`0023]O
1`001c]O00<003]O>el02c]O1`0023]O00H007l^001o;P00Obh200002gl^001o;P00Obh007l^001o
;P00Obh00P00Xgoo00<007ooOol06Woo00<007ooOol0;Goo002]Ool2002FOol00`00Oomoo`2POol7
0007>el01000>elkGc]O1`0013]O00<003]O>el033]O1`001c]O00@003]O>elkG`L000@kG`03000k
Gc]O00/kG`L000LkG`04000kGc]O>el70004>el200000gl^001o;P0200000gl^001o;P0200001Wl^
001o;Wl^001o;P800:Aoo`03001oogoo01Uoo`03001oogoo02eoo`00[goo0P00U7oo00<007ooOol0
XGoo00<003]O>el02c]O0`0033]O1`0023]O00<003]O>el02c]O0`0033]O1`001c]O00<003]O>el0
2c]O0`0033]O00@007l^001o;P800003Obh007l^00800004Obh007l^0002Obh2002UOol00`00Oomo
o`0HOol00`00Oomoo`0]Ool00;5oo`8000Eoo`03001oogoo08Yoo`03001oogoo0:9oo`L000PkG`L0
00LkG`03000kGc]O00`kG`L000PkG`L000LkG`03000kGc]O00/kG`L000PkG`L000LkG`800006Obh0
0000Obh007l^0P0000Qo;P00Obh007l^001o;P00YWoo00<007ooOol05goo00<007ooOol0;Goo002c
Ool20003Ool00`00Oomoo`2:Ool00`00Oomoo`2TOol70007>el00`00>elkG`0;>el70009>el70007
>el00`00>elkG`0;>el70008>el70007>el00`00>elkG`0;>el400000gl^001o;P02000027l^001o
;P00Obh007l^002VOol00`00Oomoo`0GOol00`00Oomoo`0]Ool00;Eoo`800003Ool007oo08]oo`03
001oogoo0:Eoo`03000kGc]O00/kG`L000TkG`L000LkG`03000kGc]O00/kG`L000PkG`L000LkG`03
000kGc]O00/kG`L000PkG`800003Obh007l^00800005Obh007l^001o;P02002XOol00`00Oomoo`0F
Ool00`00Oomoo`0]Ool00;Moo`8008aoo`03001oogoo0:Ioo`L000TkG`L000LkG`03000kGc]O00/k
G`L000LkG`L000LkG`03000kGc]O00DkG`03000kGc]O00@kG`L000LkG`L000LkG`800003Obh007l^
00800005Obh007l^001o;P02002YOol00`00Oomoo`0EOol00`00Oomoo`0]Ool00;Uoo`8008Yoo`03
001oogoo0:Uoo`L000LkG`03000kGc]O00/kG`L000LkG`L000LkG`03000kGc]O00/kG`L000PkG`L0
00LkG`03000kGc]O00/kG`<00008Obh00000Obh007l^001o;P800:Uoo`03001oogoo01Eoo`03001o
ogoo02eoo`00Rgoo1@003Goo10006Woo0P00R7oo00<007ooOol0ZWoo00<003]O>el02c]O1`0023]O
1P001c]O00<003]O>el02c]O1`0023]O1`001c]O00<003]O>el02c]O1`0023]O00T007l^000007l^
001o;P00Obh00P00ZWoo00<007ooOol057oo00<007ooOol0;Goo0029Ool8000:Ool8000JOol20026
Ool00`00Oomoo`2[Ool70008>el70006>el00`00>elkG`0;>el70008>el70007>el00`00>elkG`0;
>el70008>el70007>el300001Gl^001o;P00Obh00P00Zgoo00<007ooOol04goo00<007ooOol0;Goo
0029Ool20004Ool30009Ool20004Ool2000LOol20024Ool00`00Oomoo`2]Ool70007>el00`00>elk
G`0:>el70008>el70007>el00`00>elkG`0;>el70008>el70007>el00`00>elkG`0;>el200001Gl^
001o;P00Obh00P00[7oo00<007ooOol04Woo00<007ooOol0;Goo0028Ool20006Ool30007Ool20006
Ool2000MOol20004Ool00`00Oomoo`1kOol00`00Oomoo`2^Ool00`00>elkG`0;>el60008>el70007
>el00`00>elkG`0;>el70008>el70007>el00`00>elkG`0;>el70007>el01P00Obh007l^001o;P80
0:aoo`03001oogoo019oo`03001oogoo02eoo`00Qgoo0P0027oo0P001goo0P001Woo0P007goo0P00
0Woo00<007ooOol0Ngoo00<007ooOol0[goo1`0023]O1P001c]O00<003]O>el02c]O1`0023]O1`00
1c]O00<003]O>el02c]O1`001c]O1`001c]O0P0000=o;P00Obh00P00[Goo00<007ooOol04Goo00<0
07ooOol0;Goo0027Ool20008Ool20006Ool20008Ool2000POol3001mOol00`00Oomoo`2aOol70007
>el00`00>elkG`0:>el70008>el70007>el00`00>elkG`0;>el70008>el60007>el00`00>elkG`0;
>el300000gl^0000002^Ool00`00Oomoo`0@Ool00`00Oomoo`0]Ool008Moo`8000Qoo`8000Ioo`80
00Qoo`80029oo`03001oogoo07]oo`03001oogoo0;9oo`03000kGc]O00/kG`H000PkG`L000LkG`03
000kGc]O00/kG`L000PkG`L000HkG`03000kGc]O00/kG`L000PkG`04001o;P00002^Ool00`00Oomo
o`0@Ool00`00Oomoo`0]Ool008Moo`8000Qoo`8000Ioo`8000Qoo`8002=oo`8007]oo`03001oogoo
0;=oo`L000PkG`H000LkG`03000kGc]O00/kG`L000PkG`L000HkG`03000kGc]O00/kG`L000PkG`L0
00LkG`<00:moo`03001oogoo011oo`03001oogoo02aoo`00Qgoo0`001Woo0`001Woo0P0027oo0P00
9Goo0P00NGoo00<007ooOol0]Goo1`001c]O00<003]O>el02S]O1`0023]O1`001c]O00<003]O>el0
2S]O1`0023]O1`001c]O00<003]O>el02c]O0P00/7oo00<007ooOol03goo00<007ooOol0;7oo0027
Ool40004Ool30007Ool20008Ool2000WOol20008Ool00`00Oomoo`1/Ool00`00Oomoo`2fOol00`00
>elkG`0;>el60008>el70007>el00`00>elkG`0;>el60008>el70007>el00`00>elkG`0;>el70007
>el00`00Oomoo`2_Ool00`00Oomoo`0>Ool00`00Oomoo`0/Ool008Moo`800003Ool0000000D000Qo
o`8000Qoo`8002Uoo`8000Ioo`03001oogoo06aoo`03001oogoo0;Moo`L000PkG`H000LkG`03000k
Gc]O00/kG`L000LkG`L000LkG`03000kGc]O00/kG`L000LkG`L00;Qoo`03001oogoo00ioo`03001o
ogoo02aoo`00R7oo00<007ooOol01@002Goo0P0027oo0P00:goo0P0017oo00<007ooOol0K7oo00<0
07ooOol0^Goo1`001S]O00<003]O>el02c]O1`0023]O1P001c]O00<003]O>el02c]O1`001c]O1`00
aWoo00<007ooOol03Goo00<007ooOol0;7oo0028Ool2000?Ool20008Ool2000]Ool20002Ool00`00
Oomoo`1/Ool00`00Oomoo`2jOol00`00>elkG`0:>el70008>el70007>el00`00>elkG`0:>el70008
>el6003DOol00`00Oomoo`0<Ool00`00Oomoo`0/Ool008Qoo`<000moo`8000Ioo`80031oo`<006eo
o`03001oogoo0;aoo`H000PkG`L000LkG`03000kGc]O00/kG`H000PkG`L00>5oo`03001oogoo00]o
o`03001oogoo02aoo`00RGoo0`003Woo0P001Woo0P00<Woo0P00K7oo00<007ooOol0_Woo1P001c]O
00<003]O>el02c]O1`001c]O1`00kWoo00<007ooOol02goo00<007ooOol0;7oo002:Ool3000>Ool2
0004Ool2000eOol2001ZOol00`00Oomoo`2oOol00`00>elkG`0:>el70008>el6003lOol00`00Oomo
o`0:Ool00`00Oomoo`0/Ool008]oo`P000Qoo`P003Moo`8006Qoo`03001oogoo0<1oo`H000PkG`L0
0?moo`Yoo`03001oogoo00Uoo`03001oogoo02aoo`00SGoo1P002Woo1000>goo0P00IWoo00<007oo
Ool0`Woo1P00ogoo5goo00<007ooOol02Goo00<007ooOol0;7oo003NOol20005Ool00`00Oomoo`1L
Ool00`00Oomoo`3oOooPOol00`00Oomoo`08Ool00`00Oomoo`0/Ool00>1oo`8000=oo`03001oogoo
05aoo`03001oogoo0?moon5oo`03001oogoo00Moo`03001oogoo02aoo`00hWoo0P0000=oo`00Ool0
GGoo00<007ooOol0ogoohWoo00<007ooOol01Woo00<007ooOol0;7oo003TOol2001NOol00`00Oomo
o`3oOooROol00`00Oomoo`06Ool00`00Oomoo`0/Ool00>Ioo`8005aoo`03001oogoo0?moon=oo`03
001oogoo00Eoo`03001oogoo02aoo`00j7oo0P00FWoo00<007ooOol0ogooi7oo00<007ooOol017oo
00<007ooOol0;7oo003ZOol2001HOol00`00Oomoo`3oOooTOol00`00Oomoo`04Ool00`00Oomoo`0/
Ool00>aoo`8000Eoo`03001oogoo04ioo`03001oogoo0?moonEoo`03001oogoo00=oo`03001oogoo
02aoo`00kWoo0P000goo00<007ooOol0CWoo00<007ooOol0ogooiWoo00<007ooOol00goo00<007oo
Ool0:goo003`Ool200000goo001oo`1?Ool00`00Oomoo`3oOooWOol00`00Oomoo`02Ool00`00Oomo
o`0[Ool00?9oo`80051oo`03001oogoo0?moonMoo`03001oogoo009oo`03001oogoo02]oo`00m7oo
0P00CWoo00<007ooOol0ogooj7oo00D007ooOomoo`0002eoo`00mWoo0P00C7oo00<007ooOol0ogoo
jGoo00@007ooOol002eoo`00n7oo0P00BWoo00<007ooOol0ogoojGoo00@007ooOol002eoo`00bgoo
1`002Woo10006Woo0P0017oo00<007ooOol0@Goo00<007ooOol0ogoojWoo00<007oo0000;Goo003;
Ool70008Ool8000JOol20002Ool00`00Oomoo`11Ool00`00Oomoo`3oOoo[Ool2000]Ool00<ioo`80
00Yoo`8000Aoo`8001aoo`<004=oo`03001oogoo0?moonEoo`P002eoo`00cWoo0P002Goo0P001Woo
0P007Goo0P00@Woo00<007ooOol0ogooegoo3P00=Goo003>Ool20009Ool20006Ool2000OOol2000:
Ool00`00Oomoo`0cOol00`00Oomoo`3oOoo9Ool>0013Ool00<Ioo``000Ioo`8000Qoo`80021oo`80
00Qoo`03001oogoo03=oo`03001oogoo0?mookYoo`l0055oo`00aWoo30001Woo0P0027oo0P008Woo
0P001Woo00<007ooOol0<goo00<007ooOol0ogoo[7oo3P00H7oo0036Ool20006Ool200000goo001o
o`05Ool20008Ool2000TOol20004Ool00`00Oomoo`0cOol00`00Oomoo`3oOonNOol>001^Ool00<Mo
o`8000Eoo`8000Qoo`8000Qoo`8002Ioo`80009oo`03001oogoo03=oo`03001oogoo0?mooi1oo`h0
07aoo`00agoo0`0017oo0P0027oo0P0027oo0P00:7oo0`00=Goo00<007ooOol0ogooPWoo3P00RWoo
0038Ool20004Ool20008Ool20008Ool2000ZOol2000dOol00`00Oomoo`3oOomdOol>002HOol00<Uo
o`8000=oo`8000Qoo`8000Qoo`8002aoo`80039oo`03001oogoo0?moofIoo`h00:Ioo`00bGoo0`00
0Woo0P0027oo0P0027oo0P00;Woo0P00<7oo00<007ooOol0ogooEgoo3`00]7oo003:Ool20002Ool2
0009Ool20006Ool2000aOol20004Ool00`00Oomoo`0WOol00`00Oomoo`3oOom9Ool>0033Ool00<]o
o`800003Ool0000000Uoo`8000Ioo`8003=oo`80009oo`03001oogoo02Moo`03001oogoo0?mooc]o
o`h00=5oo`00c7oo10002Woo0P0017oo0P00=Woo0`00:Goo00<007ooOol0ogoo;Goo3P00ggoo003<
Ool4000:Ool8000hOol00`00Oomoo`0WOol00`00Oomoo`3oOolOOol>003]Ool00<eoo`<000aoo`@0
03]oo`8002Moo`03001oogoo0?mooa5oo`h00?]oo`00ogoo7Woo0P009Goo00<007ooOol0ogoo0goo
3P00ogoo2Woo003oOolPOol20006Ool00`00Oomoo`0IOol00`00Oomoo`3dOol?003oOolHOol00?mo
ob9oo`8000Aoo`03001oogoo01Uoo`03001oogoo0>Ioo`h00?moobMoo`00ogoo97oo0P000Woo00<0
07ooOol06Goo00<007ooOol0f7oo3P00ogoo=Goo003oOolVOol3000KOol00`00Oomoo`3:Ool>003o
Oom3Ool00?moobQoo`8001Yoo`03001oogoo0;aoo`h00?mooe5oo`00ogoo:Woo0P0067oo00<007oo
Ool0[Woo3P00ogooGgoo003oOol/Ool20006Ool00`00Oomoo`0=Ool00`00Oomoo`2POol>003oOom]
Ool00?moobioo`8000Aoo`03001oogoo00eoo`03001oogoo095oo`l00?moog]oo`00ogoo<7oo0P00
0Woo00<007ooOol03Goo00<007ooOol0Pgoo3P00ogooRWoo003mOol<000;Ool4000IOol3000?Ool0
0`00Oomoo`1eOol>003oOonHOol00?eoo``000Uoo`P001Uoo`8000Yoo`05001oogooOol0001YOol>
003oOonVOol00?ioo`<000Ioo`8000Uoo`8000Aoo`8001]oo`8000Qoo`05001oogooOol0001KOol>
003oOondOol00?moo`<000moo`8000Ioo`8001aoo`8000Ioo`05001oogooOol0001=Ool>003oOoo2
Ool00?moo`5oo`<000ioo`8000Ioo`8001ioo`8000Aoo`05001oogooOol0000oOol>003oOoo@Ool0
0?moo`9oo`<000aoo`8000Qoo`8001moo`80009oo`05001oogooOol0000`Ool?003oOooNOol00?mo
o`=oo`<000]oo`8000Qoo`80025oo`<000=oo`03001oogoo021oo`h00?mooneoo`00ogoo17oo0`00
2Woo0P0027oo0P008goo0P000Woo00<007ooOol04Woo3P00ogoongoo003oOol5Ool30009Ool20008
Ool2000UOol30006Ool>003oOoooOol:Ool00?moo`Ioo`<000Qoo`8000Qoo`8002Moo`L00?mooomo
oaQoo`00ogoo1goo0P0027oo0P0027oo0P00ogooogooAWoo003oOol8Ool20007Ool20008Ool2003o
OoooOom6Ool00?moo`Qoo`8000Moo`8000Qoo`800?mooomoodIoo`00oWoo0P001goo0P0027oo0P00
1Woo0P00ogooogooAgoo003nOol30006Ool20008Ool20006Ool2003oOoooOom7Ool00?ioo`@000Ao
o`8000Yoo`8000Aoo`800?mooomoodQoo`00ogoo20002goo2000ogooogooB7oo003oOol2Ool5000>
Ool4003oOoooOom:Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooceoo`@00?mooomoob9oo`00
ogoo>goo2000ogooogoo87oo003oOolkOol20004Ool2003oOoooOolPOol00?moocYoo`8000Ioo`80
0?mooomooamoo`00ogoo>Woo0P001Woo0P00ogooogoo7goo003oOoliOol20008Ool2003oOoooOolN
Ool00?moocUoo`8000Qoo`800?mooomooaioo`00ogoo>Goo0P0027oo0P00ogooogoo7Woo003oOoli
Ool20008Ool2003oOoooOolNOol00?moocUoo`8000Qoo`800?mooomooaioo`00ogoo>Goo0P0027oo
0P00ogooogoo7Woo003oOoliOol20008Ool2003oOoooOolNOol00?moocUoo`8000Qoo`800?mooomo
oaioo`00ogoo>Woo0P001Woo0P00ogooogoo7goo003oOoljOol20006Ool2003oOoooOolOOol00?mo
oc]oo`8000Aoo`800?mooomoob1oo`00ogoo>goo2000ogooogoo87oo003oOolmOol4003oOoooOolR
Ool00?mooomooomoof=oo`00ogooogooogooHgoo0000\
\>"], "Graphics",
  CellLabel->"From In[18]:=",
  Evaluatable->False,
  ImageSize->{288, 173.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["\<\
This picture shows the location of the dielectrics and of the \
conductors in the plane.\
\>", "Text",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell["calculate potential", "Subsubsection"],

Cell["\<\
To accelerate the calculation we obtain a rough guess u1 (without \
dielectrics) on a coarser grid 
(# points/4 -> faster ) as initial matrix. u1 has already some similarity to \
the true distribution:\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
nz1=nz/2;ns1=ns/2;u1=.;m1=.;
m1=Array[u1,{nz1,ns1}];a1=Array[u1,{nz1,ns1}];
Do[Do[a1[[i,j]]=u1[[i,j]],{j,1,ns1}],{i,1,nz1}]
Do[Do[
m1[[i,j]]:=Evaluate[0.25(a1[[i-1,j]]+a1[[i+1,j]]+a1[[i,j-1]]+a1[[i,j+1]])],
{j,2,ns1-1}],{i,2,nz1-1}];
Do[m1[[1,j]]:=0.,{j,1,ns1}];
Do[m1[[nz1,j]]:=0.,{j,1,ns1}];
Do[m1[[i,1]]:=0.,{i,1,nz1}];
Do[m1[[i,ns1]]:=0.,{i,1,nz1}];
(* guess for coordinates:old/2;
mb is used to identify location of conductors*)
Do[Do[If[mb[[2i,2j]]==1,m1[[i,j]]=m[[2i,2j]]],{i,nz1}],
{j,ns1}]\
\>", "Input",
  CellLabel->"In[21]:=",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}},
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(Part::"partd" \(\(:\)\(\ \)\) 
      "Part specification \!\(u1 \[LeftDoubleBracket] \(\(1, 1\)\) \
\[RightDoubleBracket]\) is longer than depth of object."\)], "Message",
  CellLabel->"From In[21]:="],

Cell[BoxData[
    \(Part::"partd" \(\(:\)\(\ \)\) 
      "Part specification \!\(u1 \[LeftDoubleBracket] \(\(1, 2\)\) \
\[RightDoubleBracket]\) is longer than depth of object."\)], "Message",
  CellLabel->"From In[21]:="],

Cell[BoxData[
    \(Part::"partd" \(\(:\)\(\ \)\) 
      "Part specification \!\(u1 \[LeftDoubleBracket] \(\(1, 3\)\) \
\[RightDoubleBracket]\) is longer than depth of object."\)], "Message",
  CellLabel->"From In[21]:="],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Part :: \"partd\"\) will be suppressed during \
this calculation."\)], "Message",
  CellLabel->"From In[21]:="]
}, Open  ]],

Cell["Let Laplace do his work...", "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell["\<\
u1=Table[0.,{i,1,nz1},{j,1,ns1}];
Timing[Do[{u1=m1;
If[Mod[i,500]==0,
Print[i,\" residual error:\",Max[Flatten[Abs[u1-m1]]]]]},
{i,1,1000}]]\
\>", "Input",
  CellLabel->"In[31]:=",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}},
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    InterpretationBox[\(500\[InvisibleSpace]" residual error:"\
\[InvisibleSpace]8.45627812959271`*^-6\),
      SequenceForm[ 500, " residual error:", 8.4562781295927092*^-06],
      Editable->False]], "Print",
  CellLabel->"From In[31]:="],

Cell[BoxData[
    InterpretationBox[\(1000\[InvisibleSpace]" residual error:"\
\[InvisibleSpace]2.2568347621265694`*^-8\),
      SequenceForm[ 1000, " residual error:", 2.2568347621265694*^-08],
      Editable->False]], "Print",
  CellLabel->"From In[31]:="],

Cell[BoxData[
    \({22.`\ Second, Null}\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell["\<\
The coarse grid u1 is interpolated to calculate intermediate points \

for the final higher resolution grid u (j -> x, i -> y)\
\>", "Text"],

Cell[BoxData[
    \(\(p = ListInterpolation[Transpose[u1]];\)\)], "Input",
  CellLabel->"In[33]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell["Control plot of interpolation:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[p[x, y], {x, 1, ns1}, {y, 1, nz1}, PlotRange \[Rule] All, 
      PlotPoints \[Rule] 30, ViewPoint \[Rule] {3. , 1. , 1. }]\)], "Input",
  CellLabel->"In[34]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P00022A000`40O003h00OogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomoolioo``000]oo`@007Uoo`00ogooogoocWoo30002Goo2000Mgoo003oOoooOoo?Ool30006Ool2
0009Ool20004Ool2001gOol00?mooomoom1oo`<000moo`8000Ioo`8007Ioo`00ogooogoodGoo0`00
3Woo0P001Woo0P00MWoo003oOoooOooBOol3000<Ool20008Ool2001eOol00?mooomoom=oo`<000]o
o`8000Qoo`8007Eoo`00ogooogooe7oo0`002Woo0P0027oo0P00MGoo003oOoooOooEOol30009Ool2
0008Ool2001eOol00?mooomoomIoo`<000Qoo`8000Qoo`8007Eoo`00ogooogooegoo0P0027oo0P00
27oo0P00MGoo003oOoooOooHOol20007Ool20008Ool2001eOol00?mooomoomQoo`8000Moo`8000Qo
o`8007Eoo`00ogooogoocgoo0P001goo0P0027oo0P001Woo0P00MWoo003oOoooOoo?Ool30006Ool2
0008Ool20006Ool2001fOol00?mooomoolmoo`@000Aoo`8000Yoo`8000Aoo`8007Moo`00ogooogoo
d7oo20002goo2000Mgoo003oOoooOooBOol5000>Ool4001iOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOolLOol:0009Ool6003oOol^Ool00?mo
oomooaaoo`X000Moo`X00?moobaoo`00ogooogoo87oo0P002goo0`001Goo0`00ogoo:goo003oOooo
OolPOol2000DOol2003oOol[Ool00?mooomoob1oo`8001Eoo`800?moobYoo`00ogooogoo87oo0P00
5Goo0P00ogoo:Woo003oOoooOolPOol2000EOol2003oOolZOol00?mooomoob1oo`8001Eoo`800:9o
o`D0089oo`00ogooogoo87oo0P005Goo0P00Vgoo1`0017oo00<007ooOol0P7oo003oOoooOolPOol2
000DOol2002EOol7000;Ool20021Ool00?mooomoob1oo`8000aoo`8000Eoo`<008ioo`L0019oo`80
085oo`00ogooogoo87oo0P0037oo2@00R7oo1`006Goo00<007oo0000P7oo003oOoooOolPOol2000<
Ool200000goo000000030021Ool8000POol00`00Ool00020Ool00?mooomoob1oo`8000aoo`80081o
o`L000=oo`03001oogoo029oo`04001oogoo001oOol00?mooomoob1oo`8000aoo`8007Uoo`L000Yo
o`03001oogoo029oo`04001oogoo001oOol00?mooomooaaoo`<00003Ool0000000aoo`80079oo`L0
015oo`03001oogoo01moo`@000=oo`03001oogoo07aoo`00ogooogoo77oo1P0037oo2P00HWoo2000
=7oo1P000dLo00D007ooOomoo`0007ioo`00ogooogoo7goo0`0037oo2P00Fgoo1`00=Woo1P002DLo
0P000goo00<007ooOol0Ngoo003oOoooOon<Ool70002Ool00`00Oomoo`0bOol6000?Acl20003Ool0
0`00Oomoo`1kOol00?mooomoohEoo`L000Uoo`03001oogoo02]oo`L001E7?`030017?`0000=oo`03
001oogoo07Yoo`00ogooogooOWoo1`0047oo00<007ooOol08goo200014Lo00<004LoAcl05DLo00<0
04Lo00000goo00<007ooOol0NWoo003oOoooOomfOol8000eOol8000=Acl00`00Acm7?`0DAcl01000
Acm7?`000goo00<007ooOol0NGoo003oOoooOom_Ool7000eOol8000EAcl00`00Acm7?`0EAcl00`00
Acl00004Ool00`00Oomoo`1hOol00?moog9oo`X000]oo`@00=aoo`L0009oo`03001oogoo02moo`P0
00A;?`030017?dLo01M7?`030017?dLo01A7?`040017?dLo0003Ool00`00Oomoo`1hOol00?moog9o
o`X000Uoo`P00==oo`L000Uoo`03001oogoo02Moo`P000e;?`030017?dLo01I7?`030017?dLo01A7
?`040017?dLo0004Ool00`00Oomoo`1gOol00?moogIoo`8000eoo`8000Aoo`800<aoo`L0011oo`03
001oogoo01moo`P001E;?`030017?dLo01M7?`030017?dLo01=7?`D000=oo`03001oogoo07Moo`00
ogooMWoo0P0037oo0P001Woo0P00`goo2000<Goo200014/o00<004/oBcl05d/o00<004LoAcl05TLo
00<004LoAcl03TLo1P000d]O00<007ooOol00Woo00<007ooOol0MWoo003oOomfOol2000<Ool20006
Ool2002lOol7000aOol8000=Bcl00`00Bcm;?`0FBcl00`00Acm7?`0GAcl00`00Acm7?`07Acl60005
Bel00`00Bem;G`02Bel01@00Oomoogoo0000N7oo003oOomfOol2000;Ool20008Ool2002dOol70003
Ool00`00Oomoo`0[Ool7000FBcl00`00Bcm;?`0FBcl00`00Acm7?`0FAcl01000Acm7?dLo1P002d]O
00<004]OBel00T]O00<007ooOol00Woo00<007ooOol0MGoo003oOomfOol2000;Ool20008Ool2002]
Ool7000:Ool00`00Oomoo`0UOol60003Bcl00`00Bcm;?`0GBcl00`00Bcm;?`0FBcl00`00Acm7?`0C
Acl7000ABel00`00Bem;G`03Bel01@00Oomoogoo0000Mgoo003oOomfOol2000;Ool20008Ool2002U
Ool8000AOol00`00Oomoo`0POol5000:Bcl00`00Bcm;?`0GBcl00`00Bcm;?`0FBcl00`00Acm7?`0:
Acl80004Bel00`00Bem;G`0ABel00`00Bem;G`03Bel00`00Oomoo`02Ool00`00Oomoo`1dOol00?mo
ogIoo`8000]oo`8000Qoo`8009ioo`L003Ioo`H000m;?`03001;?d/o01M;?`03001;?d/o01I;?`03
0017?dLo0097?`P000e;G`03001;Gd]O011;G`03001;Gd]O00A;G`05001oogooOol0001fOol00?mo
ogIoo`8000]oo`8000Qoo`8009Moo`L003Ioo`L001I;?`03001;?d/o01M;?`03001;?d/o019;?`P0
01I;G`03001;Gd]O00m;G`03001;Gd]O00A;G`03001oogoo009oo`03001oogoo07=oo`00ogooMWoo
0P002goo0P0027oo0P00T7oo1`000goo00<007ooOol0;goo200014/o00<004/oBcl05T/o00<004/o
Bcl064/o00<004/oBcl02D/o200014/o00<004]OBel05d]O00<004]OBel03d]O00<004]OBel01D]O
00D007ooOomoo`0007Eoo`00ogooMWoo0P002goo0P0027oo0P00RGoo1`002Woo00<007ooOol09goo
20003D/o00<004/oBcl05T/o00<004/oBcl05d/o00<004/oBcl00T/o1`003D/o00<004]OBel05d]O
00<004]OBel03T]O00<004]OBel01D]O00<007ooOol00Woo00<007ooOol0LWoo003oOomfOol2000;
Ool20008Ool20021Ool8000BOol00`00Oomoo`0NOol8000FBcl00`00Bcm;?`0FBcl00`00Bcm;?`0D
Bcl7000EBcl00`00Bem;G`0GBel00`00Bem;G`0=Bel00`00Bem;G`02Bel50003Ool00`00Oomoo`1b
Ool00?moogIoo`8000aoo`8000Ioo`8007]oo`L001Yoo`03001oogoo01Ioo`P000A;?`03001;?d/o
01M;?`03001;?d/o01I;?`03001;?d/o00i;?`H000=;?`03001;?d/o01I;?`03001;Gd]O01M;G`03
001;Gd]O00Y;G`P000A;G`03001oogoo009oo`03001oogoo075oo`00ogooMWoo0P0037oo0P001Woo
0P00M7oo1`008Goo00<007ooOol03goo1`003D/o00<004/oBcl05d/o00<004/oBcl05T/o00<004/o
Bcl01d/o1P002T/o00<004/oBcl05T/o00<004]OBel05d]O00<004]OBel00T]O1`000d]O00<004]O
Bel01d]O00D007ooOomoo`0007=oo`00ogooLWoo0`0000=oo`0000003Goo0P0017oo0P00KWoo1`00
1Goo00<007ooOol0:Woo20005D/o00<004/oBcl05T/o00<004/oBcl05T/o00@004/oBcm;?`H0011;
?`03001;?d/o01I;?`03001;Gd]O01E;G`L000Y;G`03001;Gd]O00M;G`03001oogoo009oo`03001o
ogoo071oo`00ogooLWoo1P003Goo2000IWoo200037oo00<007ooOol08Woo200014/o00<004/oBcl0
5T/o00<004/oBcl05d/o00<004/oBcl04T/o1`005d/o00<004/oBcl05T/o00<004]OBel03T]O1P00
0d]O00<004]OBel02d]O00<004]OBel024]O00D007ooOomoo`00079oo`00ogooMGoo0`003goo1000
HGoo1`0057oo00<007ooOol06goo1`003D/o00<004/oBcl05T/o00<004/oBcl05d/o00<004/oBcl0
2D/o200014/o00<004/oBcl05d/o00<004/oBcl05d/o00<004]OBel01d]O1P002T]O00<004]OBel0
2T]O00<004]OBel02D]O00D007ooOomoo`00075oo`00ogooiGoo1`00<Goo20005D/o00<004/oBcl0
5T/o00<004/oBcl05T/o00<004/oBcl00T/o1`003D/o00<004/oBcl05d/o00<004/oBcl05T/o00@0
04]OBem;G`H0011;G`03001;Gd]O00Y;G`03001;Gd]O00U;G`05001oogooOol0001aOol00?moomio
o`L0031oo`P000A;?`03001;?d/o01I;?`03001;?d/o01M;?`03001;?d/o019;?`P001E;?`03001;
?d/o01M;?`03001;?d/o01=;?`H001M;G`03001;Gd]O00U;G`03001;Gd]O00Y;G`05001oogooOol0
001`Ool00?moomMoo`L000Ioo`03001oogoo02Moo`L000e;?`03001;?d/o01I;?`03001;?d/o01I;
?`03001;?d/o00Y;?`P000A;?`03001;?d/o01I;?`03001;?d/o01M;?`03001;?d/o00e;?`H000=;
G`03001;Gd]O01M;G`03001;Gd]O00U;G`03001;Gd]O00Y;G`05001oogooOol0001`Ool00?moolmo
o`P000eoo`03001oogoo021oo`L001E;?`03001;?d/o01I;?`03001;?d/o01I;?`03001;?d/o009;
?`L000e;?`03001;?d/o01I;?`03001;?d/o01M;?`03001;?d/o00M;?`D000Y;G`03001;Gd]O01M;
G`03001;Gd]O00Q;G`03001;Gd]O00Q;G`@000=oo`03001oogoo06eoo`00ogoob7oo1`005Goo00<0
07ooOol06goo1@000d/o00<004/oBcl05T/o00<004/oBcl05T/o00<004/oBcl054/o1`005D/o00<0
04/oBcl05D/o00<004/oBcl05d/o00@004/oBcm;?`H000m;G`03001;Gd]O01M;G`03001;Gd]O00Q;
G`03001;Gd]O009;G`H000=;G`05001oogooOol0001_Ool00=Yoo`H00>1oo`L003Aoo`H000U;?`03
001;?d/o01I;?`03001;?d/o01I;?`03001;?d/o00e;?`H000=;?`03001;?d/o01I;?`03001;?d/o
01I;?`03001;?d/o01=;?`L001I;G`03001;Gd]O01M;G`03001;Gd]O00M;G`D000Y;G`05001oogoo
Ool0001^Ool00=Qoo`X00=Moo`L00003Ool007oo03=oo`D0011;?`03001;?d/o01I;?`03001;?d/o
01E;?`03001;?d/o00Q;?`D000Y;?`03001;?d/o01I;?`03001;?d/o01I;?`03001;?d/o00Y;?`P0
00A;?`03001;Gd]O01I;G`03001;Gd]O01M;G`04001;Gd]OBel7000>Bel01@00Oomoogoo0000KWoo
003HOol30005Ool3003?Ool70008Ool00`00Oomoo`0[Ool7000FBcl00`00Bcm;?`0EBcl00`00Bcm;
?`0FBcl01000Bcm;?d/o1P003d/o00<004/oBcl05T/o00<004/oBcl05T/o00<004/oBcl00T/o2000
3D/o00<004]OBel05T]O00<004]OBel054]O1P001T]O00<004]OBel03D]O00D007ooOomoo`0006eo
o`00hGoo0P00agoo20003goo00<007ooOol08goo200014/o00<004/oBcl05T/o00<004/oBcl05T/o
00<004/oBcl04T/o1`005T/o00<004/oBcl05T/o00<004/oBcl04T/o20005D/o00<004]OBel05T]O
00<004]OBel03T]O1P000d]O00<004]OBel01d]O00<004]OBel034]O00<007ooOol00Woo00<007oo
Ool0JWoo003ROol2002oOol7000GOol00`00Oomoo`0LOol7000=Bcl00`00Bcm;?`0FBcl00`00Bcm;
?`0EBcl00`00Bcm;?`0:Bcl80004Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0GBcl00`00Bcm;?`09Bcl8
0004Bcl00`00Bcm;?`0GBcl00`00Bem;G`0FBel00`00Bem;G`07Bel6000:Bel00`00Bem;G`06Bel0
0`00Bem;G`0=Bel01@00Oomoogoo0000K7oo003ROol2002hOol7000eOol8000EBcl00`00Bcm;?`0F
Bcl00`00Bcm;?`0EBcl00`00Bcm;?`02Bcl7000=Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0FBcl00`00
Bcm;?`02Bcl7000=Bcl00`00Bcm;?`0GBcl00`00Bem;G`0EBel01000Bem;Gd]O1P0044]O00<004]O
Bel01T]O00<004]OBel03D]O00<007ooOol00Woo00<007ooOol0JGoo003ROol2002aOol70003Ool0
0`00Oomoo`0_Ool70004Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0FBcl00`00Bcm;?`0BBcl8000EBcl0
0`00Bcm;?`0FBcl00`00Bcm;?`0CBcl7000EBcl00`00Bcm;?`0FBcl00`00Bem;G`0BBel7000GBel0
0`00Bem;G`05Bel00`00Bem;G`0>Bel01@00Oomoogoo0000Jgoo003ROol2002YOol8000:Ool00`00
Oomoo`0XOol7000<Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0FBcl00`00Bcm;?`0:Bcl70004Bcl00`00
Bcm;?`0FBcl00`00Bcm;?`0FBcl00`00Bcm;?`0=Bcl60003Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0G
Bcl00`00Bem;G`09Bel80004Bel00`00Bem;G`0GBel00`00Bem;G`05Bel00`00Bem;G`0>Bel00`00
Oomoo`02Ool00`00Oomoo`1XOol00>9oo`800:9oo`L0019oo`03001oogoo021oo`P001A;?`03001;
?d/o01I;?`03001;?d/o01I;?`03001;?d/o009;?`L000a;?`03001;?d/o01I;?`03001;?d/o01I;
?`03001;?d/o00M;?`D000Y;?`03001;?d/o01I;?`03001;?d/o01I;?`03001;Gd]O009;G`L000e;
G`03001;Gd]O01M;G`03001;Gd]O00A;G`03001;Gd]O00a;G`@000=oo`03001oogoo06Qoo`00hGoo
0P00W7oo1`00=Goo1`0014/o00<004/oBcl05T/o00<004/oBcl05T/o00<004/oBcl04T/o200054/o
00<004/oBcl05T/o00<004/oBcl05D/o00@004/oBcm;?`H0011;?`03001;?d/o01E;?`03001;?d/o
01A;?`L001E;G`03001;Gd]O01I;G`03001;Gd]O00A;G`03001;Gd]O00I;G`H000=;G`03001oogoo
009oo`03001oogoo06Moo`00fGoo0P001Goo0`00UGoo1`00=Goo1`0034/o00<004/oBcl05T/o00<0
04/oBcl05D/o00<004/oBcl02T/o200014/o00<004/oBcl05D/o00<004/oBcl05d/o00<004/oBcl0
4D/o1`005T/o00<004/oBcl05T/o00<004/oBcl03D/o1P000d]O00<004]OBel05T]O00<004]OBel0
5d]O00<004]OBel00d]O00@004]OBem;G`D000Y;G`05001oogooOol0001YOol00=Uoo`T008moo`L0
00Ioo`03001oogoo02]oo`P001A;?`03001;?d/o01E;?`03001;?d/o01I;?`03001;?d/o009;?`L0
00e;?`03001;?d/o01E;?`03001;?d/o01I;?`03001;?d/o00Y;?`L000A;?`03001;?d/o01M;?`03
001;?d/o01I;?`03001;?d/o00M;?`D000Y;G`03001;Gd]O01I;G`03001;Gd]O01I;G`04001;Gd]O
Bel6000?Bel00`00Oomoo`02Ool00`00Oomoo`1VOol00=Uoo`800003Ool0000000<008Qoo`P000eo
o`03001oogoo02Aoo`L000A;?`03001;?d/o01I;?`03001;?d/o01E;?`03001;?d/o019;?`P001E;
?`03001;?d/o01E;?`03001;?d/o01I;?`03001;?d/o009;?`L000a;?`03001;?d/o01M;?`03001;
?d/o01E;?`04001;?d/oBcl6000@Bel00`00Bem;G`0FBel00`00Bem;G`0BBel70002Bel00`00Bem;
G`0ABel01@00Oomoogoo0000J7oo003IOol20027Ool7000EOol00`00Oomoo`0MOol7000<Bcl00`00
Bcm;?`0FBcl00`00Bcm;?`0EBcl00`00Bcm;?`0:Bcl70004Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0F
Bcl00`00Bcm;?`0BBcl8000DBcl00`00Bcm;?`0GBcl00`00Bcm;?`0ABcl7000FBel00`00Bem;G`0F
Bel00`00Bem;G`0:Bel80004Bel00`00Bem;G`02Bel00`00Bem;G`0BBel01@00Oomoogoo0000Igoo
003IOol20020Ool7000LOol00`00Oomoo`0EOol8000DBcl00`00Bcm;?`0EBcl00`00Bcm;?`0FBcl0
0`00Bcm;?`02Bcl7000<Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0EBcl00`00Bcm;?`0:Bcl80004Bcl0
0`00Bcm;?`0EBcl00`00Bcm;?`0GBcl00`00Bcm;?`0:Bcl70004Bcl00`00Bem;G`0GBel00`00Bem;
G`0FBel00`00Bem;G`02Bel7000=Bel01@00Bem;Gd]O000054]O00D007ooOomoo`0006Moo`00fGoo
0P00NGoo1`000Woo00<007ooOol07Woo00<007ooOol03Woo1`0014/o00<004/oBcl05T/o00<004/o
Bcl05D/o00<004/oBcl04T/o200054/o00<004/oBcl05T/o00<004/oBcl05D/o00<004/oBcl00T/o
1`003D/o00<004/oBcl05D/o00<004/oBcl05d/o00<004/oBcl00T/o1`0034/o00<004]OBel05T]O
00<004]OBel054]O1`0054]O00D004]OBem;G`0001E;G`05001oogooOol0001VOol00=Uoo`X006Yo
o`L000Uoo`03001oogoo02Qoo`L000a;?`03001;?d/o01E;?`03001;?d/o01I;?`03001;?d/o00Y;
?`L000A;?`03001;?d/o01I;?`03001;?d/o01E;?`03001;?d/o01=;?`L001E;?`03001;?d/o01E;
?`03001;?d/o01A;?`L001A;?`03001;Gd]O01I;G`03001;Gd]O00e;G`H000=;G`03001;Gd]O01I;
G`04001;Gd]O000EBel01@00Oomoogoo0000IWoo003IOol:001ROol8000@Ool00`00Oomoo`0POol8
000DBcl00`00Bcm;?`0EBcl00`00Bcm;?`0FBcl00`00Bcm;?`02Bcl7000<Bcl00`00Bcm;?`0EBcl0
0`00Bcm;?`0FBcl00`00Bcm;?`0=Bcl50003Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0FBcl00`00Bcm;
?`0=Bcl60003Bcl00`00Bcm;?`0EBcl00`00Bem;G`0GBel00`00Bem;G`07Bel5000:Bel00`00Bem;
G`0FBel00`00Bel0000CBel40003Ool00`00Oomoo`1SOol00?moocmoo`L001Qoo`03001oogoo01Uo
o`L000A;?`03001;?d/o01I;?`03001;?d/o01E;?`03001;?d/o01=;?`L001A;?`03001;?d/o01E;
?`03001;?d/o01E;?`03001;?d/o00M;?`H000U;?`03001;?d/o01I;?`03001;?d/o01E;?`03001;
?d/o00Q;?`D000Y;?`03001;?d/o01E;?`03001;Gd]O01I;G`04001;Gd]OBel6000?Bel00`00Bem;
G`0FBel00`00Bel0000=Bel60003Bel01@00Oomoogoo0000IGoo003oOolhOol7000dOol7000<Bcl0
0`00Bcm;?`0EBcl00`00Bcm;?`0EBcl00`00Bcm;?`0>Bcl50003Bcl00`00Bcm;?`0EBcl00`00Bcm;
?`0FBcl00`00Bcm;?`0EBcl01000Bcm;?d/o1@0044/o00<004/oBcl05D/o00<004/oBcl05T/o00@0
04/oBcm;?`H0011;?`03001;?d/o01A;?`03001;Gd]O01A;G`H001I;G`03001;Gd]O01I;G`8000Q;
G`D000Y;G`05001oogooOol0001TOol00?mooc5oo`L000Ioo`03001oogoo02Yoo`P001A;?`03001;
?d/o01E;?`03001;?d/o01E;?`03001;?d/o00M;?`H000U;?`03001;?d/o01E;?`03001;?d/o01E;
?`03001;?d/o019;?`L001E;?`03001;?d/o01I;?`03001;?d/o019;?`L001I;?`03001;?d/o01E;
?`03001;Gd]O00e;G`H000=;G`03001;Gd]O01I;G`03001;Gd]O01I;G`80009;G`H000m;G`05001o
ogooOol0001TOol00?moobUoo`P000aoo`03001oogoo02Aoo`L000A;?`03001;?d/o01I;?`03001;
?d/o01E;?`03001;?d/o01E;?`04001;?d/oBcl5000@Bcl00`00Bcm;?`0EBcl00`00Bcm;?`0EBcl0
0`00Bcm;?`0:Bcl70004Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0FBcl00`00Bcm;?`09Bcl80004Bcl0
0`00Bcm;?`0GBcl00`00Bcm;?`0EBcl00`00Bem;G`07Bel5000:Bel00`00Bem;G`0FBel00`00Bem;
G`0CBel6000FBel01@00Oomoogoo0000Hgoo003oOolROol7000DOol00`00Oomoo`0MOol7000<Bcl0
0`00Bcm;?`0EBcl00`00Bcm;?`0EBcl00`00Bcm;?`0BBcl7000EBcl00`00Bcm;?`0EBcl00`00Bcm;
?`0FBcl00`00Bcm;?`02Bcl7000<Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0EBcl00`00Bcm;?`02Bcl7
000=Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0EBcl01000Bem;Gd]O1P003d]O00<004]OBel05T]O00<0
04]OBel03D]O1P000d]O00<004]OBel05d]O00@007ooOol006=oo`00ogoo6goo1`00=7oo1`0054/o
00<004/oBcl05D/o00<004/oBcl05D/o00<004/oBcl02T/o1`0014/o00<004/oBcl05T/o00<004/o
Bcl05D/o00<004/oBcl04T/o200054/o00<004/oBcl05D/o00<004/oBcl04d/o1`005D/o00<004/o
Bcl05T/o00<004/oBcl04D/o1`005T]O00<004]OBel05T]O00<004]OBel01d]O1@002D]O0P0064]O
00D007ooOomoo`00069oo`00ogoo57oo1`000Woo00<007ooOol0;goo1`000d/o00<004/oBcl05T/o
00<004/oBcl05D/o00<004/oBcl05D/o00<004/oBcl00T/o1`0034/o00<004/oBcl05T/o00<004/o
Bcl054/o00<004/oBcl02T/o200014/o00<004/oBcl05D/o00<004/oBcl05T/o00<004/oBcl03D/o
1@000d/o00<004/oBcl05T/o00<004/oBcl05d/o00<004/oBcl02D/o1`0014/o00<004]OBel05T]O
00<004]OBel05T]O00@004]OBem;G`H000i;G`8001U;G`04001oogoo001ROol00?moo`eoo`L000Uo
o`03001oogoo02Qoo`L000];?`03001;?d/o01I;?`03001;?d/o01A;?`03001;?d/o019;?`P001A;
?`03001;?d/o01E;?`03001;?d/o01E;?`03001;?d/o009;?`L000e;?`03001;?d/o01E;?`03001;
?d/o01E;?`03001;?d/o00M;?`H000U;?`03001;?d/o01I;?`03001;?d/o01I;?`03001;?d/o009;
?`L000a;?`03001;Gd]O01I;G`03001;Gd]O01=;G`H001A;G`03001;G`0001Q;G`05001oogooOol0
001QOol00?moo`Eoo`P0011oo`03001oogoo025oo`L001=;?`03001;?d/o01I;?`03001;?d/o01A;
?`03001;?d/o00Y;?`L000A;?`03001;?d/o01I;?`03001;?d/o01E;?`03001;?d/o015;?`P001E;
?`03001;?d/o01E;?`03001;?d/o01E;?`04001;?d/oBcl5000@Bcl00`00Bcm;?`0EBcl00`00Bcm;
?`0DBcl7000DBcl00`00Bem;G`0EBel00`00Bem;G`0=Bel60003Cel00`00Bem;G`0DBel01000Bem;
G`005D]O10000Woo00<007ooOol0Ggoo003mOol7000HOol00`00Oomoo`0JOol70003Bcl00`00Bcm;
?`0EBcl00`00Bcm;?`0FBcl00`00Bcm;?`0DBcl00`00Bcm;?`02Bcl7000<Bcl00`00Bcm;?`0FBcl0
0`00Bcm;?`0DBcl00`00Bcm;?`0:Bcl70004Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0FBcl00`00Bcm;
?`0ABcl7000EBcl00`00Bcm;?`0FBcl00`00Bcm;?`0=Bcl60003Ccl00`00Bcm;?`0EBcl00`00Bem;
G`0FBel00`00Bem;G`07Bel5000:Cel00`00Bem;G`0CBel01000Bem;G`003d]O1P000dmO00D007oo
Oomoo`00061oo`00mWoo1`00=Goo1`002d/o00<004/oBcl05D/o00<004/oBcl05T/o00<004/oBcl0
3d/o2@0054/o00<004/oBcl05D/o00<004/oBcl05D/o00<004/oBcl00T/o1`0034/o00<004/oBcl0
5T/o00<004/oBcl05D/o00<004/oBcl02T/o1`0014/o00<004/oBcl05T/o00<004/oBcl05T/o00<0
04/oBcl01d/o1@002Tlo00<004/oBcl05D/o00<004]OBel05D]O00@004]OBem;G`H000m?G`03001;
Gd]O01=;G`05001;Gd]OBel00009Bel5000:Cel01000Oomoo`00H7oo003_Ool70006Ool00`00Oomo
o`0/Ool7000CBcl00`00Bcm;?`0EBcl00`00Bcm;?`0FBcl00`00Bcm;?`03Bcl;0005Bcl00`00Bcm;
?`0FBcl00`00Bcm;?`0EBcl00`00Bcm;?`0BBcl7000DBcl00`00Bcm;?`0FBcl00`00Bcm;?`0EBcl0
0`00Bcm;?`02Bcl7000<Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0EBcl01000Bcm;?d/o1P003dlo00<0
04/oBcl05D/o00<004]OBel04d]O1P005TmO00<004]OBel04T]O00D004]OBem;G`0000=;G`H000m?
G`05001oogooOol0001OOol00>Moo`P000eoo`03001oogoo02Eoo`L000=;?`03001;?d/o01E;?`03
001;?d/o01E;?`03001;?d/o019;?`T0015;?`03001;?d/o01I;?`03001;?d/o01E;?`03001;?d/o
00Y;?`L000=;?`03001;?d/o01I;?`03001;?d/o01I;?`03001;?d/o015;?`P001A;?`03001;?d/o
01E;?`03001;?d/o01=;?`H001I??`03001;?d/o01E;?`03001;Gd]O00e;G`D000=?G`03001?GdmO
01M?G`03001;Gd]O019;G`L001I?G`04001oogoo001OOol00>1oo`L001Eoo`03001oogoo01ioo`L0
00];?`03001;?d/o01E;?`03001;?d/o01E;?`03001;?d/o00Y;?`L000A;?`03001;?d/o01A;?`03
001;?d/o01E;?`03001;?d/o01I;?`03001;?d/o009;?`L000];?`03001;?d/o01E;?`03001;?d/o
01I;?`03001;?d/o00Y;?`L000A;?`03001;?d/o01E;?`03001;?d/o01I;?`03001;?d/o00e;?`D0
00=??`03001??dlo01I??`03001;?d/o01I;?`03001;Gd]O00I;G`H000U?G`03001?GdmO01I?G`03
001;Gd]O00e;G`H000=?G`03001?GdmO01I?G`05001oogooOol0001NOol00=Uoo`L003Ioo`L001=;
?`03001;?d/o01E;?`03001;?d/o01E;?`03001;?d/o009;?`L000a;?`03001;?d/o01A;?`03001;
?d/o01E;?`03001;?d/o019;?`P001=;?`03001;?d/o01E;?`03001;?d/o01I;?`03001;?d/o009;
?`L000a;?`03001;?d/o01E;?`03001;?d/o01E;?`03001;?d/o00M;?`H000U??`03001??dlo01I?
?`03001;?d/o01E;?`04001;Gd]OBel5000@Cel00`00Cem?G`0FCel00`00Bem;G`07Bel50005Cel0
0`00Cem?G`02Cel00`00Cem?G`0ECel00`00Oomoo`02Ool00`00Oomoo`1KOol00=9oo`L000Aoo`03
001oogoo02moo`L000=;?`03001;?d/o01E;?`03001;?d/o01E;?`03001;?d/o019;?`L001A;?`03
001;?d/o01A;?`03001;?d/o01E;?`03001;?d/o00Y;?`L000A;?`03001;?d/o01E;?`03001;?d/o
01E;?`03001;?d/o01=;?`L001A;?`03001;?d/o01E;?`03001;?d/o01E;?`04001;?d/oBcl5000@
Ccl00`00Ccm??`0ECcl00`00Bcm;?`0BBcl7000ECel00`00Cem?G`0FCel01000Bem;Gd]O1P002TmO
00<004mOCel00TmO00<004mOCel05TmO00D007ooOomoo`0005eoo`00bgoo1`002goo00<007ooOol0
:7oo1`002d/o00<004/oBcl05D/o00<004/oBcl05D/o00<004/oBcl02T/o1`000d/o00<004/oBcl0
5T/o00<004/oBcl054/o00<004/oBcl05D/o00<004/oBcl00T/o1`0034/o00<004/oBcl054/o00<0
04/oBcl05D/o00<004/oBcl03T/o1@000d/o00<004/oBcl05D/o00<004/oBcl05T/o00<004/oBcl0
4D/o1`005Dlo00<004loCcl05Tlo00<004/oBcl02D/o200014mO00<004mOCel05TmO00<004mOCel0
4dmO1P0044mO00<004mOCel00dmO00<004mOCel05DmO00<007ooOol00Woo00<007ooOol0FWoo0033
Ool8000BOol00`00Oomoo`0OOol9000CBcl00`00Bcm;?`0EBcl00`00Bcm;?`0EBcl00`00Bcm;?`02
Bcl7000;Bcl00`00Bcm;?`0EBcl00`00Bcm;?`0EBcl00`00Bcm;?`0BBcl7000DBcl00`00Bcm;?`0D
Bcl00`00Bcm;?`0EBcl00`00Bcm;?`07Bcl60009Bcl00`00Bcm;?`0EBcl00`00Bcm;?`0EBcl00`00
Bcm;?`0:Bcl70004Ccl00`00Ccm??`0FCcl00`00Ccm??`0ECcl00`00Bcm;?`02Bcl7000=Cel00`00
Cem?G`0FCel00`00Cem?G`0=Cel50003Cel00`00Cem?G`0@Cel00`00Cem?G`04Cel00`00Cem?G`0B
Cel40003Ool00`00Oomoo`1JOol00;aoo`L001Uoo`03001oogoo01Eoo`/000I;?`03001;?d/o01A;
?`03001;?d/o01E;?`03001;?d/o019;?`L001=;?`03001;?d/o01E;?`03001;?d/o01E;?`03001;
?d/o00Y;?`L000=;?`03001;?d/o01I;?`03001;?d/o01A;?`03001;?d/o01E;?`04001;?d/oBcl5
000@Bcl00`00Bcm;?`0EBcl00`00Bcm;?`0EBcl00`00Bcm;?`02Bcl7000<Ccl00`00Ccm??`0ECcl0
0`00Ccm??`0CCcl7000DCel00`00Cem?G`0FCel00`00Cem?G`07Cel60009Cel00`00Cem?G`0?Cel0
0`00Cem?G`04Cel00`00Cem?G`0=Cel50003Cel00`00Oomoo`02Ool00`00Oomoo`1IOol00;Eoo`L0
0003Ool007oo01eoo`03001oogoo00eoo`P0019;?`03001;?d/o01A;?`03001;?d/o01E;?`03001;
?d/o00Y;?`L000=;?`03001;?d/o01E;?`03001;?d/o01E;?`03001;?d/o01E;?`03001;?d/o009;
?`L000];?`03001;?d/o01E;?`03001;?d/o01A;?`03001;?d/o019;?`L001E;?`03001;?d/o01E;
?`03001;?d/o01=;?`L001A??`03001??dlo01E??`03001??dlo00e??`D000=??`03001?GdmO01I?
G`03001?GdmO01I?G`04001?GdmOCel5000?Cel00`00Cem?G`0?Cel00`00Cem?G`05Cel00`00Cem?
G`06Cel60009Cel01@00Oomoogoo0000Fgoo002^Ool70008Ool00`00Oomoo`0LOol00`00Oomoo`06
Ool70004Bcl00`00Bcm;?`0DBcl00`00Bcm;?`0DBcl00`00Bcm;?`0EBcl00`00Bcm;?`02Bcl7000;
Bcl00`00Bcm;?`0EBcl00`00Bcm;?`0DBcl00`00Bcm;?`0BBcl8000CBcl00`00Bcm;?`0EBcl00`00
Bcm;?`0DBcl00`00Bcm;?`0:Bcl70004Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0EBcl00`00Bcm;?`0=
Bcl50003Ccl00`00Ccm??`0ECcl00`00Ccm??`0FCcl00`00Ccm??`06Ccl60009Ccl00`00Cem?G`0F
Cel00`00Cem?G`0CCel6000ECel00`00Cem?G`0>Cel00`00Cem?G`05Cel01000Cem?GdmO1@0044mO
00D007ooOomoo`0005Yoo`00Ygoo1`003goo00<007ooOol07Woo1`0034/o00<004/oBcl054/o00<0
04/oBcl054/o00<004/oBcl04T/o1`004d/o00<004/oBcl05D/o00<004/oBcl054/o00<004/oBcl0
2T/o1`0014/o00<004/oBcl05D/o00<004/oBcl05D/o00<004/oBcl054/o00<004/oBcl00T/o1`00
34/o00<004/oBcl05T/o00<004/oBcl054/o00<004/oBcl01d/o1P002Dlo00<004loCcl05Dlo00<0
04loCcl05Dlo00@004loCcm??`D0011??`03001?GdmO01E?G`03001?GdmO00e?G`H000=?G`03001?
GdmO01I?G`03001?GdmO00e?G`03001?GdmO00=?G`H001E?G`05001oogooOol0001JOol009moo`P0
01Ioo`03001oogoo01Moo`L001A;?`03001;?d/o01A;?`03001;?d/o01A;?`03001;?d/o00Y;?`L0
00=;?`03001;?d/o01E;?`03001;?d/o01A;?`03001;?d/o01E;?`03001;?d/o009;?`L000a;?`03
001;?d/o01A;?`03001;?d/o01E;?`03001;?d/o019;?`L001A;?`03001;?d/o01E;?`03001;?d/o
01E;?`04001;?d/oBcl5000@Ccl00`00Ccm??`0DCcl00`00Ccm??`0CCcl6000ECcl00`00Cem?G`0F
Cel00`00Cem?G`07Cel5000:Cel00`00Cem?G`0ECel00`00Cem?G`0=Cel60003Cel00`00Cem?G`0F
Cel01@00Oomoogoo0000FGoo002HOol7000aOol70004Acl00`00Bcm;?`0EBcl00`00Bcm;?`0DBcl0
0`00Bcm;?`0DBcl00`00Bcm;?`02Bcl7000;Bcl00`00Bcm;?`0EBcl00`00Bcm;?`0DBcl00`00Bcm;
?`0BBcl7000DBcl00`00Bcm;?`0DBcl00`00Bcm;?`0EBcl00`00Bcm;?`0:Bcl70003Bcl00`00Bcm;
?`0EBcl00`00Bcm;?`0FBcl00`00Bcm;?`0ABcl7000ECcl00`00Ccm??`0ECcl00`00Ccm??`0=Ccl5
0003Ccl00`00Ccm??`0FCcl00`00Cem?G`0ECel01000Cem?GdmO1P003dmO00<004mOCel05TmO00<0
04mOCel01dmO1P002DmO00<004mOCel05DmO00D007ooOomoo`0005Uoo`00TGoo1`001Woo00<007oo
Ool0:7oo1`0034Lo00<004/oBcl05D/o00<004/oBcl054/o00<004/oBcl03d/o2@004d/o00<004/o
Bcl05D/o00<004/oBcl054/o00<004/oBcl02T/o1`000d/o00<004/oBcl05T/o00<004/oBcl054/o
00<004/oBcl05D/o00<004/oBcl00T/o1`002d/o00<004/oBcl05D/o00<004/oBcl05D/o00<004/o
Bcl02T/o1`0014lo00<004loCcl05Tlo00<004loCcl05Dlo00<004loCcl01Tlo1P002Dlo00<004lo
Ccl05Dlo00<004mOCel04dmO1P005TmO00<004mOCel05DmO00@004mOCem?G`H000E?G`03001?GdmO
00M?G`03001?GdmO01I?G`05001oogooOol0001HOol008Yoo`L000eoo`03001oogoo029oo`H001A7
?`03001;?d/o01E;?`03001;?d/o01A;?`03001;?d/o00=;?`/000E;?`03001;?d/o01E;?`03001;
?d/o01E;?`03001;?d/o01A;?`03001;?d/o009;?`L000];?`03001;?d/o01I;?`03001;?d/o01=;
?`03001;?d/o019;?`P001=;?`03001;?d/o01E;?`03001;?d/o01E;?`03001;?d/o009;?`L000a?
?`03001??dlo01E??`03001??dlo01E??`04001??dloCcl5000@Ccl00`00Ccm??`0ECcl00`00Cem?
G`0=Cel50003Cel00`00Cem?G`0FCel00`00Cem?G`0DCel5000;Cel00`00Cem?G`08Cel00`00Cem?
G`0DCel30002Ool00`00Oomoo`1FOol0089oo`P001Aoo`03001oogoo01]oo`L000E7?`030017?dLo
01=7?`03001;?d/o01E;?`03001;?d/o015;?`P0015;?`03001;?d/o01E;?`03001;?d/o01E;?`03
001;?d/o00m;?`T001=;?`03001;?d/o01E;?`03001;?d/o01A;?`03001;?d/o00Y;?`L000A;?`03
001;?d/o01E;?`03001;?d/o01E;?`03001;?d/o015;?`P001A??`03001??dlo01E??`03001??dlo
015??`L001E??`03001??dlo01I??`03001?GdmO00I?G`H000U?G`03001?GdmO01I?G`03001?GdmO
00i?G`D0009?G`03001?GdmO00]?G`03001?GdmO00Q?G`03001?GdmO00m?G`D0009?G`05001oogoo
Ool0001GOol007]oo`L003=oo`L000e7?`030017?dLo01=7?`03001;?d/o01E;?`03001;?d/o00U;
?`L000A;?`03001;?d/o01=;?`03001;?d/o01E;?`03001;?d/o01E;?`03001;?d/o00=;?`/000E;
?`03001;?d/o01E;?`03001;?d/o01E;?`03001;?d/o01A;?`03001;?d/o009;?`L000a;?`03001;
?d/o01E;?`03001;?d/o01A;?`03001;?d/o00Y;?`L000A??`03001??dlo01E??`03001??dlo01I?
?`03001??dlo00U??`L000A??`03001??dlo01I??`03001??dlo01E??`04001?GdmOCel5000@Cel0
0`00Cem?G`0ECel00`00Cem?G`0:Cel40008Cel00`00Cem?G`0:Cel00`00Cem?G`08Cel00`00Cem?
G`0:Cel50008Cel01000Oomoo`00Egoo001dOol70005Ool00`00Oomoo`0[Ool7000EAcl00`00Acm7
?`0CAcl00`00Bcm;?`0EBcl01000Bcm;?d/o1`0034/o00<004/oBcl04d/o00<004/oBcl05D/o00<0
04/oBcl04T/o20004D/o00<004/oBcl05D/o00<004/oBcl05D/o00<004/oBcl03d/o2@0054/o00<0
04/oBcl054/o00<004/oBcl05D/o00<004/oBcl00T/o1`0034lo00<004loCcl05Dlo00<004loCcl0
5Dlo00<004loCcl00Tlo1`0034lo00<004loCcl05Dlo00<004loCcl04dlo1P005DmO00<004mOCel0
5TmO00<004mOCel01DmO100034mO00<004mOCel02TmO00<004mOCel02DmO00<004mOCel01DmO1000
3DmO00D007ooOomoo`0005Ioo`00KGoo1`0037oo00<007ooOol097oo1`001DLo00<004LoAcl05DLo
00<004LoAcl04dLo00<004/oBcl04T/o1P0054/o00<004/oBcl04d/o00<004/oBcl05D/o00<004/o
Bcl02T/o1`000d/o00<004/oBcl054/o00<004/oBcl05D/o00<004/oBcl05D/o00<004/oBcl00d/o
2`001D/o00<004/oBcl05D/o00<004/oBcl05D/o00<004/oBcl04T/o1`0054lo00<004loCcl054lo
00<004loCcl04dlo1`0054lo00<004loCcl05Dlo00<004loCcl03Dlo1@000dlo00<004mOCel05TmO
00<004mOCel05DmO00<004mOCel01@004DmO00<004mOCel02DmO00<004mOCel02DmO00<004mOCel0
1@004TmO00@007ooOol005Ioo`00IWoo1`004goo00<007ooOol07Goo1`003DLo00<004LoAcl05DLo
00<004LoAcl04dLo00<004/oBcl02T/o1`000dLo00<004/oBcl05D/o00<004/oBcl04d/o00<004/o
Bcl05D/o00<004/oBcl00T/o1`002d/o00<004/oBcl054/o00<004/oBcl05D/o00<004/oBcl04T/o
20004D/o00<004/oBcl05D/o00<004/oBcl05D/o00<004/oBcl02T/o1`000dlo00<004loCcl05Dlo
00<004loCcl05Dlo00<004loCcl03Dlo1@000dlo00<004loCcl05Dlo00<004loCcl05Tlo00<004lo
Ccl01Tlo1P002Dlo00<004mOCel05DmO00<004mOCel04dmO1@005dmO00<004mOCel024mO00<004mO
Cel01dmO1@005dmO00D007ooOomoo`0005Eoo`00HWoo1000<Woo20005DLo00<004LoAcl05DLo00<0
04LoAcl04dLo00<004/oBcl00T/o1`002dLo00<004/oBcl05D/o00<004/oBcl04d/o00<004/oBcl0
4T/o1`004d/o00<004/oBcl054/o00<004/oBcl05D/o00<004/oBcl02T/o1`000d/o00<004/oBcl0
54/o00<004/oBcl05D/o00<004/oBcl05D/o00<004/oBcl00T/o1`002dlo00<004loCcl05Dlo00<0
04loCcl05Dlo00<004loCcl01Tlo1P002Dlo00<004loCcl05Dlo00<004loCcl05Dlo00@004loCcm?
?`D0011??`03001?GdmO01E?G`03001?GdmO00e?G`D000=?G`03001?GdmO01I?G`03001?GdmO00Q?
G`03001?GdmO009?G`D000=?G`03001?GdmO01M?G`04001oogoo001EOol0069oo`03001oo`0002Uo
o`X000M7?`030017?dLo01A7?`8001I7?`030017?dLo00i7?`T001=7?`03001;?d/o01E;?`03001;
?d/o01=;?`03001;?d/o00Y;?`L000=;?`03001;?d/o01E;?`03001;?d/o01A;?`03001;?d/o01E;
?`03001;?d/o009;?`L000];?`03001;?d/o01A;?`03001;?d/o01E;?`03001;?d/o015;?`P001=?
?`03001??dlo01E??`03001??dlo01A??`04001??dloCcl5000@Ccl00`00Ccm??`0DCcl00`00Ccm?
?`0CCcl6000ECcl00`00Cem?G`0FCel00`00Cem?G`06Cel60009Cel00`00Cem?G`0FCel00`00Cem?
G`06Cel60009Cel00`00Cem?G`0FCel01@00Oomoogoo0000E7oo001ROol01000Oomoo`0087oo2000
4TLo00<004LoAcl05DLo00<004LoAcl054Lo00<004LoAcl00dLo2P001dLo00<004LoAcl04dLo00<0
04/oBcl05D/o00<004/oBcl04d/o00<004/oBcl00T/o1`002d/o00<004/oBcl05D/o00<004/oBcl0
54/o00<004/oBcl04T/o1`004d/o00<004/oBcl054/o00<004/oBcl054/o00<004/oBcl02T/o1`00
14lo00<004loCcl054lo00<004loCcl05Tlo00<004loCcl04Dlo1P005Dlo00<004loCcl05Dlo00<0
04loCcl03Dlo1@000dlo00<004loCcl05Tlo00<004mOCel05DmO00@004mOCem?G`D000m?G`03001?
GdmO01I?G`04001?GdmOCel500000dmO001?G`0=Cel00`00Cem?G`0DCel30002Ool00`00Oomoo`1B
Ool0069oo`04001oogooOol2000GOol70005Acl00`00Acm7?`0CAcl00`00Acm7?`0EAcl00`00Acm7
?`0AAcl8000BAcl00`00Acm7?`0CAcl00`00Bcm;?`0EBcl00`00Bcm;?`0>Bcl9000CBcl00`00Bcm;
?`0EBcl00`00Bcm;?`0DBcl00`00Bcm;?`0:Bcl70003Bcl00`00Bcm;?`0EBcl00`00Bcm;?`0CBcl0
0`00Bcm;?`0EBcl00`00Bcm;?`02Bcl7000<Ccl00`00Ccm??`0DCcl00`00Ccm??`0ECcl00`00Ccm?
?`0:Ccl70003Ccl00`00Ccm??`0FCcl00`00Ccm??`0ECcl00`00Ccm??`06Ccl60009Ccl00`00Ccm?
?`0ECcl00`00Cem?G`0CCel6000ECel00`00Cem?G`0DCel50006Cel00`00Cem?G`0<Cel00`00Cem?
G`0?Cel50002Cel01@00Oomoogoo0000Dgoo001ROol00`00Oomoo`03Ool00`00Oomoo`0=Ool7000=
Acl00`00Acm7?`0CAcl2000FAcl00`00Acm7?`09Acl70004Acl00`00Acm7?`0DAcl00`00Acm7?`0C
Acl00`00Bcm;?`0EBcl00`00Bcm;?`03Bcl:0006Bcl00`00Bcm;?`0DBcl00`00Bcm;?`0DBcl00`00
Bcm;?`0EBcl00`00Bcm;?`02Bcl7000;Bcl00`00Bcm;?`0DBcl00`00Bcm;?`0DBcl00`00Bcm;?`0B
Bcl7000DCcl00`00Ccm??`0DCcl00`00Ccm??`0ECcl00`00Ccm??`02Ccl7000;Ccl00`00Ccm??`0F
Ccl00`00Ccm??`0DCcl01000Ccm??dlo1@0044lo00<004loCcl05Dlo00<004mOCel03DmO1@000dmO
00<004mOCel05TmO00<004mOCel03TmO1@000TmO00<004mOCel01TmO00<004mOCel03DmO00<004mO
Cel02TmO100024mO00@007ooOol005=oo`00C7oo10004Woo00<007ooOol017oo00<007ooOol01Woo
1P005DLo00<004LoAcl054Lo00<004LoAcl054Lo00@004LoAcm7?`L000a7?`030017?dLo01A7?`03
0017?dLo01=7?`03001;?d/o019;?`P0015;?`03001;?d/o01A;?`03001;?d/o01A;?`03001;?d/o
019;?`L001=;?`03001;?d/o01A;?`03001;?d/o01A;?`03001;?d/o00Y;?`L000=;?`03001??dlo
01E??`03001??dlo01A??`03001??dlo01=??`L001=??`03001??dlo01E??`03001??dlo019??`H0
01E??`03001??dlo01I??`03001?GdmO00I?G`H000U?G`03001?GdmO01E?G`03001?GdmO00Y?G`@0
00Q?G`03001?GdmO00E?G`03001?GdmO00e?G`03001?GdmO00I?G`@000a?G`05001oogooOol0001B
Ool004Yoo`P0011oo`03001oogoo00Eoo`P000E7?`030017?dLo01A7?`8001E7?`030017?dLo0157
?`H001A7?`030017?dLo01A7?`030017?dLo01=7?`03001;?d/o00Y;?`L000=7?`03001;?d/o01A;
?`03001;?d/o01A;?`03001;?d/o01A;?`03001;?d/o00Y;?`L000=;?`03001;?d/o01E;?`03001;
?d/o01A;?`03001;?d/o01A;?`03001;?d/o009;?`L000];?`03001??dlo01E??`03001??dlo01A?
?`03001??dlo00e??`D000=??`03001??dlo01A??`03001??dlo01I??`03001??dlo00a??`D000=?
?`03001??dlo01I??`03001??dlo01E??`04001?GdmOCel5000?Cel00`00Cem?G`0FCel00`00Cem?
G`05Cel4000<Cel00`00Cem?G`05Cel00`00Cem?G`0>Cel00`00Cem?G`05000ACel01000Oomoo`00
DWoo001:Ool20004Ool2000@Ool00`00Ool00006000=Acl00`00Acm7?`0EAcl00`00Acm7?`0CAcl0
0`00Acm7?`09Acl70005Acl00`00Acm7?`0CAcl00`00Acm7?`0DAcl00`00Acm7?`0CAcl00`00Bcm;
?`02Bcl7000;Acl00`00Bcm;?`0DBcl00`00Bcm;?`0DBcl00`00Bcm;?`0DBcl00`00Bcm;?`02Bcl7
000;Bcl00`00Bcm;?`0DBcl00`00Bcm;?`0DBcl00`00Bcm;?`0BBcl7000CBcl00`00Ccm??`0ECcl0
0`00Ccm??`0CCcl00`00Ccm??`07Ccl60009Ccl00`00Ccm??`0DCcl00`00Ccm??`0ECcl00`00Ccm?
?`07Ccl50009Ccl00`00Ccm??`0ECcl00`00Ccm??`0CCcl6000ECel00`00Cem?G`0ECel00`00Cem?
G`05000ACel00`00Cem?G`04Cel00`00Cem?G`0=Cel4000FCel01@00Oomoogoo0000DGoo0019Ool2
0006Ool2000>Ool3000EAcl00`00Acm7?`0EAcl00`00Acm7?`0CAcl01000Acm7?dLo1`003DLo00<0
04LoAcl04dLo00<004LoAcl054Lo00<004LoAcl03TLo2@004dLo00<004/oBcl054/o00<004/oBcl0
54/o00<004/oBcl03d/o2@004d/o00<004/oBcl054/o00<004/oBcl054/o00<004/oBcl02T/o1`00
0d/o00<004/oBcl05D/o00<004loCcl054lo00<004loCcl054lo00@004loCcm??`D0011??`03001?
?dlo01A??`03001??dlo01E??`04001??dloCcl5000?Ccl00`00Ccm??`0ECcl00`00Ccm??`0=Ccl5
0003Ccl00`00Cem?G`0FCel00`00Cem?G`0BCel5000GCel00`00Cem?G`03Cel00`00Cem?G`08Cel5
0002Cel00`00Cem?G`0ECel01@00Oomoogoo0000DGoo0019Ool20006Ool2000>Ool00`00Ool0000F
Acl2000FAcl00`00Acm7?`0>Acl8000EAcl00`00Acm7?`0CAcl00`00Acm7?`0DAcl00`00Acm7?`03
Acl:0007Acl00`00Acm7?`0CAcl00`00Bcm;?`0DBcl00`00Bcm;?`0DBcl00`00Bcm;?`03Bcl;0005
Bcl00`00Bcm;?`0EBcl00`00Bcm;?`0DBcl00`00Bcm;?`0DBcl00`00Bcm;?`02Bcl7000;Bcl00`00
Bcm;?`0DBcl00`00Ccm??`0ECcl00`00Ccm??`0ACcl6000ECcl00`00Ccm??`0ECcl00`00Ccm??`0A
Ccl7000DCcl00`00Ccm??`0FCcl00`00Ccm??`06Ccl60009Ccl00`00Cem?G`0ECel00`00Cem?G`0=
Cel50003Cel00`00Cem?G`0FCel00`00Cem?G`04Cel00`00Cem?G`03Cel40008Cel00`00Cem?G`0E
Cel01@00Oomoogoo0000D7oo0018Ool20008Ool2000=Ool01000Oomoo`005dLo00<004LoAcl054Lo
00<004LoAcl00dLo2P001dLo00<004LoAcl054Lo00<004LoAcl04dLo00<004LoAcl04DLo20004TLo
00<004LoAcl04dLo00<004/oBcl054/o00<004/oBcl04D/o20004D/o00<004/oBcl05D/o00<004/o
Bcl04d/o00<004/oBcl04T/o1`004d/o00<004/oBcl054/o00<004loCcl054lo00<004loCcl02Tlo
1`000dln00<004loCcl05Tlo00<004loCcl054lo00<004loCcl02Tlo1`0014ln00<004loCcl05Dlo
00<004loCcl05Dlo00@004loCcm??`D0011??`03001?GdmO01E?G`03001?GdmO00I?G`H000U?G`03
001?GdmO01I?G`03001?GdmO00=?G`03001?G`0000<000a?G`03001?GdmO01E?G`03001oogoo009o
o`03001oogoo04eoo`00B7oo0P0027oo0P003Goo00@007ooOomoo`8001I7?`030017?dLo0157?`P0
0197?`030017?dLo01A7?`030017?dLo01=7?`030017?dLo00U7?`L000E7?`030017?dLo01=7?`03
0017?dLo01=7?`03001;?d/o01A;?`03001;?d/o00U;?`L000=;?`03001;?d/o01A;?`03001;?d/o
01A;?`03001;?d/o01A;?`03001;?d/o00Y;?`L000=;7`03001;?d/o01E;?`03001;?d/o01A;?`03
001??dlo01A??`03001??dlo009??`L000]??P03001??dlo01I??`03001??dlo01A??`03001??dlo
009??`L000a??P03001??dlo01A??`03001??dlo01=??`H001E??`03001?GdmO01E?G`04001?GdmO
Cel5000?Cel00`00Cem?G`0FCel00`00Cem?G`05000ACel00`00Cem?G`0CCel30003Ool00`00Oomo
o`1=Ool004Qoo`8000Qoo`8000eoo`03001oogoo00=oo`030017?dLo01A7?`030017?dLo00U7?`L0
00E7?`030017?dLo01=7?`030017?dLo01A7?`030017?dLo01=7?`040017?dLoAcl7000=Acl00`00
Acm7?`0CAcl00`00Acm7?`0CAcl00`00Bcm;?`0DBcl01000Bcm;?d/o1`002d/o00<004/oBcl054/o
00<004/oBcl054/o00<004/oBcl054/o00<004/oBcl00T/o1`002d/O00<004/oBcl054/o00<004/o
Bcl054/o00<004loCcl04Tlo1`004dln00<004loCcl05Dlo00<004loCcl04Tlo1`0054ln00<004lo
Ccl054lo00<004loCcl03Dlo1@000dlo00<004loCcl05Tlo00<004mOCel04dmO1@005DmO00<004mO
Cel054mO10000dmO00<004mOCel044mO00<004mOCel03TmO1@000Tmo00<007ooOol00Woo00<007oo
Ool0C7oo0018Ool20008Ool2000=Ool00`00Oomoo`04Ool2000EAcl01000Acm7?dLo1`003DLo00<0
04LoAcl04dLo0P005DLo00<004LoAcl03TLo20005DLo00<004LoAcl04dLo00<004LoAcl04dLo00<0
04/oBcl03d/o20004d/o00<004/oBcl054/o00<004/oBcl054/o00<004/oBcl03d/o2@004d/O00<0
04/oBcl054/o00<004/oBcl054/o00<004loCcl02Tlo1`000dln00<004lnCch054ln00<004loCcl0
5Tlo00<004loCcl034lo1@000dln00<004lnCch05Dln00<004loCcl05Dlo00<004loCcl01Tlo1P00
2Dlo00<004loCcl05Dlo00<004mOCel03dmO10000U=O00<004mOCel05TmO00<004mOCel03TmO1@00
0U=O00<004mOCel00TmO00<004mOCel044mO00<004mOCel02TmO100024mo00D007ooOomoo`0004io
o`00B7oo0P0027oo0P003Goo00<007ooOol01Woo00<004LoAcl03TLo20005DLo00<004LoAcl054Lo
00<004LoAcl04dLo00<004LoAcl00dLo2P001dLo00<004LoAcl054Lo00<004LoAcl04dLo00<004Lo
Acl04dLo00<004/oBcl00d/o2`001D/o00<004/oBcl054/o00<004/oBcl04d/o00<004/oBcl05D/o
00<004/oBcl00d/o2`001D/O00<004/OBal05D/O00<004/oBcl054/o00<004/oBcl054/o00<004lo
Ccl00Tlo1`002dln00<004lnCch054ln00<004loCcl05Dlo00<004loCcl01dlo1@002Dln00<004ln
Cch05Dln00<004loCcl054lo00@004loCcm??`D0011??`03001??dlo01E??`03001?GdmO00U?G`D0
00MCG`03001?GdmO01E?G`03001?GdmO00Y?G`@000QCG`05001?GdmOCel0000CCel00`00Cem?G`05
Cel4000<Cgl00`00Oomoo`02Ool00`00Oomoo`1;Ool004Qoo`8000Qoo`8000eoo`03001oogoo00Mo
o`030017?dLo00=7?`X000M7?`030017?dLo01A7?`8001E7?`030017?dLo00i7?`X00197?`030017
?dLo01A7?`030017?dLo01=7?`030017?dLo00i7?`X0015;?`03001;?d/o01A;?`03001;?d/o01=;
?`03001;?d/o019;?`P0015;7`03001;7d/O01A;7`03001;?d/o01A;?`03001;?d/o019;?`L001=?
?P03001??Tln01A??P03001??dlo01E??`04001??dloCcl5000?Cch00`00Cci??P0DCch00`00Ccm?
?`0BCcl6000ECcl00`00Ccm??`0FCcl00`00Cem?G`04Cel4000=Del00`00Cem?G`0ECel00`00Cem?
G`05Cel4000<Del01@00Cem?GdmO00004dmO00<004mOCel01@004Dmo00D007ooOomoo`0004eoo`00
B7oo0P0027oo0P003Goo00<007ooOol027oo1@004TLo00<004LoAcl05DLo00<004LoAcl04dLo00<0
04LoAcl00dLo2P001dLo00<004LoAcl04dLo00<004LoAcl054Lo00<004LoAcl04dLo00<004LoAcl0
0dLo2P001DLo00<004/oBcl054/o00<004/oBcl054/o00<004/oBcl04d/o00<004/oBcl02T/o1`00
0d/O00<004/OBal054/O00<004/OBal054/O00<004/oBcl054/o00<004/oBcl02T/o1`000dlN00<0
04lnCch054ln00<004lnCch05Dln00<004loCcl04Dlo1`0054ln00<004lnCch05Dln00<004loCcl0
34lo1@000e<n00<004loCcl05Tlo00<004loCcl05Dlo00<004mOCel010004E=O00<004mOCel05DmO
00<004mOCel01@004E=O00@004mOCel0019?G`@001I?O`03001oogoo009oo`03001oogoo04Yoo`00
B7oo0P0027oo0P003Goo00<007ooOol02Woo00<004LoAcl04dLo0P005TLo00<004LoAcl03TLo2P00
4TLo00<004LoAcl04dLo00<004LoAcl054Lo00<004LoAcl03TLo2P0044Lo00<004/oBcl054/o00<0
04/oBcl054/o00<004/oBcl04d/o00<004/oBcl00T/o1`002d/O00<004/OBal054/O00<004/OBal0
54/O00<004/oBcl054/o00<004/oBcl00T/o1`002dlN00<004lnCch054ln00<004lnCch054ln00<0
04loCcl02Tlo1`0014ln00<004lnCch05Dln00<004lnCch05Dln00<004loCcl01Tlo1@002E<n00<0
04loCcl05Dlo00<004loCcl04dlo1@005U=O00<004mOCel04dmO10005e=O00<004mO00003TmO1000
0U=o00<004moCgl05Tmo00D007ooOomoo`0004aoo`00BGoo0P001Woo0P003Woo00<007ooOol02goo
00<004LoAcl054Lo00<004LoAcl054Lo00<004LoAcl00dLo2P001dLo00<004LoAcl04dLo00<004Lo
Acl04dLo00<004LoAcl054Lo00<004LoAcl00dLo2P001DLo00<004LoAcl04dLo00<004/oBcl054/o
00<004/oBcl054/o00<004/oBcl03T/o2@004d/O00<004/OBal054/O00<004/OBal04d/O00<004/o
Bcl04T/o1`004dlN00<004lnCch054ln00<004lnCch054ln00<004loCcl00Tlo1`0034ln00<004ln
Cch05Dln00<004lnCch054ln00@004loCcm??`D000iC?P03001??dlo01I??`03001??dlo00e??`D0
00=CG`03001CGe=O01ECG`03001?GdmO00m?G`@0009CG`03001CGe=O01ICG`03001?G`0000U?G`D0
00MCO`03001?Odmo01E?O`03001oogoo009oo`03001oogoo04Uoo`00BGoo0P001Woo0P003Goo1000
37oo0P005DLo0P004TLo20004TLo00<004LoAcl04dLo00<004LoAcl04dLo00<004LoAcl04DLo2000
44Lo00<004LoAcl04dLo00<004/oBcl04d/o00<004/oBcl05D/o00<004/oBcl00d/o2P001D/O00<0
04/OBal05D/O00<004/OBal04d/O00<004/OBal054/O00<004/oBcl02T/o1`000dlN00<004lNCah0
54lN00<004lnCch054ln00<004lnCch04Tln1`004dln00<004lnCch05Dln00<004lnCch04Tln1P00
55<n00<004loCcl05Tlo00<004loCcl01Tlo1P002E=O00<005=ODel05E=O00<004mOCel02DmO1@00
1e=O00<005=ODel05U=O0P001DmO10003E=o00<004moCgl04dmo0`000goo00<007ooOol0BGoo001:
Ool20004Ool2000?Ool00`00Oomoo`0>Ool00`00Acm7?`0DAcl00`00Acm7?`08Acl70005Acl00`00
Acm7?`0CAcl00`00Acm7?`0CAcl00`00Acm7?`0CAcl00`00Acm7?`09Acl70003Acl00`00Acm7?`0C
Acl00`00Acm7?`0CAcl00`00Bcm;?`0CBcl00`00Bcm;?`0BBcl8000@Bal00`00Bam;7`0DBal00`00
Bam;7`0DBal00`00Bam;7`0DBal00`00Bcm;?`02Bcl7000;Cah00`00Cai?7P0DCah00`00Cci??P0D
Cch00`00Cci??P0<Cch50003Cah00`00Cci??P0ECch00`00Cci??P0ECch00`00Cci??P0<Cch50003
Dch00`00DciC?P0DDch00`00Ccm??`0FCcl01000Ccm??dlo1@003e=O00<005=ODel05U=O00<004mO
Cel014mO100035=O00<005=ODel05U=O0P0000=?G`0000000P004E=o00<004moCgl03dmo10000Tmo
00<007ooOol00Woo00<007ooOol0B7oo001:Ool8000?Ool00`00Oomoo`0?Ool2000EAcl01000Acm7
?dLo1P003DLo00<004LoAcl04dLo00<004LoAcl04dLo00<004LoAcl04dLo00@004LoAcm7?`L000]7
?`030017?dLo01=7?`030017?dLo01=7?`03001;?d/o01=;?`03001;?d/o00Y;?`L000=;7`03001;
7d/O01=;7`03001;7d/O01A;7`03001;7d/O01A;7`03001;7d/O00m;7`T001=?7P03001?7TlN01A?
7P03001??Tln01=??P03001??Tln00M??PD000U?7P03001??Tln01A??P03001??Tln01E??P03001?
?Tln00M??PD000UC?P03001C?U<n01AC?P03001??dlo01A??`D001ECG`03001CGe=O01ECG`03001?
GdmO00@0015CG`03001CGe=O01ACG`@001ICO`03001?Odmo00U?O`D000M?O`05001oogooOol0001:
Ool004aoo`@0015oo`03001oogoo015oo`030017?dLo00i7?`P001A7?`030017?dLo01=7?`030017
?dLo01=7?`030017?dLo00i7?`P001=7?`030017?dLo01=7?`030017?dLo01=7?`03001;?d/o01=;
?`03001;?d/o009;?`L000];7`03001;7d/O01=;7`03001;7d/O01A;7`03001;7d/O01A;7`03001;
7d/O00=;7`/000E?7P03001?7TlN01A?7P03001?7TlN01A?7P03001??Tln01A??P04001??TlnCch5
000>Cah00`00Cci??P0ECch00`00Cci??P0ECch01000Cci??Tln1@003U<n00<005<nDch05E<n00<0
04loCcl03Tlo1@000U<n00<005=ODel05E=O00<005=ODel055=O10005U=O00<005=ODel03U=O1@00
0U=O00<005=oDgl05E=o00<004moCgl01Dmo10003Dmo00D007ooOomoo`0004Uoo`00H7oo00<007oo
Ool04goo00<004LoAcl00dLo2P001d<o00<004LoAcl04dLo00<004LoAcl04dLo00<004LoAcl04dLo
00<004LoAcl00dLo2P001TLo00<004LoAcl04dLo00<004LoAcl04dLo00<004LoAcl04dLo00<004/o
Bcl03T/o2@004d/O00<004/OBal04d/O00<004/OBal04d/O00<004/OBal04T/O20004DlN00<004lN
Cah054lN00<004lNCah054lN00<004lnCch04Dln1P0054lN00<004lnCch05Dln00<004lnCch04Tln
1P0055<n00<005<nDch055<n00<004loCcl02Tlo100025<n00<005=ODel05E=O00<005=ODel03U=O
1@000U=O00<005=ODel05E=O00<005=ODel02U=O10001e=O0P005e=o00<004moCgl010004Dmo00D0
07ooOomoo`0004Uoo`00H7oo00<007ooOol057oo1@004T<o00<004LoAcl04dLo00<004LoAcl04dLo
00<004LoAcl03TLo2P004DLo00<004LoAcl04dLo00<004LoAcl04dLo00<004LoAcl04dLo00<004/o
Bcl00d/o2P001D/O00<004/OBal05D/O00<004/OBal04d/O00<004/OBal04d/O00<004/OBal02T/O
1`000d/N00<004lNCah054lN00<004lNCah054lN00<004lNCah04dlN00<004lnCch02Tln1`000dlN
00<004lNCah05DlN00<004lnCch054ln00<004lnCch03Dln1@000e<n00<005<nDch055<n00<005<n
Dch05E<n00<004loCcl01Dlo10003E<n00<005=ODel055=O00<005=ODel02U=O100025=O00<005=O
Del05E=O00<005=ODel01E=O10002e=O0P005U=o10005Tmo00D007ooOomoo`0004Qoo`00H7oo00<0
07ooOol05Woo00<004<o@cl04d<o00<004LoAcl04dLo00<004LoAcl04dLo00<004LoAcl00dLo2P00
1dLo00<004LoAcl04TLo00<004LoAcl04dLo00<004LoAcl04dLo00<004LoAcl03TLo2P0044/O00<0
04/OBal054/O00<004/OBal054/O00<004/OBal04d/O00<004/OBal00T/O1`002d/N00<004lNCah0
4dlN00<004lNCah054lN00<004lNCah054lN00<004lnCch00Tln1`002dlN00<004lNCah054lN00<0
04lnCch05Dln00<004lnCch01Tln1P002E<n00<005<nDch055<n00<005<nDch055<n00<004loCcl0
1@004E<n00<005=ODel05E=O00<005=ODel01E=O100035=O00<005=ODel05E=O00<005=ODel01@00
3e=O00<005=O000045=o1@000Tmo00<004moCgl05Dmo00D007ooOomoo`0004Qoo`00H7oo00<007oo
Ool05goo00<004<o@cl04d<o0P0054Lo00<004LoAcl03TLo2P004TLo00<004LoAcl04TLo00<004Lo
Acl04dLo00<004LoAcl04dLo00<004LoAcl00dLo2P001DLO00<004/OBal04d/O00<004/OBal054/O
00<004/OBal054/O00<004/OBal03T/O2@004d/N00<004lNCah04dlN00<004lNCah054lN00<004lN
Cah04DlN1`004dlN00<004lNCah054lN00<004lnCch054ln00@004lnCci??PD000mC?P03001C?U<n
01EC?P03001C?U<n015C?PD001MC?P03001CGe=O01ACG`03001CGe=O00D0015CG`03001CGe=O01=C
G`@001ACG`03001CG`0000aCO`@000Q?O`03001?Odmo01E?O`05001oogooOol00017Ool0061oo`03
001oogoo01Qoo`8001E3?`030017?dLo0197?`030017?dLo00=7?`X000M3?`030017?dLo01=7?`03
0017?dLo0197?`030017?dLo01=7?`030017?dLo00i7?`X001177`03001;7d/O01=;7`03001;7d/O
01A;7`03001;7d/O01A;7`03001;7d/O00=;7`X000E;7P03001;7T/N01E;7P03001?7TlN01=?7P03
001?7TlN01=?7P03001?7TlN00Y?7PL000=?7P03001?7TlN01A?7P03001?7TlN01A?7P03001??Tln
019??PH001EC?P03001C?U<n01AC?P03001C?U<n00aC?PD000=C?P03001C?U<n01IC?P03001CGe=O
019CG`D001MCG`03001CGe=O00iCG`@0009CG`03001CGe=O01=CG`04001CGe=O0007Dgl4000<Cgl0
0`00Cgm?O`0DCgl30002Ool00`00Oomoo`15Ool0061oo`03001oogoo01Yoo`030013?d<o01=3?`03
0017?dLo00e7?`X00193?`030017?dLo01=7?`030017?dLo0197?`030017?dLo01=7?`030017?dLo
00=7?`X000E77`0300177dLO01=77`03001;7d/O01=;7`03001;7d/O01=;7`03001;7d/O019;7`P0
011;7P03001;7T/N01A;7P03001?7TlN01=?7P03001?7TlN01A?7P03001?7TlN009?7PL000]?7P03
001?7TlN01A?7P03001?7TlN01A?7P03001??Tln00a??PD000=C7P03001C?U<n01EC?P03001C?U<n
01EC?P03001C?U<n00IC?PD000UC?P03001C?U<n01IC?P03001CGe=O00aCG`D000=CGP03001CGe=O
01ICG`03001CGe=O00UCG`D000MCG`03001CGe=O019CG`04001CGe=O0002Dgl5000ACgl00`00Cgm?
O`0>Cgl50002Cgl01@00Oomoogoo0000AWoo001POol00`00Oomoo`0KOol2000D@cl00`00Acm7?`03
Acl90007@cl00`00@cm3?`0C@cl00`00Acm7?`0CAcl00`00Acm7?`0BAcl00`00Acm7?`0>Acl:000@
Aal00`00Aam77`0CAal00`00Bam;7`0CBal00`00Bam;7`0CBal00`00Bam;7`0:Bal70003Bal00`00
Bai;7P0CBah00`00Bai;7P0DBah00`00Cai?7P0CCah00`00Cai?7P0ACah7000CCah00`00Cai?7P0D
Cah00`00Cai?7P0DCah00`00Cci??P06Cch50009Dah00`00DciC?P0EDch00`00DciC?P0DDch01000
DciC?U<n1@003e<n00<005<nDch05U<n00<005=ODel01U=O1@002E=N00<005=ODel05U=O00<005=O
Del015=O10003E=O00<005=ODel04E=O00<005=O00000`005Tmo00<004moCgl02Tmo100024mo00@0
07ooOol004Ioo`00H7oo00@007oo000001aoo`030013?d<o00e3?`X00153?`030013?d<o01=3?`80
01A7?`030017?dLo0197?`030017?dLo00=7?`X000I77`0300177dLO01977`0300177dLO01=77`03
001;7d/O01=;7`03001;7d/O01=;7`03001;7d/O009;7`L000];7`03001;7T/N01=;7P03001;7T/N
01A;7P03001?7TlN019?7P03001?7TlN00Y?7PL000=?7P03001?7TlN01A?7P03001?7TlN01A?7P03
001?7TlN01A?7P04001??TlnCch5000?Dah00`00DciC?P0EDch00`00DciC?P0ADch6000DDch00`00
DciC?P0FDch01000DemCGe=O1@003U=N00<005=ODel05U=O00<005=ODel010004E=O00<005=ODel0
3e=O10000U=o00<004moCgl05Tmo00<004moCgl01Dmo100034mo00D007ooOomoo`0004Eoo`00H7oo
0P007goo00<004<o@cl00d<o2@001d<o00<004<o@cl04T<o0P005D<o00<004LoAcl04TLo00<004Lo
Acl03DLo2P004DLO00<004LOAal04TLO00<004LOAal04dLO00<004/OBal04d/O00<004/OBal03T/O
2@004d/O00<004/NBah04T/N00<004/NBah054/N00<004lNCah04dlN00<004lNCah00TlN1`002dlN
00<004lNCah054lN00<004lNCah054lN00<004lNCah04DlN1P0055<N00<005<nDch05E<n00<005<n
Dch035<n1@000e<n00<005<nDch05E<n00<005<nDch055<n1@0055=N00<005=ODel055=O10005U=O
00<005=ODel02E=O1@000U=o00<005=oDgl00U=o00<004moCgl05Dmo00<004moCgl01@004Dmo00@0
07ooOol004Eoo`00H7oo00<007ooOol07goo1@004D<o00<004<o@cl04d<o00<004<o@cl04d<o00<0
04LoAcl04TLo00<004LoAcl00dLo2@001dLo00<004LOAal04TLO00<004LOAal04TLO00<004LOAal0
4dLO00<004/OBal04d/O00<004/OBal00d/O2P001D/O00<004/OBal05D/O00<004/NBah04T/N00<0
04/NBah054/N00<004lNCah03TlN2@004dlN00<004lNCah054lN00<004lNCah04dlN00<004lNCah0
2TlN1`000e<N00<005<NDah05E<N00<005<nDch05E<n00<005<nDch01U<n1@002E<n00<005<nDch0
55<n00<005<nDch03e<n1@000U<n00<005=NDeh05E=N00<005=ODel03U=O1@000U=O00<005=ODel0
5E=O00<005=ODel01E=O10001e=o00<005=oDgl00e=o00<004moCgl04dmo10005dmo00@007ooOol0
04Aoo`00H7oo00<007ooOol08Goo00<004<o@cl04T<o00<004<o@cl04d<o0P0054<o00<004LoAcl0
24Lo3`004DLo00<004LOAal04TLO00<004LOAal04TLO00<004LOAal04dLO00<004/OBal03T/O2P00
44/O00<004/OBal054/O00<004/NBah04d/N00<004/NBah054/N00<004lNCah00dlN2P001DlN00<0
04lNCah05DlN00<004lNCah04dlN00<004lNCah054lN00<004lNCah00TlN1`002e<N00<005<NDah0
5E<N00<005<nDch055<n00@005<nDciC?PD000iC?P03001C?U<n01EC?P03001C?U<n00YC?P@000QC
?P03001CGU=N01ACGP03001CGe=O00YCG`@000QCG`03001CGe=O01ECG`03001CGe=O00@000]CO`03
001COe=o00=CO`03001?Odmo00m?O`@0009?O`03001?Odmo01I?O`04001oogoo0014Ool0061oo`03
001oogoo029oo`8001=3?`8001E3?`030013?d<o00e3?`l000a3?`030017?dLo0197?`0300177dLO
01977`0300177dLO01977`0300177dLO01=77`03001;7d/O00=;7`X000E;7`03001;7d/O01=;7`03
001;7d/O01A;7`03001;7T/N019;7P03001;7T/N019;7PP0011?7P03001?7TlN01A?7P03001?7TlN
01A?7P03001?7TlN015?7PL001=C7P03001C7U<N01AC7P03001C?U<n019C?PH001AC?P03001C?U<n
01EC?P03001C?U<n00EC?P@000aC?P03001CGU=N01ECGP03001CGe=O00ECG`@000aCG`03001CGe=O
01ACG`@000mCO`03001COe=o00ACO`03001?Odmo00U?O`D000M?O`03001?Odmo01A?O`<0009oo`03
001oogoo045oo`00H7oo00<007ooOol097oo00<004<o@cl04T<o00<004<o@cl04d<o00<004<o@cl0
0d<o2@001d<o00<004<o@cl04T<o00<004LoAcl04TLo00<004LOAal04TLO00<004LOAal04TLO00<0
04LOAal03TLO2P0044/O00<004/OBal04d/O00<004/OBal054/O00<004/NBah04T/N00<004/NBah0
2T/N1`000dlN00<004lNCah04dlN00<004lNCah054lN00<004lNCah04dlN00<004lNCah02TlN1`00
0dlN00<005<NDah055<N00<005<NDah05E<N00<005<nDch035<n1@000e<n00<005<nDch055<n00<0
05<nDch05E<n00<005<nDch01@004E<n00<005=NDeh055=N00<005=ODel01@004E=O00<005=ODel0
45=O0`000U=o00<005=oDgl03U=o00<005=oDgl015=o00<004moCgl01Dmo100034mo00<004moCgl0
3dmo1@000Tmo00@007ooOol004=oo`00H7oo00<007ooOol09Goo00<004<o@cl04T<o00<004<o@cl0
3T<o2P004D<o00<004<o@cl04T<o00<004LoAcl04TLo00<004LOAal04TLO00<004LOAal04TLO00<0
04LOAal00dLO2P001DLO00<004/OBal04d/O00<004/OBal04d/O00<004/OBal04d/O00<004/NBah0
4d/N00<004/NBah00T/N1`002dlN00<004lNCah04dlN00<004lNCah054lN00<004lNCah04dlN00<0
04lNCah00TlN1`002dlN00<005<NDah055<N00<005<NDah055<N00<005<nDch01e<n1@002E<n00<0
05<nDch055<n00<005<nDch04e<n10005U<n00<005=NDeh04e=N10005e=O00<005=ODel02e=O1000
1U=o00<005=oDgl03U=o00<005=oDgl015=o00<004moCgl010004Dmo00<004moCgl02Tmo100024mo
00@007ooOol0049oo`00H7oo00<007ooOol09Woo0P004d<o00<004<o@cl00d<o2P001d<o00<004<o
@cl04T<o00<004<o@cl04T<o00<004LoAcl04TLo00<004LOAal04TLO00<004LOAal024LO3`0044LO
00<004/OBal04d/O00<004/OBal04d/O00<004/OBal04d/O00<004/NBah03T/N2@004dlN00<004lN
Cah04TlN00<004lNCah054lN00<004lNCah04DlN1`004TlN00<005<NDah05E<N00<005<NDah055<N
00@005<nDciC?PD000iC?P03001C?U<n01EC?P03001C?U<n00iC?P@0009C?P03001C?U<n01IC?P03
001CGU=N00iCGP@0009CGP03001CGe=O01ICG`03001CGe=O00QCG`<000YCO`03001COe=o00iCO`03
001COe=o00=CO`@001I?O`03001?Odmo00E?O`@000a?O`04001oogoo0012Ool005moo`03001oogoo
02Uoo`030013?d<o00Q3?`h00193?`030013?d<o0193?`030013?d<o0193?`030017?dLo0197?`03
00177dLO00e77`l000]77`0300177dLO01977`03001;7d/O01=;7`03001;7d/O01=;7`03001;7d/O
01=;7`03001;7T/N00=;7PX000E;7P03001?7TlN01A?7P03001?7TlN01=?7P03001?7TlN01A?7P03
001?7TlN00U?7PL000=?7P03001?7TlN01A?7P03001C7U<N01AC7P03001C7U<N019C7PH001AC?P03
001C?U<n01AC?P03001C?U<n00UC?PD000MC?P03001C?U<n01EC?P03001CGU=N00UCGPD000MCGP03
001CGe=O01ICG`03001CGe=O00=CG`@000iCO`03001COe=o00eCO`03001COe=o00<0009?O`03001?
Odmo01E?O`03001?Odmo00D0015?O`04001oogoo0011Ool005moo`03001oogoo02Yoo`X000]3?`03
0013?d<o01=3?`030013?d<o0193?`030013?d<o0193?`030017?dLo0197?`0300177dLO00=77`T0
00E77`0300177dLO01=77`0300177dLO01977`03001;7d/O01=;7`03001;7d/O01=;7`03001;7d/O
00i;7`X0011;7P03001?7TlN01A?7P03001?7TlN01=?7P03001?7TlN01A?7P04001?7TlNCah7000;
Cah00`00Cai?7P0DCah00`00DaiC7P0DDah00`00DaiC7P0<Dah50003Dah00`00DciC?P0DDch00`00
DciC?P0EDch00`00DciC?P04Dch4000=Dch00`00DciC?P0EDch00`00DeiCGP04Deh4000=Deh00`00
DemCG`0EDel00`00DemCG`03000CDgl00`00DgmCO`0;Dgl40006Cgl00`00Cgm?O`0CCgl4000FCgl0
1@00Oomoogoo0000@7oo001OOol00`00Oomoo`0/Ool00`00@cm3?`0A@cl00`00@cm3?`0C@cl00`00
@cm3?`0B@cl00`00@cm3?`0B@cl00`00Acm7?`08Acl?000?Aal00`00Aam77`0CAal00`00Aam77`0B
Aal00`00Bam;7`0CBal00`00Bam;7`0CBal00`00Bam;7`03Bal:0005Bah00`00Bai;7P0CBah00`00
Cai?7P0DCah00`00Cai?7P0BCah00`00Cai?7P0BCah6000BCah00`00Cai?7P0DCah00`00DaiC7P0D
Dah00`00DaiC7P07Dah50009Dah00`00DciC?P0DDch00`00DciC?P0DDch00`00DciC?P04000ADch0
0`00DciC?P0EDch00`00DeiCGP04000ADeh00`00DemCG`0DDel4000FDgl00`00DgmCO`08Dgl30000
0dmo001?O`07Cgl00`00Cgm?O`0@Cgl30002Cgl00`00Cgm?O`0FCgl01000Oomoo`00@7oo001OOol0
0`00Oomoo`0]Ool00`00@cm3?`0A@cl00`00@cm3?`0C@cl00`00@cm3?`0B@cl00`00@cm3?`0=@cl?
000;Aal00`00Aam77`0AAal00`00Aam77`0CAal00`00Aam77`0BAal00`00Bam;7`0CBal00`00Bam;
7`0>Bal:000@Bah00`00Bai;7P0CBah00`00Cai?7P0CCah00`00Cai?7P0CCah00`00Cai?7P0:Cah7
0003Cah00`00Cai?7P0CCah00`00Cai?7P0DCah00`00DaiC7P0DDah01000DaiC7U<N1@003U<N00<0
05<nDch05E<n00<005<nDch04E<n1@005U<n00<005<nDch04e<n10005U=N00<005=ODel03e=O1000
0U=O00<005=oDgl05U=o00<005=oDgl00e=o100014mo00<004moCgl01dmo00<004moCgl02dmo1000
1Tmo00<004moCgl05Dmo00D007ooOomoo`0003moo`00Ggoo1000;Goo00<004<o@cl04D<o0P0054<o
00<004<o@cl04T<o00<004<o@cl00d<o2@001d<O00<004LOAal04DLO00<004LOAal04DLO00<004LO
Aal04dLO00<004LOAal04TLO00<004/OBal04d/O00<004/OBal00d/O2P001D/N00<004/NBah04d/N
00<004/NBah04T/N00<004lNCah054lN00<004lNCah04dlN00<004lNCah00TlN1`002dlN00<004lN
Cah04dlN00<004lNCah04dlN00<005<NDah04U<N1P0055<N00<005<nDch055<n00<005<nDch035<n
1@000e<n00<005<nDch05E<n00<005<nDch03e<n10000UMN00<005=NDeh05U=N00<005=ODel02E=O
1@001e=O00<005=oDgl05E=o00<005=oDgl00`0024mo00<004moCgl01dmo00<004moCgl024mo0`00
2dmo00<004moCgl04dmo0`000Woo00<007ooOol0?Goo001OOol00`00Oomoo`0_Ool2000C@cl00`00
@cm3?`0B@cl00`00@cm3?`08@cl?000A@al00`00Aam77`0AAal00`00Aam77`0AAal00`00Aam77`0C
Aal00`00Aam77`0BAal00`00Bam;7`0>Bal:000@Bah00`00Bai;7P0BBah00`00Bai;7P0CBah00`00
Cai?7P0DCah00`00Cai?7P0@Cah7000BCah00`00Cai?7P0CCah00`00Cai?7P0DCah00`00DaiC7P0<
Dah50003Dah00`00DaiC7P0DDah00`00DciC?P0EDch00`00DciC?P06Dch50009Dch00`00DciC?P0E
Dch00`00DciC?P09Dch50007Eeh00`00DeiCGP0EDeh00`00DemCG`05Del4000=Del00`00DgmCO`0C
Dgl4000;Cgl00`00Cgm?O`08Cgl00`00Cgm?O`03Cgl4000>Cgl00`00Cgm?O`0?Cgl40002Bgl01@00
Oomoogoo0000?Woo001OOol00`00Oomoo`0aOol00`00@cm3?`0A@cl00`00@cm3?`0=@cl?000<@al0
0`00@am37`0B@al00`00Aam77`0AAal00`00Aam77`0AAal00`00Aam77`0CAal00`00Aam77`0BAal0
0`00Bam;7`03Bal:0005Bah00`00Bai;7P0CBah00`00Bai;7P0BBah00`00Bai;7P0CBah00`00Cai?
7P0CCah00`00Cai?7P09Cah70003Cah00`00Cai?7P0DCah00`00Cai?7P0CCah00`00Cai?7P0DCah0
0`00DaiC7P06Dah50009Dah00`00DaiC7P0DDah00`00DciC?P0DDch01000DciC?U<n1@003e<n00<0
05<nDch05E<n00<005<nDch015<n10003EMN00<005=NDeh05E=N00<005=ODel010004E=O00<005=o
Dgl03e=o10000Tmo00<004moCgl02Tmo00<004moCgl024mo00<004moCgl00`004dmo00<004moCgl0
2Dmo1@001d]o00@007ooOol003ioo`00Ggoo00<007ooOol0<Woo00<004<o@cl04D<o00<004<o@cl0
0d<o2@001d<o00<004<O@al04T<O00<004<O@al04T<O00<004LOAal04DLO00<004LOAal04DLO00<0
04LOAal04dLO00<004LOAal024LO3`0044/N00<004/NBah04d/N00<004/NBah04T/N00<004/NBah0
4T/N00<004lNCah054lN00@004lNCai?7PL000]?7P03001?7TlN01A?7P03001?7TlN019?7P03001?
7TlN01A?7P04001C7U<NDah5000>Dah00`00DaiC7P0DDah00`00DciC?P0CDch5000DDch00`00DciC
?P0EDch00`00DciC?P04000AEeh00`00DeiCGP0DDeh4000FDel00`00DgmCO`09Dgl50007Cgl00`00
Cgm?O`09Cgl00`00Cgm?O`07Cgl4000FCgl00`00Cgm?O`05Cgl4000<Bgl01@00Oomoogoo0000?Goo
001OOol00`00Oomoo`0cOol00`00@cm3?`08@cl>000A@cl00`00@am37`0B@al00`00@am37`0B@al0
0`00Aam77`0AAal00`00Aam77`0AAal00`00Aam77`0>Aal?000:Aal00`00Bai;7P0CBah00`00Bai;
7P0BBah00`00Bai;7P0BBah00`00Bai;7P0CBah00`00Cai?7P0?Cah8000BCah00`00Cai?7P0DCah0
0`00Cai?7P0CCah00`00Cai?7P0ACah6000DDah00`00DaiC7P0DDah00`00DciC?P0>Dch40002Dch0
0`00DciC?P0EDch00`00DciC?P0CDch4000FEeh00`00DeiCGP0@Deh30002Del00`00DemCG`0EDel0
0`00DgmCO`05Dgl4000<Cgl00`00Cgm?O`09Cgl00`00Cgm?O`03Cgl40002Bgl00`00Cgm?O`0FCgl0
0`00Cgm?O`04000ABgl01000Oomoo`00?Goo001OOol00`00Oomoo`0dOol:000;?cl00`00@cm3?`0B
@cl00`00@am37`0B@al00`00@am37`0B@al00`00Aam77`0AAal00`00Aam77`0AAal00`00Aam77`03
Aal:0005Aal00`00Aam77`0BAal00`00Bai;7P0CBah00`00Bai;7P0BBah00`00Bai;7P0BBah00`00
Bai;7P0CBah00`00Cai?7P03Cah;0005Cah00`00Cai?7P0CCah00`00Cai?7P0DCah00`00Cai?7P0C
Cah00`00Cai?7P09Cah70003Dad00`00DaiC7P0DDah00`00DaiC7P0DDah00`00DciC?P09Dch50007
Dch00`00DciC?P0DDch00`00DciC?P0?Dch40002Ech00`00EeiGGP0EEeh00`00DeiCGP0<Deh40006
Del00`00DemCG`0EDel00`00DgmCO`04000ACgl00`00Cgm?O`08Cgl60007Bgl00`00Cgm?O`0CCgl5
000FBgl01000Oomoo`00?7oo001OOol00`00Oomoo`0fOol00`00?clo?`0A?cl2000C@cl2000C@al0
0`00@am37`0B@al00`00Aam77`0AAal00`00Aam77`08Aal>000@Aal00`00Aam77`0BAal00`00Bai;
7P0BBah00`00Bai;7P0CBah00`00Bai;7P0BBah00`00Bai;7P0@Bah8000ACah00`00Cai?7P0CCah0
0`00Cai?7P0CCah00`00Cai?7P0CCah00`00Cai?7P02Cah7000;Dad00`00DaiC7P0DDah00`00DaiC
7P0DDah00`00DciC?P04Dch4000<Dch00`00DciC?P0EDch00`00DciC?P09Dch50007Ech00`00EeiG
GP0EEeh00`00DeiCGP08Deh3000:Del00`00DemCG`0DDel4000FCgl00`00Cgm?O`04Cgl4000=Bgl0
0`00Cgm?O`0=Cgl50003Bgl00`00Bgm;O`0EBgl01000Oomoo`00?7oo001OOol00`00Oomoo`0gOol2
000C?cl00`00@cm3?`0B@cl00`00@am37`0A@al00`00@am37`0B@al00`00Aam77`08AalC0009Aal0
0`00Aam77`0CAal00`00Aam77`0BAal00`00Bai;7P0BBah00`00Bai;7P0BBah00`00Bai;7P0BBah0
0`00Bai;7P09Bah70003C_h00`00Cai?7P0CCah00`00Cai?7P0CCah00`00Cai?7P0DCah00`00Cai?
7P0@Cah7000BDad00`00DaiC7P0DDah00`00DaiC7P0DDah00`00DciC?P04000ADch00`00DciC?P0E
Dch00`00DciC?P04Dch4000=Ech00`00EeiGGP0EEeh00`00DeiCGP03Deh4000>Del00`00DemCG`0@
Del30002Dgl00`00Cgm?O`0ECgl00`00Cgm?O`040003Bgl00`00Bgm;O`0<Bgl00`00Cgm?O`07Cgl5
0009Bgl00`00Bgm;O`0BBgl40002Ool00`00Oomoo`0iOol005moo`03001oogoo03Uoo`03000o?clo
014o?`030013?d<o0193?`0300137d<O01537`0300137d<O00Q37a@000U37`0300177dLO01577`03
00177dLO01=77`0300177dLO01577`03001;7T/N01=;7P03001;7T/N019;7P03001;7T/N019;7P04
001;7T/NBah7000;C_h00`00Cai?7P0CCah00`00Cai?7P0CCah00`00Cai?7P0DCah00`00Cai?7P08
Cah70003Dad00`00DaeC7@0DDad00`00DaiC7P0DDah00`00DaiC7P0ADah5000EDch00`00DciC?P0E
Dch00`00DciC?P04000AEch00`00EeiGGP0EEeh00`00DeiCGP03000CDel00`00DemCG`0;Del40006
Dgl00`00Cgm?O`0CCgl40007Bgl00`00Bgm;O`0=Bgl01000Cgm?Odmo1@003d]o00<004]oBgl034]o
1@000dMO00@007ooOol003]oo`00Ggoo00<007ooOol0>Woo00<003lo?cl04Clo0P004d<o00<004<O
@al024<O4`002d<O00<004<O@al044<O00<004LOAal04DLO00<004LOAal04dLO00<004LOAal04DLO
00<004/NBah04T/N00<004/NBah04d/N00<004/NBah024/N3@004dkn00<004lNCah04dlN00<004lN
Cah04TlN00<004lNCah054lN00@004lNCai?7PL000]C7@03001C7E<M01AC7@03001C7U<N01=C7P03
001C7U<N00aC7PD000=C7@03001C?U<n01EC?P03001C?U<n01=C?P@001IG?P03001GGUMN01=GGP@0
01ICG`03001CGe=O00QCG`<000]CO`03001?Odmo00i?O`@0009;O`03001;Od]o00I;O`03001;Od]o
00a;O`D001A;O`03001;Od]o00M;O`D000U7G`04001oogoo000jOol005ioo`03001oogoo03aoo`80
01<o?`030013?d<o00Q3?a<000/o7`0300137d<O01537`0300137d<O01137`0300177dLO01577`03
00177dLO01=77`0300177dLO01577`03001;7T/N019;7P03001;7T/N00i;7Pl000Y:oP03001>oTkn
01=>oP03001?7TlN01=?7P03001?7TlN01=?7P03001?7TlN015?7PH0019C7@03001C7E<M01AC7@03
001C7U<N01AC7P03001C7U<N00IC7PD000UC7@03001C?U<n01EC?P03001C?U<n00iC?P@0009G?P03
001G?ULn01EG?P03001GGUMN00mGGP@0009GGP03001CGe=O01ICG`03001CGe=O00=CG`@000mCO`03
001?Odmo00U?O`@000M;O`03001;Od]o00E;O`03001;Od]o00Q;O`@00097O`03001;Od]o01E;O`04
001;Od]oBgl5000>Ael01000Oomoo`00>Woo001NOol00`00Oomoo`0nOol00`00?clo?`08?clC000;
?al00`00?alo7`0A?al00`00@am37`0A@al00`00@am37`0@@al00`00Aam77`0AAal00`00Aam77`0B
Aal00`00Aam77`0AAal00`00Bai;7P0CBah00`00Bai;7P03Bah:0005B_h00`00B_i:oP0BB_h00`00
C_i>oP0CC_h00`00Cai?7P0CCah00`00Cai?7P0CCah00`00Cai?7P09Cah70003D_d00`00DaeC7@0C
Dad00`00DaeC7@0DDad00`00DaiC7P0CDah01000DaiC7U<N1@003e<M00<005<nDch055<n00<005<n
Dch02E<n1@001eLn00<005LnEch05ELn00<005MNEeh02EMN1@001eMN00<005=ODel05E=O00<005=O
Del00`004e=o00<004moCgl01Dmo100034]o00<004]oBgl014]o00<004]oBgl00d]o1@001dMo00<0
04]oBgl04T]o1P004dMO00D007ooOomoo`0003Uoo`00GWoo1000?Woo2P002c/O00<003lO?al04ClO
00<003lO?al04ClO00<004<O@al04D<O00<004<O@al044<O00<004LOAal04DLO00<004LOAal04TLO
00<004LOAal04DLO00<004/NBah03T/N2P0044[n00<004[nB_h04T[n00<004knC_h04Tkn00<004lN
Cah04dlN00<004lNCah04dlN00<004lNCah00TlN1`002e;m00<005<MDad04U<M00<005<MDad055<M
00<005<NDah04U<N1@0055<M00<005<nDch05E<n00<005<nDch015<n100035Ln00<005LnEch05ULn
00<005MNEeh015MN100035MN00<005=ODel055=O10005e=o00<004moCgl010004D]o00<004]oBgl0
0d]o00<004]o00000`003DMo00<004]oBgl034]o1@000dMO00<004MOAel054MO00@007ooOol003Uo
o`00GWoo00<007ooOol0@Goo00<003/O>al04C/O00<003lO?al04ClO00<003lO?al04ClO00<004<O
@al04D<O00<004<O@al044<O00<004LOAal04DLO00<004LOAal04TLO00<004LOAal04DLO00<004/N
Bah00d/N2P001D[n00<004[nB_h04d[n00<004[nB_h04D[n00<004knC_h04dkn00<004lNCah04dlN
00<004lNCah044lN1`004U;m00<005<MDad04e<M00<005<MDad055<M00<005<NDah035<N1@000U<M
00<005<MDad05E<M00<005<nDch055<n00<005<nDch010004ELn00<005LnEch05ELn00<005MNEeh0
10004EMN00<005=ODel045=O0`000U=o00<005=oDgl05E=o10005T]o00<004]oBgl010004DMo00<0
04]oBgl01d]o1@002DMO00<004MOAel04dMO00D007ooOomoo`0003Qoo`00GWoo00<007ooOol0@Woo
0P004S/O00<003lO?al04ClO00<003lO?al04ClO00<004<O@al04D<O00<004<O@al044<O00<004LO
Aal04DLO00<004LOAal04TLO00<004LOAal024LO3P0044[n00<004[nB_h04T[n00<004[nB_h04T[n
00<004knC_h04dkn00<004lNCah04dlN00<004lNCah024lN1`000dkm00<005;mD_d055;m00<005<M
Dad04e<M00<005<MDad055<M00<005<NDah01U<N1@0025<M00<005<MDad05E<M00<005<nDch04U<n
10005ELn00<005LnEch055Ln10005UMN00<005=ODel02e=O10001U=o00<005=oDgl04E=o0`000T^O
00<004]oBgl054]o10000TMo00<004MoAgl04DMo00@004]oBgm;O`D000i7G`030017GdMO01=7G`05
001oogooOol0000hOol005ioo`03001oogoo04Aoo`03000k7c/O010k7`80018o7`03000o7clO014o
7`0300137d<O01537`0300137d<O01137`0300177dLO01577`0300177dLO00Q77a@000U6oP03001:
oT[n01=:oP03001:oT[n019:oP03001:oT[n019:oP03001>oTkn019>oP03001?7TlN01=?7P04001?
7TlNCah7000;C_d00`00D_eBo@0CD_d00`00DaeC7@0CDad00`00DaeC7@0DDad01000DaiC7U<N1@00
3E<M00<005<MDad05E<M00<005<nDch03U<n10000ULm00<005LnEch05ELn00<005LnEch045Ln0`00
0UMN00<005MNEeh05EMN00<005=ODel025=O0`002e=o00<005=oDgl035=o10001T^O00<004]oBgl0
3d]o10000T=o00D004MoAgm7O`000157O`H001A7G`030017GdMO0117G`@000=oo`03001oogoo03Eo
o`00GWoo00<007ooOol0AGoo00<003/O>al04C/O00<003lO?al043lO00<003lO?al04ClO00<004<O
@al04D<O00<004<O@al044<O00<004LOAal024LO4`002TKn00<004KnA_h04DKn00<004[nB_h04T[n
00<004[nB_h04d[n00<004[nB_h04D[n00<004knC_h04dkn00<004lNCah044lN1P004dkm00<005;m
D_d04e;m00<005<MDad04e<M00<005<MDad04E<M1P004e<M00<005<MDad05E<M00<005<nDch02E<n
10001eLm00<005LnEch05ELn00<005LnEch02eLn10001UMN00<005MNEeh05EMN00<005=ODel00e=O
10003e=o00<005=oDgl025=o0`002d^O00<004]oBgl02D]o1@001d=o00@004MoAgl000a7O`D000=3
O`030017GdMO01E7G`030017GdMO00Q7G`L000=7G`05001oogooOol0000gOol005ioo`03001oogoo
04Ioo`80018k7`03000o7clO010o7`03000o7clO014o7`0300137d<O00Q37bH000U6o`030016oTKn
0196oP030016oTKn0156oP03001:oT[n019:oP03001:oT[n019:oP03001:oT[n019:oP03001>oTkn
019>oP03001?7TlN00U?7PL000=>o@03001>oDkm01=>o@03001BoE;m01ABo@03001C7E<M019C7@03
001C7E<M00aC7@D000=C7@03001C7E<M01AC7@03001C7E<M01AC7@03001C?U<n00EC?P@000]G?@03
001G?ULn01EG?P03001G?ULn00QG?P<000YGGP03001GGUMN01EGGP03001CGe=O00<001=CO`03001C
Oe=o00ACO`@000i;W`03001;Od]o00E;O`@000e3O`030017O`0000M7O`D000U3O`030017GdMO01A7
G`040017GdMOAel7000;Ael01@00Oomoogoo0000=Woo001NOol00`00Oomoo`18Ool00`00>alk7`0@
>al00`00?alo7`0@?al00`00?alo7`08?alC0009?al00`00@_m2o`0@@_l00`00A_m6o`0AA_l00`00
A_i6oP0BA_h00`00A_i6oP0AA_h00`00B_i:oP0BB_h00`00B_i:oP0BB_h00`00B_i:oP0BB_h00`00
C_i>oP0BC_h01000Cai?7TlN1`002dkm00<004kmC_d04dkm00<005;mD_d04e;m00<005<MDad04e<M
00<005<MDad01U<M1@002E<M00<005<MDad04e<M00<005<MDad05E<M00<005<nDch0100045Lm00<0
05LnEch05ELn00<005LnEch00eLn10003UMN00<005MNEeh04eMN10005e=o00<005=oDgl00`004d^O
00<004]oBgl010004T=o0P000TMo1@003d=o00<004MOAel04DMO1P004TMO00D007ooOomoo`0003Io
o`00GWoo00<007ooOol0BGoo<0002SlO00<003lO?al043lO00<004;o@_l044;o00<004KoA_l04DKo
00<004KnA_h04TKn00<004KnA_h04DKn00<004[nB_h04D[n00<004[nB_h04d[n00<004[nB_h04D[n
00<004knC_h03Tkn20004dkm00<004kmC_d04Tkm00<005;mD_d055;m00<005<MDad04U<M00@005<M
DaeC7@D000iC7@03001C7E<M01AC7@03001C7E<M01=C7@@001AG?@03001G?ULn01EG?P03001G?ULn
00<0019GGP03001GGUMN011GGP<0009GO`03001COe=o01ECO`@001E;W`@001E3O`D001A3O`030017
GdMO00Y7G`L000=7G`030017GdMO01=7G`05001oogooOol0000eOol0019oo`@000ioo`<000Yoo``0
00Uoo`H0019oo`03001oogoo04]oo`03000k7c/O010k7`03000k7c/O010k7`03000o7clO010o7`03
000o7clO010o7`030012od;o0112o`030016odKo0156o`030016oTKn0156oP030016oTKn0196oP03
001:oT[n015:oP03001:oT[n019:oP03001:oT[n019:oP03001>oTkn00=>oPX000E>o@03001>oDkm
01=>o@03001>oDkm01=>o@03001BoE;m01=Bo@03001C7E<M011C7@H001AC7@03001C7E<M01=C7@03
001C7E<M00mC7@@0009G7@03001G?ELm01AG?@03001G?ULn01=G?P@001IGGP03001GGUMN00]GGP@0
00IGO`03001COe=o015CO`<000=?W`03001;Wd^O00m;W`@000@kOP030013Od=o00e3O`D0008kG`80
01I3O`030017GdMO0097G`L000]7G`030017GdMO01=7G`04001oogoo000eOol0011oo`P000]oo`D0
00Uoo``000Moo`X0011oo`03001oogoo04aoo`80014k7`03000k7c/O010k7`03000o7clO010o7`03
000o7clO010o7`030012od;o0112o`030016odKo0156o`030016oTKn0156oP030016oTKn0156oP03
001:oT[n019:oP03001:oT[n019:oP03001:oT[n00Q:oPl0011>o@03001>oDkm01=>o@03001>oDkm
01=>o@03001BoE;m01=Bo@03001C7E<M00QC7@L000=Bo@03001C7E<M01AC7@03001C7E<M01AC7@03
001C7E<M00UC7@D000MG7@03001G?ELm01=G?@03001G?ULn011G?P<0009G?P03001GGUMN01EGGP03
001GGUMN00QGGP<000]GO`03001COe=o00aCO`@000M?W`03001;Wd^O00Y;W`@000TkOP030013Od=o
00M3O`D000PkG`8001=3O`L00197G`030017GdMO01=7G`05001oogooOol0000dOol0011oo`8000Ao
o`8000]oo`D000Yoo`<000Ioo`8000Moo`<000Eoo`<000moo`03001oogoo04ioo`03000k7c/O00lk
7`03000k7c/O010k7`03000o7clO010o7`03000o7clO010o7`030012od;o0112o`030016odKo0156
o`030016oTKn0156oP030016oTKn0156oP03001:oT[n015:oP03001:oT[n00i:oPl000Y>o@03001>
oDkm019>o@03001>oDkm01=>o@03001>oDkm01=>o@03001BoE;m01=Bo@04001C7E<MDad7000;D_d0
0`00DaeC7@0DDad00`00DaeC7@0DDad00`00DaeC7@04Dad4000<Ead00`00EceG?@0DEcd00`00EciG
?P0;Ech40006Ech00`00EeiGGP0EEeh00`00EeiGGP03Eeh4000?Egl00`00DgmCO`08Dgl3000<Cil0
0`00Bim;W`05Bil4000>>gh01000@gm3Od=o1@003C]O00<003]O00002d=o1`000d=O00<004MOAel0
54MO00<004MOAel044MO10000Woo00<007ooOol0<Woo000?Ool20006Ool2000:Ool5000;Ool3000G
Ool2000?Ool00`00Ool00002001=Ool00`00>alk7`0?>al00`00>alk7`0@>al00`00?alo7`0@?al0
0`00?alo7`0@?al00`00@_m2o`0@@_l00`00A_m6o`0AA_l00`00A_i6oP0@A_h00`00A_i6oP0BA_h0
0`00B_i:oP0AB_h00`00B_i:oP03B_h:0005B_h00`00C_e>o@0BC_d00`00C_e>o@0BC_d00`00C_e>
o@0CC_d00`00C_e>o@0CC_d00`00D_eBo@0@D_d6000BD_d00`00DaeC7@0DDad00`00DaeC7@0DDad0
0`00DaeC7@04000AEad00`00EceG?@0CEcd00`00EciG?P08Ech3000;Ech00`00EeiGGP0DEeh00`00
EeiGGP03000CEgl00`00DgmCO`04Dgl4000@Cil00`00Bim;W`04000@>gh6000B>el01000>elkG`00
0d=o1`002d=O00<004MOAel054MO00<004MOAel024MO1`000dMO00D007ooOomoo`0003=oo`003goo
0P001Woo0P002goo0`003Goo0`005goo0P003Goo0`00DGoo0P0043/O00<003/O>al043/O00<003lO
?al043lO00<003lO?al043lO00<004;o@_l044;o00<004KoA_l04DKo00<004KnA_h044Kn00<004Kn
A_h04TKn00<004[nB_h024[n3P0044[n00<004kmC_d04Tkm00<004kmC_d04Dkm00<004kmC_d054km
00<004kmC_d04Tkm00<005;mD_d02E;m1`000e;m00<005;mD_d04e;m00<005<MDad04e<M00<005<M
Dad04e<M10005ELM00<005LmEcd055Lm00<005LnEch00eLn10003ULn00<005MNEeh04eMN10005eMo
00<005=oDgl00`004dnO10003c]n1@0012ln00<003]O>el04C]O1`004d=O00<004MOAel04dMO00@0
04MOAem7G`L000]7G`05001oogooOol0000bOol000ioo`8000Qoo`8001]oo`<001Ioo`8000eoo`03
001oogoo05=oo`03000k7c/O00hk7`03000k7c/O010k7`03000o7clO010o7`03000o7clO010o7`03
0012od;o0112o`030016odKo0156o`030016oTKn0116oP030016oTKn00Q6oQ@000U:oP03001:oT[n
01=:oP03001>oDkm015>o@03001>oDkm019>o@03001>oDkm01=>o@03001>oDkm01=>o@04001BoE;m
D_d7000;D_d00`00D_eBo@0BD_d00`00DaeC7@0DDad00`00DaeC7@0>Dad40002Ead00`00EaeG7@0E
Ead00`00EceG?@0CEcd00`00EciG?P03000CEch00`00EeiGGP0?Eeh30002Fgh00`00EgmGO`0FEgl3
000CCil30004:c`00`00>ghkOP07>gh5000:;ch00`00>elkG`0:>el70003@el00`00@em3G`0C@el0
0`00Aem7G`0?Ael8000BAel01@00Oomoogoo0000<Woo000>Ool20008Ool2000LOol3000EOol2000=
Ool00`00Oomoo`1DOol:0007>al00`00>alk7`0@>al00`00?alo7`0@?al00`00?alo7`0@?al00`00
@_m2o`0@@_l00`00A_m6o`08A_lV000:A_h00`00B_i:oP0AB_h00`00B_i:oP0BB_h00`00C_e>o@0B
C_d00`00C_e>o@0BC_d00`00C_e>o@0CC_d00`00C_e>o@0@C_d6000BD_d00`00D_eBo@0CD_d00`00
DaeC7@0CDad00`00DaeC7@09Dad50007Ead00`00EaeG7@0DEad00`00EceG?@0BEcd4000FEch00`00
EeiGGP0<Eeh30006Fgh00`00EgmGO`0BEgl30002Dil00`00Cim?W`0=Cil40008:c`01000>ghkOS]n
1@0042ln00<003]O>el00S]O1`001T=O00<004=O@el00T=O00<004=O@el04d=O00<004MOAel00dMO
2`001DMO00<004MOAel04dMO00D007ooOomoo`00035oo`003Woo0P0027oo0P007Goo0`0057oo0P00
3Goo00<007ooOol0EWoo00<003;o<_l01C;oGP002D;n00<004KnA_h044Kn00<004KnA_h04TKn00<0
04[nB_h04D[n00<004[nB_h04T[n00<004kmC_d04Dkm00<004kmC_d04Tkm00<004kmC_d04dkm00<0
04kmC_d02Dkm1`000e;m00<005;mD_d04e;m00<005;mD_d04e;m00<005<MDad04e<M00<005<MDad0
15<M100035LM00<005LMEad05ELM00<005LmEcd03ELm10000U/m00<005LnEch05ULn00<005MNEeh0
1eMN10002U]n00<005MoEgl03UMo0`001U>O00<004nOCil02DnO0`002b/l1@004bln1`003D=O00<0
04=O@el00d=O00<004=O@el044=O20004DMO00<004MOAel04dMO00@007ooOol0035oo`003Woo0P00
27oo0P007Woo0`004goo0P003Goo00<007ooOol0Egoo00<003;o<_l03S;o00<003Ko=_l043Ko00<0
03[o>_l03c[o00<003ko?_l03cko00<004;o@_l044;o00<004;n@_h04D;n00<004KnA_h044Kn00<0
04KnA_h04TKn00<004[nB_h044[n00<004[nB_h04T[n00<004kmC_d04Tkm00<004kmC_d04Tkm00<0
04kmC_d04dkm00@004kmC_e>o@L000]Bo@03001BoE;m019Bo@03001BoE;m01=Bo@03001C7E<M01=C
7@03001C7E<M00@0015G7@03001G7ELM01AG7@03001G?ELm00UG?@@000MK?@03001G?ULn01IG?P03
001GGUMN00=GGP<000mKOP03001GOeMo00YGO`<000YCW`03001?WdnO00A?W`@000T[?0D000@B^080
00/_?PL000@oG`030013Gd=O00e3G`030013Gd=O00=3G`030013Gd=O00U3G`L000=7G`030017GdMO
01=7G`030017GdMO01=7G`05001oogooOol0000`Ool000ioo`8000Qoo`8001moo`<0015oo`8000io
o`03001oogoo05Qoo`8000lbo`80014fo`03000joc[o00ljo`03000nocko00lno`030012od;o0112
o`030012oT;n0152oP030016oTKn0116oP030016oTKn0156oP03001:oT[n015:oP03001:oT[n019:
oP03001>oDkm019>o@03001>oDkm015>o@03001>oDkm015>o@H0019Bo@03001BoE;m01=Bo@03001B
oE;m01=Bo@03001C7E<M015C7@@001EG7@03001G7ELM01EG7@03001G?ELm00AG?@@000]K?@03001G
?ULn01IG?P03001GGUMN00<0019KOP03001GOeMo00MGO`<000iCW`03001?WdnO00<000P[?0D000/B
^004000_?Rln;ch7000<?el00`00@em3G`0<@el00`00@em3G`04@el01000@em3Gd=O1`002dMO00<0
04MOAel04dMO00<004MOAel03TMO1P000Woo00<007ooOol0;Woo000>Ool20008Ool2000POol20009
Ool20005Ool3000>Ool00`00Oomoo`1JOol00`00<_lbo`0><_l00`00=_lfo`0?=_l00`00>_ljo`0?
>_l00`00?_lno`0??_l00`00@_m2o`0@@_l00`00@_i2oP0@@_h00`00A_i6oP0AA_h00`00A_i6oP0A
A_h00`00B_i:oP0@B_h00`00B_i:oP0CB_h00`00C_e>o@0AC_d00`00C_e>o@0BC_d00`00C_e>o@09
C_d70003D]d00`00D_eBo@0CD_d00`00D_eBo@0BD_d00`00D_eBo@0CD_d00`00DaeC7@0<Dad50002
E_`00`00EaeG7@0EEad00`00EaeG7@0DEad00`00EceG?@04000@Fcd00`00EciG?P0EEch3000FFgh0
0`00EgmGO`03Egl3000ADil50004:c`5000<4[P8000D?el00`00@em3G`0;@el00`00@em3G`08000B
Ael00`00Aem7G`0CAel00`00Aem7G`03Ael;0005Ael01@00Oomoogoo0000;goo000>Ool20008Ool2
000QOol20008Ool9000?Ool00`00Oomoo`1KOol00`00<_lbo`0><_l00`00=_lfo`0?=_l00`00>_lj
o`0?>_l00`00?_lno`0??_l00`00@_m2o`0@@_l00`00@_i2oP0@@_h00`00A_i6oP0@A_h00`00A_i6
oP0BA_h00`00B_i:oP0@B_h00`00B_i:oP0BB_h00`00C_e>o@0BC_d00`00C_e>o@0AC_d00`00C_e>
o@02C_d7000;D]d00`00D_eBo@0BD_d00`00D_eBo@0CD_d00`00D_eBo@0CD_d00`00DaeC7@06Dad5
0008E_`00`00EaeG7@0DEad00`00EaeG7@0CEad4000DFcd00`00EciG?P0BEch300000e]N001KOP0G
Fgh00`00Egl00002000ADil=00064[P:0006?el00`00?eloG`0D?el00`00@em3G`03@el:0005Ael0
0`00Aem7G`0CAel00`00Aem7G`0@Ael8000AAel01000Oomoo`00;goo000>Ool20008Ool2000QOol2
0008Ool200000goo00000003000@Ool00`00Oomoo`1LOol00`00<_lbo`0><_l2000@=_l00`00>_lj
o`0?>_l00`00?_lno`0??_l00`00@_m2o`0@@_l00`00@_i2oP0@@_h00`00A_i6oP0@A_h00`00A_i6
oP0AA_h00`00B_i:oP0AB_h00`00B_i:oP0BB_h00`00C_e>o@0AC_d00`00C_e>o@0=C_d9000BD]d0
0`00D_eBo@0CD_d00`00D_eBo@0BD_d00`00D_eBo@0CD_d01000DaeC7E<M1@003EKl00<005LMEad0
55LM00<005LMEad045LM0`000U/M00<005/mFcd055/m00<005LnEch03ULn0`001E]N00<005]nFgh0
5E]n0P004E>O2P000clO2@004CmO00<003mO?el04CmO20001dMO00<004MOAel01TMO00<004MOAel0
4dMO00<004MOAel024MO1`000dMO00<004MOAel04dMO00D007ooOomoo`0002ioo`003goo0P001Woo
0P006Goo0P001goo0P0027oo0P005Woo00<007ooOol0GGoo2`001c;o00<003Ko=_l03SKo00<003[o
>_l03c[o00<003ko?_l03cko00<004;o@_l03d;o00<004;n@_h044;n00<004KnA_h04DKn00<004Kn
A_h04DKn00<004[nB_h044[n00<004[nB_h04T[n00<004kmC_d04Tkm00<004kmC_d00dkm2@001DkM
00<005;MD]d055;M00<005;mD_d04U;m00<005;mD_d04e;m00<005;mD_d04E;m1@004eKl00<005LM
Ead055LM00<005LMEad02eLM10001U/M00<005/mFcd055/m00<005LnEch02ULn0`0025]N00<005]n
Fgh04U]n0`000UNO00<005>ODil02e>O20003ClO00<003mO?el04cmO00<003mO?el02CmO1`000d=O
00<004MOAel02DMO00<004MOAel01dMO00<004MOAel04TMO00@004MOAem7G`L000]7G`030017GdMO
01=7G`04001oogoo000^Ool000moo`8000Ioo`8001Uoo`<000Ioo`8000Qoo`8001Ioo`03001oogoo
05moo`03000^gbkO00H^ga8000Lfo`03000joc[o00ljo`03000nocko00lno`030012od;o00m2o`03
0012oT;n0112oP030016oTKn0156oP030016oTKn0156oP03001:oT[n011:oP03001:oT[n019:oP03
001>oDkm00Q>o@l000m>g@03001BgE;M01=Bg@03001BoE;m01=Bo@03001BoE;m019Bo@03001BoE;m
00aBo@D0009Fo003001Fo5Kl01=Fo003001G7ELM01AG7@03001G7ELM00QG7@<000YK7@03001K?E/m
01AK?@03001G?ULn00MG?P<000aKGP03001KOU]n00iKOP<000IGW`03001CWe>O00MCW`L0018o7`03
000oGcmO01<oG`04000oGcmO?el7000;@el00`00Aem7G`08Ael00`00Aem7G`07Ael00`00Aem7G`0>
Ael8000BAel00`00Aem7G`0CAel01@00Oomoogoo0000;Goo000@Ool20004Ool2000JOol40004Ool2
0009Ool2000EOol5001OOol2000@;]l00`00<]lbg`05<]lC0007>_l00`00?_lno`0??_l00`00@_m2
o`0?@_l00`00@_i2oP0@@_h00`00A_i6oP0@A_h00`00A_i6oP0AA_h00`00B_i:oP0@B_h00`00B_i:
oP0>B_h?000:C]d00`00C]e>g@0AC]d00`00D]eBg@0DD]d00`00D_eBo@0BD_d00`00D_eBo@0CD_d0
0`00D_eBo@06D_d50008E_`00`00E_aFo00CE_`00`00EaeG7@0DEad00`00EaeG7@03Ead4000>Fad0
0`00FceK?@0DFcd00`00EciG?P03Ech3000@Feh00`00FgiKOP0:Fgh3000:Eil00`00DimCW`03Dil4
0005Ggh00`00?alo7`0A?al00`00?eloG`0>?el8000B@el00`00Aem7G`08Ael00`00Aem7G`08Ael0
0`00Aem7G`03Ael:0005Ael00`00Aem7G`0CAel00`00Aem7G`0BAel01@00Oomoogoo0000;Goo000@
Ool8000KOol8000:Ool:000>Ool00`00Oomoo`1ROol00`00;]l^g`0>;]l00`00<]lbg`0=<]l00`00
=]lfg`07=]lC0007?_l00`00@_m2o`0?@_l00`00@_i2oP0?@_h00`00A_i6oP0AA_h00`00A_i6oP0A
A_h00`00B_i:oP0@B_h00`00B_i:oP03B_h:0005C]d00`00C]e>g@0BC]d00`00C]e>g@0AC]d00`00
D]eBg@0CD]d00`00D_eBo@0BD_d00`00D_eBo@0CD_d01000D_eBoE;m1@003EKl00<005KlE_`055Kl
00<005LMEad04eLM00<005LMEad00`004U/M00<005/mFcd055/m00<005LnEch00`004e]N00<005]n
Fgh01e]n0`003UNO00<005>O00000P002Umn00<003lO?al04ClO00<003mO?el00cmO2P001D=O00<0
04=O@el04d=O00<004MOAel01dMO00<004MOAel01TMO200044MO00<004MOAel04dMO00<004MOAel0
3DMO1P000goo00<007ooOol0:Woo000BOol4000OOol5000;Ool:000>Ool00`00Oomoo`1SOol00`00
;]l^g`0>;]l00`00<]lbg`0=<]l00`00=]lfg`0>=]l00`00>]ljg`08>]lU0007@_h00`00A_i6oP0A
A_h00`00A_i6oP08A_hQ000@C]d00`00C]e>g@0AC]d00`00C]e>g@0BC]d00`00D]eBg@0CD]d00`00
D_eBo@0BD_d00`00D_eBo@0AD_d5000CE_`00`00E_aFo00CE_`00`00EaeG7@0BEad4000FFad00`00
FceK?@0BFcd4000GFeh00`00FgiKOP03Fgh3000AEil2000=GghJ000@@el00`00@em3G`0C@el00`00
Aem7G`06Ael00`00Ael000060003Ael00`00Aem7G`0BAel00`00Aem7G`0CAel00`00Aem7G`03Ael:
0005Ael01@00Oomoogoo0000;7oo001MOol00`00Oomoo`1TOol2000?;]l00`00<]lbg`0=<]l00`00
=]lfg`0>=]l00`00>]ljg`0?>]l00`00?]hngP0??]h00`00@]i2gP08@]hV0009A]d00`00B]e:g@0@
B]d00`00C]e>g@0BC]d00`00C]e>g@0BC]d00`00C]e>g@0AC]d00`00D]eBg@0CD]d00`00D_eBo@0B
D_d00`00D_eBo@0<D_d50002E]`00`00E_aFo00CE_`00`00E_aFo00DE_`00`00EaeG7@0=Ead40002
Fa`00`00FaeK7@0EFad00`00FceK?@0?Fcd30002Fcd00`00FeiKGP0FFeh00`00FgiKOP03000AEil3
000<Ggh300000enN000o7`0B?al00`00@em3G`0C@el00`00@em3G`0B@el01000Aem7GdMO1`002dMO
00<004MOAel04TMO00<004MOAel044MO200044MO00D007ooOomoo`0002]oo`00GGoo00<007ooOol0
IWoo00<002kO;]l03BkO00<003;O<]l03C;O00<003KO=]l03SKO00<003[O>]l03c[O00<003kN?]h0
3ckN00<004;N@]h03d;N00<004KNA]h04DKN00<004KMA]d04DKM00<004[MB]d044[M00<004kMC]d0
4TkM00<004kMC]d04DkM00<004kMC]d04TkM00<005;MD]d04U;M00<005;mD_d04e;m00<005;mD_d0
1U;m1@0025KL00<005KlE_`04eKl00<005KlE_`04eKl00<005LMEad02ELM10001e/L00<005/MFad0
5E/M00<005/mFcd02e/m0`001U/m00<005]NFeh05E]N0`004UNO0P003Emn0P001EnN00<003lO?al0
4ClO00<004=O@el04T=O00<004=O@el03T=O20001DMO00<004MOAel02TMO00<004MOAel04dMO00<0
04MOAel024MO1`000dMO00<004MOAel04dMO00@007ooOol002]oo`00G7oo00<007ooOol0J7oo1P00
2RkO00<003;O<]l03C;O00<003KO=]l03SKO00<003[O>]l03c[O00<003kN?]h03ckN00<004;N@]h0
3d;N00<004KNA]h04DKN00<004KMA]d044KM00<004[MB]d044[M00<004kMC]d04TkM00<004kMC]d0
4TkM00<004kMC]d04DkM00<005;MD]d04e;M00<005;mD_d04U;m00@005;mD_eBo@D000eFg003001F
o5Kl01=Fo003001Fo5Kl01AFo003001G7ELM00AG7@@000]K7003001K7E/M01EK7@03001K?E/m00MK
?@@000YK?@03001KGU]N015KGP<0009OWP03001GWeNO00eGW`<000aOOP<000QOWP03000o7clO014o
7`030013Gd=O0193G`030013Gd=O00=3G`X000E7G`030017GdMO00E7G`030017GdMO00]7G`030017
GdMO0197G`040017GdMOAel7000;Ael00`00Aem7G`0BAel01@00Oomoogoo0000:Woo001LOol00`00
Oomoo`1ZOol010008[hR_R:n2@000RkO00<003;O<]l03C;O00<003KO=]l03SKO00<003[O>]l03c[O
00<003kN?]h03ckN00<004;N@]h03d;N00<004KNA]h04DKN00<004KMA]d044KM00<004[MB]d044[M
00<004kMC]d04TkM00<004kMC]d04DkM00<004kMC]d04TkM00<005;MD]d04U;M00<005;mD_d045;m
1P004eKL00<005KlE_`04eKl00<005KlE_`04eKl00<005LMEad0100045/L00<005/MFad05E/M00<0
05/mFcd00e/m0`003U/m00<005]NFeh03e]N0P001UnN00<005NOEil02UNO0P0000=_^`00Ggh02Umn
0P0035nN00<003lO?al043lO00<004=O@el03T=O2P0044MO00<004MOAel014MO00<004MOAel034MO
00<004MOAel03DMO20004TMO00<004MOAel04dMO00@007ooOol002Yoo`00G7oo00<007ooOol0Jgoo
00<002:n8[h02B:n2@002S;O00<003KO=]l03SKO00<003[O>]l03S[O00<003kN?]h03ckN00<004;N
@]h044;N00<004KNA]h044KN00<004KMA]d04DKM00<004[MB]d044[M00<004kMC]d04DkM00<004kM
C]d04TkM00<004kMC]d04DkM00<005;MD]d04e;M00<005;mD_d025;m1`000e;L00<005KLE]`04eKL
00<005KlE_`04eKl00<005KlE_`04UKl100055/L00<005/MFad05E/M00<005/mFcd00`004U/m00<0
05]NFeh02e]N0`002EnN00<005NOEil01UNO0`0016nk00<005mnGgh01Emn0`003enN00<003lO?al0
43lO00<004=O@el00d=O2P001DLo00<004MOAel04dMO00<004MOAel00dMO00<004MOAel034MO00<0
04MOAel00dMO2P001DMO00<004MOAel04dMO00<004MOAel044MO10000Woo00<007ooOol09goo001L
Ool00`00Oomoo`1/Ool2000>8[h01000:[lZ_bZo2@000S;O00<003KO=]l03SKO00<003[O>]l03S[O
00<003kN?]h03ckN00<004;N@]h03d;N00<004KNA]h04DKN00<004KMA]d044KM00<004[MB]d044[M
00<004kMC]d04TkM00<004kMC]d04DkM00<004kMC]d04TkM00<005;MD]d04U;M00@005;mD_eBo@L0
00]Bg003001Fg5KL01=Fg003001Fo5Kl019Fo003001Fo5Kl00mFo0<0009Jo003001K75/L01AK7003
001K7E/M01AK7@<001EK?@03001KGU]N00UKGP8000eOWP03001GWeNO00=GW`8000M_^`03001OOUmn
00=OOP80019OWQT00117?`030017GdMO0197G`030017GdMO00=7G`030017GdMO00Q7G`X00117G`03
0017GdMO01=7G`030017GdMO00Q7G`L000=;G`04001oogoo000YOol005aoo`03001oogoo06ioo`03
000R_R:n00`R_P03000Z_bZo00TZ_`T000/fg`03000jgc[O00hjg`03000ngSkN00lngP030012gT;N
00m2gP030016gTKN0116gP030016gDKM0156g@03001:gD[M011:g@03001>gDkM019>g@03001>gDkM
015>g@03001>gDkM019>g@03001BgE;M00eBg@P0019Bg003001Fg5KL01=Fg003001Fo5Kl01=Fo003
001Fo5Kl00]Fo0<000IJo003001K75/L01AK7003001K7E/M011K7@<00003Ga`005/m01IK?@03001K
GU]N00EKGP<0011OWP03001GW`0000<000U_^`03001OOP000080019OWP800003Gih003lO014o7`03
0017?dLo01=7?`030017GdMO0197G`030017GdMO0097G`/000E7?`030017GdMO01=7G`030017GdMO
0197G`040017GdMOAel7000;Bel01000Oomoo`00:7oo001LOol00`00Oomoo`1_Ool00`008[hR_P0<
8[h00`00:[lZ_`0<:[l00`00<[lb_`02<[l90003=]l00`00>]ljg`0=>]l00`00?]hngP0@?]h00`00
@]i2gP0?@]h00`00A]i6gP0@A]h00`00A]e6g@0@A]d00`00B]e:g@0@B]d00`00C]e>g@0BC]d00`00
C]e>g@0AC]d00`00C]e>g@0BC]d00`00D]eBg@03D]d:0005D]`00`00D]aBg00CD]`00`00E]aFg00C
E]`00`00E_aFo00BE_`00`00E_aFo007E_`40009F_`00`00FaaK700DFa`00`00FaeK7@0=Fad30005
Ga`00`00FceK?@0EFcd00`00FeiKGP02Feh2000CGih2000016?m001_n@002Vnk00<005nNGih045nN
0`0015nN00<003lO?al043lO00<004LoAcl04dLo00<004MOAel03DMO2P0044Lo00<004MOAel04TMO
00<004MOAel03TMO20004T]O00@007ooOol002Qoo`00G7oo00@007oo000006moo`03000R_R:n00`R
_P03000Z_bZo00`Z_`03000b_c:o00Xb_`X000Xjg`03000ngSkN00lngP030012gT;N0112gP030016
gTKN0116gP030016gDKM0116g@03001:gD[M011:g@03001>gDkM019>g@03001>gDkM015>g@03001>
gDkM00e>g@X0011Bg003001Bg5;L019Bg003001Fg5KL01=Fg003001Fo5Kl01=Fo003001Fo5Kl00=F
o0<000eJo003001K75/L01EK7003001K7E/M00UK7@<000QO7003001K?E/m01EK?@03001KGP000080
01=OWP800005Hod00000KoT0000;Kk/00`00GiiOWP0>Gih20007Gih00`00?alo7`0A?al00`00Acm7
?`0CAcl00`00Aem7G`03Ael90005Acl01@00Acm7?dLo000044Lo00<004MOAel04dMO00<004MOAel0
0dMO2P001D]O00<004]OBel04d]O00@007ooOol002Moo`00G7oo0P00LWoo10002b:n00<002Zo:[l0
32Zo00<003:o<[l03C:o00<003Zn>[h00cZn2@000S[O00<003kN?]h03ckN00<004;N@]h03d;N00<0
04KNA]h044KN00<004KMA]d044KM00<004[MB]d044[M00<004kMC]d04TkM00<004kMC]d04DkM00<0
04kMC]d00dkM2P001E:l00<005;LD]`04U;L00<005;LD]`04U;L00<005KLE]`04eKL00<005KlE_`0
4eKl00<005KlE_`00`004E[l00<005/LFa`055/L00<005/MFad01U/M0`0035lL00<005/mFcd055/m
0P004enN0`000V?m00@006oiKoT000]_^`03001c^`0000eOWP8000YOWP03000o7clO014o7`030017
?dLo00i7?`X000m7?`040017?dLo000AAcl00`00Aem7G`0@Ael8000@Bel00`00Bem;G`0BBel01000
Oomoo`009goo001LOol00`00Oomoo`1cOol00`005Wd0000500068[h00`00:[lZ_`0<:[l00`00<[lb
_`0=<[l00`00>[hj_P0;>[h>0007?]h00`00@]i2gP0?@]h00`00A]i6gP0@A]h00`00A]e6g@0@A]d0
0`00B]e:g@0@B]d00`00C]e>g@0BC]d00`00C]e>g@0<C]d:000@D[`00`00D]aBg00BD]`00`00D]aB
g00BD]`00`00E]aFg00CE]`00`00E_aFo00AE_`4000DF_`00`00FaaK700EFa`00`00FaeK7@02Fad3
000?Ga`00`00FceK?@0AFcd300000f=m001OWP0@Gih20004Hod01000KoU_n@002fnk00D007>kLk]c
^`0000YOWP8000eOWP03000o7clO014o7`030017?dLo00=7?`X000E7?`030017?dLo0157?`050017
?dLoAcl0000AAcl00`00Aem7G`08Ael70003Bcl00`00Bem;G`0BBel00`00Bem;G`0BBel01@00Oomo
ogoo00009Woo001LOol00`00Oomoo`1dOol200055Wd600000b:n000Z_`0=:[l00`00<[lb_`0=<[l0
0`00>[hj_P0=>[h00`00?[hn_P08?[hC0007@]h00`00A]i6gP0?A]h00`00A]e6g@0AA]d00`00B]e:
g@0@B]d00`00C]e>g@0AC]d00`00C]e>g@03C]d90005C[`00`00D[aB_00BD[`00`00D]aBg00BD]`0
0`00D]aBg00BD]`00`00E]aFg00CE]`00`00E_aFo00<E_`50002E]/00`00F_aJo00DF_`00`00FaaK
700DFa`00`00Fad00002000CGa`00`00FceK?@0>Fcd20005Hgd00`00GiiOWP0<Gih20004Hod20002
KoT00`00Kk]_^`09Kk/00`00Lk]c^`03Lk/00`00GiiOWP05Gih2000?Gih00`00?alo7`08?al?000@
Acl00`00Acm7?`0AAcl01000Acm7?`004DLo00@004MOAem7G`L000];?`03001;Gd]O019;G`03001;
Gd]O00m;G`@0009oo`03001oogoo02Aoo`00G7oo00<007ooOol0MWoo00<001Im5Wd021Im1P002bZo
00<003:o<[l03C:o00<003Zn>[h03CZn00<003jn?[h03cjn00<004:n@[h024:n4`001dKN00<004KM
A]d044KM00<004[MB]d044[M00<004kMC]d024kM3`003djl00<005:lD[`04E:l00<005;LD]`04U;L
00<005;LD]`04e;L00<005KLE]`04eKL00<005KlE_`01UKl1@0025KK00<005[lF_`04e[l00<005/L
Fa`055/L0P005UlL00<005/mFcd02e/m0`0026=m00<005nNGih02EnN0P001F?m00D006oiKoU_n@00
00]_^`03001c^g>k00Ac^`03001OWUnN009OWP<0015OWP/000Xo7`030017?dLo0197?`030017?dLo
0197?`030017?`0000e7?`P0019;?`03001;Gd]O01=;G`03001;Gd]O00M;G`L000=;G`05001oogoo
Ool0000UOol005aoo`03001oogoo07Moo`8000`FO@03000ROP0000D000HZ_`03000b_c:o00db_`03
000j_SZn00dj_P03000n_Sjn00ln_P030012_T:n00m2_P030016_DJm00Q6_CP000Y>_003001>_4jl
015>_003001B_5:l019B_003001Bg5;L019Bg003001Bg5;L019Bg003001Fg5KL01=Fg004001Fo5Kl
E_`5000=E]/00`00F_aJo00CF_`00`00FaaK700AFa`300000elL001O700FGa`00`00FceK?@08Fcd2
000<Hgd00`00GiiOWP06Gih20006Hod01@00KoU_nFoi00002fnk00<007>kLk/01W>k00@005nN0000
015OWP<00003Gih003lO01<o7`030017?dLo0197?`030017?dLo0157?`030017?`0000=7?`X000E;
?`03001;?d/o01=;?`03001;Gd]O019;G`04001;Gd]OBel6000;Bel01@00Oomoogoo000097oo001L
Ool00`00Oomoo`1iOol00`005WdFO@0:5Wd00`008WhROP048Wh600000bZo000b_`0=<[l00`00>[hj
_P0>>[h00`00?[hn_P0??[h00`00@[i2_P0?@[h00`00A[e6_@0?A[d00`00A[e6_@0@A[d00`00B[a:
_00@B[`00`00C[a>_00BC[`00`00C[a>_00AC[`00`00D[aB_00AD[`00`00D]aBg00BD]`00`00D]aB
g00CD]`00`00E]aFg00AE]`5000BE]/00`00F_aJo00DF_`00`00FaaK700=Fa`30005Ga`00`00GaaO
700DGa`00`00FceK?@05Fcd3000?Hgd00`00GiiOWP02Gih30006Hod20003KoT00`00Kk]_^`09Kk/0
0`00Lk]c^`08Lk/00`00GiiOWP0?Gih20005Gih00`00?alo7`0A?al00`00Acm7?`0CAcl00`00Acm7
?`0<Acl:000@Bcl00`00Bcm;?`0CBcl00`00Bem;G`0=Bel8000ABel01@00Oomoogoo000097oo001L
Ool00`00Oomoo`1jOol3000:5Wd00`008WhROP098Wh6000;<[l00`00>[hj_P0>>[h00`00?[hn_P0>
?[h00`00@[i2_P0?@[h00`00A[e6_@0@A[d00`00A[e6_@0@A[d00`00B[a:_00@B[`00`00C[a>_00A
C[`00`00C[a>_00AC[`00`00D[aB_00BD[`00`00D]aBg00BD]`00`00D]aBg00BD]`00`00E]aFg00=
E]`40002E]/00`00E]]Ff`0CE]/00`00F_aJo00CF_`00`00FaaK700:Fa`30008Ga`00`00GaaO700E
Ga`00`00FceK?@02Fcd2000CHgd01000Gih0000026?m00<006oiKoT00foi00<006nkKk/026nk00<0
07>kLk/02G>k00<005nNGih03EnN0P0025nN00<003lO?al04ClO00<004LoAcl04TLo00<004LoAcl0
0dLo2@001D/o0P004d/o00<004/oBcl04d/o00<004]OBel00d]O2P001D]O00<004]OBel04T]O00D0
07ooOomoo`0002=oo`00Fgoo00<007ooOol0OGoo100021Im00<0029n8Wh02R9n00@002ZN:YhZWPH0
00Hb_`03000j_SZn00hj_P03000n_Sjn00hn_P030012_T:n00m2_P030016_DJm00m6_@030016_DJm
0116_@03001:_4Zl011:_003001>_4jl015>_003001>_4jl019>_003001B_5:l015B_003001Bg5;L
019Bg003001Bg5;L019Bg003001Fg5KL00UFg0@000MFf`03001FfeKK019Ff`03001Jo5[l01AJo003
001K75/L00IK70<000aO7003001O75lL01AO7003001K?@00008001ESO@<000QSo@03001_nFoi00=_
n@03001_^fnk00Q_^`03001c^g>k00Uc^`03001c^`0000]OWP<000]OWP03000o7clO014o7`030017
?dLo00e7?`X000m;?`03001;?d/o019;?`03001;?d/o011;?`P0011;G`03001;Gd]O019;G`04001o
ogoo000SOol005]oo`03001oogoo07ioo`030001o07l00@000DFO@03000ROR9n00XROP03000ZWRZN
00HZWPH00003<[l003Zn00hj_P03000n_Sjn00hn_P030012_T:n0112_P030016_DJm00m6_@030016
_DJm0116_@03001:_4Zl011:_003001>_4jl015>_003001>_4jl015>_003001B_5:l019B_003001B
g5;L019Bg003001Bg5;L019Bg003001Fg5KL00AFg0@000]Ff`03001FfeKK01=Ff`03001Jo5[l01=J
o003001K75/L00=K70<000mO7003001O75lL01AO708001ISO@8000=W_@03001SoF?m00=So@8000E_
n@03001_^fnk00Q_^`03001c^g>k00Uc^`05001c^g>kLk/00008Gih2000?Gih00`00?alo7`0@?al0
0`00Acm7?`03Acl:0005Acl00`00Bcm;?`0ABcl2000DBcl00`00Bcm;?`08Bcl70003Bcl00`00Bem;
G`0BBel00`00Bem;G`0BBel01@00Oomoogoo00008Woo001KOol00`00Oomoo`1oOol200040O`40002
5Wd00`008WhROP0:8Wh00`00:YhZWP0;:Yh6000<>[h00`00?[hn_P0>?[h00`00@[i2_P0?@[h00`00
A[e6_@0?A[d00`00A[e6_@0@A[d00`00B[a:_00@B[`00`00C[a>_00AC[`00`00C[a>_00BC[`00`00
D[aB_00AD[`00`00D]aBg00BD]`00`00D]aBg00BD]`00`00E]aFg004000?E]/00`00E]]Ff`0CE]/0
0`00F_aJo00CF_`00`00FaaK7003000CGa`00`00GaaO700@Ga`300000f<l001SO@0CHgd20006Ikd0
1@00HoeSoF?m00001Voi00<006nkKk/026nk00<007>kLk/02G>k00<007>kLk/00g>k00<005nNGih0
0enN0P004EnN6@0044Lo00<004/oBcl044/o00<004/o00004d/o00@004/oBcm;?`L000];?`03001;
Gd]O019;G`03001;Gd]O00e;G`H0009oo`03001oogoo021oo`00Fgoo00<007ooOol0PGoo00<0007l
0O`01@7l1000329n00<002ZN:Yh032ZN00@003:N<YhbWPL000Hj_P03000n_Sjn00hn_P030012_T:n
00m2_P030016_DJm00m6_@030016_DJm0116_@03001:_4Zl011:_003001>_4jl015>_003001>_4jl
015>_003001B_5:l015B_003001Bg5;L019Bg003001Bg5;L011Bg0D001AFf`03001FfeKK019Ff`03
001Jo5[l019Jo0@001IO7003001O75lL00iO708000ES?003001SOF=m011SO@03001W_FNm00MW_@03
001So@0000I_n@03001_^fnk00U_^`03001c^g>k00Qc^`03001c^g>k00Ec^`03001OWP000080015O
WP800003Fih003lO014o7`030017?dLo0197?`03001;?d/o011;?`03001;?`0000m;?`P0019;?`03
001;Gd]O019;G`03001;Gd]O00=;G`X000E?G`05001oogooOol0000QOol005]oo`04001oo`000021
Ool00`000O`1o0070O`4000:8Wh00`00:YhZWP0<:Yh00`00<YhbWP07<Yh600000cZn000n_P0>?[h0
0`00@[i2_P0?@[h00`00A[e6_@0?A[d00`00A[e6_@0@A[d00`00B[a:_00@B[`00`00C[a>_00AC[`0
0`00C[a>_00AC[`00`00D[aB_00BD[`00`00D]aBg00BD]`00`00D]aBg008D]`70003E[/00`00E]]F
f`0CE]/00`00E]]Ff`0CE]/00`00F_aJo00>F_`30002F_/00`00GaaO700EGa`00`00GaaO700;Ga`3
0008Hc`00`00HgeSO@0=Hgd2000:Ikd50003KoT00`00Kk]_^`09Kk/00`00Lk]c^`08Lk/00`00Lk]c
^`07Lk/00`00GiiOWP0@Gih20004Fih00`00?alo7`0@?al00`00Acm7?`0BAcl00`00Bcm;?`0?Bcl0
1000Bcm;?`001D/o2@001Dlo00<004/oBcl04d/o00<004]OBel03d]O200044mO00@007ooOol0025o
o`00Fgoo0P00Q7oo00<0007l0O`0207l00<001Hm00000P00229n00<002ZN:Yh032ZN00<003:N<Yh0
33:N1P0033jn00<004:n@[h03d:n00<004JmA[d03dJm00<004JmA[d044Jm00<004ZlB[`044Zl00<0
04jlC[`04Djl00<004jlC[`04Djl00<005:lD[`04E:l00<005;LD]`04U;L00@005;LD]aBg0L000]F
^`03001FfeKK01=Ff`03001FfeKK019Ff`03001Jo5[l00]Jo0<000IJn`03001O75lL01EO7003001O
75lL00QO708000]S?003001SOF=m00]SO@8000]W_@03001_^fnk00=_^`<000]_^`03001c^g>k00Qc
^`03001c^g>k00Qc^`03001OWUnN00iOWP8000MKWP03000o7clO010o7`030017?dLo0197?`03001;
?d/o00e;?`X000m??`03001;?d/o01=;?`03001;Gd]O00M;G`L000=?G`03001?GdmO019?G`05001o
ogooOol0000POol005]oo`03001oogoo08Aoo`8000T1o004000F?AHm5Sd400058Wh00`00:YhZWP0<
:Yh00`00<YhbWP0=<Yh01000>YdjWCZM1P001Sjn00<004:n@[h03d:n00<004JmA[d044Jm00<004Jm
A[d03dJm00<004ZlB[`044Zl00<004jlC[`04Djl00<004jlC[`04Djl00<005:lD[`04U:l00<005;L
D]`03e;L1P004UJk00<005KKE]/04eKK00<005KKE]/04eKK00<005[lF_`01U[l10002E[k00<005lL
Ga`05ElL00<005lLGa`01ElL0`003V<l00<006=mHgd026=m0P002fNm0P001Vnk00<006nk00002Vnk
00<007>kLk/027>k00<007>kLk/027>k00<007>k000035nN0`002U^N00<003lO?al043lO00<004Lo
Acl04DLo00<004/oBcl00d/o2P0000=;?`00Bcl00T/o00<004loCcl04Dlo00<004/oBcl04d/o00@0
04]OBem;G`H000]?G`03001?GdmO019?G`04001oogoo000POol005]oo`03001oogoo08Ioo`<000L1
o003000F?AHm00@F?@@0008ROP03000ZWRZN00/ZWP03000bWS:N00hbWP03000jWCZM00HjW@H00003
?[h004:n0112_P030016_DJm00m6_@030016_DJm0116_@03001:_4Zl011:_003001>_4jl011>_003
001>_4jl019>_003001B_5:l015B_003001Bg5;L00QBg0L000=B^`03001F^eJk019F^`03001FfeKK
01AFf`03001FfeKK019Ff`03001Jo5[l00=Jo0<000iJn`03001O75lL01EO7003001O75lL009O7080
015S?003001SOF=m00ISO@8000aW_@03001_^fnk00E_^`05001_^fnkKk/00008Kk/00`00Lk]c^`08
Lk/00`00Lk]c^`08Lk/01@00Lk]c^g>k00002EnN0P003E^N00<003lO?al043lO00<004LoAcl03DLo
2P002d/o00<004/oBcl00T/o00<004loCcl04Dlo00<004/oBcl044/o1P004DmO00<004mOCel04TmO
00D007ooOomoo`0001moo`00Fgoo00<007ooOol0Qgoo00<0005i00000P001@7l00<001Hm5Sd01aHm
10003BZN00<003:N<Yh03S:N00<003ZM>Yd02cZM200034:n00<004JmA[d03dJm00<004JmA[d03dJm
00<004ZlB[`044Zl00<004jlC[`04Djl00<004jlC[`04Djl00<005:lD[`04E:l00@005;LD]aBg0L0
00]B^`03001F^eJk019F^`03001FfeKK01=Ff`03001FfeKK019Ff`03001Jo5[l00<0015Jn`03001O
75lL01EO7003001O7000008001AS?003001SOF=m00ASO@03001W_FNm00]W_@03001_^fnk00E_^`03
001_^fnk00=_^`03001_^fnk00A_^`03001c^g>k00Qc^`03001c^g>k00Qc^`03001c^g>k00=c^`03
001OWUnN00AOWP80011KWP03000o7clO010o7`030017?dLo00=7?`T000E;?`03001;?d/o00e;?`03
001;?d/o009;?`03001??dlo019??`03001;?d/o00Q;?`L000=??`03001?GdmO019?G`03001?GdmO
00m?G`@0009oo`03001oogoo01eoo`00Fgoo00<007ooOol0R7oo0P000P5i0`000`7l00<001Hm5Sd0
2AHm10002bZN00<003:N<Yh03C:N00<003ZM>Yd03CZM00<003jM?Yd00cjM2@000d:n00<004JmA[d0
3dJm00<004JmA[d044Jm00<004ZlB[`044Zl00<004jlC[`044jl00<004jlC[`04Tjl00<005:lD[`0
35:l20004U:k00<005JkE[/04UJk00<005KKE]/04eKK00<005KKE]/04EKK10005E[k00<005lLGa`0
55lL0P0066<l00@006=mHgeSO@8000aW_@8000M_^`03001_^fnk00E_^`03001_^fnk009_^`03001c
^g>k00Qc^`03001c^g>k00Qc^`03001c^g>k00Ac^`03001OWUnN009OWP80019KWQT000m;?`03001;
?d/o00a;?`03001;?d/o00=;?`03001??dlo015??`04001;?d/oBcl7000;Ccl00`00Cem?G`0BCel0
0`00Cem?G`07Cel70003Cel01@00Oomoogoo00007Woo001KOol00`00Oomoo`2:Ool00`000GT1N@02
0GT300000`7l000F?@0:5Sd00`008UhRGP030009:Yh00`00<YhbWP0=<Yh00`00>YdjW@0=>Yd00`00
?YdnW@0;?Yd:000<A[d00`00A[e6_@0?A[d00`00B[a:_00@B[`00`00C[a>_00AC[`00`00C[a>_00A
C[`00`00D[aB_003D[`90005D[/00`00D[]B^`0BD[/00`00E[]F^`0CE[/00`00E]]Ff`0CE]/00`00
E]]Ff`0=E]/30002F]/00`00F_]Jn`0DF_/00`00GaaO700BGa`200000f<K001S?00GHc`01000Hgd0
00003FNm00<006nkKk/01Vnk00<006nkKk/01Vnk00D006nkKk]_^`0000]c^`03001c^g>k00Mc^`03
001c^g>k00Ic^`04001OWP00000AFih300000eNO000fo`0A=_l00`00Bcm;?`0BBcl00`00Bcm;?`0;
Bcl00`00Bcm;?`03Bcl00`00Ccm??`0?Ccl6000BCcl00`00Cem?G`0BCel01000Cem?GdmO1P002dmO
00@007ooOol001ioo`00Fgoo00<007ooOol0Rgoo00<0005i0GT0105i0`002aHm00<0029N8Uh00R9N
10001BZN00<003:N<Yh03C:N00<003ZM>Yd03CZM00<003jM?Yd03cjM00<004:L@Y`00d:L2@000dJm
00<004JmA[d044Jm00<004ZlB[`044Zl00<004jlC[`044jl00<004jlC[`03Djl2P003e:k00<005:k
D[/04U:k00<005JkE[/04UJk00<005KKE]/04eKK00<005KKE]/02UKK0`001U[K00<005[kF_/055[k
00<005lLGa`03UlL0`0016<K00<006<lHc`05F<l0P003FNm0P0026nk00<006nkKk/026nk00<006nk
00002g>k00<007>kLk/01g>k00<007>kLk/027>k00<005^NFih03e^N0P001ENO00<003Ko=_l043Ko
00<004/oBcl04D/o00<004/oBcl02d/o00<004/oBcl014/o00<004loCcl01dlo1`000e<n00<004lo
Ccl04Tlo00<004mOCel04DmO1@004DmO00D007ooOomoo`0001eoo`00Fgoo00<007ooOol0S7oo0P00
1`5i0P002QHm00<0029N8Uh01B9N10000RZN00<003:N<Yh03C:N00<003ZM>Yd03CZM00<003jM?Yd0
3cjM00<004:L@Y`02d:L3`001dJm00<004ZlB[`044Zl00<004jlC[`044jl00<004jlC[`00djl2P00
1DjK00<005:kD[/04E:k00<005:kD[/04U:k00<005JkE[/04UJk00<005KKE]/055KK00<005KKE]/0
1UKK0`002E[K00<005[kF_/055[k00<005lLGa`035lL0P001f<K00<006<lHc`04f<l0P0000=WG000
Ikd02fNm00<006nkKk/01fnk00<006nkKk/02Vnk00<007>kLk/02G>k00<007>kLk/01g>k00<007>k
Lk/02G>k00<005^NFih03E^N0P0025NO00<003Ko=_l03cKo00<004/oBcl04T/o00<004/oBcl02T/o
00<004/oBcl014/o00@004loCcm??`H000]C?P03001??dlo019??`03001?GdmO00]?G`D0009?G`03
001?GdmO019?G`04001oogoo000MOol005]oo`03001oogoo08ioo`8000H1N@@000PF?@03000RGR9N
00PRGP@000lbWP03000jWCZM00djW@03000nWCjM00hnW@030012W4:L00m2W0030016W4JL00Q6W3<0
011>V`03001B^e:k011B^`03001B^e:k019B^`03001F^eJk01=F^`03001FfeKK01=Ff`03001FfeKK
00=Ff`<000aJf`03001Jne[k01AJn`03001O75lL00YO708000YS6`03001S?6<l011S?08000AWG003
001W_FNm00MW_@8000U_^`03001_^fnk00]_^`03001c^g>k00Qc^`03001c^g>k00Mc^`03001c^g>k
00Uc^`03001_f`0000]KWP<000YGW`03000focKo010fo`03001;?d/o015;?`03001;?d/o00Y;?`03
001;?d/o00P0015C?P03001??dlo019??`03001?GdmO00I?G`D000Q?G`03001?GdmO015?G`05001o
ogooOol0000LOol005]oo`03001oogoo08moo`<000D1N@030005g0GL008000LF?@03000RGR9N00XR
GP@000`bWP03000jWCZM00djW@03000nWCjM00lnW@030012W4:L00m2W0030016W4JL00m6W003001:
VdZK011:V`03001>VdjK011>V`03001>VdjK019>V`03001B^e:k015B^`03001B^e:k019B^`03001F
^eJk019F^`03001FfeKK01=Ff`03001FfeKK00<0011Jf`03001Jne[k01AJn`03001O75lL00MO7080
00aS6`03001S?6<l00mS?003001WG6ML00EWG003001W_FNm00EW_@03001_^fnk00Q_^`03001_^fnk
00]_^`03001_^`0000Qc^`03001c^g>k00Mc^`03001c^g>k00Uc^`05001_ffoKKm/00008Fih2000>
Eil00`00=_lfo`0?=_l00`00Bcm;?`0BBcl00`00Bcm;?`03Bcl90005Dah00`00DciC?P0BDch00`00
Ccm??`0ACcl01000Cem?GdmO1@003DmO00<004mOCel044mO0`000Woo00<007ooOol06Woo001JOol0
0`00Oomoo`2BOol300040GT010001M`5g0GL0`0011Hm00<0029N8Uh02b9N00<002iM;Ud01@0023:N
00<003ZM>Yd03CZM00<003jM?Yd03SjM00<004:L@Y`03d:L00<004JLAY`044JL00<004ZKBY/044ZK
00<004jKCY/044jK00<004jKCY/04DjK00<005:kD[/04E:k00<005:kD[/04U:k00<005JkE[/04UJk
00<005KKE]/04UKK10004e[K00<005[kF_/055[k00<005lLGa`01ElL0P003f<K00<006<lHc`036<l
0P002FML00<006NmIkd00fNm00<006nkKk/026nk00<006nkKk/02fnk00D006nkKk]_^`0000Ic^`03
001c^g>k00Mc^`03001c^g>k00Uc^`03001_ffoK00=_f`03001KWU^N00=KWP80011GW`L000`fo`03
001;?d/o00e;?`X000IC7P03001C7U<N00IC7P03001C?U<n015C?P03001??dlo00m??`H001=?G`03
001?GdmO00Y?G`D0009?G`05001oogooOol0000KOol005Yoo`@0099oo`@000<1N@030005g0GL00<5
g0<0008F?@03000RGR9N00/RGP03000^GBiM00@^G@@000@bWP03000jWCZM00djW@03000nWCjM00ln
W@030012W4:L00i2W0030016W4JL0116W003001:VdZK011:V`03001>VdjK011>V`03001>VdjK019>
V`03001B^e:k011B^`03001B^e:k01=B^`03001F^eJk019F^`03001FfeKK00iFf`<0009J^P03001J
fe[K01=Jf`03001Jne[k01AJn`04001O75lLGa`3000AHa/00`00HcaS?00:Hc`2000;Ie`01000IkeW
_FNm0P002Vnk00<006nkKk/02fnk00<006nkKk/00fnk00<007>kLk/00W>k00<007>kLk/027>k00<0
07>kLk/027>k00<006oKKm/01FoK00<005^N00000P003eNO0`0000=JfP00E[/015Jk2@000cKo00<0
04/oBcl00d/o2P001EKm00<005<NDah025<N00<005<NDah01U<N00<005<nDch04U<n00<004loCcl0
1dlo1`000dmO00<004mOCel04dmO00<004mOCel01DmO1@0024mO00@007ooOol001]oo`00FWoo00<0
07ooOol0UGoo00@0003e00000081N@030005g0GL00D5g08000035Sd0029N00`RGP03000^GBiM00L^
G@H000ljW@03000nWCjM00hnW@030012W4:L00m2W0030016W4JL00m6W003001:VdZK011:V`03001>
VdjK011>V`03001>VdjK019>V`03001B^e:k015B^`03001B^e:k019B^`03001F^eJk019F^`03001F
feKK00]Ff`<000EJ^P03001Jfe[K01=Jf`03001Jne[k01AJn`04001O7000000DHa/00`00HcaS?008
Hc`2000>Ie`00`00Ikd0000;Kk/00`00Kk]_^`0;Kk/00`00Kk]_^`04Kk/01@00Lk]c^g>k00002W>k
00<007>kLk/027>k00<006oKKm/01foK00<005NOEil03UNO0P0015[J00<005JkE[/035Jk2@0045Km
00<005<NDah01e<N00<005<NDah01e<N00<005<nDch04E<n00@004loCcm??`H000]?G`03001?GdmO
019?G`03001?GdmO00D000i?G`04001oogoo000JOol005Yoo`03001oogoo09Ioo`8000050?D00000
0GT000081M`3000<8Uh00`00;Ud^G@0<;Ud4000<>Yd00`00?YdnW@0??Yd00`00@Ya2W00>@Y`00`00
AYa6W00@AY`00`00BY]:V`0@BY/00`00CY]>V`0@CY/00`00CY]>V`0ACY/00`00D[]B^`0AD[/00`00
D[]B^`0BD[/00`00E[]F^`0CE[/00`00E]]Ff`06E]/40009F[X00`00F]]Jf`0BF]/00`00F_]Jn`0D
F_/2000GHa/00`00HcaS?005Hc`2000@Ie`2000;Kk/00`00Kk]_^`0;Kk/00`00Kk]_^`06Kk/00`00
Lk/0000:Lk/00`00Lk]c^`08Lk/00`00Km]_f`08Km/2000<Eil30007F]X00`00E[]F^`0?E[/00`00
E_eFo@0BE_d00`00DaiC7P07Dah00`00DaiC7P07Dah00`00DciC?P0?Dch6000BCel00`00Cem?G`0?
Cel5000CCel01000Oomoo`006Woo001JOol00`00Oomoo`2HOol00`000?D0m@03000:1M`2000;8Uh0
0`00;Ud^G@0<;Ud00`00=UdfG@050008>Yd00`00?YdnW@0>?Yd00`00@Ya2W00?@Y`00`00AYa6W00?
AY`00`00BY]:V`0@BY/00`00CY]>V`0@CY/00`00CY]>V`0BCY/00`00D[]B^`0@D[/00`00D[]B^`0C
D[/00`00E[]F^`0BE[/00`00E]]Ff`03E]/3000=F[X00`00F]]Jf`0CF]/00`00F_]Jn`0AF_/20000
0ekj001S6`0FHa/00`00HcaS?004Hc`00`00IeaWG00?Ie`01000Jg][N`002Fnk00<006nkKk/02fnk
00<006nkKk/026nk00<007>kLk/027>k00<007>kLk/027>k00<006oKKm/026oK00@006oKKm/000QG
W`<000YJfP03001F^eJk011F^`03001FoEKm015Fo@03001C7U<N00MC7P03001C7U<N00QC7P03001C
?U<n00MC?PL000=C?P03001?GdmO019?G`03001?GdmO00Q?G`L000=?G`03001?GdmO01=?G`04001o
ogoo000IOol005Yoo`03001oogoo09Uoo`800080m@8000T5g003000F7@00008000TRGP03000^GBiM
00`^G@03000fGCIM00@fG@@000DjW@03000nWCjM00hnW@030012W4:L00i2W0030016W4JL0116W003
001:VdZK00m:V`03001>VdjK011>V`03001>VdjK019>V`03001B^e:k015B^`03001B^e:k019B^`03
001F^eJk019F^`03001FfeKK00<0011J^P03001Jfe[K01=Jf`03001Jne[k00iJn`<000ANnP03001S
6f<K01ES6`04001S?6<lHc`2000AIe`00`00Jg][N`02Jg/00`00Kk]_^`05Kk/00`00Kk]_^`0;Kk/0
0`00Kk]_^`09Kk/00`00Lk]c^`07Lk/00`00Lk]c^`08Lk/00`00Km]_f`08Km/00`00Km]_f`02Km/0
0`00EimGW`03Eil2000=F]X00`00E[]F^`0@E[/00`00E_eFo@0BE_d00`00DaiC7P06Dah00`00DaiC
7P08Dah01000DciC?U<n1P002e<n00<004mOCel04TmO00@004mOCem?G`H000]?G`03001?GdmO015?
G`<00003Ool007oo01Qoo`00FWoo00<007ooOol0VWoo0P000`3e0P0020GL00@001HM5QdF7@8000LR
GP03000^GBiM00`^G@03000fGCIM00PfG@H0010nW@030012W4:L00m2W0030016W4JL00m6W003001:
VdZK011:V`03001>VdjK011>V`03001>VdjK015>V`03001B^e:k015B^`03001B^e:k019B^`03001F
^eJk015F^`@001AJ^P03001Jfe[K019Jf`03001Jne[k00aJn`8000MNnP03001S6f<K01ES6`04001S
?000000BIe`00`00Jg][N`04Jg/00`00Kk]_^`03Kk/00`00Kk]_^`0;Kk/00`00Kk]_^`09Kk/00`00
Kk/00007Lk/00`00Lk]c^`08Lk/00`00Km]_f`08Km/00`00Km]_f`04Km/00`00Eil00002000@F]X0
0`00E[]F^`0@E[/00`00E_eFo@0AE_d00`00DaiC7P06Dah00`00DaiC7P07Dah5000ADch00`00Cem?
G`0ACel5000BCel00`00Cem?G`0;Cel50002Bel01000Oomoo`0067oo001JOol00`00Oomoo`2KOol3
00020?D300071M`00`005QdF7@025Qd300058Uh00`00;Ud^G@0<;Ud00`00=UdfG@0<=Ud4000>?Yd0
0`00@Ya2W00>@Y`00`00AYa6W00?AY`00`00BY]:V`0@BY/00`00CY]>V`0@CY/00`00CY]>V`0BCY/0
0`00D[]B^`0@D[/00`00D[]B^`0CD[/00`00E[]F^`0;E[/50002E[X00`00F[YJ^P0CF[X00`00F]]J
f`0CF]/00`00F_]Jn`09F_/20009G_X00`00Ha]S6`0EHa/2000BIe`20008Jg/01@00Kk]_^fnk0000
3Fnk00<006nkKk/02Fnk00D006nkKk]_^`0000Ec^`03001c^g>k00Qc^`03001_ffoK00Q_f`03001_
ffoK00I_f`03001JfU[J015JfP03001F^eJk011F^`03001FoEKm019Fo@03001C7U<N00IC7P04001C
7U<NDah50002Dch00`00DciC?P0BDch00`00Cem?G`0;Cel50002Cel00`00Cem?G`0BCel00`00Cem?
G`06Cel50008Bel00`00Ool0000HOol005Yoo`03001oogoo09aoo`07000d00000000m@000ET00P00
1PGL00<001HM5Qd011HM0`000b9N00<002iM;Ud032iM00<003IM=Ud033IM00<003Yl>W`01@002CjM
00<004:L@Y`03T:L00<004JLAY`044JL00<004ZKBY/044ZK00<004jKCY/044jK00<004jKCY/04DjK
00<005:kD[/04E:k00<005:kD[/04U:k00<005JkE[/01UJk1@001eJj00<005ZjF[X04eZj00<005[K
F]/04e[K00<005[kF_/01e[k0P0035kj00<006<KHa/04V<K0P0000=W>`00Ie`046ML00<006]kJg/0
2F]k00<006nk00003Fnk00<006nkKk/02Fnk00<006nkKk/00fnk00D007>kLk]c^`0000Yc^`03001_
ffoK00Q_f`03001_ffoK00M_f`03001JfU[J015JfP03001F^eJk015F^`03001FoEKm015Fo@03001C
7U<N00EC7PD000QC?P03001C?U<n019C?P03001?GdmO00E?G`D000Q?G`03001?GdmO019?G`03001?
GdmO00D000e;G`04001oogoo000GOol0021oo`@000ioo`<000eoo`H0019oo`03001oogoo09eoo`06
000d03@00000m@000P5I0P0010GL00<001HM5Qd01aHM0P0000<RGP00;Ud03BiM00<003IM=Ud03CIM
00<003Yl>W`013Yl1@001CjM00<004:L@Y`03T:L00<004JLAY`03dJL00<004ZKBY/044ZK00<004jK
CY/044jK00<004jKCY/04DjK00<005:kD[/04E:k00<005:kD[/04U:k00@005JkE[]F^`D000eF^P03
001J^UZj01=J^P03001Jfe[K01=Jf`03001Jne[k00AJn`8000iNnP03001S6f<K011S6`8000AW>`03
001WG6ML00eWG003001[Nf]k00][N`03001_^fnk00]_^`03001_^fnk00U_^`03001_^fnk00E_^`03
001c^`0000Yc^`03001_ffoK00Q_f`03001_ffoK00M_f`8001AJfP03001F^eJk011F^`03001FoEKm
015Fo@03001C7U<N00D00003Dch005<n00YC?P03001C?U<n019C?P03001?GdmO00D000e?G`03001?
GdmO015?G`@001=;G`03001oo`0001Moo`007Woo20002goo1@002Woo2P0047oo00<007ooOol0WWoo
0P0000@d0000000000<1F@8000<5g003000F7AHM00PF7@<000h^G@03000fGCIM00`fG@03000jO3Yl
00TjO0H00112W0030016W4JL00m6W003001:VdZK011:V`03001>VdjK011>V`03001>VdjK019>V`03
001B^e:k011B^`03001B^e:k015B^`D0019F^P03001J^UZj01=J^P03001Jfe[K01=Jf`04001Jne[k
F_/3000AG_X00`00Ha]S6`0>Ha/00`00Ic]W>`04Ic/00`00IeaWG00;Ie`2000=Jg/2000<Kk/00`00
Kk]_^`09Kk/00`00Kk]_^`07Kk/00`00Lk]c^`08Lk/00`00Km]_f`08Km/00`00Km]_f`07Km/01000
HeaSG0004e[J00<005JkE[/045Jk00<005KmE_d03eKm1@001U<n00<005<nDch02U<n00<005<nDch0
45<n10004dmO00<004mOCel02dmO1@000T]O00<004]OBel04T]O00@007ooOol001Ioo`007Woo0P00
17oo0P002goo1@002Woo0`001Goo0`003goo00<007ooOol0X7oo00<003@0=0000P00105I00D000GL
1M`5g00000`F7@<000/^G@03000fGCIM00dfG@03000jO3Yl00djO0D000e2W0030016W4JL00m6W003
001:VdZK011:V`03001>VdjK011>V`03001>VdjK015>V`03001B^e:k015B^`03001B^e:k00]B^`D0
009FVP03001F^UJj019F^P03001J^UZj01=J^P03001Jfe[K01=Jf`04001Jn`00000DG_X00`00Ha]S
6`0<Ha/20008Ic/00`00IeaWG009Ie`00`00Jg][N`0<Jg/01000Ki]_V`002Vnk00<006nkKk/02Fnk
00<006nkKk/026nk00<007>kLk/01g>k00<006oKKm/026oK00<006oKKm/01foK00D006=LHeaSG000
01=JfP03001F^eJk015F^`03001FoEKm00MFo@L000=G?@03001C?U<n00EC?P03001C?U<n00YC?P03
001C?U<n00]C?PD0009?G`03001?GdmO01=?G`03001?GdmO00E?G`D000Q;G`03001;Gd]O015;G`05
001oogooOol0000EOol001eoo`8000Ioo`8000Yoo`D001=oo`8000moo`03001oogoo0:5oo`800003
=000000000@1F@8000031M`001HM00/F7@03000R7B8M00<000T^G@03000fGCIM00`fG@03000jO3Yl
00hjO0040012Fd9K@U/60007@Y`00`00AYa6W00?AY`00`00BY]:V`0@BY/00`00CY]>V`0@CY/00`00
CY]>V`0ACY/00`00D[]B^`0AD[/00`00D[]B^`06D[/50007EYX00`00E[YF^P0CE[X00`00F[YJ^P0B
F[X00`00F]]Jf`0CF]/2000FG_X00`00Ha]S6`0:Ha/2000:Ic/00`00IeaWG008Ie`00`00Jg][N`0<
Jg/00`00Ki]_V`02Ki/00`00Kk]_^`06Kk/00`00Kk]_^`09Kk/00`00Kk]_^`08Kk/00`00Km/00007
Lk/00`00Km]_f`08Km/00`00Km]_f`07Km/00`00HeaSG002He`00`00F]YJfP0AF]X00`00E[]F^`0A
E[/01000E_eFoEKm1P002eLm00<005<nDch015<n00<005<nDch02e<n00<005<nDch01E<n1@0024mO
00<004mOCel04TmO00<004mOCel01@003D]O00<004]OBel03d]O10000Woo00<007ooOol04goo000M
Ool20006Ool2000;Ool3000EOol2000=Ool7002POol01000=00d00001@5I0`0031HM00<0028M8Qd0
0R8M0`001RiM00<003IM=Ud03CIM00<003Yl>W`03SYl00<0049K@U/01T9K1P0000=2W000AY`04DJL
00<004ZKBY/03dZK00<004jKCY/044jK00<004jKCY/04TjK00<005:kD[/045:k00@005:kD[]B^`D0
00eFVP03001F^UJj019F^P03001J^UZj01=J^P03001Jfe[K00mJf`<00003G]X005kj01INnP03001S
6f<K00MS6`8000eW>`03001WG6ML00IWG003001[Nf]k00a[N`03001_VfnK00A_V`03001_^fnk00A_
^`03001_^fnk00U_^`03001_^fnk00Q_^`05001_ffoKKm/00005Lk/00`00Km]_f`08Km/00`00Km]_
f`07Km/00`00HeaSG003He`00`00F]YJfP0BF]X00`00E[]F^`0?E[/5000AEcd00`00DciC?P04Dch0
0`00DciC?P0;Dch00`00DciC?P05000=Cel00`00Cem?G`0ACel4000CBel00`00Bem;G`07Bel70003
Bel01@00Oomoogoo000057oo000LOol20008Ool2000ROol2000=Ool00`00Oomoo`2UOol00`00=00d
000200050ET2000<5Qd00`008QdR7@048Qd30004;Ud00`00=UdfG@0<=Ud00`00>W`jO00>>W`00`00
@U]2F`0<@U/8000<AY`00`00BY]:V`0@BY/00`00CY]>V`0@CY/00`00CY]>V`0ACY/00`00D[]B^`0<
D[/8000BEYX00`00E[YF^P0BE[X00`00F[YJ^P0CF[X00`00F]]Jf`0=F]/20005G]X00`00G_YNnP0D
G_X00`00Ha]S6`05Ha/2000@Ic/00`00IeaWG003Ie`2000>Jg/00`00Ki]_V`05Ki/00`00Kk]_^`03
Kk/00`00Kk]_^`09Kk/00`00Kk]_^`08Kk/00`00Km]_f`03Km/01@00Lk]c^g>k00002VoK00<006oK
Km/01foK00<006=LHe`016=L00<005[JF]X04U[J00<005JkE[/02UJk1@000U/M00<005LmEcd04ULm
00<005<nDch00e<n00<005<nDch02U<n10004dmO00<004mOCel02dmO1@000T]o00<004]OBel04T]O
00@004]OBem;G`H000];G`04001oogoo000DOol001aoo`8000Qoo`80029oo`8000eoo`03001oogoo
0:Ioo`800003=000000000H1F@8000XF7@03000R7B8M00LR7@<0008^G@03000fGCIM00`fG@03000j
O3Yl00djO0030012Fd9K00i2F`030016NdIk00=6N`T000=6W003001:VdZK011:V`03001>VdjK011>
V`03001>VdjK015>V`03001B^e:k00=B^`T000EBVP03001FVUJJ019FVP03001F^UJj019F^P03001J
^UZj01=J^P03001Jfe[K00YJf`<000MNfP03001NnUkj01ENnP03001S6f<K00=S6`03001W>fLk011W
>`03001WG6ML009WG003001[Nf]k00e[N`03001_VfnK00M_V`05001_^fnkKk/0000;Kk/00`00Kk]_
^`08Kk/00`00Km]_f`05Km/00`00Lk/0000:Km/00`00Km]_f`07Km/00`00HeaSG006He`00`00F]YJ
fP0AF]X00`00E[]F^`05E[/50008Fad00`00EceG?@0AEcd00`00DciC?P03Dch00`00DciC?P05Dch5
0002Del00`00Cem?G`0CCel00`00Cem?G`05Cel50008Bgl00`00Bem;G`0?Bel6000ABel01@00Oomo
ogoo00004goo000LOol20008Ool2000ROol2000=Ool00`00Oomoo`2XOol00`00=000000200040ET0
10001K/000002AHM00<0028M8Qd02B8M0`003SIM00<003Yl>W`03SYl00<0049K@U/03T9K00<004Ik
AW/02dIk3`001dZK00<004jKCY/044jK00<004jKCY/024jK3`003U:J00<005JJEYX04eJJ00<005Jj
E[X04UJj00<005ZjF[X04eZj00<005[KF]/01e[K0P002UkJ00<005kjG_X05Ekj00@006<KHa]S6`80
01AW>`04001WG6ML000?Jg/00`00Ki]_V`09Ki/00`00Kk/0000;Kk/00`00Kk]_^`08Kk/00`00Km]_
f`07Km/00`00Km]_f`08Km/00`00Km]_f`07Km/00`00HeaSG007He`00`00F]YJfP0BF]X00`00E[/0
0004000=Fad00`00EceG?@0BEcd00`00DciC?P02Dch00`00DciC?P050008Del00`00Cem?G`0BCel0
0`00Cem?G`05000>Bgl00`00Bem;G`07Bel70003Ael00`00Bem;G`0BBel01000Oomoo`004goo000L
Ool20008Ool2000ROol2000=Ool00`00Oomoo`2YOol300000`3F0001F@030ET00`001K/5^`030007
5Qd00`008QdR7@0;8Qd3000<=Ud00`00>W`jO00=>W`00`00@U]2F`0>@U/00`00AW]6N`0?AW/00`00
BWY:NP08BWXU000:DWX00`00DYYBVP0ADYX00`00EYYFVP0BEYX00`00E[YF^P0BE[X00`00F[YJ^P0C
F[X00`00F]]Jf`04F]/3000=G]X00`00G_YNnP0DG_X01000Ha/000005VLk00<006ML00003f]k00<0
06nKKi/02fnK00<006nkKk/02Fnk00<006nkKk/026nk00<006oKKm/026oK00<006oKKm/01foK00<0
06oKKm/01foK00<006=LHe`026=L00<005[JF]X04E[J0`004U/M00<005LmEcd04ULm00<005<nDch0
1@003E=O00<004mOCel04DmO10004d]o00@004]OBem;G`H000]7G`03001;Gd]O015;G`05001oogoo
Ool0000BOol001aoo`8000Qoo`80025oo`8000ioo`03001oogoo0:]oo`8000030=H0000000<1F@03
0005^`Fk0085^`8000DF7@03000R7B8M00/R7@03000^?2hl00<000TfG@03000jO3Yl00hjO0030012
Fd9K00e2F`030016NdIk0116N`03001:NTYj00m:NP03001>NTij011>NP03001BNU9j015BNP03001B
VU:J015BVP03001FVUJJ019FVP03001F^UJj019F^P03001J^UZj01=J^P03001Jfe[K009Jf`80011N
fP03001NnUkj01ANnP8001QW>`8000m[N`03001_VfnK00]_V`8000Y_^`03001_^fnk00Q_^`03001_
ffoK00Q_f`03001_f`0000M_f`03001_ffoK00M_f`03001SG6=L00USG003001JfU[J00iJfP<00003
Fcd005/M01=K7@03001G?ELm011G?@@0009CG`03001CGe=O00iCG`03001?GdmO00]?G`D0009;O`03
001;Od]o015;O`D00157G`03001;Gd]O00m;G`@0009oo`03001oogoo011oo`0077oo0P0027oo0P00
6Goo0P001Goo0`003Woo00<007ooOol0[7oo0P000P3F0P000P5I00<000Fk1K/00`Fk0P0011HM00<0
028M8Qd02b8M00<002hl;S`00Rhl0`001cIM00<003Yl>W`03CYl00<0049K@U/03T9K00<004IkAW/0
3dIk00<004YjBWX044Yj00<004ijCWX03dij00<0059jDWX04U9j00<005:JDYX045:J00<005JJEYX0
4eJJ00<005JjE[X04UJj00<005ZjF[X04eZj10004UkJ00<005kjG_X04Ukj0P0000=RnP00Ic/05VLk
00<006]K00003V]k00<006nKKi/02fnK00@006nKKi/000Q_^`03001_^fnk00Q_^`03001_ffoK00Q_
f`05001_ffoKKm/00005Km/00`00Km]_f`07Km/00`00HeaSG00;He`00`00F]YJfP0;F]X20005Fcd0
0`00FaeK7@0AFad00`00EceG?@0<Ecd40002Dgl01@00DemCGe=O00004E=O00<004mOCel01DmO1@00
24]o00<004]oBgl02d]o1@000TMo00<004MOAel04TMO00<004]OBel01d]O1`000dMO00D007ooOomo
o`00015oo`0077oo0P0027oo0P006Goo2@003goo00<007ooOol0[Goo0P000`3F00@0005I0ET000H5
^`8000<F7@03000R7B8M00XR7@03000^?2hl00D^?0<000@fG@03000jO3Yl00djO0030012Fd9K00i2
F`030016NdIk00m6N`03001:NTYj011:NP03001>NTij011>NP03001BNU9j015BNP03001BVU:J015B
VP03001FVUJJ019FVP03001F^UJj019F^P03001J^UZj019J^P8001INfP03001NnUkj011NnP03001R
nV;j009RnP03001W>fLk01=W>`05001[Ff]KJe/0000<Jg/00`00Ki]_V`0;Ki/00`00Ki]_V`02Ki/0
0`00Kk]_^`04Kk/00`00Kk]_^`08Kk/00`00Km]_f`08Km/00`00Km]_f`03Km/01@00Km]_ffoK0000
2FoK00<006=LHe`036=L00<005[JF]X02E[J0P001e/m00<005/MFad04U/M00<005LmEcd01eLm1000
1e=o00@005=ODel0015CG`03001?GdmO00D000i;O`03001;Od]o00E;O`D000Q7O`030017GdMO0157
G`04001;Gd]OBel6000;Ael01000Oomoo`004Goo000LOol20008Ool2000IOol200000goo00000003
000@Ool00`00Oomoo`2_Ool010000=H0eP3F0`0020Fk10003B8M00<002hl;S`01bhl0`000SIM00<0
03Yl>W`03CYl00<0049K@U/03T9K00<004IkAW/03dIk00<004YjBWX03dYj00<004ijCWX044ij00<0
059jDWX04E9j00<005:JDYX04E:J00<005JJEYX04UJJ00<005JjE[X04UJj00<005ZjF[X03eZj0`00
00=N^@00G]X05EkJ00<005kjG_X03Ukj0P001F;j00<006LkIc/04FLk0P001F]K00<006]kJg/026]k
00<006nKKi/02fnK00<006nKKi/016nK00<006nkKk/00Vnk00<006nkKk/026nk00<006oKKm/026oK
00<006oKKm/01FoK00<006oK00002FoK00<006=LHe`03F=L00<005[JF]X01U[J0`002E/m00<005/M
Fad04U/M00<005LmEcd015Lm0`002e=o00@005=ODel0011CG`@001=;O`03001;Od]o00D000e7O`03
0017GdMO00m7G`H00197G`04001oogoo000@Ool001eoo`8000Ioo`8001Yoo`8001Ioo`03001oogoo
0;1oo`8000<0eP8000X5^`8000`R7@03000^?2hl00X^?0<000ljO0030012Fd9K00i2F`030016NdIk
00m6N`03001:NTYj011:NP03001>NTij00m>NP03001BNU9j015BNP03001BVU:J015BVP03001FVUJJ
01=FVP03001F^UJj015F^P03001J^UZj00aJ^P<000EN^@03001NfUkJ01=NfP03001NnUkj00aNnP80
00MRnP03001W>fLk011W>`03001[Ff]K00E[F`03001[Nf]k00M[N`03001_VfnK00]_V`03001_VfnK
00E_V`05001_^fnkKk/0000;Kk/00`00Km]_f`07Km/00`00Km]_f`07Km/00`00Km]_f`07Km/00`00
HeaSG00>He`00`00F]YJfP04F]X2000=Fcd00`00FaeK7@0AFad00`00EceG?@04000?Dgl00`00Del0
000;Del50002Bgl00`00Bgm;O`0ABgl4000CAgl00`00Aem7G`07Ael70003Ael00`00Aem7G`0BAel0
1000Oomoo`0047oo000MOol20006Ool2000JOol2000FOol00`00Oomoo`2aOol200030=H2000;1K/2
000;8Qd00`00;S`^?00<;S`3000<>W`00`00@U]2F`0>@U/00`00AW]6N`0?AW/00`00BWY:NP0@BWX0
0`00CWY>NP0@CWX00`00DWYBNP0ADWX00`00DYYBVP0@DYX00`00EYYFVP0CEYX00`00E[YF^P0BE[X0
0`00F[YJ^P08F[X30008G[T00`00G]YNfP0DG]X00`00G_YNnP0:G_X00`00H_YRnP08H_X00`00Ic]W
>`0>Ic/00`00Je][F`07Je/00`00Jg][N`05Jg/00`00Ki]_V`0;Ki/00`00Ki]_V`07Ki/00`00Kk/0
000;Kk/00`00Km]_f`07Km/00`00Km]_f`08Km/20007Km/00`00HeaSG00?He`00`00F]YJfP02F]X2
000?Fcd00`00FaeK7@0AFad3000DDgl20006Del50008Bgl00`00Bgm;O`0;Bgl50002@gl00`00Agm7
O`0BAgl01000Aem7GdMO1P002dMO00<004MOAel03dMO1`003goo000NOol20004Ool2000KOol2000F
Ool00`00Oomoo`2bOol200040=H00`001K/5^`081K/010005M`000002B8M00<002hl;S`032hl00<0
03Hk=S/00`002SYl00<0049K@U/03T9K00<004IkAW/03dIk00<004YjBWX03dYj00<004ijCWX044ij
00<0059jDWX04E9j00<005:JDYX04E:J00<005JJEYX04UJJ00<005JjE[X04UJj00<005ZjF[X01EZj
0`002eji00<005kJG]X055kJ00<005kjG_X025kj0P002f;j00<006LkIc/036Lk0P002V]K00<006]k
Jg/016]k00<006nKKi/02fnK00<006nKKi/02FnK00<006nkKk/02Fnk00<006oKKm/01foK00<006oK
Km/026oK00@006oKKm/000E_f`03001SG6=L015SG0@0019K?@03001K7E/M00eK7@<00003Dgl005=o
01ACO`800003Del0000000<000i;O`03001;Od]o00I;O`@000Q3O`030017OdMo00m7O`H00197G`03
0017GdMO00M7G`L000=7G`04001oogoo000?Ool001ioo`P001]oo`X000eoo`D00;9oo`<000<0eP80
00T5^`03000Eg1GL008000PR7@03000^?2hl00`^?003000f>cHk008f>`<000LjO0030012Fd9K00i2
F`030016NdIk00m6N`03001:NTYj011:NP03001>NTij00m>NP03001BNU9j015BNP03001BVU:J015B
VP03001FVUJJ019FVP03001F^UJj019F^P03001J^UZj009J^P<000mN^@03001NfUkJ01=NfP03001N
nUkj00INnP8000iRnP03001W>fLk00YW>`03001[Ff]K00][F`03001[Nf]k009[N`03001_VfnK00]_
V`03001_VfnK00Y_V`03001_^fnk00Q_^`03001_ffoK00M_f`03001_ffoK00Q_f`03001_ffoK009_
f`05001_ffoKKm/0000CHe`2000EFcd00`00FaeK7@0:Fad30005Dgl00`00DgmCO`0ADgl4000DBgl0
0`00Bgm;O`05000=@gl00`00Agm7O`08Agl60004@el00`00Aem7G`0AAel01000Aem7GdMO1P002dMO
00<007oo00003goo000POol4000MOol:000>Ool00`00Oomoo`2eOol200020=H00`000CP000091K/0
10005M`Eg1GL0P001b8M00<002hl;S`02bhl00<003Hk=S/01CHk0`001CYl00<0049K@U/03T9K00<0
04IkAW/03TIk00<004YjBWX044Yj00<004ijCWX044ij00<0059jDWX04E9j00<005:JDYX045:J00<0
05JJEYX04eJJ00<005JjE[X04UJj10004Uji00<005kJG]X055kJ00<005kjG_X015kj00<006;jH_X0
3V;j00<006LkIc/02FLk00<006]KJe/03F]K00@006]kJg/000e_V`03001_VfnK00Y_V`03001_^`00
00Q_^`03001_ffoK00M_f`03001_ffoK00Q_f`03001_ffoK00A_f`03001_f`0001=SG003001OOP00
01IK?@03001K7E/M00IK7@<000UCO`03001COe=o00]CO`D00097O`80019;O`D001=3O`040017OdMo
Agl6000;@el00`00Aem7G`0=Ael7000AAel00`00Ool0000?Ool005Uoo`03001oogoo0;Ioo`800080
eP040001>00000071K/00`005M`Eg0035M`200058Qd00`00;S`^?00<;S`00`00=S/f>`07=S/30002
>W`00`00@U]2F`0>@U/00`00AW]6N`0?AW/00`00BWY:NP0?BWX00`00CWY>NP0@CWX00`00DWYBNP0A
DWX00`00DYYBVP0ADYX00`00EYYFVP0BEYX00`00E[YF^P0@E[X3000EG[T00`00G]YNfP0DG]X00`00
G_YNnP02G_X2000AH_X00`00Ic]W>`07Ic/2000@Je/00`00Jg/0000=Ki/00`00Ki]_V`0:Ki/01@00
Kk]_^fnk00001Vnk00<006oKKm/026oK00<006oKKm/01foK00<006oKKm/01VoK00<006=LHe`046=L
0P000emn00<005/mFcd04e/m00<005/MFad00e/M0`0035=o00<005=oDgl01U=o1@001dMo00<004Mo
00002T]o1`000d=o00<004=o@gl044=o1P004T=O00<004MOAel00dMO2@0014=O00<004MOAel04TMO
0P003goo001IOol00`00Oomoo`2gOol30000103F0001>04h0P001PFk00<001GL5M`011GL0P00128M
00<002hl;S`02bhl00<003Hk=S/02SHk0`00449K00<004IkAW/03dIk00<004YjBWX044Yj00<004ij
CWX03dij00<0059jDWX04E9j00<005:JDYX04E:J00<005JJEYX04UJJ00<005JjE[X03EJj0`000UZI
00<005jiG[T055ji00<005kJG]X04ekJ00<005kjG_X00P0056;j00<006LkIc/01FLk00<006]KJe/0
46]K0P003FnK00<006nKKi/02VnK00<006nkKk/00fnk00<006nkKk/00Vnk00<006oKKm/026oK00<0
06oKKm/01foK00<006oKKm/01VoK0P004F=L00<005mnGgh00emn00<005/mFcd04e/m00<005/MFad0
0`0045=o00<005=oDgl01@0034Mo00@004MoAgl000=;O`H000]3O`030013Od=o00Q3O`L000<oG`03
0013Gd=O0113G`P000i3G`030017GdMO0157G`8000moo`00F7oo00<007ooOol0^Goo0`0000<0eP00
0CP00P4h00<000Fk1K/00`Fk00<001GL5M`01QGL0P000R8M00<002hl;S`02bhl00<003Hk=S/03CHk
0`003T9K00<004IkAW/03dIk00<004YjBWX03dYj00<004ijCWX044ij00<0059jDWX0459j00<005:J
DYX04E:J00<005JJEYX04eJJ00<005JjE[X02EJj0`001EZI00<005jiG[T055ji00<005kJG]X055kJ
0P005V;j00<006LkIc/016Lk00<006]KJe/046]K00<006mk000036nK00<006nKKi/02VnK00<006nk
Kk/016nk00D006nkKk]_^`0000Y_f`03001_ffoK00M_f`03001_ffoK00I_f`04001WgFOM000>He`2
0007Ggh00`00FceK?@0BFcd3000CDgl3000AAgl00`00Agl00004000B@gl01000@gm3Od=o1P002cmO
00<004=O@el024=O1`000cmO00<004=O@el04D=O00<004MOAel034MO1P003goo001HOol00`00Oomo
o`2kOol200000`3F0001>0020CP200041K/00`005M`Eg0075M`200000b8M000^?00<;S`00`00=S/f
>`0<=S/00`00>S/j>`04000:@U/00`00AW]6N`0?AW/00`00BWY:NP0?BWX00`00CWY>NP0@CWX00`00
DWYBNP0ADWX00`00DYYBVP0ADYX00`00EYYFVP0BEYX00`00E[YF^P06E[X30009FYT00`00G[UN^@0C
G[T00`00G]YNfP0CG]X2000HH_X01000Ic]W>fLk0P004V]K00D006mkKg]_N`0000Y_V`03001_VfnK
00Y_V`03001_^fnk00I_^`03001_^`0000Y_f`03001_ffoK00M_f`03001_ffoK00I_f`05001WgFOM
Imd0000=He`00`00GgiOOP07Ggh00`00FceK?@0?Fcd300000e>O001CO`0@Dgl30003Ail00`00Agm7
O`0;Agl50003?gl00`00@gm3O`0?@gl6000B?el01000@em3Gd=O1P002cmO00<004=O@el044=O00<0
04MOAel00dMO2@001Goo00<007ooOol03Goo001HOol00`00Oomoo`2lOol300050CP200031K/00`00
5M`Eg0085M`2000=;S`00`00=S/f>`0==S/00`00>S/j>`03>S/40007@U/00`00AW]6N`0>AW/00`00
BWY:NP0@BWX00`00CWY>NP0?CWX00`00DWYBNP0ADWX00`00DYYBVP0ADYX00`00EYYFVP0BEYX00`00
E[YF^P03E[X3000<FYT00`00G[UN^@0DG[T00`00G]YNfP0@G]X200000f;I001RnP0GH_X01000Ic]W
>`004f]K00<006mkKg/00Vmk00<006nKKi/01fnK00<006nKKi/02VnK00<006nkKk/026nk0P002FoK
00<006oKKm/01foK00<006oKKm/01VoK00<006OMImd00fOM00<006=LHe`026=L0P002emn00<005/m
Fcd02e/m0`001E>O00<005=oDgl02e=o0`001dNO00<004MoAgl01TMo10000cmo00<003mo?gl00cmo
00<004=o@gl024=o1P001C]O00<003mO?el03CmO1`004SmO00<004=O@el034=O2@003Woo00<007oo
Ool03Goo001HOol00`00Oomoo`2mOol300060CP010001K/5^`0031GL0P0032hl00<003Hk=S/033Hk
00<003Xk>S/01cXk0`00149K00<004IkAW/03dIk00<004YjBWX03dYj00<004ijCWX044ij00<0059j
DWX0459j00<005:JDYX04E:J00<005JJEYX04eJJ00<005Jj00000P003eZI00<005jiG[T055ji00<0
05kJG]X03ekJ00<006;IH]T00V;I00<006;jH_X05F;j00<006Lk00004f]K00<006mkKg/016mk00<0
06nKKi/01FnK00<006nKKi/02VnK00<006nkKk/02Fnk00<006oK00001foK00<006oKKm/01foK00<0
06oKKm/01VoK00<006OMImd016OM00<006=LHe`01f=L00<005mnGgh02emn00<005/mFcd025/m0`00
2E>O00<005=oDgl01e=o0`002dNO00<004MoAgl01@001cmo00<003mo?gl013mo00@004=o@gm3O`H0
00`kG`03000oGcmO00<oG`T000DkG`03000oGcmO014oG`030013Gd=O00=3G`T001Moo`03001oogoo
00eoo`00F7oo00<007ooOol0_Woo00<0001b00001P4h0P0000<5^`005M`02QGL00@0027K000000X^
?003000f>cHk00`f>`03000j>cXk00Xj>`D00156N`03001:NTYj00m:NP03001>NTij011>NP03001B
NU9j011BNP03001BVU:J015BVP03001FVUJJ015FVP@001=JV@03001N^Eji01=N^@03001NfUkJ00eN
fP8000ERf@03001RnV;j01ERnP8001=[F`03001_Nfmk00I_N`03001_VfnK00=_V`03001_VfnK00Y_
V`03001_^fnk00U_^`05001_ffoKKm/00005Km/00`00Km]_f`07Km/00`00Km]_f`06Km/00`00ImeW
g@06Imd00`00HeaSG004He`2000>Ggh00`00FceK?@06Fcd2000<Dil00`00DgmCO`04Dgl3000=Ail4
000<?gl00`00?gloO`02?gl6000@>el8000?>el00`00?eloG`0=?el9000POol00`00Oomoo`0=Ool0
05Qoo`03001oogoo0;moo`<000L1>08000`Eg003000Qfb7K008000T^?003000f>cHk00`f>`03000j
>cXk00dj>`@000i6N`03001:NTYj011:NP03001>NTij00m>NP03001BNU9j015BNP03001BVU:J015B
VP03001FVUJJ00aFVP@0009JN003001JVEZI019JV@03001N^Eji01AN^@03001NfUkJ00YNfP8000MR
f@03001RnV;j01ARnP03001W6P00019[F`03001_Nfmk00M_N`03001_VfnK009_V`03001_VfnK00Y_
V`03001_^fnk00U_^`03001_ffoK00=_f`05001_ffoKKm/00009Km/00`00Km]_f`06Km/00`00ImeW
g@07Imd00`00HeaSG003He`00`00GgiOOP0?Ggh00`00FceK?@02Fcd3000?Dil00`00DgmCO`03000<
Ail40003=gh00`00?gloO`08?gl70004<eh00`00>elkG`08>el70003<el00`00>elkG`0B>el00`00
?eloG`03?el9000ZOol00`00Oomoo`0<Ool005Qoo`03001oogoo0<1oo`@000L1>003000Eg1GL00TE
g003000Qfb7K008Qf`8000L^?003000f>cHk00`f>`03000j>cXk00hj>`030012>T8j00D000Y6N`03
001:NTYj00m:NP03001>NTij011>NP03001BNU9j011BNP03001BVU:J015BVP03001FVUJJ00QFVP@0
00IJN003001JVEZI019JV@03001N^Eji01AN^@03001NfUkJ00QNfP8000YRf@03001RnV;j019RnP05
001W6VLJIaX0000@Je/00`00Kg]_N`09Kg/01000Ki]_V`0036nK00<006nkKk/02Fnk00<006oKKm/0
1FoK00<006oK00002FoK00<006oKKm/01VoK00<006OMImd02FOM00<006=LHe`00P004Umn00<005/m
00000P004E>O10002dNO100023Mn00@003mo?gloO`H000<cGP03000cGS=N00HcGP04000kGc]O>el6
000;<el00`00>elkG`0=>el:000cOol00`00Oomoo`0<Ool005Qoo`03001oogoo0<5oo`@000L1>080
00XEg003000Qfb7K00<Qf`8000H^?003000f>cHk00/f>`03000j>cXk00hj>`030012>T8j00E2>PD0
00E6N`03001:NTYj00m:NP03001>NTij011>NP03001BNU9j011BNP03001BVU:J015BVP03001FVUJJ
00AFVP@000]JN003001JVEZI015JV@03001N^Eji01AN^@03001NfUkJ00MNfP03001RfF;I00YRf@03
001RnV;j015RnP03001W6VLJ009W6P03001[Ff]K00e[F`03001_Nfmk00Y_N`03001_V`0000e_V`03
001_^fnk00Q_^`03001_ffoK00M_f`03001_ffoK00M_f`03001_ffoK00I_f`03001WgFOM00YWg@03
001SG00001AOOP<0011CW`<000@oWP030017WdNO00E7W`<000/gOPD000TcGP03000cGS=N00<cGPL0
018cG`03000kGc]O00<kG`T003eoo`03001oogoo00aoo`00F7oo1000`Woo0`001P4h00<0005j0000
2AGL00<0027K8M/01B7K0P0012hl00<003Hk=S/033Hk00<003Xk>S/03SXk00<0048j@SX02D8j1P00
4TYj00<004ijCWX03dij00<0059jDWX04E9j00<005:JDYX04E:J00<005JJ00000`003eYh00<005ZI
FYT04UZI00<005jiG[T055ji00<005kJG]X015kJ0P003V;I00<006;jH_X03V;j0P001VLJ00<006]K
Je/02V]K0P003Vmk00<006nKKi/02fnK00<006nkKk/026nk00<006oKKm/026oK0P001foK00<006oK
Km/01VoK00<006OMImd02fOM0P004emn0P000d^o00<005>ODil02E>O100023nN00<004NOAil01000
2CMn1@0012/l0P001C=N2@001R/m00<003=O<el03C=O2@00AWoo00<007ooOol037oo001HOol00`00
Oomoo`34Ool400050CP010000GX0000021GL00<0027K8M/01R7K0P000Rhl00<003Hk=S/033Hk00<0
03Xk>S/03SXk00<0048j@SX03T8j1@003TYj00<004ijCWX044ij00<0059jDWX0459j00<005:JDYX0
3e:J10004eYh00<005ZIFYT04UZI00<005jiG[T055ji00<005kJG]X00UkJ0P0046;I00<006;jH_X0
3F;j00<006LJIaX01VLJ00<006]KJe/02F]K00<006mkKg/03Vmk00<006nKKi/02VnK00<006nkKk/0
26nk00<006oKKm/026oK00@006okKo/000E_f`03001_ffoK00I_f`03001WgFOM00]Wg@03001KgP00
011OOP<000I;_`03001CWe>O00ACW`@000/oWP@000TgOP@000P[?0P000<[?@03000[?B/m00X[?@03
000cGc=O00<cG`T004moo`03001oogoo00aoo`00F7oo00<007ooOol0aGoo0P0000<0]@000CP0104h
00@0005j0GX000LEg003000Qfb7K00PQf`800003;S`003Hk00df>`03000j>cXk00dj>`030012>T8j
00m2>P040016>DHiAST70007BWX00`00CWY>NP0@CWX00`00DWYBNP0@DWX00`00DYYBVP0:DYX50002
EWP00`00FWQJN00BFWP00`00FYUJV@0BFYT00`00G[UN^@0DG[T01@00G]YNfUkJ00004V;I00<006;j
H_X036;j00<006LJIaX026LJ00<006]KJe/01f]K00<006mkKg/03Vmk00<006nK00002VnK00<006nk
Kk/026nk00<006oKKm/026oK00<006okKo/00Vok00D006oKKm]_f`0000Q_f`03001WgFOM00YWg@80
00=KgP03001OOUmn00]OOP8000Y;_`03001CWe>O00<000XoWPD000@[G080008gOPD000H[?0H000DS
6`8000@[?@03000[?B/m008[?@h005Qoo`03001oogoo00aoo`00F7oo00<007ooOol0aWoo0P0000<0
]@0000000`4h00@0005j0GX1NP8000HEg003000Qfb7K00TQf`8000hf>`03000j>cXk00hj>`030012
>T8j00i2>P030016>DHi00Q6>@H0009:NP03001>NTij00m>NP03001BNU9j011BNP03001BVU:J00EB
VPD000MFN003001JN5Yh01=JN003001JVEZI019JV@03001N^Eji01AN^@<001ARf@03001RnV;j00UR
nP8000]W6P03001[Ff]K00I[F`03001_Nfmk00i_N`05001_VfnKKi/00008Ki/00`00Kk]_^`08Kk/0
0`00Km]_f`08Km/00`00Ko]_n`04Ko/00`00Km/00008Km/00`00ImeWg@0:Imd00`00FmiKgP04Fmh0
0`00GgiOOP08Ggh2000;Bkl40009?ih40008:e`60004:c`600098a/=001VOol00`00Oomoo`0<Ool0
05Qoo`03001oogoo0<Moo`800080]@050001>04h0CP000040GX00`005M`Eg0035M`00`008M/Qf`0;
8M/2000<=S/00`00>S/j>`0>>S/00`00@SY2>P0?@SX00`00ASU6>@0=AST=0008CWX00`00DWYBNP0@
DWX00`00DYX00004000=EWP00`00FWQJN00BFWP00`00FYUJV@0BFYT00`00G[UN^@0CG[T2000FH]T0
0`00H_YRnP08H_X00`00IaYW6P0;IaX00`00Je][F`05Je/00`00Kg]_N`0>Kg/00`00Ki]_V`03Ki/0
0`00Ki]_V`04Ki/00`00Kk]_^`08Kk/00`00Km]_f`08Km/00`00Ko]_n`05Ko/30007Km/00`00ImeW
g@09Imd20008Fmh00`00GgiOOP05Ggh2000:Bkl30004<g`20002?ih50006:e`600047_X600068a/9
0008Ool00`00Oomoo`1XOol00`00Oomoo`0<Ool005Qoo`03001oogoo0<Qoo`800080]@050001>04h
0CP000040GX200045M`00`008M/Qf`0:8M/01000:O/000002cHk00<003Xk>S/03CXk00<0048j@SX0
3d8j00<004HiAST03dHi00<004XiBST024Xi7@004UIh00<005YhFWP04UYh00<005ZIFYT04UZI00<0
05jiG[T04Eji0P0000=N^000H]T05F;I00<006;jH_X01f;j00<006LJIaX03FLJ00<006]KJe/00f]K
00<006mkKg/03Vmk00<006nKKi/016nK00<006nKKi/00fnK00<006nkKk/02Fnk00<006oKKm/01foK
00<006okKo/01Fok00D006_kJo][n`0000E_f`03001WgFOM00UWg@03001KgU_N00QKgP03001OOUmn
009OOP<000U;_`<000LcO0D000@[G0H000@NnPH000<Bf@T0015oo`03001oogoo06Qoo`03001oogoo
00aoo`00F7oo00<007ooOol0bGoo0`0000D0]@000001>00000H1NP05000Eg1GL5M`0000=8M/00`00
:O/Yn`020009=S/00`00>S/j>`0=>S/00`00@SY2>P0?@SX00`00ASU6>@0?AST00`00BSU:>@0@BST0
0`00DUQBF00@DUP00`00EWQFN00AEWP00`00FWQJN00BFWP00`00FYUJV@0BFYT00`00G[UN^@0?G[T2
0003G[P00`00H]URf@0EH]T00`00H_YRnP05H_X00`00IaYW6P0>IaX00`00Je][F`02Je/00`00Kg]_
N`0>Kg/00`00Ki]_V`06Ki/01@00Ki]_VfnK00002fnk00<006oKKm/01foK00<006okKo/01Fok00<0
06_kJo/00f_k00D006oKKm]_f`0000YWg@8000aKgP04001OOP000009Bkl30007<g`300047_T50004
7_X?000JOol00`00Oomoo`1XOol00`00Oomoo`0<Ool005Moo`03001oogoo0<aoo`800080]@030001
>00000H1NP80008Eg003000Qfb7K00XQf`03000YnbWk008Yn`8000Pf>`03000j>cXk00dj>`030012
>T8j00i2>P030016>DHi0116>@03001:>DXi00m:>@03001BF59H011BF003001FN5Ih015FN003001J
N5Yh01=JN003001JVEZI019JV@03001N^Eji00eN^@03001N^5jh00AN^003001RfF;I01ARf@03001R
nV;j00=RnP80019W6P04001[Ff]K000@Kg/00`00Ki]_V`08Ki/00`00Ki/0000;Kk/00`00Km]_f`07
Km/00`00Ko]_n`05Ko/00`00Jo][n`05Jo/00`00Km/0000:Imd00`00FmiKgP0<Fmh30007Bkl30006
<g`400027_T500023[H=000SOol00`00Oomoo`1XOol00`00Oomoo`0<Ool005Moo`03001oogoo0<eo
o`800080]@<000L1NP03000Eg00000`Qf`03000YnbWk00@Yn`8000Hf>`03000j>cXk00dj>`030012
>T8j00m2>P030016>DHi00m6>@03001:>DXi011:>@03001BF59H011BF003001FN5Ih011FN003001J
N5Yh01=JN003001JVEZI019JV@03001N^Eji00]N^@8000MN^003001RfF;I01ERf@05001RnV;jH_X0
000DIaX00`00Je/0000@Kg/00`00Ki]_V`0:Ki/00`00Kk]_^`09Kk/00`00Km]_f`07Km/00`00Ko]_
n`05Ko/00`00Jo][n`06Jo/30008Imd2000<Fmh30003>i`20002Bkl30005<g`400027_T?000/Ool0
0`00Oomoo`1XOol00`00Oomoo`0<Ool005Moo`03001oogoo0<ioo`8000<0]@030001NP5j00H1NP<0
00`Qf`03000YnbWk00DYn`8000@f>`03000j>cXk00dj>`030012>T8j00m2>P030016>DHi00m6>@03
001:>DXi011:>@03001BF59H011BF003001FN5Ih015FN003001JN5Yh019JN003001JVEZI019JV@03
001N^Eji00UN^@8000UN^003001RfF;I01ERf@04001RnV;j000FIaX00`00Kg]_N`0>Kg/00`00Ki]_
V`0;Ki/20009Kk/00`00Km]_f`07Km/00`00Ko]_n`05Ko/00`00Jo][n`06Jo/01@00GoaOo5ol0000
1VOM00<005_NFmh02U_N0P001c^L1@000c=l0`0000<Nn@0000002@00=Goo00<007ooOol0J7oo00<0
07ooOol037oo001GOol00`00Oomoo`3?Ool200030;D00`000GX1NP070GX00`008M/Qf`0:8M/00`00
:O/Yn`07:O/20003=S/00`00>S/j>`0=>S/00`00@SY2>P0>@SX00`00ASU6>@0?AST00`00BSU:>@0@
BST00`00DUQBF00@DUP00`00EWQFN00AEWP00`00FWQJN00BFWP00`00FYUJV@0BFYT00`00G[UN^@07
G[T2000;G[P00`00H]URf@0EH]T00`00H_X0000FIaX2000?Kg/00`00Ki]_V`0;Ki/01000Kk]_^`00
1fnk00<006oKKm/01foK00<006okKo/01Fok00<006_kJo/01V_k00<005olGo`00eol00@006OMImeW
g@8000]KgP8000HkW0<000@Nm`X003ioo`03001oogoo06Qoo`03001oogoo00aoo`00Egoo00<007oo
Ool0d7oo0P000`2e0P00205j0P002b7K00<002Wk:O/022Wk0P0000<f>`00>S/03SXk00<0048j@SX0
3T8j00<004HiAST03dHi00<004XiBST044Xi00<0059HDUP0459H00<005IhEWP04EIh00<005YhFWP0
4eYh00<005ZIFYT04UZI00<005jiG[T015ji0P003Ujh00<006;IH]T056;I0P005VLJ00@006]JJeX0
00e_N`03001_VfnK00]_V`03001_^fnk009_^`03001_^fnk00=_^`03001_ffoK00M_f`03001_nfok
00E_n`03001[nf_k00I[n`03001Oo5ol00EOo003001Wg@0000YKgP<000HkW08000@Nm`L004Aoo`03
001oogoo06Qoo`03001oogoo00aoo`00Egoo1000d7oo0P000P2e00<0003G00001`5j00<000ej0000
2R7K00<002Wk:O/02RWk0P003cXk00<0048j@SX03d8j00<004HiAST03dHi00<004XiBST03dXi00<0
059HDUP0459H00<005IhEWP04EIh00<005YhFWP04eYh00<005ZIFYT04UZI00<005jiG[T00eji00<0
05jhG[P03Ujh00<006;IH]T04f;I00<006Ki00005FLJ00D006]JJeY[FP0000a_N`03001_VfnK00]_
V`03001_^fnk00A_^`05001_^fnkKk/00009Km/00`00Ko]_n`05Ko/00`00Jo][n`06Jo/00`00GoaO
o006Go`30008Fmh20006>i`300027_L60019Ool00`00Oomoo`1XOol00`00Oomoo`0<Ool005Moo`03
001oogoo0=9oo`<000040;D0003G00070GX010003GX00000227K00<002Wk:O/032Wk0P003SXk00<0
048j@SX03T8j00<004HiAST03dHi00<004XiBST044Xi00<0059HDUP0459H00<005IhEWP04EIh00<0
05YhFWP04UYh00<005ZIFYT04UZI00@005jiG[UN^@80015N^003001RfF;I019Rf@05001VnFKiI_T0
000CIaX00`00JeY[FP03JeX00`00Kg]_N`08Kg/00`00Ki]_V`0;Ki/00`00Kk]_^`06Kk/00`00Kk/0
0009Km/00`00Ko]_n`05Ko/00`00Jo][n`05Jo/20008Go`01@00@kY3^T>j00001E_N0P001C^L0`00
00<Nm`0000001000CGoo00<007ooOol0J7oo00<007ooOol037oo001GOol00`00Oomoo`3COol30000
102e0000e`001P5j00D000ej3GX=NP0000PQf`03000YnbWk00/Yn`04000anP00000<>S/00`00@SY2
>P0>@SX00`00ASU6>@0?AST00`00BSU:>@0@BST00`00DUQBF00@DUP00`00EWQFN00AEWP00`00FWQJ
N00BFWP00`00FYUJV@0CFYT3000CG[P00`00H]URf@0AH]T00`00I_UVn@02I_T00`00IaYW6P0@IaX0
0`00JeY[FP04JeX00`00Kg]_N`07Kg/00`00Ki]_V`0;Ki/00`00Kk]_^`08Kk/00`00Km]_f`07Km/0
0`00Ko]_n`05Ko/00`00Jo][n`05Jo/00`00GoaOo006Go`20005@kX00`00Fmh000020005>i`20000
0akg00000002001BOol00`00Oomoo`1XOol00`00Oomoo`0<Ool005Moo`03001oogoo0=Eoo`<00080
e`030001NP5j00@1NP04000=NPej3GX200068M/00`00:O/Yn`0;:O/01000<OXanS7j0`002CXk00<0
048j@SX03T8j00<004HiAST03dHi00<004XiBST044Xi00<0059HDUP0459H00<005IhEWP04EIh00<0
05YhFWP04UYh00<005ZIFYT04UZI0P005Ujh00<006;IH]T03V;I0P001FKi00<006LJIaX03fLJ00<0
06]JJeX01V]J00<006mkKg/01Fmk00<006nKKi/02fnK00<006nkKk/02Fnk0P001foK00<006okKo/0
1Fok00<006_kJo/01F_k00<005olGo`01Uol00<004>j@kX01D>j1@000S^L1P00EWoo00<007ooOol0
J7oo00<007ooOol037oo001GOol00`00Oomoo`3FOol300020=L200040GX00`003GX=NP033GX20004
8M/00`00:O/Yn`0<:O/00`00<OXanP03<OX20007>S/00`00@SY2>P0?@SX00`00ASU6>@0?AST00`00
BSU:>@0?BST00`00DUQBF00@DUP00`00EWQFN00AEWP00`00FWQJN00CFWP00`00FYUJV@0?FYT20000
0ejH001N^00EG[P00`00H]URf@0=H]T00`00I_UVn@06I_T00`00IaYW6P0=IaX00`00JeY[FP08JeX0
0`00Kg]_N`03Kg/00`00Ki]_V`0;Ki/00`00Kk]_^`09Kk/01000Lm]cf`001FoK00<006okKo/01Fok
00<006_kJo/01F_k00<005olGo`01Eol0P001T>j2`00FWoo00<007ooOol0JGoo00<007ooOol02goo
001GOol00`00Oomoo`3GOol300030=L00`000GX1NP020GX00`003GX=NP043GX00`008M/Qf`028M/0
0`00:O/Yn`0;:O/00`00<OXanP05<OX20006>S/00`00@SY2>P0>@SX00`00ASU6>@0?AST00`00BSU:
>@0?BST00`00DUQBF00@DUP00`00EWQFN00AEWP00`00FWQJN00CFWP00`00FYUJV@0=FYT20003GYP0
0`00G[QN^00DG[P00`00H]URf@0<H]T00`00I_UVn@07I_T00`00IaYW6P0<IaX00`00JeY[FP09JeX0
0`00Kg]_N`02Kg/00`00Ki]_V`0;Ki/00`00Kk]_^`09Kk/00`00Lm]cf`02Lm/01@00Km]_ffoK0000
1fok00<006_kJo/01F_k00<005olGo`01Eol00<004>j@kX014>j2P00GGoo00<007ooOol0JGoo00<0
07ooOol02goo001GOol00`00Oomoo`3HOol300030=L01@000GX1NP5j00001`ej0P000R7K00<002Wk
:O/02bWk00<0037j<OX01c7j0P0013Xk00<0048j@SX03T8j00<004HiAST03dHi00<004XiBST044Xi
00<0059HDUP0459H00<005IhEWP04EIh00<005YhFWP04UYh00<005ZIFYT02eZI0P001UjH00<005jh
G[P055jh00<006;IH]T02V;I00<006KiI_T026Ki00<006LJIaX02fLJ00<006]JJeX02f]J00@006mk
Kg/000e_V`03001_^fnk00U_^`03001cfg?K00Acf`03001_f`0000M_n`03001[nf_k00E[n`03001O
o5ol00AOo08000I3^PL0065oo`03001oogoo06Uoo`03001oogoo00]oo`00Egoo00<007ooOol0fGoo
0P00103G00D0005j0GX1NP0000P=NP04000Qfb7K000=:O/00`00<OXanP08<OX300000cXk0012>P0?
@SX00`00ASU6>@0?AST00`00BSU:>@0@BST00`00DUQBF00@DUP00`00EWQFN00AEWP00`00FWQJN00B
FWP00`00FYUJV@09FYT20008GYP00`00G[QN^00DG[P00`00H]URf@08H]T2000<I_T00`00IaYW6P09
IaX00`00JeY[FP0<JeX00`00Kg/0000=Ki/00`00Kk]_^`09Kk/00`00Lm]cf`06Lm/20006Ko/00`00
Jo][n`04Jo/20006Go`00`00@kY3^P04@kX7001SOol00`00Oomoo`1YOol00`00Oomoo`0;Ool005Mo
o`03001oogoo0=Yoo`8000@0e`8000030GX000ej00P=NP<000dYn`03000anS7j00/anP<00112>P03
0016>DHi00m6>@03001:>DXi00m:>@03001BF59H011BF003001FN5Ih015FN003001JN5Yh01=JN003
001JVEZI00MJV@03001NV5jH00QNV003001N^5jh01AN^003001RfF;I00MRf@03001VnFKi00aVn@03
001W6VLJ00QW6P03001[FV]J00i[FP03001_VfnK00]_V`03001_^fnk00U_^`03001cfg?K00Mcf`04
001_n`000003Ko/00`00Jo][n`04Jo/00`00GoaOo005Go`00`00@kY3^P03@kX6001VOol00`00Oomo
o`1YOol00`00Oomoo`0;Ool005Ioo`03001oogoo0=aoo`<000@0e`030001NP0000X=NP03000YnbWk
00/Yn`03000anS7j00danP8000m2>P030016>DHi00m6>@03001:>DXi00m:>@03001BF59H011BF003
001FN5Ih015FN003001JN5Yh01=JN003001JVEZI00EJV@8000]NV003001N^5jh01AN^003001RfF;I
00IRf@03001VnFKi00eVn@03001W6VLJ00MW6P03001[FV]J00m[FP03001_VfnK00Y_V`03001_^fnk
00U_^`03001cfg?K00Mcf`03001_nfok009_n`03001_n`0000I[n`03001Oo5ol00AOo08000A3^PD0
06Uoo`03001oogoo06Uoo`03001oogoo00]oo`00EWoo00<007ooOol0gWoo0P00103G0P002`ej0P00
32Wk00<0037j<OX0337j00<003Gi00000P00348j00<004HiAST03dHi00<004XiBST03dXi00<0059H
DUP0459H00<005IhEWP04EIh00<005YhFWP04eYh00<005ZIFYT00eZI0P003UjH00<005jhG[P055jh
00<006;IH]T016;I00<006KiI_T03fKi00<006LJIaX01FLJ00<006]JJeX03f]J00<006mj00002VnK
00<006nkKk/02Fnk00<007?KLm/01g?K00<006okKo/016ok0P001F_k00<005olGo`015ol00<004>j
@kX00T>j1@00Jgoo00<007ooOol0JGoo00<007ooOol02goo001FOol00`00Oomoo`3OOol200040=L2
000:3GX00`005IX0000;:O/00`00<OXanP0<<OX00`00=OTen@02=OT2000:@SX00`00ASU6>@0?AST0
0`00BSU:>@0@BST00`00DUQBF00@DUP00`00EWQFN00AEWP00`00FWQJN00BFWP01000FYUJVEZI0P00
45jH00<005jhG[P055jh00<006;IH]T00V;I0P004VKi00<006LJIaX016LJ00<006]JJeX03f]J00D0
06mjKgY_NP0000Q_V`03001_^fnk00U_^`03001cfg?K00Mcf`03001_nfok00E_n`03001SnP000080
0003Jo/005ol00AOo08000A3^P<006ioo`03001oogoo06Uoo`03001oogoo00]oo`00EWoo1000ggoo
0P00103G00<000ej3GX02@ej00<001FJ00002RWk00<0037j<OX03C7j00<003Gi=OT00cGi0P002D8j
00<004HiAST03THi00<004XiBST044Xi00<0059HDUP0459H00<005IhEWP04EIh00<005YhFWP04eYh
0`004UjH00<005jhG[P055jh00D006;IH]URf@0001AVn@03001W6VLJ00=W6P03001[FV]J00m[FP03
001_NVmj00=_NP03001_VfnK00A_V`03001_^fnk00U_^`03001cfg?K00Mcf`03001_nfok00E_n`03
001SnV?j009SnPD0009Oo0030013^T>j0093^P<0075oo`03001oogoo06Qoo`03001oogoo00]oo`00
EWoo00<007ooOol0hGoo0P00103G0P002@ej00<001FJ5IX00P002BWk00<0037j<OX0337j00<003Gi
=OT01CGi0`001T8j00<004HiAST03dHi00<004XiBST03dXi00<0059HDUP0459H00<005IhEWP04EIh
00<005YhFWP04UYh0P0055jH00<005jhG[P055jh00@006;IH]T001IVn@05001W6VLJIaX0000AJeX0
0`00KgY_NP04KgX00`00Ki]_V`03Ki/00`00Kk]_^`09Kk/00`00Lm]cf`07Lm/00`00Ko]_n`05Ko/0
0`00HoYSnP02HoX00`00AiI7UP03AiH7001dOol00`00Oomoo`1XOol00`00Oomoo`0;Ool005Ioo`03
001oogoo0>9oo`<00080e`030000n00000T=NP05000EVQFJ5IX00008:O/00`00<OXanP0<<OX00`00
=OTen@08=OT20004@SX00`00ASU6>@0?AST00`00BSU:>@0?BST00`00DUQBF00@DUP00`00EWQFN00A
EWP00`00FWQJN00?FWP300000eig001NV00DGYP00`00G[QN^00DG[P2000GI_T01000IaYW6P004F]J
00<006mjKgX01Vmj00D006nKKi]_V`0000a_^`03001cfg?K00Icf`03001_nfok00E_n`03001SnV?j
009SnP030017UTNF00=7UPH007Ioo`03001oogoo06Qoo`03001oogoo00]oo`00EWoo00<007ooOol0
hgoo00<0001B00000P3G00<0003h000020ej00<001FJ5IX00QFJ0P001RWk00<0037j<OX03C7j00<0
03Gi=OT02CGi0P000T8j00<004HiAST03dHi00<004XiBST03dXi00<0059HDUP0459H00<005IhEWP0
4UIh00<005YhFWP035Yh0P0015ig00<005jHGYP04ejH00<005jhG[P04ejh0P0066Ki00<006LJ0000
4F]J00<006mjKgX026mj00<006nK000036nk00<007?KLm/01W?K00<006okKo/01Fok00<006?jHoX0
0V?j00<004NFAiH00dNF1@00N7oo00<007ooOol0J7oo00<007ooOol02goo001FOol00`00Oomoo`3T
Ool00`00058000020=L010000?P000001`ej00<001FJ5IX00aFJ00<002Wk:O/012Wk00<0037j<OX0
337j00<003Gi=OT02cGi100044Hi00<004XiBST044Xi00<0059HDUP0459H00<005IhEWP04EIh00<0
05YhFWP02EYh0`001Uig00<005jHGYP04ejH00<005jhG[P04Ujh00<006KH00006FKi00<006]JJeX0
3f]J00<006mjKgX02Vmj00<006nkKk/02Vnk00<007?KLm/01W?K00<006okKo/01Fok00<006?jHoX0
0V?j00<004NFAiH00TNF1@00NWoo00<007ooOol0J7oo00<007ooOol02goo001FOol00`00Oomoo`3U
Ool300020=L010000?P0n0001Pej00<001FJ5IX011FJ00<002Wk:O/00bWk00<0037j<OX0337j00<0
03Gi=OT03SGi0`003dHi00<004XiBST03dXi00<0059HDUP0459H00<005IhEWP04EIh00<005YhFWP0
1eYh0P002Uig00<005jHGYP04UjH00<005jhG[P04Ejh00D006KHI]QVf00001QVn@03001[FV]J00i[
FP03001_NVmj00]_NP03001_^fnk00U_^`03001cfg?K00Icf`03001_nfok00E_n`03001SnV?j009S
nP030017UTNF0097UPD007]oo`03001oogoo06Qoo`03001oogoo00]oo`00EWoo00<007ooOol0igoo
0P0000<0e`000?P00P3h00<000ej3GX010ej00<001FJ5IX011FJ0P000bWk00<0037j<OX03C7j00<0
03Gi=OT03CGi00<003gh?OP00`0034Hi00<004XiBST03dXi00<0059HDUP0459H00<005IhEWP04EIh
00<005YhFWP015Yh0`0035ig00<005jHGYP04ejH00<005jhG[P03ejh00<006KHI]P00VKH00<006Ki
I_T05FKi00<006/j00003V]J00<006mjKgX02fmj00<007>k00002Fnk00<007?KLm/01W?K00<006ok
Ko/01Fok00<006?jHoX00V?j00<004NFAiH00TNF1000OGoo00<007ooOol0J7oo00<007ooOol02goo
001FOol00`00Oomoo`3XOol400030?P00`003GX=NP033GX00`005IXEVP065IX01@00:O/YnbWk0000
3S7j00<003Gi=OT03CGi00<003gh?OP00cgh0`002DHi00<004XiBST03dXi00<0059HDUP0459H00<0
05IhEWP04EIh00<005YhFWP00UYh0P003eig00<005jHGYP04ejH00<005jhG[P03Ujh00<006KHI]P0
0fKH00<006KiI_T056Ki00@006/jJcX000e[FP03001_NVmj00]_NP05001c^g>kLk/00007Kk/00`00
Lm]cf`06Lm/00`00Ko]_n`05Ko/00`00HoYSnP02HoX00`00AiI7UP02AiH3001oOol00`00Oomoo`1X
Ool00`00Oomoo`0;Ool000Yoo`@000ioo`<000moo`<000eoo`H0019oo`03001oogoo0>Uoo`040000
DP0000030?P200033GX00`005IXEVP075IX200000bWk000anP0=<OX00`00=OTen@0>=OT00`00?OPm
n005?OP30006AST00`00BSU:>@0?BST00`00DUQBF00@DUP00`00EWQFN00BEWP4000AGWL00`00GYQN
V00CGYP00`00G[QN^00=G[P00`00I]QVf005I]P00`00I_UVn@0BI_T00`00JcY[>P02JcX00`00JeY[
FP09JeX00`00KgY_NP0;KgX00`00Lk]c^`03Lk/00`00Kk]_^`03Kk/00`00Lm]cf`06Lm/00`00Ko]_
n`05Ko/00`00HoYSnP02HoX01000AiI7UTNF0`00PGoo00<007ooOol0J7oo00<007ooOol02goo0008
Ool8000;Ool5000>Ool3000;Ool:000@Ool00`00Oomoo`3ZOol00`00058000050?P01@003GX=NPej
00002QFJ0P003S7j00<003Gi=OT03SGi00<003gh?OP023gh0`000dHi00<004XiBST044Xi00<0059H
DUP0459H00<005IhEWP03eIh0`0055ig00<005jHGYP04ejH00<005jhG[P035jh00<006KHI]P01VKH
00<006KiI_T04FKi00<006/jJcX00f/j00<006]JJeX026]J00<006mjKgX02fmj00<007>kLk/01G>k
00D006nkKk]_^`0000Qcf`03001_nfok00E_n`03001SnV?j009SnP040017UTNFAiH20023Ool00`00
Oomoo`1XOol00`00Oomoo`0;Ool000Qoo`8000Aoo`8000]oo`D000moo`8000]oo`<000Eoo`<000mo
o`03001oogoo0>]oo`030000DP0000D0n004000=NPej000;5IX2000><OX00`00=OTen@0==OT00`00
?OPmn00;?OP300000dHi001:>@0@BST00`00DUQBF00@DUP00`00EWQFN00<EWP30002FUH00`00GWMN
M`0BGWL00`00GYQNV00CGYP00`00G[QN^00;G[P00`00I]QVf007I]P00`00I_UVn@0@I_T00`00JcY[
>P05JcX00`00JeY[FP06JeX00`00KgY_NP0;KgX00`00Lk]c^`07Lk/00`00Kk/00008Lm/00`00Ko]_
n`05Ko/00`00HoYSnP02HoX01000AiI7UTNF0P00Q7oo00<007ooOol0J7oo00<007ooOol02goo0007
Ool20006Ool2000:Ool5000?Ool3000COol2000?Ool00`00Ool00003003YOol00`00058000050?P2
00000`ej000EVP0:5IX2000=<OX00`00=OTen@0==OT00`00?OPmn00>?OP4000?BST00`00DUQBF00@
DUP00`00EWQFN009EWP30005FUH00`00GWMNM`0CGWL00`00GYQNV00CGYP00`00G[QN^008G[P2000;
I]P00`00I_UVn@0>I_T00`00JcY[>P06JcX00`00JeY[FP05JeX00`00KgY_NP0;KgX00`00Lk]c^`09
Lk/20007Lm/00`00Ko]_n`05Ko/00`00HoYSnP02HoX00`00AiI7UP020026Ool00`00Oomoo`1YOol0
0`00Oomoo`0:Ool000Moo`8000Ioo`8000]oo`<0011oo`<001Aoo`8000eoo`<00>ioo`040000DP00
00050?P2000;5IX00`007IX0000<<OX00`00=OTen@0==OT00`00?OPmn00??OP00`00?MLme`05000:
BST00`00DUQBF00@DUP00`00EWQFN006EWP30008FUH00`00GWMNM`0CGWL00`00GYQNV00CGYP00`00
G[QN^007G[P00`00I]QVf00;I]P00`00I_UVn@0=I_T00`00JcY[>P08JcX00`00JeY[FP03JeX00`00
KgY_NP0;KgX00`00Lk]c^`0:Lk/00`00Lm/00005Lm/00`00Ko]_n`05Ko/00`00HoYSnP02HoX01000
AiI7UP00R7oo00<007ooOol0JGoo00<007ooOol02Woo0006Ool20008Ool2000NOol2000DOol2000=
Ool00`00Oomoo`3_Ool200000`1c0000n0040?P2000;5IX010007IX000002c7j00<003Gi=OT03CGi
00<003gh?OP03Sgh00<003gG?ML01CgG1@001DXi00<0059HDUP0459H00<005IhEWP00eIh0`0035YF
00<005igGWL04Uig00<005jHGYP04ejH00<005jhG[P01Ujh00<006KHI]P036KH00<006KiI_T036Ki
00<006/jJcX02F/j00<006]JJeX00V]J00<006mjKgX02fmj00<007>kLk/02W>k00D007?KLm]cf`00
00=cf`03001_nfok00E_n`03001SnV?j009SnP040017UTNF0024Ool6001[Ool00`00Oomoo`0:Ool0
00Ioo`8000Qoo`8001ioo`<001=oo`8000eoo`03001oogoo0?1oo`80000307<0003h00@0n003000E
VQFJ00TEVP05000MVQfJ7IX0000:<OX00`00=OTen@0==OT00`00?OPmn00>?OP00`00?MLme`0:?ML5
00000dXi001BF00ADUP00`00EWP00002000?FUH00`00GWMNM`0BGWL00`00GYQNV00CGYP00`00G[QN
^005G[P00`00I]QVf00>I]P00`00I_UVn@0:I_T00`00JcY[>P0;JcX01000JeY[FP003Fmj00<007>k
Lk/02W>k00<007?KLm/00g?K00<007?K00001fok00<006?jHoX00V?j00@004NFAiH007Yoo`/000Eo
o`03001oogoo06Uoo`03001oogoo00Yoo`001Woo0P0027oo0P007goo0P004goo0P003Goo00<007oo
Ool0lGoo0P0000<0L`000?P0103h0P002AFJ00<001fJ7IX00QfJ0P00237j00<003Gi=OT03CGi00<0
03gh?OP03cgh00<003gG?ML03SgG5P004UYF00<005igGWL04Uig00<005jHGYP055jH00<005jhG[P0
0ejh00<006KHI]P03fKH00<006KiI_T02FKi00<006/jJcX036/j00<006]J00003Fmj00<007>kLk/0
2W>k00<007?KLm/01G?K0`001Fok00<006?jHoX00V?j00@004NF0000075oo`X0015oo`03001oogoo
06Qoo`03001oogoo00Yoo`001Woo0P0027oo0P007goo0P004goo0P003Goo00<007ooOol0lWoo0P00
00<0L`000?P00`3h00<0004H00002AFJ00<001fJ7IX00afJ00<0037j<OX01C7j00<003Gi=OT03CGi
00<003gh?OP03cgh00<003gG?ML03cgG00<004hGCQL044hG00<005YFFUH04EYF00<005igGWL04Uig
00<005jHGYP055jH00<005jhG[P00Ujh00<006KHI]P046KH00<006KiI_T026Ki00<006/jJcX03V/j
00<006mjKgX036mj00<007>kLk/02G>k00<007?KLm/01W?K00<006ojKoX00`0000=_n`00HoX00f?j
0`00JGoo2P0077oo00<007ooOol0Igoo00<007ooOol02Woo0006Ool20008Ool2000OOol3000AOol2
000>Ool00`00Oomoo`3cOol200000`1c0000n0030?P00`000AP000085IX00`007IXMVP047IX20006
<OX00`00=OTen@0==OT00`00?OPmn00>?OP00`00?MLme`0??ML00`00CQM>5`0@CQL00`00FUIJEP0A
FUH00`00GWMNM`0CGWL00`00GYQNV00CGYP01@00G[QN^5jh000056KH00<006KiI_T01VKi00<006/j
JcX03f/j00<006mjKgX02fmj00<007>kLk/02G>k00<007?KLm/01W?K00<006ojKoX016oj2000Ggoo
2`009goo00<007ooOol0IWoo00<007ooOol02Woo0006Ool20008Ool2000POol20009Ool20005Ool3
000>Ool00`00Oomoo`3dOol0100007<0L`000`3h00@0004H0AP000PEVP03000MVQfJ00DMVP03000a
nS7j00<anP03000enCGi00den@03000mn3gh00hmn003000mecgG00lme`03001>5dhG011>5`03001J
EUYF015JEP03001NMeig01=NM`03001NV5jH01=NV004001N^5jh000EI]P00`00I_UVn@05I_T00`00
JcY[>P0?JcX00`00KgX0000;KgX00`00Lk]c^`09Lk/00`00Lm]cf`06Lm/00`00KoY_nP05KoX00`00
FmMKe`04001FOol:000bOol00`00Oomoo`1VOol00`00Oomoo`0:Ool000Ioo`8000Qoo`80021oo`80
00Uoo`T000moo`03001oogoo0?Eoo`040000L`1c00030?P010000AP160001aFJ00<001fJ7IX01QfJ
00<0037j<OX00S7j00<003Gi=OT03CGi00<003gh?OP03Sgh00<003gG?ML03cgG00<004hGCQL044hG
00<005YFFUH04EYF00<005igGWL04eig00<005jHGYP055jH0P005VKH00<006KiI_T016Ki00<006/j
JcX03f/j00D006mjKgY_NP0000U_NP03001c^g>k00Uc^`03001cfg?K00Icf`03001_nVoj00E_nP03
001Kee_G00<004ioo`X003eoo`03001oogoo06Eoo`03001oogoo00Yoo`001Woo0P0027oo0P008Goo
0P0027oo0P0000=oo`0000000`0047oo00<007ooOol0mWoo00@0001c07<00080n0050001604H0AP0
00065IX00`007IXMVP077IX20003<OX00`00=OTen@0<=OT00`00?OPmn00>?OP00`00?MLme`0@?ML0
0`00CQM>5`0?CQL00`00FUIJEP0BFUH00`00GWMNM`0BGWL00`00GYQNV00CGYP2000HI]P00`00I_UV
n@02I_T00`00JcY[>P0?JcX00`00KgY_NP02KgX00`00KgY_NP06KgX00`00Lk]c^`09Lk/00`00Lm]c
f`06Lm/00`00KoY_nP05KoX00`00FmMKe`030014Ool;0018Ool00`00Oomoo`1TOol00`00Oomoo`0:
Ool000Moo`8000Ioo`80029oo`8000Qoo`8001Ioo`03001oogoo0?Moo`80000507<0003h0?P00003
0AP00`005IXEVP045IX00`007IXMVP087IX01000<OXanP003SGi00<003gh?OP03Sgh00<003gG?ML0
43gG00<004hGCQL044hG00<005YFFUH04EYF00<005igGWL04Uig00<005jHGYP04UjH00<006:h0000
66KH00D006KiI_UVn@00015[>P03001_NVmj00A_NP03001_NVmj00A_NP03001c^g>k00Uc^`03001c
fg?K00Icf`03001_nVoj00E_nP03001Kee_G00<003]oo`X005=oo`03001oogoo06Aoo`03001oogoo
00Yoo`001goo0P001Woo0P006Goo0P001goo0P0027oo0P005Woo00<007ooOol0nGoo00<0001c0000
0P3h00D0004H0AP1600000DEVP03000MVQfJ00TMVP<000len@03000mn3gh00hmn003000mecgG00lm
e`03001>5dhG011>5`03001JEUYF015JEP03001NMeig019NM`03001NV5jH015NV004001R^6:h000H
I]P01000I_UVn@004F/j00<006mjKgX01Vmj00<006mjKgX00Vmj00<007>kLk/02G>k00<007?KLm/0
1W?K00<006ojKoX01Foj00<005_GFmL00`00<Woo2P00GWoo00<007ooOol0Hgoo00<007ooOol02Woo
0008Ool20004Ool2000JOol20008Ool20007Ool2000FOol00`00Oomoo`3jOol01@0007<0003h0000
104H0P0011FJ00<001fJ7IX02QfJ0P003SGi00<003gh?OP03Sgh00<003gG?ML03cgG00<004hGCQL0
44hG00<005YFFUH04EYF00<005igGWL04eig00<005jHGYP03ejH00<006:hH[P00V:h00<006KHI]P0
5VKH0P004F/j00<006mjKgX01fmj00D006mjKgY_NP0000ac^`03001cfg?K00Ecf`03001_nVoj00E_
nP03001Kee_G008002Uoo`/006Uoo`03001oogoo069oo`03001oogoo00Yoo`0027oo20006Woo3000
1goo2P003Goo1@00nWoo00D0001c0000n00000D16005000EVQFJ5IX0000=7IX2000==OT00`00?OPm
n00>?OP00`00?MLme`0??ML00`00CQM>5`0@CQL00`00FUIJEP0AFUH00`00GWMNM`0CGWL00`00GYQN
V00>GYP00`00H[QR^003H[P00`00I]QVf00FI]P00`00JcY[>P0@JcX00`00KgY_NP08KgX00`00KgX0
000<Lk/00`00Lm]cf`05Lm/00`00KoY_nP05KoX00`00FmMKe`02000POol:001eOol00`00Oomoo`1Q
Ool00`00Oomoo`0:Ool000Yoo`@001aoo``000Moo`X000ioo`03001oogoo0?aoo`040000L`000006
0AP010005IXEVP003AfJ00<002FI000033Gi00<003gh?OP03Sgh00<003gG?ML03cgG00<004hGCQL0
44hG00<005YFFUH04EYF00<005igGWL04eig00<005jHGYP03EjH00<006:hH[P016:h00<006KHI]P0
5VKH00<006/jJcX03f/j00<006mjKgX02Vmj00<007>kLk/02W>k00<007?KLm/01G?K00<006ojKoX0
1Foj00<005_GFmL00P005goo2P00Ogoo00<007ooOol0HGoo00<007ooOol02Woo001EOol00`00Oomo
o`3mOol0100007<000001P4H00@001FJ5IX000`MVP04000UVBFI000;=OT00`00?OPmn00>?OP00`00
?MLme`0??ML00`00CQM>5`0@CQL00`00FUIJEP0BFUH00`00GWMNM`0BGWL00`00GYQNV00;GYP20007
H[P00`00I]QVf00EI]P00`00JcT0000?JcX00`00KgY_NP0;KgX00`00Lk]c^`09Lk/00`00Lm]cf`05
Lm/00`00KoY_nP05KoX01000FmMKe`003Woo2`00RWoo00<007ooOol0H7oo00<007ooOol02Woo001D
Ool00`00Oomoo`3oOol00`0007<000070AP00`005IX0000=7IX00`009ITUV@02000:=OT00`00?OPm
n00=?OP00`00?MLme`0??ML00`00CQM>5`0@CQL00`00FUIJEP0BFUH00`00GWMNM`0BGWL00`00GYQN
V00:GYP00`00H[QR^008H[P00`00I]QVf00CI]P01000JcU[>@003V/j00<006mjKgX02fmj00<007>k
00002G>k00<007?KLm/01W?K00<006ojKoX016oj00@005_GFmL000Eoo`X009Ioo`03001oogoo05mo
o`03001oogoo00Yoo`00E7oo00<007ooOol0ogoo0Goo00@0001c000000H16003000EVP0000`MVP03
000UVBFI008UV@03000enCGi00Len@03000mn3gh00dmn003000mecgG00lme`03001>5dhG011>5`03
001JEUYF019JEP03001NMeig019NM`03001NV5jH00UNV003001R^6:h00UR^003001Vf6KH019Vf003
001[>F/i009[>@03001[>V/j00Y[>P03001_NVmj00]_NP05001c^g>kLk/00007Lk/00`00Lm]cf`06
Lm/00`00KoY_nP04KoX:002QOol00`00Oomoo`1NOol00`00Oomoo`0:Ool005Aoo`03001oogoo0?mo
o`9oo`80000307<0004H00D1608000`MVP03000UVBFI00<UV@8000Len@03000mn3gh00hmn003000m
ecgG00lme`03001>5dhG00m>5`03001JEUYF019JEP03001NMeig01=NM`03001NV5jH00MNV003001R
^6:h00YR^003001Vf6KH015Vf003001[>F/i00=[>@03001[>V/j00U[>P03001_NVmj00]_NP03001c
^g>k00=c^`03001c^g>k00=c^`03001cfg?K00=cf`/0009Ke`03001oogoo0:Ioo`03001oogoo05io
o`03001oogoo00Yoo`00E7oo00<007ooOol0ogoo17oo00<0001c00001P4H00<001fJ7IX02afJ00<0
02FI9IT012FI00<003Gi=OT013Gi00<003gh?OP03Sgh00<003gG?ML03cgG00<004hGCQL044hG00<0
05YFFUH04EYF00<005igGWL04eig00<005jHGYP01UjH00<006:hH[P02f:h00<006KHI]P046KH00<0
06/iJcT016/i00<006/jJcX026/j00<006mjKgX02fmj00<007>kLk/01G>k2`000W?K00<006ojKoX0
16oj00@005_GFmL00:Yoo`03001oogoo05ioo`03001oogoo00Uoo`00E7oo00<007ooOol0ogoo1Goo
00<0001c00001P4H0P002afJ00<002FI9IT01BFI00<003Gi=OT013Gi00<003gh?OP03Cgh00<003gG
?ML03cgG00<004hGCQL044hG00<005YFFUH04EYF00<005igGWL04eig00<005jHGYP015jH0P003f:h
00<006KHI]P03VKH00<006/iJcT01V/i00<006/jJcX01V/j00<006mjKgX02fmj2`0000=c^`00Lm/0
1g?K00<006ojKoX016oj00@005_GFmL00:aoo`03001oogoo05eoo`03001oogoo00Uoo`00E7oo00<0
07ooOol0ogoo1Woo00<0001c00001@4H00<0004H00002QfJ00<002FI9IT01RFI0P0013Gi00<003gh
?OP03Cgh00<003gG?ML03cgG00<004hGCQL044hG00<005YFFUH04EYF00<005igGWL04eig00<005jH
GYP00ejH00<006:hH[P03f:h00<006KHI]P03FKH00<006/iJcT01f/i00<006/jJcX01V/j00<006mj
KgX02`002g>k0P001g?K00<006ojKoX016oj00@005_GFmL00:eoo`03001oogoo05eoo`03001oogoo
00Uoo`00E7oo00<007ooOol0ogoo1Woo0P0000<0L`000AP0104H00<0004H00002QfJ00<002FI9IT0
1bFI00D003Gi=OTen@0000lmn003000mecgG00lme`03001>5dhG011>5`03001JEUYF019JEP03001N
Meig019NM`03001NV5jH009NV003001R^6:h011R^003001Vf6KH00aVf003001[>F/i00U[>@/000Y_
NP03001c^g>k00Uc^`03001cf`0000Ecf`03001_nVoj00A_nP04001Kee_G002_Ool00`00Oomoo`1L
Ool00`00Oomoo`09Ool005Aoo`03001oogoo0?moo`Eoo`06001oogoo0000L`00104H00@0004H0AP0
00TMVP03000UVBFI00PUV@800003=OT003gh00hmn003000mecgG00lme`03001>5dhG011>5`03001J
EUYF019JEP03001NMeig019NM`05001NV5jHGYP0000CH[P00`00I]QVf00;I]P01000JcU[>F/i2P00
1F/j00<006mjKgX02fmj00<007>kLk/02G>k00D007?KLm]cf`0000=cf`03001_nVoj00A_nP04001K
ee_G002aOol00`00Oomoo`1KOol00`00Oomoo`09Ool005Aoo`03001oogoo0?moo`Eoo`07001oogoo
Ool0001c0000104H00@0004H0AP000PMVP03000UVBFI00XUV@8000lmn003000mecgG00lme`03001>
5dhG011>5`03001JEUYF019JEP03001NMeig01=NM`03001NV00001AR^003001Vf6KH00AVf0/000Y[
>@05001[>V/jJcX0000=KgX00`00Lk]c^`09Lk/00`00Lm]cf`03Lm/00`00Lm/00006KoX01000FmL0
0000/goo00<007ooOol0FWoo00<007ooOol02Goo001DOol4003oOol4Ool00`00Oomoo`02Ool00`00
07<000030AP01@000AP1604H000021fJ00<002FI9IT02RFI0P003cgh00<003gG?ML03SgG00<004hG
CQL044hG00<005YFFUH04UYF00<005igGWL04eig0P004V:h2P001FKH00<006/iJcT03F/i00@006/j
JcX000e_NP03001c^g>k00Uc^`03001cfg?K00Ecf`@000=_nP@00;Aoo`03001oogoo05Yoo`03001o
ogoo00Uoo`00E7oo00<007ooOol0ogoo1Goo00<007ooOol00goo00<0001c00000`4H00D0004H0AP1
600000LMVP03000UVBFI00/UV@8000hmn003000mecgG00hme`03001>5dhG011>5`03001JEUYF019J
EP03001NMeig019NM`8000UR^0X000AR^003001Vf6KH00MVf003001[>F/i00i[>@03001[>P0000e_
NP03001c^g>k00Uc^`03001cfg?K00Icf`04001_nVojKoX30002Ci<00`00Oomoo`2dOol00`00Oomo
o`1IOol00`00Oomoo`09Ool005Aoo`03001oogoo0?moo`Eoo`03001oogoo00Aoo`030000L`000081
60030001604H00816003000MVQfJ00@MVP03000UVBFI00/UV@03000UN00000dmn003000mecgG00lm
e`03001>5dhG00m>5`03001JEUYF019JEP03001NMeig015NM``000iR^003001Vf6KH00IVf003001[
>F/i011[>@03001_NVmj00]_NP03001c^g>k00Uc^`03001cfg?K00Icf`03001_nVoj00A_nP03001?
T`000;Qoo`03001oogoo05Qoo`03001oogoo00Uoo`00E7oo00<007ooOol0ogoo1Goo00<007ooOol0
1Goo00<0001c00000P4H00<0004H0AP00P4H0P0011fJ00<002FI9IT02bFI00@002Eh9GP000`mn003
000mecgG00lme`03001>5dhG00m>5`03001JEUYF019JEP03001NMeig00QNM`X00003HYL006:h01IR
^003001Vf6KH00EVf003001[>F/i015[>@03001_NVmj00Y_NP03001c^g>k00Uc^`03001cfg?K00Ic
f`03001_nVoj00A_nP03001?T`000;Uoo`03001oogoo05Qoo`03001oogoo00Uoo`00E7oo00<007oo
Ool0ogoo1Goo00<007ooOol01Woo00D0001c0001600000H16003000MVQfJ008MVP03000UVBFI00/U
V@04000UN2Eh000;?OP00`00?MLme`0??ML00`00CQM>5`0@CQL00`00FUIJEP0BFUH:0007GWL00`00
HYMRU`02HYL00`00H[QR^00EH[P00`00I]QVf003I]P00`00JcU[>@0AJcT00`00KgX0000:KgX00`00
Lk]c^`09Lk/00`00Lm]cf`06Lm/00`00KoY_nP04KoX00`00Ci<0002kOol00`00Oomoo`1GOol00`00
Oomoo`09Ool005=oo`03001oogoo0?moo`Ioo`03001oogoo00Moo`050000L`000AP000060AP01@00
7IXMVQfJ00003BFI00D002Eh9GPUN00000Xmn003000mecgG00lme`03001>5dhG011>5`03001JEUYF
00MJEP`000mNM`03001RUf:G00=RU`03001R^6:h01ER^003001Vf6KH009Vf003001[>F/i015[>@05
001_NVmjKgX00009KgX00`00Lk]c^`08Lk/00`00Lm]cf`06Lm/00`00KoY_nP04KoX00`00Ci<0002m
Ool00`00Oomoo`1FOol00`00Oomoo`09Ool005=oo`03001oogoo0?moo`Ioo`03001oogoo00Qoo`04
0000L`0000070AP010007IXMVP003BFI00<002Eh9GP00REh0P0023gh00<003gG?ML03cgG00<004hG
CQL044hG2P002eYF00<005igGWL035ig00<006:GHYL016:G00<006:hH[P05F:h00D006KHI]QVf000
01=[>@03001_NVmj009_NP03001_NVmj00I_NP03001c^g>k00Qc^`03001cfg?K00Icf`03001_nVoj
00A_nP03001?T`000;moo`03001oogoo05Eoo`03001oogoo00Uoo`00Dgoo00<007ooOol0ogoo1Woo
00<007ooOol02Goo00@0001c000000L16004000MVQfJ000<9IT00`009GPUN0049GP00`00?OPmn006
?OP00`00?MLme`0>?ML00`00CQM>5`06CQL;000DFUH00`00GWMNM`0;GWL00`00HYMRU`05HYL00`00
H[QR^00EH[P01000I]QVf0004f/i00<006mjKgX016mj00<006mjKgX016mj00<007>kLk/027>k00<0
07?KLm/01W?K00<006ojKoX016oj00<004nC0000`7oo00<007ooOol0EGoo00<007ooOol02Goo001C
Ool00`00Oomoo`3oOol6Ool00`00Oomoo`0:Ool00`0007<000080AP00`007IX0000=9IT00`009GPU
N0049GP00`00?OPmn005?OP00`00?MLme`0<?ML;000:CQL00`00FUIJEP0BFUH00`00GWMNM`0:GWL0
0`00HYMRU`06HYL00`00H[QR^00FH[P2000CJcT00`00KgY_NP06KgX00`00KgY_NP02KgX00`00Lk]c
^`09Lk/00`00Lm]cf`06Lm/00`00KoY_nP03KoX00`00Ci<00032Ool00`00Oomoo`1DOol00`00Oomo
o`09Ool005=oo`03001oogoo0?moo`Ioo`03001oogoo00]oo`030000L`0000P1608000dUV@03000U
N2Eh00DUN003000mn3gh00@mn003000mecgG008me`X0008me`03001>5dhG011>5`03001JEUYF019J
EP03001NMeig00UNM`03001RUf:G00QRU`03001R^6:h01ER^003001[>F/i015[>@03001_NVmj00M_
NP05001_NVmjKgX0000;Lk/00`00Lm]cf`06Lm/00`00KoY_nP04KoX20034Ool00`00Oomoo`1COol0
0`00Oomoo`09Ool005=oo`03001oogoo0?moo`Ioo`03001oogoo00aoo`<000P1608000`UV@03000U
N2Eh00HUN0/000`me`03001>5dhG011>5`03001JEUYF01=JEP03001NMeig00MNM`03001RUf:G00UR
U`03001R^6:h01ER^003001[>F/i015[>@03001_NVmj00Q_NP03001_NP0000]c^`03001cfg?K00Ic
f`03001_nVoj00A_nP800<Ioo`03001oogoo059oo`03001oogoo00Uoo`00Dgoo00<007ooOol0ogoo
1Woo00<007ooOol03Goo0`00204H00<002FI9IT02BFI2P0000<UN00000000cgh00<003gG?ML03cgG
00<004hGCQL03dhG00<005YFFUH04eYF00<005igGWL01Uig00<006:GHYL02V:G00<006:hH[P056:h
00<006/i00004F/i00<006mjKgX02Vmj00<007>kLk/02G>k00<007?KLm/01W?K00<006ojKoX016oj
0P00agoo00<007ooOol0DWoo00<007ooOol02Goo001COol4003oOol5Ool00`00Oomoo`0>Ool30007
0AP00`009IT0000900000bFI000UN00:9GP01000?OPmn0004CgG00<004hGCQL03dhG00<005YFFUH0
4eYF00<005igGWL01Eig00<006:GHYL02f:G00<006:hH[P04f:h00@006/iJcT0011[>@03001_NVmj
00]_NP8000Uc^`03001cfg?K00Icf`03001_nVoj00A_nP800<Uoo`03001oogoo055oo`03001oogoo
00Uoo`00Dgoo00<007ooOol0ogoo1Woo00<007ooOol03goo2`0032FI00<002Eh9GP02BEh00<003gh
00004CgG00<004hGCQL03dhG00<005YFFUH04eYF00<005igGWL015ig00<006:GHYL03F:G00<006:h
H[P04F:h00<006/iJcT00V/i00<006/iJcT036/i00<006mjKgX02fmj00@007>jLkX000Mc^`03001c
fg?K00Icf`03001_nVoj00A_nP800<]oo`03001oogoo055oo`03001oogoo00Qoo`00Dgoo00<007oo
Ool0ogoo1Woo00<007ooOol01Goo2P0000Aoo`00000000H1608000/UV@03000UN2Eh00XUN003000m
n000010me`03001>5dhG011>5`03001JEUYF019JEP03001NMeig00=NM`03001RUf:G00iRU`03001R
^6:h011R^003001[>F/i00=[>@03001[>F/i00][>@03001_NVmj00]_NP03001c^W>j009c^P03001c
^g>k00=c^`03001cfg?K00Icf`03001_nVoj00A_nP800<aoo`03001oogoo055oo`03001oogoo00Qo
o`00Dgoo00<007ooOol0ogoo17oo2P0037oo00<0001C00001P4H0P002RFI00<002Eh9GP02bEh0P00
43gG00<004hGCQL044hG00<005YFFUH04UYF00<005igGWL00Uig00<006:GHYL03f:G00<006:hH[P0
3f:h00<006/iJcT01F/i00<006/iJcT02F/i00<006mjKgX02fmj00<007>jLkX017>j00D007>kLk]c
^`0000Ucf`03001_nVoj00=_nP800<ioo`03001oogoo051oo`03001oogoo00Qoo`00Dgoo00<007oo
Ool0n7oo2`000Woo00<007ooOol04Woo00<0001C00001@4H00<0004H00002BFI00<002Eh9GP032Eh
0P003cgG00<004hGCQL044hG00<005YFFUH04UYF00D005igGWMNM`00019RU`03001R^6:h00mR^003
001[>F/i00E[>@03001[>F/i00Q[>@03001_NVmj00]_NP03001c^W>j00Ic^P03001c^`0000Ucf`03
001_nVoj00A_nP03001oogoo0<ioo`03001oogoo04moo`03001oogoo00Qoo`00Dgoo00<007ooOol0
kWoo2P003Goo00<007ooOol04goo00<0001C0000104H00@0004H0AP000TUV@03000UN2Eh00/UN003
000HmP0000hme`03001>5dhG011>5`03001JEUYF01=JEP03001NM`0001ARU`03001R^6:h00eR^003
001[>F/i00M[>@03001[>F/i00I[>@03001_NVmj00]_NP03001c^W>j00Qc^P8000Qcf`03001_nVoj
00A_nP03001oogoo0=1oo`03001oogoo04ioo`03001oogoo00Qoo`00Dgoo00<007ooOol0i7oo2P00
5goo00<007ooOol057oo00<0001C0000104H00@0004H0AP000PUV@03000UN2Eh00/UN004000HmQSf
000=?ML00`00CQM>5`0@CQL00`00FUIJEP0CFUH2000EHYL00`00H[QR^00<H[P00`00JcU[>@08JcT0
0`00JcU[>@06JcT00`00KgY_NP0:KgX00`00LkYc^P09LkX00`00LmX00006Lm/00`00KoY_nP04KoX2
003BOol00`00Oomoo`1>Ool00`00Oomoo`08Ool005=oo`03001oogoo0=Uoo`/0025oo`03001oogoo
01Aoo`040000D`1C00030AP01@000AP1604H00001bFI00<002Eh9GP02bEh00D001Sf6?HHmP0000`m
e`03001>5dhG011>5`03001JEUYF019JEP8001IRU`03001R^6:h00]R^003001[>F/i00U[>@03001[
>F/i00E[>@03001_NVmj00]_NP03001c^W>j00Qc^P04001cfW?JLmX20003Lm/00`00KoY_nP04KoX2
003DOol00`00Oomoo`1=Ool00`00Oomoo`08Ool0059oo`03001oogoo0=1oo`X002aoo`03001oogoo
01Eoo`040000D`1C00030AP01@000AP1604H00001RFI00<002Eh9GP032Eh00D001Sf6?HHmP0000`m
e`03001>5dhG00m>5`03001JEUYF015JEP03001RMP0001IRU`03001R^6:h00YR^003001[>F/i00][
>@03001[>F/i00=[>@03001_NVmj00]_NP03001c^W>j00Qc^P03001cfW?J00AcfP03001cf`0000I_
nP800=Ioo`03001oogoo04aoo`03001oogoo00Qoo`00DWoo00<007ooOol0aWoo2P00=Woo00<007oo
Ool05Woo00@0001C05<0008160030001604H00816003000UVBFI00@UV@03000UN2Eh00/UN003000H
mQSf008HmP03000mecgG00Tme`03001>5dhG00m>5`03001JEUYF011JEP04001RMV9f000FHYL00`00
H[QR^009H[P00`00JcU[>@0<JcT00`00JcU[>@02JcT00`00KgY_NP0;KgX00`00LkYc^P08LkX00`00
LmYcfP06LmX40003KoX2003HOol00`00Oomoo`1;Ool00`00Oomoo`08Ool0059oo`03001oogoo0;]o
o`/0041oo`03001oogoo01Moo`040000D`1C00020AP01@000AP1604H00001RFI00<002Eh9GP02bEh
00<001Sf6?H00aSf00<003gG?ML023gG00<004hGCQL03dhG00<005YFFUH03eYF00D0069fHWIRMP00
01MRU`03001R^6:h00QR^003001[>F/i00e[>@04001[>F/i000=KgX00`00LkYc^P08LkX00`00LmYc
fP07LmX01000KoU_nFoi1000fGoo00<007ooOol0Bgoo00<007ooOol027oo001BOol00`00Oomoo`2a
Ool:001;Ool00`00Oomoo`0HOol01P0005<0D`000AP000@16003000UVBFI00<UV@03000UN2Eh00/U
N003000HmQSf00@HmP03000mecgG00Lme`03001>5dhG011>5`03001JEUYF00eJEP03001RMV9f009R
MP03001RUf:G01ERU`03001R^6:h00MR^003001[>F/i00i[>@03001[>@0000e_NP03001c^W>j00Qc
^P03001cfW?J00McfP03001_nFoi00A_n@03001oogoo0=Uoo`03001oogoo04Yoo`03001oogoo00Qo
o`00DWoo00@007oo00000:Ioo`X005Eoo`03001oogoo01Uoo`030000D`1C008000D16003000UVBFI
008UV@03000UN2Eh00/UN003000HmQSf00DHmP8000Lme`03001>5dhG011>5`03001JEUYF00aJEP03
001RMV9f00ARMP03001RUf:G01ARU`03001R^6:h00IR^003001[>F/i011[>@03001_NVmj00]_NP03
001c^W>j00Qc^P03001cfW?J00McfP03001_nFoi00A_n@03001oogoo0=]oo`03001oogoo04Uoo`03
001oogoo00Qoo`00DWoo0P00WGoo2`00Ggoo00<007ooOol06Woo00<0001C05<00P001@4H00D002FI
9ITUV@0000hUN003000HmQSf00HHmP03000mecgG00@me`03001>5dhG011>5`03001JEUYF00]JEP03
001RMV9f00ERMP03001RUf:G01ARU`03001R^6:h00ER^003001[>F/i015[>@03001_NVmj00Y_NP03
001c^W>j00Uc^P03001cfW?J00IcfP03001_nFoi00A_n@03001oogoo0=aoo`03001oogoo04Uoo`03
001oogoo00Qoo`00DWoo00<007ooOol0TWoo2P00JWoo00<007ooOol06goo00@0001C05<000H16005
000UVBFI9IT0000=9GP00`006?HHmP076?H00`00?MLme`03?ML00`00CQM>5`0@CQL00`00FUIJEP0:
FUH00`00HWIRMP06HWH00`00HYMRU`0EHYL00`00H[QR^003H[P00`00JcU[>@0AJcT00`00KgX0000:
KgX00`00LkYc^P09LkX00`00LmYcfP06LmX00`00KoU_n@04KoT00`00Oomoo`3NOol00`00Oomoo`18
Ool00`00Oomoo`08Ool0059oo`03001oogoo08Qoo`X007Aoo`03001oogoo01aoo`040000D`1C0006
0AP010009ITUV@003BEh00<001Sf6?H021Sf00<003gG?ML00SgG00<004hGCQL044hG00<005YFFUH0
2EYF00<0069fHWH01f9f00<006:GHYL05F:G00<006:hH[P00f:h00<006/iJcT046/i00D006mjKgY_
NP0000U_NP03001c^W>j00Qc^P03001cfW?J00IcfP03001_nFoi00A_n@03001oogoo0>1oo`03001o
ogoo04Moo`03001oogoo00Qoo`00DWoo00<007ooOol0OGoo2`00OWoo00<007ooOol07Goo00<0001C
00001`4H00<002FI00003BEh00<001Sf6?H02ASf00D003gG?MLme`00019>5`03001JEUYF00MJEP80
00YRMP03001RUf:G01ERU`03001R^6:h009R^003001[>F/i011[>@03001_NVmj009_NP03001_NVmj
00I_NP03001c^W>j00Qc^P03001cfW?J00IcfP03001_nFoi00A_n@800>=oo`03001oogoo04Ioo`03
001oogoo00Qoo`00DWoo00<007ooOol0Lgoo2P00RGoo00<007ooOol07Woo00<0001C00001`4H0P00
3BEh00<001Sf6?H02QSf00D003gG?MLme`00015>5`03001JEUYF00IJEP03001RMV9f00YRMP03001R
Uf:G01ERU`05001R^6:hH[P0000BJcT00`00KgY_NP04KgX00`00KgY_NP04KgX00`00LkYc^P08LkX0
0`00LmYcfP07LmX00`00KoU_n@03KoT2003TOol00`00Oomoo`16Ool00`00Oomoo`08Ool0059oo`03
001oogoo06Uoo`X009=oo`03001oogoo01moo`030000D`0000L1608000dUN003000HmQSf00XHmP04
000mecgG000ACQL00`00FUIJEP05FUH00`00HWIRMP0;HWH00`00HYMRU`0EHYL01000H[QR^0004V/i
00<006mjKgX01Vmj00<006mjKgX00Vmj00<007>jLkX027>j00<007?JLmX01g?J00<006oiKoT00foi
0P00iWoo00<007ooOol0AGoo00<007ooOol027oo001BOol00`00Oomoo`1NOol;002MOol00`00Oomo
o`0POol300070AP00`009GPUN00;9GP00`006?HHmP0;6?H00`00?ML0000ACQL00`00FUIJEP04FUH0
0`00HWIRMP0=HWH00`00HYMRU`0EHYL2000CJcT00`00KgY_NP06KgX01@00KgY_NVmj00002W>j00<0
07?JLmX01g?J00<006oiKoT00foi0P00j7oo00<007ooOol0A7oo00<007ooOol027oo001BOol00`00
Oomoo`1DOol:002XOol00`00Oomoo`0QOol300060AP00`009GPUN00;9GP00`006?HHmP0<6?H2000A
CQL00`00FUIJEP03FUH00`00HWIRMP0>HWH00`00HYMRU`0EHYL00`00JcU[>@0AJcT00`00KgY_NP08
KgX00`00KgX0000:LkX00`00LmYcfP07LmX00`00KoU_n@03KoT2003ZOol00`00Oomoo`14Ool00`00
Oomoo`07Ool003Uoo`X000moo`03001oogoo04Yoo`X00;9oo`03001oogoo029oo`<000H16003000U
N2Eh00XUN003000HmQSf00dHmP<0011>5`05001JEUYFFUH0000AHWH00`00HYMRU`0EHYL00`00JcU[
>@0@JcT00`00KgY_NP0:KgX00`00LkYc^P09LkX00`00LmYcfP06LmX00`00KoU_n@03KoT2003[Ool0
0`00Oomoo`14Ool00`00Oomoo`07Ool003Uoo`X000moo`03001oogoo03moo`/00;aoo`03001oogoo
02=oo`<000D1608000/UN003000HmQSf00dHmP030019mTWf00D000]>5`04001JEUYF000BHWH00`00
HYMRU`0DHYL00`00LeT0000@JcT00`00KgY_NP0;KgX20009LkX00`00LmYcfP06LmX00`00KoU_n@04
KoT00`00Oomoo`3[Ool00`00Oomoo`13Ool00`00Oomoo`07Ool003eoo`80019oo`03001oogoo03Io
o`X00<Moo`03001oogoo02Aoo`030000D`0000D1608000/UN003000HmQSf00`HmP030019mTWf00E9
mPD000I>5`03001JEP0001=RMP03001RUf:G01=RU`04001cFG=I000?JcT00`00KgY_NP0;KgX01000
LkYc^P001g>j00<007?JLmX01W?J00<006oiKoT016oi00<007ooOol0kGoo00<007ooOol0@Woo00<0
07ooOol01goo000mOol2000BOol00`00Oomoo`0/Ool:003AOol00`00Oomoo`0UOol00`0005<00004
0AP00`000?L0000:9GP00`006?HHmP0<6?H00`00BOI9mP0:BOH500000dhG0000000DHWH00`00HYMR
U`0CHYL01000LeUcF@003V/i00<006mjKgX02fmj00<007>jLkX00W>j00<007>jLkX00g>j00<007?J
LmX01W?J00<006oiKoT016oi00<007ooOol0kWoo00<007ooOol0@Woo00<007ooOol01goo000mOol2
000BOol6000NOol;003JOol00`00Oomoo`0WOol00`0005<000030AP010000?L0m`002BEh00<001Sf
6?H031Sf00<004WfBOH03dWf0P005F9f00<006:GHYL04V:G00<007=ILeT00W=I00<006/iJcT02f/i
00<006mjKgX02Vmj00<007>jLkX017>j00D007>jLkYc^P0000UcfP03001_nFoi00=_n@03001oogoo
0?1oo`03001oogoo045oo`03001oogoo00Moo`00?Goo0P004Woo00<007ooOol05goo2P00iGoo00<0
07ooOol09goo00<0001C0000104H00<0003g00002BEh00<001Sf6?H03ASf00<004WfBOH03dWf00<0
069fHWH0569f00<006:GHYL046:G00<007=ILeT00g=I00<006/iJcT02V/i00<006mjKgX02Vmj00<0
07>jLkX01W>j00<007>j00002G?J00<006oiKoT00foi0P00lgoo00<007ooOol0@7oo00<007ooOol0
1goo000mOol2000BOol00`00Oomoo`0=Ool:003_Ool00`00Oomoo`0XOol00`0005<000030AP01000
0?L0m`0022Eh00<001Sf6?H03ASf00<004WfBOH03dWf00<0069fHWH0569f00<006:GHYL046:G00<0
07=ILeT00g=I00<006/iJcT02F/i00<006mjKgX02Vmj00<007>jLkX027>j0P0027?J00<006oiKoT0
0foi0P00mGoo00<007ooOol0?goo00<007ooOol01goo000mOol2000BOol00`00Oomoo`02Ool;003i
Ool00`00Oomoo`0YOol00`0005<000030AP010000?L0m`001bEh00<001Sf6?H03ASf00<004WfBOH0
3dWf00<0069fHWH0569f00<006:GHYL03f:G00<007=ILeT01G=I00<006/iJcT01f/i00<006mjKgX0
2fmj00<007>jLkX027>j00<007?J00001W?J00<006oiKoT00foi0P00mWoo00<007ooOol0?goo00<0
07ooOol01goo000mOol2000BOol5003oOol5Ool00`00Oomoo`0ZOol00`0005<000020AP01@000?L0
m`3g00001bEh00<001Sf6?H031Sf00<004WfBOH03dWf00<0069fHWH0569f00<006:GHYL03f:G00<0
07=ILeT01G=I00<006/iJcT01V/i00<006mjKgX02fmj00<007>jLkX027>j00@007?JLmYcfP8000=c
fP03001_nFoi00=_n@800?Qoo`03001oogoo03ioo`03001oogoo00Moo`00?Goo0P0057oo0P00ogoo
1Woo00<007ooOol0:goo00<0001C00000P4H00D0003g0?L0m`0000HUN003000HmQSf00`HmP030019
mTWf00m9mP03001RMV9f01ARMP03001RUf:G00iRU`03001cFG=I00McF@03001[>F/i00A[>@03001_
NVmj00]_NP03001c^W>j00Qc^P03001cfW?J00AcfP03001cfP0000E_n@800?Yoo`03001oogoo03eo
o`03001oogoo00Moo`00?Goo0P005Woo0P00ogoo17oo00<007ooOol0;7oo00D0001C0001600000<0
m`03000UN2Eh00@UN003000HmQSf00`HmP030019mTWf0119mP03001RMV9f01=RMP03001RUf:G00eR
U`03001cFG=I00QcF@03001[>F/i00A[>@03001_NVmj00Y_NP03001c^W>j00Qc^P03001cfW?J00Ic
fPP00?]oo`03001oogoo03eoo`03001oogoo00Moo`00?Goo0P0067oo0P00ogoo0Woo00<007ooOol0
;Goo00@0001C000000@0m`03000UN2Eh00<UN003000HmQSf00`HmP030019mTWf0119mP03001RMV9f
01=RMP03001RUf:G00eRU`03001cFG=I00QcF@03001[>F/i00=[>@03001_NVmj00Y_NP03001c^W>j
00Qc^P03001cfW?J00McfP03001cnG?i00=cn@03001oogoo0?]oo`03001oogoo03aoo`03001oogoo
00Moo`00?Goo0P006Woo0P00ogoo00<007ooOol0;Woo00@0001C000000@0m`03000UN2Eh008UN003
000HmQSf00`HmP030019mTWf0119mP03001RMV9f01=RMP03001RUf:G00aRU`03001cFG=I00YcF@05
001[>F/iJcT0000<KgX00`00LkYc^P08LkX00`00LmYcfP07LmX00`00LoUcn@03LoT2003nOol00`00
Oomoo`0kOol00`00Oomoo`07Ool003eoo`8001aoo`800?eoo`03001oogoo02moo`030000D`0000D0
m`03000UN2Eh008UN003000HmQSf00`HmP030019mTWf00m9mP03001RMV9f01ARMP03001RUf:G00YR
U`03001cFG=I00]cF@04001[>F/i000=KgX00`00LkYc^P08LkX00`00LmYcfP06LmX00`00LoUcn@03
LoT2003oOol1Ool00`00Oomoo`0jOol00`00Oomoo`07Ool003eoo`8001ioo`8000=oo`03001oogoo
0?Eoo`03001oogoo031oo`030000D`0000D0m`05000UN2Eh9GP0000>6?H00`00BOI9mP0?BOH00`00
HWIRMP0DHWH00`00HYMRU`0:HYL00`00LeUcF@0;LeT00`00JcT0000=KgX00`00LkYc^P08LkX00`00
LmYcfP06LmX00`00LoUcn@03LoT2003oOol2Ool00`00Oomoo`0jOol00`00Oomoo`07Ool003Uoo`<0
0003Ool00000021oo`800003Ool007oo0?Ioo`03001oogoo035oo`8000H0m`04000UN2Eh000>6?H0
0`00BOI9mP0?BOH00`00HWIRMP0DHWH00`00HYMRU`09HYL00`00LeUcF@0=LeT00`00KgY_NP0;KgX0
0`00LkYc^P08LkX00`00LmYcfP06LmX00`00LoUcn@03LoT2003oOol4Ool00`00Oomoo`0iOol00`00
Oomoo`07Ool003Uoo`H0029oo`800?Moo`03001oogoo039oo`8000D0m`04000UN2Eh000>6?H00`00
BOI9mP0?BOH00`00HWIRMP0DHWH00`00HYMRU`08HYL00`00LeUcF@0>LeT00`00KgY_NP0:KgX00`00
LkYc^P08LkX00`00LmYcfP06LmX00`00LoUcn@03LoT2003oOol6Ool00`00Oomoo`0hOol00`00Oomo
o`07Ool003aoo`<002=oo`<00?Eoo`03001oogoo03=oo`8000D0m`03000UN00000hHmP030019mTWf
00m9mP03001RMV9f01ARMP03001RUf:G00QRU`03001cFG=I00ecF@03001cVP0000Y_NP03001c^W>j
00Qc^P03001cfW?J00McfP03001cnG?i00=cn@03001oogoo0?moo`Ioo`03001oogoo03Moo`03001o
ogoo00Moo`00IGoo0P00lgoo00<007ooOol0=7oo0P001@3g00<002Eh00003ASf00<004WfBOH03dWf
00<0069fHWH0569f00<006:GHYL01f:G00<007=ILeT03G=I00D007>JLiYcVP0000U_NP03001c^W>j
00Mc^P03001cfW?J00McfP03001cnG?i00=cn@03001oogoo0?moo`Moo`03001oogoo03Moo`03001o
ogoo00Moo`00Igoo0P00lGoo00<007ooOol0=Goo0P001@3g0P003ASf00<004WfBOH044Wf00<0069f
HWH04f9f00<006:GHYL01V:G00<007=ILeT03G=I00<007>JLiX00g>J00<006mjKgX01Fmj00<007>j
LkX027>j00<007?JLmX01W?J00<007?iLoT00g?i00<007ooOol0ogoo2Goo00<007ooOol0=goo00<0
07ooOol01Woo001YOol2003_Ool00`00Oomoo`0fOol200050?L00`006?HHmP0;6?H00`00BOI9mP0@
BOH00`00HWIRMP0DHWH00`00HYMRU`05HYL00`00LeUcF@0=LeT00`00LiYcVP04LiX00`00KgY_NP03
KgX00`00LkYc^P08LkX00`00LmYcfP06LmX00`00LoUcn@03LoT2003oOol<Ool00`00Oomoo`0fOol0
0`00Oomoo`06Ool006]oo`800>eoo`03001oogoo03Moo`8000@0m`03000HmQSf00/HmP030019mTWf
0119mP03001RMV9f01ARMP03001RUf:G00ARU`03001cFG=I00ecF@03001cVW>J00IcVP05001_NVmj
KgX0000:LkX00`00LmYcfP06LmX00`00LoUcn@03LoT2003oOol=Ool00`00Oomoo`0fOol00`00Oomo
o`06Ool006eoo`8000Aoo`03001oogoo0>Aoo`03001oogoo03Qoo`030000m`3g00<0m`03000HmQSf
00/HmP030019mTWf00m9mP03001RMV9f01ARMP03001RUf:G00=RU`03001cFG=I00ecF@03001cVW>J
00QcVP03001_NP0000Yc^P03001cfW?J00IcfP03001cnG?i00=cn@800?moo`moo`03001oogoo03Eo
o`03001oogoo00Ioo`00Kgoo0P000Woo00<007ooOol0i7oo00<007ooOol0>Goo00<0003g0?L00P3g
00<001Sf6?H02aSf00<004WfBOH03dWf00<0069fHWH0569f00<006:GHYL00f:G00<007=ILeT03G=I
00<007>JLiX02G>J00<007>jLkX027>j00<007?JLmX01g?J00<007?iLoT00g?i00<007ooOol0ogoo
3goo00<007ooOol0=7oo00<007ooOol01Woo001aOol3003VOol00`00Oomoo`0iOol200040?L00`00
6?HHmP0:6?H00`00BOI9mP0?BOH00`00HWIRMP0DHWH00`00HYMRU`02HYL00`00LeUcF@0=LeT00`00
LiYcVP0:LiX20009LkX00`00LmYcfP06LmX00`00LoUcn@03LoT00`00Oomoo`3oOolAOol00`00Oomo
o`0cOol00`00Oomoo`06Ool007=oo`03001oogoo0>Aoo`03001oogoo03Yoo`8000<0m`03000HmQSf
00XHmP030019mTWf00m9mP03001RMV9f01ARMP03001RUf:G009RU`03001cFG=I00acF@03001cVW>J
00YcVP04001c^W>j0007LkX00`00LmYcfP06LmX00`00LoUcn@03LoT00`00Oomoo`3oOolBOol00`00
Oomoo`0cOol00`00Oomoo`06Ool007=oo`<00>Aoo`03001oogoo03]oo`8000<0m`03000HmQSf00TH
mP030019mTWf00m9mP03001RMV9f01ARMP05001RUf:GHYL0000>LeT00`00LiYcVP0:LiX00`00LkYc
^P02LkX00`00LkYc^P03LkX00`00LmYcfP06LmX00`00LoUcn@03LoT00`00Oomoo`3oOolDOol00`00
Oomoo`0bOol00`00Oomoo`06Ool004Eoo`L000Yoo`@001aoo`800>9oo`03001oogoo03aoo`800080
m`03000HmQSf00THmP030019mTWf00m9mP03001RMV9f01ERMP03001RU`0000mcF@03001cVW>J00Uc
VP03001c^W>j00Ac^P05001c^W>jLkX00008LmX00`00LoUcn@03LoT2003oOolGOol00`00Oomoo`0a
Ool00`00Oomoo`06Ool004Eoo`L000Qoo`P001aoo`800>1oo`03001oogoo03eoo`800080m`03000H
mQSf00PHmP030019mTWf0119mP03001RMV9f01ARMP03001RU`0000icF@03001cVW>J00YcVP03001c
^W>j00Ec^P03001c^P0000UcfP03001cnG?i00=cn@03001oogoo0?mooaMoo`03001oogoo031oo`03
001oogoo00Ioo`00B7oo0P002Woo0P0017oo0P007Woo0P00gWoo00<007ooOol0?Woo00@0003g0?L0
00XHmP030019mTWf0119mP03001RMV9f01ARMP8000icF@03001cVW>J00YcVP03001c^W>j00Mc^P80
00QcfP03001cnG?i00=cn@03001oogoo0?mooaQoo`03001oogoo031oo`03001oogoo00Ioo`00B7oo
0P002Goo0P001Woo0P007goo0P00g7oo00<007ooOol0?goo00@0003g000000XHmP030019mTWf00m9
mP03001RMV9f01ARMP03001cFG=I00acF@03001cVW>J00YcVP03001c^W>j00Qc^P03001g^P0000Ic
fP03001cnG?i00=cn@800?mooa]oo`03001oogoo02moo`03001oogoo00Ioo`00B7oo0P002Goo0P00
1Woo0P008Goo0P000goo00<007ooOol0e7oo00<007ooOol0@7oo00<0003g00002QSf00<004WfBOH0
3dWf00<0069fHWH0569f00<007=ILeT037=I00<007>JLiX02W>J00<007>jLkX01g>j00@007NjMkYg
^P8000=cfP03001cnG?i00=cn@800?mooaeoo`03001oogoo02ioo`03001oogoo00Ioo`00@7oo3000
1Woo0P0027oo0P008Woo0P0000=oo`00Ool0eGoo00<007ooOol0@Goo0`002ASf00<004WfBOH03dWf
00<0069fHWH04f9f00<007OI000037=I00<007>JLiX02W>J00<007>jLkX01g>j00<007NjMkX017Nj
00<007?J00001G?i00<007?f0000ogoo7Goo00<007ooOol0;Woo00<007ooOol01Woo0010Ool<0006
Ool20008Ool2000TOol2003FOol00`00Oomoo`12Ool200096?H00`00BOI9mP0?BOH00`00HWIRMP0C
HWH01000MmUgf@002W=I00<007>JLiX02W>J00<007>jLkX01g>j00<007NjMkX01WNj1`0000=cmP00
Ool0ogoo7Woo00<007ooOol0;Goo00<007ooOol01Woo0010Ool20006Ool200000goo001oo`05Ool2
0008Ool2000UOol3003DOol00`00Oomoo`12Ool300086?H00`00BOI9mP0?BOH00`00HWIRMP0BHWH0
1@00MmUgfGOI00002G=I00<007>JLiX02W>J00<007>jLkX027>j00<007NjMkX01WNj00<007OIMmT0
0gOI0P00ogoo8Goo00<007ooOol0;7oo00<007ooOol01Woo0011Ool20005Ool20008Ool20008Ool2
000XOol2003BOol00`00Oomoo`13Ool200086?H00`00BOI9mP0?BOH00`00HWIRMP0BHWH00`00MmUg
f@02MmT00`00LeUcF@06LeT00`00LiYcVP0:LiX00`00LkYc^P07LkX00`00MkYg^P06MkX00`00MmUg
f@03MmT00`00LoH0003oOolROol00`00Oomoo`0[Ool00`00Oomoo`06Ool0045oo`<000Aoo`8000Qo
o`8000Qoo`8002Yoo`800=1oo`03001oogoo04Aoo`8000LHmP030019mTWf00m9mP03001RMV9f015R
MP03001gfGOI00Agf@03001cFG=I00AcF@03001cVW>J00YcVP03001c^W>j00Mc^P03001g^WNj00Ig
^P03001gfGOI00=gf@03001cmP000?moob=oo`03001oogoo02]oo`03001oogoo00Ioo`00@Woo0P00
17oo0P0027oo0P0027oo0P00;7oo0P00cWoo00<007ooOol0AGoo00<001Sf6?H01ASf00<004WfBOH0
44Wf00<0069fHWH0469f00<007OIMmT017OI00<007=ILeT00g=I00<007>JLiX02W>J00<007>jLkX0
1g>j00<007NjMkX01WNj00<007OIMmT017OI00<007?f0000ogoo97oo00<007ooOol0:Woo00<007oo
Ool01Woo0013Ool20003Ool20008Ool20008Ool2000^Ool20005Ool00`00Oomoo`34Ool00`00Oomo
o`16Ool00`006?HHmP056?H00`00BOI9mP0?BOH00`00HWIRMP0?HWH00`00MmUgf@06MmT00`00LeUc
F@02LeT00`00LiYcVP09LiX00`00LkYc^P08LkX00`00MkYg^P06MkX00`00MmUgf@03MmT00`00LoH0
003oOolVOol00`00Oomoo`0ZOol00`00Oomoo`05Ool004=oo`<0009oo`8000Qoo`8000Qoo`80031o
o`8000=oo`03001oogoo0<Aoo`03001oogoo04Ioo`03000HmQSf00DHmP030019mTWf00m9mP03001R
MV9f00mRMP03001gfGOI00Igf@05001cFG=ILeT0000<LiX00`00LkYc^P07LkX00`00MkYg^P06MkX0
0`00MmUgf@03MmT00`00LoH0003oOolXOol00`00Oomoo`0YOol00`00Oomoo`05Ool004Aoo`80009o
o`8000Uoo`8000Ioo`8003=oo`800003Ool007oo0<Eoo`03001oogoo04Moo`03000HmQSf00@HmP03
0019mTWf00m9mP03001RMV9f00iRMP03001gfGOI00Qgf@03001cF@0000acVP03001c^W>j00Mc^P03
001g^WNj00Ig^P03001gfGOI00Agf@03001cmP000?moobQoo`03001oogoo02Uoo`03001oogoo00Eo
o`00AGoo0P0000=oo`0000002Goo0P001Woo0P00=Goo0P00aWoo00<007ooOol0Agoo00<001Sf6?H0
11Sf00<004WfBOH03dWf00<0069fHWH03V9f00<007OIMmT02GOI00<007>JLiX02W>J00<007>jLkX0
1g>j00<007NjMkX01gNj00<007OIMmT00gOI00<007?f0000ogoo:Woo00<007ooOol0:7oo00<007oo
Ool01Goo0016Ool4000:Ool20004Ool2000gOol30034Ool00`00Oomoo`18Ool00`006?HHmP036?H0
0`00BOI9mP0?BOH00`00HWIRMP0=HWH00`00MmUgf@0:MmT00`00LiYcVP09LiX00`00LkYc^P07LkX0
0`00MkYg^P07MkX00`00MmUgf@03MmT01000LoIcmP00ogoo:goo00<007ooOol09goo00<007ooOol0
1Goo0016Ool4000:Ool8000jOol20031Ool00`00Oomoo`19Ool00`006?HHmP036?H00`00BOI9mP0?
BOH00`00HWIRMP0=HWH00`00MmUgf@09MmT00`00MkX0000:LiX00`00LkYc^P07LkX00`00MkYg^P06
MkX00`00MmUgf@04MmT00`00LoH0003oOol/Ool00`00Oomoo`0WOol00`00Oomoo`05Ool004Moo`<0
00aoo`@003ioo`8000Uoo`03001oogoo0;=oo`03001oogoo04Yoo`03000HmQSf008HmP030019mTWf
00m9mP03001RMV9f00aRMP03001gfGOI00Ugf@05001g^WNjMkX00008LiX00`00LkYc^P07LkX00`00
MkYg^P06MkX00`00MmUgf@04MmT00`00LoH0003oOol^Ool00`00Oomoo`0VOol00`00Oomoo`05Ool0
09Yoo`8000Moo`03001oogoo0;=oo`03001oogoo04Yoo`03000HmQSf008HmP030019mTWf00m9mP03
001RMV9f00aRMP03001gfGOI00Ugf@03001g^WNj009g^P03001cVW>J00AcVP03001c^W>j00Mc^P03
001g^WNj00Mg^P03001gfGOI00=gf@04001cmW?f003oOol_Ool00`00Oomoo`0UOol00`00Oomoo`05
Ool009aoo`8000Eoo`03001oogoo0;=oo`03001oogoo04]oo`05000HmQSf6?H0000BBOH00`00HWIR
MP0:HWH00`00MmUgf@09MmT00`00MkYg^P04MkX00`00LiYcVP03LiX00`00LkYc^P06LkX00`00MkYg
^P07MkX00`00MmUgf@04MmT00`00LoH0003oOolaOol00`00Oomoo`0TOol00`00Oomoo`05Ool009io
o`80009oo`03001oogoo0;Aoo`03001oogoo04]oo`03000HmQSf008HmP030019mTWf00m9mP03001R
MV9f00YRMP03001gfGOI00Qgf@03001g^WNj00Ig^P05001cVW>JLiX00009LkX00`00MkYg^P06MkX0
0`00MmUgf@04MmT01000LoIcmP00ogoo<Goo00<007ooOol097oo00<007ooOol01Goo002POol3002f
Ool00`00Oomoo`1<Ool01@006?HHmQSf00004DWf00<0069fHWH02F9f00<007OIMmT02GOI00<007Nj
MkX01gNj00<007>J00002G>j00<007NjMkX01gNj00<007OIMmT00gOI00@007?fLoH00?mooc=oo`03
001oogoo02=oo`03001oogoo00Eoo`00XWoo0P00]Goo00<007ooOol0C7oo00D001Sf6?HHmP000159
mP03001RMV9f00URMP03001gfGOI00Qgf@03001g^WNj00Ug^P8000Qc^P03001g^WNj00Mg^P03001g
fGOI00Agf@03001cmP000?moocEoo`03001oogoo029oo`03001oogoo00Eoo`00Y7oo0P00/goo00<0
07ooOol0CGoo00@001Sf6?H00159mP03001RMV9f00QRMP03001gfGOI00Qgf@03001g^WNj00Yg^P03
001g^P0000Ic^P03001g^WNj00Mg^P03001gfGOI00Agf@04001cmW?f003oOoleOol00`00Oomoo`0R
Ool00`00Oomoo`05Ool00:Ioo`800;5oo`03001oogoo04eoo`04000HmQSf000ABOH00`00HWIRMP08
HWH00`00MmUgf@08MmT00`00MkYg^P09MkX01@00MkYg^WNj00001G>j00<007NjMkX01WNj00<007OI
MmT017OI00@007?fLoH00?moocMoo`03001oogoo025oo`03001oogoo00Eoo`00Z7oo0P00[goo00<0
07ooOol0CWoo00<001Sf00004DWf00<0069fHWH01f9f00<007OIMmT027OI00<007NjMkX02GNj00<0
07NjMkX00gNj00D007>jLkYc^P0000Ug^P03001gfGOI00Agf@04001cmW?f003oOolhOol00`00Oomo
o`0POol00`00Oomoo`05Ool00:Yoo`800:eoo`03001oogoo04ioo`03000HmP000159mP03001RMV9f
00MRMP03001gfGOI00Mgf@03001g^WNj00Ug^P03001g^WNj00Eg^P03001c^P0000Ug^P03001gfGOI
00Agf@04001cmW?f003oOoljOol00`00Oomoo`0OOol00`00Oomoo`05Ool00:aoo`8000=oo`03001o
ogoo0:Eoo`03001oogoo04moo`800159mP03001RMV9f00IRMP03001gfGOI00Qgf@03001g^WNj00Ug
^P03001g^WNj00Ig^P8000Qg^P03001gfGOI00Agf@04001cmW?f003oOolkOol00`00Oomoo`0OOol0
0`00Oomoo`05Ool00:ioo`800003Ool007oo0:Ioo`03001oogoo04moo`03000HmP000159mP03001R
MV9f00ERMP03001gfGOI00Mgf@03001g^WNj00Ug^P03001g^WNj00Mg^P04001g^@000006MkX00`00
MmUgf@04MmT01000LoIcmP00ogoo?7oo00<007ooOol07Woo00<007ooOol01Goo002`Ool2002WOol0
0`00Oomoo`1@Ool2000ABOH00`00HWIRMP04HWH00`00MmUgf@07MmT00`00MkYg^P09MkX00`00MkYg
^P07MkX00`00MkUg^@02MkT00`00MkYg^P02MkX00`00MmUgf@04MmT01000LoH00000ogoo?Woo00<0
07ooOol07Goo00<007ooOol01Goo002aOol3002UOol00`00Oomoo`1@Ool2000ABOH00`00HWIRMP04
HWH00`00MmUgf@07MmT00`00MkYg^P09MkX00`00MkYg^P06MkX00`00MkUg^@04MkT200000gNj001g
f@05MmT01@00LoH007]g0000ogoo?goo00<007ooOol07Goo00<007ooOol017oo002dOol00`00Oomo
o`2ROol00`00Oomoo`1AOol2000@BOH00`00HWIRMP03HWH00`00MmUgf@07MmT00`00MkYg^P09MkX0
0`00MkYg^P06MkX00`00MkUg^@07MkT30005MmT200000g]g001oo`3oOoloOol00`00Oomoo`0MOol0
0`00Oomoo`04Ool00;Eoo`800:9oo`03001oogoo05=oo`8000i9mP03001RMV9f00=RMP03001gfGOI
00Mgf@03001g^WNj00Qg^P03001g^WNj00Mg^P03001g^GNi00Mg^@03001g^GNi00<00003MmT007]g
009kM`03001oogoo0?moocmoo`03001oogoo01aoo`03001oogoo00Aoo`00]goo0P00X7oo00<007oo
Ool0E7oo0`0034Wf00<0069fHWH00V9f00<007OIMmT01gOI00<007NjMkX027Nj00<007NjMkX01gNj
00<007NiMkT01gNi00<007NiMkT017Ni00D007]gNgMkM`000?mood=oo`03001oogoo01]oo`03001o
ogoo00Aoo`00^Goo0P001Goo00<007ooOol0UWoo00<007ooOol0EWoo0`002TWf00<0069fHWH00V9f
00<007OIMmT01WOI00<007NjMkX02GNj00<007NjMkX01WNj00<007NiMkT01gNi00<007NiMkT01GNi
00D007]gNgMkM`000?mood=oo`03001oogoo01]oo`03001oogoo00Aoo`00^goo0P000goo00<007oo
Ool0UWoo00<007ooOol0Egoo00@0008K000000Q9mP05001RMV9fHWH00009MmT00`00MkYg^P08MkX0
0`00MkYg^P06MkX00`00MkUg^@07MkT00`00MkUg^@05MkT01@00NgMkMg]g0000ogooAGoo00<007oo
Ool06Woo00<007ooOol017oo002mOol200000goo001oo`2GOol00`00Oomoo`1HOol200000`8K0019
mP06BOH01@00HWIRMV9f000027OI00<007NjMkX027Nj00<007NjMkX01gNj00<007NiMkT01gNi00<0
07NiMkT017Ni00<007]gNgL00W]g00<007ooOol0ogooA7oo00<007ooOol06Goo00<007ooOol017oo
002oOol2002HOol00`00Oomoo`1JOol40006BOH00`00HWH00008MmT00`00MkYg^P08MkX00`00MkYg
^P07MkX00`00MkUg^@07MkT00`00MkUg^@05MkT00`00NgMkM`02NgL00`00Oomoo`3oOom5Ool00`00
Oomoo`0HOol00`00Oomoo`04Ool00<5oo`8009Ioo`03001oogoo05]oo`03000>?@00008000A9mP03
001RMP0000Qgf@03001g^WNj00Qg^P03001g^WNj00Ig^P03001g^GNi00Mg^@03001g^GNi00Eg^@03
001kMg]g009kM`03001oogoo0?moodIoo`03001oogoo01Qoo`03001oogoo00Aoo`00`goo0P00U7oo
00<007ooOol0G7oo00@000hm3Sd>?@800099mP8000Qgf@03001g^WNj00Qg^P03001g^WNj00Ig^P03
001g^GNi00Qg^@03001g^GNi00Ag^@03001kMg]g00=kM`03001oogoo0?moodMoo`03001oogoo01Mo
o`03001oogoo00Aoo`00aGoo0P00TWoo00<007ooOol0GGoo00<000hm3Sd00Phm10001gOI00<007Nj
MkX027Nj00<007NjMkX01WNj00<007NiMkT027Ni00<007NiMkT01GNi00<007]gNgL00W]g00<007oo
Ool0ogooBGoo00<007ooOol05Woo00<007ooOol017oo002EOol5000>Ool4000KOol20005Ool00`00
Oomoo`28Ool00`00Oomoo`1NOol00`003Sd>?@033Sd30006MmT00`00MkYg^P07MkX00`00MkYg^P07
MkX00`00MkUg^@07MkT00`00MkUg^@05MkT00`00NgMkM`03NgL00`00Oomoo`3oOom:Ool00`00Oomo
o`0EOol00`00Oomoo`04Ool009=oo`T000Yoo`P001]oo`8000=oo`03001oogoo08Qoo`03001oogoo
05moo`<000D>?@<0009gf@03001g^WNj00Qg^P03001g^WNj00Ig^P03001g^GNi00Mg^@03001g^GNi
00Eg^@03001kMg]g00=kM`03001oogoo0?mood]oo`03001oogoo01Eoo`03001oogoo00Aoo`00TWoo
100017oo0`002Goo0P0017oo0P007Goo0P0000=oo`00Ool0RGoo00<007ooOol0HGoo10001@hm0`00
2GNj00<007NjMkX01WNj00<007NiMkT027Ni00<007NiMkT01GNi00<007]gNgL00g]g00<007ooOol0
ogooC7oo00<007ooOol057oo00<007ooOol017oo002BOol20007Ool30007Ool20006Ool2000NOol2
002:Ool00`00Oomoo`1ROol2000010Hl000000001@hm00<007NjMkX01GNj00<007NjMkX01WNj00<0
07NiMkT027Ni00<007NiMkT01GNi00<007]gNgL00g]g00<007ooOol0ogooCWoo00<007ooOol04goo
00<007ooOol017oo002LOol20007Ool20006Ool2000POol20028Ool00`00Oomoo`1TOol010001S`6
?0Hl0`000`hm0P001GNj00<007NjMkX01WNj00<007NiMkT01gNi00<007NiMkT01GNi00<007]gNgL0
17]g00<007ooOol0ogooCWoo00<007ooOol04goo00<007ooOol017oo002LOol20006Ool20008Ool2
000QOol20026Ool00`00Oomoo`1UOol00`001S`6?0031S`300023Sd01@00MkYg^WNj000027Nj00<0
07NiMkT01gNi00<007NiMkT01WNi00<007]gNgL00g]g00<007ooOol0ogooD7oo00<007ooOol04Woo
00<007ooOol017oo002LOol20006Ool20008Ool2000SOol20024Ool00`00Oomoo`1VOol300051S`4
00000gNj001g^P07MkX00`00MkUg^@08MkT00`00MkUg^@05MkT00`00NgMkM`04NgL00`00Oomoo`3o
OomAOol00`00Oomoo`0AOol00`00Oomoo`04Ool009]oo`<000Ioo`8000Qoo`8002Eoo`8000Eoo`03
001oogoo07Yoo`03001oogoo06Qoo`@000D6?0<000Mg^P03001g^GNi00Qg^@03001g^GNi00Eg^@03
001kMg]g00AkM`03001oogoo0?mooe=oo`03001oogoo011oo`03001oogoo00Aoo`00VWoo0`001goo
0P0027oo0P009goo0P000goo00<007ooOol0NWoo00<007ooOol0JGoo0P0000<1nP0000000P0010Hl
00<007NjMkX017Nj00<007NiMkT01gNi00<007NiMkT01GNi00<007]gNgL01G]g00<007ooOol0ogoo
Dgoo00<007ooOol04Goo00<007ooOol00goo002GOol50008Ool20008Ool2000YOol200000goo001o
o`1kOol00`00Oomoo`1[Ool00`000OX1nP020OX400000`Hl00000003MkX00`00MkUg^@07MkT00`00
MkUg^@06MkT00`00NgMkM`05NgL00`00Oomoo`3oOomDOol00`00Oomoo`0@Ool00`00Oomoo`03Ool0
09Moo`@000Uoo`8000Qoo`8002]oo`8007aoo`03001oogoo06aoo`<000D1nP@00003MkX007Ni00Ug
^@03001g^GNi00Eg^@03001kMg]g00EkM`03001oogoo0?mooeIoo`03001oogoo00moo`03001oogoo
00=oo`00VWoo0P0027oo0P0027oo0P00;Goo0P00NWoo00<007ooOol0KWoo10001@7j0`002GNi00<0
07NiMkT01GNi00<007]gNgL01W]g00<007ooOol0ogooEgoo00<007ooOol03Woo00<007ooOol00goo
002KOol20007Ool20008Ool2000_Ool20008Ool00`00Oomoo`1]Ool00`00Oomoo`1aOol400050OX0
0`00MkUg^@05MkT00`00MkUg^@06MkT00`00NgMkM`05NgL00`00Oomoo`3oOomHOol00`00Oomoo`0>
Ool00`00Oomoo`03Ool009]oo`8000Qoo`8000Ioo`80039oo`8000Ioo`03001oogoo06eoo`03001o
ogoo07=oo`D000<1nP8000Eg^@03001g^GNi00Eg^@03001kMg]g00IkM`03001oogoo0?mooeUoo`03
001oogoo00eoo`03001oogoo00=oo`00Tgoo0P001Woo0P0027oo0P001Woo0P00=7oo0P0017oo00<0
07ooOol0KGoo00<007ooOol0MGoo1P000P7j00D007NiMkUg^@0000Mg^@03001kMg]g00IkM`03001o
ogoo0?mooe]oo`03001oogoo00aoo`03001oogoo00=oo`00Tgoo0`0017oo0`002Goo0P0017oo0P00
=goo0P000Woo00<007ooOol0K7oo00<007ooOol0N7oo0`0000<1U`0000000P0000=g^@00MkT01gNi
00<007]gNgL01W]g00<007ooOol0ogooFgoo00<007ooOol037oo00<007ooOol00goo002DOol8000:
Ool8000iOol3001^Ool00`00Oomoo`1jOol40000106G000000001gNi00<007]gNgL01W]g00<007oo
Ool0ogooGGoo00<007ooOol02goo00<007ooOol00goo002EOol5000>Ool4000mOol2001]Ool00`00
Oomoo`1lOol500000`6G001g^@04MkT00`00NgMkM`07NgL00`00Oomoo`3oOomNOol00`00Oomoo`0:
Ool00`00Oomoo`03Ool00>]oo`8006]oo`03001oogoo07ioo`03000`030000@000=g^@03001kMg]g
00IkM`03001oogoo0?moof1oo`03001oogoo00Uoo`03001oogoo00=oo`00kGoo0P00JGoo00<007oo
Ool0Ogoo0P000S000`0000=g^@00NgL027]g00<007ooOol0ogooH7oo00<007ooOol02Goo00<007oo
Ool00goo003_Ool20005Ool00`00Oomoo`1OOol00`00Oomoo`21Ool20003<0000`00NgMkM`07NgL0
0`00Oomoo`3oOomROol00`00Oomoo`08Ool00`00Oomoo`03Ool00?5oo`8000=oo`03001oogoo05mo
o`03001oogoo08=oo`80008`0003001kMg]g00IkM`03001oogoo0?moof=oo`03001oogoo00Moo`03
001oogoo00=oo`00lgoo0P0000=oo`00Ool0H7oo00<007ooOol0QGoo00@00300<00000MkM`03001o
ogoo0?moof=oo`03001oogoo00Moo`03001oogoo00=oo`00mGoo0P00HGoo00<007ooOol0QWoo0P00
00<`0000NgL017]g00<007ooOol0ogooIGoo00<007ooOol01Woo00<007ooOol00goo003fOol2001P
Ool00`00Oomoo`28Ool30004NgL00`00Oomoo`3oOomVOol00`00Oomoo`05Ool00`00Oomoo`03Ool0
0?Qoo`8005ioo`03001oogoo08Yoo`80009kM`03001oogoo0?moofQoo`03001oogoo00Aoo`03001o
ogoo00=oo`00nWoo0P00G7oo00<007ooOol0Rgoo0P0000=kM`00Ool0ogooJGoo00<007ooOol017oo
00<007ooOol00goo003lOol20005Ool00`00Oomoo`1BOol00`00Oomoo`2=Ool00`00Oomoo`3oOomZ
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00?ioo`8000=oo`03001oogoo059oo`03001oogoo0?mo
oo]oo`03001oogoo00=oo`03001oogoo009oo`00ogoo0Goo0`00EGoo00<007ooOol0ogooo7oo00<0
07ooOol00Woo00<007ooOol00Woo003oOol3Ool2001DOol00`00Oomoo`3oOoolOol00`00Oomoo`02
Ool00`00Oomoo`02Ool00?moo`Eoo`80059oo`03001oogoo0?moooeoo`05001oogooOol00004Ool0
0?moo`Moo`80051oo`03001oogoo0?moooioo`04001oogoo0004Ool00?moo`Uoo`8000Eoo`03001o
ogoo04Ioo`03001oogoo0?moooioo`04001oogoo0004Ool00?moo`]oo`8000=oo`03001oogoo04Io
o`03001oogoo0?mooomoo`03001oo`0000Aoo`00ogoo3Goo0P0000=oo`00Ool0Agoo00<007ooOol0
ogooogoo0Goo0P0017oo003HOol<000;Ool4000KOol20018Ool00`00Oomoo`3oOoojOol80004Ool0
0=Qoo``000Uoo`P001]oo`8004Ioo`03001oogoo0?moonaoo`h000aoo`00fGoo0`001Woo0P002Goo
0P0017oo0P007Goo0P00A7oo00<007ooOol0ogoogWoo3P006Woo003JOol3000?Ool20006Ool2000N
Ool20005Ool00`00Oomoo`0jOol00`00Oomoo`3oOoo@Ool>000XOol00=]oo`<000ioo`8000Ioo`80
021oo`8000=oo`03001oogoo03Yoo`03001oogoo0?mool9oo`h003Ioo`00g7oo0`0037oo0P0027oo
0P008Goo0P0000=oo`00Ool0>goo00<007ooOol0ogoo]7oo3P00A7oo003MOol3000;Ool20008Ool2
000SOol2000lOol00`00Oomoo`3oOonVOol>001BOol00=ioo`<000Yoo`8000Qoo`8002Eoo`8000Qo
o`03001oogoo02moo`03001oogoo0?mooiQoo`h0061oo`00ggoo0`002Goo0P0027oo0P009goo0P00
1Woo00<007ooOol0;goo00<007ooOol0ogooRWoo3P00KWoo003POol30008Ool20008Ool2000YOol2
0004Ool00`00Oomoo`0_Ool00`00Oomoo`3oOommOol=001lOol00>5oo`8000Qoo`8000Qoo`8002]o
o`80009oo`03001oogoo02moo`03001oogoo0?moofmoo`h008Uoo`00hWoo0P001goo0P0027oo0P00
;Goo0`00<Goo00<007ooOol0ogooHGoo3P00Ugoo003ROol20007Ool20008Ool2000_Ool2000`Ool0
0`00Oomoo`3oOomCOol>002UOol00=Uoo`8000Moo`8000Qoo`8000Ioo`80039oo`8002ioo`03001o
ogoo0?moodEoo`h00;=oo`00fGoo0`001Woo0P0027oo0P001Woo0P00=7oo0P001Woo00<007ooOol0
8goo00<007ooOol0ogoo=goo3P00`Goo003IOol40004Ool2000:Ool20004Ool2000gOol20004Ool0
0`00Oomoo`0SOol00`00Oomoo`3oOolYOol>003?Ool00=Yoo`P000]oo`P003Uoo`80009oo`03001o
ogoo02=oo`03001oogoo0?mooa]oo`h00=eoo`00g7oo1@003Woo1000?Goo0`009Goo00<007ooOol0
ogoo3Goo3P00jgoo003oOolcOol2000SOol00`00Oomoo`3oOol>003iOol00?moocEoo`80025oo`03
001oogoo0?5oo`h00?moo`Qoo`00ogoo=goo00<007ooOol017oo00<007ooOol05goo00<007ooOol0
hgoo3P00ogoo5Woo003oOolhOol20004Ool00`00Oomoo`0GOol00`00Oomoo`3EOol>003oOolTOol0
0?moocYoo`80009oo`03001oogoo01Moo`03001oogoo0<Moo`h00?mooc9oo`00ogoo?7oo0`006Goo
00<007ooOol0^Goo3P00ogoo@7oo003oOolnOol2000HOol00`00Oomoo`2[Ool>003oOom>Ool00?mo
od1oo`8000Moo`03001oogoo00aoo`03001oogoo09eoo`h00?mooeaoo`00ogoo@Woo0P001Goo00<0
07ooOol037oo00<007ooOol0Sgoo3P00ogooJWoo003oOom4Ool20003Ool00`00Oomoo`0<Ool00`00
Oomoo`21Ool>003oOomhOol00?moodIoo`800003Ool007oo00eoo`03001oogoo07Aoo`d00?moohIo
o`00ogooB7oo0P003Woo00<007ooOol0IWoo3P00ogooTgoo003oOolHOol:000;Ool4000IOol2000<
Ool00`00Oomoo`1HOol>003oOonQOol00?mooaQoo`X000Uoo`P001Uoo`8000Eoo`03001oogoo009o
o`03001oogoo04Yoo`h00?moojmoo`00ogoo77oo0P003Goo0P0017oo0P006goo0P000goo00<007oo
Ool00Woo00<007ooOol0?7oo3P00ogoo_Goo003oOolLOol2000<Ool20006Ool2000LOol200000goo
001oo`03Ool00`00Oomoo`0^Ool>003oOoo;Ool00?mooaaoo`8000aoo`8000Ioo`8001ioo`8000Ao
o`03001oogoo021oo`h00?moomUoo`00ogoo77oo0P002goo0P0027oo0P007goo0P000Woo00<007oo
Ool04Woo3P00ogooigoo003oOolLOol2000;Ool20008Ool2000QOol30006Ool>003oOooeOol00?mo
oaaoo`8000]oo`8000Qoo`8002=oo`L00?mooomoo`Aoo`00ogoo77oo0P002goo0P0027oo0P00ogoo
ogoo;Woo003oOolLOol2000;Ool20008Ool2003oOoooOol^Ool00?mooaaoo`8000]oo`8000Qoo`80
0?mooomoobioo`00ogoo77oo0P002goo0P0027oo0P00ogooogoo;Woo003oOolLOol2000;Ool20008
Ool2003oOoooOol^Ool00?mooaaoo`8000aoo`8000Ioo`800?mooomoobmoo`00ogoo77oo0P0037oo
0P001Woo0P00ogooogoo;goo003oOolHOol300000goo0000000=Ool20004Ool2003oOoooOol`Ool0
0?mooaQoo`H000eoo`P00?mooomooc1oo`00ogoo6goo0`003goo1000ogooogoo<Woo003oOoooOooo
OomSOol00?mooomooomoof=oo`00\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  Evaluatable->False,
  ImageSize->{288, 173.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["Control plot of interpolated potential.", "Text"],

Cell["\<\
Copy coarse to fine grid as input for the main calculation 
(near the border the interpolation has to extrapolate a little):\
\>", "Text",\

  PageBreakAbove->True],

Cell[CellGroupData[{

Cell["u=Table[p[j/2,i/2],{i,1,nz},{j,1,ns}];", "Input",
  CellLabel->"In[35]:=",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}},
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(InterpolatingFunction::"dmval" \(\(:\)\(\ \)\) 
      "Input value \!\({1\/2, 1\/2}\) lies outside the range of data in the \
interpolating function. Extrapolation will be used."\)], "Message",
  CellLabel->"From In[35]:="],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(InterpolatingFunction :: \"dmval\"\) will be \
suppressed during this calculation."\)], "Message",
  CellLabel->"From In[35]:="]
}, Open  ]],

Cell["Once again time for Laplace...", "Text"],

Cell[CellGroupData[{

Cell["\<\
Timing[Do[{u=m;
If[Mod[i,100]==0,{err=Max[Abs[Flatten[u-m]]];
Print[i,\" residual error: \",err];
If[err<10^-6,Break[]]}]},{i,1,2000}]]\
\>", "Input",
  CellLabel->"In[36]:=",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}},
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    InterpretationBox[\(1200\[InvisibleSpace]" residual error: "\
\[InvisibleSpace]7.761236794356918`*^-7\),
      SequenceForm[ 1200, " residual error: ", 7.7612367943569183*^-07],
      Editable->False]], "Print",
  CellLabel->"From In[36]:="],

Cell[BoxData[
    \({120.53333333333333`\ Second, Null}\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ListPlot3D[u,
ImageSize->400,PlotRange->All,ViewPoint\[Rule]{3.,1.,1.}]\
\>", "Input",
  CellLabel->"In[37]:=",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}},
  Background->GrayLevel[0.849989]],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000B`0002da000`40O003h00Oogooogooogooogoo
]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOooo
OoooOoooOondOol00?mooomooomooo1oo`L000Yoo`@00:ioo`00ogooogooogool7oo1`0027oo2000
[7oo003oOoooOoooOoocOol2000:Ool20004Ool2002/Ool00?mooomooomooo=oo`8000Uoo`8000Io
o`800:]oo`00ogooogooogoolgoo0P002Goo0P001Woo0P00Zgoo003oOoooOoooOoo[Ool<0006Ool2
0008Ool2002ZOol00?mooomooomoon]oo``000Ioo`8000Qoo`800:Yoo`00ogooogooogoojgoo0P00
1Woo0P0000=oo`00Ool01Goo0P0027oo0P00ZWoo003oOoooOoooOoo/Ool20005Ool20008Ool20008
Ool2002ZOol00?mooomooomoonaoo`<000Aoo`8000Qoo`8000Qoo`800:Yoo`00ogooogooogookGoo
0P0017oo0P0027oo0P0027oo0P00ZWoo003oOoooOoooOoo^Ool20003Ool20008Ool20008Ool2002Z
Ool00?mooomooomoonioo`<0009oo`8000Qoo`8000Qoo`800:Yoo`00ogooogooogookgoo0P000Woo
0P002Goo0P001Woo0P00Zgoo003oOoooOoooOoo`Ool200000goo00000009Ool20006Ool2002[Ool0
0?mooomooomooo5oo`@000Yoo`8000Aoo`800:aoo`00ogooogooogoolGoo10002Woo2000[7oo003o
OoooOoooOoobOol3000<Ool4002^Ool00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003o
OoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOooo
OondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mo
oomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomo
okAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogoo
ogooogooogoo]7oo003oOoooOoobOol5000>Ool4003oOonZOol00?mooomooo1oo`T000Yoo`P00?mo
ojQoo`00ogooogookgoo100017oo0`002Goo0P0017oo0P00k7oo1@00]Woo003oOoooOoo_Ool20007
Ool30007Ool20006Ool2003TOol70004Ool00`00Oomoo`2dOol00?mooomoooUoo`8000Moo`8000Io
o`800=eoo`L000]oo`800;Eoo`00ogooogoonGoo0P001Woo0P0027oo0P00eGoo1`004Woo0P00]Goo
003oOoooOooiOol20006Ool20008Ool2003>Ool7000IOol00`00Ool0002dOol00?mooomoooQoo`<0
00Ioo`8000Qoo`800<Ioo`P0021oo`03001oo`000;Aoo`00ogooogoomgoo0`001goo0P0027oo0P00
_goo1`00:7oo00@007ooOol00;=oo`00ogooogoom7oo1@0027oo0P0027oo0P00^7oo1`00;goo00@0
07ooOol00;=oo`00ogooogoom7oo10002Goo0P0027oo0P00/Goo1`000Woo00<007ooOol0<Goo00D0
07ooOomoo`000;9oo`00ogooogoomgoo0P0027oo0P0027oo0P00ZWoo1`002Goo00<007ooOol0;Woo
10000goo00<007ooOol0/7oo003oOoooOoohOol20007Ool20008Ool2002SOol7000@Ool00`00Oomo
o`0WOol70003Acl00`00Oomoo`02Ool00`00Oomoo`2_Ool00?mooomoooQoo`8000Qoo`8000Ioo`80
09aoo`P001Moo`03001oogoo025oo`H000Y7?`8000=oo`03001oogoo0:moo`00ogooogool7oo0P00
1Woo0P0027oo0P001Woo0P00UGoo1`007goo00<007ooOol06Woo1`0044Lo0P0017oo00<007ooOol0
[Woo003oOoooOoo`Ool30004Ool30009Ool20004Ool2002?Ool7000mOol6000GAcl00`00Acl00003
Ool00`00Oomoo`2^Ool00?mooomooo5oo`P000Yoo`P008Qoo`L003eoo`L000=7?`030017?dLo01M7
?`030017?`0000Aoo`03001oogoo0:eoo`00ogooogoolWoo1@003Woo1000Pgoo1`0000=oo`00Ool0
>goo1P002dLo00<004LoAcl05DLo1@0017oo00<007ooOol0[7oo003oOoooOoooOon5Ool80008Ool0
0`00Oomoo`0cOol7000BAcl00`00Acm7?`0;Acl90002Acl00`00Acl00004Ool00`00Oomoo`2/Ool0
0?mooomooomoogioo`L0011oo`03001oogoo02aoo`L001U7?`030017?dLo0097?`T000]7?`040017
?dLo0004Ool00`00Oomoo`2[Ool00?mooomooomoogMoo`L001Moo`03001oogoo02=oo`T000A7?`03
0017?dLo01M7?`L001A7?`040017?dLo0004Ool00`00Oomoo`2[Ool00?mooomooomoog1oo`L001io
o`03001oogoo01]oo`P000i7?`030017?dLo00m7?`L000=7?`030017?dLo01E7?`040017?dLo0005
Ool00`00Oomoo`2ZOol00?mooomooomoofUoo`L003aoo`L001M7?`030017?dLo00Q7?`H000]7?`03
0017?dLo01A7?`D000Aoo`03001oogoo0:Yoo`00ogooogooogooHGoo2000?7oo1`000d/o00<004Lo
Acl064Lo00@004LoAcm7?`L00157?`030017?dLo00m7?`H000=7G`03001oogoo00=oo`03001oogoo
0:Uoo`00ogooogooogooFWoo1`0000=oo`00Ool0>goo1P002d/o00<004LoAcl054Lo1`006DLo00<0
04LoAcl01dLo1`001DMO00<004MOAel00TMO00<007ooOol00Woo00<007ooOol0ZGoo003oOoooOooo
OomCOol70008Ool00`00Oomoo`0cOol7000BBcl00`00Acm7?`0:Acl90004Bcl00`00Acm7?`0IAcl0
1000Acm7?dLo1P0034MO00<004MOAel00dMO00<007ooOol00Woo00<007ooOol0Z7oo003oOoooOooo
Oom<Ool7000?Ool00`00Oomoo`0/Ool7000IBcl00`00Acm7?`02Acl8000>Bcl00`00Acm7?`0EAcl7
000BAel00`00Aem7G`03Ael00`00Oomoo`02Ool00`00Oomoo`2XOol00?mooomooomoodEoo`L001Mo
o`03001oogoo029oo`T000A;?`03001;?d/o01M;?`L001M;?`030017?dLo00]7?`T000A;?`030017
GdMO0197G`040017GdMOAel40004Ool00`00Oomoo`2WOol00?mooomooomooceoo`P001ioo`03001o
ogoo01Yoo`P000i;?`03001;?d/o00m;?`L000=;?`03001;?d/o01Q;?`030017?dLo0097?`T000i;
?`030017GdMO00i7G`L000=7G`03001oogoo009oo`03001oogoo0:Moo`00ogooogooogoo=Woo1`00
?7oo1`005d/o00<004/oBcl024/o1P002d/o00<004/oBcl05D/o1`005d/o00<004MOAel024MO1P00
0dMO00<004MOAel01DMO00<007ooOol00Woo00<007ooOol0YWoo003oOoooOoooOol_Ool7000mOol6
0003Bcl00`00Bcm;?`0HBcl01000Bcm;?d/o1`004D/o00<004/oBcl03d/o1P000d/o00<004/oBcl0
64/o00@004MOAem7G`L000U7G`030017GdMO00I7G`05001oogooOol0002XOol00?mooomooomoobQo
o`L0009oo`03001oogoo03Qoo`L000Y;?`03001;?d/o01E;?`H001U;?`03001;?d/o00M;?`L000Y;
?`03001;?d/o01E;?`H00117G`030017GdMO00I7G`03001oogoo009oo`03001oogoo0:Eoo`00ogoo
ogooogoo8Goo1`002Goo00<007ooOol0<Woo1P004D/o00<004/oBcl03d/o1P000d/o00<004/oBcl0
6D/o00@004/oBcm;?`H0015;?`03001;?d/o00m;?`H000=;G`030017GdMO0117G`030017GdMO00A7
G`@000=oo`03001oogoo0:Eoo`00ogooogooogoo6Woo1`0047oo00<007ooOol0:goo1`0064/o00<0
04/oBcl01d/o1`002T/o00<004/oBcl05T/o1P0064/o00<004/oBcl01d/o1`002T]O00<004MOAel0
3dMO1`000d]O00<007ooOol00Woo00<007ooOol0Y7oo003oOoooOol<000;Ool4003fOol8000GOol0
0`00Oomoo`0ROol90004Bcl00`00Bcm;?`0HBcl01000Bcm;?d/o1P004D/o00<004/oBcl03d/o1`00
0d/o00<004/oBcl064/o00@004/oBcm;?`H0019;G`030017GdMO00Q7G`L000Y;G`05001oogooOol0
002VOol00?mooomoo``000Uoo`P00>eoo`L001moo`03001oogoo01Yoo`P000i;?`03001;?d/o01A;
?`L001Q;?`03001;?d/o00Q;?`H000];?`03001;?d/o01A;?`L001Q;G`040017GdMOAel70006Bel0
0`00Bem;G`08Bel00`00Oomoo`02Ool00`00Oomoo`2SOol00?mooomoo`5oo`<000Ioo`8000Uoo`80
00Aoo`800>Ioo`L003]oo`P001M;?`03001;?d/o00Y;?`T000A;?`03001;?d/o01Q;?`04001;?d/o
Bcl7000BBcl00`00Bcm;?`0:Bcl90004Bcl00`00Bem;G`0FBel6000=Bel00`00Bem;G`08Bel00`00
Oomoo`02Ool00`00Oomoo`2SOol00?mooomoo`9oo`<000moo`8000Ioo`800=ioo`L003Uoo`T000A;
?`03001;?d/o01Q;?`03001;?d/o009;?`P000i;?`03001;?d/o01A;?`L001U;?`03001;?d/o009;
?`P000i;?`03001;Gd]O00m;G`H000=;G`03001;Gd]O00e;G`03001;Gd]O00I;G`@000Aoo`03001o
ogoo0:9oo`00ogooogoo0goo0`003Woo0P001Woo0P00egoo1`000Woo00<007ooOol0<goo20003T/o
00<004/oBcl05D/o1`005d/o00<004/oBcl02T/o2@0014/o00<004/oBcl05d/o1`005d/o00<004]O
Bel01d]O1`002T]O00<004]OBel034]O00<004]OBel01P000d]O00<007ooOol00Woo00<007ooOol0
XWoo003oOoooOol4Ool3000<Ool20008Ool2003>Ool80009Ool00`00Oomoo`0/Ool7000FBcl00`00
Bcm;?`0?Bcl60003Bcl00`00Bcm;?`0HBcl00`00Bcm;?`02Bcl8000>Bcl00`00Bcm;?`0@Bcl60003
Bcl00`00Bcm;?`0HBcl01000Bem;Gd]O1P004T]O00<004]OBel01d]O1`002T]O00<007ooOol00Woo
00<007ooOol0XGoo003oOoooOol5Ool3000;Ool20008Ool20037Ool7000AOol00`00Oomoo`0VOol6
0003Bcl00`00Bcm;?`0HBcl00`00Bcm;?`07Bcl7000:Bcl00`00Bcm;?`0EBcl7000GBcl00`00Bcm;
?`08Bcl7000:Bcl00`00Bcm;?`0EBcl6000HBel01000Bem;Gd]O1P0014]O00<004]OBel02d]O00D0
07ooOomoo`000:=oo`00ogooogoo1Woo0`002Woo0P0027oo0P00`7oo1`0067oo00<007ooOol07goo
1`002T/o00<004/oBcl05d/o00@004/oBcm;?`H0015;?`03001;?d/o00m;?`H000=;?`03001;?d/o
01U;?`04001;?d/oBcl6000ABcl00`00Bcm;?`0?Bcl60003Bcl00`00Bem;G`0FBel6000:Bel00`00
Bem;G`0;Bel00`00Oomoo`02Ool00`00Oomoo`2POol00?mooomoo`Moo`<000Uoo`8000Qoo`800;Uo
o`L001moo`03001oogoo01Uoo`H0015;?`03001;?d/o01A;?`L001Q;?`03001;?d/o00M;?`L000Y;
?`03001;?d/o01I;?`H001Q;?`03001;?d/o00M;?`L000Y;?`03001;Gd]O00m;G`H000=;G`03001;
Gd]O00Y;G`03001;Gd]O00U;G`@000=oo`03001oogoo0:1oo`00ogooogoo27oo0`0027oo0P0027oo
0P00/Woo1`009Woo00<007ooOol04Woo1`0064/o00<004/oBcl02T/o2@0014/o00<004/oBcl064/o
00@004/oBcm;?`H0019;?`03001;?d/o00m;?`H000=;?`03001;?d/o01Q;?`04001;?d/oBcl6000B
Bcl00`00Bem;G`07Bel7000:Bel00`00Bem;G`09Bel00`00Bem;G`03Bel60003Bel00`00Oomoo`02
Ool00`00Oomoo`2OOol00?mooomoo`Uoo`8000Qoo`8000Qoo`800:Yoo`P002eoo`03001oogoo00Uo
o`T000A;?`03001;?d/o01Q;?`03001;?d/o009;?`P000i;?`03001;?d/o01A;?`L001Q;?`03001;
?d/o00Q;?`L000Y;?`03001;?d/o01A;?`L001Q;?`04001;Gd]OBel6000BBel00`00Bem;G`07Bel7
000:Bel01@00Oomoogoo0000XGoo003oOoooOol:Ool20007Ool20008Ool2002SOol70004Ool00`00
Oomoo`0^Ool01000Oomoogoo20003T/o00<004/oBcl05D/o1`005d/o00<004/oBcl02T/o2@0014/o
00<004/oBcl06D/o00@004/oBcm;?`H0019;?`03001;?d/o00Y;?`T000A;?`03001;?d/o01I;?`H0
01Q;G`04001;Gd]OBel60002Bel00`00Bem;G`0<Bel00`00Oomoo`02Ool00`00Oomoo`2NOol00?mo
oomoo`Yoo`8000Moo`8000Qoo`8009aoo`L000]oo`03001oogoo02]oo`L001M;?`03001;?d/o00i;
?`H000=;?`03001;?d/o01Q;?`03001;?d/o009;?`P000i;?`03001;?d/o01E;?`L001Q;?`03001;
?d/o009;?`P000i;?`03001;?d/o00m;?`H000=;G`03001;Gd]O01I;G`H000Q;G`03001;Gd]O00e;
G`03001oogoo009oo`03001oogoo09eoo`00ogooogoo0Goo0P001goo0P0027oo0P001Woo0P00UWoo
1`004Woo00<007ooOol09Goo1P000d/o00<004/oBcl064/o00<004/oBcl024/o1P002T/o00<004/o
Bcl05D/o1`005d/o00<004/oBcl02d/o2@0014/o00<004/oBcl05T/o1`005d/o00<004/oBcl01d/o
1`002T]O00<004]OBel03d]O1P000d]O00<004]OBel024]O00<004]OBel03D]O00<007ooOol00Woo
00<007ooOol0WGoo003oOoooOol1Ool30006Ool20008Ool20006Ool2002?Ool7000IOol00`00Oomo
o`0OOol6000:Bcl00`00Bcm;?`0HBcl01000Bcm;?d/o1P004D/o00<004/oBcl03T/o1P000d/o00<0
04/oBcl06D/o00<004/oBcl00T/o20003T/o00<004/oBcl03d/o1P000d/o00<004/oBcl064/o00@0
04/oBcm;?`H0019;G`03001;Gd]O00M;G`L000Y;G`03001;Gd]O00M;G`03001;Gd]O00Y;G`D000Ao
o`03001oogoo09aoo`00ogooogoo0Goo100017oo0P002Woo0P0017oo0P00RGoo1`0087oo00<007oo
Ool06Goo1P004D/o00<004/oBcl054/o1`005d/o00<004/oBcl024/o1P002T/o00<004/oBcl05T/o
1`005d/o00<004/oBcl01d/o1`002T/o00<004/oBcl05D/o1P0064]O00@004]OBem;G`H0019;G`03
001;Gd]O00I;G`04001;Gd]OBel90004Bel00`00Oomoo`02Ool00`00Oomoo`2LOol00?mooomoo`9o
o`P000]oo`P0085oo`P003aoo`L001M;?`03001;?d/o00];?`T000A;?`03001;?d/o01Q;?`04001;
?d/oBcl6000ABcl00`00Bcm;?`0?Bcl60003Bcl00`00Bcm;?`0HBcl01000Bcm;?d/o1P004D/o00<0
04/oBcl03d/o1P000d/o00<004]OBel05T]O1P0064]O00<004]OBel00T]O20003T]O00<007ooOol0
0Woo00<007ooOol0Vgoo003oOoooOol4Ool5000>Ool4001lOol7000kOol90004Bcl00`00Bcm;?`0H
Bcl00`00Bcm;?`02Bcl8000>Bcl00`00Bcm;?`0DBcl7000GBcl00`00Bcm;?`08Bcl7000:Bcl00`00
Bcm;?`0EBcl6000HBcl00`00Bcm;?`07Bcl7000:Bcl00`00Bem;G`0?Bel60003Bel00`00Bem;G`0F
Bel70004Bel00`00Bem;G`0?Bel00`00Oomoo`02Ool00`00Oomoo`2KOol00?mooomooi1oo`L000Io
o`03001oogoo035oo`P000i;?`03001;?d/o01A;?`P001M;?`03001;?d/o00Y;?`T000A;?`03001;
?d/o01Q;?`04001;?d/oBcl6000ABcl00`00Bcm;?`0?Bcl60003Bcl00`00Bcm;?`0HBcl01000Bcm;
?d/o1P004T/o00<004]OBel01d]O1`002T]O00<004]OBel03T]O1`000d]O00<004]OBel01D]O00<0
04]OBel03d]O00<007ooOol00goo00<007ooOol0VWoo003oOoooOon9Ool7000=Ool00`00Oomoo`0Y
Ool8000GBcl00`00Bcm;?`0;Bcl80004Bcl00`00Bcm;?`0HBcl00`00Bcm;?`02Bcl8000>Bcl00`00
Bcm;?`0DBcl7000HBcl00`00Bcm;?`07Bcl7000:Bcl00`00Bcm;?`0DBcl7000HBcl01000Bem;Gd]O
1P004D]O00<004]OBel024]O1P002d]O00<004]OBel014]O00<004]OBel03D]O100017oo00<007oo
Ool0VWoo003oOoooOon2Ool7000DOol00`00Oomoo`0QOol80004Bcl00`00Bcm;?`0IBcl00`00Bcm;
?`02Bcl8000=Bcl00`00Bcm;?`0EBcl7000GBcl00`00Bcm;?`0:Bcl90004Bcl00`00Bcm;?`0HBcl0
1000Bcm;?d/o1P004T/o00<004/oBcl02T/o2@0014/o00<004/oBcl05T/o1P005d]O00@004]OBem;
G`L0015;G`03001;Gd]O00A;G`03001;Gd]O00M;G`H000=;G`03001oogoo00=oo`03001oogoo09Uo
o`00ogooogooNWoo20006goo00<007ooOol06Goo20003D/o00<004/oBcl05T/o1`005T/o00<004/o
Bcl03T/o1P000d/o00<004/oBcl064/o00<004/oBcl00T/o20003T/o00<004/oBcl054/o1`0064/o
00<004/oBcl00T/o20003T/o00<004/oBcl03d/o1P000d/o00<004]OBel05D]O1P0064]O00<004]O
Bel014]O00<004]OBel01`002T]O00<007ooOol00Woo00<007ooOol0VGoo003oOoooOomcOol7000S
Ool00`00Oomoo`0BOol7000FBcl00`00Bcm;?`0?Bcl60003Bcl00`00Bcm;?`0GBcl00`00Bcm;?`08
Bcl6000:Bcl00`00Bcm;?`0EBcl7000GBcl00`00Bcm;?`0:Bcl90004Bcl00`00Bcm;?`0FBcl7000G
Bcl00`00Bcm;?`07Bcl7000:Bcl00`00Bem;G`0>Bel60003Bel00`00Bem;G`0IBel00`00Bem;G`06
000BBel00`00Oomoo`02Ool00`00Oomoo`2HOol00?mooomoofaoo`L003Uoo`H000=;?`03001;?d/o
01M;?`03001;?d/o00Q;?`L000Y;?`03001;?d/o01M;?`04001;?d/oBcl6000ABcl00`00Bcm;?`0>
Bcl60003Bcl00`00Bcm;?`0HBcl00`00Bcm;?`02Bcl8000>Bcl00`00Bcm;?`0?Bcl60003Bcl00`00
Bcm;?`0HBcl01000Bcm;?d/o1P004T/o00<004]OBel01d]O1P002T]O00<004]OBel05D]O1P000d]O
00<004]OBel04D]O0`000goo00<007ooOol0V7oo003oOoooOomUOol700000goo001oo`0gOol6000:
Bcl00`00Bcm;?`0GBcl01000Bcm;?d/o1P004D/o00<004/oBcl054/o1`005d/o00<004/oBcl024/o
1P002T/o00<004/oBcl05D/o1`005d/o00<004/oBcl01d/o1`002T/o00<004/oBcl05D/o1P0064/o
00@004]OBem;G`H0011;G`03001;Gd]O00m;G`H000=;G`03001;Gd]O00=;G`03001;Gd]O00a;G`D0
009;G`03001oogoo009oo`03001oogoo09Moo`00ogooogooGWoo1`0027oo00<007ooOol0<7oo1P00
4D/o00<004/oBcl04d/o1`0064/o00<004/oBcl02T/o2@0014/o00<004/oBcl064/o00@004/oBcm;
?`H0015;?`03001;?d/o00i;?`H000=;?`03001;?d/o01Q;?`04001;?d/oBcl6000ABcl00`00Bcm;
?`0?Bcl60003Bcl00`00Bcm;?`0FBcl6000GBel00`00Bem;G`07Bel7000:Bel00`00Bem;G`02Bel0
0`00Bem;G`07Bel50008Bel01@00Oomoogoo0000VGoo003oOoooOomFOol8000?Ool00`00Oomoo`0Y
Ool7000GBcl00`00Bcm;?`0;Bcl80004Bcl00`00Bcm;?`0HBcl00`00Bcm;?`02Bcl8000>Bcl00`00
Bcm;?`0DBcl7000GBcl00`00Bcm;?`08Bcl6000:Bcl00`00Bcm;?`0EBcl6000HBcl00`00Bcm;?`07
Bcl7000:Bcl00`00Bcm;?`0?Bcl60003Bel00`00Bem;G`0GBel01000Bem;Gd]O1P004T]O00D004]O
Bem;G`0000A;G`D000i;G`05001oogooOol0002HOol00?mooomoodmoo`L001Moo`03001oogoo025o
o`P000A;?`03001;?d/o01Q;?`03001;?d/o009;?`P000e;?`03001;?d/o01E;?`L001M;?`03001;
?d/o00Y;?`T000A;?`03001;?d/o01Q;?`04001;?d/oBcl6000ABcl00`00Bcm;?`0>Bcl60003Bcl0
0`00Bcm;?`0HBcl01000Bcm;?d/o1P004T/o00<004/oBcl01d/o1`002T]O00<004]OBel054]O1P00
64]O00@004]OBem;G`D001=;G`05001oogooOol0002HOol00?mooomoodQoo`L001ioo`03001oogoo
01Uoo`P000e;?`03001;?d/o01E;?`L001I;?`03001;?d/o00i;?`H000=;?`03001;?d/o01Q;?`03
001;?d/o009;?`P000i;?`03001;?d/o01E;?`H001M;?`03001;?d/o00Q;?`H000Y;?`03001;?d/o
01E;?`H001Q;?`04001;?d/oBcl6000ABel00`00Bem;G`0>Bel60003Bel00`00Bem;G`0FBel7000F
Bel30003Ool00`00Oomoo`2EOol00?mooomood5oo`L003Uoo`P001I;?`03001;?d/o00i;?`H000=;
?`03001;?d/o01M;?`03001;?d/o00Q;?`H000Y;?`03001;?d/o01E;?`L001I;?`03001;?d/o00m;
?`H000=;?`03001;?d/o01Q;?`04001;?d/oBcl6000@Bcl00`00Bcm;?`0?Bcl60003Bcl00`00Bcm;
?`0FBcl6000GBel00`00Bem;G`07Bel7000:Bel00`00Bem;G`0?Bel60003Bel01000Bem;G`004D]O
1@000T]O00D007ooOomoo`0009Moo`00ogooogoo>Woo1`00>7oo200014/o00<004/oBcl05d/o00<0
04/oBcl024/o1P002T/o00<004/oBcl05d/o00@004/oBcm;?`H0015;?`03001;?d/o00i;?`H000=;
?`03001;?d/o01Q;?`03001;?d/o00M;?`L000Y;?`03001;?d/o01A;?`L001M;?`03001;?d/o00M;
?`L000Y;?`03001;?d/o00m;?`H000=;?`03001;Gd]O01Q;G`03001;Gd]O00H0019;G`03001;Gd]O
00M;G`L000Y;G`03001;G`0000a;G`D000Q;G`05001oogooOol0002FOol00?mooamoo`X000]oo`@0
0?Uoo`P000Aoo`03001oogoo031oo`P000e;?`03001;?d/o01M;?`04001;?d/oBcl6000ABcl00`00
Bcm;?`0CBcl7000GBcl00`00Bcm;?`08Bcl6000:Bcl00`00Bcm;?`0GBcl01000Bcm;?d/o1P004T/o
00<004/oBcl02T/o2@0014/o00<004/oBcl05d/o00@004/oBcm;?`H0019;?`03001;?d/o00M;?`L0
00Y;?`03001;Gd]O01A;G`H001Q;G`04001;Gd]OBel6000BBel20007Bel5000=Bel01@00Oomoogoo
0000UWoo003oOolOOol:0009Ool8003`Ool7000<Ool00`00Oomoo`0YOol7000FBcl00`00Bcm;?`0C
Bcl7000GBcl00`00Bcm;?`0;Bcl80004Bcl00`00Bcm;?`0HBcl01000Bcm;?d/o1P004D/o00<004/o
Bcl04d/o1`0064/o00<004/oBcl00T/o20003T/o00<004/oBcl04d/o1`0064/o00@004/oBcm;?`H0
015;?`03001;Gd]O00i;G`H000=;G`03001;Gd]O01I;G`H001Q;G`80009;G`D0019;G`03001oogoo
009oo`03001oogoo09=oo`00ogoo8goo0P003Goo0P0017oo0P00jGoo1`004goo00<007ooOol08goo
1P000d/o00<004/oBcl05d/o00<004/oBcl02d/o200014/o00<004/oBcl064/o00<004/oBcl00T/o
20003D/o00<004/oBcl054/o1`005d/o00<004/oBcl02d/o200014/o00<004/oBcl05T/o1`005d/o
00<004/oBcl02T/o200014/o00<004/oBcl05T/o1P0064/o00<004]OBel01d]O1P002T]O00<004]O
Bel03d]O1P000d]O00<004]OBel05T]O1P005T]O0`000goo00<007ooOol0Tgoo003oOolSOol2000<
Ool20006Ool2003QOol7000JOol00`00Oomoo`0MOol6000:Bcl00`00Bcm;?`0GBcl00`00Bcm;?`02
Bcl8000=Bcl00`00Bcm;?`0DBcl8000FBcl00`00Bcm;?`0;Bcl80004Bcl00`00Bcm;?`0HBcl00`00
Bcm;?`02Bcl8000=Bcl00`00Bcm;?`0?Bcl60003Bcl00`00Bcm;?`0HBcl00`00Bcm;?`02Bcl8000=
Bcl00`00Bcm;?`0?Bcl60003Bcl00`00Bcm;?`0HBcl01000Bem;Gd]O1P004D]O00<004]OBel01d]O
1`002T]O00<004]OBel03d]O1P000d]O00<004]OBel04D]O1@000T]O00<007ooOol00Woo00<007oo
Ool0TWoo003oOolSOol2000<Ool20006Ool2003JOol7000QOol00`00Oomoo`0GOol6000ABcl00`00
Bcm;?`0CBcl8000FBcl00`00Bcm;?`0;Bcl80004Bcl00`00Bcm;?`0HBcl00`00Bcm;?`02Bcl8000=
Bcl00`00Bcm;?`0EBcl7000FBcl00`00Bcm;?`08Bcl6000:Bcl00`00Bcm;?`0EBcl7000FBcl00`00
Bcm;?`08Bcl6000:Bcl00`00Bcm;?`0DBcl7000GBel01000Bem;Gd]O1P004T]O00<004]OBel01d]O
1`002D]O0P003D]O1@0024]O00D007ooOomoo`0009Aoo`00ogoo8goo0P002goo0P0027oo0P00dWoo
1`00>goo1`005d/o00<004/oBcl02d/o200014/o00<004/oBcl064/o00<004/oBcl00T/o20003D/o
00<004/oBcl05D/o1`005T/o00<004/oBcl03T/o1P000d/o00<004/oBcl064/o00@004/oBcm;?`H0
011;?`03001;?d/o00m;?`H000=;?`03001;?d/o01Q;?`04001;?d/oBcl6000ABcl00`00Bcm;?`0:
Bcl90004Bcl00`00Bem;G`0EBel6000HBel01000Bem;Gd]O1P0044]O0P0024]O1@003T]O00D007oo
Oomoo`0009=oo`00ogoo8goo0P002goo0P0027oo0P00bWoo2@00>Goo20001D/o00<004/oBcl05d/o
00<004/oBcl00T/o20003D/o00<004/oBcl05D/o1`005T/o00<004/oBcl03T/o1P000d/o00<004/o
Bcl05d/o00<004/oBcl024/o1P002T/o00<004/oBcl05D/o1P005d/o00<004/oBcl01d/o1`002T/o
00<004/oBcl05D/o1P005d/o00<004/oBcl00T/o20003T/o00<004]OBel03T]O1P000d]O00<004]O
Bel05T]O1P005T]O0P000d]O1@004d]O00D007ooOomoo`0009=oo`00ogoo8goo0P002goo0P0027oo
0P00`goo1`0027oo00<007ooOol0<7oo1`003T/o00<004/oBcl04d/o20005T/o00<004/oBcl03T/o
1P000d/o00<004/oBcl05d/o00<004/oBcl024/o1P002T/o00<004/oBcl05d/o00@004/oBcm;?`H0
015;?`03001;?d/o00i;?`H000=;?`03001;?d/o01M;?`04001;?d/oBcl6000ABcl00`00Bcm;?`0?
Bcl60003Bcl00`00Bcm;?`0EBcl7000GBcl00`00Bem;G`07Bel6000:Bel00`00Bem;G`0?Bel60003
Bel00`00Bem;G`0EBel6000FBel40003Ool00`00Oomoo`2@Ool00?moob=oo`8000]oo`8000Qoo`80
0;aoo`L000moo`03001oogoo02Qoo`P001I;?`03001;?d/o00Y;?`P000A;?`03001;?d/o01M;?`03
001;?d/o00Q;?`H000Y;?`03001;?d/o01M;?`04001;?d/oBcl6000ABcl00`00Bcm;?`0CBcl7000G
Bcl00`00Bcm;?`08Bcl6000:Bcl00`00Bcm;?`0DBcl6000HBcl00`00Bcm;?`07Bcl7000:Bcl00`00
Bcm;?`0>Bcl60003Bcl00`00Bcm;?`0HBcl01000Bem;Gd]O1P004D]O00<004]OBel01d]O1`002T]O
00<004]OBel03T]O1P000T]O0P004T]O1P000d]O00D007ooOomoo`00099oo`00ogoo8goo0P002goo
0P0027oo0P00]Goo1`005Woo00<007ooOol087oo200014/o00<004/oBcl064/o00<004/oBcl00T/o
1`003D/o00<004/oBcl05d/o00@004/oBcm;?`H0015;?`03001;?d/o01=;?`L001M;?`03001;?d/o
00];?`P000A;?`03001;?d/o01Q;?`04001;?d/oBcl6000@Bcl00`00Bcm;?`0>Bcl60003Bcl00`00
Bcm;?`0HBcl01000Bcm;?d/o1P004T/o00<004/oBcl01d/o1P002T/o00<004/oBcl05D/o1P005d]O
00@004]OBem;G`H0019;G`03001;Gd]O00M;G`H000Q;G`03001;G`0000Y;G`L000Y;G`05001oogoo
Ool0002AOol00?moob=oo`8000]oo`8000Qoo`800:ioo`L001eoo`03001oogoo01Qoo`P000e;?`03
001;?d/o01E;?`L001E;?`03001;?d/o01=;?`L001M;?`03001;?d/o00];?`P000A;?`03001;?d/o
01Q;?`03001;?d/o009;?`P000e;?`03001;?d/o01A;?`L001M;?`03001;?d/o00M;?`H000Y;?`03
001;?d/o01A;?`L001Q;?`04001;?d/oBcl6000@Bcl00`00Bcm;?`0?Bcl60003Bcl00`00Bem;G`0E
Bel6000HBel01000Bem;Gd]O1P003T]O00@004]OBel000=;G`H0015;G`03001oogoo009oo`03001o
ogoo08ioo`00ogoo8goo0P002goo0P0027oo0P00YWoo200097oo00<007ooOol047oo20005T/o00<0
04/oBcl03T/o1P000d/o00<004/oBcl05d/o00<004/oBcl02T/o200014/o00<004/oBcl064/o00<0
04/oBcl00T/o20003D/o00<004/oBcl054/o20005T/o00<004/oBcl02T/o2@0014/o00<004/oBcl0
5d/o00@004/oBcm;?`H0015;?`03001;?d/o00];?`P000A;?`03001;?d/o01I;?`H001M;?`03001;
?d/o00M;?`L000Y;?`03001;Gd]O00i;G`H000=;G`03001;Gd]O01I;G`H001A;G`03001;G`0000@0
01M;G`03001oogoo009oo`03001oogoo08ioo`00ogoo8goo0P002goo0P0027oo0P00Wgoo1`00;7oo
00<007ooOol027oo200014/o00<004/oBcl05d/o00<004/oBcl024/o1P002T/o00<004/oBcl05d/o
00<004/oBcl00T/o1`003D/o00<004/oBcl054/o20005T/o00<004/oBcl02d/o200014/o00<004/o
Bcl05d/o00<004/oBcl00T/o20003T/o00<004/oBcl04d/o1`0064/o00<004/oBcl00T/o20003D/o
00<004/oBcl03d/o1P000d/o00<004/oBcl05d/o00@004/oBcm;?`H0019;?`03001;Gd]O00M;G`H0
00Y;G`03001;Gd]O00m;G`H000=;G`03001;Gd]O015;G`D0009;G`03001;Gd]O01E;G`@000Aoo`03
001oogoo08eoo`00ogoo8goo0P0037oo0P001Woo0P00VGoo1`001Goo00<007ooOol0:goo00@007oo
Oomoo`L000e;?`03001;?d/o01M;?`04001;?d/oBcl6000ABcl00`00Bcm;?`0CBcl8000EBcl00`00
Bcm;?`0;Bcl80004Bcl00`00Bcm;?`0HBcl00`00Bcm;?`02Bcl8000=Bcl00`00Bcm;?`0DBcl7000G
Bcl00`00Bcm;?`0:Bcl80004Bcl00`00Bcm;?`0FBcl7000FBcl00`00Bcm;?`07Bcl7000:Bcl00`00
Bcm;?`0DBcl6000HBcl01000Bem;Gd]O1P004D]O00<004]OBel01d]O1`002T]O00<004]OBel02d]O
1@000d]O00<004]OBel00T]O00<004]OBel03T]O1P000d]O00<007ooOol00Woo00<007ooOol0SGoo
003oOolSOol2000<Ool20006Ool2002BOol7000<Ool00`00Oomoo`0XOol7000EBcl00`00Bcm;?`0C
Bcl7000GBcl00`00Bcm;?`0;Bcl80004Bcl00`00Bcm;?`0GBcl00`00Bcm;?`02Bcl8000=Bcl00`00
Bcm;?`0EBcl7000EBcl00`00Bcm;?`0>Bcl60003Bcl00`00Bcm;?`0HBcl00`00Bcm;?`02Bcl8000=
Bcl00`00Bcm;?`0?Bcl60003Bcl00`00Bcm;?`0GBcl01000Bcm;?d/o1P004D/o00<004/oBcl03T/o
1P000d/o00<004/oBcl05T/o1P005d]O00@004]OBem;G`H0015;G`03001;Gd]O00I;G`D000Q;G`03
001;Gd]O009;G`03001;Gd]O00M;G`L000Y;G`03001oogoo009oo`03001oogoo08aoo`00ogoo7goo
0`0000=oo`0000003Goo0P0017oo0P00S7oo1`004goo00<007ooOol08Woo1P000d/o00<004/oBcl0
5d/o00<004/oBcl02T/o200014/o00<004/oBcl064/o00<004/oBcl00T/o20003D/o00<004/oBcl0
54/o1`005T/o00<004/oBcl03T/o1P000d/o00<004/oBcl05d/o00<004/oBcl01d/o1P002T/o00<0
04/oBcl05D/o1`005T/o00<004/oBcl024/o1P002T/o00<004/oBcl054/o1P0064/o00<004/oBcl0
1d/o1P002T/o00<004/oBcl03d/o1P000d]O00<004]OBel05D]O1P005d]O00@004]OBem;G`D000e;
G`03001;Gd]O009;G`04001;Gd]OBel6000BBel01@00Oomoogoo0000SWoo003oOolOOol6000=Ool8
0024Ool8000JOol00`00Oomoo`0MOol5000:Bcl00`00Bcm;?`0GBcl00`00Bcm;?`02Bcl7000=Bcl0
0`00Bcm;?`0EBcl7000FBcl00`00Bcm;?`0=Bcl60003Bcl00`00Bcm;?`0GBcl00`00Bcm;?`08Bcl6
000:Bcl00`00Bcm;?`0FBcl01000Bcm;?d/o1P004D/o00<004/oBcl03T/o1P000d/o00<004/oBcl0
64/o00@004/oBcm;?`H0011;?`03001;?d/o00i;?`H000=;?`03001;?d/o01Q;?`04001;?d/oBcl6
000ABcl00`00Bcm;?`07Bcl7000:Bel00`00Bem;G`0>Bel60003Bel00`00Bem;G`0EBel6000BBel0
1000Bem;Gd]O1@0064]O00<007ooOol00Woo00<007ooOol0Rgoo003oOolROol3000?Ool4001oOol7
000ROol00`00Oomoo`0GOol6000@Bcl00`00Bcm;?`0CBcl8000EBcl00`00Bcm;?`0>Bcl60003Bcl0
0`00Bcm;?`0GBcl00`00Bcm;?`08Bcl5000:Bcl00`00Bcm;?`0GBcl01000Bcm;?d/o1P004D/o00<0
04/oBcl04T/o1`005d/o00<004/oBcl024/o1P002T/o00<004/oBcl05D/o1P005d/o00<004/oBcl0
1d/o1P002T/o00<004/oBcl05D/o1P005d/o00@004/oBcm;?`H0019;G`03001;Gd]O00M;G`H000Y;
G`03001;Gd]O00i;G`H000=;G`03001;Gd]O015;G`D0009;G`03001;Gd]O01I;G`@000=oo`03001o
ogoo08]oo`00ogoo/7oo1`00?7oo1`005d/o00<004/oBcl02T/o200014/o00<004/oBcl05d/o00<0
04/oBcl024/o1@002T/o00<004/oBcl05d/o00@004/oBcm;?`H0011;?`03001;?d/o01=;?`L001M;
?`03001;?d/o00Y;?`P000A;?`03001;?d/o01Q;?`04001;?d/oBcl6000ABcl00`00Bcm;?`0>Bcl6
0003Bcl00`00Bcm;?`0GBcl01000Bcm;?d/o1P004D/o00<004/oBcl03T/o1P000d/o00<004/oBcl0
5D/o1P0064]O00@004]OBem;G`H0015;G`03001;Gd]O00M;G`H000Y;G`03001;Gd]O00];G`D00003
Bel004]O00E;G`03001;Gd]O00m;G`H000=;G`03001oogoo009oo`03001oogoo08Yoo`00ogooZGoo
1`000Woo00<007ooOol0=Woo200014/o00<004/oBcl064/o00<004/oBcl00T/o1`003D/o00<004/o
Bcl05d/o00@004/oBcm;?`H0011;?`03001;?d/o01=;?`L001I;?`03001;?d/o00];?`P000A;?`03
001;?d/o01Q;?`03001;?d/o009;?`L000e;?`03001;?d/o01A;?`L001M;?`03001;?d/o00Q;?`H0
00Y;?`03001;?d/o01A;?`H001M;?`03001;?d/o00Q;?`H000Y;?`03001;?d/o00i;?`H000=;?`03
001;Gd]O01I;G`H001M;G`04001;Gd]OBel6000ABel00`00Bem;G`05Bel50006Bel00`00Bem;G`05
Bel00`00Bem;G`07Bel7000:Bel01@00Oomoogoo0000S7oo003oOonROol70009Ool00`00Oomoo`0_
Ool7000=Bcl00`00Bcm;?`0DBcl8000EBcl00`00Bcm;?`0CBcl7000FBcl00`00Bcm;?`0;Bcl80004
Bcl00`00Bcm;?`0GBcl00`00Bcm;?`02Bcl8000=Bcl00`00Bcm;?`0EBcl7000EBcl00`00Bcm;?`0;
Bcl80004Bcl00`00Bcm;?`0HBcl01000Bcm;?d/o1P0044/o00<004/oBcl03T/o1P000d/o00<004/o
Bcl064/o00@004/oBcm;?`H0015;?`03001;?d/o00M;?`H000Y;?`03001;Gd]O00m;G`H000=;G`03
001;Gd]O01E;G`H001M;G`03001;Gd]O00D000];G`03001;Gd]O00E;G`04001;Gd]OBel6000ABel0
0`00Oomoo`02Ool00`00Oomoo`29Ool00?mooi]oo`L0011oo`03001oogoo02Moo`P001E;?`03001;
?d/o00];?`P000A;?`03001;?d/o01I;?`03001;?d/o00];?`P000A;?`03001;?d/o01M;?`03001;
?d/o009;?`P000e;?`03001;?d/o01A;?`L001I;?`03001;?d/o00i;?`H000=;?`03001;?d/o01M;
?`03001;?d/o009;?`P000e;?`03001;?d/o01E;?`H001M;?`03001;?d/o00M;?`H000Y;?`03001;
?d/o01A;?`L001M;?`04001;?d/oBcl6000ABcl00`00Bem;G`07Bel7000:Bel00`00Bem;G`0>Bel6
0003Bel00`00Bem;G`0EBel5000@Bel00`00Bem;G`04Bel5000FBel30003Ool00`00Oomoo`29Ool0
0?mooi=oo`P001Moo`03001oogoo01moo`P000A;?`03001;?d/o01M;?`03001;?d/o009;?`P000e;
?`03001;?d/o01I;?`03001;?d/o009;?`P000e;?`03001;?d/o01=;?`P001I;?`03001;?d/o00e;
?`H000=;?`03001;?d/o01M;?`03001;?d/o00Q;?`H000Y;?`03001;?d/o01A;?`L001I;?`03001;
?d/o00i;?`H000=;?`03001;?d/o01M;?`04001;?d/oBcl6000ABcl00`00Bcm;?`0:Bcl90004Bcl0
0`00Bcm;?`0EBcl6000GBcl01000Bem;Gd]O1P004D]O00<004]OBel01d]O1`002T]O00<004]OBel0
3T]O1P000d]O00<004]OBel03d]O00<004]O000010000T]O00<004]OBel04D]O1@000T]O00<007oo
Ool00Woo00<007ooOol0R7oo003oOon<Ool7000OOol00`00Oomoo`0HOol7000=Bcl00`00Bcm;?`0C
Bcl8000FBcl00`00Bcm;?`0BBcl8000FBcl00`00Bcm;?`0:Bcl80004Bcl00`00Bcm;?`0GBcl00`00
Bcm;?`08Bcl5000:Bcl00`00Bcm;?`0GBcl01000Bcm;?d/o1P0044/o00<004/oBcl03T/o1P000d/o
00<004/oBcl05d/o00<004/oBcl024/o1P002T/o00<004/oBcl04d/o1`005d/o00<004/oBcl00T/o
20003T/o00<004/oBcl03T/o1P000d/o00<004/oBcl05D/o1P005d]O00@004]OBem;G`H0019;G`03
001;Gd]O00M;G`H000Y;G`03001;Gd]O00];G`D000Q;G`03001;Gd]O00];G`D000Q;G`05001oogoo
Ool0002:Ool00?moohEoo`L003Uoo`P001E;?`03001;?d/o00Y;?`P000A;?`03001;?d/o01M;?`03
001;?d/o00Y;?`P000A;?`03001;?d/o01Q;?`03001;?d/o009;?`L000e;?`03001;?d/o01M;?`04
001;?d/oBcl6000@Bcl00`00Bcm;?`0CBcl7000GBcl00`00Bcm;?`07Bcl6000:Bcl00`00Bcm;?`0G
Bcl01000Bcm;?d/o1P004D/o00<004/oBcl02T/o200014/o00<004/oBcl05D/o1`005d/o00<004/o
Bcl01d/o1P002T/o00<004/oBcl03T/o1P000d/o00<004]OBel05D]O1P0064]O00@004]OBem;G`H0
015;G`03001;Gd]O00E;G`D000=;G`03001;Gd]O00Q;G`03001;Gd]O00E;G`D000i;G`05001oogoo
Ool00029Ool00?moogioo`P003Moo`P000A;?`03001;?d/o01M;?`03001;?d/o009;?`L000e;?`03
001;?d/o01M;?`03001;?d/o009;?`L000e;?`03001;?d/o01E;?`L001E;?`03001;?d/o01=;?`L0
01I;?`03001;?d/o00];?`P000A;?`03001;?d/o01M;?`04001;?d/oBcl6000ABcl00`00Bcm;?`0C
Bcl7000GBcl00`00Bcm;?`02Bcl8000=Bcl00`00Bcm;?`0>Bcl60003Bcl00`00Bcm;?`0HBcl01000
Bcm;?d/o1P004D/o00<004/oBcl01d/o1P002T/o00<004]OBel03T]O1P000dmO00<004]OBel05T]O
1P005d]O00<004]OBel01@0024]O00<004]OBel024]O00<004]OBel01@004d]O00D007ooOomoo`00
08Uoo`00ogooMgoo1`001goo00<007ooOol0;Woo1`003D/o00<004/oBcl054/o1`005D/o00<004/o
Bcl04d/o20005D/o00<004/oBcl03T/o1P000d/o00<004/oBcl05T/o00<004/oBcl02d/o200014/o
00<004/oBcl05d/o00<004/oBcl00T/o20003D/o00<004/oBcl04d/o1`005d/o00<004/oBcl02d/o
200014/o00<004/oBcl05D/o1`005T/o00<004/oBcl01d/o1P002T/o00<004/oBcl05D/o1P005d/o
00@004/oBcm;?`H0015;?`03001;Gd]O00M;G`H000Y?G`03001;Gd]O00m;G`H000=?G`03001;Gd]O
01E;G`D000e;G`03001;Gd]O00M;G`@001M;G`<000=oo`03001oogoo08Ioo`00ogooKgoo20003Woo
00<007ooOol09Woo20005D/o00<004/oBcl03D/o1P000d/o00<004/oBcl05d/o00<004/oBcl02T/o
200014/o00<004/oBcl05d/o00<004/oBcl024/o1@002T/o00<004/oBcl05T/o00<004/oBcl00T/o
20003D/o00<004/oBcl04d/o20005T/o00<004/oBcl02T/o200014/o00<004/oBcl064/o00<004/o
Bcl00T/o20003D/o00<004/oBcl03T/o1P000d/o00<004/oBcl05d/o00@004/oBcm;?`H0015;?`03
001;?d/o00i;?`H000=;?`03001;?d/o01E;?`H001M;?`04001;Gd]OBel6000ACel00`00Bem;G`07
Bel7000:Cel00`00Bem;G`0>Bel60003Cel00`00Bem;G`0<Bel00`00Bem;G`02Bel50002Cel00`00
Bem;G`0ABel50002Cel01@00Oomoogoo0000R7oo003oOomXOol7000FOol00`00Oomoo`0NOol80004
Bcl00`00Bcm;?`0FBcl00`00Bcm;?`08Bcl5000:Bcl00`00Bcm;?`0GBcl00`00Bcm;?`02Bcl7000=
Bcl00`00Bcm;?`0GBcl01000Bcm;?d/o1P0044/o00<004/oBcl04T/o20005T/o00<004/oBcl02T/o
200014/o00<004/oBcl064/o00<004/oBcl00T/o1`003D/o00<004/oBcl05D/o1`005T/o00<004/o
Bcl01d/o1P002T/o00<004/oBcl054/o1P005d/o00<004/oBcl024/o1P002T/o00<004/oBcl03T/o
1P000dlo00<004/oBcl05T/o1@005dmO00@004]OBem;G`H0015?G`03001;Gd]O00M;G`L000Y?G`03
001;Gd]O00];G`D000Q?G`03001;Gd]O00];G`D000Q?G`05001oogooOol00027Ool00?moof5oo`L0
01eoo`03001oogoo01Moo`L000e;?`03001;?d/o01I;?`04001;?d/oBcl6000@Bcl00`00Bcm;?`0C
Bcl8000EBcl00`00Bcm;?`0CBcl7000FBcl00`00Bcm;?`0:Bcl80004Bcl00`00Bcm;?`0HBcl00`00
Bcm;?`02Bcl7000=Bcl00`00Bcm;?`0EBcl7000EBcl00`00Bcm;?`0>Bcl60003Bcl00`00Bcm;?`0G
Bcl01000Bcm;?d/o1P004D/o00<004/oBcl03D/o1P000d/o00<004/oBcl064/o00@004/oBcm;?`H0
015;?`03001;?d/o00M;?`H000Y??`03001;?d/o011;?`D0009??`03001?GdmO01I?G`D001M?G`04
001;Gd]OBel6000ACel00`00Bem;G`06Bel6000<Cel00`00Bem;G`06Bel5000=Cel01@00Oomoogoo
0000Qgoo003oOomJOol7000TOol00`00Oomoo`0?Ool8000EBcl00`00Bcm;?`0BBcl7000GBcl00`00
Bcm;?`0:Bcl80004Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0;Bcl80004Bcl00`00Bcm;?`0GBcl00`00
Bcm;?`02Bcl7000=Bcl00`00Bcm;?`0EBcl7000EBcl00`00Bcm;?`0>Bcl60003Bcl00`00Bcm;?`0F
Bcl00`00Bcm;?`08Bcl6000:Bcl00`00Bcm;?`0DBcl6000GBcl00`00Bcm;?`08Bcl5000:Bcl00`00
Bcm;?`0EBcl6000GBcl01000Bcm;?d/o1P0044lo00<004/oBcl02d/o1@0024lo00<004mOCel044mO
1@000TmO00<004mOCel05DmO1P005dmO00@004]OBem;G`D000E?G`03001?GdmO00Y?G`04001;Gd]O
Bel5000BCel00`00Oomoo`02Ool00`00Oomoo`24Ool00?mooe=oo`L003Eoo`P000A;?`03001;?d/o
01M;?`03001;?d/o00Y;?`L000E;?`03001;?d/o01M;?`03001;?d/o009;?`L000e;?`03001;?d/o
01I;?`03001;?d/o009;?`P000e;?`03001;?d/o01=;?`P001E;?`03001;?d/o00i;?`H000=;?`03
001;?d/o01I;?`03001;?d/o00Q;?`H000Y;?`03001;?d/o01I;?`04001;?d/oBcl6000ABcl00`00
Bcm;?`0=Bcl60003Bcl00`00Bcm;?`0HBcl01000Bcm;?d/o1P0044/o00<004/oBcl03T/o1P000dlo
00<004/oBcl05D/o1P005dlo00<004/oBcl01D/o1@003Dlo00<004mOCel02dmO1@0024mO00<004mO
Cel03TmO1P000dmO00<004mOCel05DmO1P002TmO00<004mOCel024mO1P005TmO0`000goo00<007oo
Ool0Q7oo003oOom;Ool80005Ool00`00Oomoo`0]Ool7000=Bcl00`00Bcm;?`0GBcl00`00Bcm;?`02
Bcl7000=Bcl00`00Bcm;?`0CBcl8000EBcl00`00Bcm;?`0BBcl8000FBcl00`00Bcm;?`0:Bcl80004
Bcl00`00Bcm;?`0GBcl00`00Bcm;?`08Bcl5000:Bcl00`00Bcm;?`0FBcl01000Bcm;?d/o1P004D/o
00<004/oBcl04T/o1`005d/o00<004/oBcl024/o1@002T/o00<004/oBcl05D/o1P005T/o00<004/o
Bcl024/o1P002Tlo00<004/oBcl03T/o1P000dlo00<004loCcl05dlo00<004/oBcl01@004dlo00<0
04mOCel01DmO1@003TmO00<004mOCel01dmO1P002TmO00<004mOCel03TmO1P000dmO00<004mOCel0
2TmO00<004mOCel00TmO1P000dmO00<004mOCel04DmO1@000TmO00<007ooOol00Woo00<007ooOol0
Pgoo003oOom4Ool7000=Ool00`00Oomoo`0UOol8000EBcl00`00Bcm;?`0CBcl8000EBcl00`00Bcm;
?`0:Bcl80004Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0:Bcl80005Bcl00`00Bcm;?`0GBcl00`00Bcm;
?`02Bcl7000=Bcl00`00Bcm;?`0GBcl01000Bcm;?d/o1P0044/o00<004/oBcl04T/o1`005d/o00<0
04/oBcl02T/o200014/o00<004/oBcl064/o00@004/oBcm;?`H0011;?`03001;?d/o00i;?`H000=?
?`03001;?d/o01M;?`04001;?d/oBcl6000ACcl00`00Bcm;?`07Bcl6000:Ccl00`00Ccm??`0DCcl5
000HCcl00`00Cem?G`05000CCel01000Cem?GdmO1P004DmO00<004mOCel01dmO1P002TmO00<004mO
Cel024mO1P002TmO00<004mOCel02dmO1@0024mO00D007ooOomoo`0008Eoo`00ogoo?Goo1`0057oo
00<007ooOol07Woo1`0014/o00<004/oBcl05d/o00<004/oBcl02T/o200014/o00<004/oBcl05d/o
00<004/oBcl00T/o1`003D/o00<004/oBcl05T/o00<004/oBcl00T/o1`003T/o00<004/oBcl04d/o
20005D/o00<004/oBcl04d/o1`005T/o00<004/oBcl02T/o200014/o00<004/oBcl064/o00<004/o
Bcl00T/o1`003D/o00<004/oBcl054/o1`005T/o00<004/oBcl024/o1P002Tlo00<004/oBcl054/o
1P005dlo00@004/oBcm;?`H0011??`03001??dlo00i??`H000=??`03001??dlo01E??`D001M?G`D0
01M?G`04001?GdmOCel6000ACel01000Cem?GdmO1P0000=?G`00Cel03TmO00<004mOCel01DmO1@00
3DmO00<007ooOol00Woo00<007ooOol0PWoo003oOolfOol7000KOol00`00Oomoo`0GOol7000<Bcl0
0`00Bcm;?`0GBcl00`00Bcm;?`02Bcl7000=Bcl00`00Bcm;?`0CBcl8000EBcl00`00Bcm;?`0BBcl8
000FBcl00`00Bcm;?`0:Bcl80004Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0;Bcl80004Bcl00`00Bcm;
?`0GBcl00`00Bcm;?`02Bcl7000=Bcl00`00Bcm;?`0DBcl8000EBcl00`00Bcm;?`0;Bcl80004Bcl0
0`00Bcm;?`0GBcl01000Bcm;?d/o1P0044lo00<004/oBcl03T/o1P000dlo00<004loCcl05Dlo1P00
5dlo00<004loCcl01dlo1P002Tlo00<004loCcl03Tlo1P000dlo00<004mOCel04DmO1@000TmO00<0
04mOCel05TmO1@005TmO1@001dmO00<004mOCel03DmO00<004mOCel01@004DmO0`000goo00<007oo
Ool0PWoo003oOol_Ool7000ROol00`00Oomoo`0@Ool7000DBcl00`00Bcm;?`0CBcl8000EBcl00`00
Bcm;?`0:Bcl80004Bcl00`00Bcm;?`0GBcl00`00Bcm;?`0:Bcl70004Bcl00`00Bcm;?`0HBcl00`00
Bcm;?`02Bcl7000=Bcl00`00Bcm;?`0FBcl00`00Bcm;?`02Bcl8000=Bcl00`00Bcm;?`0CBcl8000E
Bcl00`00Bcm;?`0;Bcl80004Bcl00`00Bcm;?`0GBcl00`00Bcm;?`02Bcl8000=Bcl00`00Bcm;?`0C
Bcl7000GCcl00`00Bcm;?`07Bcl6000:Ccl00`00Ccm??`0>Ccl60003Ccl00`00Ccm??`0GCcl01000
Ccm??dlo1P004Dlo00<004loCcl01dlo1P002Tlo00<004mOCel02dmO1@0024mO00<004mOCel044mO
1@000TmO00<004mOCel04DmO1@000TmO00<004mOCel024mO00<004mOCel02TmO1@004DmO1@000TmO
00<007ooOol00Woo00<007ooOol0PGoo003oOolXOol7000gOol50003Bcl00`00Bcm;?`0FBcl00`00
Bcm;?`0:Bcl80005Bcl00`00Bcm;?`0FBcl00`00Bcm;?`02Bcl7000=Bcl00`00Bcm;?`0GBcl00`00
Bcm;?`02Bcl7000<Bcl00`00Bcm;?`0EBcl7000EBcl00`00Bcm;?`0BBcl8000FBcl00`00Bcm;?`0:
Bcl80004Bcl00`00Bcm;?`0GBcl00`00Bcm;?`02Bcl8000=Bcl00`00Bcm;?`0DBcl7000FBcl00`00
Bcm;?`0:Bcl80004Ccl00`00Ccm??`0GCcl01000Bcm;?d/o1P004Dlo00<004loCcl01dlo1P002Tlo
00<004loCcl054lo1P005dlo00@004loCcm??`H0015??`03001?GdmO00E?G`D000e?G`03001?GdmO
00]?G`D000Q?G`03001?GdmO00]?G`D000Q?G`03001?GdmO00M?G`03001?GdmO00A?G`H000=?G`03
001?GdmO00]?G`D000Q?G`05001oogooOol00023Ool00?moob1oo`P000=oo`03001oogoo039oo`H0
00U;?`03001;?d/o01I;?`03001;?d/o009;?`L000i;?`03001;?d/o019;?`P001E;?`03001;?d/o
01=;?`P001A;?`03001;?d/o00i;?`H000=;?`03001;?d/o01I;?`03001;?d/o00Y;?`P000A;?`03
001;?d/o01Q;?`03001;?d/o009;?`L000e;?`03001;?d/o01A;?`L001I;?`03001;?d/o00e;?`H0
00=;?`03001;?d/o01M;?`03001;?d/o009;?`P000e??`03001??dlo01=??`L001M??`04001??dlo
Ccl6000@Ccl00`00Ccm??`0>Ccl60003Ccl00`00Ccm??`0ECcl6000GCcl00`00Cem?G`05000CCel0
0`00Cem?G`05Cel5000>Cel00`00Cem?G`05Cel5000>Cel00`00Cem?G`06Cel7000:Cel00`00Cem?
G`05Cel5000>Cel01@00Oomoogoo0000PWoo003oOolIOol7000;Ool00`00Oomoo`0]Ool5000@Bcl0
0`00Bcm;?`0BBcl8000FBcl00`00Bcm;?`0:Bcl70004Bcl00`00Bcm;?`0GBcl00`00Bcm;?`0:Bcl8
0004Bcl00`00Bcm;?`0FBcl00`00Bcm;?`08Bcl5000:Bcl00`00Bcm;?`0FBcl00`00Bcm;?`02Bcl7
000=Bcl00`00Bcm;?`0EBcl7000EBcl00`00Bcm;?`0=Bcl60003Bcl00`00Bcm;?`0GBcl00`00Bcm;
?`08Bcl5000:Bcl00`00Bcm;?`0DBcl7000FCcl00`00Ccm??`0:Ccl80004Ccl00`00Ccm??`0ECcl6
000GCcl00`00Ccm??`07Ccl6000:Ccl00`00Ccm??`0>Ccl60003Ccl00`00Ccm??`0ECcl5000HCel0
0`00Cem?G`05000CCel00`00Cem?G`05000CCel01000Cem?GdmO1P0044mO00<004mOCel01@004dmO
00<007ooOol00Woo00<007ooOol0Ogoo003oOolBOol7000BOol00`00Oomoo`0VOol7000FBcl00`00
Bcm;?`0:Bcl70005Bcl00`00Bcm;?`0GBcl00`00Bcm;?`02Bcl7000<Bcl00`00Bcm;?`0GBcl00`00
Bcm;?`02Bcl7000=Bcl00`00Bcm;?`0FBcl01000Bcm;?d/o1P0044/o00<004/oBcl04T/o20005D/o
00<004/oBcl03T/o1P000d/o00<004/oBcl05T/o00<004/oBcl024/o1@002T/o00<004/oBcl05d/o
00@004/oBcm;?`H0011;?`03001;?d/o00e;?`H000=??`03001??dlo01M??`03001??dlo009??`P0
00e??`03001??dlo00i??`H000=??`03001??dlo01M??`04001??dloCcl6000ACcl00`00Ccm??`07
Ccl6000:Ccl00`00Ccm??`0>Ccl60003Cel00`00Cem?G`0ECel5000GCel4000GCel50005Cel00`00
Cem?G`0=Cel4000GCel30003Ool00`00Oomoo`1oOol00?moo`]oo`L001Uoo`03001oogoo01ioo`P0
00E;?`03001;?d/o01I;?`03001;?d/o009;?`L000e;?`03001;?d/o01=;?`P001A;?`03001;?d/o
01=;?`P001E;?`03001;?d/o019;?`L001I;?`03001;?d/o00Y;?`P000A;?`03001;?d/o01M;?`03
001;?d/o00Q;?`D000Y;?`03001;?d/o01I;?`04001;?d/oBcl6000@Bcl00`00Bcm;?`0CBcl7000F
Bcl00`00Bcm;?`08Bcl5000:Ccl00`00Ccm??`0DCcl7000FCcl00`00Ccm??`08Ccl5000:Ccl00`00
Ccm??`0DCcl6000GCcl01000Ccm??dlo1P004Dlo00<004loCcl01dlo1P002TmO00<004mOCel03TmO
1P000dmO00<004mOCel04DmO1@000TmO00<004mOCel04DmO1@000TmO00<004mOCel01DmO00<004mO
Cel024mO1@000TmO00<004mOCel04DmO1@000TmO00<007ooOol00Woo00<007ooOol0OWoo003oOol4
Ool7000POol00`00Oomoo`0GOol7000>Bcl00`00Bcm;?`0BBcl8000EBcl00`00Bcm;?`0:Bcl80004
Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0:Bcl80004Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0:Bcl80004
Bcl00`00Bcm;?`0GBcl00`00Bcm;?`02Bcl7000=Bcl00`00Bcm;?`0GBcl01000Bcm;?d/o1P0044/o
00<004/oBcl04T/o1`005T/o00<004/oBcl02d/o200014/o00<004/oBcl05d/o00@004/oBcm;?`H0
011??`03001??dlo00e??`H000=??`03001??dlo01Q??`04001??dloCcl6000@Ccl00`00Ccm??`0=
Ccl60003Ccl00`00Ccm??`0ECcl6000GCcl01000Ccm??dlo1P004DmO00<004mOCel01dmO1P002TmO
00<004mOCel02dmO1@0024mO00<004mOCel02dmO1@0024mO00<004mOCel014mO00<004mOCel00dmO
1@0024mO00<004mOCel02dmO1@0024mO00D007ooOomoo`00081oo`00ngoo20009goo00<007ooOol0
3goo20005T/o00<004/oBcl02T/o1`001D/o00<004/oBcl05T/o00<004/oBcl00T/o1`003D/o00<0
04/oBcl05T/o00<004/oBcl00T/o1`003D/o00<004/oBcl05T/o00<004/oBcl00T/o1`003D/o00<0
04/oBcl04d/o20005D/o00<004/oBcl04d/o1`005T/o00<004/oBcl02T/o200014/o00<004/oBcl0
5d/o00<004/oBcl00T/o20003D/o00<004/oBcl04d/o1`005Tlo00<004loCcl024lo1@002Tlo00<0
04loCcl05Dlo1P005Tlo00<004loCcl024lo1@002Tlo00<004loCcl03Tlo1P000dlo00<004loCcl0
5Dlo1P005dmO00@004mOCem?G`H0015?G`03001?GdmO00E?G`D000i?G`03001?GdmO00E?G`D000e?
G`03001?GdmO00A?G`H000i?G`03001?GdmO00E?G`D000e?G`03001oogoo009oo`03001oogoo07eo
o`00m7oo1`0017oo00<007ooOol0:7oo00<007ooOol027oo1`001D/o00<004/oBcl05d/o00<004/o
Bcl00T/o1`003D/o00<004/oBcl04T/o20005D/o00<004/oBcl04T/o20005D/o00<004/oBcl04T/o
20005D/o00<004/oBcl02T/o200014/o00<004/oBcl05d/o00<004/oBcl02T/o200014/o00<004/o
Bcl05d/o00<004/oBcl00T/o1`003D/o00<004/oBcl054/o1`005T/o00<004/oBcl02T/o200014lo
00<004loCcl05dlo00@004loCcm??`H0011??`03001??dlo00i??`H000=??`03001??dlo01M??`04
001??dloCcl6000@Ccl00`00Ccm??`08Ccl5000:Ccl00`00Ccm??`0>Ccl60003Ccl00`00Cem?G`0E
Cel6000GCel00`00Cem?G`05000CCel00`00Cem?G`05000BCel00`00Cem?G`05000CCel00`00Cem?
G`05000BCel00`00Oomoo`02Ool00`00Oomoo`1mOol00>eoo`L000]oo`03001oogoo02Qoo`04001o
ogooOol7000=Bcl00`00Bcm;?`0CBcl8000EBcl00`00Bcm;?`0:Bcl70004Bcl00`00Bcm;?`0GBcl0
0`00Bcm;?`0:Bcl70004Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0:Bcl80005Bcl00`00Bcm;?`0FBcl0
0`00Bcm;?`02Bcl7000=Bcl00`00Bcm;?`0GBcl00`00Bcm;?`02Bcl7000=Bcl00`00Bcm;?`0CBcl8
000EBcl00`00Bcm;?`0=Bcl60003Bcl00`00Bcm;?`0GBcl00`00Bcm;?`02Bcl8000=Ccl00`00Ccm?
?`0DCcl6000FCcl00`00Ccm??`08Ccl6000:Ccl00`00Ccm??`0DCcl6000GCcl01000Ccm??dlo1P00
44lo00<004loCcl01dlo1P002Tlo00<004mOCel03TmO1P000dmO00<004mOCel05DmO1@005dmO1000
5TmO100014mO00<004mOCel044mO10005TmO0`0017oo00<007ooOol0O7oo003VOol7000AOol00`00
Oomoo`0UOol8000EBcl00`00Bcm;?`0:Bcl80005Bcl00`00Bcm;?`0FBcl00`00Bcm;?`02Bcl7000<
Bcl00`00Bcm;?`0GBcl00`00Bcm;?`02Bcl7000<Bcl00`00Bcm;?`0FBcl00`00Bcm;?`02Bcl7000>
Bcl00`00Bcm;?`0BBcl8000EBcl00`00Bcm;?`0CBcl8000EBcl00`00Bcm;?`0:Bcl80004Bcl00`00
Bcm;?`0FBcl00`00Bcm;?`08Bcl5000:Bcl00`00Bcm;?`0DBcl7000ECcl00`00Ccm??`0>Ccl60003
Ccl00`00Ccm??`0GCcl01000Ccm??dlo1P0044lo00<004loCcl03Tlo1P000dlo00<004loCcl05Dlo
1P005Tlo00@004loCcm??`H0015??`03001?GdmO00M?G`H000Y?G`03001?GdmO00i?G`H000=?G`03
001?GdmO015?G`D0009?G`03001?GdmO011?G`D0009?G`03001?GdmO00=?G`03001?GdmO00]?G`D0
009?G`03001?GdmO011?G`D0009?G`03001oogoo009oo`03001oogoo07aoo`00ggoo1`0067oo00<0
07ooOol07Woo1`001D/o00<004/oBcl05T/o00<004/oBcl00T/o1`003T/o00<004/oBcl04T/o2000
54/o00<004/oBcl04d/o200054/o00<004/oBcl04T/o20005T/o00<004/oBcl02T/o1`0014/o00<0
04/oBcl05d/o00<004/oBcl02T/o200014/o00<004/oBcl05d/o00<004/oBcl00T/o1`003D/o00<0
04/oBcl05T/o00@004/oBcm;?`H0011;?`03001;?d/o00e;?`H000=??`03001??dlo01M??`03001?
?dlo00M??`H000Y??`03001??dlo01A??`H001M??`03001??dlo00M??`H000Y??`03001??dlo00i?
?`H000=??`03001??dlo01E??`D001M??`04001?GdmOCel6000ACel00`00Cem?G`07Cel6000:Cel0
0`00Cem?G`0;Cel50008Cel00`00Cem?G`0:Cel50008Cel00`00Cem?G`02Cel00`00Cem?G`06Cel5
0008Cel00`00Cem?G`0:Cel50008Cel00`00Oomoo`02Ool00`00Oomoo`1kOol00=Moo`P001moo`03
001oogoo01Moo`L000e;?`03001;?d/o019;?`P001I;?`03001;?d/o00Y;?`L000A;?`03001;?d/o
01I;?`03001;?d/o00Y;?`P000A;?`03001;?d/o01I;?`03001;?d/o00Y;?`L000E;?`03001;?d/o
01M;?`03001;?d/o009;?`L000a;?`03001;?d/o01M;?`03001;?d/o009;?`L000e;?`03001;?d/o
01=;?`P001E;?`03001;?d/o019;?`L001I;?`03001;?d/o00Q;?`D000Y??`03001??dlo01I??`04
001??dloCcl6000@Ccl00`00Ccm??`0>Ccl60003Ccl00`00Ccm??`0GCcl01000Ccm??dlo1P004Dlo
00<004loCcl01dlo1P002Tlo00<004loCcl03dlo1@000Tlo00<004loCcl05Tlo1@005dmO00@004mO
Cem?G`H0015?G`03001?GdmO00E?G`D000e?G`03001?GdmO00E?G`D000i?G`05001?GdmOCel00003
Cel5000=Cel00`00Cem?G`05Cel5000>Cel01@00Oomoogoo0000OGoo003@Ool7000iOol8000EBcl0
0`00Bcm;?`0:Bcl70006Bcl00`00Bcm;?`0FBcl00`00Bcm;?`02Bcl7000<Bcl00`00Bcm;?`0FBcl0
0`00Bcm;?`02Bcl7000=Bcl00`00Bcm;?`0FBcl00`00Bcm;?`02Bcl7000=Bcl00`00Bcm;?`0CBcl8
000DBcl00`00Bcm;?`0CBcl8000EBcl00`00Bcm;?`0:Bcl80004Bcl00`00Bcm;?`0FBcl00`00Bcm;
?`0:Bcl80004Bcl00`00Bcm;?`0GBcl01000Bcm;?d/o1P0044lo00<004loCcl04Tlo1`005dlo00<0
04loCcl01dlo1P002Tlo00<004loCcl054lo1P005dlo00@004loCcm??`H0011??`03001??dlo00Y?
?`D000Q??`03001??dlo011??`D0009??`03001?GdmO01I?G`D001M?G`03001?GdmO00D0019?G`03
001?GdmO00D001=?G`03001?GdmO00D0019?G`03001?GdmO00D0019?G`<000=oo`03001oogoo07Yo
o`00bGoo1`000goo00<007ooOol0<goo1`001D/o00<004/oBcl05T/o00<004/oBcl00T/o1`003T/o
00<004/oBcl04T/o200054/o00<004/oBcl04T/o20005D/o00<004/oBcl044/o2P005D/o00<004/o
Bcl02T/o200014/o00<004/oBcl05T/o00<004/oBcl02T/o200014/o00<004/oBcl05d/o00<004/o
Bcl00T/o1`003D/o00<004/oBcl05T/o00<004/oBcl00T/o1`003D/o00<004/oBcl04d/o1`005Tlo
00<004loCcl02Tlo200014lo00<004loCcl05dlo00@004loCcm??`H0011??`03001??dlo00i??`H0
00=??`03001??dlo01E??`H001M??`03001??dlo00E??`@000i??`03001??dlo00Y??`D000Q??`03
001?GdmO011?G`D0009?G`03001?GdmO01E?G`D001I?G`@001M?G`@00003Cel004mO01=?G`@0019?
G`D0009?G`05001oogooOol0001lOol00<9oo`L000Yoo`03001oogoo02aoo`L000e;?`03001;?d/o
019;?`P001I;?`03001;?d/o00Y;?`L000A;?`03001;?d/o01I;?`03001;?d/o00Y;?`L000E;?`03
001;?d/o01I;?`03001;?d/o00A;?`/000M;?`03001;?d/o01I;?`03001;?d/o009;?`L000e;?`03
001;?d/o01I;?`03001;?d/o009;?`L000e;?`03001;?d/o01A;?`L001E;?`03001;?d/o019;?`P0
01E;?`03001;?d/o00Y;?`P000A??`03001??dlo01M??`03001??dlo009??`L000e??`03001??dlo
01=??`L001M??`03001??dlo00M??`H000Y??`03001??dlo00i??`H000=??`03001??dlo01M??`03
001??dlo00D0019??`03001??dlo00I??`@000e??`03001?GdmO00]?G`D000Q?G`03001?GdmO00i?
G`H000=?G`03001?GdmO011?G`D0009?G`03001?GdmO015?G`D0009?G`04001?GdmO000?Cel50002
Cel00`00Cem?G`0<Cel50008Cel01@00Oomoogoo0000Ngoo002kOol7000AOol00`00Oomoo`0TOol8
000EBcl00`00Bcm;?`0:Bcl70006Bcl00`00Bcm;?`0FBcl00`00Bcm;?`02Bcl7000<Bcl00`00Bcm;
?`0FBcl00`00Bcm;?`02Bcl7000=Bcl00`00Bcm;?`0BBcl:000CBcl00`00Bcm;?`0BBcl8000EBcl0
0`00Bcm;?`0BBcl8000EBcl00`00Bcm;?`0=Bcl60003Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0:Bcl8
0004Bcl00`00Bcm;?`0GBcl00`00Bcm;?`02Bcl7000=Ccl00`00Ccm??`0DCcl7000ECcl00`00Ccm?
?`0:Ccl80004Ccl00`00Ccm??`0GCcl01000Ccm??dlo1P004Dlo00<004loCcl01dlo1P002Tlo00<0
04loCcl054lo1@0064lo00<004loCcl01@004Tlo00<004mOCel01DmO1@003TmO00<004mOCel01dmO
1P002TmO00<004mOCel02TmO1@0024mO00<004mOCel02dmO1@0024mO00<004mO00002TmO1@0024mO
00<004mOCel01TmO1@003DmO00D007ooOomoo`0007]oo`00/goo200067oo00<007ooOol07Goo1`00
1T/o00<004/oBcl05D/o00<004/oBcl00T/o1`003T/o00<004/oBcl04T/o200054/o00<004/oBcl0
4T/o20005D/o00<004/oBcl02T/o1`0014/o00<004/oBcl05d/o00<004/oBcl02T/o1`0014/o00<0
04/oBcl05T/o00<004/oBcl02T/o200014/o00<004/oBcl05T/o00<004/oBcl024/o1@002T/o00<0
04/oBcl05T/o00<004/oBcl00T/o1`003D/o00<004/oBcl054/o1`005Dlo00<004loCcl03Dlo1P00
0dlo00<004loCcl05dlo00<004loCcl00Tlo1`003Dlo00<004loCcl04dlo1`005dlo00@004loCcm?
?`H0011??`03001??dlo00i??`H000=??`03001??dlo01E??`D001M??`03001?GdmO00D001=?G`04
001?GdmOCel6000@Cel00`00Cem?G`05Cel5000>Cel00`00Cem?G`05Cel5000=Cel00`00Cel00005
Cel5000>Cel00`00Cem?G`05000BCel00`00Oomoo`02Ool00`00Oomoo`1hOol00:aoo`L0021oo`03
001oogoo01Ioo`L000i;?`03001;?d/o019;?`L001I;?`03001;?d/o00Y;?`L000E;?`03001;?d/o
01E;?`03001;?d/o00Y;?`L000E;?`03001;?d/o01I;?`03001;?d/o009;?`L000a;?`03001;?d/o
01M;?`03001;?d/o009;?`L000a;?`03001;?d/o01I;?`03001;?d/o009;?`L000e;?`03001;?d/o
01I;?`04001;?d/oBcl6000@Bcl00`00Bcm;?`0BBcl8000EBcl00`00Bcm;?`0=Bcl60003Bcl00`00
Ccm??`0FCcl00`00Ccm??`08Ccl5000:Ccl00`00Ccm??`0DCcl7000ECcl00`00Ccm??`0:Ccl80004
Ccl00`00Ccm??`0ECcl6000GCcl00`00Ccm??`07Ccl6000:Ccl00`00Ccm??`0>Ccl60003Ccl00`00
Ccm??`0DCcl5000GCel5000FCel00`00Cem?G`05000CCel00`00Cem?G`05000BCel00`00Cel00005
000BCel4000FCel30003Ool00`00Oomoo`1hOol00:Eoo`L003Uoo`L001I;?`03001;?d/o00Y;?`L0
00E;?`03001;?d/o01I;?`03001;?d/o009;?`L000e;?`03001;?d/o01E;?`03001;?d/o009;?`L0
00e;?`03001;?d/o019;?`P001A;?`03001;?d/o01=;?`P001A;?`03001;?d/o019;?`P001E;?`03
001;?d/o019;?`L001I;?`03001;?d/o00Y;?`P000A;?`03001;?d/o01I;?`03001;?d/o00Q;?`D0
00Y;?`03001??dlo01I??`04001??dloCcl6000@Ccl00`00Ccm??`0=Ccl60003Ccl00`00Ccm??`0G
Ccl00`00Ccm??`02Ccl7000=Ccl00`00Ccm??`0>Ccl60003Ccl00`00Ccm??`0GCcl01000Ccm??dlo
1P004Dlo00<004loCcl01dlo1P002Tlo00<004loCcl03Dlo1P000dlo00<004mOCel04DmO1@000TmO
00<004mOCel054mO1@005dmO10005TmO10004TmO1@000TmO00<004mOCel044mO1@000TmO00<007oo
Ool00Woo00<007ooOol0Mgoo002NOol70003Ool00`00Oomoo`0cOol70005Bcl00`00Bcm;?`0FBcl0
0`00Bcm;?`02Bcl7000=Bcl00`00Bcm;?`0BBcl8000EBcl00`00Bcm;?`0@Bcl9000EBcl00`00Bcm;
?`0:Bcl70004Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0:Bcl80004Bcl00`00Bcm;?`0FBcl00`00Bcm;
?`0:Bcl70004Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0:Bcl80004Bcl00`00Bcm;?`0GBcl00`00Bcm;
?`02Bcl7000=Bcl00`00Bcm;?`0FBcl01000Bcm;?d/o1P0044/o00<004loCcl04Tlo1`005Tlo00<0
04loCcl024lo1@002Tlo00<004loCcl054lo1`005Dlo00<004loCcl024lo1@002Tlo00<004loCcl0
54lo1P005dlo00@004loCcm??`H0015??`03001??dlo00M??`D000Y??`03001?GdmO00]?G`D000Q?
G`03001?GdmO00e?G`H000=?G`03001?GdmO015?G`D0009?G`03001?GdmO011?G`D0009?G`8000e?
G`D000Q?G`03001?GdmO00Y?G`D000Q?G`05001oogooOol0001iOol009Moo`L000Yoo`03001oogoo
02aoo`L000e;?`03001;?d/o019;?`P001E;?`03001;?d/o00Y;?`L000E;?`03001;?d/o01I;?`03
001;?d/o00A;?`/000I;?`03001;?d/o01I;?`03001;?d/o009;?`L000a;?`03001;?d/o01I;?`03
001;?d/o009;?`L000e;?`03001;?d/o01I;?`03001;?d/o009;?`L000a;?`03001;?d/o01I;?`03
001;?d/o009;?`L000e;?`03001;?d/o01=;?`P001E;?`03001;?d/o019;?`L001I;?`03001??dlo
00Y??`P000A??`03001??dlo01M??`04001??dloCcl6000@Ccl00`00Ccm??`0=Ccl60003Ccl00`00
Ccm??`0GCcl01000Ccm??dlo1P0044lo00<004loCcl03Dlo1P000dlo00<004loCcl05Dlo1P005dlo
00@004loCcm??`H0011??`03001?GdmO00E?G`D000i?G`03001?GdmO00M?G`D000Y?G`03001?GdmO
00]?G`D000Q?G`03001?GdmO00Y?G`D000Q?G`03001?GdmO00I?G`D000e?G`03001?GdmO00E?G`D0
00e?G`03001oogoo009oo`03001oogoo07Ioo`00T7oo1`004Goo00<007ooOol097oo20005D/o00<0
04/oBcl02T/o1`001D/o00<004/oBcl05T/o00<004/oBcl00T/o1`003D/o00<004/oBcl04T/o2P00
4T/o00<004/oBcl04T/o200054/o00<004/oBcl04T/o20005D/o00<004/oBcl04T/o200054/o00<0
04/oBcl04T/o20005D/o00<004/oBcl02T/o200014/o00<004/oBcl05T/o00<004/oBcl02T/o2000
14/o00<004/oBcl05d/o00<004loCcl00Tlo1`003Dlo00<004loCcl04dlo1`005Tlo00<004loCcl0
24lo1@002Tlo00<004loCcl054lo1P005Tlo00<004loCcl024lo1@002Tlo00<004loCcl03Tlo1P00
0dlo00<004loCcl05Dlo1P005Tlo00<004mOCel01@004dmO00@004mOCem?G`H0011?G`03001?GdmO
00E?G`D000i?G`03001?GdmO00E?G`@000e?G`80009?G`D0019?G`03001?GdmO00D0015?G`<000=o
o`03001oogoo07Ioo`00R7oo200067oo00<007ooOol07Goo1`001DLo00<004/oBcl05T/o00<004/o
Bcl00T/o1`003D/o00<004/oBcl04T/o20005D/o00<004/oBcl02T/o1`0014/o00<004/oBcl05T/o
00<004/oBcl02T/o1`0014/o00<004/oBcl05T/o00<004/oBcl02T/o1`001D/o00<004/oBcl05D/o
00<004/oBcl02T/o200014/o00<004/oBcl05T/o00<004/oBcl02T/o1`001D/o00<004/oBcl05T/o
00<004/oBcl00T/o1`003D/o00<004/oBcl05T/o00<004/oBcl00T/o1`003D/o00<004/oBcl04d/o
20005Dlo00<004loCcl02Tlo200014lo00<004loCcl05dlo00@004loCcm??`H0011??`03001??dlo
00e??`H000=??`03001??dlo01M??`04001??dloCcl6000@Ccl00`00Ccm??`07Ccl6000:Ccl00`00
Ccm??`0>Ccl60003Ccl00`00Ccm??`0DCcl5000GCel5000FCel00`00Cem?G`05000CCel00`00Cem?
G`05000ACel4000FCel4000ACel50002Cgl00`00Oomoo`02Ool00`00Oomoo`1eOol0085oo`L0021o
o`03001oogoo01Ioo`L000e7?`03001;?d/o019;?`P001E;?`03001;?d/o00Y;?`L000E;?`03001;
?d/o01I;?`03001;?d/o009;?`L000a;?`03001;?d/o01I;?`03001;?d/o009;?`L000a;?`03001;
?d/o01I;?`03001;?d/o009;?`L000e;?`03001;?d/o01E;?`03001;?d/o009;?`L000e;?`03001;
?d/o01I;?`03001;?d/o009;?`L000e;?`03001;?d/o019;?`P001E;?`03001;?d/o019;?`P001E;
?`03001;?d/o00Y;?`P000A??`03001??dlo01M??`03001??dlo009??`L000e??`03001??dlo01A?
?`H001I??`03001??dlo00Q??`D000Y??`03001??dlo01A??`H001I??`04001??dloCcl6000ACcl0
0`00Ccm??`07Ccl6000:Ccl00`00Ccm??`0=Ccl60003Ccl00`00Cem?G`0ACel50002Cel00`00Cem?
G`0ECel4000GCel4000BCel500000dmO001?G`0ACel50002Cel00`00Cem?G`0;Cel50008Cgl01@00
Oomoogoo0000Mgoo001jOol7000hOol8000EAcl00`00Bcm;?`0:Bcl70005Acl00`00Bcm;?`0FBcl0
0`00Bcm;?`02Bcl7000=Bcl00`00Bcm;?`0BBcl8000DBcl00`00Bcm;?`0BBcl8000DBcl00`00Bcm;
?`0BBcl8000EBcl00`00Bcm;?`0@Bcl9000EBcl00`00Bcm;?`0@Bcl:000EBcl00`00Bcm;?`0:Bcl7
0004Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0:Bcl80004Bcl00`00Bcm;?`0GBcl00`00Bcm;?`02Bcl7
000=Ccl00`00Ccm??`0DCcl7000ECcl00`00Ccm??`0=Ccl60003Ccl00`00Ccm??`0GCcl01000Ccm?
?dlo1P003dlo00<004loCcl03Tlo1P000dlo00<004loCcl054lo1P005dlo00@004loCcm??`H0015?
?`03001??dlo00M??`D000Y??`03001?GdmO00]?G`D000Q?G`03001?GdmO00m?G`D0009?G`03001?
GdmO015?G`D0009?G`03001?GdmO00e?G`@000A?G`04001?GdmO000<Cel50008Cel00`00Cem?G`05
Cel5000=Cgl00`00Oomoo`02Ool00`00Oomoo`1dOol007=oo`L000=oo`03001oogoo039oo`L000I7
?`030017?dLo01E7?`03001;?d/o009;?`L000e7?`03001;?d/o019;?`P001E;?`03001;?d/o00Y;
?`L000E;?`03001;?d/o01E;?`03001;?d/o00Y;?`L000E;?`03001;?d/o01E;?`03001;?d/o00Y;
?`L000E;?`03001;?d/o01I;?`03001;?d/o00A;?`/000I;?`03001;?d/o01I;?`03001;?d/o00A;
?`/000I;?`03001;?d/o01M;?`03001;?d/o009;?`L000a;?`03001;?d/o01I;?`03001;?d/o009;
?`L000e;?`03001;?d/o01A;?`L001E??`03001??dlo00e??`H000=??`03001??dlo01I??`03001?
?dlo00Q??`D000Y??`03001??dlo01A??`H001I??`03001??dlo00M??`H000Y??`03001??dlo00e?
?`H000=??`03001??dlo01I??`D001M??`04001??dloCcl6000@Ccl00`00Cem?G`05Cel5000=Cel0
0`00Cem?G`0:Cel50008Cel00`00Cem?G`0;Cel50008Cel00`00Cem?G`08Cel40008Cel01000Cem?
G`001dmO1@003DmO00<004mOCel01@004Dmo0`000goo00<007ooOol0M7oo001/Ool7000:Ool00`00
Oomoo`0[Ool7000>Acl00`00Acm7?`0BAcl7000EAcl00`00Bcm;?`0:Bcl70005Acl00`00Bcm;?`0F
Bcl00`00Bcm;?`02Bcl7000=Bcl00`00Bcm;?`0EBcl00`00Bcm;?`02Bcl7000=Bcl00`00Bcm;?`0E
Bcl00`00Bcm;?`02Bcl7000=Bcl00`00Bcm;?`0BBcl:000BBcl00`00Bcm;?`0BBcl:000BBcl00`00
Bcm;?`0CBcl8000DBcl00`00Bcm;?`0BBcl8000EBcl00`00Bcm;?`0=Bcl60003Ccl00`00Ccm??`0F
Ccl00`00Ccm??`08Ccl5000:Ccl00`00Ccm??`0FCcl01000Ccm??dlo1P003dlo00<004loCcl03Tlo
1P000dlo00<004loCcl05Tlo00@004loCcm??`H0015??`03001??dlo00M??`D000Y??`03001??dlo
011??`D0009??`03001??dlo01I??`D001I??`03001?GdmO00D001=?G`03001?GdmO00E?G`@000i?
G`03001?GdmO00E?G`D000e?G`03001?GdmO00A?G`@000a?G`04001?GdmO0002Cel5000ACel4000B
Cgl40002Cgl00`00Oomoo`02Ool00`00Oomoo`1cOol006Qoo`@0015oo`03001oogoo02Aoo`L001I7
?`030017?dLo00Y7?`L000E7?`030017?dLo01E7?`03001;?d/o009;?`L000e7?`03001;?d/o019;
?`P001E;?`03001;?d/o011;?`T001E;?`03001;?d/o011;?`T001E;?`03001;?d/o00Y;?`L000A;
?`03001;?d/o01I;?`03001;?d/o00Y;?`L000A;?`03001;?d/o01I;?`03001;?d/o00Y;?`P000A;
?`03001;?d/o01E;?`03001;?d/o00Y;?`P000A;?`03001;?d/o01I;?`03001;?d/o00Q;?`D000Y?
?`03001??dlo01I??`04001??dloCcl6000@Ccl00`00Ccm??`0BCcl7000FCcl00`00Ccm??`07Ccl6
000:Ccl00`00Ccm??`0CCcl6000GCcl01000Ccm??dlo1P0044lo00<004loCcl02Tlo1@0024lo00<0
04loCcl044lo1@000Tlo00<004loCcl05Dlo100064mO00<004mOCel01@004TmO00<004mOCel01@00
4TmO00<004mOCel010004DmO1@004TmO10000TmO00<004moCgl03Dmo10001dmo00D007ooOomoo`00
07Eoo`00J7oo00<007oo00004Woo00<007ooOol07Goo1`001DLo00<004LoAcl05TLo00<004LoAcl0
0TLo1`003DLo0P004DLo2@005DLo00<004/oBcl02T/o1`001DLo00<004/oBcl05T/o00<004/oBcl0
14/o2`001T/o00<004/oBcl05T/o00<004/oBcl014/o2`001T/o00<004/oBcl05T/o00<004/oBcl0
0T/o1`0034/o00<004/oBcl05T/o00<004/oBcl00T/o1`0034/o00<004/oBcl05T/o00<004/oBcl0
0T/o1`003D/o00<004/oBcl05D/o00<004/oBcl00T/o1`003D/o00<004/oBcl05T/o00@004/oBcm;
?`H0011??`03001??dlo019??`L001I??`03001??dlo00Y??`P000A??`03001??dlo01I??`04001?
?dloCcl6000@Ccl00`00Ccm??`0=Ccl60003Ccl00`00Ccm??`0ECcl6000FCcl00`00Ccm??`06Ccl4
000=Ccl00`00Ccm??`0;Ccl50008Ccl00`00Ccm??`0?Ccl50002Ccl00`00Cem?G`0ECel5000FCel4
000FCel4000ACel50002Cel00`00Cem?G`0=Cel40007Cel00`00Cgm?O`09Cgl3000<Cgl01@00Oomo
ogoo0000M7oo001XOol01000Oomoo`004Goo00<007ooOol05Woo1`003DLo0P004TLo2@005TLo00<0
04LoAcl00dLo2`001dLo00<004LoAcl05DLo00<004/oBcl00T/o1`003DLo00<004/oBcl04T/o2P00
4T/o00<004/oBcl04T/o2P004T/o00<004/oBcl04T/o200054/o00<004/oBcl04T/o200054/o00<0
04/oBcl04T/o20005D/o00<004/oBcl04D/o20005D/o00<004/oBcl04T/o1`005Tlo00<004loCcl0
2Tlo200014lo00<004loCcl05dlo00<004loCcl00Tlo1`003Dlo00<004loCcl04Tlo1`005dlo00<0
04loCcl01dlo1@002Tlo00<004loCcl03Tlo1P000dlo00<004loCcl05dlo00<004loCcl01@004Tlo
00<004loCcl01Dlo1@003Dlo00<004loCcl02Tlo1@0024lo00<004mOCel03TmO1P000dmO00<004mO
Cel044mO1@000TmO00<004mOCel044mO1@000TmO00<004mOCel02dmO1@0014mO00D004mOCem?G`00
00]?G`<000a?G`03001?Odmo00A?O`@000m?O`05001oogooOol0001dOol006Qoo`04001oogooOol2
000QOol7000FAcl00`00Acm7?`04Acl;0007Acl00`00Acm7?`0BAcl9000CAcl00`00Acm7?`0BAcl7
000EAcl00`00Bcm;?`0:Bcl70004Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0:Bcl70004Bcl00`00Bcm;
?`0FBcl00`00Bcm;?`0:Bcl70004Bcl00`00Bcm;?`0FBcl00`00Bcm;?`0:Bcl70004Bcl00`00Bcm;
?`0FBcl00`00Bcm;?`0:Bcl70004Bal00`00Bcm;?`0FBcl00`00Bcm;?`0:Bcl70004Bal00`00Bcm;
?`0FBcl00`00Bcm;?`0:Bcl80004Bal00`00Ccm??`0GCcl00`00Ccm??`02Ccl7000=Ccl00`00Ccm?
?`0DCcl7000ECcl00`00Ccm??`09Ccl80004Cch00`00Ccm??`0GCcl01000Ccm??dlo1P0044lo00<0
04loCcl024lo1@002Tlo00<004loCcl054lo1@005dlo00<004loCcl01@004dlo00<004loCcl01Dlo
10003Tlo00<004mOCel01dmO1P002TmO00<004mOCel02TmO1@0024mO00<004mOCel02TmO1@0024mO
00<004mOCel01TmO10002DmO00<004mOCel00TmO00<004mOCel014mO10003dmO00<004moCgl01000
4Tmo0`000goo00<007ooOol0LGoo001XOol00`00Oomoo`03Ool00`00Oomoo`0GOol70005Acl00`00
Acm7?`0CAcl9000CAcl00`00Acm7?`0:Acl70005Acl00`00Acm7?`0EAcl00`00Acm7?`0:Acl70004
Acl00`00Acm7?`0FAcl00`00Bcm;?`02Bcl7000<Bcl00`00Bcm;?`0FBcl00`00Bcm;?`02Bcl7000<
Bcl00`00Bcm;?`0FBcl00`00Bcm;?`02Bcl7000<Bcl00`00Bcm;?`0FBcl00`00Bcm;?`02Bcl7000<
Bcl00`00Bcm;?`0FBcl00`00Bcm;?`02Bcl7000<Bal00`00Bcm;?`0FBcl00`00Bcm;?`02Bcl7000<
Bal00`00Bcm;?`0FBcl00`00Bcm;?`02Bcl7000=Bal00`00Ccm??`0CCcl8000ECcl00`00Ccm??`0=
Ccl60003Cch00`00Ccm??`0FCcl00`00Ccm??`02Ccl7000=Cch00`00Ccm??`0DCcl6000GCcl01000
Ccm??dlo1P003dlo00<004loCcl03Tlo1P000dlo00<004loCcl054lo1@0064lo00<004loCcl01@00
4Tlo00@004mOCem?G`H0011?G`03001?GdmO00E?G`D000i?G`03001?GdmO00E?G`@000i?G`03001?
GdmO00D000e?G`03001?GdmO009?G`03001?GdmO00@0019?G`@0015?O`D0009?O`03001oogoo009o
o`03001oogoo071oo`00J7oo00<007ooOol017oo00<007ooOol03goo1`003DLo0P0034Lo1`001DLo
00<004LoAcl05DLo00<004LoAcl00TLo1`003DLo00<004LoAcl05DLo00<004LoAcl00TLo1`0034Lo
00<004LoAcl04TLo200054/o00<004/oBcl04T/o200054/o00<004/oBcl04T/o200054/o00<004/o
Bcl04T/o200054/o00<004/oBcl04T/o200054/O00<004/oBcl04T/o200054/O00<004/oBcl04T/o
20005D/O00<004loCcl02Tlo200014lN00<004loCcl05Tlo00<004loCcl024lo1@002Tln00<004lo
Ccl04dlo1`005Dln00<004loCcl03Dlo1P000dln00<004loCcl05Dlo1P005Tlo00<004loCcl01dlo
1P002Tlo00<004loCcl03Dlo1P000dlo00<004loCcl05Dlo1@005Tlo1@005TmO00<004mOCel01@00
4dmO00<004mOCel01@004DmO10004TmO00@004mOCem?G`@0019?G`@0009?G`03001?Odmo00]?O`D0
00Q?O`05001oogooOol0001bOol004ioo`@001Ioo`03001oogoo00Eoo`8000Qoo`L001I7?`030017
?dLo0097?`L000e7?`030017?dLo0197?`L001E7?`030017?dLo0117?`T001A7?`030017?dLo00Y7
?`L000E7?`03001;?d/o01E;?`03001;?d/o00Y;?`L000E;?`03001;?d/o01E;?`03001;?d/o00Y;
?`L000A;?`03001;?d/o01E;?`03001;?d/o00Y;?`P000A;?`03001;?d/o01E;?`03001;?d/o00Y;
?`P000A;7`03001;7d/O01E;7`03001;?d/o00Y;?`P000A;7`03001;7d/O01I;7`03001;?d/o00Y;
?`L000A;7`03001;7d/O01M;7`03001??dlo009??`L000e?7P03001??dlo01I??`04001??dloCcl6
000?Cch00`00Ccm??`0=Ccl60003Cch00`00Cci??P0FCch00`00Ccm??`08Ccl5000:Cch00`00Ccm?
?`0>Ccl60003Cch00`00Ccm??`0FCcl01000Ccm??dlo1P004Dlo00<004loCcl01dlo1@002Tlo00<0
04loCcl03Tlo1P000dlo00<004loCcl044lo1@000Tlo00<004mOCel05DmO10005dmO10004TmO1000
0U=O00<004mOCel044mO1@000TmO00<004mOCel03DmO10001dmO00<004moCgl01Dmo1@003Dmo00<0
07ooOol00Woo00<007ooOol0Kgoo001<Ool8000DOol00`00Oomoo`07Ool80005Acl00`00Acm7?`0C
Acl7000EAcl00`00Acm7?`0:Acl70005Acl00`00Acm7?`0EAcl00`00Acm7?`04Acl;0007Acl00`00
Acm7?`0DAcl00`00Acm7?`02Acl7000=Acl00`00Bcm;?`0EBcl00`00Bcm;?`02Bcl7000=Bcl00`00
Bcm;?`0EBcl00`00Bcm;?`02Bcl7000<Bcl00`00Bcm;?`0EBcl00`00Bcm;?`02Bcl7000=Bcl00`00
Bcm;?`0EBcl00`00Bcm;?`02Bcl7000=Bal00`00Bam;7`0EBal00`00Bcm;?`02Bcl7000=Bal00`00
Bam;7`0FBal00`00Bcm;?`02Bcl7000<Bal00`00Bam;7`0DBal7000ECah00`00Ccm??`0BCcl7000F
Cch00`00Ccm??`07Ccl5000:Cch00`00Cci??P0FCch01000Ccm??dlo1P0044ln00<004loCcl024lo
1@002Tln00<004loCcl04dlo1P005dlo00@004loCcm??`H0011??`03001??dlo00M??`H000Y??`03
001??dlo00Y??`D000Q??`03001?GdmO00m?G`D0009?G`03001?GdmO015?G`D0009?G`03001?GdmO
00e?G`@000MCG`03001?GdmO00Y?G`D00003Cel004mO00E?G`03001?GdmO00Q?G`@000]?G`03001?
Odmo00D0015?O`<000=oo`03001oogoo06moo`00C7oo0P0017oo0P004goo00<007ooOol00Woo1`00
3DLo0P0034Lo1`001DLo00<004LoAcl05DLo00<004LoAcl00TLo1`003DLo00<004LoAcl04TLo2@00
4dLo00<004LoAcl03dLo2@005DLo00<004/oBcl044/o2@005D/o00<004/oBcl044/o2@0054/o00<0
04/oBcl044/o2@005D/o00<004/oBcl044/o2@005D/O00<004/OBal04D/O20005D/O00<004/OBal0
4T/O200054/O00<004/OBal03D/O1P000dlN00<004lNCah05TlN00<004loCcl02Tlo200014lN00<0
04lnCch05Tln00@004loCcm??`H0011??P03001??Tln019??PL001M??P04001??dloCcl6000?Cch0
0`00Ccm??`0=Ccl60003Cch00`00Ccm??`0FCcl5000FCcl01000Ccm??dlo1P004Dlo00<004loCcl0
1Dlo10003Dlo00<004mOCel02TmO1@0024mO00<004mOCel02dmO1@0024mO00<004mOCel024mO1000
2e=O00<004mOCel01DmO1@001TmO00<004mOCel014mO00<004mOCel014mO10003TmO10004Tmo1000
0U=o00<007ooOol00Woo00<007ooOol0KWoo001;Ool20006Ool2000BOol5000FAcl00`00Acm7?`02
Acl7000=Acl00`00Acm7?`0BAcl7000EAcl00`00Acm7?`0:Acl70004Acl00`00Acm7?`0FAcl00`00
Acm7?`03Acl;0007Acl00`00Acm7?`0EAcl00`00Bcm;?`04Bcl;0006Acl00`00Bcm;?`0FBcl00`00
Bcm;?`04Bcl;0005Bcl00`00Bcm;?`0FBcl00`00Bcm;?`04Bcl;0006Bcl00`00Bcm;?`0FBcl00`00
Bcm;?`04Bcl;0006Bal00`00Bam;7`0EBal00`00Bam;7`0:Bal70004Bal00`00Bam;7`0FBal00`00
Bam;7`0:Bal80004Bal00`00Bam;7`0EBal00`00Bam;7`08Bal5000:Cah00`00Cai?7P0FCah00`00
Ccm??`02Ccl7000=Cah00`00Cci??P0CCch6000FCch00`00Cci??P0:Cch80004Cch00`00Cci??P0E
Cch6000FCch00`00Ccm??`07Ccl5000:Cch00`00Ccm??`0@Ccl50002Cch00`00Ccm??`0ECcl5000G
Ccl00`00Ccm??`05000BCcl00`00Cem?G`05Cel4000>Cel00`00Cem?G`05Cel5000=Cel00`00Cem?
G`04Cel4000?Del00`00Cem?G`05000;Cel00`00Cem?G`04Cel00`00Cem?G`04000>Cel40002Del0
0`00Cgm?O`0=Cgl40007Dgl01@00Oomoogoo0000L7oo001;Ool20006Ool2000BOol01000Oomoo`00
5DLo1`005DLo00<004LoAcl02TLo1`0014Lo00<004LoAcl05TLo00<004LoAcl00TLo1`0034Lo00<0
04LoAcl04TLo2@004dLo00<004LoAcl04TLo2@004TLo00<004/oBcl04T/o2P004D/o00<004/oBcl0
4T/o2P004T/o00<004/oBcl04T/o2P004T/O00<004/OBal05D/O00<004/OBal00T/O1`0034/O00<0
04/OBal05T/O00<004/OBal00T/O1`003D/O00<004/OBal05D/O00@004/OBam;7`H0011?7P03001?
7TlN019?7PP001A?7P03001??Tln00e??PH000=??P03001??Tln01M??P03001??Tln009??PL000e?
?P03001??Tln00i??PH000=??P03001??Tln01I??P04001??dloCcl6000@Cch00`00Ccm??`0:Ccl5
0008Cch00`00Ccm??`0?Ccl50002Ccl00`00Ccm??`0FCcl4000GCcl00`00Cem?G`05000BCel00`00
Cem?G`05000BCel00`00Cem?G`04000BDel4000@Cel00`00Cem?G`03Cel4000>Cel40007Del00`00
Cgm?O`09Cgl3000;Dgl00`00Oomoo`02Ool00`00Oomoo`1]Ool004Yoo`8000Qoo`80015oo`04001o
ogooOol2000<Acl70005Acl00`00Acm7?`0EAcl00`00Acm7?`02Acl7000<Acl00`00Acm7?`0BAcl8
000DAcl00`00Acm7?`0:Acl70005Acl00`00Acm7?`0EAcl00`00Acm7?`0:Acl70004Acl00`00Acm7
?`0EAcl00`00Bcm;?`0:Bcl70005Bcl00`00Bcm;?`0DBcl00`00Bcm;?`0:Bcl70004Bcl00`00Bcm;
?`0FBcl00`00Bcm;?`0:Bcl70004Bal00`00Bam;7`0FBal00`00Bam;7`0@Bal9000DBal00`00Bam;
7`0BBal8000EBal00`00Bam;7`0ABal7000FCah00`00Cai?7P0:Cah80004Cah00`00Cai?7P0FCah0
0`00Cci??P07Cch5000:Cch00`00Cci??P0DCch7000ECch00`00Cci??P08Cch5000:Cch00`00Cci?
?P0CCch6000FCch00`00Ccm??`06Ccl4000=Cch00`00Ccm??`0:Ccl50008Ccl00`00Ccm??`0@Ccl5
0002Ccl00`00Ccm??`0ECcl4000FCel4000FCel4000BDel40002Del00`00Cem?G`0?Cel60002Del0
0`00Cem?G`0:Cel3000<Del00`00Cgm?O`04Cgl4000=Dgl30003Ool00`00Oomoo`1]Ool004Yoo`80
00Qoo`80015oo`03001oogoo00=oo`030017?dLo0097?`L000e7?`030017?dLo0117?`T001A7?`03
0017?dLo00Y7?`L000E7?`030017?dLo01E7?`030017?dLo0097?`L000e7?`030017?dLo01E7?`03
0017?dLo0097?`L000a7?`030017?dLo01E7?`03001;?d/o009;?`L000e;?`03001;?d/o01A;?`03
001;?d/o009;?`L000a;?`03001;?d/o01I;?`03001;?d/o009;?`L000a;7`03001;7d/O01I;7`03
001;7d/O00A;7`/000I;7`03001;7d/O01E;7`03001;7d/O00Y;7`L000A;7`03001;7d/O01I;7`03
001;7d/O00Y;7`L000E?7P03001?7TlN01I?7P03001?7TlN009?7PL000e?7P03001?7TlN01E?7P04
001??TlnCch6000@Cch00`00Cci??P0=Cch60003Cch00`00Cci??P0GCch01000Cci??Tln1P003dln
00<004lnCch03Dln1P000dln00<004lnCch05dln00<004loCcl01@004Tln00<004loCcl01Dlo1000
3Dlo00<004loCcl02dlo1@0024lo00<004loCcl03dlo1@000U=O00<004mOCel044mO1@000U=O00<0
04mOCel044mO1@000U=O00<005=ODel03E=O10001e=O00<004mOCel02TmO1@0025=O00<004mOCel0
1DmO10003e=O00<004moCgl010003E=o10000U=o00<007ooOol00Woo00<007ooOol0K7oo001:Ool2
0008Ool2000AOol00`00Oomoo`04Ool4000EAcl00`00Acm7?`04Acl;0007Acl00`00Acm7?`0DAcl0
0`00Acm7?`02Acl7000=Acl00`00Acm7?`0BAcl7000EAcl00`00Acm7?`0@Acl9000DAcl00`00Acm7
?`0@Acl9000EBcl00`00Bcm;?`0?Bcl9000DBcl00`00Bcm;?`0BBcl8000DBal00`00Bam;7`0BBal:
000BBal00`00Bam;7`0EBal00`00Bam;7`02Bal7000<Bal00`00Bam;7`0FBal00`00Bam;7`02Bal7
000=Cah00`00Cai?7P0BCah8000ECah00`00Cai?7P0ACah7000FCch00`00Cci??P08Cch5000:Cch0
0`00Cci??P0DCch6000FCch00`00Cci??P07Cch5000:Cch00`00Cci??P0DCch5000GCch00`00Ccm?
?`05000BCcl00`00Ccm??`05Ccl5000=Ccl00`00Ccm??`0:Ccl50008Del00`00Cem?G`0:Cel50008
Del00`00Cem?G`0:Cel50008Del00`00DemCG`09Del3000<Del00`00Cem?G`05Cel40004Del00`00
DemCG`07Del00`00Cem?G`04000BDel4000=Dgl40007Dgl01@00Oomoogoo0000KWoo001:Ool20008
Ool2000AOol00`00Oomoo`06Ool00`00Acm7?`0BAcl9000CAcl00`00Acm7?`0?Acl9000EAcl00`00
Acm7?`0:Acl70005Acl00`00Acm7?`0EAcl00`00Acm7?`04Acl;0006Acl00`00Acm7?`0EAcl00`00
Acm7?`04Acl;0006Acl00`00Bcm;?`0FBcl00`00Bcm;?`03Bcl;0006Bcl00`00Bcm;?`0EBcl00`00
Bcm;?`0:Bcl70004Bal00`00Bam;7`0FBal00`00Bam;7`0:Bal70004Bal00`00Bam;7`0FBal00`00
Bam;7`0@Bal9000DBal00`00Bam;7`0@Bal:000ECah00`00Cai?7P0:Cah70004Cah00`00Cai?7P0F
Cah00`00Cai?7P0:Cah70004Cah00`00Cci??P0GCch01000Cci??Tln1P0044ln00<004lnCch03Dln
1P000dln00<004lnCch05Tln00@004lnCci??PH0011??P03001??Tln00e??PH000=??P03001??Tln
01A??PD001M??`03001??dlo00D001=??`03001??dlo00E??`@000iCG`03001?GdmO00E?G`@000iC
G`03001?GdmO00E?G`@000iCG`03001CGe=O00ACG`@000mCG`03001?GdmO00D000QCG`03001CGe=O
00ICG`@0019CG`@0009CO`03001COe=o00UCO`<000aCO`05001oogooOol0001]Ool004Yoo`8000Qo
o`80015oo`03001oogoo00Moo`030017?dLo00Y7?`L000E7?`030017?dLo01E7?`030017?dLo00=7
?`/000M7?`030017?dLo01E7?`030017?dLo0097?`L000e7?`030017?dLo0197?`T00197?`030017
?dLo0197?`T00197?`03001;?d/o019;?`T0019;?`03001;?d/o01E;?`03001;?d/o009;?`L000a;
7`03001;7d/O01I;7`03001;7d/O009;7`L000a;7`03001;7d/O01I;7`03001;7d/O00A;7`/000E;
7`03001;7d/O01I;7`03001;7d/O00A;7`/000I;7P03001?7TlN01M?7P03001?7TlN009?7PL000a?
7P03001?7TlN01I?7P03001?7TlN009?7PL000a?7P03001??Tln01=??PL001I??P03001??Tln00Q?
?PD000Y??P03001??Tln01=??PH001I??P03001??Tln00Q??PD000Y??P03001??Tln00e??PH000=?
?P03001??dlo01A??`D001Q??`03001??dlo00D0019CG`03001?GdmO00D0019CG`03001?GdmO00D0
019CG`03001CGe=O00@0019CG`@000eCG`03001CGe=O009CG`@0009CG`03001CGe=O00eCG`@000MC
O`03001COe=o00ACO`@000mCO`05001oogooOol0001]Ool004Yoo`8000Qoo`80015oo`03001oogoo
00Qoo`030017?dLo0097?`L000e7?`030017?dLo0197?`P001=7?`800157?`T001E7?`030017?dLo
00Y7?`L000A7?`030017?dLo01E7?`030017?dLo00Y7?`L000A7?`030017?dLo01E7?`03001;?d/o
00Y;?`L000A;?`03001;?d/o01E;?`03001;?d/o011;?`T001A;7`03001;7d/O019;7`P001A;7`03
001;7d/O019;7`X0015;7`03001;7d/O019;7`X0019;7P03001?7TlN01=?7PP001A?7P03001?7TlN
019?7PP001A?7P03001??Tln00Y??PP000A?7P03001??Tln01M??P04001??TlnCch6000?Cch00`00
Cci??P0=Cch60003Cch00`00Cci??P0GCch01000Cci??Tln1P0044ln00<004lnCch01dln1@002Tln
00<004loCcl03Dlo1P000e<n00<004loCcl05Dlo1@005U=O10005U=O10005U=O10004U=O10000U=O
00<005=ODel035=O1@001e=O00<005=ODel025=O10002e=o00<005=oDgl010004U=o0`000goo00<0
07ooOol0JWoo001:Ool20008Ool2000AOol00`00Oomoo`09Ool4000EAcl00`00Acm7?`0:Acl70005
Acl00`00Acm7?`0EAcl00`00Acm7?`03Acl;0007Acl00`00Acm7?`0EAcl00`00Acm7?`02Acl7000<
Acl00`00Acm7?`0EAcl00`00Acm7?`02Acl7000<Acl00`00Acm7?`0EAcl00`00Bcm;?`02Bcl7000<
Bcl00`00Bcm;?`0EBcl00`00Bcm;?`04Bcl;0006Bcl00`00Bam;7`0EBal00`00Bam;7`0:Bal70004
Bal00`00Bam;7`0EBal00`00Bam;7`0:Bal80004Bal00`00Bam;7`0EBal00`00Bam;7`0:Bal70004
Bal00`00Bai;7P0FBah00`00Cai?7P0:Cah80004Cah00`00Cai?7P0ECah00`00Cai?7P0:Cah80004
Cah00`00Cai?7P0FCah00`00Cci??P02Cch7000=Cah00`00Cci??P0DCch6000FCch00`00Cci??P07
Cch5000:Cch00`00Cci??P0DCch6000FCch01000Cci??Tln1P0044ln00<004loCcl01dlo1@002U<n
00<004loCcl03Tlo1P000e<o00<005=ODel045=O1@000U=O00<005=ODel045=O1@000U=O00<005=O
Del045=O1@000U=O00<005=ODel03E=O10001e=O00<005=ODel02E=O0`002e=O00<005=ODel015=O
10003U=o10004U=o10000U=o00D007ooOomoo`0006aoo`00BWoo0P0027oo0P004Goo00<007ooOol0
2goo00<004LoAcl05DLo00<004LoAcl00TLo1`003DLo00<004LoAcl04TLo20004dLo0P004DLo2@00
54Lo00<004LoAcl044Lo2@0054Lo00<004LoAcl044Lo2@0054/o00<004/oBcl04T/o2@004T/o00<0
04/OBal05D/O00<004/OBal00T/O1`0034/O00<004/OBal05D/O00<004/OBal00T/O1`003D/O00<0
04/OBal05D/O00<004/OBal00T/O1`0034/O00<004/NBah05T/N00<004lNCah00TlN1`003DlN00<0
04lNCah05DlN00<004lNCah00TlN1`003DlN00<004lNCah04dlN1`005DlN00<004lnCch03Dln1P00
0dln00<004lnCch05Tln00@004lnCci??PH0011??P03001??Tln00e??PH000=??P03001??Tln01E?
?PD001I??P04001??dloCcl6000@Dch00`00Ccm??`07Ccl6000:Dcl00`00DemCG`0:Del50008Del0
0`00DemCG`0:Del50008Del00`00DemCG`0:Del50008Del00`00DemCG`09Del3000<Del00`00DemC
G`04Del40002Del00`00DemCG`09Del00`00DemCG`04000>Dgl40002Dgl00`00DgmCO`0=Dgl40007
Dgl01@00Oomoogoo0000Jgoo001;Ool20006Ool2000BOol00`00Oomoo`0<Ool2000AAcl9000EAcl0
0`00Acm7?`0:Acl70004Acl00`00Acm7?`0FAcl00`00Acm7?`03Acl;0007Acl00`00Acm7?`0DAcl0
0`00Acm7?`04Acl;0006Acl00`00Acm7?`0EAcl00`00Acm7?`04Acl;0006Acl00`00Bcm;?`0EBcl0
0`00Bcm;?`0:Bcl70004Bcl00`00Bcm;?`0EBcl00`00Bam;7`0@Bal9000DBal00`00Bam;7`0ABal8
000EBal00`00Bam;7`0ABal8000DBal00`00Bai;7P0BBah8000ECah00`00Cai?7P0ACah8000ECah0
0`00Cai?7P0=Cah50003Cah00`00Cai?7P0FCah00`00Cci??P08Cch5000:Cch00`00Cci??P0CCch6
000FCch00`00Cci??P08Cch5000:Cch00`00Cci??P0?Cch50002Cch00`00Cci??P0ECch5000FDch0
1000Ccm??dlo1P004E<o00<005=ODel01E=O10003U=O00<005=ODel01E=O10003U=O00<005=ODel0
1E=O10003U=O00<005=ODel015=O10003e=O00<005=ODel010001U=O00<005=ODel025=O10003U=o
10001e=o00<005=oDgl025=o10002e=o00D007ooOomoo`0006]oo`00Bgoo0P001Woo0P004Woo00<0
07ooOol03Woo00<004LoAcl00dLo2`001dLo00<004LoAcl05DLo00<004LoAcl00TLo1`0034Lo00<0
04LoAcl04TLo2@004dLo00<004LoAcl03dLo2`004TLo00<004LoAcl04TLo2@004TLo00<004/oBcl0
5D/o00<004/oBcl00T/o1`0034/o00<004/oBcl05D/o00<004/OBal014/O2`001D/O00<004/OBal0
5D/O00<004/OBal02T/O1`0014/O00<004/OBal05T/O00<004/OBal02T/O1`0014/O00<004/OBal0
5T/O00<004/NBah02T/N1`0014lN00<004lNCah05TlN00<004lNCah02TlN1`0014lN00<004lNCah0
5TlN00<004lNCah01dlN1P002DlN00<004lNCah05TlN00@004lnCci??PH000m??P03001??Tln00e?
?PH000=??P03001??Tln01M??P04001??TlnCch6000?Cch00`00Cci??P0:Cch50008Cch00`00Cci?
?P0?Cch50002Dch00`00DciC?P0EDch5000GDcl00`00DemCG`05000BDel00`00DemCG`05000BDel0
0`00DemCG`05000BDel00`00DemCG`04000BDel4000:Del00`00DemCG`03Del50002Del00`00DgmC
O`0:Dgl3000;Dgl00`00DgmCO`04Dgl4000>Dgl30003Ool00`00Oomoo`1XOol004aoo`8000Aoo`80
01=oo`03001oogoo00moo`D001=7?`800157?`T001A7?`030017?dLo00Y7?`L000E7?`030017?dLo
01E7?`030017?dLo00=7?`/000M7?`030017?dLo01A7?`030017?dLo00Y7?`L000E7?`030017?dLo
01A7?`03001;?d/o011;?`T001A;?`03001;?d/o011;?`/0015;7`03001;7d/O01E;7`03001;7d/O
009;7`L000a;7`03001;7d/O01I;7`03001;7d/O009;7`L000a;7`03001;7d/O01I;7`03001;7T/N
009;7PL000a?7P03001?7TlN01I?7P03001?7TlN009?7PL000a?7P03001?7TlN01I?7P04001?7TlN
Cah5000@Cah00`00Cai?7P0BCah7000FCch00`00Cci??P07Cch5000:Cch00`00Cci??P0DCch6000F
Cch00`00Cci??P05Cch4000=Cch00`00Cci??P0:Cch50008Dch00`00DciC?P0?Dch50002Dch00`00
DcmC?`0FDcl4000FDel4000FDel4000FDel4000ADel50002Del00`00DemCG`09Del60008Del00`00
DgmCO`05Dgl4000>Dgl00`00DgmCO`04000>Dgl40002Dgl01@00Oomoogoo0000JWoo001<Ool8000C
Ool00`00Oomoo`0AOol00`00Acm7?`0EAcl00`00Acm7?`03Acl;0007Acl00`00Acm7?`0DAcl00`00
Acm7?`02Acl7000=Acl00`00Acm7?`0BAcl8000CAcl00`00Acm7?`0DAcl00`00Acm7?`02Acl7000=
Acl00`00Acm7?`0DAcl00`00Bcm;?`04Bcl;0006Acl00`00Bcm;?`0EBcl00`00Bcm;?`04Bcl;0005
Bal00`00Bam;7`0EBal00`00Bam;7`0@Bal9000DBal00`00Bam;7`0BBal8000DBal00`00Bam;7`0B
Bal8000DCah00`00Cai?7P0BCah8000DCah00`00Cai?7P0BCah7000ECah00`00Cai?7P0:Cah80004
Cah00`00Cci??P0FCch01000Cci??Tln1P0044ln00<004lnCch03Dln1P000dln00<004lnCch05Tln
00<004lnCch01@004Tln00<004lnCch01Dln10003E<n00<005<nDch02U<n1@0025<n00<005<oDcl0
45<o1@000U<n00<005=ODel045=O1@000U=O00<005=ODel045=O1@000U=O00<005=ODel045=O1@00
0U=O00<005=ODel02e=O1@0025=O00<005=ODel01E=O10003U=O00<005=oDgl010004E=o10003U=o
10001e=o00D007ooOomoo`0006Uoo`00CWoo100057oo00<007ooOol04goo00<004LoAcl04TLo2000
4dLo00<004LoAcl03dLo2@005DLo00<004LoAcl02TLo1`0014Lo00<004LoAcl05DLo00<004LoAcl0
3dLo2@005DLo00<004LoAcl03dLo2`004TLo00<004/oBcl04T/o2@004D/O00<004/OBal05D/O00<0
04/OBal014/O2`001T/O00<004/OBal05D/O00<004/OBal02T/O1`0014/O00<004/OBal05D/O00<0
04/OBal02T/O200014/N00<004lNCah05DlN00<004lNCah02TlN200014lN00<004lNCah05DlN00<0
04lNCah02TlN200014lN00<004lNCah05TlN00<004lNCah00TlN1`003DlN00<004lnCch04dln1P00
5Tln00<004lnCch024ln1@002Tln00<004lnCch04dln1@005dln00<004lnCch01@004U<n00<005<n
Dch01E<n10003U<n00<005<oDcl02U<o1@0025<n00<005=ODel02U=O1@0025=O00<005=ODel02U=O
1@0025=O00<005=ODel02U=O1@0025=O00<005=ODel01E=O1@003E=O00<005=ODel01@000e=O00<0
05=ODel02e=O10004E=o10000U=o00<005=oDgl02U=o0`002e=o00D007ooOomoo`0006Uoo`00IWoo
00<007ooOol00`004Goo00<004LoAcl02TLo1`001DLo00<004LoAcl054Lo00<004LoAcl00dLo2`00
1dLo00<004LoAcl05DLo00<004LoAcl00TLo1`0034Lo00<004LoAcl05DLo00<004LoAcl00dLo2`00
1dLo00<004LoAcl05DLo00<004LoAcl00dLo2`001TLo00<004LoAcl05DLo00<004/oBcl02T/o1`00
0d/O00<004/OBal05D/O00<004/OBal04T/O2@004T/O00<004/OBal05D/O00<004/OBal00T/O1`00
34/O00<004/OBal05D/O00<004/OBal00T/O1`003D/N00<004lNCah05DlN00<004lNCah00TlN1`00
3DlN00<004lNCah05DlN00<004lNCah00TlN1`003DlN00<004lNCah04dlN1`0054lN00<004lnCch0
3Dln1P000dlN00<004lnCch05dln00@004lnCci??PH000m??P03001??Tln00e??PH000=??P03001?
?Tln01A??PD001MC?P03001C?U<n00D0019C?P03001C?e<o00IC?`@000iC?P03001CGe=O00ECG`@0
00iCG`03001CGe=O00ECG`@000eCG`03001CGe=O00ECG`D000eCG`03001CGe=O00D0015CG`@000QC
G`03001CGe=O00MCG`@0009CO`03001COe=o00aCO`@000MCO`03001COe=o00ECO`@000eCO`<000=o
o`03001oogoo06Ioo`00IWoo0`005Goo00<004LoAcl00TLo1`003DLo00<004LoAcl03dLo2P004dLo
0P004DLo2@0054Lo00<004LoAcl044Lo2P004dLo00<004LoAcl044Lo2P004TLo00<004LoAcl05DLo
00<004/oBcl00T/o1`002d/O00<004/OBal05D/O00<004/OBal02T/O1`000d/O00<004/OBal05T/O
00<004/OBal044/O2@0054/O00<004/OBal04D/O20005D/N00<004lNCah04DlN20005DlN00<004lN
Cah04DlN200054lN00<004lNCah03DlN1P000dlN00<004lNCah05TlN00<004lnCch01dln1@002TlN
00<004lnCch054ln1P005Tln00<004lnCch01dln1@002Tln00<004lnCch03Dln1P000e<n00<005<n
Dch05E<n100065<n00<005<oDcl01@004U<n00<005=ODel01@004U=O00<005=ODel01@004E=O00<0
05=ODel01@004E=O10004U=O10000U=O00<005=ODel01e=O00<005=ODel00e=O10001e=o00<005=o
Dgl025=o0`0035=o00<005=oDgl010003E=o10000U=o00D007ooOomoo`0006Qoo`00IWoo00<007oo
Ool05Woo10005DLo00<004LoAcl00dLo2`001dLo00<004LoAcl05DLo00<004LoAcl00dLo2`001dLo
00<004LoAcl054Lo00<004LoAcl014Lo2`001TLo00<004LoAcl05DLo00<004LoAcl014Lo2`001TLo
00<004LoAcl054Lo00<004LoAcl044Lo2@004d/O00<004/OBal05D/O00<004/OBal00T/O1`002d/O
00<004/OBal05T/O00<004/OBal014/O2`001D/O00<004/OBal05D/O00<004/OBal02T/O1`0014/N
00<004/NBah05T/N00<004lNCah02TlN1`0014lN00<004lNCah05TlN00<004lNCah02TlN1`0014lN
00<004lNCah05TlN00<004lNCah01dlN1@002TlN00<004lNCah05DlN00@004lnCci??PH0011?7P03
001??Tln00e??PH000=??P03001??Tln01I??P04001??TlnCch6000@Cch00`00Cci??P07Cch5000:
Dch00`00DciC?P0?Dch50002Dch00`00DciC?P0FDch4000FDch4000FDel4000EDel4000BDel40002
Del00`00DemCG`0=Del40007Del00`00DemCG`06Del00`00DemCG`03000;Dgl00`00DgmCO`04Dgl4
000>Dgl4000=Dgl40007Dgl01@00Oomoogoo0000Igoo001VOol00`00Oomoo`0HOol00`00Acm7?`0B
Acl8000CAcl2000AAcl:000CAcl00`00Acm7?`0?Acl;000BAcl00`00Acm7?`0BAcl9000BAcl00`00
Acm7?`0DAcl00`00Acm7?`04Acl;0005Aal00`00Bam;7`0EBal00`00Bam;7`0@Bal9000CBal00`00
Bam;7`0BBal:000ABal00`00Bam;7`0EBal00`00Bam;7`02Bal7000<Bah00`00Bai;7P0FBah00`00
Cai?7P02Cah7000<Cah00`00Cai?7P0FCah00`00Cai?7P02Cah7000<Cah00`00Cai?7P0ECah01000
Cai?7TlN1P0044lN00<004lNCah04DlN1`005TlN00<004lnCch024ln1@002Tln00<004lnCch04dln
1P005Tln00@004lnCci??PH000mC?P03001C?U<n00YC?PD000QC?P03001C?U<n011C?PD0009C?P03
001C?U<n011C?PD0009C?P03001CGe=O015CG`@0009CGP03001CGe=O00mCG`D0009CG`03001CGe=O
00eCG`@000MCG`03001CGe=O00UCG`<000aCG`03001CGe=O00ACG`@000iCO`03001COe=o00@000iC
O`@0009CO`03001COe=o00UCO`<000]CO`05001oogooOol0001WOol006Ioo`03001oogoo01Uoo`80
00]7?`L000E7?`030017?dLo01E7?`030017?dLo00=7?`/000I7?`030017?dLo01E7?`030017?dLo
00=7?`/000M7?`030017?dLo01A7?`030017?dLo00Y7?`L000A7?`030017?dLo01E7?`030017?dLo
00m7?`/001577`03001;7d/O01E;7`03001;7d/O00A;7`/000E;7`03001;7d/O01E;7`03001;7d/O
00Y;7`L000A;7`03001;7d/O01E;7`03001;7d/O011;7`T001A;7P03001;7T/N019;7PP001A?7P03
001?7TlN019?7PP001A?7P03001?7TlN015?7PL001I?7P03001?7TlN00Y?7PL000A?7P03001?7TlN
01M?7P04001??TlnCch6000?Cch00`00Cci??P0=Cch60003Cch00`00Cci??P0ECch5000FDch00`00
DciC?P05Dch4000>Dch00`00DciC?P0:Dch50008Dch00`00DciC?P0:Dch50008Dch00`00DemCG`0<
Del40007Deh00`00DemCG`09Del50008Del00`00DemCG`09Del3000<Del00`00DemCG`04Del4000?
Del00`00DemCG`040002Dgl00`00DgmCO`0<Dgl4000>Dgl40007Dgl00`00DgmCO`04Dgl4000=Dgl3
0003Ool00`00Oomoo`1TOol006Ioo`03001oogoo01]oo`040017?dLoAcl7000=Acl00`00Acm7?`0B
Acl8000BAcl00`00Acm7?`0BAcl8000CAcl00`00Acm7?`0DAcl00`00Acm7?`02Acl7000<Acl00`00
Acm7?`0EAcl00`00Acm7?`03Acl;0006Acl00`00Aam77`0DAal00`00Bam;7`0@Bal;000ABal00`00
Bam;7`0EBal00`00Bam;7`02Bal7000<Bal00`00Bam;7`0EBal00`00Bam;7`04Bal;0005Bah00`00
Bai;7P0FBah00`00Bai;7P0:Bah70004Bah00`00Cai?7P0ECah00`00Cai?7P0:Cah80004Cah00`00
Cai?7P0ECah00`00Cai?7P0:Cah70004Cah00`00Cai?7P0GCah00`00Cai?7P02Cah7000<Cah00`00
Cai?7P0DCah6000FCch00`00Cci??P07Cch5000:Cch00`00Cci??P0?Cch50002Dch00`00DciC?P0F
Dch00`00DciC?P05000BDch00`00DciC?P06Dch4000>Dch00`00DciC?P05Dch4000=Dch00`00DemC
G`09Del3000;Deh00`00DemCG`05Del4000>Del00`00DemCG`04Del4000?Del00`00DemCG`04000B
Del40006Dgl00`00DgmCO`08Dgl40002Dgl00`00DgmCO`0:Dgl3000;Dgl00`00DgmCO`04000>Dgl3
0002Dgl01@00Oomoogoo0000IWoo001VOol00`00Oomoo`0LOol3000EAcl00`00Acm7?`0:Acl70004
Acl00`00Acm7?`0DAcl00`00Acm7?`0:Acl70005Acl00`00Acm7?`0DAcl00`00Acm7?`0?Acl9000D
Acl00`00Acm7?`0@Acl:000BAcl00`00Aam77`0DAal00`00Bam;7`04Bal;0006Bal00`00Bam;7`0D
Bal00`00Bam;7`0@Bal9000DBal00`00Bam;7`0ABal:000ABah00`00Bai;7P0FBah00`00Bai;7P02
Bah7000<Bah00`00Cai?7P0ECah00`00Cai?7P02Cah7000=Cah00`00Cai?7P0ECah00`00Cai?7P02
Cah7000<Cah00`00Cai?7P0DCah7000DCah00`00Cai?7P0=Cah60003Cah00`00Cci??P0FCch01000
Cci??Tln1P003dln00<004lnCch02Tln1@0025<n00<005<nDch04e<n1@0065<n00<005<nDch01@00
4U<n00<005<nDch01@004U<n00<005=ODel015=O10003U=N00<005=ODel01@004U=O00<005=ODel0
10004U=O10004U=O10000U=O00<005=oDgl01E=o00<005=oDgl015=o10001e=o00<005=oDgl01E=o
10003E=o10003e=o0`001U=o00D007ooOomoo`0006Eoo`00IWoo00<007ooOol07Woo00<004LoAcl0
54Lo00<004LoAcl00TLo1`0034Lo00<004LoAcl054Lo00<004LoAcl00TLo1`003DLo00<004LoAcl0
54Lo00<004LoAcl00dLo2`001dLo00<004LoAcl054Lo00<004LoAcl014Lo2`001TLo00<004LoAcl0
54Lo00<004LOAal03dLO2`004T/O00<004/OBal054/O00<004/OBal014/O2`001T/O00<004/OBal0
54/O00<004/OBal02T/O1`0014/O00<004/NBah05D/N00<004/NBah04T/N200054/N00<004lNCah0
4DlN20005DlN00<004lNCah04DlN200054lN00<004lNCah03DlN1P000dlN00<004lNCah05DlN00<0
04lNCah024lN1@002TlN00<004lnCch04dln1P005Tln00<004lnCch01Dln10003E<n00<005<nDch0
3E<n1P000e<n00<005<nDch05U<n10005U<n10005e<n00<005=ODel010004E=N10005U=O10004U=O
10000U=O00<005=ODel03E=O10001e=O00<005=oDgl015=o00@005=oDgmCO`<000aCO`03001COe=o
00@000eCO`@0009CO`03001COe=o00YCO`@000UCO`05001oogooOol0001UOol006Ioo`03001oogoo
01moo`030017?dLo00m7?`T001A7?`030017?dLo00m7?`T001E7?`030017?dLo00m7?`X001=7?`03
0017?dLo00m7?`/00197?`030017?dLo01A7?`0300177dLO00=77`/000I77`03001;7d/O01E;7`03
001;7d/O00m;7`/0019;7`03001;7d/O01A;7`03001;7d/O009;7`L000a;7`03001;7T/N01E;7P03
001;7T/N00Y;7PL000A;7P03001;7T/N01E;7P03001?7TlN00Y?7PL000A?7P03001?7TlN01I?7P03
001?7TlN00Y?7PL000A?7P03001?7TlN01E?7P03001?7TlN00Q?7PD000Y?7P03001?7TlN01E?7P04
001?7TlNCah6000?Cah00`00Cci??P0=Cch60003Cah00`00Cci??P0FCch00`00Cci??P05000BDch0
0`00DciC?P07Dch5000:Dch00`00DciC?P0@Dch50002Dch00`00DciC?P0@Dch50002Dch00`00DciC
?P0EDch4000ADeh40002Deh00`00DemCG`0ADel40002Del00`00DemCG`0=Del40007Del00`00DemC
G`09Del3000;Del00`00DgmCO`04Dgl4000>Dgl4000=Dgl40007Dgl00`00DgmCO`06Dgl3000=Dgl0
0`00Oomoo`02Ool00`00Oomoo`1ROol006Ioo`03001oogoo021oo`030017?dLo00=7?`/000M3?`03
0017?dLo01A7?`030017?dLo00=7?`/000M7?`030017?dLo01E7?`030017?dLo00=7?`/000I7?`03
0017?dLo01E7?`030017?dLo00=7?`/000I7?`030017?dLo01E7?`030017?dLo00m7?`X001977`03
001;7d/O01E;7`03001;7d/O00=;7`/000I;7`03001;7d/O01E;7`03001;7d/O00m;7`T001A;7`03
001;7T/N01E;7P03001;7T/N009;7PL000a;7P03001;7T/N01E;7P03001?7TlN009?7PL000a?7P03
001?7TlN01I?7P03001?7TlN009?7PL000a?7P03001?7TlN01E?7P04001?7TlNCah6000?Cah00`00
Cai?7P0CCah6000FCah00`00Cci??P07Cch5000:Cah00`00Cci??P0CCch5000GDch01000DciC?U<n
1P0045<n00<005<nDch02U<n1@0025<n00<005<nDch02U<n1@0025<n00<005<nDch03e<n1@000U<n
00<005=NDeh035=N10001e=N00<005=ODel035=O10001e=O00<005=ODel02E=O0`0035=O00<005=O
Del015=O10003U=O00<005=oDgl01@003E=o10000U=o00<005=oDgl02E=o0`002e=o00<005=oDgl0
0e=o0`003e=o0`0017oo00<007ooOol0HGoo001VOol00`00Oomoo`0QOol5000C@cl2000@Acl:000C
Acl2000AAcl:000BAcl00`00Acm7?`0BAcl8000BAcl00`00Acm7?`0EAcl00`00Acm7?`03Acl;0006
Aal00`00Aam77`0DAal00`00Bam;7`0@Bal:000BBal00`00Bam;7`0EBal00`00Bam;7`03Bal;0005
Bal00`00Bam;7`0FBal00`00Bai;7P0@Bah9000DBah00`00Bai;7P0ABah8000DCah00`00Cai?7P0B
Cah8000DCah00`00Cai?7P0ACah7000FCah00`00Cai?7P0=Cah50003Cah00`00Cai?7P0FCah01000
Cci??Tln1P0044lN00<004lnCch03Dln1@000e<n00<005<nDch05E<n1@005U<n00<005<nDch01U<n
10003U<n00<005<nDch01E<n10003E<n00<005<nDch02U<n1@0025<n00<005=NDeh025=N0`002e=N
00<005=ODel02E=O0`0035=O00<005=ODel015=O10003e=O00<005=ODel010004E=O100015=o00<0
05=oDgl01e=o10001e=o00<005=oDgl015=o10003U=o00<005=oDgl00`003U=o10000U=o00<007oo
Ool00Woo00<007ooOol0HGoo001VOol00`00Oomoo`0SOol00`00@cm3?`0E@cl00`00Acm7?`03Acl:
0007@cl00`00Acm7?`0EAcl00`00Acm7?`03Acl;0006Acl00`00Acm7?`0DAcl00`00Acm7?`0:Acl7
0004Acl00`00Acm7?`0DAcl00`00Acm7?`0@Acl:000BAal00`00Aam77`0DAal00`00Bam;7`04Bal;
0005Bal00`00Bam;7`0EBal00`00Bam;7`0@Bal:000ABal00`00Bam;7`0FBal00`00Bai;7P04Bah;
0005Bah00`00Bai;7P0EBah00`00Bai;7P0:Bah70004Cah00`00Cai?7P0ECah00`00Cai?7P0:Cah8
0004Cah00`00Cai?7P0ECah00`00Cai?7P0:Cah70004Cah00`00Cai?7P0GCah00`00Cai?7P06Cah6
0009Cah00`00Cai?7P0CCah6000FCah00`00Cci??P07Cch60009Dch00`00DciC?P0?Dch50002Dch0
0`00DciC?P0GDch00`00DciC?P05000BDch00`00DciC?P05000BDch00`00DciC?P05Dch4000=Dch0
0`00DeiCGP04Deh4000?Deh00`00DemCG`04Del4000?Del00`00DemCG`04000BDel4000ADel40002
Del00`00DgmCO`03Dgl00`00DgmCO`04Dgl3000;Dgl00`00DgmCO`04000ADgl4000=Dgl40007Dgl0
0`00Oomoo`02Ool00`00Oomoo`1POol006Ioo`03001oogoo02Aoo`800153?`X00193?`800157?`X0
0197?`030017?dLo01A7?`030017?dLo0097?`L000a7?`030017?dLo01A7?`030017?dLo00A7?`/0
00E7?`0300177dLO01E77`0300177dLO00m77`/0015;7`03001;7d/O01E;7`03001;7d/O00A;7`/0
00E;7`03001;7d/O01A;7`03001;7d/O019;7`X0015;7P03001;7T/N01E;7P03001;7T/N009;7PL0
00a?7P03001?7TlN01E?7P03001?7TlN009?7PL000e?7P03001?7TlN01E?7P03001?7TlN009?7PL0
00a?7P03001?7TlN01I?7P04001?7TlNCah5000@Cah00`00Cai?7P0=Cah50003Cah00`00Cai?7P0G
Cah01000Cci??Tln1@0045<n00<005<nDch02U<n100025<n00<005<nDch055<n1@005U<n10005e<n
00<005<nDch01@004E<n00<005=NDeh010004e=N00<005=ODel010004U=O10004U=O10000U=O00<0
05=ODel035=O10001e=O00<005=oDgl00U=o00<005=oDgl010003E=o10004E=o10000U=o00<005=o
Dgl02E=o0`002e=o00<007ooOol00Woo00<007ooOol0H7oo001VOol00`00Oomoo`0VOol00`00@cm3
?`03@cl;0007@cl00`00@cm3?`0D@cl00`00Acm7?`03Acl;0007@cl00`00Acm7?`0CAcl00`00Acm7
?`0?Acl9000DAcl00`00Acm7?`0?Acl;000AAcl00`00Aam77`0EAal00`00Aam77`03Aal;0005Aal0
0`00Bam;7`0EBal00`00Bam;7`0ABal:000ABal00`00Bam;7`0DBal00`00Bam;7`0:Bal70004Bah0
0`00Bai;7P0EBah00`00Bai;7P0ABah8000DCah00`00Cai?7P0ACah8000ECah00`00Cai?7P0ACah8
000DCah00`00Cai?7P0BCah7000ECah00`00Cai?7P07Cah60009Cah00`00Cai?7P0DCah6000EDch0
0`00DciC?P06Dch4000=Dch00`00DciC?P0=Dch60003Dch00`00DciC?P0@Dch50002Dch00`00DciC
?P0EDch4000EDch4000FDeh4000BDel40002Del00`00DemCG`0=Del40007Del00`00DemCG`08Del3
000<Del00`00DgmCO`04000>Dgl30002Dgl00`00DgmCO`0<Dgl40007Dgl00`00DgmCO`04Dgl4000=
Dgl30004Ool00`00Oomoo`1OOol006Eoo`03001oogoo02Qoo`D001=3?`030013?d<o00m3?`X001=3
?`030017?dLo01=7?`030017?dLo00=7?`/000M7?`030017?dLo01A7?`030017?dLo00=7?`/000I7
?`030017?dLo01A7?`0300177dLO01177`X001577`03001;7d/O01A;7`03001;7d/O00Y;7`L000A;
7`03001;7d/O01E;7`03001;7d/O01A;7`03001;7d/O009;7`L000a;7P03001;7T/N01A;7P03001;
7T/N00Y;7PL000A;7P03001?7TlN01E?7P03001?7TlN00Y?7PL000A?7P03001?7TlN01I?7P03001?
7TlN00Y?7PL000A?7P03001?7TlN01E?7P03001?7TlN00Y?7PP000A?7P03001?7TlN01I?7P04001?
7TlNCah5000@Cah00`00Cai?7P0=Cah60003Dah00`00DciC?P0FDch00`00DciC?P05000ADch00`00
DciC?P08Dch5000:Dch00`00DciC?P0:Dch50008Dch00`00DciC?P0?Dch50002Dch00`00DciC?P0?
Dch50002Dch00`00DeiCGP0@Deh50002Deh00`00DemCG`0=Del40007Del00`00DemCG`09Del3000;
Del00`00DemCG`04Del4000>Del400000e=o001CO`0<Dgl30006Dgl00`00DgmCO`08Dgl3000;Dgl0
0`00DgmCO`04000=Dgl40002Dgl00`00Oomoo`02Ool00`00Oomoo`1OOol006Eoo`03001oogoo02Yo
o`030013?d<o01A3?`030013?d<o00=3?`/000M3?`030013?d<o01A3?`030017?dLo00U7?`l001=7
?`030017?dLo00m7?`X00197?`030017?dLo01A7?`0300177dLO00A77`/000E77`0300177dLO01A7
7`03001;7d/O01A;7`03001;7d/O009;7`L000a;7`03001;7d/O01A;7`03001;7d/O011;7`T001A;
7P03001;7T/N01A;7P03001;7T/N009;7PL000a;7P03001?7TlN01E?7P03001?7TlN009?7PL000a?
7P03001?7TlN01I?7P03001?7TlN009?7PL000a?7P03001?7TlN01E?7P03001?7TlN009?7PL000e?
7P03001?7TlN01=?7PH001E?7P03001?7TlN00Q?7PD000YC7P03001C?U<n01=C?PD001MC?P04001C
?U<nDch6000@Dch00`00DciC?P05Dch4000=Dch00`00DciC?P0:Dch50008Dch00`00DciC?P0:Dch4
0008Dch00`00DeiCGP0:Deh50008Deh00`00DemCG`09Del3000<Del00`00DemCG`04Del4000>Del0
0`00DemCG`04000>Del40002Dgl01000DgmCO`002E=o10002E=o00<005=oDgl015=o10003E=o1000
3U=o0`001e=o00<007ooOol00Woo00<007ooOol0GWoo001UOol00`00Oomoo`0[Ool2000@@cl:000C
@cl00`00@cm3?`0?@cl@000<Acl00`00Acm7?`0DAcl00`00Acm7?`03Acl;0006Acl00`00Acm7?`0D
Acl00`00Acm7?`0?Acl;000AAal00`00Aam77`0DAal00`00Bam;7`0?Bal9000DBal00`00Bam;7`0D
Bal00`00Bam;7`04Bal;0005Bah00`00Bai;7P0EBah00`00Bai;7P0@Bah9000DBah00`00Cai?7P0A
Cah8000DCah00`00Cai?7P0BCah8000DCah00`00Cai?7P0ACah8000DCah00`00Cai?7P0=Cah60003
Cah00`00Cai?7P0FCah01000Cai?7TlN1P003e<N00<005<nDch03E<n1P000e<n00<005<nDch05E<n
1@005U<n00<005<nDch01@004U<n00<005<nDch01E<n10003U<n00<005<nDch01E<n10003E<n00<0
05=NDeh01E=N10003U=N00<005=ODel015=O10003e=O00<005=ODel010004E=O10003U=O10001e=o
00<005=o00001U=o0`003E=o00<005=oDgl010003E=o10000U=o00<005=oDgl02E=o10002e=o00D0
07ooOomoo`00061oo`00IGoo1P00:Woo00<004<o@cl00d<o2P001d<o00<004<o@cl054<o00<004<o
@cl00d<o2`001T<o00<004LoAcl054Lo00<004LoAcl03dLo2P004TLo00<004LoAcl054Lo00<004Lo
Acl00dLo2`001TLO00<004LOAal054LO00<004LOAal054LO00<004/OBal00d/O2`001T/O00<004/O
Bal05D/O00<004/OBal03d/O2`004D/N00<004/NBah05D/N00<004/NBah014/N2`001D/N00<004/N
Bah05D/N00<004lNCah02TlN1`0014lN00<004lNCah05DlN00<004lNCah02TlN200014lN00<004lN
Cah05DlN00<004lNCah02TlN1`0014lN00<004lNCah05TlN00<004lNCah01dlN1@002TlN00<004lN
Cah04dlN1P005U<N00<005<nDch01e<n1@002U<n00<005<nDch03e<n1@000U<n00<005<nDch05E<n
10005e<n00<005<nDch01@004U<n00<005<nDch01@004E<n00<005=NDeh01@004U=N00<005=ODel0
10004U=O10004E=O10000U=O00<005=ODel02U=O0`002e=o00<005=o00000e=o0`003e=o10003U=o
0`001e=o00<005=oDgl015=o10003U=o0`000goo00<007ooOol0GGoo001UOol00`00Oomoo`0^Ool5
000B@cl2000@@cl:000B@cl00`00Acm7?`0DAcl00`00Acm7?`03Acl;0006Acl00`00Acm7?`0DAcl0
0`00Acm7?`0?Acl:000BAal00`00Aam77`0DAal00`00Aam77`0?Aal:000BBal00`00Bam;7`0EBal0
0`00Bam;7`03Bal;0005Bal00`00Bai;7P0EBah00`00Bai;7P0@Bah;000ABah00`00Bai;7P0EBah0
0`00Cai?7P02Cah7000<Cah00`00Cai?7P0ECah00`00Cai?7P02Cah7000=Cah00`00Cai?7P0ECah0
0`00Cai?7P02Cah7000<Cah00`00Cai?7P0ECah01000Cai?7TlN1P003dlN00<004lNCah03DlN1P00
0e<N00<005<NDah05U<N00@005<nDciC?PH000mC?P03001C?U<n00YC?PD000QC?P03001C?U<n00mC
?PD0009C?P03001C?U<n01EC?P@001IC?P@001EC?P@001ICGP@0019CG`@0009CG`03001CGe=O00aC
G`@000MCG`03001CGe=O00ECG`@000iCO`03001CO`0000<000iCO`@0009CO`03001COe=o00UCO`@0
00]CO`03001COe=o00<000iCO`@0009?O`05001oogooOol0001OOol006Eoo`03001oogoo031oo`03
0013?d<o01A3?`030013?d<o00=3?`X000M3?`030013?d<o01=3?`030017?dLo00m7?`X00197?`03
0017?dLo01A7?`030017?dLo00=7?`/000I77`0300177dLO01A77`0300177dLO01A77`0300177dLO
00=77`/000I77`03001;7d/O01A;7`03001;7d/O011;7`X0015;7`03001;7T/N01E;7P03001;7T/N
00A;7P/000E;7P03001;7T/N01E;7P03001;7T/N015;7PP001A?7P03001?7TlN015?7PP001A?7P03
001?7TlN01=?7PL001A?7P03001?7TlN015?7PL001I?7P03001?7TlN00M?7PD000YC7P03001C7U<N
01=C7PH001IC?P03001C?U<n00EC?P@000eC?P03001C?U<n00YC?PD000QC?P03001C?U<n00mC?PD0
009C?P03001C?U<n015C?P@0009C?P03001C?U<n011C?P@0009CGP03001CGU=N011CGPD0009CGP03
001CGe=O00eCG`@000MCG`03001CGe=O00QCG`<000aCG`03001CGe=O00@0015CO`@000eCO`@000MC
O`03001COe=o00ACO`@000iCO`@000eCO`@000M?O`05001oogooOol0001NOol006Eoo`03001oogoo
035oo`030013?d<o00m3?`X00193?`030013?d<o01=3?`030017?dLo00=7?`/000I3?`030017?dLo
01A7?`030017?dLo00m7?`X001977`0300177dLO01A77`0300177dLO00U77a0001977`03001;7d/O
01A;7`03001;7d/O00A;7`/000E;7`03001;7d/O01A;7`03001;7T/N019;7PT0015;7P03001;7T/N
01A;7P03001;7T/N00Y;7PL000A?7P03001?7TlN01E?7P03001?7TlN00Y?7PL000A?7P03001?7TlN
01I?7P03001?7TlN00e?7PD000=?7P03001?7TlN01E?7P03001?7TlN00Y?7PL000A?7P03001?7TlN
01I?7P04001?7TlNCah6000?Dah00`00DaiC7P0=Dah60003Dah00`00DciC?P0FDch00`00DciC?P05
000BDch00`00DciC?P05Dch4000=Dch00`00DciC?P0:Dch50008Dch00`00DciC?P0<Dch40007Dch0
0`00DciC?P0<Dch30007Deh00`00DeiCGP0:Deh50008Deh00`00DemCG`09Del3000;Del00`00DemC
G`04Del4000>Del4000ADgl40002Dgl2000:Dgl3000<Dgl00`00DgmCO`03000>Dgl40002Dgl00`00
DgmCO`09Dgl3000;Cgl01@00Oomoogoo0000GWoo001UOol00`00Oomoo`0bOol00`00@cm3?`03@cl;
0007@cl00`00@cm3?`0C@cl00`00@cm3?`0>@cl:000B@cl00`00Acm7?`0DAcl00`00Acm7?`03Acl;
0006Acl00`00Aam77`0DAal00`00Aam77`0?Aal@000;Aal00`00Aam77`0EAal00`00Bam;7`0?Bal;
000ABal00`00Bam;7`0DBal00`00Bai;7P0:Bah70003Bah00`00Bai;7P0EBah00`00Bai;7P0DBah0
0`00Bai;7P02Bah7000<Cah00`00Cai?7P0ECah00`00Cai?7P02Cah7000<Cah00`00Cai?7P0FCah0
0`00Cai?7P06Cah60009Cah00`00Cai?7P0ECah00`00Cai?7P02Cah7000<Cah00`00Cai?7P0CCah6
000FDah00`00DaiC7P07Dah5000:Dah00`00DciC?P0CDch5000GDch00`00DciC?P05000BDch00`00
DciC?P05Dch4000=Dch00`00DciC?P09Dch3000;Dch00`00DciC?P08Dch4000;Deh00`00DeiCGP05
Deh4000>Deh00`00DemCG`04Del4000>Del00`00DemCG`04000>Del40002Del00`00DgmCO`0<Dgl4
0007Dgl00`00DgmCO`04Dgl4000>Dgl4000=Dgl40007Dgl00`00DgmCO`04Dgl4000=Cgl30003Ool0
0`00Oomoo`1KOol006Eoo`03001oogoo03=oo`D001=3?`030013?d<o01=3?`030013?d<o00=3?`X0
00M3?`030013?d<o01=3?`030017?dLo00m7?`X00197?`0300177dLO01A77`0300177dLO00=77`/0
00E77`0300177dLO01A77`0300177dLO01E77`03001;7d/O00=;7`/000E;7`03001;7d/O01E;7`03
001;7d/O01A;7`03001;7T/N009;7PL000];7P03001;7T/N01A;7P03001;7T/N011;7PT001A?7P03
001?7TlN015?7PP001=?7P03001?7TlN01I?7P04001?7TlNCah5000?Cah00`00Cai?7P0CCah7000D
Cah00`00Cai?7P0=Cah50003Dah00`00DaiC7P0FDah01000DaiC7U<N1P003e<N00<005<nDch03E<n
1P000e<N00<005<nDch05E<n10005e<n00<005<nDch01@004U<n00<005<nDch015<n10003e<n00<0
05<nDch00e<n10003e=N00<005=NDeh01@004U=N00<005=ODel010004E=O10003U=O10001e=O00<0
05=oDgl025=o0`002e=o00<005=oDgl010003U=o10000U=o00<005=oDgl02E=o0`002e=o00<005=o
Dgl010003Dmo10000Tmo00D007ooOomoo`0005eoo`00IGoo00<007ooOol0=Goo00<004<o@cl054<o
00<004<o@cl02D<o3`004T<o0P0054<o00<004LoAcl00dLo2`001TLo00<004LoAcl054Lo00<004LO
Aal03dLO2P004DLO00<004LOAal054LO00<004LOAal044LO2P004D/O00<004/OBal054/O00<004/O
Bal044/O2@004d/N00<004/NBah054/N00<004/NBah014/N2`001D/N00<004lNCah05DlN00<004lN
Cah02TlN1`0014lN00<004lNCah05DlN00<004lNCah04TlN1`005DlN00<004lNCah03DlN1@000dlN
00<004lNCah05DlN00<004lNCah01dlN1P002E<N00<005<NDah04e<N1P005U<N00<005<nDch01e<n
1@002U<N00<005<nDch03e<n1@000U<n00<005<nDch05E<n10005e<n00<005<nDch010004e<n00<0
05<nDch00`004U=N10005U=N10004E=O10000U=O00<005=ODel02U=O0`002e=O00<005=oDgl015=o
10003E=o10003U=o10001e=o00<005=oDgl015=o10003E=o10003Dmo10001dmo00D007ooOomoo`00
05aoo`00IGoo00<007ooOol0=Woo0P0044<o400034<o00<004<o@cl054<o00<004<o@cl024<o3`00
4TLo00<004LoAcl054Lo00<004LOAal00dLO2`001TLO00<004LOAal04dLO00<004LOAal054LO00<0
04LOAal014LO2`001DLO00<004/OBal054/O00<004/OBal054/O00<004/OBal014/O2`001D/N00<0
04/NBah05D/N00<004/NBah03d/N2`004D/N00<004lNCah05DlN00<004lNCah00TlN1`0034lN00<0
04lNCah05DlN00<004lNCah02DlN200014lN00<004lNCah05TlN00<004lNCah01TlN1P002DlN00<0
04lNCah05DlN00@004lNCai?7PD0011C7P03001C7U<N00eC7PD000=C7P03001C7U<N01IC7P04001C
?U<nDch6000?Dah00`00DciC?P0:Dch50008Dch00`00DciC?P0?Dch50002Dch00`00DciC?P0EDch4
000FDch4000ADeh40002Deh00`00DeiCGP0ADeh40002Deh00`00DemCG`0<Del40007Del00`00DemC
G`05Del4000>Del00`00DgmCO`04000=Dgl400000e=o0000000<Dgl3000;Dgl00`00DgmCO`04000=
Dgl40002Cgl00`00Cgm?O`09Cgl3000;Cgl01@00Oomoogoo0000G7oo001UOol00`00Oomoo`0hOol0
0`00@cm3?`03@cl:0006@cl00`00@cm3?`0D@cl00`00@cm3?`0?@cl?000<@cl00`00Acm7?`0CAcl0
0`00Acm7?`0?Acl:000BAal00`00Aam77`0CAal00`00Aam77`0?Aal;000AAal00`00Bam;7`0DBal0
0`00Bam;7`0?Bal;000ABah00`00Bai;7P0EBah00`00Bai;7P03Bah;0005Bah00`00Bai;7P0EBah0
0`00Cai?7P0ACah8000CCah00`00Cai?7P0ECah00`00Cai?7P02Cah7000=Cah00`00Cai?7P0ECah0
1000Cai?7TlN1@003dlN00<004lNCah04dlN1P005E<N00<005<NDah01e<N1P002E<N00<005<NDah0
55<N1@005U<N00<005<nDch01E<n10003E<n00<005<nDch02U<n1@0025<n00<005<nDch03e<n1@00
0U<n00<005<nDch045<n1@000U<n00<005=NDeh035=N10001e=N00<005=NDeh035=N10001e=N00<0
05=ODel025=O0`0035=O00<005=ODel010004E=O10003U=o0`001E=o00<005=o00001e=o10003E=o
10003E=o10001dmo00<004moCgl014mo10003Dmo0`000goo00<007ooOol0FGoo001UOol00`00Oomo
o`0iOol5000A@cl00`00@cm3?`0D@cl00`00@cm3?`03@cl;0006@cl00`00@cm3?`0C@cl2000DAcl0
0`00Acm7?`03Acl;0006Aal00`00Aam77`0DAal00`00Aam77`0CAal00`00Aam77`03Aal;0006Aal0
0`00Aam77`0DAal00`00Bam;7`0DBal00`00Bam;7`03Bal;0006Bal00`00Bai;7P0DBah00`00Bai;
7P0@Bah:000ABah00`00Bai;7P0DBah00`00Cai?7P0:Cah70004Cah00`00Cai?7P0ECah00`00Cai?
7P0ACah8000DCah00`00Cai?7P0BCah7000ECah00`00Cai?7P0=Cah50003Cah00`00DaiC7P0FDah0
1000DaiC7U<N1@003e<N00<005<NDah03e<N1@000U<N00<005<NDah05U<N00<005<nDch01@004U<n
00<005<nDch01E<n10003E<n00<005<nDch02U<n1@0025<n00<005<nDch02U<n1@0025<n00<005=N
Deh025=N0`002e=N00<005=NDeh02E=N0`002e=N00<005=ODel015=O10003U=O10004E=O10000U=o
00<005=oDgl02E=o100025=o00@005=oDgl0009CO`@000eCO`@0009CO`03001COe=o00UCO`<000]?
O`03001?Odmo00@000e?O`@0009?O`05001oogooOol0001KOol006Eoo`03001oogoo03]oo`030013
?d<o0193?`030013?d<o00m3?`X00193?`030013?d<o01A3?`030017?dLo00Q7?`l001977`030017
7dLO01A77`0300177dLO00U77`l001977`0300177dLO01A77`03001;7d/O00U;7a00019;7`03001;
7T/N01A;7P03001;7T/N00A;7P/000E;7P03001;7T/N01A;7P03001;7T/N01A;7P03001?7TlN009?
7PL000a?7P03001?7TlN01E?7P03001?7TlN00U?7PL000A?7P03001?7TlN01I?7P03001?7TlN00U?
7PP000A?7P03001?7TlN01I?7P03001?7TlN00I?7PH000U?7P03001C7U<N01=C7PH001EC7P03001C
7U<N00YC7P@000QC7P03001C7U<N01AC7P@001MC?P03001C?U<n00D0019C?P03001C?U<n00EC?P@0
00iC?P03001C?U<n00EC?P@000eC?P03001CGU=N00ACGP@000mCGP03001CGU=N00ACGP@000iCGP03
001CGe=O00@000mCG`<0009CG`03001CGe=O00eCG`<000MCO`03001COe=o00ACO`@000aCO`03001C
O`0000<000eCO`@000MCO`03001COe=o00ACO`@000e?O`@000e?O`@000M?O`05001oogooOol0001J
Ool006Eoo`03001oogoo03aoo`030013?d<o0193?`030013?d<o00=3?`/000M3?`030013?d<o01=3
?`030013?d<o00m3?`l000a37`0300177dLO01=77`0300177dLO00m77a0000]77`0300177dLO01A7
7`0300177dLO00m77a0000];7`03001;7d/O01E;7`03001;7T/N00m;7P/0015;7P03001;7T/N01A;
7P03001;7T/N00m;7PT001A?7P03001?7TlN01A?7P03001?7TlN009?7PL000a?7P03001?7TlN01E?
7P03001?7TlN009?7PL000e?7P03001?7TlN01E?7P04001?7TlNCah5000@Cah00`00DaiC7P0=Dah5
0003Dah00`00DaiC7P0FDah00`00DaiC7P05Dah4000<Dah00`00DaiC7P0?Dah50002Dah00`00DciC
?P0EDch4000GDch00`00DciC?P05000BDch00`00DciC?P05000ADch00`00DeiCGP04000CDeh00`00
DeiCGP04000ADeh4000@Del30006Del00`00DemCG`08Del4000;Dgl00`00DgmCO`03000>Dgl40002
Dgl00`00DgmCO`09Dgl3000;Dgl00`00DgmCO`04000=Cgl40002Cgl00`00Cgm?O`09Cgl3000;Cgl0
1@00Oomoogoo0000FWoo001TOol00`00Oomoo`0nOol00`00@cm3?`08@cl?000C@cl00`00@cm3?`0C
@cl00`00@cm3?`03@cl;0006@cl00`00@am37`0C@al00`00Aam77`0CAal00`00Aam77`03Aal;0006
Aal00`00Aam77`0CAal00`00Aam77`0DAal00`00Aam77`03Aal;0005Aal00`00Bam;7`0DBal00`00
Bam;7`0EBal00`00Bai;7P03Bah;0005Bah00`00Bai;7P0EBah00`00Bai;7P0DBah00`00Bai;7P03
Bah;0005Bah00`00Cai?7P0ECah00`00Cai?7P0@Cah9000DCah00`00Cai?7P0ACah8000DCah00`00
Cai?7P0BCah7000ECah00`00DaiC7P07Dah60009Dah00`00DaiC7P0EDah00`00DaiC7P05000ADah0
0`00DaiC7P0:Dah40008Dah00`00DciC?P0?Dch50002Dch00`00DciC?P0EDch4000FDch4000EDch4
000FDeh4000ADeh40002Eeh00`00DemCG`0;Del4000:Del00`00DemCG`03Del4000>Dgl4000=Dgl4
0002Dgl00`00DgmCO`02Dgl00`00DgmCO`04Dgl4000=Dgl4000=Cgl40007Cgl00`00Cgm?O`04Cgl4
000=Cgl30003Ool00`00Oomoo`1GOol006Aoo`03001oogoo03moo`X000a3?`030013?d<o01A3?`03
0013?d<o00U3?`l00193?`0300137d<O01=37`0300177dLO00U77`l001977`0300177dLO01=77`03
00177dLO00m77`X001577`03001;7d/O01A;7`03001;7d/O011;7`X0015;7P03001;7T/N01A;7P03
001;7T/N011;7PX0015;7P03001?7TlN01E?7P03001?7TlN00A?7P/000E?7P03001?7TlN01E?7P03
001?7TlN00Y?7PL000A?7P03001?7TlN01I?7P03001?7TlN00U?7PP000A?7P03001?7TlN01I?7P04
001C7U<NDah5000?Dah00`00DaiC7P0CDah5000GDah00`00DaiC7P05Dah4000=Dah00`00DciC?P0:
Dch40008Dch00`00DciC?P0?Dch50002Dch00`00DciC?P0ADch40002Dch00`00DciC?P0@Dch40002
Ech00`00DeiCGP0ADeh40002Eeh00`00DeiCGP0=Deh30007Eeh00`00DemCG`07Del3000>Del00`00
DemCG`03000>Dgl40002Dgl00`00DgmCO`09Dgl30006Dgl00`00DgmCO`02Dgl00`00DgmCO`04000=
Dgl40002Cgl00`00Cgm?O`09Cgl3000;Cgl00`00Cgm?O`04000<Cgl50002Cgl01@00Oomoogoo0000
FGoo001TOol00`00Oomoo`11Ool00`00@cm3?`0B@cl2000@@cl@000<@cl00`00@cm3?`0C@cl00`00
@am37`0>@al@000;Aal00`00Aam77`0DAal00`00Aam77`0CAal00`00Aam77`03Aal;0005Aal00`00
Aam77`0DAal00`00Bam;7`0DBal00`00Bam;7`04Bal;0005Bah00`00Bai;7P0DBah00`00Bai;7P0D
Bah00`00Bai;7P04Bah;0005Bah00`00Bai;7P0DBah00`00Cai?7P0BCah9000ACah00`00Cai?7P0E
Cah00`00Cai?7P02Cah7000<Cah00`00Cai?7P0ECah00`00Cai?7P02Cah7000=Cah00`00Cai?7P0C
Cah6000EDah00`00DaiC7P0=Dah50003Dah00`00DaiC7P0FDah00`00DaiC7P05000ADah00`00DciC
?P06Dch4000<Dch00`00DciC?P0:Dch50008Dch00`00DciC?P0<Dch40007Dch00`00DciC?P0<Dch3
0007Ech00`00DeiCGP0<Deh40007Eeh00`00DeiCGP08Deh4000;Eeh00`00DemCG`03Del3000@Del4
000=Dgl40007Dgl00`00DgmCO`04Dgl40009Dgl01000DgmCOe=o10003U=o0`001dmo00<004moCgl0
14mo10003Dmo10002dmo1@0024mo00D007ooOomoo`0005Qoo`00I7oo00<007ooOol0@Woo00<004<o
@cl04d<o00<004<o@cl00d<o2P001d<o00<004<o@cl04d<o00<004<o@cl04d<o00<004<O@al00d<O
2P001T<O00<004LOAal04dLO00<004LOAal054LO00<004LOAal02DLO3`004DLO00<004LOAal054LO
00<004/OBal03d/O2`004D/N00<004/NBah054/N00<004/NBah03d/N2`004D/N00<004/NBah054/N
00<004lNCah02TlN1`000dlN00<004lNCah05DlN00<004lNCah04DlN200054lN00<004lNCah04DlN
200054lN00<004lNCah03DlN1P000e<N00<005<NDah05U<N00<005<NDah01U<N1P002E<N00<005<N
Dah04e<N1@005e<N00<005<nDch01@004E<n00<005<nDch01E<n10003E<n00<005<nDch02E<n0`00
2e<n00<005<nDch025<n10002ULn00<005=NDeh02E=N0`0035MN00<005=NDeh00e=N10003eMN00<0
05=ODel00`003e=O10000U=o00<005=oDgl02E=o0`002e=o00<005=oDgl010003E=o10000U=o00<0
05=oDgl02E=o10002Tmo00<004moCgl0100034mo1@000Tmo00<004moCgl01Tmo10003Dmo00D007oo
Oomoo`0005Qoo`00I7oo00<007ooOol00`00@7oo00<004<o@cl02D<o3`004T<o00<004<o@cl04d<o
00<004<o@cl02D<o3`004D<O00<004LOAal04dLO00<004LOAal03dLO40002dLO00<004LOAal04dLO
00<004LOAal054LO00<004/OBal00d/O2`001D/O00<004/NBah05D/N00<004/NBah054/N00<004/N
Bah00d/N2`001D/N00<004/NBah05D/N00<004/NBah054/N00<004lNCah00TlN1`002dlN00<004lN
Cah054lN00<004lNCah02TlN1`0014lN00<004lNCah05DlN00<004lNCah02TlN1`0014lN00<004lN
Cah05TlN00<004lNCah01dlN1@002U<N00<005<NDah05E<N00@005<NDaiC7PD000mC7P03001C7U<N
00eC7PH000=C7P03001C7U<N01EC7P@001IC?P03001C?U<n00D0019C?P03001C?U<n00AC?P@000mC
?P03001C?U<n00=C?P@000mG?P03001CGU=N00ACGP@000mGGP03001CGU=N00<0019GGP@000iCG`@0
00MCO`03001COe=o00ACO`@000eCO`@000iCO`<00003Dgl005=o00ACO`03001COe=o00ACO`@000e?
O`@000a?O`@000Q?O`03001?Odmo00D0011?O`<000=oo`03001oogoo05Eoo`00I7oo0`00A7oo2`00
34<o00<004<o@cl04d<o00<004<o@cl03T<o400034<O00<004<O@al04T<O00<004LOAal04dLO00<0
04LOAal00dLO2`001TLO00<004LOAal04dLO00<004LOAal04dLO00<004LOAal03dLO2P004D/O00<0
04/NBah054/N00<004/NBah044/N2P004D/N00<004/NBah054/N00<004/NBah044/N2@004dlN00<0
04lNCah054lN00<004lNCah00TlN1`0034lN00<004lNCah05DlN00<004lNCah00TlN1`0034lN00<0
04lNCah05DlN00@004lNCai?7PH000mC7P03001C7U<N01=C7PH001EC7P03001C7U<N00MC7PD000YC
7P03001C7U<N00mC7PD0009C7P03001C?U<n01AC?P@001MC?P03001C?U<n00@001=C?P03001C?U<n
00<001=G?P03001CGU=N00@0019GGP@0015GGP@0009GGP03001CGe=O00YCG`<000]CO`03001COe=o
00@000iCO`<0009CO`03001COe=o00UCO`@000ACO`03001COe=o00ACO`03001COe=o00<000e?O`@0
00=?O`03001?Odmo00I?O`@000]?O`@0011?O`D0009;O`05001oogooOol0001GOol006Aoo`03001o
ogoo04Ioo`030013?d<o01=3?`030013?d<o01=3?`030013?d<o00=3?`X000I3?`0300137d<O01A3
7`0300137d<O01937`0300177dLO00U77`l001977`0300177dLO01=77`0300177dLO01=77`030017
7dLO00=77`/000I77`03001;7d/O01=;7`03001;7T/N01A;7P03001;7T/N00A;7P/000E;7P03001;
7T/N01A;7P03001;7T/N01A;7P03001;7T/N00A;7P/000E?7P03001?7TlN01E?7P03001?7TlN015?
7PL001=?7P03001?7TlN01=?7PL001=?7P03001?7TlN01=?7PH001IC7P03001C7U<N00aC7PH000=C
7P03001C7U<N01EC7P04001C7U<NDah6000?Dah00`00DaiC7P0:Dah50008Dah00`00DciC?P0>Dch5
0002Dch00`00DciC?P0EDch4000FDch4000EEch4000BEeh40002Eeh00`00EeiGGP0=Eeh30007Eeh0
0`00DemCG`05Del4000=Dgl4000?Dgl30006Dgl00`00DgmCO`04Dgl40008Dgl00`00DgmCO`03Dgl4
000=Cgl30008Cgl00`00Cgm?O`05000;Cgl40002Bgl00`00Cgm?O`0;Cgl40008Bgl01@00Oomoogoo
0000EWoo001TOol00`00Oomoo`17Ool2000D@cl00`00@cm3?`09@cl?000A@cl00`00@am37`0D@al0
0`00@am37`08@alE000;@al00`00Aam77`0DAal00`00Aam77`0CAal00`00Aam77`09Aal?000BAal0
0`00Bam;7`0CBal00`00Bai;7P0?Bah;000ABah00`00Bai;7P0CBah00`00Bai;7P0@Bah;000ACah0
0`00Cai?7P0DCah00`00Cai?7P0:Cah70003Cah00`00Cai?7P0ECah00`00Cai?7P0=Cah50003Cah0
0`00Cai?7P0ECah00`00Cai?7P0=Cah50003Dah00`00DaiC7P0FDah00`00DaiC7P07Dah5000:Dah0
0`00DaiC7P0BDah6000FDah00`00DaiC7P05Dah4000=Dah00`00DciC?P0:Dch40008Dch00`00DciC
?P0?Dch50002Ech00`00DciC?P0ADch40002Ech00`00EciG?P0@Ech40002Ech00`00EeiGGP0=Eeh4
0007Eeh00`00EeiGGP08Eeh4000;Eeh00`00DemCG`04000>Dgl30002Dgl00`00DgmCO`0;Dgl3000:
Dgl00`00DgmCO`03000<Dgl00`00Dgl000030002Cgl00`00Cgm?O`08Cgl4000:Cgl4000=Cgl30007
Bgl00`00Cgm?O`06Cgl4000<Bgl01@00Oomoogoo0000EWoo001TOol00`00Oomoo`19Ool00`00@cm3
?`08@clE000<@cl00`00@cm3?`0B@cl00`00@am37`0?@al?000;@al00`00@am37`0C@al00`00Aam7
7`0DAal00`00Aam77`09AalE000;Aal00`00Aam77`0DAal00`00Bam;7`0CBal00`00Bai;7P03Bah;
0005Bah00`00Bai;7P0EBah00`00Bai;7P0CBah00`00Bai;7P04Bah;0005Bah00`00Cai?7P0ECah0
0`00Cai?7P0DCah00`00Cai?7P02Cah7000;Cah00`00Cai?7P0ECah00`00Cai?7P06Cah60009Cah0
0`00Cai?7P0ECah00`00Cai?7P06Cah60009Dah00`00DaiC7P0EDah01000DaiC7U<N1P003e<N00<0
05<NDah03E<N1@000e<N00<005<NDah05U<N00<005<NDah01@004U<N00<005<nDch01E<n10003E<n
00<005<nDch02U<n100025Ln00<005<nDch035<n10001eLn00<005LnEch035Ln0`001eLn00<005MN
Eeh02EMN0`0035MN00<005MNEeh00eMN10003UMN10003e=o0`001U=o00<005=oDgl01e=o0`0035=o
10003E=o10001dmo00<004moCgl00dmo10002Tmo10000Tmo00<004moCgl024mo10002d]o00<004mo
Cgl01@003d]o0`000goo00<007ooOol0Dgoo001TOol00`00Oomoo`1:Ool:000<?cl00`00@cm3?`0C
@cl00`00@cm3?`0B@cl00`00@am37`03@al;0006@al00`00@am37`0B@al00`00@am37`0C@al00`00
Aam77`0?Aal@000;Aal00`00Aam77`0CAal00`00Aam77`0DAal00`00Bam;7`09Bal?000ABah00`00
Bai;7P0DBah00`00Bai;7P0?Bah;000ABah00`00Cai?7P0DCah00`00Cai?7P0@Cah9000CCah00`00
Cai?7P0DCah01000Cai?7TlN1@003dlN00<004lNCah05DlN00@004lNCai?7PD000mC7P03001C7U<N
01=C7PH001IC7P03001C7U<N00IC7PH000UC7P03001C7U<N01=C7PD001MC7P03001C?U<n00D0015C
?P03001C?U<n00IC?P@000aG?P03001C?U<n00UC?P<000]G?P03001G?ULn00QG?P@000]G?P03001G
GUMN00AGGP@000mGGP03001GGUMN00<000mGGP<0009GGP03001COe=o00]CO`<000YCO`03001COe=o
00=CO`<000aCO`<0009CO`03001COe=o00UCO`<0009?O`03001?Odmo00I?O`03001?Odmo00<000Y?
O`@000M?O`03001?Odmo00=?O`@000i;O`@000m;O`D0009;O`03001oogoo009oo`03001oogoo059o
o`00I7oo00<007ooOol0C7oo00<003lo?cl04Slo00<004<o@cl04d<o00<004<o@cl024<o3`004T<O
00<004<O@al04T<O00<004<O@al04d<O00<004LOAal00dLO2`001TLO00<004LOAal04dLO00<004LO
Aal04dLO00<004LOAal03dLO40002T/N00<004/NBah054/N00<004/NBah054/N00<004/NBah00d/N
2`001D/N00<004/NBah05D/N00<004lNCah054lN00<004lNCah014lN2`001Dkn00<004lNCah054lN
00<004lNCah044lN20005DlN00<004lNCah04DlN1`005E<N00<005<NDah03E<N1@000e<M00<005<N
Dah05U<N00@005<NDaiC7PD0011C7P03001C7U<N00eC7PD000=C7P03001C7U<N01EC7P@001MC?P03
001C?U<n00D0015G?P03001C?U<n00AC?P@000mG?P03001G?ULn00=G?P@000mG?P03001GGUMN00@0
019GGP@000mGGP<000IGGP03001COe=o00MCO`<000eCO`03001COe=o00<000aCO`<000ICO`03001C
Oe=o00ACO`@000E?O`03001?Odmo00E?O`@000Y?O`<000]?O`03001?Odmo00<000e;O`D0009;O`03
001;Od]o00Y;O`@000Q;O`05001oogooOol0001DOol006Aoo`03001oogoo04eoo`03000o?clo018o
?`030013?d<o00U3?a@000a37`0300137d<O01=37`0300137d<O01937`0300137d<O00U37`l00197
7`0300177dLO01=77`0300177dLO01=77`0300177dLO00=77`/000E77`03001;7T/N01=;7P03001;
7T/N01A;7P03001;7T/N00m;7PX0015;7P03001;7T/N01A;7P03001?7TlN011?7P/0015>oP03001?
7TlN01A?7P03001?7TlN00A?7P/000E>oP03001?7TlN01I?7P03001?7TlN00U?7PL000A?7P03001C
7U<N01IC7P03001C7U<N00IC7PH000UC7@03001C7U<N01AC7PD001EC7P03001C7U<N00MC7PH000UC
7P03001C7U<N00mC7PD0009C7P03001C?U<n01EC?P@001IG?P03001C?U<n00@001=G?P03001G?ULn
00<0019G?P@0019GGP@0009GGP03001GGUMN00YGGP@000YGGP03001COe=o00=CO`<000mCO`@000]C
O`@000UCO`03001COe=o00@000U?O`04001?OdmoCgl40002Cil00`00Cgm?O`05Cgl4000=Cgl4000;
Bgl50008Bgl00`00Bgm;O`05Bgl4000<Bgl00`00Oomoo`02Ool00`00Oomoo`1AOol006Aoo`03001o
ogoo04ioo`03000o?clo00Po?aD000`o?`0300137d<O01937`0300137d<O01=37`0300137d<O00Q3
7aD000]37`0300177dLO01A77`0300177dLO01=77`0300177dLO00U77`l001577`03001;7T/N01=;
7P03001;7T/N01A;7P03001;7T/N00=;7P/000E;7P03001;7T/N01A;7P03001;7T/N01A;7P03001?
7TlN00A?7P/000E>oP03001>oTkn01E>oP03001?7TlN015?7PT0015>oP03001?7TlN01E?7P03001?
7TlN009?7PL000a?7P03001C7U<N01EC7P04001C7U<NDah5000?Dad00`00DaiC7P0?Dah50002Dad0
0`00DaiC7P0FDah01000DaiC7U<N1@0045<N00<005<NDah02U<N100025<N00<005<nDch03e<n1@00
0ULn00<005LnEch055Ln10005ULn10004ELn10000UMN00<005MNEeh03EMN10001eMN00<005MNEeh0
1UMN0`003UMN00<005=oDgl00`003U=o10000U=o00<005=oDgl01e=o0`0035=o10003Dmo10001dnO
00<004moCgl0100034mo1@000T]o00<004]oBgl01T]o10003D]o00<004]oBgl01@003T]o10000goo
00<007ooOol0DGoo001TOol00`00Oomoo`1?Ool:000<?cl00`00?clo?`0C?cl00`00@am37`0B@al0
0`00@am37`09@alD000;@al00`00@am37`0C@al00`00Aam77`0DAal00`00Aam77`09AalE000:Aal0
0`00Aam77`0DAal00`00Bai;7P0BBah00`00Bai;7P0@Bah:000ABah00`00Bai;7P0DBah00`00Bai;
7P0ABah9000AC_h00`00C_i>oP0DC_h00`00Cai?7P0:Cah70003C_h00`00C_i>oP0EC_h00`00Cai?
7P0ACah8000DCah00`00DaiC7P0ADah7000EDad00`00DaiC7P0:Dah40008Dad00`00DaiC7P0DDah5
000EDah00`00DaiC7P06Dah4000<Dah00`00DciC?P0:Dch50008Ech00`00EciG?P0>Ech50002Ech0
0`00EciG?P0@Ech50002Ech00`00EciG?P0=Ech30007Eeh00`00EeiGGP09Eeh3000;Eeh00`00EeiG
GP03Eeh3000@Eeh4000=Dgl40007Dgl00`00DgmCO`03Dgl3000<Dgl30002Dil00`00Cgm?O`09Cgl4
0009Cil4000<Cgl40008Bgl00`00Bgm;O`05000?Bgl5000>Bgl50003Bel00`00Oomoo`02Ool00`00
Oomoo`1@Ool006Aoo`03001oogoo055oo`03000o?clo018o?`8001@o?`0300137d<O00Q37aD000]3
7`0300137d<O01937`0300137d<O01=37`0300177dLO00m77a0000Y77`0300177dLO01=77`030017
7dLO01=77`03001;7T/N01=;7P03001;7T/N00A;7P/000E;7P03001;7T/N01A;7P03001;7T/N01=;
7P03001;7T/N00Y;7PL000=:oP03001>oTkn01A>oP03001>oTkn01E>oP03001?7TlN009?7PL000]>
oP03001>oTkn01A>oP03001?7TlN00Y?7PL000A>o@03001?7TlN01E?7P03001C7U<N00YC7PL000AC
7@03001C7E<M01IC7@03001C7U<N00EC7P@000aC7@03001C7U<N00mC7PD0009C7@03001C7U<N01IC
7P03001C7U<N00D0015C7P03001C?U<n00EC?P@000eG?P03001G?ULn00YG?P@000QG?P03001G?ULn
00YG?PD000QG?P03001G?ULn00QG?P@000]GGP03001GGUMN00AGGP@000iGGP03001GGUMN00<0011G
GP<0009GO`03001COe=o00UCO`<000]CO`03001COe=o00<000aCO`<000ICW`03001?Odmo00A?O`@0
00=?W`03001?WdnO00=?W`@000=;W`03001?Odmo00I?O`@000];O`@000i;O`H000=;O`03001;Od]o
00M;O`H000U;G`05001oogooOol0001BOol006=oo`03001oogoo05=oo`8001@o?`03000o?clo00Po
?a@000a37`0300137d<O01937`0300137d<O01937`0300137d<O01=37`0300177dLO00=77`/000E7
7`0300177dLO01=77`0300177dLO01=77`0300177dLO01=77`03001;7T/N00U;7Q00015;7P03001;
7T/N01=;7P03001;7T/N01A;7P03001;7T/N009;7PL000]:oP03001>oTkn01A>oP03001>oTkn015>
oPP0019>oP03001>oTkn01E>oP03001?7TlN009?7PL000a>o@03001?7TlN01E?7P03001C7U<N009C
7PL000aC7@03001C7E<M01EC7@03001C7U<N00D0015C7@03001C7U<N00YC7P@000QC7@03001C7U<N
01AC7P@001IC7P03001C?U<n00D0019G?P03001G?ULn00EG?P@000eG?P03001G?ULn00EG?P@000iG
?P03001G?ULn00=G?P@000mGGP03001GGUMN00@0015GGP@0011GGP<000IGO`03001COe=o00ACO`@0
00eCO`@000aCO`<000YCW`03001?Odmo00<000M?W`03001?WdnO00<000Q;W`03001?Odmo00D000Y;
O`D00097O`03001;Od]o00Q;O`D000Y;O`04001;Od]oBgl5000?Bel00`00Oomoo`02Ool00`00Oomo
o`1?Ool006=oo`03001oogoo05Eoo`03000o?clo00Po?a@000`o7`0300137d<O01937`0300137d<O
01937`0300137d<O01937`0300137d<O00U37`l001577`0300177dLO01=77`0300177dLO01=77`03
00177dLO00U77aD000Y;7P03001;7T/N01E;7P03001;7T/N01=;7P03001;7T/N00U;7Pl0019:oP03
001>oTkn01E>oP03001>oTkn00U>oPL000A>oP03001>oTkn01A>oP03001>oTkn015>oPP001=>o@03
001?7TlN01=?7PL001AC7@03001C7E<M015C7@H001MC7@03001C7U<N00EC7P@000aC7@03001C7U<N
00mC7PD0009C7@03001C7U<N01AC7P@001MG?P03001G?ULn00D0015G?P03001G?ULn00D0019G?P03
001G?ULn00<0019GGP@0015GGP@0009GGP03001GGUMN00]GGP@000UGO`03001COe=o00@000eCO`@0
009CO`03001COe=o00QCO`<000aCW`@000U?W`@000Y;W`@000];O`@000Q7O`04001;Od]oBgl6000>
Bgl5000BBel40003Ool00`00Oomoo`1?Ool006=oo`03001oogoo05Ioo`X000`o7`03000o7clO018o
7`0300137d<O01937`0300137d<O01937`0300137d<O00Q37aD000]37`0300177dLO01=77`030017
7dLO01977`0300177dLO00m77a0000Y77P03001;7T/N01=;7P03001;7T/N01A;7P03001;7T/N00m;
7Q0000]:oP03001:oT[n01A:oP03001>oTkn01A>oP03001>oTkn009>oPL000a>oP03001>oTkn01A>
oP03001>oTkn00U>oPL000A>o@03001>oDkm01E>o@03001?7TlN00e?7PD000=Bo@03001C7E<M01EC
7@03001C7E<M00YC7@L000AC7@03001C7E<M01IC7@03001C7U<N00D0015C7@03001C7U<N00UC7PD0
00QC7@03001C7U<N00mC7P@0009G7@03001G?ULn01EG?P@001EG?P@001IG?P@0019GGP<0009GGP03
001GGUMN00eGGP<000MGGP03001GGUMN00MGGP<000aGO`@000iCO`<000MCO`03001COe=o00ACO`<0
00]CW`@0009?W`03001?WdnO00A?W`@00003Bil004^O00M;W`@00097W`03001;Od]o00I;O`@000]7
O`D000m;O`D00097O`03001;Gd]O00e;G`D000=;G`03001oogoo009oo`03001oogoo04ioo`00Hgoo
00<007ooOol0F7oo00<003lO?al04SlO00<003lO?al04SlO00<004<O@al024<O:@0034<O00<004<O
@al04T<O00<004LOAal04dLO00<004LOAal04TLO00<004LOAal00dLO2`001DLO00<004LNAah04dLN
00<004/NBah04d/N00<004/NBah054/N00<004/NBah00d/N2`001D[n00<004[nB_h054[n00<004[n
B_h054[n00<004knC_h03dkn2@004dkn00<004knC_h054kn00<004knC_h00Tkn1`0034km00<004km
C_d05Dkm00<004lNCah01TlN1P002E;m00<005<MDad05E<M00<005<MDad00U<M1`0035<M00<005<M
Dad04e<M1@005U<M00<005<NDah01E<N10003E<M00<005<NDah035<N0`001eLM00<005LnEch045Ln
10000ULn00<005LnEch045Ln10000ULn00<005LnEch04ELn10000ULn00<005MNEeh03UMN0`001UMN
00<005MNEeh025MN10002eMN00<005MNEeh00eMN0`0035Mo0`000UMo00<005=oDgl02E=o10002e=o
00<005=oDgl00`002U>O10001dnO00<004nOCil00`001D^O00<004^OBil00T^O10001dNO00<004]o
Bgl01@002TMo1@000TMo00<004]oBgl02d]o100024Mo00<004]OBel01T]O1P002D]O00D007ooOomo
o`00051oo`00Hgoo00<007ooOol0FGoo00<003lO?al04SlO00<003lO?al023lO50002clO00<004<O
@al04d<O00<004<O@al04T<O00<004<O@al04T<O00<004LOAal04dLO00<004LOAal024LO3`004DLO
00<004LNAah04dLN00<004/NBah04d/N00<004/NBah03d/N2P004D[n00<004[nB_h054[n00<004[n
B_h04d[n00<004knC_h014kn2`001Dkn00<004knC_h05Dkn00<004knC_h04Dkn1`004dkm00<004km
C_d05Dkm00@004lNCai?7PD000mBo@03001C7E<M01=C7@L001=C7@03001C7E<M00eC7@H000=C7@03
001C7E<M01EC7@03001C7U<N00D0019C7@03001C7U<N00MC7P@000YG7@03001G?ULn00eG?P<000MG
?P03001G?ULn00aG?P<000MG?P03001G?ULn00aG?P@000MG?P03001GGUMN00YGGP<000YGGP03001G
GUMN00=GGP@000mGGP03001GGUMN00<000aGO`<000IGO`03001COe=o00ACO`@000iCO`@000YCW`<0
00Y?W`@000Q;W`03001;W`00008000Y7W`@000]7O`@000Q7O`03001;Od]o00I;O`@000a7O`04001;
Gd]OBel5000?Bel00`00Oomoo`02Ool00`00Oomoo`1=Ool006=oo`03001oogoo05Yoo`03000o7clO
00Po7a@000/o7`03000o7clO018o7`0300137d<O01=37`0300137d<O01937`0300137d<O01937`03
00177dLO00U77a@000]77`0300177dLO01=77`0300177TLN01=77P03001;7T/N01=;7P03001;7T/N
00=;7P/000E:oP03001:oT[n01A:oP03001:oT[n01=:oP03001:oT[n00m:oP/0015>oP03001>oTkn
01E>oP03001>oTkn00U>oPL000=>o@03001>oDkm01E>o@03001>oDkm015>o@L001EBo@03001C7E<M
00eC7@D000=Bo@03001C7E<M01EC7@03001C7E<M00MC7@D000YC7@03001C7E<M01=C7@@001MC7@03
001C7U<N00=C7P@000mG7@03001G?ULn00QG?P@000YG?P03001G?ULn00QG?P@000YG?P03001G?ULn
00UG?P<000]G?P03001GGUMN00MGGP<000eGGP03001GGUMN00<0019GGP@000aGO`<000YGO`03001C
Oe=o00<000iCO`@0009CW`03001CWe>O00ECW`@000U?W`@0009;W`03001;Wd^O00E;W`@000U7W`@0
0097O`030017OdMo00I7O`@000e7O`03001;Od]o00D000i7O`H0015;G`D000=oo`03001oogoo04eo
o`00Hgoo00<007ooOol00`00F7oo2P0033lO00<003lO?al04ClO00<003lO?al04SlO00<004<O@al0
4d<O00<004<O@al024<O:P002TLO00<004LOAal04dLO00<004LOAal04dLO00<004LNAah04dLN00<0
04/NBah02D/N3`004D[n00<004[nB_h054[n00<004[nB_h04d[n00<004[nB_h00d[n2`001Dkn00<0
04knC_h05Dkn00<004knC_h054kn00<004knC_h00Tkn1`002dkm00<004kmC_d05Dkm00<004kmC_d0
2Dkm1`0015;m00<005;mD_d05U;m00<005<MDad01U<M1P002E;m00<005<MDad055<M00@005<MDaeC
7@H000mC7@03001C7E<M00iC7@D0009C7@03001C7E<M01IC7@03001C7U<N00<001AG7@03001G?ULn
00=G?P@000mG?P03001G?ULn00=G?P@000mG?P03001G?ULn00AG?P@000mG?P03001GGUMN00=GGP<0
00mGGP@0015GGP@0009GGP03001GOeMo00QGO`<000aGO`@000eCO`@000MCW`03001CWe>O00@000Y?
W`<000M;W`03001;Wd^O00@00097W`030017WdNO00E7W`<000M7O`030017OdMo00D000m7O`D000i7
O`D000=7G`03001;Gd]O00Y;G`L000A;G`03001oogoo009oo`03001oogoo04aoo`00Hgoo0`00GGoo
00<003lO?al04SlO00<003lO?al04ClO00<003lO?al04SlO00<004<O@al02D<O50002d<O00<004<O
@al04T<O00<004LOAal04TLO00<004LOAal04dLO00<004LOAal04dLO00<004LNAah02DLN5@002T[n
00<004[nB_h054[n00<004[nB_h04d[n00<004[nB_h03d[n2P004Dkn00<004knC_h054kn00<004kn
C_h044kn2@004Tkm00<004kmC_d05Dkm00<004kmC_d00Tkm1`0035;m00<005;mD_d05E;m00@005<M
DaeC7@D000mBo@03001C7E<M019C7@H001IC7@03001C7E<M00UC7@@000QC7@03001C7E<M01AC7@@0
01MG7@03001G?ULn00<001=G?P03001G?ULn00<001=G?P03001G?ULn00@001=G?P03001GGUMN00<0
00mGGP<0009GGP03001GGUMN00eGGP<000MGGP03001GOeMo00AGO`<000aGO`<0009GO`03001COe=o
00UCO`<000YCW`@000Y?W`@000U;W`@000I7W`040017WdNOAil40009Agl4000>Agl60003Agl00`00
Agm7O`07Agl60009Ael00`00Bem;G`02Bel7000<Bel01@00Oomoogoo0000CWoo001SOol00`00Oomo
o`1NOol00`00?alo7`0B?al00`00?alo7`0A?al00`00?alo7`08?alE000;@al00`00@am37`0B@al0
0`00@am37`0B@al00`00Aam77`0BAal00`00Aam77`0CAal00`00Aam77`09AalE000:A_h00`00B_i:
oP0CB_h00`00B_i:oP0CB_h00`00B_i:oP0DB_h00`00B_i:oP03B_h;0005B_h00`00C_i>oP0DC_h0
0`00C_i>oP0DC_h00`00C_i>oP04C_h;0005C_h00`00C_e>o@0DC_d00`00C_e>o@0AC_d8000CD_d0
0`00D_eBo@0CD_d6000ED_d00`00DaeC7@0<Dad50003Dad00`00DaeC7@0FDad00`00DaeC7@05Dad4
000<Dad00`00DaeC7@0?Dad50002Ead00`00EaeG7@0EEad4000EEch4000EEch4000FEch4000?Eeh3
0006Eeh00`00EeiGGP08Eeh4000;Eeh00`00EgmGO`03000<Egl30006Egl00`00DgmCO`04Dgl4000:
Dil30003Cil00`00Cim?W`04Cil40009Bil40003Ail00`00Aim7W`04Ail40008Agl50002@gl00`00
Agm7O`08Agl5000:Agl01000Agm7OdMo1@003DMO1`004D]O10000goo00<007ooOol0Bgoo001SOol0
0`00Oomoo`1OOol00`00?alo7`08?alX000<?al00`00@am37`0B@al00`00@am37`0B@al00`00@am3
7`0B@al00`00Aam77`0BAal00`00Aam77`09AalE000:A_l00`00A_i6oP0CA_h00`00B_i:oP0CB_h0
0`00B_i:oP0CB_h00`00B_i:oP09B_h@000AB_h00`00C_i>oP0DC_h00`00C_i>oP0?C_h;000AC_h0
0`00C_e>o@0DC_d00`00C_e>o@09C_d70004C_d00`00D_eBo@0ED_d00`00D_eBo@0=D_d50003D_d0
0`00D_eBo@0ED_d00`00DaeC7@06Dad60009Dad00`00DaeC7@0EDad00`00DaeC7@05000ADad00`00
DaeC7@0:Dad40008Ead00`00EaeG7@0?Ead50002Ead00`00EciG?P0@Ech40002Ecd00`00EciG?P0@
Ech40002Ech00`00EciG?P0AEch40002Ech00`00EeiGGP0;Eeh3000:Eeh00`00EeiGGP03Eeh4000>
Eeh4000<Egl30009Egl00`00DgmCO`04000;Dil30007Cil00`00Cim?W`03000:Bil30008Ail00`00
Aim7W`040007Agl40008@gl01000Agm7OdMo1P003DMo1P003DMO1@000dMO00<004]OBel03D]O1@00
0dMO00D007ooOomoo`0004eoo`00Hgoo00<007ooOol0H7oo2P0033/O00<003lO?al04ClO00<003lO
?al04SlO00<004<O@al04T<O00<004<O@al04T<O00<004<O@al04T<O00<004LOAal024LO5@002TLO
00<004KoA_l04dKo00<004KnA_h04dKn00<004[nB_h04T[n00<004[nB_h03d[n40002d[n00<004[n
B_h054[n00<004knC_h054kn00<004knC_h00dkn2`001Dkn00<004knC_h054kn00<004kmC_d054km
00<004kmC_d00Tkm1`0034km00<005;mD_d05E;m00<005;mD_d01U;m1P002E;m00<005;mD_d055;m
00@005<MDaeC7@D000mC7@03001C7E<M01=C7@D001MC7@03001C7E<M00EC7@@000aG7@03001G7ELM
00YG7@D000QG7@03001G?ULn00aG?P<000MG?@03001G?ULn00aG?P<000MG?P03001G?ULn00aG?P@0
00MG?P03001GGUMN00MGGP<000eGGP03001GGUMN00<000mGGP<0009GOP03001GOeMo00QGO`<000]G
O`@000aCW`<000U?W`@000U;W`@000Y7W`@000=7O`040017OdMoAgl4000:@gl6000>Agl50003@gl0
0`00Aem7G`07Ael60009Ael00`00Bem;G`06Bel60009Ael01@00Oomoogoo0000C7oo001SOol00`00
Oomoo`1ROol2000C>al00`00?alo7`0A?al00`00?alo7`0B?al00`00@am37`0B@al00`00@am37`08
@alY000;@al00`00Aam77`0BAal00`00A_m6o`0CA_l00`00A_i6oP0BA_h00`00B_i:oP0CB_h00`00
B_i:oP03B_h;0005B_h00`00B_i:oP0DB_h00`00B_i:oP0CB_h00`00C_i>oP0@C_h:000AC_h00`00
C_i>oP0DC_h00`00C_e>o@0AC_d7000CC_d00`00D_eBo@0ED_d01000D_eBoE;m1@003e;m00<005;m
D_d04U;m1P005E<M00<005<MDad03E<M1@000e<M00<005<MDad05U<M00<005<MDad01@004ELM00<0
05LMEad01ELM10003ELM00<005LnEch025Ln10002ULm00<005LnEch025Ln10002ULn00<005LnEch0
2ELn0`0035Ln00<005MNEeh00eMN0`003eMN10003eMN0`001UMn00<005MoEgl015Mo0`002eMo0`00
0U>O00<005>ODil025>O0`002DnO0`000T^O00<004^OBil014^O10002DNO1@000cmo00<004MoAgl0
1@002D=o1@0013mo00<004MoAgl01dMo1P002D=o00@004MOAem7G`D000m7G`04001;Gd]OBel5000?
Ael01@00Oomoogoo0000C7oo001SOol00`00Oomoo`1TOol00`00>alk7`0A>al00`00?alo7`0A?al0
0`00?alo7`08?alY000;@al00`00@am37`0A@al00`00@am37`0C@al00`00Aam77`0BAal00`00A_m6
o`0BA_l00`00A_i6oP0CA_h00`00B_i:oP09B_h?000AB_h00`00B_i:oP0DB_h00`00B_i:oP0CB_h0
0`00C_i>oP04C_h;0005C_h00`00C_i>oP0CC_h00`00C_i>oP0EC_h00`00C_e>o@09C_d70003C_d0
0`00C_e>o@0EC_d00`00D_eBo@0AD_d7000ED_d00`00D_eBo@0<D_d50003D_d00`00DaeC7@0FDad0
0`00DaeC7@06Dad60009Dad00`00DaeC7@0DDad4000FEad00`00EaeG7@05000BEad00`00EciG?P03
Ech4000?Ecd00`00EciG?P03Ech4000?Ech00`00EciG?P04Ech4000?Ech00`00EeiGGP03000?Eeh3
0002Eeh00`00EeiGGP0;Eeh3000:Egh00`00EgmGO`03000;Egl30006Dil00`00DimCW`04Dil30009
Cil30006Bil00`00Bim;W`030009Ail40007?gl400000d=o0013O`05@gl6000:?gl01000Agm7OdMo
1@003D=o1P004DMO1`004DMO1@000goo00<007ooOol0BGoo001SOol00`00Oomoo`1UOolb000;?al0
0`00?alo7`0B?al00`00@am37`0B@al00`00@am37`0A@al00`00@am37`0C@al00`00Aam77`0BAal0
0`00A_m6o`0BA_l00`00A_i6oP09A_hE000:B_h00`00B_i:oP0DB_h00`00B_i:oP0CB_h00`00B_i:
oP0?B_h;000AC_h00`00C_i>oP0CC_h00`00C_i>oP0DC_h00`00C_e>o@02C_d7000;C_d00`00C_e>
o@0EC_d00`00D_eBo@09D_d70004D_d00`00D_eBo@0ED_d00`00D_eBo@06D_d60009D_d00`00DaeC
7@0EDad01000DaeC7E<M1@003e<M00<005<MDad03e<M1@000ULM00<005LMEad055LM10005eLM00<0
05LnEch00`004eLm00<005LnEch00`004eLn00<005LnEch010004ULn10003eMN0`001UMN00<005MN
Eeh01eMN0`003EMn0`002eMo0`002U>O00<005>ODil00`002DnO0`0024^O100024NO10001Smo1@00
0c]n00@004=o0013O`D000hoO`H000e3O`D000=3G`030017GdMO00Y7G`L000A7G`030017GdMO00Y7
G`L000A7G`05001oogooOol0001;Ool006=oo`03001oogoo06Moo`03000k7c/O014k7`03000o7clO
014o7`03000o7clO014o7`03000o7clO018o7`0300137d<O01937`0300137d<O01537`0300137d<O
01=37`0300177dLO01977`030016odKo00Q6oaD000Y6oP03001:oT[n01=:oP03001:oT[n01A:oP03
001:oT[n01=:oP03001:oT[n00=:oP/000E:oP03001>oTkn01A>oP03001>oTkn01A>oP03001>oTkn
00m>oPT0019>o@03001>oDkm01E>o@03001BoE;m009Bo@L000aBo@03001BoE;m01ABo@04001BoE;m
D_d5000?D_d00`00DaeC7@0CDad6000EDad00`00DaeC7@0:Dad40008Ead00`00EaeG7@0>Ead50002
Ead00`00EaeG7@0EEad4000EEcd4000EEch4000CEch30002Eeh00`00EeiGGP0;Eeh3000:Eeh00`00
EeiGGP03Eeh3000=Egh300000eMo001GO`08Egl3000<Dil40009Cil30007Bil40004@il00`00Aim7
W`050006?gl40007>gh5000>?gl50003?gl00`00@gm3O`07@gl60009@el00`00Aem7G`02Ael7000<
Ael00`00Aem7G`02Ael7000<Ael01@00Oomoogoo0000BWoo001ROol00`00Oomoo`1YOol00`00>alk
7`0A>al00`00?alo7`0A?al00`00?alo7`0A?al00`00?alo7`0B?al00`00@am37`0B@al00`00@am3
7`0A@al00`00@am37`09@alY000:A_h00`00A_i6oP0CA_h00`00B_i:oP0CB_h00`00B_i:oP0CB_h0
0`00B_i:oP0?B_h:000AB_h00`00C_i>oP0DC_h00`00C_i>oP0CC_h00`00C_i>oP04C_h;0005C_d0
0`00C_e>o@0DC_d00`00C_e>o@0AC_d8000CD_d00`00D_eBo@0BD_d6000ED_d00`00DaeC7@0=Dad5
0003D_d00`00DaeC7@0FDad00`00DaeC7@05Dad4000<Ead00`00EaeG7@0:Ead40008Ead00`00EaeG
7@0@Ead40002Ead00`00EceG?@0@Ecd40002Ecd00`00EciG?P0@Ech40002Ech00`00EciG?P0?Ech3
0006Eeh00`00EeiGGP07Eeh3000=Eeh00`00EeiGGP03000=Egh30005Egl00`00EgmGO`03Egl3000<
Dil30003Dil00`00Cim?W`04Cil30007Bil30007@il40007?gl40006>gh50003=gh00`00?gloO`07
?gl60009?gl01000@gm3Od=o1@003D=O1`004DMO1`004dMO00D007ooOomoo`0004Yoo`00HWoo00<0
07ooOol0JWoo00<003/O>al04C/O00<003lO?al04ClO00<003lO?al04ClO00<003lO?al04SlO00<0
04<O@al024<O:@002T;o00<004KoA_l04TKo00<004KnA_h04TKn00<004KnA_h04dKn00<004[nB_h0
4d[n00<004[nB_h04d[n00<004[nB_h00d[n2`001D[n00<004[nB_h04d[n00<004knC_h05Dkn00<0
04knC_h03Tkn2`004Dkm00<004kmC_d054km00<004kmC_d02Dkm1`0014km00<005;mD_d05E;m00<0
05;mD_d035;m1@000e;m00<005;mD_d05U;m00<005<MDad01U<M1P002E;m00<005<MDad05E<M00<0
05<MDad01@004ELM00<005LMEad01ELM100035LM00<005LMEad03ELM0`001eLM00<005LmEcd035Lm
0`001eLm00<005LnEch035Ln0`001eLn00<005LnEch02ULn10002UMN00<005MNEeh00eMN0`003eMN
10003EMn0`0025Mo00<005MoEgl00`0035>O0`001e>O00<004nOCil00`001T^O10001T>O10000cMm
00<003mo?gl01@001S]n10002CMn00@003mo?gloO`D000`oO`L000e3G`D000=7G`030017GdMO00e7
G`D000=7G`030017GdMO0157G`D000=oo`03001oogoo04Moo`00HWoo00<007ooOol0JgooF`002d<O
00<004;o@_l04D;o00<004;o@_l04T;o00<004KoA_l04TKo00<004KnA_h04TKn00<004KnA_h04dKn
00<004[nB_h04d[n00<004[nB_h02D[n3`004D[n00<004[nB_h04d[n00<004knC_h054kn00<004kn
C_h00dkn2`001Dkm00<004kmC_d054km00<004kmC_d054km00<004kmC_d00Tkm1`0034km00<005;m
D_d05E;m00<005;mD_d01U;m1@002E;m00<005;mD_d05E;m00@005<MDaeC7@D000mBo@03001C7E<M
01=C7@D001IG7@03001G7ELM00D0015G7@03001G7ELM00QG7@@000YG7@03001G?ELm00QG?@@000YG
?@03001G?ULn00QG?P@000YG?P03001G?ULn00MG?P<000iGGP03001GGUMN00<000mGGP<0009GGP03
001GOUMn00UGOP<000]GO`<000aCW`<000UCW`@000E;W`@000M3W`<000HgO@@000LkOP@000XgOPL0
00XoO`L000A3G`030013Gd=O00M3G`H000U7G`030017GdMO00I7G`H000U7G`030017GdMO00U7G`L0
00A7G`05001oogooOol00019Ool0069oo`03001oogoo06eoo`03000k7c/O014k7`03000k7c/O014k
7`03000o7clO014o7`03000o7clO018o7`0300137d<O01537`030012od;o0152o`030012od;o0192
o`030016odKo0196o`030016oTKn0196oP030016oTKn01=6oP03001:oT[n00U:oQD000Y:oP03001:
oT[n01=:oP03001:oT[n01A:oP03001>oTkn00m>oPX0015>o@03001>oDkm01A>o@03001>oDkm015>
o@L001=>o@03001BoE;m01EBo@04001BoE;mD_d5000>D_d00`00D_eBo@0CD_d6000ED_d00`00DaeC
7@0=Dad50003Ead00`00EaeG7@0DEad4000GEad00`00EaeG7@03Ead4000?Ead00`00EceG?@03Ecd4
000?Ecd00`00EciG?P03Ech4000?Ech00`00EciG?P03Ech3000@Eeh4000?Eeh30006Eeh00`00EgiG
OP05Egh3000;Egl300000eNO001CW`09Dil30009Dil30003Bil00`00Bim;W`030007@il40004=gd5
0003:e`00`00>ghkOP050007=gh70003>el00`00>el00004?gl7000<@el01000@em3Gd=O1@003dMO
00@004MOAem7G`D000m7G`030017GdMO0097G`L000a7G`05001oogooOol00018Ool0069oo`03001o
ogoo06ioo`80018k7`03000k7c/O014k7`03000o7clO014o7`03000o7clO018o7`0300137d<O0153
7`030012od;o0152o`030012od;o0192o`030016odKo0196o`030016oTKn0196oP030016oTKn00U6
oQD000Y:oP03001:oT[n01=:oP03001:oT[n01=:oP03001:oT[n01=:oP03001>oTkn00A>oP/000E>
o@03001>oDkm01=>o@03001>oDkm01E>o@03001>oDkm00U>o@L000=>o@03001>oDkm01E>o@03001B
oE;m015Bo@L001ABo@03001BoE;m00eBo@D000=Bo@03001BoE;m01IBo@03001C7E<M00IC7@H000UG
7@03001G7ELM00mG7@@0009G7@03001G7ELM01IG7@03001G7ELM00<001=G7@03001G?ELm00<001=G
?@03001G?ULn00<001=G?P03001G?ULn00<0011GGP<0009KGP03001GGUMN00]GGP<000UGGP03001G
OUMn009GOP<000]GO`<000EGW`03001CWe>O00ACW`<000UCW`<000E;W`@000I3W`@000@gO@@000H[
G0H000@gOPL000TkG`P00113G`L00157G`L00157G`P001=7G`05001oogooOol00018Ool0019oo`@0
00ioo`<000Yoo``000Uoo`H001Ioo`03001oogoo071oo`03000k7c/O010k7`03000k7c/O014k7`03
000o7clO014o7`03000o7clO018o7`0300137d<O01537`030012od;o0152o`030012od;o0192o`03
0016odKo00Q6obX000Y6oP03001:oT[n01=:oP03001:oT[n01=:oP03001:oT[n01=:oP03001:oT[n
00i:oP/0015>o@03001>oDkm01=>o@03001>oDkm01A>o@03001>oDkm009>o@L000]>o@03001>oDkm
01E>o@03001BoE;m00UBo@L000ABo@03001BoE;m01EBo@03001BoE;m00IBo@H000UBo@03001BoE;m
01EBo@04001C7E<MDad5000?Ead00`00EaeG7@0<Ead30007Ead00`00EaeG7@0DEad4000EEad4000E
Ecd4000EEch4000@Eeh30006Feh00`00EeiGGP07Eeh3000<Eeh00`00Egh00002000;Egl30009Eil0
0`00DimCW`030009Dil30005Bil30004?ih00`00@im3W`030004=gd40005:e`500039c`70009>el7
00001CmO000oGcmO000034=O1`0014=O00<004MOAel02TMO1`0014MO00<004MOAel02TMO1`0014MO
00<004MOAel04DMO1@000goo00<007ooOol0AGoo000@Ool8000;Ool50009Ool<0007Ool:000DOol0
0`00Oomoo`1aOonG000:A_h00`00A_i6oP0BA_h00`00A_i6oP0CA_h00`00B_i:oP0CB_h00`00B_i:
oP0BB_h00`00B_i:oP0CB_h00`00B_i:oP03B_h;0005B_h00`00C_e>o@0DC_d00`00C_e>o@0DC_d0
0`00C_e>o@0?C_d9000BC_d00`00C_e>o@0EC_d00`00D_eBo@02D_d7000<D_d00`00D_eBo@0DD_d0
1000D_eBoE;m1@003e;m00<005;mD_d055;m1@005ELM00<005LMEad01eLM10002ULM00<005LMEad0
3eLM1@000ULM00<005LMEad045LM10000ULM00<005LmEcd04ELm0`000ULm00<005LnEch045Ln1000
0ULm00<005MNEeh02eMN10002U]N00<005MNEeh00eMN0`003UMN0`0035Mo0P002eNO10002E>O0`00
1D^O0`001SnN10000SMm1@000b]L1P000bLl1@0012mN00<003]O>el00S]O1`0023mO00D003mO?elo
G`0000A3G`L000a3G`030017GdMO0097G`L000a7G`030017GdMO0097G`L000a7G`030017GdMO00U7
G`L000A7G`05001oogooOol00017Ool0011oo`8000Aoo`8000]oo`D000Yoo`<000Ioo`8000Moo`<0
00Eoo`<001=oo`04001oogooOol5001]Ool00`00=alg7`0@=al00`00>alk7`0@>al00`00>alk7`0A
>al00`00?_lno`0A?_l00`00?_lno`0B?_l00`00@_m2o`0A@_l00`00@_m2o`0A@_l00`00A_i6oP0B
A_h00`00A_i6oP0BA_h00`00A_i6oP0CA_h00`00B_i:oP0BB_h00`00B_i:oP0CB_h00`00B_i:oP09
B_h?000AB_h00`00C_e>o@0DC_d00`00C_e>o@0CC_d00`00C_e>o@04C_d;0005C_d00`00C_e>o@0D
C_d00`00C_e>o@0AC_d8000CD_d00`00D_eBo@0BD_d6000ED_d00`00D_eBo@0>D_d50002D_d00`00
EaeG7@0EEad00`00EaeG7@03Ead4000?Ead00`00EaeG7@09Ead50008Ead00`00EaeG7@0<Ead30007
Ead00`00EceG?@0=Ecd30006Ecd00`00EciG?P0<Ech30007Ecd00`00EeiGGP07Eeh3000>Feh00`00
EeiGGP03000>Eeh30002Egh00`00EgmGO`07Egl3000:Eil30003Dil00`00DimCW`04Dil30005Bil3
0005?ih40002:cX40003:e`500039c`60006;eh8000??el9000@@el8000@Ael8000CAel00`00Aem7
G`02Ael7000<Ael01@00Oomoogoo0000AWoo000?Ool20006Ool2000:Ool5000;Ool3000GOol2000C
Ool4001cOol00`00=alg7`0@=al00`00>alk7`0@>al00`00>alk7`0A>al00`00?_lno`0A?_l00`00
?_lno`0B?_l00`00@_m2o`0A@_l00`00@_m2o`0A@_l00`00A_i6oP0BA_h00`00A_i6oP0BA_h00`00
A_i6oP0BA_h00`00B_i:oP0CB_h00`00B_i:oP09B_hE000:B_h00`00B_i:oP0DB_h00`00C_e>o@0D
C_d00`00C_e>o@0>C_d;000AC_d00`00C_e>o@0DC_d00`00C_e>o@09C_d70004D_d00`00D_eBo@0E
D_d00`00D_eBo@0<D_d50003D_d00`00D_eBo@0ED_d00`00D_eBo@0:D_d40008D_d00`00EaeG7@0D
Ead00`00EaeG7@03000CEad00`00EaeG7@05Ead4000=Ead00`00EaeG7@08Ead4000:Ead00`00EceG
?@0:Ecd30009Ecd00`00EciG?P08Ech4000;Ecd00`00EeiGGP03Eeh3000AFeh3000>Eeh30006Egh0
0`00EgmGO`03Egl3000:Eil30007Dil00`00DimCW`030005Bil30005?ih300000b/j0000000:0003
9c`50005;eh70004>el00`00?eloG`0:?el70004?el00`00@em3G`0:@el70004@el00`00Aem7G`0:
Ael70004Ael00`00Aem7G`0AAel8000CAel00`00Oomoo`02Ool00`00Oomoo`13Ool000moo`8000Io
o`8000]oo`<000eoo`<001Moo`80019oo`03001oogoo07Eoo`03000g7cLO010g7`03000k7c/O010k
7`03000k7c/O014k7`03000nocko014no`03000nocko018no`030012od;o0152o`030012od;o0152
o`030016oTKn0196oP030016oTKn0156oP030016oTKn01=6oP03001:oT[n00U:oQD000Y:oP03001:
oT[n01=:oP03001:oT[n01A:oP03001>oDkm01=>o@03001>oDkm00=>o@/000E>o@03001>oDkm01A>
o@03001>oDkm01A>o@03001>oDkm009>o@L000aBo@03001BoE;m01ABo@03001BoE;m00IBo@H000UB
o@03001BoE;m01EBo@03001BoE;m00EBo@@000aBo@03001G7ELM01=G7@@001IG7@03001G7ELM00D0
019G7@03001G7ELM00=G7@@000mG7@03001G?ELm00IG?@<000eG?@03001G?ULn00=G?P@000mG?@03
001GGUMN00<0015KGP<00003Feh005MN00]GGP<000YGOP03001GO`00008000YGW`<000UCW`@000E;
W`<000@oWQL000<_GPL000`kG`03000oGcmO008oG`L000HoG`03000oGcmO00<oG`030013Gd=O0093
G`L000a3G`030017GdMO0097G`L000a7G`030017GdMO00U7G`L000A7G`030017GdMO0117G`H000=o
o`03001oogoo04=oo`003Woo0P0027oo0P006goo0`005Woo0P004Woo00<007ooOol0MWoo7P0023/O
00<003/O>al04C/O00<003ko?_l04Cko00<003ko?_l04Sko00<004;o@_l04D;o00<004;o@_l04D;o
00<004KnA_h04TKn00<004KnA_h04DKn00<004KnA_h02DKn5@002T[n00<004[nB_h04d[n00<004[n
B_h04T[n00<004[nB_h054[n00<004kmC_d03dkm2P004Dkm00<004kmC_d054km00<004kmC_d04Dkm
1`004e;m00<005;mD_d055;m00@005;mD_eBo@D000mBo@03001BoE;m01EBo@03001BoE;m00D0011B
o@03001G7ELM00iG7@D0009Fo@03001G7ELM01AG7@@001MG7@03001G7ELM00<001=G7@03001G?ELm
00=G?@<0011G?@03001G?ULn00<0019G?@@0015KGP<000EKGP03001GGUMN00IGGP<000eGOP8000YG
W`<000UCW`<000=?_`03001;Wd^O00<000<oWQ<0008S70T000lkG`T000doG`03000oG`0000P00153
G`L001=7G`030017GdMO0097G`L000a7G`030017GdMO00A7G`/000E7G`03001oogoo009oo`03001o
ogoo049oo`003Woo0P0027oo0P0077oo0`005Goo0P004Woo00<007ooOol0N7oo0P004CKo00<003[o
>_l01S[oXP002TKn00<004[nB_h04d[n00<004[nB_h04T[n00<004[nB_h04d[n00<004[nB_h054[n
00<004kmC_d00dkm2`001Dkm00<004kmC_d04dkm00<004kmC_d05Dkm00<004kmC_d02Dkm1`000dkm
00<005;mD_d05E;m00<005;mD_d04E;m1P005E;m00<005;mD_d04U;m1@005U;m00<005LMEad02ELM
100025Km00<005LMEad03eLM10000ULM00<005LMEad05ELM10005ULM00<005LmEcd00`004ULm1000
4ULm0`000U/m00<005]NFeh03E]N0`0025]N00<005MNEeh00eMN0`003EMn0`000U]o00<005NOEil0
15NO0`002E>O0`001Tno10000SnN2`000R<L2`001cMO00<003]O>el00c]O2`001cmO00<003mO?el0
0cmO2`001T=O00<004=O@el02T=O1`000dMO00<004MOAel044MO2@0044MO2P004DMO00D007ooOomo
o`0004Aoo`003Woo0P0027oo0P007Goo0`0057oo0P004Woo00<007ooOol0NWoo00<003Ko=_l03cKo
00<003[o>_l043[o00<003[o>_l043[o00<003ko?_l04Cko00<003ko?_l04Cko00<004;o@_l04D;o
00<004;o@_l04D;o00<004KnA_h04TKn00<004KnA_h04DKn00<004KnA_h04dKn00<004[nB_h04T[n
00<004[nB_h04d[n00<004[nB_h04d[n00<004[nB_h03d[n2P004Dkm00<004kmC_d04dkm00<004km
C_d054km00<004kmC_d00Tkm1`002dkm00<005;mD_d055;m00<005;mD_d035;m1@000e;m00<005;m
D_d05E;m00<005;mD_d03E;m1@000e;m00<005;mD_d05E;m00<005LMEad01ELM100035Km00<005LM
Ead035LM0`001eLM00<005LMEad045LM10000ULM00<005LMEad055LM10004ULm0`000U/m00<005Lm
Ecd03ULm0`001U/m00<005]NFeh02E]N0`002e]N00<005MNEeh00`003EMn0`001U]o00<005NOEil0
0`002E>O0`001Tno0`000SnM4@003SMO2P003cmO2@002D=O00<004=O@el01T=O00<004=O@el00T=O
1`002dMO00<004MOAel014MO2`001DMO00<004MOAel02TMO1`0014MO00<004MOAel04DMO1@000goo
00<007ooOol0@Goo000>Ool20008Ool2000NOol3000COol2000BOol00`00Oomoo`1kOol;0007=_l0
0`00>_ljo`0@>_l00`00>_ljo`0@>_l00`00?_lno`0A?_l00`00?_lno`0A?_l00`00@_m2o`0A@_l0
0`00@_m2o`0A@_l00`00A_i6oP0BA_h00`00A_i6oP0AA_h00`00A_i6oP0CA_h00`00B_i:oP0BB_h0
0`00B_i:oP0CB_h00`00B_i:oP0BB_h00`00B_i:oP04B_h;0005C_d00`00C_e>o@0CC_d00`00C_e>
o@0DC_d00`00C_e>o@0?C_d9000BC_d00`00D_eBo@0ED_d00`00D_eBo@06D_d50009D_d00`00D_eB
o@0ED_d00`00D_eBo@06D_d60009D_d00`00D_eBo@0DD_d00`00EaeG7@05000AE_d00`00EaeG7@07
Ead4000:Ead00`00EaeG7@0=Ead30007Ead00`00EaeG7@0?Ead40002Ead00`00EceG?@0>Ecd30006
Fcd00`00EceG?@0:Ecd30009Fcd00`00FeiKGP06Feh3000>Feh3000=Egh30009Fgl30009Dil30006
Ckl30002?id70009=cl00`00=elgG`04=el;0005?el00`00?eloG`0:?el70004@el00`00@em3G`0;
@el00`00@em3G`02@el9000@Ael9000AAel00`00Aem7G`02Ael7000<Ael00`00Aem7G`09Ael70004
Ael01@00Oomoogoo0000@goo000>Ool20008Ool2000OOol3000AOol2000COol00`00Oomoo`1mOol0
0`00<_lbo`06<_lC0008>_l00`00>_ljo`0@>_l00`00?_lno`0A?_l00`00?_lno`0A?_l00`00@_m2
o`0A@_l00`00@_m2o`0A@_l00`00A_i6oP0BA_h00`00A_i6oP0AA_h00`00A_i6oP0CA_h00`00B_i:
oP0BB_h00`00B_i:oP0BB_h00`00B_i:oP09B_h@000AC_d00`00C_e>o@0CC_d00`00C_e>o@0CC_d0
0`00C_e>o@04C_d;0005C_d00`00C_e>o@0DC_d00`00D_eBo@0DD_d01000D_eBoE;m1@003U;m00<0
05;mD_d05E;m00@005;mD_eBo@D000mBo@03001BoE;m019Bo@D001IFo@03001G7ELM00=G7@@000mG
7@03001G7ELM00QG7@@000YG7@03001G7ELM00aG7@<000MG7@03001G?ELm00YG?@<000UK?@03001G
?ELm00MG?@<000eK?@03001KGU]N009KGP<000iKGP<00003Feh005Mn00]GOP8000UKO`<0009GW`03
001CWe>O00ACW`<000I?_`<0008oW@D000@g?a40014oG`03000oGcmO008oG`L000a3G`030013Gd=O
00A3G`/000E3G`030017GdMO00Y7G`L000=7G`030017GdMO0197G`L001=7G`030017GdMO0097G`L0
00a7G`05001oogooOol00012Ool000ioo`8000Qoo`80021oo`8000Uoo`8000Eoo`<0019oo`03001o
ogoo07moo`03000boc;o00lbo`03000focKo00Hfoa@000Pjo`03000nocko014no`03000nocko010n
o`030012od;o0152o`030012od;o0192o`030016oTKn0156oP030016oTKn0196oP030016oTKn01=6
oP03001:oT[n015:oP03001:oT[n00U:oQD000Y:o@03001>oDkm01A>o@03001>oDkm01A>o@03001>
oDkm00i>o@/0015>o@03001>oDkm01=>o@03001BoE;m015Bo@L001ABo@03001BoE;m019Bo@H001EB
o@03001BoE;m00aBo@D000=Fo@03001FoEKm01EFo@03001G7ELM00<001AG7@03001G7ELM00=G7@@0
00mG7@03001G7ELM00MG7@@000YG7@03001G?ELm00MG?@<000eK?@03001G?ELm00=G?@<0011K?@03
001KGP00008000iKGP<000EKGP03001GOUMn00IGOP<000UKO`8000IGW`03001CWe>O00<000M?_`80
008oW@`000/o?`03000oGcmO010oG`T00113G`X000I3G`030013Gd=O00Q3G`030017GdMO0097G`L0
00]7G`030017GdMO00Y7G`L000=7G`030017GdMO0157G`P001=7G`05001oogooOol00012Ool000io
o`8000Qoo`80025oo`8000Qoo`T001=oo`03001oogoo081oo`03000boc;o00lbo`03000focKo010f
o`03000joc[o00HjobP000Pno`030012od;o0152o`030012od;o0192o`030016oTKn0156oP030016
oTKn0196oP030016oTKn00U6oRT000Y:oP03001:oD[m01=:o@03001>oDkm01A>o@03001>oDkm01=>
o@03001>oDkm00=>o@/000E>g@03001>oDkm01A>o@03001>oDkm01A>o@03001BoE;m00UBo@L000AB
o@03001BoE;m01ABo@03001BoE;m00eBo@D000=Bo@03001BoE;m01EBo@03001BoE;m00IBo@H000UF
o@03001FoEKm01=Fo@@001MG7@03001G7ELM00<001=G7@03001G7ELM00=G7@@000mG7@03001G?ELm
00=G?@<0011K?@03001G?ELm00<0019K?@<000iKGP<000UKGP03001GOUMn009GOP<000UKO`<000QG
W`<000M?_`<00003?id0000000@001Do?`03000oGcmO00@oG`/000E3G`030013Gd=O00Y3G`L000A3
G`030013Gd=O00U3G`030013Gd=O00E3G`P001=7G`030017GdMO0097G`L000]7G`030017GdMO00U7
G`L000A7G`030017GdMO0157G`D000=oo`03001oogoo03moo`003Woo0P0027oo0P008Goo0P0027oo
0P0000=oo`0000000`0057oo00<007ooOol0PGoo2`001c;o00<003Ko=_l043Ko00<003[o>_l043[o
00<003[o>_l043[o00<003ko?_l01ckoIP002TKn00<004[nB_h04D[n00<004[nB_h04d[n00<004[m
B_d04d[m00<004kmC_d054km00<004kmC_d03Tkm2P004DkM00<004kmC_d054km00<004kmC_d04dkm
00<005;mD_d00U;m1`0035;m00<005;mD_d055;m00<005;mD_d01U;m1P002E;m00<005;mD_d055;m
00@005;mD_eBo@D000mFo@03001FoEKm00mFo@@0009Fo@03001G7ELM01EG7@@001IG7@03001G7ELM
00<001=G7@03001G?ELm00<001=K?@<0019K?@<0009KG@03001KGU]N00YKGP8000aKGP03001GOP00
008000YKO`8000QGW`<00003Ekl004no00A?_`<00003?id0000000<000A3?`03000o?clo00To?a00
0153G`030013Gd=O0093G`L000a3G`030013Gd=O00Q3G`P000A7G`030017GdMO0117G`T00197G`03
0017GdMO0097G`L000a7G`030017GdMO00U7G`L000A7G`05001oogooOol00011Ool000moo`8000Io
o`8001Uoo`8000Moo`8000Qoo`8001Yoo`03001oogoo08=oo`03000boc;o00Hboa<000Pfo`03000j
oc[o010jo`03000joc[o010jo`03000nocko010no`030012od;o0152o`030012oT;n0152oP030016
oTKn0156oP030016oTKn0196oP030016oTKn01=6oP03001:oT[n015:oP03001:oT[n01=:oP03001:
oD[m01=:o@03001>oDkm01=>o@03001>oDkm00=>o@/000E>g@03001>gDkM01=>g@03001>oDkm01A>
o@03001>oDkm015>o@L001=Bo@03001BoE;m01ABo@04001BoE;mD_d5000?D_d00`00D_eBo@0CD_d5
000EE_d00`00E_eFo@09E_d50007E_d00`00EaeG7@0@Ead40002Ead00`00EaeG7@0DEad4000EEad4
000CFcd300000e/m001K?@0?Fcd30006Fed00`00FeiKGP06Feh3000>Feh2000;Fgl20008Eil20005
Ekl00`00Ckl0000200000cnM000000030003@cl@000;@cl00`00@em3G`0?@el9000C@el00`00@em3
G`02@el7000<Ael00`00Aem7G`04Ael;0005Ael00`00Aem7G`0?Ael9000CAel00`00Aem7G`02Ael7
000<Ael01@00Oomoogoo0000@7oo000?Ool20006Ool2000IOol30006Ool20008Ool2000JOol00`00
Oomoo`24Ool00`00<_lbo`0?<_l00`00=_lfo`06=_lD0008>_l00`00>_ljo`0@>_l00`00?_lno`0@
?_l00`00@_m2o`0A@_l00`00@_i2oP0A@_h00`00A_i6oP0AA_h00`00A_i6oP0BA_h00`00A_i6oP0B
A_h00`00B_i:oP0BB_h00`00B_i:oP0CB_h00`00B_e:o@0BB_d00`00C_e>o@0?C_d:000AC]d00`00
C]e>g@0CC]d00`00C_e>o@0DC_d00`00C_e>o@09C_d70003D]d00`00D_eBo@0ED_d00`00D_eBo@0@
D_d7000DD_d00`00D_eBo@0>D_d50002E_`00`00E_eFo@0FE_d00`00E_eFo@04E_d4000<E_d00`00
EaeG7@0=Ead30007Ead00`00EaeG7@0?Ead40002Ead00`00EaeG7@0AEad30002Fad00`00FceK?@0?
Fcd30005Fcd00`00FceK?@0:Fcd3000:Fed00`00FeiKGP02Feh3000>Feh300000e]n001KO`07Fgl3
0007Eil30007Ekl>0005@cl00`00@cm3?`0D@cl00`00@em3G`03@el;0006@el00`00@em3G`0?@el9
0006Ael00`00Aem7G`07Ael:000AAel00`00Aem7G`03Ael;0006Ael00`00Aem7G`0?Ael9000CAel0
1@00Oomoogoo0000@7oo000@Ool20004Ool2000JOol40004Ool20009Ool2000JOol00`00Oomoo`25
Ool00`00<_lbo`0?<_l00`00=_lfo`0?=_l00`00=_lfo`07=_lD0008>_l00`00?_lno`0@?_l00`00
@_m2o`0A@_l00`00@_i2oP0A@_h00`00A_i6oP0AA_h00`00A_i6oP0BA_h00`00A_i6oP0BA_h00`00
B_i:oP0BB_h00`00B_i:oP0BB_h00`00B_e:o@0CB_d00`00C_e>o@03C_d;0005C]d00`00C]e>g@0C
C]d00`00C]e>g@0CC]d00`00C_e>o@0DC_d00`00C_e>o@02C_d7000;D]d00`00D_eBo@0DD_d00`00
D_eBo@09D_d70004D_`00`00D_eBo@0ED_d00`00D_eBo@09D_d40008E_`00`00E_eFo@0EE_d00`00
E_eFo@04000AE_d00`00EaeG7@08Ead4000:Ead00`00EaeG7@0<Ead30007Ead00`00EaeG7@0=Ead3
0006Fad00`00FceK?@0;Fcd30008Fcd00`00FceK?@07Fcd3000=Fed00`00Feh00002000>Feh30005
Fgh00`00FgmKO`03Fgl20008Eil20007Ekl8000?@cl00`00@cm3?`0?@cl:000B@el00`00@em3G`03
@el;0005Ael00`00Aem7G`07Ael00`00Aem7G`070004Ael00`00Aem7G`0AAel9000BAel00`00Aem7
G`03Ael;0005Ael00`00Aem7G`0@Ael60003Ool00`00Oomoo`0mOol0011oo`P001]oo`P000Yoo`X0
019oo`03001oogoo08Ioo`/000Lbo`03000focKo00lfo`03000focKo010fo`03000joc[o00Ljoa@0
00Pno`030012od;o0152o`030012oT;n0112oP030016oTKn0196oP030016oTKn0156oP030016oTKn
01=6oP03001:oT[n019:oP03001:oT[n019:oP03001:oD[m00U:o@l0015>g@03001>gDkM01=>g@03
001>gDkM01=>g@03001>oDkm00m>o@T0019Bg@03001BoE;m01ABo@03001BoE;m009Bo@L000aBo003
001BoE;m01ABo@03001BoE;m00EBo@@000aFo003001FoEKm01AFo@@001IFo@03001G7ELM00=G7@@0
00mG7@03001G7ELM00MG7@@000YG7@03001G7ELM00YG7@<000UK7@03001K?E/m00UK?@8000aK?@03
001K?E/m00=K?@<0011KG@8000iKGP<000UKOP03001KO`00008000QGW`8000IG_`<00003Akd00000
00800193?`030013?d<o00A3?`/000E3?`030013Gd=O0113G`X00157G`030017GdMO0097G`L000a7
G`030017GdMO00U7G`L000A7G`030017GdMO0157G`T00157G`030017GdMO00A7G`/000E7G`05001o
ogooOol0000oOol0019oo`@001moo`D000]oo`X0019oo`03001oogoo08Qoo`8000L^o`h000`fo`03
000focKo010fo`03000joc[o010jo`03000nocko00LnobP000Q2oP030016oTKn0196oP030016oTKn
0156oP030016oTKn0196oP03001:oT[n00U:oRX000Y:g@03001>gDkM01=>g@03001>gDkM01=>g@03
001>gDkM01=>g@03001>oDkm00A>o@/000E>g@03001BgE;M01ABg@03001BoE;m015Bo@L001=Bo003
001BoE;m01ABo@03001BoE;m00D0015Fo003001FoEKm00iFo@D0009Fo003001FoEKm01EFo@03001G
7ELM00<001=G7@03001G7ELM00=G7@@000mG7@03001G7ELM00IG7@<000eK7@03001K?E/m00EK?@<0
00iK?@03001K?E/m00<0011KG@<00003Fed005]N00]KGP8000aKOP8000QGW`<000IG_`800003Akd0
000000<000]3?a000153?`030013Gd=O00A3G`/000E7G`030017GdMO00m7G`T000A7G`030017GdMO
00a7G`030017GdMO0097G`L000a7G`030017GdMO00U7G`L000A7G`030017GdMO0157G`T00157G`05
001oogooOol0000nOol0065oo`03001oogoo08Yoo`03000^obko00h^o`04000boc;o<_l:0003=_l0
0`00=_lfo`0@=_l00`00>_ljo`0@>_l00`00?_lno`0@?_l00`00?_lno`0@?_l00`00@_i2oP08@_iB
000:B]h00`00B]e:g@0BB]d00`00B]e:g@0CB]d00`00C]e>g@0CC]d00`00C]e>g@0CC]d00`00C]e>
g@0>C]d;000AC]d00`00D]eBg@0CD]d00`00D_eBo@0<D_d50003D]`00`00D_aBo00ED_`00`00D_eB
o@0AD_d5000FE_`00`00E_eFo@0:E_d40008E_`00`00E_eFo@0CE_d4000FEad00`00EaeG7@03000C
Ead00`00EaeG7@03Ead3000@Fad00`00FceK?@02Fcd3000AFcd3000@Fed30005Fed00`00FeiKGP06
Feh3000;Fgh30002Fih00`00EimGW`03Eil20006Ekl300000dNm0000000@000;Acl00`00@cm3?`0?
@cl;000AAel00`00Aem7G`03Ael;0006Ael00`00Aem7G`04Ael00`00Aem7G`08Ael9000CAel00`00
Aem7G`02Ael7000<Ael00`00Aem7G`09Ael70003Ael00`00Aem7G`0AAel50002Ool00`00Oomoo`0l
Ool0065oo`03001oogoo00<008Qoo`H000/^o`03000boc;o00Xbo`l000Pfo`03000joc[o010jo`03
000nocko010no`03000nocko010no`030012oT;n0112oP030012gT;N0192gP030016gTKN0156gP03
0016gTKN0196gP03001:gT[N01=:gP03001:gD[M019:g@03001:gD[M019:g@03001>gDkM01=>g@03
001>gDkM01=>g@03001>gDkM00=>g@/000E>g@03001>gDkM01A>g@03001BgE;M01ABg@03001BoE;m
00IBo@D000UBg003001Bo5;l01ABo003001BoE;m00aBo@D000=Bo003001Fo5Kl01IFo003001FoEKm
00EFo@@000aFo003001FoEKm00mFo@@0009Fo003001G7ELM01AG7@@001IG7@03001G7ELM00<001=K
7@03001K?@000080015K?@<00003Fcd005]M00eKG@<000UKG@03001KGU]N009KGP<000]KOP<000IK
WP03001GW`00008000IG_`800097_@H000=7?`030017?dLo01A7?`030013?d<o00=3?`/000I7?`03
0017GdMO00m7G`X00197G`030017GdMO00=7G`/000E7G`030017GdMO0117G`T001=7G`030017GdMO
0097G`L000]7G`030017GdMO00U7G`L000A7G`05001oogooOol0000mOol0065oo`<008eoo`04000Z
gb[O:]l90003;_l00`00<_lbo`0?<_l00`00=_lfo`06=_lD0008>_l00`00?_lno`0@?_l00`00?_ln
o`0@?_l00`00@_i2oP0@@_h00`00@]i2gP0B@]h00`00A]i6gP0AA]h00`00A]i6gP0BA]h00`00B]i:
gP0BB]h00`00B]e:g@0BB]d00`00B]e:g@0CB]d00`00C]e>g@0CC]d00`00C]e>g@0>C]d:000AC]d0
0`00C]e>g@0DC]d00`00D]eBg@0CD]d01000D_eBoE;m1@003U;L00<005;lD_`05E;l00<005;mD_d0
1U;m1@002E;l00<005KlE_`05EKl00<005KmE_d01@0045Kl00<005KmE_d035Km0`001eKl00<005LM
Ead03eLM10000ULL00<005LMEad055LM10005U/M0P004E/m0`001E/m00<005]MFed02E]M0P0035]M
00<005]N00000P002e]n0`002E^N0`001ENo0`0000=7_@0000000P002DLo00<004LoAcl03dLo2P00
4TLo00<004MOAel00dMO2`001DMO00<004MOAel04DMO2P0044MO00<004MOAel014MO2`001DMO00<0
04MOAel044MO2@004TMO00<004MOAel00TMO1`0034MO00@007ooOol003eoo`00HGoo00<007ooOol0
SWoo00<002[O:]l02B[O2P0033;o00<003Ko=_l03SKo00<003[o>_l023[o500023ko00<003ko?_l0
43ko00<004;n@_h044;n00<004;N@]h04T;N00<004KNA]h04DKN00<004KNA]h04DKN00<004[NB]h0
4d[N00<004[MB]d04T[M00<004[MB]d04d[M00<004kMC]d04TkM00<004kMC]d00dkM2`001DkM00<0
04kMC]d04dkM00<004kMC]d054kM00<005;MD]d03e;M200055;L00<005;lD_`055;l00@005;mD_eB
o@D000iBo003001Fo5Kl01=Fo0D001IFo003001FoEKm00MFo@@000YFo003001G7ELM00aG7@<000MG
7003001G7ELM011G7@<0009K7@03001K7E/M019K7@<00003Fad005/m00iK?@8000QK?@03001KGE]M
00IKG@<000iKG@8000aKOP8000YKWP8000=K_P03001G_`0000800097_@<000e7?`030017?dLo00=7
?`/000E7?`030017?dLo0157?`T00157G`030017GdMO00U7G`L000A7G`030017GdMO0097G`030017
GdMO00a7G`T00157G`030017GdMO00A7G`/000E7G`030017GdMO00m7G`T001=7G`05001oogooOol0
000lOol0065oo`03001oogoo08moo`03000Zgb[O00hZg`04000bgc;O<]l:0003<_l00`00=_lfo`0>
=_l00`00>_ljo`0@>_l00`00?]lng`08?]lD0008?_l00`00@_i2oP0@@_h00`00@]i2gP0A@]h00`00
A]i6gP0BA]h00`00A]i6gP0AA]h00`00B]i:gP0BB]h00`00B]e:g@0CB]d00`00B]e:g@0BB]d00`00
C]e>g@09C]d?000AC]d00`00C]e>g@0CC]d00`00C]e>g@0CC]d00`00D]eBg@04D]d;0005D]`00`00
D]aBg00DD]`00`00D_aBo00AD_`7000DD_`00`00E_aFo00=E_`50003E_`00`00E_aFo00EE_`00`00
E_eFo@03E_d4000?E_`00`00EaeG7@07Ead4000:Ea`00`00EaeG7@0=Ead30006Fad00`00FaeK7@0>
Fad30005Fad00`00FceK?@09Fcd3000;Fcd00`00FeeKG@02Fed3000>Fed300000emM001KOP08Fgh3
0009Fih30005Fkh3000014Nm000000003TLo20004DLo00<004LoAcl02DLo1`0014Lo00<004MOAel0
4dMO00<004MOAel00TMO1`0034MO00D004MOAem7G`0000M7G`L000=7G`030017GdMO0197G`T00157
G`030017GdMO00=7G`/000E7G`030017GdMO0117G`H0009oo`03001oogoo03Yoo`00HGoo00<007oo
Ool0T7oo1P002b[O00<003;O<]l02S;O2P002cKo00<003[o>_l043[o00<003kO?]l043kO00<003kO
?]l023kO500024;n00<004;N@]h04D;N00<004KNA]h04DKN00<004KNA]h04TKN00<004[NB]h04T[N
00<004[MB]d04T[M00<004[MB]d02D[M5@002TkM00<004kMC]d04dkM00<004kMC]d04dkM00<004kM
C]d04DkM2@004E;L00<005;LD]`055;L00<005;lD_`02E;l1`0015;L00<005;lD_`05E;l00<005Kl
E_`01UKl1P002EKl00<005KlE_`055Kl00<005KmE_d00`004eKl00<005LMEad00eLM10003ULL00<0
05LMEad02ULM0`002E/M00<005/MFad02e/M0`002E/M00<005/mFcd01U/m0P003U/m00<005]M0000
0P003e]M0P001EmM00<005]nFgh00e]n0`002U^N0P001U^n0P000U_N0`002DLo1`000dLo00<004Lo
Acl04dLo00<004LoAcl00TLo1`0034Lo00<004MOAel03TMO2@004dMO00@004MOAem7G`P000]7G`03
0017GdMO00Y7G`L000=7G`030017GdMO0157G`T00157G`030017GdMO00A7G`/000E7G`05001oogoo
Ool0000kOol0065oo`03001oogoo099oo`04000Zgb[O:]l90003:]l00`00<]lbg`0?<]l01000=]lf
gcKO2@000cKo00<003[o>_l043[o00<003kO?]l043kO00<003kO?]l043kO00<004;N@]h024;N:@00
24KN00<004KNA]h04DKN00<004[NB]h04T[N00<004[MB]d02D[M5@002T[M00<004kMC]d04dkM00<0
04kMC]d04dkM00<004kMC]d04dkM00<004kMC]d02DkM1`000e;L00<005;LD]`055;L00<005;LD]`0
55;L00<005;lD_`00U;l1`0035;L00<005;lD_`055;l00@005KlE_aFo0D000mFo003001Fo5Kl01=F
o0@001IFo003001G7ELM00<001=G7003001G7ELM00IG7@<000eK7@03001K7E/M00MK7@<000aK7@03
001K?E/m00=K?@<0011K?@8000mKG@<000QOG@03001KOP00008000]KWP8000IK_P80009KgP<000A7
?`L000]7?`030017?dLo00i7?`T001=7?`030017GdMO00=7G`/000I7?`030017GdMO00m7G`T001=7
G`030017GdMO0097G`L000]7G`030017GdMO00U7G`L000A7G`030017GdMO0157G`T00157G`04001o
ogoo000kOol0061oo`03001oogoo09Aoo`03000Zgb[O00TZg`X000`bg`03000fgcKO00Tfg`l000Pj
o`03000ngckO010ng`03000ngckO010ng`030012gT;N0112gP030012gT;N0152gP030016gTKN00U6
gSd000Y:g@03001:gD[M01=:g@03001>gDkM019>g@03001>gDkM01=>g@03001>gDkM01=>g@03001>
gDkM009>g@L000]Bg003001Bg5;L01ABg003001Bg5;L015Bg0L001=Bg003001Bo5;l01=Bo0D001AF
o003001Fo5Kl00iFo0D0009Fo003001Fo5Kl01AFo0@001IG7003001G7ELM00=G7@<0015K7@03001K
7E/M00=K7@<0011K7@03001K?@000080011K?@<00003Fcd005]M00aKG@8000]OG@8000aKWP8000IK
_P8000=KgP80009oM0@00197?`030017?dLo00=7?`/000I7?`030017?dLo00m7?`X00197?`030017
GdMO00=7G`/000E7?`050017GdMOAel0000>Ael9000BAel00`00Aem7G`02Ael7000<Ael00`00Aem7
G`09Ael70003Ael00`00Aem7G`0AAel50002Ool00`00Oomoo`0hOol0061oo`03001oogoo09Eoo`03
000Zgb[O00hZg`04000^gbkO;]l:0003<]l00`00=]lfg`0>=]l00`00>]ljg`06>]l?000<?]l00`00
?]lng`0A?]l00`00@]i2gP0@@]h00`00@]i2gP0A@]h00`00A]i6gP0AA]h00`00A]i6gP0AA]h00`00
B]e:g@0BB]d00`00B]e:g@0CB]d00`00B]e:g@0BB]d00`00C]e>g@0CC]d00`00C]e>g@0CC]d00`00
C]e>g@0>C]d9000BD]`00`00D]aBg00DD]`00`00D]aBg00<D]`50003D]`00`00D]aBg00DD]`00`00
D_aBo00>D_`50002E]`00`00E_aFo00EE_`00`00E_aFo009E_`40008E_`00`00E_aFo00@E_`30002
E_`00`00EaaG700EEa`00`00EaeG7@03000DFad00`00FaeK7@03000CFad2000@Fcd30005Fcd00`00
FeeKG@08Fed2000;Ged200000emn001KWP09Fih20006Fkh20003Fmh30003Og@00`00Acm7?`0?Acl:
000BAcl00`00Acm7?`03Acl;0005Acl00`00Acm7?`0@Acl:000AAcl01000Aem7G`000dMO2`001DLo
00<004MOAel03dMO2@004dMO00<004MOAel00TMO1`002dMO00<004MOAel02DMO1`0014MO00@007oo
Ool003Yoo`00H7oo00<007ooOol0UWoo1P002b[O00<002kO;]l02RkO2P002cKO00<003[O>]l03c[O
00<003[O>]l00S[O2P000ckO00<003kO?]l043kO00<004;N@]h04D;N00<004;N@]h04D;N00<004KN
A]h04DKN00<004KNA]h04DKN00<004[MB]d04T[M00<004[MB]d04T[M00<004[MB]d04d[M00<004kM
C]d04dkM00<004kMC]d04TkM00<004kMC]d00dkM2`001DkL00<005;LD]`055;L00<005;LD]`055;L
00<005;LD]`01U;L1@002E;L00<005;LD]`055;L00<005;lD_`02E;l100025KL00<005KlE_`055Kl
00<005KlE_`01EKl100035Kl00<005KlE_`035Kl10001UKl00<005LLEa`04eLL10005U/M10004e/M
0`0000=K?@00Fcd03E/m0P0025/m00<005]MFed01E]M0`002UmM0`0015mn00<005^NFih015^N0`00
1U^n0P000e_N100017md0P001DLo2`001TLo00<004LoAcl03dLo2P004DLo00<004LoAcl014Lo2`00
1DLo00<004LoAcl04DLo2@004DLo00<004MOAel00dMO2`001DLo00<004MOAel04DMO20004TMO00<0
04MOAel00TMO1`002dMO00D007ooOomoo`0003Uoo`00H7oo00<007ooOol0V7oo00@002Jo9[lV_`T0
00<Zg`03000^gbkO00d^g`03000bgc;O00<bg`T000<fg`03000jgc[O00ljg`03000jgc[O00/jg`l0
00Png`030012gT;N0112gP030012gT;N0192gP030016gTKN0116gP030016gTKN0196gP03001:gD[M
015:g@03001:gD[M01=:g@03001:gD[M019:g@03001>gDkM01=>g@03001>gDkM00U>g@l0015>g003
001Bg5;L01=Bg003001Bg5;L01ABg004001Bg5;LD]`5000>D]`00`00D]aBg00DD]`00`00D_aBo005
D_`4000<E]`00`00E_aFo00DE_`00`00E_aFo005000AE_`00`00E_aFo008E_`3000:E_`00`00EaaG
700@Ea`30002Fa`00`00FaeK7@0BFad30002Fa`00`00FaeK7@0?Fad30005Fcd00`00FceK?@08Fcd3
000;Fcd00`00FeeKG@02Fed2000;Ged20008Ggh01000FiiKWU^N0P001e^n0P000e_N0`000Wmd00D0
07mdOgAoM000009oT`D00197?`030017?dLo00=7?`/000E7?`030017?dLo0157?`T00157?`030017
?dLo00U7?`L000=7?`030017?`000197?`P00157?`030017GdMO00U7G`L000A7?`030017GdMO0157
G`L001=7G`04001oogoo000iOol0061oo`03001oogoo09Uoo`03000V_bJo00TV_`P000`^g`03000b
gc;O00/bg`X000`jg`03000jgc[O00ljg`03000ngSkN00LngQ@000Q2gP030012gT;N0152gP030016
gTKN0156gP030016gTKN0196gP03001:gD[M015:g@03001:gD[M01=:g@03001:gD[M019:g@03001>
gDkM00i>gA0000Y>g003001>g4kL01=>g003001Bg5;L01=Bg003001Bg5;L015Bg0L001ABg003001B
g5;L01=Bg003001Bo5;l00D0015Fg003001Fo5Kl019Fo0@001MFo003001Fo5Kl00=Fo0@000iFo003
001G75LL00]G70@000IK7003001K7E/M00iK7@<000IK7003001K7E/M00]K7@<000QK?@03001K?E/m
00IK?@8000iK?@03001KG@00008000]OG@8000YOOP04001KWP000007Fkh20004Fmh30003Og@01@00
OgAoM7md00000WnC00<004LoAcl04TLo20004DLo00<004LoAcl02DLo1`000dLo00<004LoAcl054Lo
00<004LoAcl00TLo1`002dLo0P002dLo1`000dLo00<004LoAcl04dLo00<004MOAel00TMO1`0034Lo
00<004MOAel02DMO1`000d]O00<004MOAel04DMO10000goo00<007ooOol0=Woo001POol00`00Oomo
o`2JOol4000=9[l00`00:[l000060006;]l00`00<]lbg`0?<]l00`00=]lfg`02=]l:0003>]l00`00
>]ljg`0?>]l00`00?]hngP0??]h00`00@]i2gP08@]hE0008@]h00`00A]i6gP0AA]h00`00A]i6gP0A
A]h00`00B]e:g@0BB]d00`00B]e:g@0BB]d00`00B]e:g@0BB]d00`00C]e>g@03C]d;0005C]d00`00
C]a>g00CC]`00`00C]a>g00CC]`00`00D]aBg00CD]`00`00D]aBg009D]`70004D]`00`00D]aBg00D
D]`00`00D]aBg00AD]`5000FE]`00`00E_aFo00>E_`40002E_`00`00E_aFo00FE_`00`00E_aFo003
000BE_`00`00EaaG7008Ea`3000:Fa`00`00FaeK7@0;Fad30009Fa`00`00FaeK7@09Fad2000<Fcd0
0`00FceK?@02Fcd3000@Fcd2000<Ged2000<Ggh20007Fkh20004Fmh20002Og@01@00OgAoM7md0000
0gmd00<007nCOi<00P0034Lo1`000dLo00<004LoAcl04dLo00<004LoAcl00TLo1`002dLo00<004Lo
Acl03dLo2@004dLo00<004LoAcl00TLo1`002dLo00<004LoAcl03TLo2@004dLo00<004MOAel00TMO
1`002d]O00<004MOAel02DMO1`000d]O00D007ooOomoo`0003Qoo`00H7oo00<007ooOol0W7oo00<0
02:n00001P001bJo00<002Zo:[l01BZo1P0000<^g`00<]l043;O00<003KO=]l02cKO2P0033[O00<0
03kN?]h03ckN00<004;N@]h044;N00<004;N@]h02D;N500024KN00<004KNA]h04TKN00<004[MB]d0
4D[M00<004[MB]d02D[M90004DkM00<004kLC]`04TkL00<004kLC]`04dkL00<005;LD]`04e;L00<0
05;LD]`00U;L1`0035;L00<005;LD]`04e;L00<005;LD]`035;L1@000e;L00<005KLE]`05EKL00<0
05KlE_`02EKl1@001eKl00<005KlE_`055Kl10005UKl00<005LLEa`00eLL10003U/L00<005/MFad0
1e/M0`003E/L00<005/MFad01E/M0`003U/m00<005/m00000P0045/m0`0000=OG@00Ged02EmM0P00
35mn0P000V=m00<005^nFkh00U^n0P0015_N0`000Wmd00D007mdOgAoM00000=oM004001oTgnC0002
Oi<00`00Acm7?`02Acl7000;Acl00`00Acm7?`0>Acl9000CAcl00`00Acm7?`03Acl;0005Acl00`00
Acm7?`0@Acl9000BAcl00`00Acm7?`03Acl;0005Acl00`00Acm7?`0@Acl9000BBel00`00Aem7G`02
Ael7000;Bel01@00Oomoogoo0000=goo001POol00`00Oomoo`2MOol00`008[hR_P058[h700000bJo
000Z_`0;:[l8000<<]l00`00=]lfg`0>=]l00`00>]ljg`03>]l:0003>]l00`00?]hngP0??]h00`00
@]i2gP0@@]h00`00@]i2gP0A@]h00`00A]i6gP08A]hm000:B]d00`00B]e:g@0BB]d00`00C]e>g@0C
C]d00`00C]a>g00CC]`00`00C]a>g00CC]`00`00D]aBg00>D]`9000CD]`00`00D]aBg00DD]`00`00
D]aBg006D]`50009D]`00`00E]aFg00EE]`00`00E_aFo004E_`4000<E_`00`00E_aFo00@E_`40002
E_`00`00E_aFo00EE_`00`00EaaG7003000CFa`00`00FaeK7@03Fad3000@Fa`00`00FaeK7@02Fad3
000AFcd2000@Fcd30005Ged00`00GeeOG@04Ged3000;Ggh30005Hgd01000Fkh0000015_N0`0000Eo
M000OgAoM00000=oM005001oM7mdOg@00002Oi<01000Oi=oTgnC10004TLo00<004LoAcl00dLo2`00
1TLo00<004LoAcl03dLo2P004DLo00<004LoAcl014Lo2`0014Lo0P004DLo2P004DLo00<004LoAcl0
14Lo2`001D/o00<004]OBel03d]O2@004T]O00<007ooOol00Woo00<007ooOol0=7oo001POol00`00
Oomoo`2NOol00`008[hR_P0;8[h6000<:[l01000<]lbgc;O2P000c;O00<003KO=]l03SKO00<003[O
>]l033[O2P0033kN00<004;N@]h044;N00<004;N@]h04D;N00<004KNA]h044KN00<004KMA]d04TKM
00<004[MB]d04D[M00<004[MB]d04d[M00<004[MB]d04T[M00<004kMC]d04dkM00<004kLC]`04TkL
00<004kLC]`04dkL00<005;LD]`00e;L2`001E;L00<005;LD]`055;L00<005;LD]`055;L00@005;L
D]aBg0D000iBg003001Fg5KL01EFg003001Fo5Kl00@0015Fo003001Fo5Kl00aFo0<000MFo003001F
o5Kl01=Fo0@001IK7003001K7E/M00<001=K7003001K7@000080015K?@<00003Fcd005/m00eK?@80
00UOG@04001OGEmMGed2000<Ggh20008Hgd30004Fmh20003Og@01000OgAoM0000gmd00D007mdOgAo
M000009oT`05001oTgnCOi<0000AAcl:000BAcl00`00Acm7?`03Acl;0005Acl00`00Acm7?`0?Acl;
000?Acl00`00Acl00005Acl;0005Acl00`00Acm7?`0AAcl9000ABcl00`00Bem;G`03Bel;0005Bel0
0`00Bem;G`0?Bel60003Ool00`00Oomoo`0dOol0061oo`03001oogoo09moo`@000`R_P03000Z_bZo
00L000HZ_`03000bgc;O00Xbg`P000dfg`03000jgc[O00ljg`03000ngSkN00<ngPX000<ngP030012
gT;N0112gP030012gT;N0112gP030016gTKN0156gP030016gDKM0196g@03001:gD[M015:g@03001:
gD[M019:g@03001:gD[M019:g@03001>gDkM01=>g@03001>g4kL01=>g003001>g4kL00i>g0X0015B
g003001Bg5;L01ABg003001Bg5;L011Bg0L001ABg003001Fg5KL019Fg0D001EFo003001Fo5Kl00QF
o0@000YFo003001Fo5Kl00mFo0@0009Fo003001K75/L01AK70@001EK70<0015K?@<000EK?@03001K
?E/m00QK?@<000]OG@04001OG@00000<Ggh20008Hgd20003Hid00`00Fmh000020004Og@01000OgAo
M0000gmd00D007mdOgAoM000009oT`04001oTgnCOi<20005Acl;0006Acl00`00Acm7?`0?Acl:000A
Acl00`00Acm7?`03Acl;0005Acl00`00Acm7?`0BAcl8000AAcl00`00Acm7?`09Acl70003Bcl00`00
Bcm;?`0ABcl9000ABel00`00Bem;G`03Bel;0005Bel00`00Oomoo`02Ool00`00Oomoo`0cOol0061o
o`03001oogoo0:5oo`T000HR_P03000Z_bZo00HZ_`H00003:[l003;O00lbg`03000fgcKO00L000Lf
g`03000jgc[O00ljg`03000ngSkN00`ngPl000Q2gP030012gT;N0112gP030016gTKN0116gP030016
gDKM0196g@03001:gD[M015:g@03001:gD[M01=:g@03001:gD[M019:g@03001>gDkM019>g@03001>
g4kL01=>g003001>g4kL00=>g0/000E>g003001Bg5;L01=Bg003001Bg5;L01ABg003001Bg5;L00UB
g0L000ABg003001Bg5;L01ABg003001Fg5KL00eFg0D000=Fg003001Fo5Kl01EFo003001Fo5Kl00=F
o0@000iFo003001Fo5Kl00aFo0<000MFo003001K75/L011K70<0009Jo003001K75/L015K70<0009K
7003001K?E/m00aK?@<000QK?@03001K?E/m00IK?@8000iOG@8000aOOP8000QSO@8000ESW@<00003
NeD007md009oM004001oM7md0003Og@01@00OgAoM7md00000WnC00D007nCOi=oT`00009oT`D00197
?`030017?dLo00=7?`/000E7?`030017?dLo0157?`P00157?`030017?dLo00Y7?`P00097?`030017
?dLo01=7?`030017?dLo0097?`L000];?`03001;?d/o00U;?`L000A;?`03001;Gd]O015;G`P0015;
G`05001oogooOol0000eOol0061oo`03001oo`0000800:5oo`03000NWQjN00@NWPH000038[h002Zo
00`Z_`H000dbg`03000fgcKO00Hfg`L00003=]l003[O010jg`03000ngSkN00lngP030012gT;N00Q2
gPl000e2gP030016gTKN0116gP030016gDKM0196g@03001:gD[M015:g@03001:gD[M019:g@03001:
gD[M019:g@03001>gDkM01=>g@03001>g4kL00i>g0X0015>g003001Bg5;L01=Bg003001Bg5;L01=B
g003001Bg5;L009Bg0L000aBg003001Bg5;L01ABg003001Fg5KL00IFg0H000UFg003001Fo5Kl01AF
o003001Fo5Kl00<001=Fo003001Fo5Kl00MFo0@000YFo003001K75/L00eK70<000IJo003001K75/L
00eK70<000IK7003001K?E/m00UK?@8000aK?@03001K?E/m009K?@<000eOG@<00003Ged005mn00UO
OP8000QSO@8000ESW@@0009kE@05001oM7mdOg@00002Og@01@00OgAoM7md00000gmd00@007nCOi<0
00=oT`04001oTgnC000DAcl8000AAcl00`00Acm7?`09Acl70003Acl00`00Acm7?`0DAcl00`00Acm7
?`02Acl70007Acl01@00Acm7?dLo000044Lo2@004T/o00<004/oBcl00T/o1`0034/o00<004]OBel0
2D]O1`000d]O00<004]OBel04D]O10000goo00<007ooOol0<Woo001POol2002UOol300097Yh6000<
:[l00`00;[l^_`070007<]l00`00=]lfg`0<=]l8000;>]l00`00?]hngP0@?]h00`00@]i2gP0@@]h0
0`00@]i2gP03@]h:0003@]h00`00A]i6gP0AA]h00`00A]e6g@0BA]d00`00B]e:g@0AB]d00`00B]e:
g@0BB]d00`00B]e:g@0BB]d00`00C]e>g@0BC]d00`00C]a>g003C]`;0005C]`00`00C]a>g00CC]`0
0`00D]aBg00CD]`00`00D]aBg00AD]`7000CD]`00`00D]aBg00DD]`01000E]aFg5KL1@003eKL00<0
05KlE_`04eKl10005UKl00<005KlE_`00eKl10003UKl00<005/LFa`02U/L0`002E[l00<005/LFa`0
2U/L0`002E/L00<005/mFcd01U/m0`003U/m00<005/m00000P003UmM0P001EmM00<005mnGgh015mn
0`0026=m0P001V>M00L006^l001cV@00NeD00004Og@01000OgAoM0000gmd00D007mdOgAoM000009o
T`05001oTgnCOi<00002Oi<2000<Acl70003Acl00`00Acm7?`0CAcl00`00Acm7?`02Acl7000;Acl0
0`00Acm7?`0?Acl9000>Acl01@00Acm7?dLo00001DLo2`001DLo00<004/oBcl03d/o2@004d/o00<0
04]OBel00T]O1`002d]O00<004]OBel02D]O1`000d]O00D007ooOomoo`0003Aoo`00H7oo00<007oo
Ool0YWoo1P0021jN00<002JO0000100022Zo00<002jo;[l01Rjo1`0000<bg`00=]l03SKO00<003Zn
>[h00cZn2@000c[O00<003kN?]h043kN00<004;N@]h044;N00<004;N@]h034;N3`0024KN00<004KM
A]d04TKM00<004[MB]d04D[M00<004[MB]d04T[M00<004[MB]d04T[M00<004kMC]d02DkM3`004DkL
00<004kLC]`04dkL00<005;LD]`04e;L00<005;LD]`02E;L1`000e;L00<005;LD]`05E;L00<005;L
D]`04E;L1P0055KL00<005KlE_`03UKl1@000UKL00<005KlE_`05EKl00<005KlE_`00`004eKl00<0
05/LFa`01U/L0`003E[l00<005/LFa`01U/L0`003E/L00<005/mFcd00U/m0`004E/m0P003emM0P00
25mM00@005mnGgiOOP8000USO@8000ISW@800004Jk`007>I0002NeD01@00OgAoM7md00000gmd00@0
07mdOg@000AoM004001oTgnC0003Oi<00`00Oi<00002Oi<00`00Acm7?`02Acl7000;Acl00`00Acm7
?`0>Acl9000CAcl00`00Acm7?`03Acl;0005Acl00`00Acm7?`0?Acl:000AAcl00`00Bcm;?`03Bcl;
0005Bcl00`00Bcm;?`0@Bcl9000BBel00`00Bem;G`02Bel7000;Bel01@00Oomoogoo0000<goo001P
Ool00`00Oomoo`2WOol00`005WhFOP025Wh500047Yh00`009YlVW`039Yl50004:[l00`00;[l^_`0<
;[l6000<=]l00`00>[hj_P0;>[h:000<?]h00`00@]i2gP0@@]h00`00@]i2gP0@@]h00`00A[e6_@08
A[eW000:C[`00`00C]a>g00CC]`00`00C]a>g00CC]`00`00D]aBg00CD]`00`00D]aBg002D]`7000;
D]`00`00D]aBg00DD]`00`00D]aBg00<D]`50003E]`00`00E]aFg00EE]`00`00E_aFo009E_`40008
E]`00`00E_aFo00CE_`4000FE_`00`00FaaK7003Fa`3000@F_`00`00FaaK7003Fa`3000@Fa`00`00
Fcd00002000AFcd300000ell001OG@0;Ged3000:Ged01000Ggh000002F=m0P001V>M0P000V^l00<0
07>I00000g]E00D007mdOgAoM000009oM005001oM7mdOg@00003Og@01000Oi=oT`000gnC00@007nC
Oi<000=oT`@00197?`030017?dLo00=7?`/000I7?`030017?dLo00m7?`X00157?`030017?dLo00=7
?``000A7?`030017?dLo0157?`P0015;?`03001;?d/o00A;?`/000E;?`03001;Gd]O015;G`L0019;
G`05001oogooOol0000cOol005moo`03001oogoo0:Uoo`03000FOQIn00HFOPH000TVW`H000l^_`04
000b_c:o<[l70006=]l00`00>[hj_P0>>[h00`00?[hn_P03?[h:0003?]h00`00@]i2gP0@@]h00`00
@]i2gP0@@]h00`00A[e6_@0@A[d00`00A[e6_@0BA[d00`00B[e:_@0AB[d00`00B[e:_@0BB[d00`00
B[a:_00BB[`00`00C[a>_00CC[`00`00C]a>g00CC]`00`00C]a>g00BC]`00`00D]aBg00AD]`7000B
D]`00`00D]aBg00ED]`00`00D]aBg006D]`50009E]`00`00E]aFg00DE]`00`00E_aFo005E_`4000<
E]`00`00E_aFo00?E_`40002E_`00`00E_aFo00EE_`00`00FaaK7003000CF_`00`00FaaK7003000C
Fa`2000BFcd20005Gc`00`00GeeOG@07Ged2000=Ged20009Hgd20007Hid00`00Jka[_00200000g>I
001kE@02NeD00`00OgAoM002Og@01000OgAoM0000gmd00D007mdOgAoM000009oT`05001oTgnCOi<0
0002Oi<01000Oi=oTgnC0P0044Lo2P004TLo00<004LoAcl00dLo2`001DLo00<004LoAcl03dLo2P00
2dLo00<004LoAcl00dLo00<004LoAcl02DLo1`000d/o00<004/oBcl04D/o2@004D/o00<004]OBel0
2D]O1`000d]O00<004]OBel03d]O1P000goo00<007ooOol0<7oo001OOol00`00Oomoo`2ZOol3000:
5Wh4000;9Yl5000<;[l00`00<[lb_`07<[l600000cKO000j_P0?>[h00`00?[hn_P0<?[h:000=@]h0
0`00@]i2gP0?@]h00`00A[e6_@0AA[d00`00A[e6_@0BA[d00`00B[e:_@0AB[d00`00B[e:_@0BB[d0
0`00B[a:_00BB[`00`00C[a>_00BC[`00`00C]a>g00CC]`00`00C]a>g00CC]`00`00D]aBg009D]`7
0003D]`00`00D]aBg00DD]`00`00D]aBg00DD]`01000D]aBg5;L1@003UKL00<005KLE]`055KL00<0
05KlE_`01@0045KL00<005KlE_`035Kl0`001eKl00<005KlE_`04eKl10005U[l0`004e/L0`0000=K
7000Fcd03U/m0`001ell00<005mMGed01EmM0P003EmM0P0000=SG@00Hgd01V=m0P001f>M0P000V^l
00D007>ILiUcV@0000=kE@03001oM7md009oM004001oM7md0003Og@01@00OgAoM7md00000WnC00D0
07nCOi=oT`00009oT`07001oTgnCOi<007nC00001DLo2P001TLo00<004LoAcl03dLo2P004DLo00<0
04LoAcl00dLo2`001DLo00<004LoAcl03DLo00<004LoAcl00dLo00<004LoAcl00TLo1`002d/o00<0
04/oBcl02D/o1`000d/o00<004/oBcl054/o00<004]OBel00T]O1`002d]O00<004]OBel00d]O2`00
1D]O00D007ooOomoo`00039oo`00Ggoo00<007ooOol0[7oo1P0021In1@0022JO00@002Zo:[lZ_`L0
00H^_`03000b_c:o00`b_`H000dj_P03000n_Sjn00ln_P03000n_Sjn00<n_PX000=2gP030012gT;N
0112gP030016_DJm0156_@030016_DJm0156_@03001:_DZm019:_@03001:_DZm015:_@03001:_4Zl
019:_003001>_4jl01=>_003001>g4kL019>g003001>g4kL01=>g003001Bg5;L009Bg0L000]Bg003
001Bg5;L01=Bg003001Bg5;L019Bg0H001AFg003001Fg5KL019Fg0@001IFg003001Fo5Kl00MFo0@0
00YFo003001Fo5Kl011Fo0<0009Jo003001Jo5[l019Jo0<00003F_`005/L015K708000EK7003001K
?E/m00YK?@8000]O?004001OGEmMGed3000=Ged20004Hed00`00HgeSO@02Hgd20007Hid20003Jk`0
1@00LiUcVG>I000017]E00D007mdOgAoM00000=oM004001oM7md0003Og@01000Oi=oT`0017nC00<0
07nC00000gnC00@007nCOi=oT`D00157?`030017?dLo00=7?`/000E7?`030017?dLo0157?`P00157
?`030017?dLo00a7?`030017?`0000P0019;?`03001;?d/o009;?`L000];?`03001;?d/o00m;?`T0
011;G`P0015;G`05001oogooOol0000aOol005moo`03001oogoo0:ioo`04000BGA9M4Ud500045Wh0
10008YhRWR:N10001BJO00<002Zo:[l01bZo1P0000<^_`00<[l03S:o00@003Jn=[hf_PL000Lj_P03
000n_Sjn00ln_P03000n_Sjn00`n_PX000e2gP030016_DJm0156_@030016_DJm0156_@03001:_DZm
015:_@03001:_DZm019:_@03001:_4Zl019:_003001>_4jl019>_003001>g4kL01=>g003001>g4kL
00i>g0T0019Bg003001Bg5;L01=Bg003001Bg5;L00eBg0D000=Bg003001Fg5KL01AFg003001Fg5KL
00iFg0@0009Ff`03001Fg5KL01EFg003001Fo5Kl00=Fo0@000iFo003001Fo5Kl00eFo0<000IJo003
001Jo5[l00iJo0<000EJo003001K75/L00aK70<000MK7003001K?E/m00QK?@8000eO?004001OG@00
000>Ged20007Hed01000Hgd0000026>M00<006^lJk`00V^l00@007>ILiUcV@8000AkE@05001oM7md
Og@00002Og@01@00OgAoM7md00000gmd00@007nCOi<000=oT`04001oTgnC0003Oi<01@00Oi=oTgnC
00004dLo20004DLo00<004LoAcl02DLo1`000dLo00<004LoAcl04dLo00<004LoAcl00dLo2`001DLo
00<004/oBcl03d/o2@004d/o00<004/oBcl00d/o2`001D/o00<004]OBel02T]O1`000d]O00<004]O
Bel04D]O10000Woo00<007ooOol0;goo001OOol00`00Oomoo`2_Ool300054Ud600068Yh300039Yl0
0`00:[lZ_`0<:[l6000<<[l00`00=[hf_P07=[h700000cZn000n_P0@?[h00`00?[hn_P0??[h00`00
@[e2_@03@[d:0003@]h00`00A[e6_@0AA[d00`00A[e6_@0AA[d00`00B[e:_@0BB[d00`00B[e:_@0A
B[d00`00B[a:_00BB[`00`00C[a>_00CC[`00`00C]a>g00BC]`00`00C]a>g003C]`;0005C[`00`00
D]aBg00DD]`00`00D]aBg00CD]`00`00D]aBg006D]`60009D]`00`00E]aFg00CE]`00`00E]aFg009
E]`50007E]/00`00E]aFg00DE]`00`00E_aFo003000CE_`00`00E_aFo009E_`30009F_`00`00F_aJ
o00;F_`30008F_`00`00FaaK700:Fa`2000;Fa`00`00FceK?@04Fcd3000?Gc`2000>Ged20009Hed2
0008Hid20004Jk`01`00LiUcVG>I001g5P0000=kE@03001oM7md009oM004001oM7md0003Og@01@00
OgAoM7md00000WnC00D007nCOi=oT`00009oT`05001oTgnCOi<00003Oi<2000;Acl70003Acl00`00
Acm7?`0CAcl00`00Acm7?`02Acl7000;Acl00`00Acm7?`0>Acl:0009Acl00`00Acm7?`05Acl00`00
Bcm;?`03Bcl;0005Bcl00`00Bcm;?`0ABcl9000ABcl00`00Bem;G`02Bel7000;Bel00`00Bem;G`09
Bel70003Bel01@00Oomoogoo0000<7oo001OOol00`00Oomoo`2`Ool00`003Sd0000200074Ud40006
8Yh5000?:[l01000<[hb_S:n1@0023:o00<003Jn=[h03CJn1P003Sjn00<003jn?[h03cjn00<004:m
@[d034:m400024Jm00<004JmA[d04DJm00<004ZmB[d04DZm00<004ZmB[d04TZm00<004ZlB[`04TZl
00<004jlC[`04Tjl00<004kLC]`02DkL3`004Djl00<005;LD]`04e;L00<005;LD]`04e;L00@005;L
D]aBg0D000mBg003001Fg5KL01AFg003001Fg5KL00AFg0@000aFf`03001Fg5KL01=Fg0@001IFo003
001Fo5Kl00IFo0<000aJo003001Jo5[l00UJo08000]Jo003001K75/L00QK708000eK7003001K?E/m
009K?@80011O?0800003Gc`005mM00YOG@<000USG@800003He`006>M00ESW@8000E[_003001cVG>I
009cV@8000AkE@05001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00@007nCOi<000=oT`04001o
TgnC0003Oi<01P00Oi=oT`00Oi<000A7?`L000]7?`030017?dLo00i7?`T00197?`030017?dLo00=7
?`/000E7?`030017?dLo00]7?`030017?dLo00=7?`P0015;?`03001;?d/o00U;?`L000A;?`03001;
?d/o015;?`L0019;G`03001;Gd]O009;G`L000];G`04001oogoo000`Ool005moo`03001oogoo0;5o
o`04000>?@hm3Sd300054Ud00`007WhNOP0400068Yh5000<:[l00`00<[hb_P05<[h50004<[l00`00
=[hf_P0>=[h01000>[hj_SZn1`001cjn00<003jn?[h043jn00<004:m@[d03d:m00<004JmA[d02DJm
500024Jm00<004ZmB[d04TZm00<004ZmB[d04DZm00<004ZlB[`04TZl00<004jlC[`02Djl5@002Tjl
00<004jlC[`04djl00<005;LD]`04e;L00<005;LD]`04E;L1P0055;L00<005KLE]`055KL00<005KL
E]`010004EKK00<005KLE]`03eKL0`000UKK00<005KlE_`05EKl00<005KlE_`00eKl0`0045[l00<0
05[lF_`01E[l0`003U[l00<005/LFa`015/L0`003e/L00<005/m00000P003ell0`0015ll00<005mM
Ged01UmM0P002f=M00<006=LHe`00V=L00<006>MHid00V>M00<006^lJk`00f^l0P0017>I00<007LF
000017]E00D007mdOgAoM00000=oM004001oM7md0003Og@01000Oi=oT`000gnC00@007nCOi<000=o
T`05001oTgnCOi<00002Oi<4000BAcl00`00Acm7?`03Acl;0005Acl00`00Acm7?`0?Acl:000AAcl0
0`00Acm7?`09Acl70003Bcl00`00Bcm;?`0CBcl00`00Bcm;?`02Bcl7000<Bcl00`00Bcm;?`09Bcl7
0003Bcl00`00Bem;G`0ABel7000@Bel40002Ool00`00Oomoo`0]Ool005moo`03001oogoo0;9oo`03
000>?@hm00<>?@<000<BG@03000NOQin00<NOP@000DRWP03000ZWP0000@000PZ_`03000b_S:n00Tb
_PH0010f_P03000j_SZn00Lj_PL00003?[h003jn014n_P030012_D:m00m2_@030016_DJm0156_@03
0016_DJm00Q6_E8000Y>_003001>_4jl01=>_003001>_4jl01=>_003001Bg5;L01=Bg003001Bg5;L
00UBg0L000=B^`03001Bg5;L01EBg003001Fg5KL015Fg0D001EFf`03001Fg5KL00]Fg0@000IFf`03
001Fo5Kl01EFo003001Fo000008001=Jo003001Jo5[l009Jo0<0015Jo003001K75/L009K7080019K
7080011O?08000MO?003001OGEmM00AOG@8000]SG@8000ISG004001SW@000005Jk`00`00LiUcV@03
LiT01000MaIg5P000g]E00<007mdOg@00Wmd00@007mdOg@000=oM005001oM7mdOg@00002Oi<01@00
Oi=oTgnC00000WnC00D007nCOi=oT`0000=oT`03001oTgnC00800117?`X00157?`030017?dLo00=7
?`/000E7?`030017?dLo01=7?`030017?dLo0097?`L00003Bcl004/o00Q;?`03001;?d/o00i;?`T0
01=;?`03001;?d/o009;?`L000];?`03001;Gd]O00U;G`L000=?G`03001;Gd]O00a;G`D000=?G`04
001oogoo000_Ool005moo`03001oogoo0;=oo`<000D>?@<000034Ud001in00LNOP<000<RWP03000Z
WRZN00<ZWPD000@Z_`03000b_S:n00db_PD000df_P03000j_SZn00dj_PP000`n_P030012_D:m0112
_@030016_DJm0156_@030016_DJm0116_@03001:_DZm019:_@03001:_4Zl015:_003001>_4jl019>
_003001>_4jl01=>_003001>_4jl019>_003001>_4jl01=>_003001Bg5;L01=Bg003001Bg5;L009B
g0L000]B^`03001Bg5;L01ABg003001Fg5KL00aFg0D000=Ff`03001FfeKK01AFf`03001Fg5KL00QF
g0<000YFf`03001Fo5Kl01=Fo0@001IJo003001Jo000008001AJo003001K70000080015K70<00003
Ga`005ll00eO?08000YO?004001OGEmMGed2000;Hed20008He`20006Jk`00`00LiUcV@04LiT00`00
MaH00004NeD00`00OgAoM002Og@01000OgAoM0000gmd00D007mdOgAoM000009oT`05001oTgnCOi<0
0002Oi<01@00Oi=oTgnC00000gnC00H007nCOi<007nC0005Acl:0006Acl00`00Acm7?`0>Acl:000A
Acl00`00Acm7?`0>Acl90008Bcl00`00Bcm;?`08Bcl00`00Bcm;?`03Bcl:0005Bcl00`00Bcm;?`0B
Bcl7000BBcl00`00Bem;G`02Bel7000;Cel00`00Bem;G`06Bel50008Cel01@00Oomoogoo0000;Woo
001OOol00`00Oomoo`2eOol400053Sd3000:7Wh50009:Yh6000?<[h01000=[hf_SJn1`001SJn00<0
03Zn>[h03cZn00<003jn?[h00cjn2P000cjn00<004:m@[d044:m00<004JmA[d044Jm00<004JmA[d0
4DJm00<004ZmB[d04TZm00<004ZlB[`04DZl00<004jlC[`04Tjl00<004jlC[`04Tjl00<004jlC[`0
4djl00<004jlC[`04Tjl00<005;LD]`04E;L1`004U:k00<005;LD]`055;L00<005KLE]`01UKL1P00
2EKK00<005KKE]/055KK00<005KLE]`00eKL10003UKK00<005KlE_`03eKl0`000U[k00<005[lF_`0
5E[l0P005e[l0P004U/L0P001ElL00<005llGc`02Ell0P0035ll00@005mM000000]SG@8000USG003
001WF`0000E[_003001cVG>I00AcV@04001g5WLF0004NeD01@00OgAoM7md00000gmd00@007mdOg@0
00AoM004001oTgnC0003Oi<00`00Oi<00004Oi<01000Oi=oT`000WnC00@007nCOi=oT`D00157?`03
0017?dLo00=7?`X000E7?`030017?dLo01A7?`030017?dLo00=7?`X000I7?`03001;?d/o00Q;?`03
001;?d/o00A;?`X0011;?`03001;?d/o00Y;?`L000=??`03001;?d/o015;?`L0019?G`04001;Gd]O
Bel5000>Cel01000Oomoo`00;Woo001OOol00`00Oomoo`2gOol00`001Q`0000200053Sd3000;7Wh4
000;:Yh4000=<[h00`00=[hf_P07=[h600000cJn000j_P0@>[h00`00?[hn_P0<?[h:000<@[d00`00
A[e6_@0AA[d00`00A[e6_@0@A[d00`00B[e:_@0BB[d00`00B[a:_00AB[`00`00C[a>_00BC[`00`00
C[a>_00CC[`00`00C[a>_00BC[`00`00C[a>_00CC[`00`00D]aBg009D]`70003D[/00`00D[]B^`0D
D[/00`00D]aBg00DD]`00`00E]aFg005000?E]/00`00E]]Ff`0DE]/00`00E]aFg003000BE]/00`00
E_aFo00;E_`40006F_/00`00F_aJo00AF_`300000e[l001Jo00CF_`300000e/L001K700>Fa`30007
Ga`00`00GcaO?007Gc`2000>Gc`2000<Hed00`00HeaSG007He`20003Ie/01@00Jka[_6^l00001W>I
00D007LFMaIg5P0000AkE@05001oM7mdOg@00003Og@01000OgAoM0000gmd00@007nCOi<000=oT`04
001oTgnC0003Oi<01@00Oi=oTgnC00000WnC00D007nCOi=oT`000157?`X00117?`030017?dLo00m7
?`X00157?`03001;?d/o00=;?`/000E;?`03001;?d/o01=;?`03001;?d/o009;?`L000]??`03001;
?d/o00U;?`L000=??`03001?GdmO015?G`H0011?G`@000=oo`03001oogoo02]oo`00Ggoo00<007oo
Ool0^7oo0P000PHL0`0010hm1@002Ain00<002In00000`0022ZN00<002jN;Yh01@002C:n00<003Jn
=[h033Jn1P003SZn00<003jn?[h03cjn00<004:m@[d00d:m2P000d:m00<004JmA[d044Jm00<004Jm
A[d04DJm00<004ZmB[d04TZm00<004ZlB[`04DZl00<004jlC[`04Tjl00<004jlC[`04Tjl00<004jl
C[`04Tjl00<004jlC[`04djl00<005;LD]`00U;L1`002e:k00<005:kD[/04e:k00<005;LD]`04E;L
1P0055KK00<005KKE]/04eKK10005EKK00<005KlE_`025Kl0`002U[k00<005[lF_`03U[l0`001E[l
00<005[lF_`03U[l0`001E/L00<005/LFa`02U/L0P002elL00<005llGc`00ell0`003Ull0P0000=O
?000Hed02F=M0P002F=L00<006MKIe/016MK00<006^l00001W>I00<007LFMaH00WLF00D007]ENeEk
E@0000AoM004001oM7md0003Og@01@00OgAoM7md00000WnC00D007nCOi=oT`00009oT`05001oTgnC
Oi<00003Oi<01000Oi=oT`000gnC0P001DLo2`001DLo00<004LoAcl04dLo00<004LoAcl00dLo2`00
1DLo00<004LoAcl03dLo2P0014/o00<004/oBcl02T/o00<004/oBcl03T/o2@004Tlo00<004/oBcl0
0T/o1`002dlo00<004mOCel02DmO1`000dmO00<004mOCel02DmO1`000dmO00D007ooOomoo`0002eo
o`00Ggoo00<007ooOol0^Woo0`000PHL0`000Phm00@001IN5UhFGP@000HNOP03000VORIn008VOP@0
00DZWP03000^WRjN00@^WPD000@b_P03000f_SJn00hf_P04000j_SZn>[h70007>[h00`00?[hn_P0@
?[h00`00@[e2_@0<@[d:000=A[d00`00A[e6_@0@A[d00`00B[e:_@0BB[d00`00B[a:_00AB[`00`00
C[a>_00BC[`00`00C[a>_00BC[`00`00C[a>_00CC[`00`00C[a>_00>C[`9000BD[/00`00D[]B^`0C
D[/00`00D]aBg00<D]`50003E[/00`00E]]Ff`0EE]/00`00E]]Ff`0=E]/50002E]/00`00E]]Ff`0E
E]/00`00E_aFo003E_`4000>F_/00`00F_aJo00:F_`30008F_`00`00F_aJo00<F_`20008Fa`00`00
FaaK7008Fa`2000=Ga`01000GcaO?5ll0P003ell0P0015ll00<006=MHed01F=M0P002F=L0P001fMK
0P001g>I00D007LFMaIg5P0000AkE@05001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00@007nC
Oi<000=oT`04001oTgnC0003Oi<01@00Oi=oTgnC00000WnC00@007nCOi<0009oT`D00157?`030017
?dLo00i7?`X00157?`030017?dLo00=7?`/000E;?`03001;?d/o00I;?`03001;?d/o00Y;?`03001;
?d/o00=;?`/000E??`03001??dlo015??`L0019??`03001?GdmO009?G`L000]?G`04001?GdmOCel7
000;Cel01@00Oomoogoo0000;7oo001OOol00`00Ool00002002jOol400021Q`400065Uh400037Wh0
0`009WhVOP059Wh30003:Yh00`00;Yh^WP08;Yh6000@=[h00`00>[hj_P07>[h700000cZn000n_P0@
?[h00`00@[e2_@0@@[d00`00A[e6_@03A[d:0003A[d00`00A[e6_@0AA[d00`00B[e:_@0AB[d00`00
B[a:_00AB[`00`00C[a>_00BC[`00`00C[a>_00CC[`00`00C[a>_00BC[`00`00C[a>_003C[`;0005
D[/00`00D[]B^`0CD[/00`00D[]B^`0DD[/00`00D]aBg006D]`50009E[/00`00E]]Ff`0DE]/00`00
E]]Ff`09E]/40008E]/00`00E]]Ff`0DE]/00`00E_aFo003000BF_/00`00F_aJo007F_`3000<F_`0
0`00F_aJo008F_`3000;Fa`00`00FaaK7004Fa`3000?Ga`01000Gc`000003ell0P001Ull00<006=M
Hed00f=M0P002V=L00<006MKIe/01VMK00<006LJ00001W>I00<007LFMaH00WLF00<007]ENeD00W]E
00D007mdOgAoM00000=oM004001oM7md0003Og@01@00Oi=oTgnC00000gnC00<007nC00000gnC00D0
07nCOi=oT`00009oT`05001oTgnCOi<00002Oi<00`00Acm7?`0CAcl00`00Acm7?`03Acl;0005Acl0
0`00Acm7?`0?Acl:000ABcl00`00Bcm;?`06Bcl00`00Bcm;?`05Bcl:000ACcl00`00Ccm??`09Ccl7
0003Ccl00`00Ccm??`0ACcl7000?Cel7000@Cel40002Ool00`00Oomoo`0ZOol005moo`800;ioo`80
00040O/0000000021Q`400075Uh500099Wh5000>;Yh5000==[h00`00>[hj_P0=>[h6000>?[h00`00
@[e2_@0@@[d00`00A[e6_@0<A[d?0008A[d00`00B[e:_@0BB[d00`00B[a:_00AB[`00`00C[a>_00B
C[`00`00C[a>_00BC[`00`00C[a>_009C[`?000AD[/00`00D[]B^`0CD[/00`00D[]B^`0CD[/01000
D]aBg5;L1@003UJk00<005KKE]/055KK00<005KKE]/01EKK100035KK00<005KKE]/04eKK10005U[k
00<005[lF_`00e[l0`003e[l00<005[lF_`01U[l0P003U/L00<005/LFa`00U/L0P004UlL0P003ell
0P002Ell00D006=MHeeSG@0000YSG08000QWF`05001W6VLJIaX00004LiT00`00MaIg5P03MaH01@00
NeEkEG]E000017md00@007mdOg@000=oM005001oM7mdOg@00002Oi<01@00Oi=oTgnC00000WnC00D0
07nCOi=oT`0000=oT`04001oTgnC0003Oi<00`00Oi=oT`02000@Acl:000AAcl00`00Acm7?`03Acl;
0005Acl00`00Bcm;?`0CBcl00`00Bcm;?`03Bcl;0005Bcl00`00Ccm??`0CCcl00`00Ccm??`02Ccl7
000;Ccl00`00Ccm??`09Ccl70003Ccl00`00Cem?G`0;Cel50003Cel00`00Cem?G`0<Cel50003Cel0
1@00Oomoogoo0000:goo001NOol00`00Oomoo`2oOol300020O/200031Q`400085Uh4000:9Wh4000<
;Yh01000=YhfWSJN1`001cJn00<003Zn>[h03SZn00@003jM?YdnW@L000Pn_P030012_D:m00m2_@03
0016_DJm0116_@030016_DJm00Q6_AD000Q:_@03001:_4Zl015:_003001>_4jl019>_003001>_4jl
00U>_1D000Y>^`03001B^e:k01=B^`03001B^e:k01=B^`03001B^e:k015B^`H001=F^`03001FfeKK
01EFf`03001Ff`0000@0011Ff`03001FfeKK00mFf`@0009Ff`03001Jne[k01EJn`03001Jo5[l00<0
01=Jo003001Jo5[l009Jo0<0011K7003001K70000080015O70<00003Ga`005ll00aO?08000]O?004
001SG@00000:He`00`00Ie]WF`07Ie/00`00IaYW6P02IaX00`00LiUcV@02LiT00`00MaIg5P02MaH0
0`00NeEkE@02NeD00`00OgAoM002Og@01000OgAoM0000gmd00D007mdOgAoM000009oT`05001oTgnC
Oi<00002Oi<01@00Oi=oTgnC00000gnC00@007nCOi<000=oT`03001oT`00009oT`030017?dLo00=7
?`X000I7?`030017?dLo00i7?`X00157?`03001;?d/o00i;?`X000=;?`03001;?d/o00];?`03001?
?dlo00i??`T0019??`03001??dlo009??`L000Y??`03001?GdmO00I?G`D000U?G`03001?GdmO00I?
G`D000U?G`04001oogoo000[Ool005ioo`03001oogoo0<1oo`030001^P00008000060O/000000006
70000Q8m0`001QIN00<0029n8Wh0100022In00<002jN00000`002BjN00<003JN=Yh01cJN1`0000<f
_P00>[h03cZn00<003jM?Yd01cjM1`0000<n_P00@[d04D:m00<004JmA[d044Jm00<004JmA[d044Jm
00<004ZlB[`02DZl?@002Tjl00<004jkC[/04djk00<005:kD[/04e:k00<005:kD[/04e:k00<005:k
D[/02e:k1@000e:k00<005JkE[/055Jk00<005KKE]/04UKK10005UKK00<005KKE]/02eKK0`001eKK
00<005[kF_/04e[k10005U[l00<005[l00000P004e/L0P004UlL0P001ElL00<005llGc`025ll0P00
3Ell0P002V=L0P0026MK0P001VLJ00@007>ILiT000Eg5P03001kEG]E009kE@05001oM7mdOg@00003
Og@01@00OgAoM7md00000gmd00@007nCOi<000=oT`04001oTgnC0003Oi<01000Oi=oT`000WnC00D0
07nCOi=oT`00009oT`04001oTgnCOi<5000AAcl00`00Acm7?`03Acl:0005@cl00`00Acm7?`0CAcl0
0`00Bcm;?`03Bcl;0005Bal00`00Bcm;?`05Bcl00`00Bcm;?`0;Bcl00`00Ccm??`03Ccl;0005Cch0
0`00Ccm??`0ACcl7000BCcl00`00Cem?G`05000>Cel01000Cem?GdmO1@003TmO00D007ooOomoo`00
02Yoo`00GWoo00<007ooOol0`Goo00@0006j0KX1^P800081n`<000@B?@<000@FGP03000ROR9n00<R
OP@000DVOP03000^WRjN008^WP@000H^WP03000fWSJN00dfWPD000dj_P03000nWCjM00hnW@H000i2
_@030016_DJm0116_@030016_DJm0156_@03001:_4Zl015:_003001:_4Zl015:_003001>_4jl019>
_003001>_4jl01=>_003001>^djk019>^`03001B^e:k01=B^`03001B^e:k01=B^`03001B^e:k00IB
^`D000UB^`03001F^eJk01=F^`03001FfeKK00iFf`@0009Ff`03001FfeKK01EFf`03001FfeKK00MF
f`@000YFf`03001Jne[k011Jn`<0009Jn`03001Jo5[l01AJo0<001=K70<00003Ga`005lL00mO7080
00MO7003001O?5ll00IO?08000eO?0800003Hc`006=L00QSG003001WFfMK00MWF`03001W6VLJ00IW
6P03001cV@0000Ig5P03001kEG]E009kE@05001oM7mdOg@00003Og@01000OgAoM0000gmd00D007nC
Oi=oT`0000=oT`03001oT`0000=oT`05001oTgnCOi<00002Oi<01@00Oi=oTgnC00000WnC00D007nC
Oi=oT`000157?`X00113?`030017?dLo00i7?`X0015;7`03001;?d/o00A;?`03001;?d/o00U;?`P0
015??P03001??dlo00U??`L000=??P03001??dlo011??`H0015?G`H0015?G`@0009oo`03001oogoo
02Qoo`00GWoo00<007ooOol0`Woo0P000`6j0P000`7k0P001A8m0`000QIN00<0029n8Wh01R9n0`00
0bIn00<002jN;Yh01BjN10000bjN00<003JN=Yh03SJN00<003ZN>Yh01@002CZn00<003jM?Yd03cjM
00@004:M@Ye2W@L000Q2_@030016_DJm0116_@030016_DJm0116_@03001:_4Zl019:_003001:_4Zl
015:_003001>_4jl019>_003001>_4jl019>_003001>^djk01=>^`03001B^e:k019B^`03001B^e:k
01=B^`04001B^e:kD[/5000>D[/00`00E[]F^`0DE[/00`00E]]Ff`08E]/50007E]/00`00E]]Ff`0D
E]/00`00E]]Ff`03E]/4000>E]/00`00F_]Jn`0=F_/30006F_/00`00F_aJo00@F_`30002F_/00`00
FaaK700?Fa`20005Ga`00`00GaaO700:Ga`3000:Ga`00`00GcaO?003Gc`2000=Gc`20004Hc`00`00
HeaSG004He`20009Ie/00`00IaYW6P07IaX20006MaH00`00NeEkE@02NeD00`00OgAoM002Og@01000
OgAoM0000gmd00D007mdOgAoM000009oT`05001oTgnCOi<00002Oi<01@00Oi=oTgnC00000gnC00@0
07nCOi<000=oT`04001oTgnC0003Oi<20005Acl;0005Acl00`00@cm3?`0C@cl00`00Acm7?`03Acl:
0005Aal00`00Bam;7`0CBal00`00Bcm;?`04Bcl00`00Bcm;?`02Bcl70003Cah00`00Cci??P0CCch0
0`00Ccm??`02Ccl7000;Cch00`00Ccm??`08Ccl70003Ccl00`00Cem?G`0<Cel50003Cel00`00Cem?
G`0<Cel50003Cel01@00Oomoogoo0000:Goo001NOol00`00Oomoo`34Ool300020KX200020O/40005
4Sd4000:8Wh5000:;Yh5000@=Yh00`00>YhjWP04>Yh50005>[h00`00?YdnW@0??Yd00`00@Ye2W@07
@Yd700000d:m0016_@0AA[d00`00A[e6_@0AA[d00`00B[a:_00AB[`00`00B[a:_00AB[`00`00C[a>
_00BC[`00`00C[a>_00BC[`00`00C[]>^`0CC[/00`00D[]B^`0CD[/00`00D[]B^`0>D[/8000CD[/0
0`00E[]F^`0DE[/00`00E]]Ff`04E]/4000<E]/00`00E]]Ff`0EE]/00`00E]/00002000CE]/00`00
F_]Jn`09F_/30009F_/00`00F_aJo00=F_`30006F_/00`00FaaK700<Fa`20007Ga`00`00GaaO7008
Ga`2000=Ga`01000GcaO?5ll0P003Ull00<006<lHc`016<l00<006=LHe`00f=L00<006MKIe/026MK
00<006LJIaX01fLJ00<006<K00001WLF00<007]ENeD00W]E00D007mdOgAoM00000=oM005001oM7md
Og@00003Og@01000Oi=oT`000gnC00@007nCOi<000=oT`05001oTgnCOi<00002Oi<01000Oi=oT`00
0WnC00D007nCOi=oT`00009oT`D00157?`030013?d<o00U3?`l001177`03001;7d/O019;7`03001;
?d/o009;?`L000]?7P03001??Tln011??PL0019??P04001??dloCcl7000;Ccl00`00Cem?G`06Cel5
0009Cel00`00Cem?G`06Cel50009Cel01000Oomoo`00:Goo001NOol00`00Oomoo`36Ool300020KX4
00023Qd300054Sd4000;8Wh4000;;Yh4000==Yh00`00>YhjWP09>Yh6000A?Yd00`00@Ye2W@0>@Yd8
000=A[d00`00A[e6_@0@A[d00`00B[a:_00BB[`00`00B[a:_00AB[`00`00C[a>_00BC[`00`00C[a>
_00BC[`00`00C[]>^`0BC[/00`00D[]B^`0CD[/00`00D[]B^`03D[/;0005D[/00`00D[]B^`0DD[/0
0`00E[]F^`0CE[/00`00E]]Ff`04000@E]/00`00E]]Ff`0CE]/4000FE]/00`00F_]Jn`06F_/3000<
F_/00`00F_aJo00:F_`30009F_/00`00FaaK7009Fa`3000:Ga`00`00GaaO7005Ga`2000?Ga`01000
Gc`000003Ull0P0026<l00<006=LHe`00P002FMK0P002FLJ00@006<KHa/000Ig5P03001kEG]E009k
E@05001oM7mdOg@00003Og@01000OgAoM00017md00@007nCOi<000=oT`04001oTgnC0003Oi<01000
Oi=oT`000WnC00D007nCOi=oT`00009oT`05001oTgnCOi<00002Oi<00`00Acm7?`0AAcl>000:@cl0
0`00Aam77`0CAal00`00Bam;7`0=Bal90002Cah00`00Cai?7P0=Cah00`00Cci??P09Cch70003Cah0
0`00Cci??P0ACch6000BCcl01000Cem?GdmO1@003TmO00@004mOCem?G`D000a?G`@0009oo`03001o
ogoo02Ioo`00GWoo00<007ooOol0agoo10000`6j0P0010hM0`00118m00<001iN00000P002B9n00<0
02Yn:Wh00`002BjN00<003:N<Yh01@002CJN00<003ZN>Yh03CZN1@003SjM00<004:M@Yd03d:M00<0
04:M@Yd00d:M2P000dJm00<004JmA[d04DJm00<004ZlB[`04DZl00<004ZlB[`04DZl00<004jlC[`0
4Tjl00<004jlC[`04Tjl00<004jkC[/04djk00<005:kD[/03U:k2P004E:k00<005:kD[/04e:k00<0
05JkE[/04EJk1@005EKK00<005KKE]/03eKK0`000UKK00<005KKE]/05EKK00<005[kF_/00e[k0`00
45[k00<005[lF_`01U[l0`0035[k00<005/LFa`01e/L0P003UlL00@005lLGaaO70<0015O708000iO
?08000YS?003001SG00000YWF`03001W6VLJ00QW6P03001S6f<K009S6`03001g5WLF009g5P03001k
EG]E009kE@03001oM7md009oM005001oM7mdOg@00002Og@01@00OgAoM7md00000gnC00L007nCOi=o
T`00Oi<00003Oi<01@00Oi=oTgnC00000WnC00D007nCOi=oT`00009oT`05001oTgnCOi<00002Oi<2
000;Acl70003Acl00`00@cm3?`0C@cl00`00Aam77`0BAal00`00Bam;7`03Bal:0005Cah00`00Cai?
7P03Cah00`00Cai?7P0=Cah00`00Cci??P02Cch7000;Cah00`00Cci??P0;Cch50003Dch00`00Ccm?
?`0@Ccl6000ACel6000<Cel50003Cel01@00Oomoogoo00009goo001NOol00`00Oomoo`39Ool50002
0KX200053Qd200034Sd010007UhNGQiN0`001b9n00<002Yn:Wh00RYn0`001bjN00<003:N<Yh013:N
1@001CJN00<003ZN>Yh03CZN00@003jM?YdnW@D000TnW@030012WD:M0112W@030012WD:M00a2W@l0
00Q6_@03001:_4Zl015:_003001:_4Zl015:_003001>_4jl019>_003001>_4jl01=>_003001>^djk
019>^`03001B^e:k00=B^`/000EB^`03001B^e:k01=B^`03001B^e:k01AB^`03001F^eJk00]F^`D0
00=F^`03001FfeKK01AFf`03001FfeKK00]Ff`@000IFf`03001FfeKK01EFf`03001Jn`00008001=J
n`03001Jo5[l00=Jo0<0011Jn`03001K75/L00AK7080011O7004001O7000000BGa`200000elL001O
?00;Gc`2000<Hc`2000:Ie/00`00IaYW6P08IaX00`00Ha]S6`03Ha/00`00MaIg5P02MaH00`00NeEk
E@02NeD00`00OgAoM002Og@01000OgAoM0000gmd00D007mdOgAoM000009oT`05001oTgnCOi<00002
Oi<01@00Oi=oTgnC00000gnC00@007nCOi<000=oT`03001oT`0000AoT`03001oT`00009oT`040017
?dLoAcl7000;Acl00`00@cm3?`0B@cl00`00Aam77`09Aal?000@Cah00`00Cai?7P02Cah00`00Cai?
7P09Cah9000BCah00`00Cci??P06Cch50009Dch00`00Ccm??`08Ccl70003Dcl00`00Cem?G`0<Cel5
0003Cel00`00Cem?G`07Cel50009Cel01000Oomoo`009goo001NOol00`00Oomoo`3:Ool300000`6I
000000020KX300043Qd300000a8m000NGP047Uh300058Wh00`00:WhZOP04:Wh30005;Yh00`00<Yhb
WP08<Yh6000@>Yh00`00?YdnW@05?Yd50005?Yd00`00@Ye2W@0?@Yd00`00@Ye2W@0@@Yd00`00AYa6
W008AY`?000>B[`00`00B[a:_00AB[`00`00C[a>_00BC[`00`00C[a>_00BC[`00`00C[]>^`0>C[/:
000@D[/00`00D[]B^`0CD[/00`00D[]B^`0DD[/00`00E[]F^`06E[/50009E[/00`00E]]Ff`0DE]/0
0`00E]]Ff`07E]/3000:E]/00`00E]]Ff`0DE]/3000FF_/00`00F_aJo003000CF_/01000FaaK75/L
0`004UlL0P004UlL0P0015lL00<005llGc`01ell0P0036<l0P0000=S6`00Ie/026MK00<006LJIaX0
26LJ00<006<KHa/016<K00<007LFMaH00WLF00<007]ENeD00W]E00D007mdOgAoM00000=oM005001o
M7mdOg@00003Og@01000Oi=oT`000gnC00@007nCOi<000=oT`05001oTgnCOi<00002Oi<01000Oi=o
T`000WnC00D007nCOi=oT`00009oT`04001oTgnCOi<3000BAcl00`00@cm3?`09@clE000:Bal00`00
Cai?7P0BCah00`00Cai?7P02Cah<0005Dah00`00Cai?7P0CCah01000Cci??Tln1@003U<n00@004lo
Ccm??`L000]C?`03001?GdmO00I?G`D000U?G`04001?GdmOCel5000<Cel30003Ool00`00Oomoo`0T
Ool005ioo`03001oogoo0<]oo`@000060IT000000KX000Gl0`0010hM0`001aiN0`000R9n00<002Yn
:Wh01bYn0`000RjN00<003:N<Yh03C:N1@003CZN00<003jM?Yd02CjM1P004T:M00<004:M@Yd044:M
00<004JLAY`044JL00<004ZLBY`00dZL2`000dZl00<004ZlB[`04DZl00<004jlC[`04Tjl00<004jl
C[`04Tjl00<004jkC[/00djk2`001Djk00<005:kD[/04e:k00<005:kD[/04e:k00<005:kD[/04e:k
00@005JkE[]F^`D000iF^`03001FfeKK01AFf`03001FfeKK00=Ff`@000eFf`03001FfeKK015Ff`<0
0003F]/005[k01IJn`<001IJn`04001K7000000CGa`200000elK001O700?Ga`20006Ga`00`00GcaO
?005Gc`2000=Hc`00`00Ha]S6`02Ha/00`00Ie]WF`05Ie/00`00IaYW6P08IaX00`00Ha]S6`05Ha/0
0`00MaIg5P02MaH01@00NeEkEG]E000017md00D007mdOgAoM000009oM005001oM7mdOg@00003Oi<0
1@00Oi=oTgnC00000WnC00D007nCOi=oT`00009oT`04001oTgnC0003Oi<01000Oi=oT`000gnC00@0
07nCOi<000=oT`030017?dLo00i7?a0000Xk7`03001;7d/O01=;7`03001?7TlN00e?7PX0015C7P03
001?7TlN011?7PH0015C?PH0019C?`04001?GdmOCel5000<Cel6000=Cel40002Cel01@00Oomoogoo
00009Woo001NOol00`00Oomoo`3=Ool40000106I000000000`Gl0`0010hM0`001aiN10002bYn1000
3c:N00@003JM=YdfW@D000TjWP03000nWCjM00dnW@D000i2W@030012WD:M0112W@030016W4JL0156
W003001:W4ZL00e:W4L0015>^`03001B^e:k019B^`03001B^e:k01=B^`03001B^e:k015B^`H001=F
^`03001FfeKK01AFf`03001FfeKK00<0019Ff`03001FfeKK00eFf`<000EJf`03001Jne[k015Jn`<0
0003F]/005[k01IJn`80019O70<000AO6`03001O75lL00]O708000UO7003001O?5ll00=O?003001S
?6<l00]S?08000ES6`03001WFfMK00=WF`8000YW6P03001S6f<K00IS6`05001g5WLFMaH00004NeD0
0`00OgAoM002Og@01@00OgAoM7md00000Wmd00D007mdOgAoM000009oT`03001oTgnC009oT`03001o
T`0000=oT`05001oTgnCOi<00002Oi<01@00Oi=oTgnC00000WnC00D007nCOi=oT`00009oT`04001o
TgnCOi<20005Acl:0006Acl00`00>alk7`0B>al00`00Bam;7`0BBal00`00Cai?7P03Cah:0005C_d0
1@00DaiC7U<N00004E<N00<004lNCah02DlN1`000e<N00<005<nDch035<n1@000e<n00<005<oDcl0
4E<o1@0034mO1@000dmO00<004mOCel02DmO10001dmO00D007ooOomoo`0002Eoo`00GWoo00<007oo
Ool0cWoo1@000P6I0P0010Gl0P000`hM00<001Xm00000P001aiN10002bYn10003C:N00<003JM=Yd0
1CJM1@0013ZN00<003jM?Yd03SjM00@004:M@Ye2W@L000Q2W@030012WD:M0112W@030016W4JL0116
W003001:W4ZL015:W003001:W4ZL015:W003001>VdjK019>V`03001>VdjK019>V`03001>^djk01=>
^`03001B^e:k019B^`03001B^e:k01AB^`03001B^e:k00]B^`D000=B^`03001F^eJk01AF^`03001F
feKK019Ff`@001EFf`03001FfeKK00YFf`<000QJf`03001Jne[k00iJn`<000EJf`03001Jne[k015J
n`<00003F_/005lL00mO708000MO6`03001O75lL00QO70<000]O7004001O?5llGc`2000<Hc`20008
Ha/01@00Ie]WFfMK00002fLJ00<006<KHa/026<K00@007LFMaH000AkE@05001oM7mdOg@00003Og@0
1@00OgAoM7md00000gmd00@007nCOi<000=oT`04001oTgnC0003Oi<01@00Oi=oTgnC00000WnC00L0
07nCOi=oT`00Oi<00003Oi<01000Oi=oT`000gnC00<007nCOi<01@004DLo00<003/O>al04C/O00<0
04/OBal02D/O3`0044km00@005<NDah0015C7P03001?7TlN009?7PL000]C7P03001C?U<n00IC?PD0
00UC?P03001C?e<o00]C?`D0009CG`03001?GdmO00M?G`D000U?G`03001?GdmO00A?G`@000]?G`05
001oogooOol0000UOol005ioo`03001oogoo0<moo`030001=`0000<000030IT00000008000<5o0<0
00033Qd001Xm008J?@<000HNGP03000VGP00008000TZOP03000bOS9n00@000TbWP03000fWCJM00Xf
W@H0010nW@030012WD:M00M2W@L00003@Yd004:M0152W@030016W4JL0156W003001:W4ZL015:W003
001:W4ZL015:W003001>VdjK019>V`03001>VdjK019>V`03001>^djk019>^`03001B^e:k01=B^`03
001B^e:k01=B^`03001B^e:k00IB^`D000QB^`03001F^eJk01AF^`03001FfeKK00iFf`@0009F^`03
001FfeKK01EFf`03001FfeKK00IFf`<000aJf`03001Jne[k00]Jn`8000QJf`03001Jne[k00iJn`<0
00EJn`03001O75lL00]O708000UO6`03001O75lL00IO708000iO7004001O?000000=Hc`00`00Ha]S
6`08Ha/01000Ie]WF`002fLJ00<006<KHa/02F<K00@007LFMaH000AkE@05001oM7mdOg@00003Og@0
1@00OgAoM7md00000gmd00@007nCOi<000=oT`04001oTgnC0003Oi<01@00Oi=oTgnC00000WnC00@0
07nCOi<0009oT`05001oTgnCOi<00002Oi<01@00Oi=oTgnC00000WnC0P0044Lo90002Tkm00<004km
C_d04Tkm00@005<NDah000mC7PL0019C7P04001C?U<nDch5000>Dch00`00DcmC?`06Dcl50008Del0
1000Cem?GdmO1@003TmO00<004mOCel010003TmO0`000goo00<007ooOol08Woo001NOol00`00Oomo
o`3@Ool200000`4g0000000300020M/200041O`300056Sd300047Uh010009UhVGRIN0`001bYn00<0
039n<Wh00c9n10001S:N00<003JM=Yd03SJM1@003CjM00<004:M@Yd03D:M20003D:M00<004JLAY`0
4DJL00<004ZLBY`044ZL00<004ZLBY`04DZL00<004jKCY/04TjK00<004jKCY/04TjK00<004jkC[/0
4djk00<005:kD[/04U:k00<005:kD[/04e:k00@005:kD[]B^`D000iB^`03001F^eJk01AF^`03001F
feKK00QFf`D000IF^`03001FfeKK01EFf`03001FfeKK00=Ff`<000mJf`03001Jne[k00QJn`<000YJ
f`03001Jne[k00]Jn`<000QJn`03001O75lL00UO708000aO6`03001O75lL00=O7080011O708000eS
?08000]S6`03001WF`0000]W6P03001S6f<K00YS6`03001g5P0000AkE@03001oM7md009oM005001o
M7mdOg@00002Og@01@00OgAoM7md00000gnC00D007nCOi=oT`00009oT`05001oTgnCOi<00002Oi<0
1000Oi=oT`000gnC00@007nCOi<000=oT`04001oTgnC0003Oi<01P00Oi=oT`00Oi8000E7?`X000E7
?`03000^gbkO014^g`03001>oDkm01=>o@03001>oDkm019>o@03001C7P0000QC7PL000=C7@03001C
7U<N015C7PH001=C?P04001C?e<oDcl5000<Del5000ACel5000=Cel50002Cgl01@00Oomoogoo0000
97oo001NOol00`00Oomoo`3BOol200000`4g0001N00200030M/200051O`200066Sd300027Uh00`00
9UhVGP039Uh30005:Wh00`00<WhbOP06<Wh30004<Yh00`00=YdfW@0>=Yd01000>YdjWCZM1@002CjM
00<004:M@Yd03T:M00<004:L@Y`00d:L2P000d:M00<004JLAY`04DJL00<004ZLBY`04DZL00<004ZL
BY`044ZL00<004jKCY/04TjK00<004jKCY/04TjK00<004jkC[/04djk00<005:kD[/04U:k00<005:k
D[/03e:k20004e:k00<005JkE[/055Jk00<005KKE]/015KK100035Jk00<005KKE]/055KK00<005KK
E]/00`004U[K00<005[kF_/01U[k0P003U[K00<005[kF_/025[k0P002e[k00<005lLGa`01elL0P00
3UlK00@005lLGaaO7080011O70800003Ga/006<l00YS?08000eS6`8000]W6P03001S6f<K00]S6`03
001g5P0000AkE@03001oM7md009oM005001oM7mdOg@00002Og@01@00OgAoM7md00000WnC00D007nC
Oi=oT`00009oT`05001oTgnCOi<00003Oi<01000Oi=oT`000gnC00@007nCOi<000=oT`03001oT`00
00=oT`04001oTgnC0003Oi85000@Acl00`00;]l^g`0A;]l00`00C_e>o@0BC_d00`00C_e>o@0BC_d0
1000Dah005<N1`002e<M00<005<NDah02e<N1@000e<n00<005<nDch04E<n1P003E=O10000U=O00<0
04mOCel034mO1@000dmO00<004mOCel01dmO1@0024mo00D007ooOomoo`0002=oo`00GGoo00<007oo
Ool00`00dGoo1@0000<1N00000000`7K0`000`Gl10001QXm10001bIN0`000RYn00<0039n<Wh02C9n
1@004CJM00<003ZM>Yd01CZM1@0013jM00<004:M@Yd03d:M00<004:L@Y`034:L2P003TJL00<004ZL
BY`044ZL00<004ZLBY`04DZL00<004jKCY/04TjK00<004jKCY/04TjK00<004jkC[/04Tjk00<005:k
D[/04e:k00<005:kD[/00e:k2`001E:k00<005:kD[/04e:k00<005JkE[/055Jk00<005KKE]/01000
45Jk00<005KKE]/04eKK10005U[K00<005[kF_/00U[k0`0045[K00<005[kF_/01E[k0`003U[k00<0
05lLGa`00elL0`0045lK00@005lL0000011O708000AO6`03001S?6<l00MS?003001S6f<K00aS6`03
001RnP0000YW6P03001S6f<K00aS6`03001g5P0000AkE@05001oM7mdOg@00003Og@01@00OgAoM7md
00000gmd00@007nCOi<000=oT`04001oTgnC0003Oi<01@00Oi=oTgnC00000WnC00L007nCOi=oT`00
Oi<00003Oi<01000Oi=oT`000gnC00@007nCOi<000=oTP030017?dLo00i7?`X000h^g`03001>oDkm
019>o@03001>oDkm00i>o@P0019C7@03001C7U<N00IC7PD000UC?P03001C?U<n00]C?PD000=C?P03
001CGe=O00UCG`@000MCG`03001?GdmO00I?G`D000U?G`04001?GdmOCel5000;Cgl40002Ool00`00
Oomoo`0QOol005eoo`<00=Eoo`<000040CL000000GP200040M/200021O`00`004QdB7@0200076Sd3
00089Uh4000><Wh4000>=Yd00`00>YdjW@0:>Yd6000@@Yd00`00@Ya2W00@@Y`00`00AYa6W003AY`;
0003AY`00`00BYa:W00@BY`00`00BYa:W00ABY`00`00CY]>V`0BCY/00`00CY]>V`0BCY/00`00C[]>
^`0CC[/00`00D[]B^`0?D[/9000@D[/00`00D[]B^`0DD[/00`00E[]F^`0BE[/4000DE[/00`00E]]F
f`0?E]/40002F]/00`00F]]Jf`0EF]/00`00F_/00002000CF]/00`00F_]Jn`02F_/3000AF_/01000
GaaO75lL0P004elK0P0045lL0P001UlK00<006<lHc`01F<l0P003F<K0P000f;j00<006LJIaX01VLJ
00<006<KHa/03V<K00<007]ENeD00W]E00<007mdOg@00Wmd00D007mdOgAoM000009oM003001oM7md
009oM004001oTgnC0003Oi<01000Oi=oT`000gnC00D007nCOi=oT`00009oT`04001oTgnC0002Oi<0
1@00Oi=oTgnC00000WnC00D007nCOi=oT`00009oT`04001oTWnBOi820005Acl:0005EUL00`00EUQF
F002EUP70008;]l00`00C_e>o@0BC_d00`00C_e>o@02C_d;0005D_`2000CDad01000DaiC7U<N1@00
3U<n00<005<nDch01U<n1@002E<n00<005=ODel015=O10002e=O00@004mOCem?G`D000e?G`D000]?
O`D000=?O`05001oogooOol0000ROol005eoo`03001oogoo0=Moo`<000030CL0000000<000@1f`80
00031O`0018M008B7@8000HJ?@03000RG@00008000PVGP@000`bOP03000fOCIm00@000/fW@03000j
WCZM00hjW@@000i2W@030012W4:L0112W0030016W4JL00e6W0X000e:W003001:W4ZL015:W003001>
VdjK019>V`03001>VdjK019>V`03001>^djk019>^`03001B^e:k00QB^`L000=BV`03001B^e:k01AB
^`03001B^e:k01=B^`03001F^eJk00eF^`D0009F^P03001F^eJk01AF^`03001FfeKK00]Ff`<000MJ
f`03001Jfe[K01=Jf`<001MJf`@001AJn`04001O7000000CGa/200000elK001O700=Ga`20009Ga/0
0`00HcaS?002Hc`2000>Ha/00`00H_YRnP03H_X00`00IaYW6P05IaX00`00Ha]S6`0>Ha/20004NeD0
0`00OgAoM002Og@01@00OgAoM7md00000Wmd00D007mdOgAoM00000=oT`07001oTgnCOi<007nC0000
17nC00@007nCOi<0009oT`05001oTgnCOi<00002Oi<01@00Oi=oTgnC00000WnC00L007nCOi=oT`00
Oi<00003Oi800`00Nk5k/@05000?EUL00`00EUQFF009EUP700000bkO001>o@09C_d?000AD_`00`00
DaeC7@0?Dad6000CDch01000DciC?U<n1@003U<n00<005=ODel010003U=O1@003TmO10000TmO00<0
04moCgl01Tmo1@002Dmo00@007ooOol0029oo`00GGoo00<007ooOol0fGoo0`0000@1=`000001^P80
00@1f`<000@B7@<000@J?@04000RGB9M8Ud300069Uh00`00;Wd^O@03000:<Wh00`00=WdfO@03=Wd4
0007=Yd00`00>YdjW@0?>Yd00`00?WdnO@050009@Yd00`00@Ya2W00@@Y`00`00AYa6W00AAY`00`00
BYa:W003BY`:0003BY`00`00BYa:W00ABY`00`00CY]>V`0BCY/00`00CY]>V`0BCY/00`00C[]>^`0B
C[/01000D[]B^e:k1`002e:K00<005:kD[/04e:k00<005:kD[/04e:k00<005JkE[/02EJk10001eJj
00<005JkE[/055Jk00<005KKE]/01eKK10002U[K00<005[KF]/045[K0`000U[K00<005[KF]/055[K
0P005e[k0P004UlK0`0015lK00<005lLGa`02ElL0P002elK00D006<lHcaS?00000iS6`8000IRnP03
001W6VLJ00AW6P03001S6f<K00iS6`03001SG00000AkE@03001oM7md009oM005001oM7mdOg@00002
Og@01@00OgAoM7md00000WnC00D007nCOi=oT`00009oT`05001oTgnCOi<00003Oi<01000Oi=oT`00
0gnC00@007nCOi<000=oT`03001oT`0000=oT`04001oTgnC0003Oi801000Nk5k/@004eIG00<005IH
EUP045IH30002UJj00<005;lD_`04e;l00<005<MDad025<M1`000eLM00<005<nDch04U<n1@004E<n
1@003E=O1@000U=O00<004mOCel02DmO1@001dmO00<004moCgl01@003Dmo0`000Woo00<007ooOol0
7goo001MOol00`00Oomoo`3JOol40000104g0000006j0`00107K0P001A8M0P000aXm00<0029M8Ud0
0b9M0`0012IN00<002im;Wd00Rim0`00239n00<003Im=Wd01SIm100013JM00<003ZM>Yd03cZM00<0
03im?Wd013im1@001D:M00<004:L@Y`044:L00<004JLAY`04DJL00<004ZLBY`034ZL3`0024ZL00<0
04jKCY/04TjK00<004jKCY/04TjK00<004jkC[/02Djk3@004U:K00<005:kD[/04e:k00<005:kD[/0
4e:k00<005JkE[/01EJk100035Jj00<005JkE[/04eJk00<005KKE]/00eKK10003U[K00<005[KF]/0
3E[K0`001E[K00<005[KF]/04E[K0`0000=Jf`00F_/04e[k0`0000=Nn`00Ga/03elK0P001elK00<0
05lLGa`025lL00<005lKGa/02elK00@006<l000000iS6`03001RnV;j00MRnP03001W6VLJ009W6P03
001S6f<K00eS6`8000=SG005001kEG]ENeD00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM000
009oT`05001oTgnCOi<00002Oi<01@00Oi=oTgnC00000gnC00@007nCOi<000=oT`03001oT`0000=o
T`04001oTgnC0003Oi<01000Oi=oT`000gnB00@007^aNk4001AFE`03001FF5IH015FF003001F^UJj
015F^P03001Bo5;l01=Bo004001C7E<MDad7000;Ead00`00DciC?P0<Dch50002Dch00`00DciC?P0<
Dch50003Del00`00DemCG`07Del50008Del00`00Cem?G`04Cel4000:Cel5000>Cgl40002Cgl01000
Oomoo`008Goo001MOol00`00Oomoo`3KOol800020KX200020M/010003O`000001A8M0P0000<J?@00
8Ud01b9M0P000bIN00<002im;Wd012im10001C9n00<003Im=Wd02CIm1@004CZM00<003im?Wd02Cim
1P004T:L00<004JLAY`04DJL00<004ZLBY`044ZL00<004ZKBY/024ZK?P002TjK00<005:KDY/04U:K
00<005:kD[/055:k00<005:kD[/04e:k00<005Jk0000100045Jj00<005JkE[/055Jk00<005KK0000
0P004e[K00<005[KF]/02E[K0`002E[K00<005[KF]/03U[K0P001E[K00<005[kF_/03e[k0P001Ekk
00<005lKGa/02elK0P002ElK00<005lLGa`01UlL0P003UlK0P003V<K0P002V;j00D006LJIaYW6P00
00mS6`03001SG6=L00=SG004001kEG]E0004Og@01@00OgAoM7md00000Wmd00D007mdOgAoM00000=o
T`05001oTgnCOi<00002Oi<01@00Oi=oTgnC00000gnC00<007nC00000gnC00@007nCOi<000=oT`04
001oTgnC0003Oi<01000Oi=oT`000WnB00<007^aNk400P0055IG00<005IHEUP04EIH00<005JjE[X0
4UJj00<005;lD_`045;l1P004eLM00<005<nDch01U<n1@0025<n00<005<nDch01U<n1@002E=O00@0
05=ODemCG`D000eCG`03001?GdmO00@000Y?G`@0009?O`03001?Odmo00U?O`D000M?O`04001oogoo
000POol005eoo`03001oogoo0=aoo`H000030GT000000081^P8000040M/000gl3O`200054Qd30009
8Ud300000bIN000^O@08;Wd30002<Wh00`00=WdfO@0==Wd5000>>Yd00`00?WdnO@0=?Wd5000>@Y`0
0`00AYa6W00AAY`00`00BYa:W00ABY`00`00BY]:V`0@BY/00`00CY]>V`0BCY/00`00CY]>V`0BCY/0
0`00CY]>V`0BCY/00`00DY]BV`0CDY/00`00D[]B^`0CD[/00`00D[]B^`0@D[/5000EE[X00`00E[]F
^`0BE[/4000FF]/00`00F]]Jf`06F]/3000<F]/00`00F]]Jf`0<F]/20007F]/00`00F_]Jn`0=F_/2
0007G_/00`00Ga]O6`09Ga/2000<Ga/00`00GaaO7003Ga`2000>Ga/200000elK001S6`0<Ha/00`00
H_YRnP0:H_X01000IaYW6P003V<K0P001f=L00<007]E000017md00D007mdOgAoM000009oM005001o
M7mdOg@00003Oi<01`00Oi=oTgnC001oT`0000=oT`05001oTgnCOi<00002Oi<01@00Oi=oTgnC0000
0WnC00D007nCOi=oT`00009oT`07001oTgnCOi<007nC00000gnB00<007^aNk400P0055IG00<005IH
EUP04UIH00<005JjE[X04EJj00<005;lD_`02e;l1@000UKl0P005ELM00@005<nDciC?PD000eC?P04
001C?U<nDch5000=Del5000ADel4000:Cel40007Cgl00`00Cgm?O`04Cgl4000:Cgl30002Ool00`00
Oomoo`0NOol005eoo`03001oogoo0=eoo`030000/`0000<00081N@040001^P6j0KX300033O`20006
4Qd2000:8Ud3000;;Wd4000?=Wd01000>WdjOCYm1@002CZM00<003im?Wd03Sim00@0049l@Wa2O0L0
00Q2W0030016W4JL0156W003001:W4ZL011:W003001:VdZK015:V`03001>VdjK019>V`03001>VdjK
019>V`03001>VdjK019>V`03001BVe:K019BV`03001B^e:k01=B^`03001B^e:k00UB^`L000=F^P03
001F^UJj01EF^P03001F^eJk00iF^`<0009F^P03001Jfe[K01EJf`03001Jfe[K00=Jf`<000mJf`03
001Jfe[K00UJf`<000YJf`03001Jne[k00UJn`<000UNn`03001O6elK00MO6`8000iO6`04001O75lL
Ga`2000?Ga/00`00Ga]O6`02Ga/00`00Ha]S6`08Ha/2000>H_X2000>Ha/00`00HeaSG007He`00`00
NeD00003Og@00`00OgAoM002Og@01000OgAoM0000gmd00@007nCOi<000=oT`04001oTgnC0003Oi<0
1@00Oi=oTgnC00000WnC00D007nCOi=oT`00009oT`07001oTgnCOi<007nC00000gnC00@007nCOi<0
00=oTP06001k/G^a00000@004eIG00<005IHEUP04UIH00<005JjE[X04EJj00<005;lD_`01U;l1@00
1eKl00<005Kl00004ULM1P004E<n1@003U=O10000U=O00<005=ODel035=O1@000TmO00<004mOCel0
1DmO10002dmo00<004moCgl010002Tmo10000Tmo00D007ooOomoo`0001moo`00GGoo00<007ooOol0
gWoo1`0000<1N@0000000`6j0P0010gl0P00118M00<001hm00000P002R9M0P0032im10003CIm00<0
03Ym>Wd01CYm1@001CZM00<003im?Wd03Sim00<0049l@W`01d9l1`0000=2W000AY`04TJL00<004ZL
BY`044ZL00<004ZKBY/04DZK00<004jKCY/04TjK00<004jKCY/04TjK00<004jKCY/04TjK00<005:K
DY/04U:K00<005:kD[/055:k00@005:kD[]B^`L000]F^P03001F^UJj01AF^P03001F^eJk00YF^`@0
00IF^P03001Jfe[K01EJf`03001Jf`00008001=Jf`03001Jfe[K00IJf`8000eJf`03001Jne[k00MJ
n`8000eNn`03001O6elK00=O6`<0011O6`04001O7000000?Ga/20005Ga/00`00Ha]S6`07Ha/00`00
H_YRnP0=H_X2000=Ha/2000:He`20004Og@01@00OgAoM7md00000gmd00D007mdOgAoM000009oT`05
001oTgnCOi<00002Oi<01@00Oi=oTgnC00000gnC00@007nCOi<0009oT`04001oTgnC0003Oi<01000
Oi=oT`000gnC00@007nCOi<000=oTP03001k/@0000800@03001FEeIG015FE`03001FF5IH019FF003
001F^UJj019F^P03001Bo5;l00D000aFo003001Fo00000eG7@D000=G7@03001C?U<n00aC?PD0009C
?P03001CGe=O00UCG`D000MCG`03001CGe=O00ICG`D000Q?G`03001?GdmO00@000i?O`@000Y?O`@0
00M?O`04001oogoo000OOol005eoo`03001oogoo0>1oo`030000/`0000@000030GT0000000<1^P80
00@=o08000<B7@04000N?Ahm7Sd300078Ud00`00:Ud00002000:;Wd00`00<WdbO@040009=Wd00`00
>WdjO@0:>Wd6000@?Wd00`00@Wa2O00>@W`7000?AY`00`00BYa:W00@BY`00`00BY]:V`0@BY/00`00
CY]>V`0BCY/00`00CY]>V`0BCY/00`00CY]>V`0BCY/00`00DY]BV`0CDY/00`00D[]B^`0@D[/7000B
E[X00`00E[YF^P0DE[X00`00E[]F^`07E[/3000:E[X00`00F]]Jf`0DF]/3000FF]/00`00F]]Jf`04
F]/2000?F]/00`00F_]Jn`05F_/2000?G_/01000Ga]O6elK0P004elK0P003elK0P0025lK00<006<K
Ha/016<K0P003f;j00<006=M000036<K00<006=LHe`02V=L0P0017md00D007mdOgAoM000009oM005
001oM7mdOg@00003Oi<01@00Oi=oTgnC00000WnC00D007nCOi=oT`00009oT`04001oTgnC0003Oi<0
1000Oi=oT`000gnC00@007nCOi<000=oT`03001oT`0000=oTP04001k/G^a000200400`00EUMFE`0A
EUL00`00EUQFF00BEUP00`00E[YF^P0@E[X5000AE_`00`00E_`00008Ead50009Ead00`00DciC?P06
Dch50008Dch00`00DemCG`04Del4000<Del01000DemCGe=O1@002dmO1@003Dmo1@000Tmo00<004mo
Cgl01Dmo10002dmo00D007ooOomoo`0001ioo`00GGoo00<007ooOol0hGoo1`000P5i0P0000<1^P00
1M`00P0010gl0P000Q8M00<001hm7Sd00ahm0`001B9M00@002YM:UdZG@<000P^O@03000bOC9m00<b
O@@000HfO@03000jOCYm00hjO@@000hnO@030012O49l00m2O0030016O4Il0096O0L000Q6W003001:
W4ZL011:W003001:VdZK015:V`03001>VdjK019>V`03001>VdjK019>V`03001>VdjK019>V`03001B
Ve:K019BV`03001B^e:k00UB^`L000=BVP03001F^UJj01=F^P03001F^UJj01AF^P03001F^eJk00=F
^`@000eF^P03001Jfe[K015Jf`<00003F[X005[K01IJf`04001Jfe[KF]/3000BF]/01000F_]Jne[k
0`004Ekk00@005lK000001=O6`800003Ga/005lK00aO6`8000YO6`03001S6f<K00=S6`03001RnV;j
00eRnP8000=SG@03001S6f<K00MS6`8000aSG003001SO@0000AoM005001oM7mdOg@00002Og@01@00
OgAoM7md00000gnC00L007nCOi=oT`00Oi<00003Oi<01@00Oi=oTgnC00000WnC00D007nCOi=oT`00
009oT`07001oTgnCOi<007nC00000gnC00@007nCOi<000=oTP04001k/G^a000200400`00EUMFE`0B
EUL00`00EUQFF00AEUP00`00E[YF^P0;E[X50002E]/00`00E_aFo00AE_`01000E_aFo0000ULM1@00
3ULM00@005<nDciC?PD000eC?P03001CGe=O00@000mCG`D000]?G`D000=?O`03001?Odmo00M?O`D0
00Q?O`03001?Odmo00@000i?O`<0009oo`03001oogoo01aoo`00GGoo00<007ooOol0hgoo00<0002c
000010000P5i0`000PGL0P0010gl0`0021hm0P00129M00<002YM:Ud00bYM0`001Bim00<0039m<Wd0
1c9m0`0013Im00<003Ym>Wd03SYm00<003il?W`010002cim00<0049l@W`03d9l00<004IlAW`024Il
1`0000=6W000BY`04TZL00<004ZKBY/044ZK00<004jKCY/04TjK00<004jKCY/04TjK00<004jKCY/0
4TjK00<005:KDY/04U:K00<005:kD[/00U:k1`002e:J00<005JjE[X04eJj00<005JjE[X055Jj00<0
05Jk00000P004UJj00<005[KF]/03E[K0`001EZj00<005[KF]/05E[K0`005E[K00@005[k000001AN
n`8001=O6`8000AO6`03001O6elK00UO6`03001O6elK00]O6`03001S6f<K008000mRnP03001SGF=M
00=SG@03001S6f<K00IS6`03001SG6=L00YSG08000=SO@04001oM7md0003Og@01@00OgAoM7md0000
0gmd00@007nCOi<000=oT`04001oTgnC0003Oi<01@00Oi=oTgnC00000WnC00L007nCOi=oT`00Oi<0
0003Oi<01000Oi=oT`000gnC00@007nCOi<000=oTP03001k/@0000<00@03001FEeIG019FE`03001F
F5IH019FF003001F^UJj00EF^PD000QFf`03001Fo5Kl015Fo0D0019G7@D0015C?P@000mCG`@0009C
G`03001?GdmO00I?G`D000U?O`04001?OdmoCgl5000;Cgl5000=Cgl50002Cgl01@00Oomoogoo0000
7Goo001MOol00`00Oomoo`3TOol800020GT200031M`200043O`200097Sd300000b9M000ZG@07:Ud2
0004;Wd00`00<WdbO@09<Wd5000A>Wd00`00?W`nO003?W`40007?Wd00`00@Wa2O00?@W`00`00AWa6
O00?AW`8000=BY`00`00BY]:V`0ABY/00`00CY]>V`0ACY/00`00CY]>V`0BCY/00`00CY]>V`0BCY/0
0`00DY]BV`0>DY/9000BDYX00`00E[YF^P0CE[X00`00E[YF^P0BE[X4000EE[X00`00F]]Jf`0:F]/3
0008F[X00`00F]]Jf`0DF]/2000GF]/2000DG_/200000ekk001O6`0@Ga/20006Ga/00`00Ga]O6`07
Ga/2000>Ga/00`00Ha/0000?H_X20006Hed00`00Ha]S6`04Ha/2000;He`20005Hgd01000OgAoM000
0gmd00@007mdOg@000AoM004001oTgnC0003Oi<01000Oi=oT`000gnC00D007nCOi=oT`00009oT`04
001oTgnC0002Oi<01@00Oi=oTgnC00000WnC00D007nCOi=oT`00009oT`04001oTWnB0002Nk401@00
00400@01000055IG00<005IHEUP04UIH00<005JjE[X01@003EKK00<005KlE_`03EKl1@0000=G7@00
Ead03eLM10000ULn00<005<nDch03E<n10000U=O00<005=ODel02E=O1@001e=O00<004mOCel01@00
3Dmo1@002dmo1@000dmo00<004moCgl01dmo1@0024mo00@007ooOol001eoo`00GGoo00<007ooOol0
iWoo00<0002c00000P0000@1F0000001N@8000@5g0<000<=o08000XN?@<000TZG@<0008^O@03000b
OC9m00`bO@@000hjO@03000nO3il00LnO0@000@nO@030012O49l00m2O0030016O4Il0116O0030016
NdIk00=6N`X000=:W003001:VdZK015:V`03001>VdjK019>V`03001>VdjK019>V`03001>VdjK019>
V`03001BVe:K009BV`/000EBVP03001BVU:J01=BVP03001F^UJj01=F^P03001F^UJj00iF^P@0009F
^P03001F^UJj01EF^P03001Jfe[K00IJf`<000]J^P03001Jfe[K015Jf`<00003F]X005[K01=Jf`<0
0003G_/005kk015Nn`8000ANn`03001O6elK00aO6`8000QO6`03001O6elK00EO6`80011O6`8000mR
nP03001SGF=M00MSG@03001S6f<K009S6`03001SG6=L00YSG003001SOF=m00ISO@03001oM00000=o
M004001oM7md0003Og@01@00Oi=oTgnC00000gnC00@007nCOi<000=oT`04001oTgnC0002Oi<01@00
Oi=oTgnC00000WnC00D007nCOi=oT`00009oT`07001oTgnCOi<007nC00000gnB00@007^aNk4000<0
0@03001FEeIG019FE`03001FF5IH011FF0D001=Ff`03001Fo5Kl00QFo0@000AG7@04001G7ELM000:
Ead50007Ech00`00DciC?P08Dch40007Del00`00DemCG`04Del4000:Del5000>Cgl40002Cgl00`00
Cgm?O`06Cgl50009Cgl01000Cgm?Odmo1@002dmo10000Woo00<007ooOol06Woo000NOol4000>Ool3
000=Ool6000GOol00`00Oomoo`3WOol60000105H0001N@5i0P001@GL0P000Pgl10002Qhm0P002RYM
0`003c9m00<003Ym>Wd00`0033Ym00<003il?W`02Sil1@004T9l00<004IlAW`044Il00<004IkAW/0
34Ik3`0024ZK00<004jKCY/04TjK00<004jKCY/04TjK00<004jKCY/03DjK2P004E:J00<005:JDYX0
4e:J00<005JjE[X04eJj00<005JjE[X025Jj1@001eJj00<005JjE[X055Jj00<005[KF]/00e[K0`00
3eZj00<005[KF]/03E[K0`001E[J00<005[KF]/03e[K0P001Ekk00<005kkG_/03Ekk0P001Ukk00<0
05lKGa/02ElK0`002elK00<005lKGa/00UlK0P0045lK0P0000=Nn`00H_X036;j0P002V=M00<006<K
Ha/00P002f=L0P002F=m0P0017md00@007mdOg@000=oM005001oTgnCOi<00003Oi<00`00Oi<00003
Oi<01@00Oi=oTgnC00000WnC00D007nCOi=oT`00009oT`07001oTgnCOi<007nC00000gnC00@007nC
Oi<000=oTP03001k/@0000@00@03001FEeIG019FE`03001FF5IH00aFF0@0009J^P03001FfeKK01=F
f`03001Fo5Kl00AFo0@000QG7@04001G7ELM0006Ead4000<Ech00`00DciC?P04Dch4000;Del00`00
DemCG`04000:Del40002Cgl00`00Cgm?O`09Cgl50007Cgl00`00Cgm?O`05000<Cgl6000;Cgl50003
Cgl01000Oomoo`0077oo000LOol8000;Ool5000:Ool:000DOol00`00Oomoo`3ZOol010000;<0004g
100000@1N@00000000D5g08000043O`001XM6Qd200087Sd00`009Sd00002000::Ud3000=<Wd00`00
>WdjO@02>Wd30009>Wd00`00?W`nO00>?W`5000>@W`00`00AWa6O00@AW`00`00AW]6N`0@AW/00`00
BW]:N`08BW/E0008CY/00`00CY]>V`0BCY/00`00CY]>V`03CY/:0005CYX00`00DYYBVP0CDYX00`00
DYYBVP0CDYX00`00E[YF^P0CE[X00`00E[YF^P04E[X4000<E[X00`00E[YF^P0DE[X00`00F]]Jf`03
000BF[X00`00F]]Jf`0;F]/20008F]X00`00F]]Jf`0<F]/30007G_/00`00G_]Nn`0;G_/20009G_/0
0`00Ga]O6`06Ga/2000>Ga/01@00Ga]O6elK000045lK0P0015kk00<006;jH_X02F;j00<006=MHed0
2V=M00<006<K00002f=L0P002f=m0P000gmd00D007mdOgAoM00000=oM004001oTgnC0003Oi<01000
Oi=oT`000gnC00D007nCOi=oT`00009oT`07001oTgnCOi<007nC00000gnC00@007nCOi<000=oT`04
001oTgnC0002Oi801000Nk5k/@00100100<005IGEUL04UIG00<005IHEUP025IH10001eZj00<005KK
E]/04UKK00<005KlE_`0100035LM00@005LMEad0009G7@@0011G?P03001C?U<n00@000iCG`@000YC
G`@000M?O`03001?Odmo00A?O`@000Y?O`D000a?O`D000=?O`03001?Odmo00I?O`D000U?O`04001o
ogoo000KOol001aoo`8000Aoo`8000]oo`D000Yoo`<000Eoo`<001=oo`03001oogoo0>]oo`@00003
0CL0005H00<000030K/0000000D5g0<000<J7@8000LN?@04000V?BHm9Sd20008:Ud00`00<UdbG@03
000;<Wd00`00>WdjO@04>Wd40005>Wd00`00?W`nO00??W`01000@Wa2O49l1`00249l00<004IlAW`0
3dIl00<004IkAW/04DIk00<004YkBW/044Yk00<004ikCW/02Dik8`0044jJ00<005:JDYX04U:J00<0
05:JDYX04e:J00<005JjE[X04eJj00<005JjE[X0100045Jj00<005JjE[X055Jj0`005EZj00<005[K
F]/025[K0`002U[J00<005[KF]/02U[K0P002Ukk00<005kkG_/025kk0`002ekk00<005lKGa/015lK
0P0045lK00@005lK0000011O6`03001Nnekk00ANn`03001RnV;j00MRnP8000eSG@8000]SG003001S
OF=m00YSO@03001SO@0000=oM004001oM7md0003Og@01@00Oi=oTgnC00000gnC00@007nCOi<000=o
T`05001oTgnCOi<00002Oi<01000Oi=oT`000WnC00D007nCOi=oT`00009oT`07001oTgnCOi<007nC
00000gnB00@007^aNk4000D00@03001FEeIG019FE`03001FF5IH00=FF0@000]J^P03001FfeKK015F
f`@0011G7@03001G7@0000<001=G?P@000iCG`@0009CG`03001CGe=O00ECG`@000]?O`03001?Odmo
00@000Y?O`@0009?O`03001?Odmo00M?O`D000U?O`03001?Odmo00D000a?O`<0009oo`03001oogoo
01Uoo`006goo0P001Woo0P002Woo1@004goo0P004goo00@007ooOomoo`D00>Ioo`@000040CL00000
0EP200020K/200051M`200046Qd300047Sd00`009SdV?@039Sd20007:Ud00`00<UdbG@02<Ud30008
<Wd00`00>WdjO@08>Wd30003>Wd00`00?W`nO00??W`00`00@Wa2O007@W`700000d9l0016O00AAW`0
0`00AW]6N`0@AW/00`00BW]:N`0ABW/00`00CW]>N`0ACW/00`00CYY>VP0BCYX00`00CYY>VP0BCYX0
0`00DYYBVP0CDYX00`00DYYBVP0CDYX00`00E[YF^P0@E[X5000EE[X00`00E[YF^P0@E[X300000eZj
001J^P0FF[X00`00F]]Jf`05F]/2000>F]X00`00F]]Jf`07F]/2000=G_/00`00G_]Nn`05G_/2000?
G_/01000Ga]O6elK0P004UlK0P0045lK0P001ekk00<006;jH_X01V;j00<006=MHed02f=M0P0000=O
O@00He`026=L0P002f=m0P000f=m00@007mdOg@0009oM005001oM7mdOg@00003Oi<01@00Oi=oTgnC
00000WnC00D007nCOi=oT`00009oT`04001oTgnC0003Oi<01000Oi=oT`000gnC00@007nCOi<0009o
T`04001oTgnC0003Oi800`00Nk40000600400`00EUMFE`0BEUL00`00EUP00003000?F[X00`00E]]F
f`0>E]/30002F_`00`00EaeG7@0>Ead30002Ech00`00EciG?P0>Ech40002Eeh00`00DemCG`09Del4
0007Del00`00DemCG`04000>Cgl4000:Cgl40007Cgl01000Cgm?Odmo1@0034mo1@0034mo1@000T]o
00D007ooOomoo`0001Yoo`006goo0P001Woo0P002goo0`005Goo0P004Woo1000kGoo100000<1=`00
00000P000`6k0P001@GL0P001AXM0P000ahm00<002Hm9Sd012Hm0`0012YM00<0039M<Ud01C9M1000
1C9m00<003Ym>Wd02SYm10004Cil00<0049l@W`03T9l1P003TIl00<004IkAW/044Ik00<004YkBW/0
4DYk00<004ikCW/04Tik00<004jJCYX04DjJ00<004jJCYX04TjJ00<005:JDYX04e:J00<005:JDYX0
4e:J00<005JjE[X02eJj1@000eJJ00<005JjE[X055Jj00<005JjE[X03EJj0`001EZj00<005ZjF[X0
55Zj00<005[KF]/00U[K0`0045[J00<005[KF]/015[K0`003ekk00<005kkG_/00ekk0P004Ekk00@0
05lK0000019O6`800003G_/005lK00eO6`8000YNn`03001RnV;j00=RnP8000eSG@03001OOEmm009O
O@03001SG6=L00ESG003001SOF=m00USO@8000ISO@03001oM000009oM005001oM7mdOg@00003Oi<0
1`00Oi=oTgnC001oT`0000=oT`05001oTgnCOi<00002Oi<01@00Oi=oTgnC00000WnC00L007nCOi=o
T`00Oi<00003Oi<01000Oi=oT`000gnB00<007^a00001P0100<005IGEUL04EIG0`0055Zj00<005KK
E]/02UKK0`001U[l00<005LMEad02ULM0`0000=G?P00Ech00eLn00<005LnEch02ELn10001eMN00<0
05=ODel015=O10002U=O10003Dmo1@000Tmo00<004moCgl01Dmo10002Tmo1@0034mo1@000T]o00<0
04moCgl01dmo1@0024]o00@007ooOol001Yoo`006Woo0P0027oo0P008Woo0P004Woo00<007ooOol0
kgoo0P0000H0mP000CL1=`000EP200030K/00`001M`5g0021M`010004O`000001AXM0P000Qhm00<0
02Hm9Sd01RHm0P000bYM00<0039M<Ud0239M0`000S9m00<003Ym>Wd03CYm10003cil00<0049l@W`0
3d9l00@004IkAW]6N`D000Y6O0030016NdIk0116N`03001:NdYk011:N`03001>Ndik019>N`03001>
VTjJ019>VP03001>VTjJ019>VP03001BVU:J019BVP03001BVU:J01=BVP03001F^UJj00IF^PD000UF
VP03001F^UJj01=F^P03001F^UJj00YF^P<000QJ^P03001J^UZj01AJ^P03001Jf`00008001=JfP03
001Jfe[K009Jf`80019Nn`04001NnekkG_/2000CG_/2000BGa/20004G_/00`00Ga]O6`09Ga/2000<
G_/00`00H_YRnP02H_X00`00HeeSG@0;Hed20005Ggd00`00HeaSG003He`2000;Hgd00`00HgeSO@06
Hgd20003Og@01@00OgAoM7md00000WnC00D007nCOi=oT`00009oT`05001oTgnCOi<00003Oi<01000
Oi=oT`000gnC00<007nC00000gnC00@007nCOi<000=oT`04001oTgnC0002Oi801000Nk5k/@001P01
00<005IGEUL03eIG0P0000=N^@00F[X055Zj00<005KKE]/01UKK10002E[l00<005LMEad01ULM1000
15Ln00<005LnEch00eLn00<005LnEch015Ln10002eMN00<005=ODel010002U=O10000U=o00<004mo
Cgl01dmo1@0024mo00<004moCgl010002Tmo10000T]o00<004moCgl01dmo1@0024]o00@004moCgm?
O`D000a;O`<0009oo`03001oogoo01Moo`006Woo0P0027oo0P008Woo0P004Woo00<007ooOol0l7oo
1@0000<1=`0000000`000P6k0P000`GL00<0017l4O`00P001AXM0`002RHm0P000RYM00<0039M<Ud0
2S9M10003cYm00<003il?W`010002cil00<0049l@W`0449l00<004IkAW/01DIk1@001DIl00<004Ik
AW/044Ik00<004YkBW/04DYk00<004ikCW/04Dik00<004jJCYX04TjJ00<004jJCYX04TjJ00<005:J
DYX04e:J00<005:JDYX04e:J00<005JjE[X01@003UJJ00<005JjE[X055Jj00<005JjE[X01UJj0`00
2eZj00<005ZjF[X055Zj0P005e[J10005Ekk0`004ekk0P0000=Nn`00Ga/03elK0P001Ukk00<005lK
Ga/01elK0P003Ukk00<006;jH_X00P0036=M0P0025mm00<006=LHe`00P002f=m0P002F=m0P000Wmd
00D007mdOgAoM00000=oT`05001oTgnCOi<00002Oi<01@00Oi=oTgnC00000gnC00@007nCOi<0009o
T`04001oTgnC0003Oi<01000Oi=oT`000gnC00<007nC00000gnB00@007^aNk4000H00@03001FEeIG
00eFE`8000=N^@03001J^UZj01=J^P03001FfeKK00=Ff`<000eJo003001G7ELM00=G7@<000QG?P03
001G?ULn00=G?P03001G?ULn00@000iGGP@000YCG`@000MCO`04001?OdmoCgl5000<Cgl4000:Cgl4
0007Bgl01000Cgm?Odmo1@0034]o1@0034]o1@000T]O00D007ooOomoo`0001Qoo`006Woo0P0027oo
0P008Woo0P004Woo00<007ooOol0lWoo0P0000@0mP000CL1=`8000030IX000000081^`800085g004
000Ao17l4O`200066Qd2000:9Sd3000?<Ud4000=>Wd00`00?W`nO003?W`40007?W`00`00@Wa2O00@
@W`00`00AW]6N`0:AW/6000BAW/00`00BW]:N`0ABW/00`00CW]>N`0BCW/00`00CYY>VP0ACYX00`00
CYY>VP0BCYX00`00DYYBVP0CDYX00`00DYYBVP0@DYX6000CEYX00`00E[YF^P0DE[X00`00E[YF^P03
E[X3000?F[X00`00F[YJ^P0@F[X300000eZj001JfP0EF]X2000GG_/2000CG_/20004G_/00`00Ga]O
6`0;Ga/20008G_/00`00Ga]O6`05Ga/2000AG_/2000<Hed2000:Ggd00`00He`0000;Hgd20009Hgd2
00001F>M001oM7md00000gmd00D007nCOi=oT`0000=oT`04001oTgnC0003Oi<01000Oi=oT`000WnC
00D007nCOi=oT`00009oT`07001oTgnCOi<007nC00000gnC00@007nCOi<000=oTP03001k/@0000L0
0@03001FEeIG00aFE`03001N^Eji00AN^@03001J^UZj01=J^P03001Ff`000080015Jo003001G7@00
008000]G?P03001G?ULn009G?P@000iGGP@0009CO`03001CGe=O00ECG`@000YCO`D000a?O`D0009?
O`03001?Odmo00E?O`@000Y;O`D000a;O`D0009;O`03001;Od]o00M;O`D000Q;G`04001oogoo000H
Ool001Yoo`8000Qoo`80029oo`80019oo`03001oogoo0?=oo`D00081=`040001VP6J00030K/30005
4O`300036Qd00`008Qd00002000:9Sd2000><Ud00`00=U`fG003000:>Wd00`00?W`nO007?W`40004
?W`00`00@Wa2O00?@W`00`00AW]6N`0?AW/5000?AW/00`00BW]:N`0@BW/00`00CW]>N`0BCW/00`00
CYY>VP0BCYX00`00CYY>VP0BCYX00`00DYYBVP0BDYX00`00DYYBVP09DYX70003DYX00`00EYYFVP0D
EYX00`00E[YF^P0CE[X00`00E[YF^P03000BF[X00`00F[YJ^P0=F[X30004F[X00`00F]YJfP0AF]X3
00000e[J001Nn`0DG_/200000ekk001Nn`0@G_/20006G_/00`00Ga]O6`09Ga/2000;G_/00`00Ga]O
6`03Ga/00`00G_]Nn`0@G_/2000<Hed00`00GgeOO@0:Ggd2000;Hgd00`00HgeSO@08Hgd00`00HieS
W@02Hid00`00Og@00003Og@01000Oi=oT`0017nC00<007nC00000gnC00D007nCOi=oT`00009oT`05
001oTgnCOi<00002Oi<01000Oi=oT`000WnC00D007nCOi=oT`00009oT`04001oTWnB0002Nk400`00
00400@0500400`00EUMFE`0:EUL20007G[T00`00F[YJ^P0BF[X3000BF_`4000>Ech00`00Ech00002
0002Eeh00`00EeiGGP09Eeh40007Dgl00`00DemCG`04000:Dgl40002Cgl00`00Cgm?O`07Cgl50008
Cgl00`00Cgm?O`040009Bgl50002Bgl00`00Bgm;O`07Bgl50008Bgl01000Bgm;Od]o1@002d]O1000
0Woo00<007ooOol05Goo000JOol20008Ool2000QOol2000COol00`00Oomoo`3dOol500020CL20000
0`6J000000030K/200074O`200026Qd010008QdR7B8M0P0022Hm00<002hm00000P00339M00<003IL
=U`00SIL0`0023Ym00<003il?W`02Sil1@004T9l00<004IkAW/03dIk00@004IkAW]6N`L000Q6N`03
001:NdYk015:N`03001>Ndik015>N`03001>VTjJ019>VP03001>VTjJ019>VP03001BVU:J01=BVP04
001BVU:JDYX7000;DYX00`00EYYFVP0CEYX00`00E[YF^P0BE[X4000EF[X00`00F[YJ^P0:F[X30008
F[X00`00F]YJfP0>F]X20005F]X00`00G_]Nn`0@G_/20004G_/00`00G_]Nn`0<G_/20008G_/00`00
Ga]O6`08Ga/00`00G_]Nn`0;G_/01000Ga]O6elK0P004Ekk0P0000=SO@00Hed02F=M0P002emm0P00
00=OO@00Hgd026=m0P002F=m0P001F>M0P0017md00@007nCOi<000=oT`04001oTgnC0003Oi<01@00
Oi=oTgnC00000WnC00L007nCOi=oT`00Oi<00003Oi<01000Oi=oT`000gnC00<007nC00000gnB00@0
07^aNk4000L00@03001FEeIG00QFE`8000UN^@03001J^UZj00mJ^P<00003F_`005[l00mJo0<0009K
?@03001G?ULn00]G?P@000IGGP03001GGUMN00AGGP@000YCO`@000YCO`@000M?O`04001?OdmoCgl5
000<Cgl40008Bgl50008Bgl01000Bgm;Od]o1@0034]o1@002d]O1@000d]O00@007ooOol001Moo`00
6Woo0P0027oo0P006Goo0P001Goo0`004goo00<007ooOol0mGoo1`0000@1F@000IX1VP8000<1^`80
00LAo08000036Qd0028M00<R7@<000HV?@04000^?Bhm;Sd30009<Ud00`00=U`fG005=U`30005>Wd0
0`00?W`nO00>?W`5000>@W`00`00AW]6N`0@AW/00`00AW]6N`07AW/700000dIk001:N`0BBW/00`00
CW]>N`0BCW/00`00CYY>VP0ACYX00`00CYY>VP0BCYX00`00DYYBVP0>DYX9000BDYX00`00EYYFVP0C
EYX00`00E[YF^P0>E[X40002EYX00`00F[YJ^P0EF[X00`00F[YJ^P06F[X3000;F[X00`00F]YJfP0<
F]X20007F]X00`00G_]Nn`0>G_/20006G_/00`00G_]Nn`0:G_/2000;G_/00`00Ga]O6`05Ga/2000>
G_/01000Ga/000004Ekk0P0016=m00<006=MHed01F=M0P002emm0P0015mm00<006=mHgd01F=m00<0
06=mHgd01f=m0P001f>M0P000gmd00D007nCOi=oT`0000=oT`04001oTgnC0003Oi<01`00Oi=oTgnC
001oT`0000=oT`04001oTgnC0003Oi<01000Oi=oT`000WnC00@007nCOi<000=oTP03001k/@0000P0
0@03001FEeIG00IFE`8000aN^@03001J^UZj00]J^P<000EJo003001Jo5[l00YJo0<000IK?@03001G
?ULn00MG?P<0009GGP03001GGUMN00EGGP03001GGUMN00@000]CO`<0009CO`03001COe=o00ECO`@0
00Y?O`D000a?O`D000=;O`04001;Od]oBgl5000<Bgl5000<Bgl50002Bgl00`00Bem;G`06Bel50008
Bel01@00Oomoogoo00005Woo000JOol20008Ool2000IOol9000DOol00`00Oomoo`3gOol600000`5I
000000020IX200000`6k000=g00200074O`300068Qd200059Sd00`00;Sd^?@03;Sd30007<Ud00`00
=U`fG007=U`30003>Wd00`00?W`nO00>?W`01000@Ua2G49L1@002T9l00<004IkAW/03dIk00<004Ik
AW/03TIk3@0024Yk00<004ikCW/04Tik00<004jJCYX04DjJ00<004jJCYX04djJ00<005:JDYX00U:J
2`001E:J00<005:JDYX04e:J00<005JJEYX055JJ00<005JjE[X025Jj1@001UJJ00<005ZjF[X05EZj
00<005ZjF[X00eZj0`003UZj00<005[JF]X02E[J0`002E[J00<005kkG_/035kk0P0025kk00<005kk
G_/025kk0P003Ekk00<005lKGa/00elK0P0045kk0P004Ukk00<006=mHgd016=m00<006=MHed00f=M
0P002emm0P001Umm00<006=mHgd00f=m0P0026=m0P001f>M0P0000=SW@00Og@00Wmd00D007nCOi=o
T`0000=oT`04001oTgnC0003Oi<01000Oi=oT`000WnC00D007nCOi=oT`00009oT`07001oTgnCOi<0
07nC00000gnC00@007nCOi<000=oTP03001k/@0000T00@03001FEeIG00=FE`8000iN^@03001J^UZj
00QJ^P<000QJo003001Jo5[l00IJo0@000UK?@03001G?ULn00=G?P@000EGGP03001GGUMN00AGGP@0
00aCO`<000ICO`03001COe=o00@000Y?O`@0009?O`03001?Odmo00M?O`D000M;O`D000a;O`D0009;
O`03001;Od]o00M;O`D000Q;O`03001;Gd]O00D000i;G`04001oogoo000FOol001Yoo`8000Qoo`80
01Uoo`800003Ool0000000<001Eoo`03001oogoo0?Qoo`8000040=D0000000020ET200020IX30002
3M`200074O`200078Qd300039Sd00`00;Sd^?@05;Sd30004<Ud00`00=U`fG00:=U`4000A?W`00`00
@Ua2G005@U`50005@W`00`00AW]6N`0?AW/00`00AW]6N`0@AW/00`00BW]:N`08BW/E0008CW/00`00
CYY>VP0BCYX00`00CYY>VP08CYX?000@DYX00`00DYYBVP0DDYX00`00EYYFVP0CEYX00`00E[YF^P04
E[X4000<EYX00`00F[YJ^P0DF[X00`00F[YJ^P03000BF[X00`00F]YJfP06F]X2000=F]X00`00G_]N
n`08G_/3000;G_/00`00G_]Nn`05G_/2000?G_/01000Ga]O6elK0P0045kk0P0000=Nn`00G_/03ekk
0P0026=m00D006=MHeeSG@0000]OO@8000UOO@03001SOF=m008000USO@03001SWF>M00ISW@03001S
WF>M009SW@04001oM7md0002Oi<01@00Oi=oTgnC00000WnC00D007nCOi=oT`0000=oT`04001oTgnC
0003Oi<01000Oi=oT`000WnC00@007nCOi<000=oT`04001oTgnC0002Oi801000Nk5k/@002@0100<0
05IGEUL00UIG00<005jiG[T03Uji00<005ZjF[X01EZj0`002e[l00<005[lF_`00e[l0`003E/m00<0
05LnEch00`002EMN00@005MNEeiGGP<0009CO`03001COe=o00MCO`@000QCO`@000Y?O`@000M?O`04
001?OdmoCgl50008Bgl40002Bgl00`00Bgm;O`07Bgl50008Bgl01000Bgm;Od]o1@002d]o1@0044]O
10000goo00<007ooOol04goo000KOol20006Ool2000JOol2000KOol00`00Oomoo`3iOol600030ET0
10000IX1VP6J0P000`gL0P001a7l0P00228M0P0000<V?@00;Sd02Bhm0`000S9M00<003IL=U`033IL
10003Sil00<0049L@U`02T9L1P004TIk00<004IkAW/044Ik00<004YkBW/044Yk00<004ijCWX02Dij
:0002U9j00<005:JDYX04e:J00<005:JDYX04e:J00<005JJEYX04eJJ00<005JjE[X0100045JJ00<0
05ZjF[X04eZj10005EZj00<005[JF]X015[J0P003e[J00<005kkG_/01Ukk0P003Ukk00<005kkG_/0
0ekk0P004Ukk0`004Ekk00<005kkG_/00Ukk00<005kkG_/02ekk0P002V=m00@006=M000000YOO@80
00]OO@03001SO@0000USO@8000MSW@8000ISW@8000=oT`05001oTgnCOi<00002Oi<01@00Oi=oTgnC
00000gnC00@007nCOi<0009oT`04001oTgnC0003Oi<01000Oi=oT`000gnC00<007nC00000gnB00<0
07^a00002P0100<005IGEUL00P004Eji00<005ZjF[X00UZj0`003e[l00<005[l00000P003e/m1000
35MN10001U=o00<005=oDgl00e=o0`002E=o0`000Tmo00<004moCgl01Dmo10002Tmo1@002D]o1000
1d]o00@004]oBgm;O`D000a;O`D000];O`D00097O`03001;Gd]O00U;G`L000=;G`05001oogooOol0
000EOol001]oo`8000Ioo`8001Yoo`8001]oo`03001oogoo0?]oo`8000040=D0000000020ET20002
0IX200043M`200054O`010007Q`00000228M0`0032hm0`003cIL00<003YL>U`00`0033il00<0049L
@U`03T9L1@003TIk00<004IkAW/044Ik00<004YkBW/04DYk00<004ijCWX04Dij00<004ijCWX04Dij
00<0059jDWX04U9j00<005:JDYX04e:J00<005:JDYX04e:J00<005JJEYX04UJJ100055JJ00<005Zj
F[X045Zj0`000UZj00<005ZjF[X055Zj00@005[JF]YJfP<0019JfP03001Nnekk00=Nn`80011Nn`04
001NnekkG_/2000CG_/2000AG_/20005G_/00`00G_]Nn`09G_/2000<Hgd2000;Ggd00`00GgeOO@0;
Ggd20008Hgd20007Hid20008Hid20003Oi<01@00Oi=oTgnC00000WnC00D007nCOi=oT`0000=oT`03
001oT`0000=oT`04001oTgnC0003Oi<01000Oi=oT`000WnC00@007nCOi<000=oTP03001k/@0000X0
0@<001AN^@@0015Jo0<000mK?@<0009GGP03001GGUMN00QGGP@000UCO`03001COe=o00<000UCO`<0
00I?O`03001?Odmo00@000Y?O`@0009;O`03001;Od]o00E;O`@000Y;O`D000a;O`D00097O`03001;
Od]o00I;O`D000Q7O`04001;Gd]OBel7000;Bel01@00Oomoogoo000057oo000LOol20004Ool2000K
Ool2000JOol00`00Oomoo`3mOol600030ET010000IX1VP6J0P0010gL00<0017l4O`00a7l00<001hL
7Q`00P002B8M0P003Bhm0P003SIL00<003YL>U`00SYL0`002Cil00<0049L@U`03d9L00@0049K@U]2
F`D000Y6N`030016NdIk00m6N`03001:NdYk015:N`03001>NTij015>NP03001>NTij015>NP03001B
NU9j01=BNP03001BVU:J019BVP03001BVU:J01ABVP03001FVUJJ00eFVP@0009FV@03001FVUJJ01AF
VP03001J^UZj00aJ^P<000EJ^P03001J^UZj01EJ^P<001EJfP04001NnekkG_/2000CG_/3000CG_/2
00000ekk001Nn`0>G_/20007G_/00`00G_]Nn`07G_/2000<Hgd200000emn001OO@08Ggd2000;Ggd3
00000emn001SO@05Hgd20007Hid20008Hid20002Hid01000Oi=oT`000gnC00<007nC000017nC00@0
07nCOi<0009oT`05001oTgnCOi<00002Oi<01`00Oi=oTgnC001oT`0000=oT`04001oTgnC0002Oi80
1000Nk5k/@002P0100<005jiG[T04eji0P004E[l0`0000=KG@00Fcd035/m0`001UMN00<005MNEeh0
15MN0`000e=o00<005=oDgl01U=o100025=o100024mo10002Tmo10001d]o00<004]oBgl010002D]o
1@000TMo00<004]oBgl01d]o1@0024Mo00<004]oBgl01@002dMo1P0044]O10000Woo00<007ooOol0
4Woo000LOol8000KOol:000BOol00`00Oomoo`3nOol30000103E000000000P5I0P0000<1VP001K/0
0P000`gL0P000a7l00<001hL7Q`00QhL0P001b8M00<002Xl00000P002Rhm00<0038l00000P002cIL
00<003YL>U`01CYL10001Cil00<0049L@U`0449L00<0049K@U/01D9K1@001DIk00<004IkAW/044Ik
00<004YkBW/044Yk00<004ijCWX04Tij00<004ijCWX04Dij00<0059jDWX04U9j00<005:JDYX04e:J
00<005:JDYX04e:J00<005JJEYX025JJ1@001UJI00<005JJEYX055JJ00<005ZjF[X02EZj0`002EZj
00<005ZjF[X04eZj0P005e[J00@005kk000001ANn`8001=Nn`8000ANn`03001Nnekk00YNn`8000YN
n`03001Nnekk00ANn`8000aSO@8000AOOP03001OOEmm00AOO@8000]OO@8000EOOP03001SOF=m009S
O@03001SWF>M00ISW@03001SWF>M00MSW@03001SWF>M00=SW@8000=oT`04001oTgnC0003Oi<01@00
Oi=oTgnC00000WnC00L007nCOi=oT`00Oi<00003Oi<01000Oi=oT`000gnC00<007nC00000gnB00<0
07^a00002`0100<005jiG[T04Eji0P0000=O?000F_`03U[l0P001E]M00<005/mFcd01U/m10002UMN
00<005MNEeh00`001U=o00<005=oDgl00U=o10000U=o00<005=oDgl015=o0`0024mo10000T^O00<0
04moCgl01Dmo10002T]o100024]o1@0024Mo00@004]oBgm;O`D000Y7O`H000U7O`L000=7G`03001;
Gd]O00U;G`L000=7G`05001oogooOol0000COol001ioo`@001eoo`X0019oo`03001oogoo0?moo`<0
0080e@<00081F@030001VP000085^`03000=g0gL008=g080008Ao003000N71hL00<N70<000DR7@04
000Z?2Xl:S`20009;Sd01000<S`b?38l0`002CIL00<003YL>U`023YL0`000cil00<0049L@U`03d9L
00<0049K@U/02T9K1P004TIk00<004YkBW/04DYk00<004ijCWX04Dij00<004ijCWX04Dij00<0059j
DWX04U9j00<005:JDYX04e:J00<005:JDYX04e:J00<005JJEYX015JJ100035JI00<005JJEYX04eJJ
00<005ZjF[X01UZj0`0035Zj00<005ZjF[X045Zj0`0000=J^P00F]X05U[J0P0055kk0P0000=Nn`00
G_/045kk0P001Ukk00<005kkG_/02Ekk00<005kkG_/02Ukk00<005kkG_/00ekk00<006=mHgd02V=m
0P001emn00@005mmGgeOO@8000]OO@8000QOOP04001SO@000007Hid20008Hid20006Hid20003Oi<0
1000Oi=oT`000gnC00D007nCOi=oT`00009oT`04001oTgnC0002Oi<01@00Oi=oTgnC00000WnC00L0
07nCOi=oT`00Oi<00003Oi800`00Nk40000:0042000AG[T20003Gc`00`00F_aJo00:F_`30007Fed0
0`00FceK?@03Fcd3000=Eeh40009Dgl50007Dgl00`00DgmCO`030007Cgl40007Bil00`00Cgm?O`04
0009Bgl50003Agl01000Bgm;Od]o1@0034Mo1@0024Mo1`0014Mo00@004MoAgm7O`L000]7G`04001;
Gd]OBel7000;Ael01000Oomoo`004goo001KOol00`00Oomoo`3oOol2Ool30000103E000000000P5I
0`000PFk0P0010gL0P0000<Ao0007Q`01QhL0P000b8M00<002Xl:S`00bXl0P001bhm00<0038l<S`0
138l0`001SIL00<003YL>U`02cYL10004D9L00<0049K@U/03d9K1@003TIk00<004YkBW/04DYk00<0
04ijCWX04Dij00<004ijCWX04Dij00<0059jDWX04e9j00<005:JDYX04U:J00<005:JDYX055:J00<0
05JJ00000`0045JI00<005JJEYX04eJJ00<005ZjF[X00eZj0`003eZj00<005ZjF[X03UZj0P001EZj
00<005[JF]X04U[J0P0000=NfP00G_/04Ekk0P0015kk00<005kkG_/035kk0P0025kk00<005kkG_/0
1ekk0P003Ekk00@005kkG_]Nn`8000]SO@8000UOOP04001OO@00000:Ggd3000:Ggh20007Hid20008
Hid20007Hid00`00Hkd00003Oi<01000Oi=oT`000gnC00L007nCOi=oT`00Oi<00003Oi<01000Oi=o
T`000gnC00<007nC00000gnC00@007nCOi<0009oTP04001k/G^a000900401000Ho]Sn`003eji00<0
05llGc`015ll00<005[lF_`01e[l0P002U]M00<005/mFcd00`003EMN0`000UMo00<005=oDgl01E=o
10002U=o10001Tmo10002T^O100024]o1@001dMo1@0034Mo1@000TMo00@004MoAgm7O`L000Y7O`D0
0117G`H000m7G`@000=oo`03001oogoo011oo`00Fgoo00<007ooOol0ogoo0goo100000@15`000000
0081F@8000<5^`8000@=g08000TN7080008R7@03000Z?2Xl00@Z?0<000D^?@03000b?38l00Hb?080
00@fG003000jG3YL00hjG0@000m2G0030012Fd9K00m2F`040016FdIKAU/5000:AW/00`00BW]:N`0@
BW/00`00CWY>NP0BCWX00`00CWY>NP0ACWX00`00DWYBNP0BDWX00`00DYYBVP0CDYX00`00DYYBVP0@
DYX5000DEYT00`00EYYFVP0DEYX00`00F[X00002000BF[X00`00F[YJ^P0<F[X20007F[X00`00F]YJ
fP0@F]X20004G]X00`00G_]Nn`0=G_/20006G_/00`00G_]Nn`0:G_/2000;G_/00`00G_]Nn`04G_/2
000@G_/3000;Hgd2000;Ggh2000:Ggd2000;Ggh200000emn001SW@04Hid20008Hid20007Hid20003
Hkd01P00Oi=oT`00Oi<000=oT`05001oTgnCOi<00002Oi<01@00Oi=oTgnC00000WnC00L007nCOi=o
T`00Oi<00003Oi<01000Oi=oT`000WnB00<007^a00002P0100@006?kHo/000eN^@8000MO?003001J
o5[l00AJo0<000aKG@<000eGGP<000IGO`03001COe=o00@000=CO`03001COe=o00ACO`@000=?W`03
001?Odmo00@000Y;W`@000=;W`04001;Od]oBgl50007Agl50002Agl00`00Agm7O`07Agl50006Agl5
000<Agl50002Agl00`00Aem7G`09Ael70003Ael00`00Aem7G`08Ael70003Ael01@00Oomoogoo0000
4Woo001KOol00`00Oomoo`03003oOol1Ool40000104G0001>0000`5I00<000Fk1K/00PFk0P0010gL
0P002AhL0P0000<R7@00:S`01bXl0P000bhm00<0038l<S`0238l0`000SIL00<003YL>U`03SYL00<0
03iK?U/00`00349L00<0049K@U/0449K00<004IKAU/01DIK1@001DIk00<004YkBW/04DYk00<004ij
CWX04Dij00<004ijCWX04Dij00<0059jDWX04U9j00<005:JDYX04e:J00<005:JDYX02e:J1@000eJI
00<005JIEYT04eJI00<005JJEYX04eJJ0`005UZj00<005ZjF[X025Zj0`002EZj00<005[JF]X03U[J
0P001UkJ00<005kkG_/02ekk0P002Ekk00<005kkG_/025kk00<005kkG_/02ekk00<005kkG_/00Ukk
0P004Ekk0P0036=m00<005mnGgh02Emn0P0000=OOP00Ggd01emm0P002emn0P0015mn00D006>MHieS
W@0000USW@03001SWF>M00ESW@8000IS_@80009oT`05001oTgnCOi<00003Oi<01000Oi=oT`000gnC
00<007nC00000gnC00@007nCOi<000=oT`03001oT`0000=oTP03001k/@0000T00@05001Snf?kHo/0
000;G[T20009Gc`00`00F_aJo002F_`2000<Fed300000e]n001GGP09Eeh40009Egl30007Dgl00`00
DgmCO`040006Cil4000:Bil40006Bil50007Agl50008Agl01000Agm7OdMo1@001TMo1@000T=o00<0
04MoAgl01dMo1@0024Mo00@004MOAem7G`L000]7G`030017GdMO00L000]7G`D0015oo`00Fgoo0`00
ogoo1Woo0`0000<15`0000000P000P5I0P0010Fk00H000gL3M`=g0006O`200097Q`2000::S`20002
;Sd00`00<S`b?00:<S`3000A>U`00`00?U/nF`02?U/30009@U`00`00@U]2F`0@@U/00`00AU]6F`0:
AU/6000CBW/00`00CWY>NP0ACWX00`00CWY>NP0ACWX00`00DWYBNP0CDWX00`00DYYBVP0BDYX00`00
DYYBVP06DYX50008EYT00`00EYUFV@0DEYT00`00EYYFVP0?EYX300000eJI001J^P0FF[X00`00F[YJ
^P06F[X2000=F[X00`00F]YJfP0;F]X20008G]X00`00G_]Nn`08G_/3000;G_/00`00G_]Nn`06G_/2
000>G_/01@00G_]Nnekk00004Ekk0P0000=OO@00Hgd02F=m0P002Umn0P0015mn00<005mmGgd00Umm
0`002emn0P001Umn00@006>M000000QSW@8000MSW@03001S_F>m00IS_@80009oT`05001oTgnCOi<0
0003Oi<01000Oi=oT`000WnC00@007nCOi<000=oT`04001oTgnC0002Oi<01000Oi=oT`000gnB00<0
07^a0000200100<006?kHo/00f?k00<005jiG[T01Uji0P0035ll100035]M0P001E]n00<005MNEeh0
15MN0`002UMo0`0000=CW`00Dgl01U=o10001dnO0`000T^O00<004^OBil01D^O10001T^O10000dMo
00@004MoAgm7O`D000]7O`H000I7O`D000Q3O`040017OdMoAgl5000;Agl6000=Ael8000>Ael60002
Ool00`00Oomoo`0?Ool005]oo`03001oogoo0?moo`Moo`<000815`070001>0000ET0006J000010Fk
0P000PgL00<001Wl6O`00P002AhL0P002RXl0`003c8l0P003cYL00<003iK?U/01CiK10001T9L00<0
049K@U/03d9K00<004IKAU/03dIK1`003DYk00<004ijCWX04Tij00<004ijCWX04Dij00<0059jDWX0
4U9j00<005:JDYX04e:J00<005:JDYX01@003UJI00<005JIEYT04eJI00<005JJEYX035JJ0`0015JI
00<005ZjF[X05EZj00<005ZjF[X015Zj0P003eZj00<005[JF]X025[J0`002ekJ00<005kkG_/01Ekk
0P003Ukk00<005kkG_/015kk0P004Ekk0`004Ekk00<005mmGgd00Umm00<006=mHgd01F=m0P002Umn
0P001emn00@005mm000000aOOP8000QOOP8000QSW@8000MSW@8000MS_@800005Hkd007nCOi<00003
Oi<01000Oi=oT`000WnC00D007nCOi=oT`00009oT`07001oTgnCOi<007nC00000gnC00@007nCOi<0
009oTP04001k/G^a000700400`00Ho]Sn`04Ho/00`00G[UN^@04G[T2000=Gc`2000<Fed30008Fgh0
0`00EeiGGP03000:Egl30005Dil00`00DgmCO`0400000dnO001?W`05Cil30006Bil00`00Bim;W`04
0006Bil40006Agl50009Agl70003@gl01000Agm7OdMo1@002d=o1P002DMo1`0014=O00<004MOAel0
0dMO2@001TMO00<004MOAel00dMO2P001DMO00@007ooOol0015oo`00Fgoo00<007ooOol0ogoo27oo
100000<15`0000000`0000<1VP00000010Fk0P0000<=g0006O`00QWl0P001ahL00@002HL000000/Z
?08000db?003000j?000008000`jG003000nFciK00TnF`<000=2G0030012Fd9K0112F`030016FdIK
00m6F`03001:FTYJ00=:FPX000A:N`03001>NTij015>NP03001>NTij015>NP03001BNU9j019BNP03
001BVU:J00iBVPP001=FV@03001FVEJI01=FV@03001FVUJJ00UFVP<000QFV@03001J^UZj01AJ^P04
001J^UZjF[X3000AF[X00`00F]YJfP06F]X2000>G]X00`00G_]Nn`03G_/2000AG_/01000G_]Nnekk
0P004Ukk0P004Ekk0P001Umm00<006=mHgd00V=m0P002Umn0P002Emn0P002emn0`0025mn0P0000=O
WP00Hid01F>M0P001f>M0P0026>m00<006>mHkd00V>m0P000gnC00D007nCOi=oT`00009oT`05001o
TgnCOi<00002Oi<01000Oi=oT`000WnC00D007nCOi=oT`00009oT`06001oTWnB001k/@00200100<0
06?kHo/016?k00<005jiG[T00eji00<005llGc`02ell0P0000=OOP00Fed02E]M0P002e]n0`002UMo
0`001e>O10001DnO00<004nOCil0100024^O10001T^O10001TMo10000d=o00@004MoAgm7O`L000Q3
O`H000U3O`L000A3O`040017OdMoAgl70009@el8000=Ael8000@Ael00`00Ool0000AOol005]oo`03
001oogoo0?moo`Uoo`@000815`040001>00000020IX200041K/200056O`200067Q`00`009Q`V7002
0009:S`01000<S`00000338l00@003Xl>S`j?0<000XjG003000nFciK00/nF`@00192F`030016FdIK
0116F`03001:FTYJ00a:FPX000i>NP03001>NTij015>NP03001BNU9j01=BNP03001BVU:J009BVP/0
00EBN@03001FVEJI01=FV@03001FVEJI01=FV@03001FVUJJ00IFVP<000]FV@03001J^UZj01EJ^P<0
01EJ^P03001JfU[J00=JfP80011NfP04001NnekkG_/2000CG_/01000G_/000004Ukk0P0000=Nn`00
G_/03Ukk0P002Emm00@006=m000000UOOP<000UOOP800003Ggh005mn00QOOP8000UOOP8000AOWP03
001SWF>M009SW@03001SWF>M00ISW@03001S_F>m00IS_@8000ES_@8000=oT`05001oTgnCOi<00002
Oi<01`00Oi=oTgnC001oT`0000=oT`04001oTgnC0003Oi<00`00Oi<00003Oi800`00Nk4000070040
0`00Ho]Sn`05Ho/01000G[UN^Eji0P0035ll0P0015mn00<005]MFed015]M0`002U]n0`0000=GW`00
Egl01eMo0`001e>O0`000TnO00<004nOCil014nO0`0024^O10000dNO00<004^OBil010001TMo1000
1T=o1@0024=o1`0014=o00@004=o@gm3O`L000U3O`H000U3G`L000=3G`030017GdMO00Q7G`L000=3
G`030017GdMO00i7G`L0015oo`00Fgoo00<007ooOol0ogoo2goo0`000P4G00@0004h0CP000<1VP03
0005^`Fk0085^`8000HIo003000N71hL00<N7003000V72HL008V708000PZ?003000b?38l008000Xb
?003000j?3Xl00@j?0<000LjG003000nFciK00hnF`@000m2F`030016FdIK0116F`03001:FTYJ011:
FP03001:NTYj00=:NP/000A>NP03001>NTij015>NP03001BNU9j00QBNPl0011BN@03001FVEJI01=F
V@03001FVEJI01=FV@03001FVUJJ00=FVP<000iFV@03001J^UZj01AJ^P8001MJ^P04001JfU[JF]X2
000CG]X3000EG_/2000BG_/20004G_/00`00G_]Nn`0:G_/2000;Ggd20009Ggh2000:Ggh20004Ggh0
0`00GgiOOP04Ggh20009Ggh20007Gih01000Hid000001f>M0P001f>m0P001V>m00<006>m00000gnC
00D007nCOi=oT`00009oT`04001oTgnC0002Oi<01@00Oi=oTgnC00000WnC00@007nCOi<0009oT`04
001oTWnB0002Nk400`0000400@0400400`00Ho]Sn`07Ho/3000<Gc`20006Ggh00`00FeeKG@02Fed2
000;Fgh20005Eil00`00EgmGO`02Egl30007Dil30006Cil00`00Cim?W`0300000d^O001;W`04Bil4
0006Ail40006Agl40006@gl40003?gl01000@gm3Od=o1P002D=o1P002D=o1`0014=o00@004=O@em3
G`L000]3G`030017GdMO00L000]3G`030017GdMO00=7G`X000E7G`80015oo`00Fgoo00<007ooOol0
ogoo37oo100000@15`000001>0800081VP8000@5^`8000DIo08000@N7003000V72HL00<V708000HZ
?003000b?38l008b?08000Pb?003000j?3Xl00Lj?0<000DjG003000nFciK00hnF`030012Fd9K00@0
00a2F`030016FdIK00m6F`03001:FTYJ011:FP03001:NTYj00i:NR<000YBN@03001BNE9i01=BN@03
001FVEJI01=FV@03001FVEJI01=FV@03001FVP000080019FV@03001J^UZj011J^P<00003F[T005Zj
01IJ^P04001JfP00000DG]X2000EG_/200000ekk001Nn`0?G_/20006G_/00`00G_]Nn`09G_/00`00
GgeOO@09Ggd200000enN001OOP06Ggh2000:Ggh20007Ggh01000GgiOOUmn0P002Emn0P002EnN0P00
26>M00<006>mHkd01F>m0P001V>m0P000f>m00@007nCOi<0009oT`04001oTgnC0003Oi<01000Oi=o
T`000gnC00<007nC00000gnC00@007nCOi<0009oTP03001k/@0000L00@03001Snf?k00ISn`8000aO
?08000QOOP03001KG@00008000YKOP<000MGW`03001GO`00008000ICW`@000Q?W`@000A;W`03001;
W`0000<000I7W`@000=3W`030017OdMo00@000I3O`@000HoO`D000Q3O`L000@oO`040013Od=o@gl7
0009@gl6000=@el8000>@el:000@Ael00`00Oomoo`0?Ool005]oo`03001oogoo0?moo`eoo`@00081
5`8000030ET0006J0081VP800085^`04000Ag00000056O`200027Q`00`009Q`V70059Q`00`00:S`Z
?004:S`00`00<S`b?003<S`30006<S`00`00>S`j?009>S`30002>U`00`00?U/nF`0??U/00`00@U]2
F`03@U/40008@U/00`00AU]6F`0@AU/00`00BUY:FP0@BUX00`00BWY:NP0ABWX00`00CWY>NP0ACWX0
0`00DWUBN@0BDWT00`00DWUBN@0CDWT00`00EYUFV@0CEYT00`00EYUFV@0AEYT4000EEYT00`00F[YJ
^P0=F[X30005F[T00`00F[YJ^P0DF[X2000DG]X200000ekJ001Nn`0BG_/20004G_/00`00G_]Nn`0;
G_/20008G_/00`00G_]Nn`07G_/2000:Ggd20004Gih00`00GgiOOP02Ggh2000:Ggh20009Ggh01000
Ggh0000025mn0`002EnN0P0000=OWP00Hid01F>M0P001f>m00<006>mHkd01F>m00<006>mHkd016>m
0P000gnC00@007nCOi<000=oT`04001oTgnC0002Oi<01000Oi=oT`000gnC00<007nC00000gnB00<0
07^a00001P0100<006?kHo/01V?k00<006?M00002Ull0P002Umn0P002e]n0P002ENO0`001U>O0`00
24nO10000dNO00<004^OBil010001TNO10001T>O10001T=o10001Cmo1@000Smo00@004=o@gm3O`L0
00ToO`H000U3O`L000<oG`030013Gd=O00=3G`X000I3G`030013Gd=O00=3G`X000E3G`030017GdMO
00e7G`H0015oo`00Fgoo00<007ooOol0ogoo3goo100000@15`000001F@8000<1VP040005^`Fk0002
4M`00`006O`Io0046O`200000ahL000V70069Q`20004:S`00`00<S`b?006<S`20004<S`00`00>S`j
?00<>S`3000A?U/00`00@U]2F`07@U/40004@U/00`00AU]6F`0@AU/00`00BUY:FP0@BUX00`00BWY:
NP0ABWX00`00CWY>NP0ACWX00`00DWUBN@0CDWT00`00DWUBN@0BDWT00`00EYUFV@0CEYT00`00EYUF
V@0=EYT40002EYT00`00EYUFV@0DEYT00`00F[YJ^P0;F[X20008F[T00`00F[YJ^P0AF[X300000ekJ
001NfP0AG]X20004G]X00`00G_]Nn`0>G_/20006G_/00`00G_]Nn`09G_/2000;G_/00`00G_]Nn`04
G_/2000:Ggd20007Gih01000Ggh000002Umn0P002emn0P0025mn0P002UnN0P0015nN00@006>MHieS
W@8000MS_@8000IS_@8000MS_@8000=oT`04001oTgnC0003Oi<00`00Oi<00003Oi<01000Oi=oT`00
0WnC00@007nCOi<000=oTP03001k/@0000D00@03001Snf?k00ISn`05001SgF?MHmd00007Gc`2000:
Ggh200000e^O001KOP07Fgh30008Eil30003Cil00`00DimCW`030007Cil40006Ail40002Ail01000
Aim7WdNO10001D>O1@000cmo00<004=o@gl0100013mo1@001Smo1@002Cmo1`0013mo00@004=o@gm3
O`L000PoG`P000i3G`P00113G`030017GdMO0097G`X000Eoo`03001oogoo00moo`00Fgoo00<007oo
Ool0ogoo47oo0P0000D0eP000AL15`000081F@800081VP8000041K/0017L4M`200066O`200099Q`2
0002:S`00`00<S`b?008<S`20003<S`00`00>S`j?00>>S`2000??U/00`00@U]2F`0;@U/400000d9K
0016F`0@AU/00`00BUY:FP0@BUX00`00BWY:NP0BBWX00`00CWY>NP0ACWX00`00DWUBN@0BDWT00`00
DWUBN@0BDWT00`00EYUFV@0CEYT00`00EYUFV@08EYT50006EYT00`00EYUFV@0EEYT00`00F[YJ^P07
F[X3000:F[T00`00F[YJ^P0?F[X20004G]X00`00G]YNfP0>G]X20006G]X00`00G_]Nn`0<G_/20008
G_/00`00G_]Nn`08G_/00`00G_]Nn`0;G_/00`00G_]Nn`02G_/2000:Ggd20009Gih2000;Ggh00`00
GgiOOP09Ggh200000enN001OOP05Ggh2000:Gih20007Gih00`00Hid00007Hkd20007Hkd00`00HkeS
_@05Hkd20002Hkh01P00Oi=oT`00Oi<000=oT`04001oTgnC0003Oi<00`00Oi<00003Oi<01000Oi=o
T`000WnB00<007^a00001@0100<006?kHo/01V?k00<006?MHmd00V?M00<005llGc`00ell0P002Emn
0`0015^O00<005]nFgh00e]n0P0025NO0`001DnO10001TnO10001TNO10000d>O00<004NOAil01000
14>O1@001cmo10000cmo1@001Smo1@000c]o00@003mo?gloO`L000ToO`H000PoG`L000<oG`030013
Gd=O00U3G`L000<oG`030013Gd=O00e3G`X000moo`03001oogoo00moo`00FWoo00<007ooOol0ogoo
4Woo10000P4G00D0005I0ET1F@0000<1VP8000@Ag08000HIo08000TV70800003:S`0038l00Xb?080
0003<S`003Xl00lj?003000n>`00008000dnF`030012Fd9K00i2F`D000m6F`03001:FTYJ011:FP03
001:NTYj015:NP03001>NTij015>NP03001BNE9i019BN@03001BNE9i019BN@03001FVEJI01=FV@03
001FVEJI00AFV@@000aFV@03001FVEJI01AFV@03001J^UZj00EJ^P8000iJ^@03001J^UZj00aJ^P80
00MNfP03001NfUkJ00]NfP8000QNfP03001Nnekk00YNn`8000]Nn`03001Nnekk00ENn`8000iNn`05
001NnekkG_/0000:Ggd20009Gih200000enN001OOP08Ggh2000:Ggh20004Gih01000GgiOOUmn0P00
2UnN0P002EnN0P001V>m0P001f>m0P001f>m00<006>nHkh00f>n0P000WnC00D007nCOi=oT`00009o
T`07001oTgnCOi<007nC00000gnC00@007nCOi<0009oTP03001k/@0000D00@03001Snf?k00ESn`03
001SgF?M00=Sg@04001O?5llGc`20009Ggh20008Fil00`00Fgh000020006Eil40005Cil30003Bil0
0`00Cim?W`040006Ail40006@il50002@il50007?gl50002>gl50006?gl50006>gl60009?gl70004
>el01000?eloGcmO1P002cmO00@004=O@em3G`L000/oG`030013Gd=O00=3G`T001Yoo`03001oogoo
00ioo`00FWoo00<007ooOol0ogoo4goo1@0000<15`0000000P5I0P000`6J00<0017L4M`00a7L0P00
11Wl00@0027l000000TV708000db?080014j?004000n>chk?S/3000:?U/00`00@U]2F`0?@U/01000
AUY6FTIJ1@002TIK00<004YJBUX044YJ00<004YjBWX04DYj00<004ijCWX04Dij00<0059iDWT04e9i
00<0059iDWT04U9i00<005JIEYT04eJI00<005JI00000`0045JI00<005JIEYT055JI00<005ZjF[X0
0UZj0`0045Zi00<005ZjF[X02EZj0`002EkJ00<005kJG]X02EkJ0P002ekJ00<005kkG_/025kk00<0
05kkG_/02ekk00<005kkG_/00ekk0P004Ekk0`002Emm0P002EnN0P0015nN00<005mnGgh015mn0P00
2Umn0P001UnN00@005mn000000UOWP<000QOWP<0009KWP03001S_F>m009S_@03001S_F>m00ES_@80
00MS_@8000IS_P80009oT`05001oTgnCOi<00002Oi<01000Oi=oT`000WnC00L007nCOi=oT`00Oi<0
0003Oi800`00Nk40000400400`00Ho]Sn`05Ho/00`00HmeSg@05Hmd30009Ggh2000:Fil20006Eil3
0006Cil30005Bil40006Ail40005@il50002?ih50007?gl50002>gl50003>gh00`00?gloO`050004
>gl70004>el01000?gloOcmo1`002C]O1P003CmO20003SmO2P008goo00<007ooOol03Woo001JOol0
0`00Oomoo`3oOolDOol300001@3F0000004h00000`5I00@0006J0IX1VP8000DAg003000Io1Wl008I
o003000Qo27l008000TV708000db?08000lj?003000n>chk00@n>`<000LnF`030012Fd9K0112F`03
0016FTIJ00E6FPD000E6F`03001:FTYJ011:FP03001:NTYj015:NP03001>NTij019>NP03001BNE9i
019BN@03001BNE9i019BN@03001FVEJI015FV@@001AFV@03001FVEJI01EFV@@001=J^@03001J^UZj
00MJ^P8000aNfP03001NfUkJ00QNfP03001NfUkJ00]NfP03001Nnekk00INn`8000iNn`04001Nnekk
G_/2000BG_/20009Ggd20009Gih20007Gih01000GgiOOUmn0P002Umn0P0025nN0P002EnN0P002EnN
0P001U^N00@006>m000000MS_@03001S_F>m00ES_@8000IS_P800005Hkh007nCOi<00002Oi<01000
Oi=oT`000gnC00@007nCOi<0009oT`04001oTgnC0002Oi800`00Nk40000400400`00Ho]Sn`04Ho/2
0007Hmd20009Ggh20009Fil30002Dkl00`00EimGW`030005Cil40005Bil30003@ih00`00Aim7W`04
0004@il50003?ih40002>gh20003?gl50002>gl50006>gh50003>gl60009>el60009>el70003>el0
0`00?eloG`03?el:0006>el00`00?eloG`03?el:000]Ool00`00Oomoo`0>Ool005Yoo`03001oogoo
0?mooaIoo`D000030CP000000081F@8000040IX000Vk00054M`200026O`00`008O`Qo0028O`20007
9Q`01000;Q`000002c8l00<003Hk00000P0033Xl00<003hk?S/01chk0`001CiK00<0049K@U/03d9K
00<004IJAUX02TIJ1@0000=6F`00BUX04DYJ00<004YjBWX04DYj00<004ijCWX04Dij00<0059iDWT0
4U9i00<0059iDWT04U9i00<005JIEYT03EJI10000UIi00<005JIEYT055JI00<005JIEYT04eJI0P00
5eZi00<005ZjF[X015Zj0P003ekJ00<005kJG]X01EkJ0P003ekJ00<005kkG_/00ekk0P004Ekk0`00
4Ukk0P0000=OWP00Ggd01Umm0P002EnN0P002EnN00@005mn000000UOOP<000QOWP800003Gih005nN
00IOWP8000UOWP8000QKWP8000MS_@8000IS_@8000MS_P03001S_V>n009S_P8000=oT`04001oTgnC
0003Oi<00`00Oi<00003Oi<01000Oi=oT`000WnB00<007^a0000100100<006?kHo/00f?k00<006?M
Hmd01V?M00<005_N00001emn0P002E^O0P001E>o0`001DnO0`001T^O0`001D>N10000d>O1@0013nN
10001S]n1@000S]o1@0013]n1`000SMN1P0023]O1`0013MO00@003]O>elkG`L000HkG`X000`kG`X0
03Moo`03001oogoo00ioo`00FWoo00<007ooOol0ogoo5goo0`0000D0eP000CP1>00000<1F@040001
VP002K/200054M`200000aWl000Qo0048O`200069Q`00`00;Q`^7002000:<S`01000=S/f>cHk0P00
2cXl00<003hk?S/02Chk0`000SiK00<0049K@U/03d9K00<004IJAUX03dIJ1@003dYJ00<004YjBWX0
4DYj00<004ijCWX04Dij00<0059iDWT04U9i00<0059iDWT04U9i00<005JIEYT025JI1@001UIi00<0
05JIEYT055JI00<005JIEYT045JI0`0000=JV@00F[T05UZi00@005ZjF[YJ^P<0015NfP03001NfUkJ
00=NfP80015NfP04001NnekkG_/2000BG_/2000BG_/20004Gih00`00GgeOO@02Ggd20009Gih2000;
Gih20009Ggh20008Gih30004Gih00`00GiiOWP02Gih20008Gih30008Fih200000e^N001S_@05Hkd0
0`00HkeS_@05Hkd00`00HkiS_P05Hkh20005Hkh20003Oi<01000Oi=oT`000gnC00<007nC00000gnC
00<007nC00000gnB00<007^a00000`0100<006?kHo/00f?k00<006?MHmd01F?M0P000e_N00@005mn
GgiOOP<000QKW`<000AC_`<0009;_P03001?WdnO00<000E;W`@000A3WP@0008oWPD000DoWP@000Dk
OPH00003=gh0000000<0008kOPL0008gGPL000@cGP04000kGc]O>el60007=el80004>el90006=el0
0`00>elkG`03>el:0011Ool00`00Oomoo`0>Ool005Yoo`03001oogoo0?mooaQoo`D00081>0800081
F@<00089^`8000DAg003000Io00000HQo003000V72HL00<V7003000^72hL008^708000Pb?003000f
>cHk00<f>`<000Pj?003000n>chk00`n>`<00192F`030016FTIJ00m6FP04001:FTYJBUX70008BUX0
0`00BWY:NP0ABWX00`00CWY>NP0ACWX00`00DWUBN@0CDWT00`00DWUBN@0ADWT00`00EYUFV@04EYT4
000<EWT00`00EYUFV@0CEYT00`00EYUFV@0=EYT30004FYT00`00F[UJ^@0EF[T01000F[X0000055kJ
00@005kJG]YNfP8001=NfP04001Nn`00000BG_/200000ekk001Nn`0?G_/20007Gih01000Ggd00000
2UnN00<005nNGih02EnN0P0000=OWP00Ggh01Umn0P0025nN0P0025nN00@005nN000000QOWP8000UK
WP8000AKWP04001S_F>mHkd20006Hkd20006Hkh20005Hkh20002Hkh01P00Oi=oT`00Oi<000=oT`04
001oTgnC0002Oi<01000Oi=oT`000gnB00<007^a00000P0100<006?kHo/00f?k00<006?MHmd01F?M
00<005_NFmh00e_N00@005mn000000UKW`8000EC_`8000E;_P<000E;W`<000A3WP@0008oWP@000<k
O@03000oWSnN00@000@kOPD0008gOPD0008cG@D0008gGPL000TcGPH000<gG`X000@cG`P000/gG`X0
04]oo`03001oogoo00ioo`00FWoo00<007ooOol0ogoo6Goo0P0000@0]@0000000081>0040001F@5I
0ET200032K/00`004M`Ag0034M`200078O`200049Q`00`00;Q`^7003;Q`30006<S`00`00=S/f>`05
=S/20006>S`00`00?S/n>`0??S/3000?@U/00`00AUY6FP0?AUX00`00BUY:FP08BUX70002BUX00`00
BWY:NP0@BWX00`00CWY>NP0BCWX00`00DWUBN@0BDWT00`00DWUBN@0BDWT00`00EYT00003000@EWT0
0`00EYUFV@0DEYT00`00EYUFV@09EYT30008FYT00`00F[UJ^@0DF[T2000GG]X3000EG]X2000BG_/2
0004G_/00`00G_]Nn`0;G_/20009Gih2000:Gih2000:Gih20004Gih00`00GgiOOP02Ggh20008Gih2
000:Gih20008Gih20009Fih20007Fih00`00Hkd00006Hkd20006Hkh20006Hkh00`00HkiS_P03Hkh2
0002Oi<01@00Oi=oTgnC00000WnC00@007nCOi<0009oT`06001oTWnB001k/@000`0100<006?kHo/0
0V?k00<006?MHmd016?M0P001U_N0P0025^O0`0015>o0`0014^n0`000T>N00<004^OBil00`0014>N
0`000SnN10001S]m10000c]n1@000SMn1@000S=M1@000RmM1@002C=N1`0000<cGP0000001P001c=O
1`0013=N00<003MO=el00cMO2@00EGoo00<007ooOol03Woo001JOol00`00Oomoo`03003oOolGOol6
00020CP200030ET010002K/9^`Vk0P001A7L0P001b7l0P000RHL00<002hL;Q`01RhL0P00138l00<0
03Hk=S/01cHk0`0013Xl00<003hk?S/03Shk00<0048j@SX00`00349K00<004IJAUX044IJ00<004YJ
BUX03TYJ20003DYj00<004ijCWX04Tij00<0059iDWT04U9i00<0059iDWT03E9i1`0055Ii00<005JI
EYT055JI00<005JIEYT01UJI0`002eZI00<005ZiF[T04UZi0P0000=J^@00G]X05EkJ0P005EkJ0P00
00=Nn`00G_/03ekk0P001Ukk00<005kkG_/02Ekk0P002EnN0P000UnN00<005nNGih01EnN0P002UnN
0P001enN00@005mn000000QOWP8000UOWP<0009OWP03001OWUnN009OWP<000UKWP8000UKWP8000ES
_@8000MS_P03001S_V>n00AS_P8000IS_P80009oT`07001oTgnCOi<007nC00000gnC00@007nCOi<0
009oTP03001k/@0000800@04001Snf?kHo/20006Hmd00`00FmiKgP04Fmh20002Dmh00`00FimKW`03
Fil20005Dkl20004Bkh30004@ih50002@ih40002?ih30005>gd50002<gd50002=gh50002<ed50000
0bmM000000040003;cd01000<ehcGS=N1`0000<cGP0000001@0012ln00@003=O<elcG`L000LcGPX0
05ioo`03001oogoo00ioo`00FWoo0`00ogoo77oo1@000`4h00@0005I0ET1F@8000<9^`03000Ag17L
008Ag004000Ig00000078O`200000bHL000^7008;Q`20002<S`00`00=S/f>`0:=S/20002>S`00`00
?S/n>`0??S/00`00@SY2>P02@SX3000:@U/00`00AUY6FP0?AUX00`00BUY:FP0@BUX00`00BUU:F@03
BUT:0004BWX00`00CWY>NP0ACWX00`00DWUBN@0CDWT00`00DWUBN@02DWT:0005DWT00`00EWUFN@0C
EWT00`00EYUFV@0DEYT00`00EYUFV@03EYT3000>FYT00`00F[UJ^@0?F[T30003F[T00`00G]YNfP0B
G]X200000ekJ001NfP0BG]X20004G_/00`00G_]Nn`0;G_/20008G_/00`00G_]Nn`08G_/00`00GiiO
WP07Gih20005Gih00`00GiiOWP02Gih2000:Gih20009Gih20008Gih20009Gih20006Gih01000Gih0
00002E^N0`0025^N0`0000=KWP00Hkd00f>m00<006>nHkh01F>n0P001F>n0P001V>n0P0000ES_P00
Oi=oT`00009oT`04001oTgnC0003Oi<00`00Oi<00003Oi801@00Nk40000100000f?k00<006?MHmd0
16?M0P001E_N0P001E?N00<005^O00000P0015>o0`000d^n0`0014>N0`000cnM10000SnN10000c]m
1@000S=m1@000bmL10000S=M1@000RmM1@001Rlm1P000S=N1P001bln200013=N2P00J7oo00<007oo
Ool03Woo001JOol00`00Oomoo`3oOolMOol600020CP01P000ET1F@000GX000<9^`8000<Ag004000I
g1WL00088O`2000;;Q`200000c8l000f>`0<=S/3000A?S/00`00@SY2>P05@SX40006@U/00`00AUY6
FP0?AUX00`00BUY:FP0@BUX00`00BUU:F@0=BUT@0009CWX00`00DWUBN@08DWT?000?DWT00`00EWUF
N@0DEWT00`00EYUFV@0DEYT00`00EYT00002000AFYT00`00F[UJ^@0=F[T20007F[T00`00G]YNfP0?
G]X20003G]X00`00G]YNfP0?G]X20006G_/00`00G_]Nn`09G_/2000;G_/00`00G_]Nn`05G_/20008
Gih20008Gih01000Gih000002EnN0`002EnN0P000UnN00<005nNGih00UnN0`002EnN0P0025nN0P00
2E^N0P002E^N0P001E^N00@006>m000000IS_P8000IS_P03001S_V>n00ES_P03001S_V>n009S_P80
00=oT`04001oTgnC0002Oi<01000Oi=oT`000WnB00D007^a00000@0000=Sn`03001SgF?M00=Sg@80
00EKgP8000MCgP8000EC_`8000=;_P<000A3WP<000<oW@<0008gO@@0008kO@D0008cO@D000<_G0D0
0003:e`0000000<0008_G@D000@_?@l000@_?PT0008[?PX0079oo`03001oogoo00ioo`00FWoo00<0
07ooOol0ogoo7Woo100000@15`000CP1>08000040ET0005j00042K/010004M`Ag0000aWL0P00227l
0P002bhL0P0043Hk0P003chk00<0048j@SX02D8j0`000d9K00<004IJAUX044IJ00<004YJBUX044YJ
00<004YIBUT044YI00<004iICUT02DiI50002U9I00<0059iDWT04U9i00<005IiEWT04eIi00<005JI
EYT04eJI0`005EZI00<005ZiF[T02UZi0P002EZi00<005kJG]X03EkJ0P001UkJ00<005kJG]X035kJ
0P0025kk00<005kkG_/025kk00<005kkG_/02ekk00<005kkG_/00ekk0P0025nN0P002UnN0P002EnN
0P002UnN0P001EnN00@005nN000000UOWP<000QOWP800003Gih005^N00IKWP8000UKWP8000MKWP80
00IS_P8000IS_P8000IS_P8000ES_P8000=oT`03001oT`0000=oT`04001oTgnC0002Oi801@00Nk40
000100000V?k00<006?MHmd00f?M00<005_NFmh00e_N0P001e?N0P000T^n00<005>o00000P000T^n
0`0014>N0`000cnM0`000SMm0`000S=L10000S=m1@000bmL2`000RLl1@000blm3@000RLm2P000R/n
2@00O7oo00<007ooOol03Woo001JOol00`00Oomoo`3oOolOOol600030CP010000ET0005j0P000`Vk
0P0000<Ag0006M`00aWL0P001R7l00@002Gl000000/^708000hf>`03000j>`00008000dn>`030012
>T8j00]2>P<00003@U/004IJ0116FP03001:FTYJ011:FP03001:FDYI011:F@03001>FDiI019>F@03
001BFE9I019BF@03001BNE9i019BN@03001FNEIi01=FN@03001FVEJI011FV@<00003EWT005ZI01EJ
V@03001J^EZi00QJ^@8000]J^@03001NfUkJ00]NfP8000QNfP03001NfUkJ00YNfP8000]Nn`03001N
nekk00ENn`8000iNn`04001NnekkG_/20008Gih2000:Gih200000enN001OWP06Gih2000:Gih20007
Gih20009Gih20009Gih20004Gih00`00FiiKWP02Fih20008Fih30007Fih20002Fih00`00HkiS_P02
Hkh00`00HkiS_P04Hkh20006Hkh20005Hkh20002Hkh01P00Oi=oT`00Oi<000=oT`03001oT`0000=o
TP04001k/@000002Ho/00`00HmeSg@02Hmd20005Fmh00`00DmiCgP04Dmh30004Bkh3000014^n0000
000014>N0`000SnM10000SMm0`0000<cG00000000P000R]K10000bmL2@000RLl4`000RLm2@000RLL
2P00QGoo00<007ooOol03Woo001JOol00`00Oomoo`3oOolPOol700020CP200030GX00`002K/9^`02
2K/300056M`200058O`00`009O`Uo0020009;Q`01000<Q/000003CHk00@003Xk>S/j>`<000Xn>`03
0012>T8j00i2>P@000m6FP03001:FTYJ011:FP03001:FDYI015:F@03001>FDiI015>F@03001BFE9I
019BF@03001BNE9i019BN@03001FNEIi01AFN@03001FVEJI00aFV@<000AFN@03001JVEZI01AJV@03
001J^EZi00IJ^@8000eJ^@03001NfUkJ00UNfP8000YNfP03001NfUkJ00QNfP8000eNn`03001Nnekk
00=Nn`80015Nn`<000UOWP03001OWUnN00QOWP8000AOWP03001OWUnN009OWP8000YOWP8000MOWP80
0003Gih005nN00IOWP8000UOWP8000MOWP04001KWP000008Fih20007Fih30005Fih01000Hkh00000
1V>n00<006>nHkh016>n0P001V>n00<006>nHkh00f>n0P000WnC00L007nCOi=oT`00Oi<00002Oi80
0`00Nk40000200000f?k001Sg@03Hmd00`00FmiKgP03Fmh20005Dmh20004Bkh30002@kd40002@ih3
0002?id30002=gd80002:e/400029c/700029c`M00000bLL00000007002?Ool00`00Oomoo`0>Ool0
05Yoo`03001oogoo0?moob9oo`@000030AL0004h0081>0040001NP5j0GX200042K/00`006M`Ig005
6M`00`008O`Qo0028O`00`009O`Uo0029O`20008;Q`00`00<Q/b6`03000:=S/00`00>S/j>`04>S/3
0007?S/00`00@SY2>P0?@SX00`00ASY6>P04000<AUX00`00BUY:FP0@BUX00`00BUU:F@0@BUT00`00
CUU>F@0BCUT00`00DUUBF@0BDUT00`00DWUBN@0ADWT00`00EWUFN@0DEWT00`00EYUFV@09EYT30008
EWT00`00FYUJV@0CFYT00`00F[UJ^@03F[T3000@F[T00`00G]YNfP07G]X00`00G]YNfP0;G]X00`00
G]YNfP05G]X2000?G_/01000G_]Nnekk0P004Ukk0P002EnN0P002EnN0P001enN00@005nN000000UO
WP<000MOWP8000AOWP04001OWUnNGih30009Gih20009Gih20008Fih20007Fih20008Fih20006Hkh2
0006Hkh00`00HkiS_P04Hkh20006Hkh20002Oi<01000Oi=oT`000WnC00D007nBOi8007^a00@000=S
g@8000AKgP8000ECgP8000A;_P800093_@<000<kW0<0008oW@<0008gO@L0008[F`@000039c/00000
00D000037aX0000001H0008Nn`X009Qoo`03001oogoo00ioo`00FWoo00<007ooOol0ogoo8goo1`00
0P4h0P000`5j00<000Vk2K/00PVk0P001QWL0P000b7l00<002Gl9O`00bGl0P001RhL00<0038K<Q/0
0c8K0P0023Hk00<003Xk>S/01cXk0`001Chk00<0048j@SX03T8j00<004HjASX014Hj100024IJ00<0
04YJBUX044YJ00<004YIBUT044YI00<004iICUT04TiI00<0059IDUT04U9I00<0059iDWT04U9i00<0
05IiEWT04eIi00<005JIEYT01UJI0`002eIi00<005ZIFYT04eZI00@005ZiF[UJ^@8001=J^@03001N
fUkJ00ENfP8000iNfP03001NfUkJ00=NfP80019Nn`<0019Nn`800003Gih005nN00IOWP8000UOWP80
00UOWP8000UOWP8000QOWP8000IOWP04001OWP000009Gih30008Gih30002Fih00`00FiiKWP02Fih3
0007Fih20007Fih30002Fih01000HkiS_V>n0P001V>n0P001F>n0P001V>n0P000V?N0P000gnC00@0
07nCOi<0009oTP04001k/@000002>gH00`00Hmd00004Fmh20005Dmh20003Bkh3000014>m00000000
0c^L0`0000<cN`0000000P000SMm1P000R]K4`000Q[i2P000Qkk2P0027oo00<007ooOol0Ugoo00<0
07ooOol03Woo001IOol00`00Oomoo`3oOolUOol500001P4G0001>0000ET000<1NP070009^`Vk2K/0
016k00001aWL0P0000<Qo0009O`01RGl00<002hL;Q`012hL00<0038K<Q/0138K0P001cHk00<003Xk
>S/02CXk0`000Shk00<0048j@SX03d8j00<004HjASX01dHj100014IJ00<004YJBUX044YJ00<004YI
BUT044YI00<004iICUT04TiI00<0059IDUT04U9I00<0059iDWT04U9i00<005IiEWT04eIi00<005JI
EYT00eJI0`003UIi00<005ZIFYT055ZI0`005EZi00<005kJG]X00ekJ0P0045kJ00@005kJG]YNfP80
01=Nn`80019Nn`8000AOWP03001OWUnN009OWP8000QOWP<000UOWP800003Gih005nN00IOWP8000QO
WP8000QOWP8000UOWP8000UOWP8000IKWP04001KWP000008Fih20007Fih20006Fih00`00Hkh00006
Hkh20006Hkh00`00HkiS_P05Hkh00`00HmiSgP02Hmh30002Oi<00`00Oi<00003Oi830003>gH40000
0e_N00000005Dmh20003Bkh2000014>m000000000c^L0`0000@cN`000000008[FPH0008[Fa00008J
nA<0019oo`03001oogoo09Moo`03001oogoo00ioo`00FGoo00<007ooOol0ogoo9Woo1@0000H15`00
0CP0005I00030GX200022K/010004K/000001aWL00<0027l00001bGl0P0012hL00<0038K<Q/01S8K
0P001CHk00<003Xk>S/033Xk0`004D8j00<004HjASX02dHj100000=6FP00BUX044YJ00<004YIBUT0
4DYI00<004iICUT04DiI00<0059IDUT04U9I00<0059iDWT04U9i00<005IiEWT055Ii00<005JI0000
0P004EIi00<005ZIFYT04eZI0P005eZi00@005kJG]YNfP8001=NfP<001=Nn`800003G_/005kk00mN
n`8000MOWP04001OWP000008Gih2000:Gih20004Gih00`00GiiOWP02Gih20007Gih30008Gih20000
0enN001OWP06Gih20009Gih20008Fih20008Fih20007Fih20008Fih20005Hkh20006Hkh20006Hkh2
0003Hmh20003Gmh20002Oi<01P00Oi9oTP00Nk4000<kMP040013^T>j@kX20004Dmh30002Bkh30000
0d>m00000003>i`300001C=k00000000:eX01P000R<I3P000Q[i3`0077oo00<007ooOol0Ugoo00<0
07ooOol03Woo001IOol00`00Oomoo`3oOolWOol500001@4G000000000ET00P000`5j00<000Vk0000
0a6k0P001QWL0P002BGl0P000RhL00<0038K<Q/0238K0P0013Hk00<003Xk>S/03SXk0P003d8j00<0
04HjASX03dHj1@003dYJ00<004YIBUT044YI00<004iICUT04TiI00<0059IDUT04E9I00<0059iDWT0
4e9i00<005IiEWT04EIi100055Ii00<005ZIFYT045ZI0`0000=JV@00F[T05eZi0`0055kJ0P0055kk
00<005kkG_/00Ukk00<005kkG_/02ekk0P002EnN0`001enN0P002UnN0P001enN00@005nN000000MO
WP8000UOWP8000AOWP03001OWUnN009OWP8000QOWP<000MKWP<0009KWP03001KWU^N009KWP<000IK
WP<000MKWP<00003Fkh006>n00=S_P03001S_V>n00AS_P8000IS_P8000ASgP03001OgUoN00=OgP80
009oT`07001oTWnB001k/@00>gH00P000T>j0P000T>j00@005?N000000=;_P800004@kd000000002
>i`=00000b<I0000000I000UOol00`00Oomoo`2GOol00`00Oomoo`0>Ool005Uoo`03001oogoo0?mo
obUoo`D000030AL0005I0081F@040001NP5j0GX300044K/00`006M`Ig0056M`200099O`200000bhL
000b6`0:<Q/300000cHk000j>`0?>S/00`00?SX00002000<@SX00`00ASY6>P0@ASX01000ASU6>DHi
1@002TYJ00<004YIBUT044YI00<004iICUT04TiI00<0059IDUT04U9I00<0059iDWT04U9i00<005Ii
EWT03EIi10000UIh00<005IiEWT055Ii00<005ZIFYT03EZI0P0015ZI00<005ZiF[T05EZi0P0055kJ
0P0000=NnP00G_/04Ekk0P001Ekk00<005kkG_/02Ekk0P002EnN0P000enN00<005nNGih00UnN0P00
2UnN0P002EnN0P001enN0P002EnN0P001enN00@005nN000000QOWP8000QKWP8000IKWP04001KWP00
0007Fih20008Fih20005Fkh01000Hkh000001V>n00<006>nHkh01F>n00<006?NHmh00V?N0P0015oN
0P000UoN0P000gnB10000T>j0P0014>j0`0000=;_P00000010000S^L1P0000<[FP0000006@00;goo
00<007ooOol0Ugoo00<007ooOol03Woo001IOol00`00Oomoo`3oOolZOol30000103F00015`000`5I
0P000`5j0P00116k0P001AWL00<0027k00002RGl0P003S8K0P0043Xk00<003hj?SX00Shj0P002d8j
00<004HjASX03dHj00<004HiAST01THi1@001DYJ00<004YIBUT04DYI00<004iICUT04DiI00<0059I
DUT04U9I00<0059iDWT04U9i00<005IiEWT025Ii1@001UIh00<005IiEWT055Ii00<005ZIFYT02eZI
0P001eZI00<005ZiF[T04UZi0P0000=N^@00G]X04UkJ00<005kjG_X00Ukj00<005kkG_/03Ekk0P00
1ekk00<005kkG_/025kk00<005nNGih01enN0P001UnN00@005nN000000UOWP<000UOWP80009OWP03
001OWUnN009OWP8000UOWP8000UOWP8000QOWP8000QKWP8000QKWP8000MKWP8000QKWP8000MK_P80
00IS_P8000IS_P8000=SgP8000EOgP03001OgUoN009OgPL000=3^P030013^T>j0093^P80008kVPH0
0003>i`0000001X003Qoo`03001oogoo09Qoo`03001oogoo00eoo`00FGoo00<007ooOol0ogoo:goo
1@0000<15`0000000`5I00D0005j0GX1NP0000HA^`03000Ig1WL00<Ig004000Qn`00000:9O`2000>
<Q/2000?>S/00`00?SXn>P03?SX20009@SX00`00ASY6>P0@ASX00`00ASU6>@0:AST500000dYJ001:
F@0ABUT00`00CUU>F@0ACUT00`00DUUBF@0BDUT00`00DWUBN@0BDWT00`00EWUFN@04EWT4000<EWP0
0`00EWUFN@0CEWT00`00FYUJV@08FYT30009FYT00`00F[UJ^@0@F[T20003G[T00`00G]YNfP0?G]X2
0005G_X00`00G_]Nn`0;G_/2000:G_/00`00G_]Nn`05G_/20008Gih20008Gih20009Gih2000:Gih2
0005Gih01000Gih000002EnN0P002EnN0P000UnN00<005nNGih00UnN0`001e^N0`0025^N0P0000=K
WP00Fih00e^N0`001e^N0`001e^n0P000U^n00@006>nHkiS_P8000IS_P8000ASgP03001OgUoN00=O
gP8000=OgP8000=Oo@<00093^P800093^P<00003>iX0000000@00003:eT0000001<0049oo`03001o
ogoo09Qoo`03001oogoo00eoo`00FGoo00<007ooOol0ogoo;7oo1P0000<1>0000ET00P5I00@0005j
0GX1NP8000DA^`8000<Ig004000Qnb7k8O/200089O`01000;O/00000338K00@003HK000000dj>`03
000n>Shj00Dn>P<000I2>P030016>THj0116>P030016>DHi00m6>@D000m:F@03001>FDiI019>F@03
001BFE9I015BF@03001BNE9i01=BN@03001FN@0000<0011FN003001FNEIi01=FN@03001JVEZI00IJ
V@8000aJV@03001J^EZi00iJ^@8000IN^@03001NfUkJ00aNfP8000MNnP03001Nnekk00YNn`03001N
nekk00YNn`03001Nnekk00=Nn`8000QOWP8000QOWP800003Gih005nN00IOWP8000YOWP8000MOWP80
00UOWP8000QOWP<000EOWP04001OWP000008Fih20009Fih20004Fih01000Fih0000025^N0P001e^n
0`001E^n00<006>n00001f>n00<006?NHmh00V?N0P0015oN0P0015oN00@005omGoeOo@<00093^P80
0093^P80008kVP800004<gT00000:eTB0018Ool00`00Oomoo`2HOol00`00Oomoo`0=Ool005Uoo`03
001oogoo0?moobeoo`@000040=H0004h00030ET20000105j0009V`001Q6k00D001WL6M`Ig00000@Q
n`03000Uo2Gl00HUo003000]nbgk008000/b6`03000f6cHK008000/j>`03000n>Shj00Pn>P8000A2
>P030016>THj0116>P030016>DHi0116>@04001:>DXiBST70008BUT00`00CUU>F@0BCUT00`00DUUB
F@0ADUT00`00DWUBN@0@DWT5000DEWP00`00EWUFN@0CEWT00`00FYUJV@04FYT2000?FYT00`00F[UJ
^@0;F[T20008G[T00`00G]YNfP0:G]X2000:G_X00`00G_]Nn`07G_/2000=G_/01000G_]Nnekk0P00
25nN0P0025nN0P0015nN00<005nNGih00UnN0P002UnN0P001enN0P0000=OWP00Gih01UnN0P0025nN
0P0025nN0P0025^N0P002E^N0P001U^N0P0025^N0P001e^n0P0025^n0P001V>n0P000f?N0P001EoN
00<005oNGmh00UoN0P000eom0`0000=3^P0000000T>j0P000S^J4`00Cgoo00<007ooOol0V7oo00<0
07ooOol03Goo001IOol00`00Oomoo`3oOol_Ool300000`3F0001>00200030ET010000GX000VK0P00
1A6k0P0000<Ig0008O/0127k0P001RGl00<002gk;O/00Rgk00<0038K<Q/0238K00<003HK=Q/00SHK
0P002CXk00<003hj?SX02Shj0P000T8j00<004HjASX044Hj00<004HiAST044Hi00<004XiBST024Xi
1`000TYI00<004iICUT04DiI00<0059IDUT04U9I00<0059iDWT0259i1`000e9H00<005IhEWP04eIh
00<005IiEWT055Ii00<005ZIFYT00`004EZI00<005ZiF[T02EZi0P002Uji00<005kJG]X02EkJ00<0
05kjG_X02Ukj00<005kkG_/01Ekk0P0045kk0`002EnN00<005nNGih01UnN0P001enN00@005nN0000
00UOWP<000MOWP8000AOWP03001OWUnN009OWP8000QOWP8000QOWP80009OWP03001KWU^N009KWP<0
00UKWP8000IKWP80009KWP03001KWU^N009KWP<000MK_P8000QK_P80009K_P04001S_V>nHkh20004
Hmh00`00GmiOgP03Gmh20003Gmh20003God300000d>j00000002@kX200000c^J0000000=001GOol0
0`00Oomoo`2GOol00`00Oomoo`0=Ool005Uoo`03001oogoo00<00?moobeoo`<000050=H0004h0CP0
00030ET300022I/00`004K/A^`044K/300068O/00`009O`Uo0039O`00`00;O/]n`03;O/20008<Q/0
0`00=Q/f6`04=Q/30007>S/00`00?SXn>P0;?SX4000AASX00`00ASU6>@0AAST00`00BSU:>@0>BST8
000>CUT00`00DUUBF@0BDUT01000DWUBNE9i1`002U9H00<005IhEWP055Ih00<005IiEWT04eIi0`00
55ZI00<005ZiF[T025Zi00<005jiG[T02eji00<005kJG]X01UkJ0P003Ukj00<005kkG_/00Ukk0P00
4Ekk0P002EnN0P001enN0P002EnN0P002EnN0P0025nN0P001enN00@005nN000000QOWP8000QOWP80
00EOWP04001KWP000009Fih30006Fih20005Fih01000Fih0000025^n0P001e^n0`001E^n00<006>n
000016?N0P0015oN0P0015oN00@005omGoeOo@@00004@kX004>j@kX200000c^J0000000:001LOol0
0`00Oomoo`2GOol00`00Oomoo`0=Ool005Uoo`<00?mooc5oo`H000030CP0005I00<1F@040009V`VK
2I/200064K/00`008O/Qn`058O/200049O`00`00;O/]n`04;O/20007<Q/00`00=Q/f6`06=Q/20005
>S/00`00?SXn>P0>?SX3000@ASX00`00ASU6>@0@AST00`00BSU:>@0@BST00`00CUU>F@03CUT;0004
CUT00`00DUUBF@07DUT>000BDUP00`00EWQFN00CEWP00`00EWUFN@0BEWT2000GFYT00`00F[UJ^@05
F[T2000>G[T00`00G]YNfP04G]X2000@G_X01@00G_]Nnekk00004Ekk0P0000=OWP00Gih01UnN0P00
1enN0P002EnN0P0000=OWP00Gih01UnN0P0025nN0P002EnN0P0025nN0P0025nN0P001enN0P002E^N
0P001e^N0P001e^N0P0025^n0P001e^n0P0025^n0P000f?N0P001EoN00<005oNGmh00UoN0P000eom
00@005_k0013^PD00003>iX0000000P0061oo`03001oogoo09Moo`03001oogoo00eoo`00FGoo00<0
07ooOol0ogoo<Woo100000<0m`000CP00P000`5I00<000VK2I/00PVK00<0016k4K/0116k0P001b7k
00D002Gl9O`Uo00000P]n`8000Db6`03000f6cHK00Pf6`8000<j>`03000n>Shj00hn>P030012>T8j
00<000e6>P030016>DHi0116>@03001:>DXi011:>@03001>FDiI00i>F@h000YBF003001BF59H01=B
F003001FN5Ih01=FN003001FNEIi00mFN@<00003FWP005ZI01IJV@03001J^EZi00=J^@80011N^@03
001NfUkJ009NfP80019NnP04001Nn`00000@G_/20004Gih00`00GiiOWP02Gih20008Gih00`00GiiO
WP07Gih20004Gih00`00GiiOWP02Gih20007Gih30009Gih20002Gih00`00GiiOWP02Gih30008Gih2
0007Gih200000e^N001KWP06Fih20007Fih20007Fih20002Fkh00`00FkiK_P02Fkh30007Fkh20007
Fkh30002Fkh00`00Hmh00005Gmh20003Gmh20003God800000c^J00000006001UOol00`00Oomoo`2G
Ool00`00Oomoo`0=Ool005Uoo`03001oogoo0?mooc=oo`@000050?L0004h0CP000030ET200032I/2
00044K/00`006M/000078O/200029O`00`00;O/]n`07;O/20003<Q/00`00=Q/f6`0:=Q/200000cXk
000n>P0??SX00`00@SY2>P03@SX3000:ASX00`00ASU6>@0@AST00`00BSU:>@0ABST00`00CUU>F@0A
CUT00`00DUQBF00ADUP00`00DUQBF00CDUP00`00EWQFN00CEWP00`00EWUFN@0=EWT20004FWP00`00
FYUJV@0EFYT01000F[UJ^EZi0P004Uji00D005kJG]YNfP0001ANnP80011Nn`8000MOWP04001OWP00
0008Gih20008Gih20007Gih01000Gih000001enN0P002UnN0P001EnN00@005nN000000UOWP8000MO
WP8000AKWP03001KWU^N009KWP8000MKWP8000MKWP8000EK_P04001K_P000008Fkh20007Fkh20005
Fkh30003Gmh20004Gmh01000GoeOoEom0P0000=Kn`0000002P00JGoo00<007ooOol0Ugoo00<007oo
Ool03Goo001IOol00`00Oomoo`3oOoleOol30000103g0000004h0P0000@1F@000GX000@9V`03000A
^a6k008A^`04000If`0000078O/3000;;O/01@00<Q/b6c8K00003CHK0`0043hj00<0048j@SX01D8j
10001THj00<004HiAST04DHi00<004XiBST044Xi00<004iICUT04DiI00<0059HDUP04U9H00<0059H
DUP04U9H00<005IhEWP055Ih00<005IiEWT02EIi0`001eYh00<005ZIFYT05EZI0`005Eji0`004ekj
0P0000=S6`00G_/03Ekk0P002EnN0`001enN0P0025nN0P002EnN0P001enN0P002UnN0P001enN0P00
2EnN0P001enN0P001e^N00@005^N000000MKWP8000MKWP8000MK_P8000QK_P8000MK_P8000EK_P80
00=K_P03001OgP0000AOgP8000=Oo@03001Kn`0000X006aoo`03001oogoo09Moo`03001oogoo00eo
o`00FGoo00<007ooOol0ogoo=Woo0`000P3g00P0004h0CP0005I0001NP0010VK00D0016k4K/A^`00
00<If`03000Qnb7k00HQn`03000]nbgk00X]n`800003<Q/003HK00hf6`8000ln>P030012>T8j00U2
>P<000=6>P030016>DHi0156>@03001:>DXi011:>@03001>FDiI015>F@03001BF59H019BF003001B
F59H01=BF003001FN5Ih01=FN003001FNEIi00MFN@8000YJN003001JVEZI01AJV@8001IN^@8001AN
nP03001S6f<K009S6`03001Nnekk00UNn`8000UOWP8000=O_P03001OWUnN009OWP8000MOWP<000UO
WP80009OWP03001OWUnN009OWP8000YOWP8000MOWP800003Gih005nN00IOWP8000MOWP8000UKWP80
00MKWP8000MKWP8000MK_P80009K_P03001K_U^n009K_P<000IK_P<000AK_P<000EK_P8000=OgP80
00=Oo@800003Fo/0000000L006moo`03001oogoo09Moo`03001oogoo00eoo`00F7oo00<007ooOol0
ogoo>7oo100000P0m`000CP1>0000ET0005j0P000`VK0P000Q6k00@001WK6M/If`8000LQn`8000`]
n`8000lf6`04000j6P00000=?SX00`00@SY2>P0<@SX300000dHj0016>@0AAST00`00BSU:>@0@BST0
0`00CUU>F@0BCUT00`00DUQBF00ADUP00`00DUQBF00CDUP00`00EWQFN00CEWP00`00EWUFN@04EWT3
000<FWP00`00FYUJV@0BFYT200000ejH001N^@0DG[T00`00G]T0000BG_X20005Ha/00`00G_]Nn`08
G_/00`00GiiOWP07Gih20006Gkh01000Gih000001enN0P002UnN0P001EnN00@005nN000000UOWP<0
00MOWP8000AOWP03001OWUnN009OWP8000MOWP8000UKWP80009KWP03001KWU^N009KWP8000MKWP80
00MK_P8000EK_P04001K_P000007Fkh20005Fkh20006Fkh20002Emh00`00Gmh00003God20002Fo/6
001cOol00`00Oomoo`2GOol00`00Oomoo`0=Ool005Qoo`03001oogoo0?moocUoo`@000040?L00000
0CP300020GX00`002I/9V`022I/00`004K/000056M/00`008O/Qn`048O/010009O/0000032gk0P00
3SHK00<003XJ>QX00`002chj00<0048j@SX03T8j100044Hi00<004XiBST04DXi00<004iICUT04DiI
00<0059HDUP04E9H00<0059HDUP04e9H00<005IhEWP04eIh00<005IiEWT00UIi0P003eYh00<005ZI
FYT045ZI0P000ejH00<005jiG[T04Eji0P000ekI00<005kjG_X03Ekj0P001f<K00<005kkG_/01Ukk
0P002EnN00<005nnGkh01Unn0P001enN0P002UnN0P001enN0P002EnN0P0025nN0P001enN00@005nN
000000MOWP8000QKWP<000EKWP04001KWP000007Fih20007Fkh20007Fkh20007Fkh20005Fkh20005
Fkh30004Emh4000015om001Kne_k1@00MWoo00<007ooOol0Ugoo00<007ooOol03Goo001HOol00`00
Oomoo`3oOoljOol400020?L010000CP1>0000`5j00<000VK2I/00PVK0`001AWK0P001B7k00<002Gk
9O/00P002Rgk00@0037k000000`f6`03000j6SXJ00<j6P8000Tn>P030012>T8j00m2>P030016>DHi
00<000i6>@03001:>DXi011:>@03001>FDiI015>F@03001BF59H015BF003001BF59H01=BF003001F
N5Ih01AFN0@0019JN003001JVEZI00eJV@8000INV003001N^Eji00iN^@8000ENf@03001NnUkj00]N
nP8000YS6`03001Nnekk00=Nn`8000UOWP8000MO_P80009O_P03001OWUnN009OWP8000YOWP8000MO
WP800003Gih005nN00IOWP8000QOWP8000UOWP8000MOWP8000QKWP8000QKWP8000MKWP8000MK_P80
00IK_P<00003Fkh005^n00=K_P<000EK_P8000EK_P8000EGgP8000=GgP<00003Fo/00000008007Qo
o`03001oogoo09Moo`03001oogoo00eoo`00F7oo00<007ooOol0ogoo?7oo0`000P3g0P0000<1>000
0GX00P5j0P0010VK00<001WK6M/01AWK00<0027k8O/00R7k00<002Gk9O/00RGk00<002gk;O/022gk
00<0037k<O/00P002SHK00<003XJ>QX01CXJ0P001chj00<0048j@SX03d8j00<004HiAST00dHi1000
2THi00<004XiBST044Xi00<004iICUT04DiI00<0059HDUP04U9H00<0059HDUP04U9H00<005IhEWP0
4UIh0`005EYh00<005ZIFYT02eZI0P0025jH00<005jiG[T03Eji00<005kIG]T01EkI00<005kjG_X0
2Ukj00<006<KHa/02V<K00@005kkG_]Nn`8000UOWP8000MO_P8000EO_P04001OWP000009Gih30007
Gih20004Gih00`00GiiOWP02Gih20007Gih30008Gih30002Gih00`00GiiOWP02Gih20008Fih20007
Fih30002Fih00`00FiiKWP02Fih20007Fkh20006Fkh20005Fkh01000Fkh000001U^n0P001E^n0P00
15ON0`000eON0P000U_N0`00Ngoo00<007ooOol0Ugoo00<007ooOol03Goo001HOol00`00Oomoo`3o
OolmOol400020?L010000CP000000`5j00<000VK2I/00PVK0P001QWK00<0027k8O/00R7k00<002Gk
9O/00RGk0P0022gk00<0037k<O/00S7k0P002CHK00<003XJ>QX01SXJ0P001Shj00<0048j@SX03d8j
00<004HiAST01THi0`001dHi00<004XiBST044Xi00<004iICUT04DiI00<0059HDUP04U9H00<0059H
DUP04e9H00<005IhEWP03UIh0`000UIh00<005YhFWP04eYh00<005ZIFYT02EZI0P002UjH00<005ji
G[T02eji0P002EkI00<005kjG_X01ekj0P003F<K00@005kk000000UOWP8000MO_P8000MO_P8000UO
WP8000QOWP8000MOWP04001OWP000007Gih20009Gih20006Gih01000Gih0000025^N0P001e^N0P00
1U^N00@005^N000000MK_P8000IK_P8000MK_P<000AK_P<000EK_P8000AGgP8000AGgP80009KgP80
07ioo`03001oogoo09Moo`03001oogoo00eoo`00F7oo00<007ooOol0ogoo?Woo10000P3g0P0000<1
>@000GX00P5j0P000PVK00<0016K00001QWK0P000R7k00<002Gk9O/012Gk0P001Rgk00<0037k<O/0
137k0P001cHK00<003XJ>QX023XJ0P0013hj00<0048j@SX03d8j00<004HiAST02DHi10000dHi00<0
04XiBST044Xi00<004iICUT04TiI00<0059HDUP04E9H00<0059HDUP04e9H00<005IhEWP02UIh1000
1EIh00<005YhFWP055Yh00<005ZIFYT01eZI00<005jHGYP02UjH00<005jiG[T02Eji0P002ekI00<0
05kjG_X01Ekj0P003f<K0P002EnN0P001enn0P001enn0P0000=O_P00Gih01UnN0P0025nN0P002EnN
0P001enN0P002EnN0P0025nN0P0025^N0P001e^N0P0025^N0P001e^n0P001E^n0`001e^n0P000e^n
00@005^n000000IK_P8000AGgP8000AGgP80009KgP<007moo`03001oogoo09Moo`03001oogoo00eo
o`00F7oo00<007ooOol0ogoo?goo10000P3g0P0000<1>@000GX00`5j00H000VK2I/0016K00076M/0
0`008O/000089O/20005;O/00`00<O/an`05<O/00`00=Q/f6`04=Q/00`00>QXj6P0:>QX300000chj
0012>P0@@SX00`00ASU6>@0=AST300000dHi001:>@0ABST00`00CUU>F@0ACUT00`00DUQBF00ADUP0
0`00DUQBF00CDUP00`00EWQFN007EWP30009EWP00`00FWQJN00DFWP00`00FYUJV@05FYT2000>GYP0
0`00G[UN^@07G[T00`00G]UNf@0<G]T00`00G_YNnP02G_X2000?Ha/20002Gkh00`00GiiOWP05Gih0
0`00GkiO_P05Gkh20007Gkh20004Gkh00`00GiiOWP02Gih20007Gih30008Gih30002Gih00`00GiiO
WP02Gih20008Gih30007Gih30002Fih00`00FiiKWP02Fih30006Fih30007Fih30002Fkh00`00FkiK
_P02Fkh20005Fkh20007Fkh30005Fkh30004Fkh30004Emh20004Emh20002Fmh30021Ool00`00Oomo
o`2GOol00`00Oomoo`0=Ool005Qoo`03001oogoo0?mood1oo`D00080m`040001>@0000030GX00`00
2I/000024I/200066M/300099O/20003;O/00`00<O/an`06<O/20005=Q/00`00>QXj6P0<>QX3000@
@SX00`00ASU6>@0@AST5000?BST00`00CUU>F@0ACUT00`00DUQBF00BDUP00`00DUQBF00BDUP00`00
EWQFN003EWP4000=EWP00`00FWQJN00CFWP00`00FYUJV@03FYT2000@GYP00`00G[UN^@05G[T2000?
G]T01@00G_YNnUkj000046<K00<005nnGkh00enn00<005nNGih00UnN0P001enn00<005nnGkh01Enn
0P001enn00@005nN000000MOWP8000UOWP8000IOWP04001OWP000008Gih20008Gih20006Fih01000
Fih000001e^N0P0025^N0P001U^n00@005^n000000EK_P8000MK_P8000IK_P8000=K_P04001K_P00
0005Emh20004Emh20002Fmh40022Ool00`00Oomoo`2GOol00`00Oomoo`0=Ool005Qoo`03001oogoo
0?mood9oo`@00080m`040001>@4i00030GX300034I/00`006M/If`056M/00`009O/Un`099O/01@00
;O/]nbgk00002C7k0P000cHK00<003XJ>QX03SXJ0P00448j00<004HiAST044Hi00@004XiBSU:>@D0
00Y:>@03001>FDiI015>F@03001BF59H019BF003001BF59H01=BF003001FN0000080015FN003001J
N5Yh01=JN004001JVEZIFYT2000BGYP00`00G[UN^@04G[T00`00G]UNf@0?G]T01000G_X000003f<K
0P001enn00@005nN000000MO_P8000IO_P8000UO_P8000MOWP8000UOWP8000QOWP8000QOWP8000QO
WP8000QKWP8000MKWP8000QKWP8000QK_P8000AK_P<000MK_P8000EK_P<000EK_P8000AGgP<000AG
gP80009KgP@008Aoo`03001oogoo09Qoo`03001oogoo00aoo`00F7oo00<007ooOol0ogoo@goo1000
0P3g0P0000<1>@000GX00`5j0P000a6K00<001WK6M/01AWK0P002RGk0P0000<]n`00<O/02S7k0P00
00<f6`00>QX03cXJ00<003hI00000P003D8j00<004HiAST044Hi00<004XiBST01TXi1@001DXi00<0
04iICUT04DiI00<0059HDUP04U9H00<0059HDUP0459H1@0055Ih00<005YhFWP055Yh0`0055jH00<0
05jiG[T00Uji0P004UkI0P003f<K0P002Enn0P001enn0P001Unn0P002Enn0P000UnN00<005nNGih0
0UnN0P0025nN0`001enN0`000UnN00<005nNGih00UnN0`001enN0`001e^N0`0000=KWP00Fih00e^N
0`001e^N0`001e^n0`000U^n00@005^n000000QK_P8000EK_P8000IK_P80009K_P04001GgP000005
Emh20002Fmh200000eol001oo`25Ool00`00Oomoo`2HOol00`00Oomoo`0<Ool005Qoo`03001oogoo
0?moodAoo`@000060?L0004H0001>@00105j00<0016K4I/00Q6K0P001AWK00<0027K00002bGk0P00
3C7k0`003cXJ00<003hI?QT00ShI0P002d8j00<004HiAST044Hi00<004XiBST02dXi1@0000=:>@00
CUT04DiI00<0059HDUP04U9H00<0059HDUP02e9H1@000e9H00<005IhEWP04eIh00<005YhFWP04eYh
0P005UjH00<005jiG[T00P004ekI00<006<K00003F<K0P002Enn0P000Unn00<005nnGkh00Unn0P00
1enn00<005nnGkh01enn0P001EnN00@005nN000000QOWP8000QOWP8000IOWP04001OWP000008Gih2
0008Fih20005Fih01000Fih0000025^N0P0025^n0P001E^n0P0025^n0P001E^n0P001U^n0P0015^n
0`0015ON0P000U_N0P0000=Oo0000000Qgoo00<007ooOol0V7oo00<007ooOol037oo001HOol00`00
Oomoo`3oOom5Ool600000`4H0001>@0200030GX200044I/00`006M/If`036M/010008M/000002bGk
0P003C7k0P003cXJ00<003hI?QT00chI0`002D8j00<004HiAST044Hi00<004XiBST03dXi1`003TiI
00<0059HDUP04E9H00<0059HDUP01U9H1@00259H00<005IhEWP04eIh00<005YhFWP04EYh0P0000=J
N000GYP05UjH0P004ekI0P000f<K00<006<KHa/02F<K00<005nnGkh01enn0P001Enn00@005nn0000
00MO_P8000QO_P8000MOWP8000QOWP8000QOWP8000QOWP8000QOWP8000QKWP8000MKWP8000QKWP80
00QK_P8000EK_P80009K_P03001K_U^n009K_P<000EK_P8000IK_P8000AK_P8000=KgP04001GgP00
0002Fmh20002Go`00`00Oomoo`27Ool00`00Oomoo`2HOol00`00Oomoo`0<Ool005Qoo`D00?moodAo
o`80000609@00000000160000P4i00H0005j0GX000Ej00044I/200036M/01@008M/Qfb7K00002RGk
00<002gj0000337k00@003Gj000000dj6P03000n6ChI00Hn6@8000M2>P030016>DHi0116>@03001:
>DXi011:>@03001>>4hh00=>>0X000A>F@03001BF59H019BF003001BF59H00D000eBF003001FN5Ih
01=FN003001JN5Yh00mJN08000=JN003001NV5jH01ANV08001=Nf@03001S6f<K00=S6`03001S6f<K
00MS6`8000QO_P8000MO_P8000MO_P8000QO_P8000MOWP80009OWP03001OWUnN009OWP<000MOWP<0
00QOWP80009OWP03001OWUnN009OWP<000MKWP<000MKWP80009KWP03001KWU^N009KWP<000MK_P<0
00EK_P8000EK_P04001K_P000006Fkh20006Fkh20004Fkh20005Fmh300000e_N00000002Go`2002:
Ool00`00Oomoo`2HOol00`00Oomoo`0<Ool005Qoo`03001oogoo0?moodQoo`@0008160040001>@4i
00020GX00`001GX000054I/01@006M/IfaWK00000b7K0P002BGk00@002gj000000/an`03000enSGj
008000/j6P03000n6ChI00Pn6@<000A2>P030016>DHi0116>@03001:>DXi011:>@03001>>4hh00e>
>1`001=BF003001FN5Ih01=FN003001JN5Yh00aJN08000IJN003001NV5jH019NV003001N^000019N
f@03001S6f<K00AS6`03001S6f<K00ES6`8000QO_P8000MO_P80009O_P03001O_Unn009O_P8000MO
_P<000MOWP8000EOWP04001OWP000008Gih20009Gih20005Gih01000Gih0000025^N0P001e^N0`00
1E^N00@005^N000000QK_P8000IK_P8000MK_P<000AK_P<000IK_P8000AK_P8000EKgP80009KgP@0
0003Go`007oo08]oo`03001oogoo09Qoo`03001oogoo00aoo`00F7oo00<007ooOol0ogooBGoo1000
0P4H0P0000@1>@0000000085NP03000AVa6K00<AV`04000IfaWK00058M/00`009O/Un`069O/01000
;OX]nRgj0P002C7k00<003Gj=OX00SGj00<003XJ>QX02CXJ00<003hI?QT02ShI0P000T8j00<004Hi
AST044Hi00<004XiBST04DXi00<004hhCSP044hh00<004hhCSP04Thh00<0059HDUP04e9H00<005Ih
EWP04eIh00<005YhFWP02UYh0P0025Yh00<005jHGYP045jH0P000ejh00<005kIG]T03EkI0P0026<K
00<006<KHa/00V<K0P0025nn0P001enn0P001Enn00@005nn000000MO_P8000QOWP8000MOWP8000QO
WP8000UOWP8000MOWP8000QKWP8000MKWP8000QKWP8000QK_P8000IK_P8000MK_P8000=K_P04001K
_P000007Fkh20004Fkh20005Fmh20002Fmh20003Gmh2002=Ool00`00Oomoo`2HOol00`00Oomoo`0<
Ool005Moo`03001oogoo0?mood]oo`D0008160030001>@4i00800085NP8000@AV`<000HQf`8000HU
n`03000]nRgj00<]nP03000anc7k00Han`03000enSGj00<enP8000Tj6P03000n6ChI00`n6@@00156
>@03001:>DXi015:>@03001>>4hh011>>003001>>4hh019>>003001BF59H01=BF003001FN5Ih01=F
N003001JN5Yh00QJN08000YJN003001NV5jH00mNV003001N^5jh00=N^003001NfEkI00aNf@03001S
6f<K00QS6`05001S6f<KHa/00009Gkh00`00GkiO_P05Gkh20007Gkh20007Gkh20008Gih20007Gih2
0002Gih00`00GiiOWP02Gih30009Gih20007Gih20002Gih00`00FiiKWP02Fih30007Fih20008Fih2
0002Fkh00`00FkiK_P02Fkh30006Fkh20006Fkh30005Fkh20007Fkh20004Fkh20005Fmh20003Fmh0
1000GmiOgUoN0P00Sgoo00<007ooOol0V7oo00<007ooOol037oo001GOol00`00Oomoo`3oOom<Ool2
00000`2D000000020AP00`000CT1>@0200031GX00`004I/AV`034I/200078M/200059O/00`00;OX]
nP03;OX20007<O/00`00=OXenP04=OX20007>QX00`00?QTn6@0??QT2000AAST00`00BSU:>@0@BST0
0`00CSQ>>00ACSP00`00CSQ>>00ACSP00`00DUQBF00CDUP00`00EWQFN00CEWP00`00FWQJN007FWP0
0`00FWQJN00:FWP00`00GYQNV00>GYP00`00G[QN^004G[P00`00G]UNf@0:G]T2000;Ha/01000Ha/0
000025nn0P001Unn0P001enn0P000Unn00<005nnGkh00Unn0P0025nN0P001enN0P001EnN00@005nN
000000YOWP8000MOWP8000EOWP04001KWP000008Fih20007Fih30005Fkh01000Fkh000001e^n0P00
1U^n0P001U^n0P000U^n00<005^nFkh00U^n0P0015^n0P001E_N0P000e_N0P000UoN0P00TGoo00<0
07ooOol0V7oo00<007ooOol037oo001GOol00`00Oomoo`3oOom=Ool200000`2D000000020AP01000
0CT1>@0010Ej00<0016K4I/00a6K00<0027K8M/01b7K00<002Gk9O/00RGk00<002gj;OX01Bgj00<0
037k<O/0137k00<003Gj=OX01SGj0P001CXJ00<003hI?QT03chI00<0048I00000P003THi00<004Xi
BST044Xi00<004hhCSP04Dhh00<004hhCSP04Thh00<0059HDUP04U9H00<005IhEWP04eIh00<005Yh
FWP01EYh0P003UYh00<005jHGYP02ejH0P0025jh00<005kIG]T025kI00<006<KHa/02f<K0`001enn
0P001Enn0`001enn0P001Enn00@005nn000000QOWP8000MOWP8000MOWP8000YOWP8000MOWP8000MO
WP8000QKWP8000MKWP8000QK_P8000MK_P8000IK_P8000IK_P8000EK_P04001K_P000004Fkh20005
Fmh20003Fmh20003Gmh00`00Oomoo`2AOol00`00Oomoo`2HOol00`00Oomoo`0<Ool005Moo`03001o
ogoo0?moodmoo`040000U00000020AP00`000CT1>@0200031GX200044I/200088M/200029O/00`00
;OX]nP06;OX20004<O/00`00=OXenP08=OX20004>QX00`00?QTn6@0>?QT00`00@QU26@02@QT2000<
AST00`00BSU:>@0@BST00`00CSQ>>00ACSP00`00CSQ>>00BCSP00`00DUQBF00BDUP00`00EWQFN00C
EWP00`00FWQJN003FWP2000@FWP00`00GYQNV00:GYP00`00G[QN^008G[P00`00G]UNf@07G]T00`00
Ha]S6`0;Ha/01@00Cm]?fdoK000015nn0P001Enn0P0025nn0P001enn0`001enN0P001enN0P001enN
0P000UnN00<005nNGih01EnN0P001enN0P001enN0P000U^N00<005^NFih00U^N0`001e^N0P0025^n
0P000U^n00<005^nFkh00U^n0P001U^n0P001U^n0P001e^n0P0015^n0P001E_N0P000e_N0P000eoN
0P00U7oo00<007ooOol0V7oo00<007ooOol037oo001GOol00`00Oomoo`3oOom@Ool400020AP30000
0`5I0005NP031GX01`004I/AVa6K000E^`0000TQf`04000UnbGk0009;OX00`00<O/an`02<O/00`00
=OXenP09=OX01@00>QXj6SXJ00004ChI00<0048I@QT00d8I0`002DHi00<004XiBST04DXi00<004hh
CSP044hh00<004hhCSP04Thh00<0059HDUP04U9H00<005IhEWP055Ih00<005YhFWP00P004UYh00<0
05jHGYP025jH0P002ejh00<005kIG]T01EkI0P0036<K0P001DoK00@005nn000000EO_P8000QO_P80
00MO_P8000=O_P03001OWUnN009OWP8000MOWP8000MOWP8000EOWP03001OWUnN009OWP8000MOWP80
00MOWP8000EKWP04001KWP000008Fih20007Fkh30005Fkh01000Fkh000001U^n0P001U^n0P001U^n
0`000U^n00@005^n000000EKgP8000AKgP04001OgUoNGmh2002FOol00`00Oomoo`2HOol00`00Oomo
o`0<Ool005Moo`03001oogoo0?mooe5oo`80000309@000000081608000030ET000Ej00<5NP06000A
Va6K4I/001Fk0P00227K0`002Rgj0P000S7k00<003Gj=OX02SGj0P0000<j6P00?QT043hI00<0048I
@QT01T8I0P001dHi00<004XiBST04DXi00<004hhCSP044hh00<004hhCSP04Thh00<0059HDUP04e9H
00<005IhEWP04eIh0`0055Yh00<005jHGYP01ejH00<005jhG[P035jh00<005kIG]T00ekI00<006<K
Ha/02f<K00<004oKCm/01DoK0`0015nn0P001enn0`001enn0P001Unn00@005nN000000MOWP8000MO
WP8000QOWP04001OWP000007Gih20007Gih20007Fih20008Fih20007Fkh20008Fkh30004Fkh30006
Fkh20006Fkh20005Fkh30004Fmh20004Fmh20002Gmh2002HOol00`00Oomoo`2HOol00`00Oomoo`0<
Ool005Moo`03001oogoo0?mooe9oo`80000309@000000081608000030ET000Ej00<5NP04000AVa6K
00035K/00`008M/Qf`078M/00`00;OX]nP0:;OX3000>=OX3000@?QT00`00@QU26@08@QT30004AST0
0`00BSU:>@0ABST00`00CSQ>>00ACSP00`00CSQ>>00ACSP00`00DUQBF00CDUP00`00EWQFN00BEWP2
000GFWP00`00GYQNV004GYP2000?G[P01000G]UNfEkI0P003F<K00<004oKCm/014oK0P000e_N00@0
05nn000000MO_P8000QO_P8000QO_P8000MOWP8000MOWP8000YOWP8000MOWP8000MOWP8000MKWP80
009KWP03001KWU^N009KWP<000MK_P8000QK_P8000=K_P04001K_P000007Fkh20006Fkh20005Fkh2
0003Fkh01000Fmh0000015_N0P000UoN0P00Vgoo00<007ooOol0Ugoo00<007ooOol037oo001GOol0
0`00Oomoo`3oOomCOol200000`2D000000020AP00`000ET1F@0200031GX200000a6K000E^`025K/0
0`008M/Qf`078M/2000<;OX2000?=OX2000??QT00`00@QU26@0;@QT20003AST00`00BSU:>@0@BST0
0`00CSQ>>00ACSP00`00CSQ>>00BCSP00`00DUQBF00BDUP00`00EWQFN00?EWP300000eYG001JN00F
FWP00`00GYQNV003GYP00`00G[QN^00?G[P01000G]UNf@003F<K0P001DoK0P001E_N0P001enn0P00
25nn0P0025nn0P000UnN00<005nNGih00UnN0P001enN0P002EnN0`000UnN00<005nNGih00UnN0P00
1enN0P001e^N0P001E^N00@005^N000000QK_P8000MK_P<000EK_P8000MK_P8000EK_P<000EK_P80
00EK_P<000AKgP05001OgUoNGmh0002MOol00`00Oomoo`2GOol00`00Oomoo`0<Ool005Moo`03001o
ogoo0?mooeAoo`80000309@00000008160050001F@5I0ET000041GX200045K/200078M/00`009MX0
000<;OX2000>=OX01000>OT000003ShI00<0048I@QT0348I10004TXi00<004hhCSP04Dhh00<004hh
CSP04Thh00<0059HDUP04U9H00<005IhEWP035Ih0`0015YG00<005YhFWP05EYh00<005jHGYP00UjH
00<005jhG[P04Ejh0P003F<K00<004oKCm/00doK0P001E_N0P000U^n00<005nnGkh00Unn0P0025nn
0P0025nn0P001EnN00@005nN000000MOWP8000UOWP8000IOWP04001OWP000007Gih20007Fih20007
Fih20008Fkh20007Fkh20006Fkh20002Fkh00`00FkiK_P02Fkh20005Fkh20006Fkh20005Fkh20003
Gkh01000Fmh000000UoN0P00WWoo00<007ooOol0Ugoo00<007ooOol037oo001GOol00`00Oomoo`3o
OomFOol400020AP200020ET00`001GX5NP021GX200055K/00`008M/Qf`058M/010009MX000002Rgj
00<0037j00003CGj00@003Wi>OTin@8000`n6@0300126D8I00m26@<0015:>@03001>>4hh011>>003
001>>4hh019>>003001BF59H019BF003001FN5Ih00YFN08000QJE`03001JN5Yh01AJN003001NV5jH
008001=N^08000aS6`8000A?f`8000EKgP8000EK_P04001O_P000008Gkh20008Gkh20007Gih20007
Gih20009Gih20008Gih20007Gih20007Fih20007Fih20002Fih00`00FkiK_P02Fkh30007Fkh20006
Fkh20005Fkh01000Fkh000001E^n0P001U^n0P001E^n0P001Enn0`0000=OgP000000X7oo00<007oo
Ool0Ugoo00<007ooOol037oo001GOol00`00Oomoo`3oOomGOol60000104H0001F@5I0P000`Ej00<0
01Fk5K/011Fk0P001B7K00D002GJ9MXUfP0000X]nP04000anP00000<=OX00`00>OTin@02>OT2000:
?QT00`00@QU26@0?@QT00`00AQQ66003000>BST00`00CSQ>>00@CSP00`00CSQ>>00BCSP00`00DUQB
F00BDUP00`00EWQFN007EWP3000:FUL00`00FWQJN00EFWP2000DG[P00`00I_T0000;Ha/00`00Cm]?
f`02Cm/20005Fmh20007Fkh30007Gkh20008Gkh20007Gih20002Gih00`00GiiOWP02Gih20008Gih3
0007Gih30002Gih00`00GiiOWP02Gih20007Fih20007Fih20005Fih01000Fkh0000025^n0P001U^n
0P001e^n0P0015^n0`001U^n0P001E^n0P001Enn0P000UoN0P00XWoo00<007ooOol0Ugoo00<007oo
Ool037oo0007Ool4000>Ool3000?Ool3000=Ool6000FOol00`00Oomoo`3oOomHOol300001@3F0000
004H00000`5I00@000Ej1GX5NP8000HE^`03000Qfb7K008Qf`03000UfRGJ008UfP8000P]nP05000a
nS7j<OX0000;=OX00`00>OTin@04>OT20008?QT00`00@QU26@0?@QT00`00AQQ66003AQP4000:BST0
0`00CSQ>>00ACSP00`00CSQ>>00ACSP00`00DUQBF00BDUP00`00EWQFN005EWP2000=FUL00`00FWQJ
N00DFWP2000DG[P01@00I_UVnFKi00002F<K00<004oKCm/00ToK00<005_NFmh00e_N0P001e^n0P00
0e^n00<005nnGkh00Unn0P001enn0`001enN0P001EnN00@005nN000000QOWP8000QOWP8000IOWP04
001OWP000007Fih20007Fih20007Fih20008Fkh20006Fkh20007Fkh20002Gkh01000Fkh000001e^n
0P001E^n0P001Enn0P000UoN0P00Y7oo00<007ooOol0Ugoo00<007ooOol037oo0005Ool8000;Ool5
000>Ool3000;Ool:000DOol00`00Oomoo`3oOomIOol600000`4H0001F@020ET01P001GX5NP003GX0
00HE^`8000<Qf`03000UfRGJ00<UfP03000]nRgj00D]nP03000anS7j008anP8000TenP03000inCWi
00Hin@8000Ln6@0300126D8I00m26@03001664HH00I660<000M:>@03001>>4hh015>>003001>>4hh
019>>003001BF59H019BF004001FN5IhEWP3000?FUL00`00FWQJN00CFWP00`00GWL0000CG[P00`00
I_UVn@02I_T00`00Ha]S6`05Ha/20003Cm/20004Fmh20007Fkh20006Fkh01000Gkh000001enn0P00
25nN0P001enN0P0025nN0P0025nN0P0025nN0P001e^N0P001e^N0P001e^N0P000U^n00<005^nFkh0
0U^n0`001U^n0P001U^n0`0015nn0P001e^n0P001E^n0P001Enn0P000UoN0P00YWoo00<007ooOol0
V7oo00<007ooOol02goo0005Ool20004Ool2000;Ool5000?Ool2000;Ool30005Ool3000COol00`00
Oomoo`3oOomJOol200000`2D000000020AP01@000ET1F@5I00000PEj00<000ej00001aFk00@0027K
8M/000HUfP8000H]nP03000anS7j00<anP03000enSGj00LenP03000inCWi00Lin@8000Dn6@030012
6D8I00m26@03001664HH00U660@000=:>@03001>>4hh015>>003001>>4hh019>>003001BF59H019B
F0@0019JE`03001JN5Yh015JN080009NM`03001N^5jh011N^003001VnFKi00=Vn@03001S6f<K00AS
6`04001?fdoKCm/20005Fmh00`00FkiK_P05Fkh20008Fkh20007Gkh20008Gih20007Gih20002Gih0
0`00GiiOWP02Gih30007Gih30007Gih30002Gih00`00FiiKWP02Fih20007Fih20006Fih30005Fkh0
1000Fkh000001e^n0P001U^n0P001Enn0P000Unn00<005^nFkh00U^n0P001E^n0P001Enn0P000eoN
00<007ooOol0YWoo00<007ooOol0V7oo00<007ooOol02goo0004Ool20006Ool2000:Ool5000?Ool3
000COol2000COol8003oOomGOol0100009@000000P4H0P000P5I0`000Pej0P001QFk00@0027K8M/0
00LUfP03000]nRgj00<]nP03000anS7j00@anP8000LenP03000inCWi00Tin@8000<n6@0300126D8I
00m26@03001664HH00e660<00003BST004hh015>>003001>>4hh019>>003001BF59H011BF0<001IJ
E`03001JN5Yh00mJN003001NMeig009NM`03001N^5jh00mN^003001VnFKi00EVn@04001S6f<KHa/2
0002Cm/20005Fmh20006Fkh20008Fkh20002Fkh00`00GkiO_P02Gkh20007Gih30007Gih20005Gih0
1000Gih0000025nN0P0025nN0P001UnN00@005^N000000MKWP8000IKWP8000QK_P8000MK_P8000IK
_P8000EO_P8000EO_P04001K_P000005Fkh20005Gkh20003Gmh2002YOol00`00Oomoo`2HOol00`00
Oomoo`0;Ool000Aoo`8000Ioo`8000]oo`<0011oo`<001Aoo`80015oo`03001oogoo0?mooeioo`03
0000U0000080008160040001F@5I0ET200033GX00`005K/E^`045K/300089MX00`00;OX]nP02;OX0
0`00<OXanP06<OX20005=OX00`00>OTin@0;>OT200000chI00126@0@@QT00`00AQQ6600@AQP5000?
CSP00`00CSQ>>00BCSP00`00DUQBF00<DUP40002DSL00`00FUMJE`0DFUL00`00FWQJN00>FWP00`00
GWMNM`04GWL00`00G[QN^00<G[P20008I_T01000Ha]S6`000ToK0P001E_N0P001U^n0P0025^n0P00
1E^n00@005nn000000MOWP8000QOWP8000MOWP8000QOWP8000QOWP8000QOWP8000MKWP8000IKWP80
00QK_P80009O_P03001K_U^n009K_P8000IK_P8000EO_P8000MO_P<000AK_P8000EO_P8000=OgP80
0:]oo`03001oogoo09Qoo`03001oogoo00]oo`000goo0P0027oo0P007Woo0P0057oo0P004Goo00<0
07ooOol0ogooGgoo00D0002D0000e`00008160040001F@5I0ET200033GX00`005K/E^`055K/00`00
9MXUfP079MX20003;OX00`00<OXanP07<OX00`00=OXenP02=OX00`00>OTin@0=>OT3000@@QT00`00
AQQ6600AAQP01000BQQ:64XH1`002Dhh00<004hhCSP04Dhh00<0059HDUP0259H10001U8g00<005YG
FUL055YG00<005YhFWP035Yh0P001eig00<005jhG[P02ejh00<006KiI_T026Ki00<006<K00001000
15_N0P001U^n0P0025^n0P001e^n0P001enN0P0025nN0P001enN0P000UnN00<005nNGih00UnN0`00
1enN0`001enN0`000UnN00<005^NFih00U^N0P001U^N0P001e^n0`001Enn00@005^n000000IK_P80
00EO_P8000MO_P8000=O_P04001K_P000005Gkh20003Gmh2002]Ool00`00Oomoo`2HOol00`00Oomo
o`0;Ool000=oo`8000Qoo`8001ioo`<001=oo`80015oo`03001oogoo0?moof1oo`<000050=L0004H
0AP000030ET00`003GX=NP023GX200065K/200099MX01000;OX]nP002S7j0P000cGj00<003Wi>OT0
3SWi0P00448I00<004HHAQP044HH00<004XHBQP024XH1`000Thh00<004hhCSP04Thh00<0059HDUP0
0e9H10002U8g00<005YGFUL055YG00<005YhFWP02eYh00<005igGWL01eig00<005jhG[P02Ujh00<0
06KiI_T02VKi0`000e_l00@005_N000000IK_P8000QK_P8000IK_P<0009O_P03001OWUnN009OWP80
00MOWP<000MOWP8000EOWP04001OWP000008Gih20008Gih20006Gih01000Fih000001U^N0P001e^n
0P0025nn0`0015^n0`001Enn0P001Unn0`001Enn0`0015nn0P000eoN0P00[goo00<007ooOol0V7oo
00<007ooOol02goo0003Ool20008Ool2000OOol2000COol2000AOol00`00Oomoo`3oOomQOol30000
1@3G0001604H00000`5I0P0010ej00<001Fk5K/00aFk00<001fj00002BGJ0`00337j00@003Gj=OX0
010in@04000mn@00000>@QT00`00AQQ6600@AQP00`00BQQ:600?BQP>0009CSP00`00DUP00003000?
DSL00`00FUMJE`0CFUL00`00FWQJN009FWP2000:GWL00`00G[QN^009G[P00`00I_UVn@0:I_T00`00
10000004Fo`30005Fkh20007Fkh30006Fkh20006Gkh01000Gih000001enN0P0025nN0P001enN0P00
25nN0P0025nN0P0025nN0`0015^N0`001e^n0P0025nn0P000enn00@005^n000000IO_P8000IO_P80
00IO_P8000=O_P04001O_P000004Gmh00`00Oomoo`2_Ool00`00Oomoo`2HOol00`00Oomoo`0;Ool0
00=oo`8000Qoo`8001moo`8001=oo`80015oo`03001oogoo0?moof9oo`<000050=L0004H0AP00002
0ET00`000ET000043GX00`005K/E^`035K/00`007KX0000:9MX2000<<OX3000@>OT01000?OTmnCgi
0P00348I00<004HHAQP04DHH00<004XHBQP044XH00<004hgCSL02Dhg2`004e8g00<005YGFUL055YG
00<005YhFWP01eYh00<005igGWL02Uig00<005jhG[P025jh00<006KiI_T02VKi0`0015_l00@006?M
HmeSg@800003Fkh0000000MK_P8000MK_P8000QO_P8000MOWP8000QOWP8000MOWP80009OWP03001O
WUnN009OWP<000MOWP<000QOWP8000=OWP04001KWP000008Fkh20007Gkh30005Gkh20006Gkh20006
Gkh20006Gkh20005Gkh20004Gmh2002]Ool6002JOol00`00Oomoo`0;Ool000=oo`8000Qoo`8001mo
o`<0015oo`80019oo`03001oogoo0?moof=oo`H000070AP000000ET0005I000010ej0P000aFk00@0
01fj7KX000XUfP8000danP80010in@03000mnCgi008mn@8000Y26@03001664HH01566003001:64XH
011:6003001>=dhg019>=`03001B=e8g019B=`03001JEeYG01AJE`03001JN5Yh00IJN003001NMeig
00aNM`03001N^5jh00IN^003001VnFKi00YVn@8000AKo08000ESg@8000MK_P8000IK_P<000QO_P80
009OWP03001OWUnN009OWP8000QOWP8000MOWP8000EOWP04001OWP000008Gih20008Gih30005Gih2
0008Fkh20007Gkh20006Gkh200000enn001O_P03Gkh20006Gkh20006Gkh20005Gkh20002Gmh01000
Gmh00000Y7oo2`001Goo00<007ooOol0V7oo00<007ooOol02goo0003Ool20008Ool2000POol20009
Ool20005Ool3000BOol00`00Oomoo`3oOomTOol20000102E0000e`000P4H0P000P5I00<000ej3GX0
0`ej00D001Fk5K/E^`00008M^P8000PUfP03000YfP0000danP8000lin@03000mnCgi00@mn@8000U2
6@03001664HH01166003001:64XH011:6003001>=dhg019>=`03001B=e8g019B=`03001JEeYG01AJ
E`03001JN5Yh00AJN08000mNM`03001N^5jh00AN^08000aVn@8000AKo003001SgF?M00ASg@04001S
gF?M0004Fkh20006Fkh20008Gkh30005Gih01000Gih0000025nN0P001enN0P001enN0P0025nN0P00
25nN0P001UnN0P000UnN00<005^nFkh00U^n0`001enn0P001Unn0P0015nn00@005nn000000IO_P80
00IO_P8000EO_P8000AOgP8009aoo`X0015oo`03001oogoo09Moo`03001oogoo00]oo`000goo0P00
27oo0P0087oo0P002Goo2@004goo00<007ooOol0ogooIWoo00D0002E0000e`00008160800081F@03
000=NPej00<=NP04000E^aFk00047KX00`009MXUfP069MX00`00:MX0000<<OX00`00=MT0000>>OT0
0`00?OTmn@06?OT20007@QT00`00AQQ6600@AQP00`00BQQ:600ABQP00`00CSM>=`0ACSL00`00DSMB
=`0BDSL00`00FUMJE`0DFUL00`00FWQJN003FWP00`00GWMNM`0?GWL00`00G[QN^003G[P00`00I_UV
n@0;I_T20004Fo`00`00HmeSg@03Hmd20004Hmd01000Fkh000001U^n0P0025nn0P0025nN0`001enN
0P001enN0P001enN0P000UnN00<005nNGih00UnN0`0025nN0P001UnN0P001EnN00@005^n000000QO
_P8000IO_P8000IO_P<000AO_P<000IO_P8000EO_P8000AOgP8009Aoo`X001aoo`03001oogoo09Io
o`03001oogoo00]oo`000goo0P0027oo0P008Goo0P0027oo0P0000=oo`0000000`0057oo00<007oo
Ool0ogooIgoo00D0002E0000e`00008160800081F@8000@=NP<000DM^P03000UfRGJ00DUfP03000Y
fRWJ008000XanP03000efCGI008000`in@03000mnCgi00Pmn@8000E26@03001664HH01166003001:
64XH015:6003001>=dhg015>=`03001B=e8g019B=`03001JEeYG01AJE`04001JN5YhFWP2000BGWL0
0`00G[QN^002G[P00`00I_UVn@0;I_T00`00FoaKo002Fo`20004Hmd20006Hmd30004Fkh30008Gkh2
0008Gih20003Gih00`00GiiOWP02Gih20007Gih20007Gih20005Gih01000Gih000002EnN0P001UnN
0P001enN0P0025nn0P001Unn0P001Unn0P000enn00@005nn000000MO_P8000EO_P8000AOgP8008]o
o`/002Moo`03001oogoo09Eoo`03001oogoo00]oo`0017oo0P001Woo0P008Woo0P0027oo0P006Woo
00<007ooOol0ogooJ7oo00D0002E0000e`00008160030001F@5I0081F@03000=NPej00<=NP8000DM
^P8000DUfP03000YfRWJ008YfP03000anS7j00PanP05000efCGI=MT0000<>OT00`00?OTmn@09?OT2
0003@QT00`00AQQ6600@AQP00`00BQQ:600ABQP00`00CSM>=`0BCSL00`00DSMB=`0BDSL00`00FUMJ
E`0DFUL00`00FWP0000DGWL01@00G[QN^5jh00003FKi00<005_lFo`00U_l00<006?MHmd00f?M00<0
06?MHmd01F?M00H006>mHkeS_@00Fkh20009Gkh20007Gih30006Gih01000Gih000001enN0P001enN
0P001enN0`0025nN0P001UnN0P001enN0P000Unn00<005nnGkh00Unn0`001Unn0P001Unn0P001Enn
0P001enn0P001Enn0P0015oN0P00Pgoo2P00<Woo00<007ooOol0UGoo00<007ooOol02goo0004Ool2
0006Ool2000IOol20007Ool20008Ool2000JOol00`00Oomoo`3oOomYOol30000103G0001604H0P00
0`5I00<000ej3GX00`ej00<001fj7KX01Afj00<002GJ9MX00bGJ00<002WJ:MX00RWJ00<0037j<OX0
1c7j00<003GI=MT00SGI0P002SWi00<003gi?OT02cgi0P0000=26@00AQP04DHH00<004XHBQP04DXH
00<004hgCSL04Thg00<0058gDSL04U8g00<005YGFUL055YG0P005Uig00<005jh00003FKi00@005_l
FoaKo08000ASg@8000ISg@8000AS_@<000QO_P8000MOWP8000UOWP8000MOWP8000MOWP8000MOWP80
00=OWP03001OWUnN009OWP<000IOWP8000MOWP8000EO_P04001O_P000007Gkh20006Gkh20005Gkh2
0002Gkh00`00GkiO_P02Gkh20005Gkh20004Gmh2001kOol:000mOol00`00Oomoo`2DOol00`00Oomo
o`0;Ool000Eoo`8000Aoo`8001Yoo`8000Qoo`8000Moo`8001Yoo`03001oogoo0?moofYoo`<00006
0=L00000000160000`5I00<000ej3GX00`ej0P001Qfj00<002GJ9MX00RGJ00<002WJ:MX00bWJ0P00
1c7j00<003GI=MT013GI00<003Wi>OT01cWi00<003gi?OT03Cgi0`004THH00<004XHBQP044XH00<0
04hgCSL04Thg00<0058gDSL04U8g00<005YGFUL04eYG0P005eig0P003FKi00D005_lFoaKo00000AS
g@8000MSg@03001S_F>m00=S_@05001S_F>mHkd00004Gkh30007Gih20008Gih30002Gih00`00GiiO
WP02Gih20007Gih20006Gih30006Gih01000Gih000001enN0P001enN0P001enn0P001enn0P001Enn
0`001Enn0P001Enn00@005nn000000EO_P8000EOgP03001oogoo071oo`/004Qoo`03001oogoo09=o
o`03001oogoo00]oo`001Goo20006Woo30001goo2P004Woo00<007ooOol0ogooJgoo0`000P3G0P00
00<160000ET00P5I00<000ej3GX00Pej00<0015j00001Qfj00D002GJ9MXUfP0000LYfP03000anS7j
00DanP03000efCGI00@ef@8000Lin@03000mnCgi00lmn@8001566003001:64XH011:6003001>=dhg
019>=`03001B=e8g019B=`03001JEeYG015JE`800003FUH005ig01INM`03001VnFKi00]Vn@03001K
o5_l008000ASg@03001SgF?M00ESg@8000AS_@8000ES_@04001O_P000008Gih20008Gih20006Gih0
1000Gih000001enN0P001UnN0P002EnN0P001enN0P001enN0P001enn0P000Unn00<005nnGkh00Unn
0P001Enn0P001Unn0P001enn0`0015nn0P001EoN0P00JGoo2P00Dgoo00<007ooOol0Tgoo00<007oo
Ool02goo0007Ool4000LOol<0007Ool:000BOol00`00Oomoo`3oOom/Ool400001@3G0000004H0000
0`5I00<000ej3GX00Pej00<0015j00001Qfj0P000RGJ00<002WJ:MX01BWJ00<0037j<OX0137j00<0
03GI=MT01SGI0P001CWi00<003gi?OT03cgi00@0047h000000m66003001:64XH015:6003001>=dhg
015>=`03001B=e8g019B=`03001JEeYG011JE`05001JEUYFFUH0000GGWL00`00I_UVn@0:I_T01000
FoaKo00016?M0P001f?M00<006>mHkd00f>m00<006>mHkd01F>m0P0025nN0P0025nN0P0025nN0P00
1enN0P001UnN0P0025nN0`000UnN00<005nNGih00UnN0P001enN0P001Unn0`001Enn00@005nn0000
00EO_P8000IO_P8000MO_P8000=O_P04001O_P000005Gmh2001QOol:001NOol00`00Oomoo`2BOol0
0`00Oomoo`0;Ool005Ioo`03001oogoo0?moofeoo`80000409D0003G00020AP010000ET1F@5I0P00
0Pej00@0015j4GX000LM^P03000UfP0000PYfP8000@anP03000efCGI00Pef@03000inCWi00<in@03
000mnCgi00hmn@040011n47h@OP3000<AQP00`00BQQ:600ABQP00`00CSM>=`0ACSL00`00DSMB=`0B
DSL00`00FUMJE`0>FUL20004FUH00`00GWMNM`0DGWL00`00HYH0000:I_T01000FoaKo00016?M00<0
06?MHmd01F?M0P001F>m00<006>mHkd01F>m00@006>mHkd000AOWP<000MOWP<000QOWP80009OWP03
001OWUnN009OWP8000IOWP8000QOWP8000IOWP04001OWP000007Gih20006Gkh20008Gkh30004Gkh2
0006Gkh20007Gkh20005Gkh30004Gmh2001HOol;001YOol00`00Oomoo`2AOol00`00Oomoo`0;Ool0
05Eoo`03001oogoo0?moofmoo`80000409D0003G00020AP00`000ET1F@020ET00`003GX000034GX0
0`007KXM^P057KX2000::MX01@00<OXanS7j00002cGI0P000cWi00<003gi?OT03cgi00<0047h@OP0
0d7h0P002THH00<004XHBQP04DXH00<004hgCSL04Dhg00<0058gDSL04e8g00<005YGFUL02eYG0P00
1UYF00<005igGWL04eig00@006:FHYH000UVn@04001Ko0000003Hmd20006Hmd20005Hkd20006Hkd2
0004Hkd01000Gih0000025nN0P0025nN0`001EnN00@005nN000000IOWP8000QOWP8000QOWP8000MO
WP8000IO_P8000QO_P8000=O_P04001O_P000006Gkh20007Gkh20005Gkh20003Gkh01000Gmh00000
D7oo2P00MGoo00<007ooOol0T7oo00<007ooOol02goo001EOol00`00Oomoo`03003oOom]Ool20000
0`2E0000e`0200000`4H0001F@030ET00`003GX000034GX200067KX2000::MX01@00<OXanS7j0000
33GI00@003Wi>OT0014mn@030011n47h00E1n08000Q66003001:64XH015:6003001>=dhg015>=`03
001B=e8g01=B=`03001JEeYG00UJE`8000UJEP03001NMeig015NM`05001RUV:FHYH00008I_T00`00
Fo`00003Hmd20007Hmd00`00HkeS_@04Hkd00`00HkeS_@04Hkd20006Hkd20008Gih20008Gih20008
Gih30004Gih30007Gih30008Gih20002Gih00`00GiiOWP02Gih20006Gkh20007Gkh30005Gkh20006
Gkh20007Gkh20005Gkh20005Gkh20018Ool:001oOol00`00Oomoo`2AOol00`00Oomoo`0:Ool005Eo
o`<00?moog5oo`80000709D000000=L0004H0000105I0P001A5j00<001fj7KX011fj0P002RWJ0P00
00<anP00=MT033GI0`004Cgi00<0047h@OP01d7h0P001THH00<004XHBQP04DXH00<004hgCSL04Thg
00<0058gDSL04U8g00<005YGFUL025YG00<005YFFUH02EYF00<005igGWL045ig00<006:FHYH00f:F
00<006KiI_T016Ki1@0000=Sg@00Hmd01V?M0P001F>m0P001V>m00<006>mHkd01F>m00@006>mHkd0
00AOWP<000QOWP8000QOWP8000=OWP04001OWP000008Gih20008Gih30005Gih01000Gih000001Unn
0P001enn0P001Unn0P0000=O_P00Gkh00enn0P001enn0P001Enn0P001Enn0P00?goo2`00RWoo00<0
07ooOol0T7oo00<007ooOol02Woo001EOol00`00Oomoo`3oOombOol500000`3G0001600200030ET0
0`004GXANP044GX00`007KXM^P037KX00`008KX0000;:MX2000?=MT2000@?OT00`00@OQ1n009@OP2
0005AQP00`00BQQ:600@BQP00`00CSM>=`0BCSL00`00DSMB=`0BDSL00`00FUMJE`06FUL2000<FUH0
0`00GWMNM`0?GWL00`00HYIRUP04HYH00`00I_UVn@03I_T01000NeEkE@000Wmd0P001V?M00<006>m
Hkd016>m00<006>mHkd016>m0P001V>m0P0016>m00@005nN000000UOWP8000MOWP<000EOWP8000QO
WP8000QOWP8000QOWP<000AO_P<000MO_P8000IO_P8000AO_P04001O_P000007Gkh20005Gkh20005
Gkh2000gOol:002FOol00`00Oomoo`2?Ool00`00Oomoo`0:Ool005Eoo`03001oogoo0?moogAoo`@0
00050=L0004H0AP000030ET200054GX00`007KXM^P037KX00`008KX0000;:MX2000?=MT2000??OT0
0`00@OQ1n00;@OP30002AQP00`00BQQ:600ABQP00`00CSM>=`0ACSL00`00DSMB=`0BDSL00`00FUMJ
E`04FUL2000>FUH00`00GWMNM`0>GWL00`00HYIRUP06HYH01@00I_UVnFKi00000g]E00H007mdOg@0
07md0003Hmd20005Hkd20005Hkd20007Hkd00`00HkeS_@04Hkd30008Gih20007Gih20006Gih20002
Gih00`00GiiOWP02Gih30008Gih20008Gih20003Gih01000Gkh0000025nn0P001Unn0P001Unn0P00
1enn0P001Enn0P001Enn0P00;goo2P00XGoo00<007ooOol0SWoo00<007ooOol02Woo001EOol00`00
Oomoo`3oOomeOol300020=L010000AP160000P5I00<000EI00001A5j00<001fj7KX00Qfj00@0026j
8KX000/YfP8000hef@04000if000000>?OT00`00@OQ1n00=@OP3000CBQP00`00CSM>=`0ACSL00`00
DSMB=`0BDSL00`00FUMJE`02FUL2000@FUH00`00GWMNM`0=GWL00`00HYIRUP07HYH01000I_UVn@00
0g]E00D007mdOgAoM000009oM003001Sg@0000IS_@03001S_F>m00AS_@03001S_F>m00ES_@8000IS
_@05001S_F>mHkd00004Gih30007Gih20006Gih20005Gih01000Gih000002EnN0P001enN0`001EnN
0P0025nn0P001Unn0P001Unn0P000Unn00<005nnGkh00Unn0P001Enn0P001Enn0P009Woo2`00Zgoo
00<007ooOol0SWoo00<007ooOol02Woo001EOol00`00Oomoo`3oOomfOol300020=L010000AP16000
0P5I00<000EI00001A5j00D001fj7KXM^P0000<Q^P03000YfRWJ00PYfP03000]^@0000def@05000i
f3WH>MP0000=?OT00`00@OQ1n00?@OP3000ABQP00`00CSM>=`0ACSL00`00DSMB=`0CDSL01000FUMJ
E`004UYF00<005igGWL035ig00<006:FHYH026:F00@006Ki000000=kE@04001oM7md0004Og@00`00
HkeS_@04Hkd00`00HkeS_@03Hkd20007Hkd00`00HkeS_@04Hkd20005Hkd01000Gih0000025nN0P00
1UnN0P001enN0`0025nN0P001enN0P001UnN0P000UnN00<005nnGkh00Unn0`001Unn0P001Unn0P00
1Enn00@005nn000000EO_P8000EO_P8001ioo`X00;Moo`03001oogoo08eoo`03001oogoo00Yoo`00
EGoo00<007ooOol0ogooMgoo100000L0e`000AP160000ET000021ET00`004GXANP034GX200027KX0
10008KXQ^R6j0P0022WJ00@002fi;KT000`ef@03000if3WH008if08000/mn@030011n47h00m1n003
0015mdGg00<000i:6003001>=dhg015>=`03001B=e8g01=B=`<001=JEP03001NMeig00]NM`03001R
UV:F00YRUP03001ZeP0000=kE@04001oM7md0004Og@20003Hkd20005Hkd00`00HkeS_@05Hkd20006
Hkd00`00HkeS_@05Hkd20008Gih20006Gih20007Gih20003Gih00`00GiiOWP02Gih30007Gih20006
Gih20005Gih01000Gkh000001enn0P001Unn0P001enn0`0015nn0P001Enn0P005Woo2P00`Woo00<0
07ooOol0S7oo00<007ooOol02Woo001EOol00`00Oomoo`3oOomhOol20000102E0000e`000P4H00<0
005I00000PEI00<0015j4GX0115j00<001fj00001B6j00<002WJ:MX01RWJ00@002fi;KT000`ef@03
000if3WH00<if08000Tmn@030011n47h00m1n0030015mdGg00=5m`@000Y:6003001>=dhg015>=`03
001B=e8g015B=`<001IJEP03001NMeig00UNM`03001RUV:F00]RUP8000=kE@05001oM7mdOg@00004
Og@01@00Og@006>m00001F>m0P001V>m0P001V>m0P001f>m00@006>mHkd000AOWP<000IOWP8000MO
WP8000IOWP04001OWP000008Gih20006Gih20007Gih20007Gkh20006Gkh20007Gkh20003Gkh01000
Gkh000001Enn0P003Goo2`00c7oo00<007ooOol0S7oo00<007ooOol02Woo001EOol00`00Oomoo`3o
OomiOol200000`2E0000e`0200000`4H000000031ET00`004GXANP044GX00`007KX000058KX00`00
:MXYfP05:MX01000;KT]^Bfi0P002SGI00<003WH>MP01CWH00<003gi?OT01Sgi00<0047h@OP03d7h
00<004GgAOL01dGg0`001dXH00<004hgCSL04Dhg00<0058gDSL03U8g0`000U8f00<005YFFUH055YF
00<005igGWL025ig00<006:FHYH02f:F00<006[F00000g]E00D007mdOgAoM00000=oM004001oM7md
Og@20003Hkd20007Hkd00`00HkeS_@05Hkd00`00HkeS_@05Hkd20004Hkd01000Gih000001enN0P00
1enN0P0025nN0P0025nN0P001UnN0P001enN0P000UnN00<005nnGkh00Unn0P001enn00<005nnGkh0
1Enn0P001Enn0`0015nn0P001Goo2P00f7oo00<007ooOol0Rgoo00<007ooOol02Woo001EOol00`00
Oomoo`3oOomhOol01P00Ool0000009D00080e`040001600000031ET200054GX200068KX00`00:MXY
fP04:MX00`00;KT]^@03;KT00`00=MTef@07=MT00`00>MPif006>MP20007?OT00`00@OQ1n00?@OP0
0`00AOM5m`09AOL40004BQP00`00CSM>=`0@CSL00`00DSMB=`0:DSL40005DSH00`00FUIJEP0DFUH0
0`00GWMNM`07GWL00`00HYIRUP0<HYH00`00J]H00003NeD01000OgAoM00017md00T007mdOgAoM000
Og@006>m00001f>m0P001V>m0P001V>m0P001V>m0P001enN0P001enN0P001enN0`000UnN00<005nN
Gih00UnN0`001UnN0P001enN0P001EnN00@005nn000000MO_P8000IO_P8000EO_P8000=O_P/00>=o
o`03001oogoo08Yoo`03001oogoo00Yoo`00EGoo00<007ooOol0ogooN7oo00<007ooOol00P0000L0
U@000=L0e`000AP000051ET00`004GXANP034GX00`008KXQ^P058KX00`00:MXYfP03:MX00`00;KT]
^@04;KT00`00=MTef@06=MT00`00>MPif008>MP20005?OT00`00@OQ1n00?@OP00`00AOM5m`0=AOL3
00000dXH001>=`0BCSL00`00DSMB=`06DSL30009DSH00`00FUIJEP0DFUH00`00GWMNM`06GWL00`00
HYIRUP0<HYH00`00J]H00004NeD01000OgAoM00017md00D007mdOgAoM000009oM08000IS_@03001S
_F>m00AS_@8000MS_@03001S_F>m00ES_@04001S_F>m0004Gih20007Gih20007Gih20006Gih01000
Gih000001enN0P001enN0P001enN0P001enn0P001Unn0P000Unn3000kGoo00<007ooOol0RGoo00<0
07ooOol02Woo001EOol00`00Oomoo`3oOomhOol00`00Oomoo`02Ool300020=L010000AP0000010EI
00<0015j4GX00a5j0P001R6j00<002WJ:MX00bWJ00<002fi;KT012fi0P001SGI00<003WH>MP02SWH
00<003gi?OT00Sgi00<0047h@OP03d7h00<004GgAOL044Gg1`003Thg00<0058gDSL00U8g1000358f
00<005YFFUH055YF00<005igGWL01Eig00<006:FHYH03F:F00<006[F00000g]E00D007mdOgAoM000
00AoM004001oM7md0003Og@00`00Og@00003Hkd20006Hkd00`00HkeS_@05Hkd20006Hkd20004Hkd0
1000Gih000001enN0P001enN0P0025nN0P001enN0P001enN0P001enN0P000UnN00<005nnGkh00Unn
0P000Unn2P0000=O_P0000001Enn0P00kgoo00<007ooOol0RGoo00<007ooOol02Woo001EOol00`00
Oomoo`3oOomhOol00`00Oomoo`03Ool300020=L200000`4H0005F@031ET00`004GXANP024GX00`00
5GX000068KX20003:MX00`00;KT]^@06;KT00`00=MTef@04=MT00`00>MPif00:>MP20002?OT00`00
@OQ1n00?@OP00`00AOM5m`0AAOL00`00CQM>5`03CQL:0004CSL00`00DSL00002000@DSH00`00FUIJ
EP0DFUH00`00GWMNM`04GWL00`00HYIRUP0=HYH01000J]IZeP000g]E00@007mdOg@000AoM005001o
M7mdOg@00003Og@01P00OgAoM000Hkd000IS_@8000IS_@8000MS_@03001S_F>m00AS_@8000MOWP80
00IOWP<000QOWP80009OWP03001OWUnN009OWP8000MOWP8000MOWP8000=OWPX000=O_P8000AO_P80
00EO_P800?9oo`03001oogoo08Qoo`03001oogoo00Yoo`00EGoo00<007ooOol0ogooN7oo00<007oo
Ool017oo0`000P3G0P0000<160001ET00`EI00<0015j4GX00Q5j00<001Ej00001b6j00@002WJ:MX0
00T]^@03000efCGI00<ef@03000if3WH00`if0<00151n0030015mdGg0155m`03001>5dhG00e>5`H0
01AB=P03001JEUYF01=JEP03001NMeig00=NM`03001RUV:F00eRUP04001ZeV[F0004NeD01000OgAo
M00017md00D007mdOgAoM000009oM003001oM7md009oM003001S_F>m00AS_@03001S_F>m00ES_@03
001S_F>m00ES_@8000IS_@04001S_F>m0004Gih20006Gih20008Gih30005Gih01000Gih000001enN
0P000enN2`000UnN0P001enn0P0015nn0P001Unn00<007ooOol0lgoo00<007ooOol0Qgoo00<007oo
Ool02Woo001DOol00`00Oomoo`3oOomiOol00`00Oomoo`05Ool400001@3G0000004H000010EI0P00
0Q5j00@001Ej5GX000LQ^P03000YfP0000X]^@03000efCGI008ef@03000if3WH00hif0800111n003
0015mdGg0155m`03001>5dhG015>5`03001B=U8f01=B=P03001JEUYF01=JEP03001NMeig009NM`03
001RUV:F00iRUP04001ZeV[F0004NeD01000OgAoM00017md00D007mdOgAoM000009oM003001oM7md
009oM08000=S_@8000IS_@8000MS_@03001S_F>m00AS_@8000AS_@04001OWP000006Gih20008Gih2
0008Gih20004Gih:0002Gih20007Gih20002Gih00`00GkiO_P02Gkh20004Gkh20006Gkh2003gOol0
0`00Oomoo`26Ool00`00Oomoo`0:Ool005Aoo`03001oogoo0?moogUoo`03001oogoo00Ioo`800004
09D0003G00020AP00`001ET5F@031ET010004GXANP000QEj00<0026j8KX01B6j0P002bfi0P000SGI
00<003WH>MP03cWH0P00447h00<004GgAOL044Gg00<004hGCQL04DhG00<0058fDSH04e8f00<005YF
FUH055YF00@005igGWL0011RUP05001ZeV[FJ]H00003NeD01@00OgAoM7md00000gmd00D007mdOgAo
M00000=oM003001oM7md009oM005001oM000Hkd00007Hkd00`00HkeS_@05Hkd20006Hkd00`00HkeS
_@04Hkd30004Gih30008Gih20006Gih:00000enN00000007Gih20007Gih20005Gih01000Gkh00000
15nn0P001Unn0P00nGoo00<007ooOol0QWoo00<007ooOol02Woo001DOol00`00Oomoo`3oOomiOol0
0`00Oomoo`07Ool20000102E0000e`000P4H00<000EI1ET00`EI00<0015j00000aEj00<0026j8KX0
1B6j0P0032fi00<003GI00004CWH00<003gH00003d7h00<004GgAOL044Gg00<004hGCQL04DhG00<0
058fDSH04e8f00<005YFFUH055YF00<005ig00004F:F00D006[FJ]IZeP0000=kE@04001oM7md0004
Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM003001S_F>m00AS_@8000IS_@8000IS_@80
00ES_@8000=S_@04001OWP000008Gih=0005Gih01000Gih000001enN0P001enN0P001enN0P0015nn
0P001Unn0P00o7oo00<007ooOol0QGoo00<007ooOol02Woo001DOol00`00Oomoo`3oOomiOol00`00
Oomoo`08Ool200000`2E0000e`0200000`4H000000041ET200045GX00`008KXQ^P058KX2000<;KT0
0`00=MT0000@>MP00`00?MPmf002000=@OP00`00AOM5m`0AAOL00`00CQM>5`0@CQL00`00DSIB=P0C
DSH00`00FUIJEP0DFUH2000AHYH01@00J]IZeV[F000017]E00@007mdOg@000AoM005001oM7mdOg@0
0002Og@00`00OgAoM002Og@01000OgAoM7md0P000f>m0P001f>m00<006>mHkd01F>m00<006>mHkd0
16>m00<006>mHkd00f>m3@001enN0P0025nN0P001enN0P001enN0P001enN0P000V>N00@005nn0000
00IO_P800?moo`03001oogoo08Aoo`03001oogoo00Yoo`00E7oo1P00ogooMWoo00<007ooOol02Goo
0P0000D0U@000000e`00008160030005F@EI0085F@8000@ENP03000Q^R6j00@Q^P03000QV@0000`]
^@80010if003000mf3gH008mf0030011n47h00Y1n0030015mdGg0155m`03001>5dhG015>5`03001B
=U8f019B=P03001JEUYF01=JEP80019RUP05001ZeV[FJ]H00003NeD01@00OgAoM7md000017md00@0
07mdOg@000=oM003001oM7md009oM009001oM7mdOg@007md001S_@0000MS_@8000IS_@8000ES_@X0
0003Hkd005nN00=OWP<000MOWP8000QOWP80009OWP03001OWUnN009OWP8000MOWP8000MOWP8000AS
WP8000MO_P03001oogoo0?moo`5oo`03001oogoo08=oo`03001oogoo00Yoo`00E7oo00<007ooOol0
ogooNGoo00<007ooOol02Woo1@0000D0e`000AP1600000@5F@03000ENQEj00<ENP8000DQ^P03000Q
V@0000`]^@80010if003000mf3gH008mf08000Y1n0030015mdGg0155m`03001>5dhG015>5`03001B
=U8f019B=P03001JEUYF019JEP03001NEP00015RUP03001ZeV[F009ZeP05001kEG]ENeD00003Og@0
1@00OgAoM7md00000gmd00D007mdOgAoM00000AoM004001oM7md0003Og@20006Hkd00`00HkeS_@02
Hkd;0005Hkd20005Hkd01000Gih0000025nN0P001enN0`001EnN00@005nN000000MOWP8000MOWP80
00ASWP80009SWP03001O_Unn009O_P800?moo`Aoo`03001oogoo08Aoo`03001oogoo00Uoo`00E7oo
00<007ooOol0ogooNGoo00<007ooOol037oo100000D0e`000AP1600000@5F@8000DENP03000Q^R6j
008Q^P04000QVB6I000;;KT00`00<KP0000?>MP00`00?MPmf004?MP00`00@OQ1n008@OP00`00AOM5
m`0@AOL00`00CQM>5`0ACQL00`00DSIB=P0BDSH00`00FUIJEP0AFUH01000GUINEP004F:F00D006[F
J]IZeP0000AkE@04001oM7md0004Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM006001o
M7mdOg@007md2`0000=S_@00Hkd01F>m00<006>mHkd016>m00<006>mHkd01F>m0P0025nN0P001enN
0P0025nN0P001enN0P001enN0P001F>N00<006>NHih00f>N00@005nn00000?moo`Moo`03001oogoo
08=oo`03001oogoo00Uoo`00E7oo00<007ooOol0ogooNGoo00<007ooOol03Goo0`000P3G00@0004H
0AP000<5F@030005F@0000DENP05000Q^R6j8KX000038IT00`00;KT]^@08;KT01000<KPa^0003SWH
00<003gH?MP01CgH0P00247h00<004GgAOL044Gg00<004hGCQL04DhG00<0058fDSH04U8f00<005YF
FUH045YF00D005iFGUINEP00011RUP03001ZeV[F009ZeP03001kEG]E009kE@04001oM7md0004Og@0
1@00OgAoM7md00000Wmd00<007mdOg@00Wmd300000=S_@00Hkd01F>m0P001F>m0P001F>m0P001f>m
00@006>mHkd000AOWP<000MOWP8000QOWP80009OWP03001OWUnN009OWP8000MOWP8000ESWP8000IS
WP800?moo`Yoo`03001oogoo089oo`03001oogoo00Uoo`00E7oo00<007ooOol0ogooNGoo00<007oo
Ool03Woo0`000P3G00<0004H0AP00P000PEI00<000EI00001AEj00D0026j8KXQ^P0000<QV@03000]
^Bfi00P]^@04000a^36h000=>MP00`00?MPmf007?MP20006@OP00`00AOM5m`0@AOL00`00CQM>5`0A
CQL00`00DSIB=P0BDSH00`00FUIJEP0?FUH00`00GUINEP03GUH00`00HYIRUP0<HYH00`00J]IZeP03
J]H01@00NeEkEG]E00000gmd00<007mdOg@00Wmd00<007md00002P000gmd00@007mdOg@000AoM003
001S_F>m00AS_@03001S_F>m00=S_@8000IS_@03001S_F>m00ES_@8000AS_@04001OWP000008Gih2
0007Gih30005Gih01000Gih000001enN0P001F>N0P001V>N0P00ogoo37oo00<007ooOol0PWoo00<0
07ooOol02Goo001DOol00`00Oomoo`3oOomiOol00`00Oomoo`0?Ool400000`3G000160020AP00`00
1ET000021ET00`005GXENP035GX010008KXQ^P00126I0P0022fi00@0036h<KPa^08000/if003000m
f3gH00Tmf0030011n47h00=1n0030015mdGg0115m`03001>5dhG015>5`03001B=U8f01=B=P03001J
EUYF00eJEP03001NEUiF00ANEP03001RUV:F00aRUP03001ZeV[F009ZeP03001kEG]E009kE@/00003
Og@007md009oM005001oM7mdOg@00003Og@01@00OgAoM7md000017md0P000f>m0P001F>m00<006>m
Hkd016>m0P001f>m00<006>mHkd016>m0P0025nN0P001enN0P0025nN0P001enN0P001F>N0P001f>N
00<007ooOol0ogoo3Goo00<007ooOol0PGoo00<007ooOol02Goo001DOol00`00Oomoo`3oOomiOol0
0`00Oomoo`0@Ool20000102E0000e`000`4H00<000EI00000PEI00<001Ej5GX00aEj00<0026j0000
1R6I00<002fi;KT01Bfi00<0036h<KP00c6h00<003WH>MP023WH00<003gH?MP02SgH0P000d7h00<0
04GgAOL044Gg00<004hGCQL04DhG00<0058fDSH04e8f00<005YFFUH035YF00<005iFGUH01EiF00<0
06:FHYH02f:F00<006[F00002@000Wmd00<007mdOg@00Wmd00D007mdOgAoM00000=oM005001oM7md
Og@00003Og@01@00OgAoM7md000017md00D007md001S_@0000ES_@8000IS_@03001S_F>m00ES_@80
00IS_@04001W_FNm0004Gih30007Gih20008Gih20002Gih00`00GiiOWP02Gih20006Hih00`00HiiS
WP05Hih2003oOolAOol00`00Oomoo`20Ool00`00Oomoo`09Ool005Aoo`03001oogoo0?moogUoo`03
001oogoo015oo`80000409D0003G00030AP200031ET00`005GXENP035GX00`008KX000068IT00`00
;KT]^@04;KT00`00<KPa^004<KP00`00>MPif007>MP00`00?MPmf00<?MP01000@OQ1n0004TGg00<0
04hGCQL04DhG00<0058fDSH04e8f00<005YFFUH02eYF00<005iFGUH01UiF00<006:FHYH00V:F2`00
16[F00<007]ENeD00W]E00@007mdOg@000AoM005001oM7mdOg@00002Og@00`00OgAoM002Og@01@00
OgAoM7md00000gmd00D007mdOgAoM00000=oM08000=S_@8000MS_@03001S_F>m00ES_@03001S_F>m
00AS_@8000AW_@04001OWP000008Gih20007Gih30005Gih01000Gih000001V>N0P001V>N0P00ogoo
57oo00<007ooOol0Ogoo00<007ooOol02Goo001DOol00`00Oomoo`3oOomiOol00`00Oomoo`0BOol2
0000102E0000e`000`4H0P000`EI00<001Ej5GX00aEj0P001b6I00<002fi;KT012fi00<0036h<KP0
136h00<003WH>MP01cWH00<003gH?MP033gH0P0000=1n000AOL04DGg00<004hGCQL04DhG00<0058f
DSH04U8f00<005YFFUH02UYF00<005iFGUH00UiF2P0026:F00<006[FJ]H00f[F00<007]ENeD00W]E
00D007mdOgAoM00000AoM004001oM7md0003Og@00`00OgAoM002Og@01@00OgAoM7md00000Wmd00<0
07mdOg@00Wmd00T007mdOgAoM000Og@006>m00001f>m0P001V>m0P001V>m00<006NmIkd016Nm0P00
25nN0P001enN0P0025nN0P001V>N0P001V>N0P00ogoo5Woo00<007ooOol0Ogoo00<007ooOol02Goo
001DOol00`00Oomoo`3oOomiOol00`00Oomoo`0COol20000102E0000e`000`4H00<000EI1ET00PEI
00<001Ej5GX00aEj00<0026I8IT01R6I00<002fi;KT00bfi00<0036h<KP01C6h0P001cWH00<003gH
?MP03SgH0P004TGg00<004hGCQL04DhG00<0058fDSH04U8f00<005YFFUH01EYF2P001EiF00<006:F
HYH02V:F00<006[FJ]H00f[F00<007]ENeD00W]E00@007mdOg@000AoM005001oM7mdOg@00003Og@0
1@00OgAoM7md00000gmd00D007mdOgAoM00000AoM005001oM7mdOg@00002Og@20006Hkd00`00HkeS
_@04Hkd20006Hkd20006Ikd01000IkeW_@0015nN0`001enN0P0025nN0P000V=m00<006>NHih00V>N
00<006>NHih01F>N00<007ooOol0ogoo5goo00<007ooOol0OWoo00<007ooOol02Goo001DOol00`00
Oomoo`3oOomiOol00`00Oomoo`0EOol300000`3G000160020AP00`001ET5F@021ET00`005GXENP03
5GX200078IT20003;KT00`00<KPa^007<KP00`00>MPif004>MP00`00?MPmf00??MP2000AAOL00`00
CQM>5`0ACQL00`00DSIB=P0?DSH;0003FUH00`00GUINEP09GUH00`00HYIRUP09HYH00`00J]IZeP04
J]H00`00NeEkE@02NeD01000OgAoM00017md00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@0
1@00OgAoM7md000017md00@007mdOg@000=oM003001oM00000=S_@8000IS_@03001S_F>m00ES_@03
001W_FNm00AW_@8000AW_@04001OWP000008Gih20008Gih20005Hgd01000Hih000001V>N0P00ogoo
6goo00<007ooOol0OGoo00<007ooOol02Goo001COol00`00Oomoo`3oOomjOol00`00Oomoo`0FOol3
0000103G0001604H0P0010EI00<001Ej5GX00QEj00<001Ei0000226I00D002fi;KT]^@0000Ta^003
000if3WH00<if003000mf3gH00lmf0040011e`00000?AOL00`00CQM>5`0ACQL00`00DSIB=P05DSH:
0003DSH00`00FUIJEP07FUH00`00GUINEP0;GUH00`00HYIRUP08HYH00`00J]IZeP04J]H01@00NeEk
EG]E00000gmd00<007mdOg@00Wmd00D007mdOgAoM000009oM003001oM7md009oM005001oM7mdOg@0
0003Og@01@00OgAoM7md00000gmd00D007mdOgAoM000009oM003001S_@0000IS_@8000IS_@8000IW
_@03001W_FNm00AW_@8000QOWP8000QOWP8000MSO@8000ISWP800?mooaioo`03001oogoo07aoo`03
001oogoo00Uoo`00Dgoo00<007ooOol0ogooNWoo00<007ooOol05goo0`0000@0e`000AP1608000@5
F@03000ENQEj008ENP03000EN@0000PQV@04000]^Bfi000:<KP00`00>MPif002>MP00`00?MPmf00?
?MP01000@MM1ed7G0P003DGg00<004hGCQL03dhG2P003E8f00<005YFFUH01UYF00<005iFGUH035iF
00<006:FHYH01f:F00<006[FJ]H016[F00<007]ENeD00W]E00D007mdOgAoM00000=oM005001oM7md
Og@00003Og@00`00OgAoM002Og@01@00OgAoM7md00000Wmd00<007mdOg@00Wmd00D007mdOgAoM000
009oM003001oM7md009oM003001S_F>m00AS_@03001S_F>m00AS_@8000IW_@8000IW_@04001WWFNM
0004Gih30008Gih20007Hgd20002Ie`00`00HiiSWP02Hih00`00Oomoo`3oOolNOol00`00Oomoo`1l
Ool00`00Oomoo`09Ool005=oo`03001oogoo0?moogYoo`03001oogoo01Qoo`<000060=L0004H0001
600010EI00D001Ej5GXENP00008EN@03000QVB6I00HQV@03000]^@0000/a^080008if003000mf3gH
00lmf0030011ed7G00=1e`030015mdGg00Y5m`03001>5dhG00A>5`/0009>5`03001B=U8f019B=P03
001JEUYF00EJEP03001NEUiF00eNEP03001RUV:F00IRUP03001ZeV[F00EZeP03001kEG]E009kE@04
001oM7md0004Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00004Og@0
1@00OgAoM7md00000Wmd00<007mdOg@00Wmd0P000f>m0P001V>m00<006NmIkd01FNm00<006NmIkd0
16Nm0P0016NM00@005nN000000UOWP8000MSO@8000EWG004001SWP00003oOolROol00`00Oomoo`1k
Ool00`00Oomoo`09Ool005=oo`03001oogoo0?moogYoo`03001oogoo01Uoo`<000060=L0004H0001
600010EI00@001Ej5GX000<EN@03000QVB6I00HQV@8000da^003000if000014mf0030011ed7G00A1
e`8000M5m`X000e>5`03001B=U8f019B=P03001JEUYF00AJEP03001NEUiF00iNEP03001RUV:F00IR
UP03001ZeV[F00EZeP03001kEG]E009kE@04001oM7md0004Og@01@00OgAoM7md00000gmd00D007md
OgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00<007mdOg@00Wmd00D007md
001S_@0000IS_@8000IW_@8000IW_@03001WWFNM00AWW@8000UOWP8000QSO@03001WG6ML00EWG080
0?moobEoo`03001oogoo07Yoo`03001oogoo00Uoo`00Dgoo00<007ooOol0ogooNWoo00<007ooOol0
6Woo0`0000<0e`0000000P4H00<000EI1ET00PEI00@001Ej5GX000<EN@03000QVB6I00HQV@8000da
^003000if000014mf0030011ed7G0091e`X000=5m`03001>5dhG015>5`03001B=U8f019B=P03001J
EUYF00=JEP03001NEUiF00mNEP03001RUV:F00ERUP03001ZeV[F00EZeP03001kEG]E009kE@05001o
M7mdOg@00004Og@01000OgAoM0000gmd00<007mdOg@00Wmd00D007mdOgAoM00000=oM005001oM7md
Og@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000IS_@03001W_FNm00AW_@8000IW_@80
00IWW@03001WW@0000MOWP8000QSO@8000MWG003001oogoo0?moobEoo`03001oogoo07Yoo`03001o
ogoo00Uoo`00Dgoo00<007ooOol0ogooNWoo00<007ooOol06goo0`0000<0e`000AP00P4H00<000EI
1ET00PEI00<001Ej000011Ei00<0026I8IT01R6I0P003C6h0P002cgH2`001D7G0P001TGg00<004hG
CQL04ThG00<0058fDSH04U8f00D005YFFUIJEP00019NEP03001RUV:F00ERUP03001ZeV[F00EZeP03
001kEG]E009kE@05001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00<007mdOg@00Wmd00D007md
OgAoM000009oM003001oM7md009oM005001oM7mdOg@00002Og@00`00OgAoM002Og@01000OgAoM7md
0P000f>m0P001VNm00<006NmIkd01FNm00<006NMIid016NM0P000fNM00<005nNGih00UnN0P0026=m
0P001fML0P00ogoo:Goo00<007ooOol0NGoo00<007ooOol02Goo001COol00`00Oomoo`03003oOomg
Ool00`00Oomoo`0LOol300000`3G000000020AP00`001ET5F@021ET00`005GX000045GT00`008ITQ
V@058IT00`009IT0000=<KP<0006?MP00`00@MM1e`09@ML20005AOL00`00CQM>5`0ACQL00`00DSIB
=P0BDSH01000FUIJEP0055iF00<006:FHYH00f:F00<006[FJ]H01V[F00<007]ENeD00W]E00@007md
Og@000AoM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000AoM005001o
M7mdOg@00002Og@00`00OgAoM002Og@02@00OgAoM7md001oM000Hkd00006Ikd20006Ikd20006Iid0
0`00IieWW@04Iid01000Gih0000026=m0P0026ML00<007ooOol0ogoo:Woo00<007ooOol0N7oo00<0
07ooOol02Goo001COol3003oOomjOol00`00Oomoo`0MOol400001@3G0001604H000010EI0P001AEi
00<0026I8IT0126I00@002FI9IT000@a^0/000lmf0030011ed7G00]1e`030015mdGg0095m`03001>
5dhG015>5`03001B=U8f019B=P03001JEP0001ENEP03001RUV:F00=RUP03001ZeV[F00EZeP03001k
EG]E009kE@05001oM7mdOg@00004Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001o
M7mdOg@00003Og@01@00OgAoM7md00000gmd00<007mdOg@00Wmd00@007mdOg@000=oM003001W_FNm
00AW_@03001W_FNm00AW_@8000IWW@8000MWW@8000QSO@8000QWG0800?moobioo`03001oogoo07Mo
o`03001oogoo00Uoo`00Dgoo00<007ooOol0ogooNWoo00<007ooOol07Woo100000D0e`000AP16000
00@5F@03000ENAEi00@EN@03000QVB6I00/000Pa^004000aV36H000>?MP00`00@MM1e`0<@ML20002
AOL00`00CQM>5`0ACQL00`00DSIB=P0BDSH2000FGUH00`00HYIRUP02HYH00`00J]IZeP06J]H00`00
NeEkE@02NeD01@00OgAoM7md000017md00@007mdOg@000=oM003001oM7md009oM005001oM7mdOg@0
0003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@20003Ikd2
0006Ikd00`00IieWW@05Iid00`00IieWW@06Iid00`00Ie`00007Hgd00`00IeaWG007Ie`00`00Oomo
o`3oOol^Ool00`00Oomoo`1gOol00`00Oomoo`09Ool005=oo`03001oogoo0?moogYoo`03001oogoo
01moo`@000050=L0004H0AP000031ET:00048IT01@009ITUVBFI00002c6h00@0036H<IP000dmf003
0011ed7G00i1e`<001=>5`03001B=U8f015B=P8001MNEP03001RUV:F009RUP03001ZeV[F00IZeP03
001kEG]E009kE@05001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000AoM004
001oM7md0004Og@01@00OgAoM7md00000Wmd00<007mdOg@00Wmd00D007mdOgAoM00000=oM005001o
M000Ikd00006Ikd20006Iid20007Iid20003Ie`00`00HgeSO@02Hgd20008Ie`2003oOolbOol00`00
Oomoo`1gOol00`00Oomoo`08Ool005=oo`03001oogoo0?moogYoo`03001oogoo021oo`/000031ET0
000000HEN@03000QVB6I008QV@03000UVBFI008UV@03000a^36h00Pa^005000aV36H<IP0000<?MP0
0`00@MM1e`0@@ML3000ACQL00`00DSIB=P0>DSH300000e8F001NEP0FGUH01@00HYIRUV:F000026[F
00<007]ENeD00g]E00@007mdOg@000AoM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D0
07mdOgAoM00000AoM004001oM7md0003Og@00`00OgAoM002Og@01@00OgAoM7md00000Wmd00D007md
OgAoM00000IW_@03001WWFNM00AWW@8000MWW@8000IWG004001SO@000008Ie`2003oOoleOol00`00
Oomoo`1fOol00`00Oomoo`08Ool005=oo`03001oogoo0?moogYoo`03001oogoo01Ioo`h00080e`04
0001604H00031ET200065GT00`008ITQV@028IT00`009ITUV@029IT00`00<KPa^007<KP00`00<IPa
V002<IP00`00?MPmf009?MP00`00@MM1e`0@@ML00`00AMI5eP03000>CQL00`00DSIB=P0;DSH30004
DQH00`00GUINEP0EGUH01000HYIRUP002F[F00<007]ENeD00W]E00D007mdOgAoM00000AoM005001o
M7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@0
0`00OgAoM002Og@01000OgAoM0000gmd00@007mdOgAoM08000=W_@8000IWW@03001WWFNM00IWW@03
001WG6ML00IWG08000UWG003001oogoo0?moocIoo`03001oogoo07Eoo`03001oogoo00Qoo`00Dgoo
00<007ooOol0ogooNWoo00<007ooOol037oo2P0037oo100000D0e`000AP160000085F@030005>@00
00HEN@05000QVB6I8IT000059IT00`00<KPa^006<KP00`00<IPaV003<IP00`00?MPmf009?MP00`00
@MM1e`0?@ML00`00AMI5eP03AMH4000:CQL00`00DSIB=P08DSH30007DQH00`00GUINEP0EGUH01000
HYIRUP002F[F00<007]ENeD00W]E00D007mdOgAoM00000AoM004001oM7md0003Og@00`00OgAoM002
Og@01@00OgAoM7md00000Wmd00<007mdOg@00Wmd00D007mdOgAoM00000=oM005001oM7mdOg@00003
Og@01@00OgAoM7md00000gmd00D007md001W_@0000IWW@8000MWW@8000QWG003001Vn@0000MWG080
0?moocUoo`03001oogoo07Eoo`03001oogoo00Qoo`00Dgoo00<007ooOol0ogooNWoo00<007ooOol0
0Woo2P005goo0P0000@0U@000=L0008160060005F@EI0005>@001QEi00@0026I8IT000HUV@03000a
^36h00Da^003000aV36H00@aV003000mf3gH00Pmf0030011ed7G00m1e`030015eTGF00M5eP<000Q>
5`03001B=U8f00AB=P<000YB5P03001NEUiF01INEP8000UZeP03001kEG]E00=kE@04001oM7md0004
Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000AoM004001oM7md0004Og@01@00OgAoM7md0000
0Wmd00<007mdOg@00Wmd00D007mdOgAoM00000=oM004001oM7md0003Og@00`00IieWW@04Iid00`00
IieWW@06Iid00`00IeaWG007Ie`01@00I_UVnFKi00001FML00<007ooOol0ogoo>Woo00<007ooOol0
M7oo00<007ooOol027oo001COol00`00Oomoo`3oOomdOol;000ROol20000102E0000e`000P4H00<0
00EI00000PDi00<001Ei5GT011Ei00@0026I8IT000HUV@03000a^36h00Da^003000aV36H00@aV003
000mf3gH00Lmf0030011ed7G00m1e`030015eTGF00Y5eP@000A>5`04001B=U8fDSH3000=DQH00`00
GUINEP0FGUH20009J]H00`00NeEkE@03NeD01000OgAoM00017md00D007mdOgAoM00000=oM005001o
M7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM003001oM7md009oM005001o
M7mdOg@00002Og@01@00OgAoM7md00000gmd0P000fNM0P001fNM0P0026ML0P001FKi00<006MLIe`0
0P00ogoo?Woo00<007ooOol0Lgoo00<007ooOol027oo001BOol00`00Oomoo`3oOom[Ool:0006Ool0
0`00Oomoo`0UOol20000102E0000e`000P4H0P000`Di00<001Ei5GT011Ei00<0026I00001bFI00<0
036h<KP0136h00<0036H<IP01C6H0P001cgH00<0047G@ML03d7G00<004GFAMH03TGF0`0000=>5`00
00000P004E8F00<005iFGUH05EiF00<006[FJ]H026[F00<007]ENeD00W]E00D007mdOgAoM00000Ao
M005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@0
0003Og@00`00OgAoM002Og@01000OgAoM0000gmd00D007mdOgAoM00000=oM005001oM000Iid00008
Iid00`00IeaWG007Ie`00`00I_UVn@05I_T00`00Ie`0003oOom0Ool00`00Oomoo`1cOol00`00Oomo
o`08Ool0059oo`03001oogoo0?moof5oo`X0011oo`03001oogoo02Ioo`80000409D0003G00020AP2
00031CT00`005GTEN@045GT200089IT00`00<KPa^003<KP00`00<IPaV007<IP00`00?MPmf004?MP0
0`00@MM1e`0@@ML00`00AMI5eP0@AMH2000DDQH00`00GUINEP0EGUH00`00J]IZeP08J]H00`00NeEk
E@02NeD01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM003001oM7md009oM005001oM7mdOg@0
0002Og@00`00OgAoM002Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@0
0003Og@01000OgAoM0000gmd0P001VNM0P002FML00<006KiI_T01fKi00<007ooOol0ogoo@7oo00<0
07ooOol0LWoo00<007ooOol027oo001BOol00`00Oomoo`3oOomFOol;000JOol00`00Oomoo`0WOol2
0000102E0000e`000P4H00<000Di1CT00PDi00<001Ei5GT011Ei0P0022FI00<0036h<KP00S6h00<0
036H<IP0236H00<003gH?MP00cgH00<0047G@ML0447G00<004GFAMH04DGF00<0058FDQH04U8F00<0
05iFGUH055iF0P002F[F00<007]ENeD00g]E00@007mdOg@000AoM005001oM7mdOg@00003Og@01@00
OgAoM7md000017md00@007mdOg@000AoM005001oM7mdOg@00002Og@00`00OgAoM002Og@01@00OgAo
M7md00000gmd00@007mdOg@000=oM007001oM7mdOg@007md00000fNM0P002FML0P002FKi00<007oo
Ool0ogoo@Woo00<007ooOol0LGoo00<007ooOol027oo001BOol00`00Oomoo`3oOom<Ool:000UOol0
0`00Oomoo`0XOol20000102E0000e`000P4H00<000Di1CT00PDi00<001Ei5GT011Ei00<002FI9IT0
1bFI00<0036h<KP00S6h00<0036H<IP0236H00<003gH?MP00SgH00<0047G@ML0447G00<004GFAMH0
4DGF00<0058FDQH04U8F00<005iFGUH055iF0P002F[F00<007]ENeD00W]E00D007mdOgAoM00000Ao
M005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@0
0003Og@00`00OgAoM002Og@01000OgAoM0000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00002
Og@00`00Iid0000:Ie`00`00I_UVn@08I_T00`00Oomoo`3oOom4Ool00`00Oomoo`1`Ool00`00Oomo
o`08Ool0059oo`03001oogoo0?mood9oo`X002moo`03001oogoo02Uoo`80000609D0003G00016000
1@Di00<001Ei5GT00aEi00<002FI9IT022FI00D0036h<KPa^00000/aV005000mf3gH?MP0000B@ML0
0`00AMI5eP0AAMH00`00DQIB5P0BDQH00`00GUINEP0CGUH00`00GUD00009J]H00`00NeEkE@02NeD0
1@00OgAoM7md000017md00@007mdOg@000AoM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd
00D007mdOgAoM00000=oM003001oM7md009oM004001oM7md0003Og@01@00OgAoM7md00000gmd00@0
07mdOg@000AoM003001WG6ML00MWG08000YVn@03001oogoo0?moodEoo`03001oogoo071oo`03001o
ogoo00Qoo`00DWoo00<007ooOol0ogoo=goo2`00>7oo00<007ooOol0:goo0P0000H0U@000=L0004H
00051CT00`005GTEN@035GT00`009ITUV@089IT01000<KPa^000336H00@003gH?MP00191e`030015
eTGF0155eP03001B5U8F019B5P03001NEUiF01=NEP04001NEEiE0007J]H00`00NeEkE@03NeD01@00
OgAoM7md00000gmd00D007mdOgAoM00000=oM003001oM7md009oM005001oM7mdOg@00002Og@00`00
OgAoM002Og@01@00OgAoM7md00000Wmd00<007mdOg@00Wmd00D007mdOgAoM00000=oM004001oM7md
0003Og@01@00OgAoM7md000017md00<006MLIe`01VML00<006KiI_T02FKi00<007ooOol0ogooAgoo
00<007ooOol0Kgoo00<007ooOol027oo001BOol00`00Oomoo`3oOol]Ool:0013Ool00`00Oomoo`0/
Ool200000`2E0000e`0300051CT00`005GTEN@025GT2000:9IT00`00<KP0000=<IP01000?MPmf000
4D7G00<004GFAMH04DGF00<0058FDQH04U8F00<005iFGUH04UiF00D005iEGUENE@0000MZeP03001k
EG]E00=kE@04001oM7md0004Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000AoM004001oM7md
0004Og@01@00OgAoM7md00000Wmd00<007mdOg@00Wmd00D007mdOgAoM000009oM005001oM7mdOg@0
0003Og@01@00OgAoM7md000017md0P001VML00<006KiI_T02FKi00<007ooOol0ogooBGoo00<007oo
Ool0KWoo00<007ooOol027oo001BOol00`00Oomoo`3oOolSOol:001=Ool00`00Oomoo`0]Ool20000
0`2E0000e`0300051CT01`005GTENAEi000EF@0000XUV@8000haV003000mf0000151e`030015eTGF
0155eP03001B5U8F019B5P03001NEUiF015NEP03001NEEiE009NE@03001ZeV[F00EZeP03001kEG]E
009kE@05001oM7mdOg@00004Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7md
Og@00003Og@01@00OgAoM7md00000gmd00<007mdOg@00Wmd00@007mdOg@000=oM005001oM7mdOg@0
0003Og@01@00OgAoM7md00000gmd00<007nb000016ML0P002fKi00<007ooOol0ogooBgoo00<007oo
Ool0KGoo00<007ooOol027oo001BOol00`00Oomoo`3oOolHOol;001GOol00`00Oomoo`0^Ool20000
0`2E0000e`0300051CT01`005GTENAEi000EF@0000XUV@8000haV0800151e`030015eTGF0155eP03
001B5U8F019B5P03001NEUiF015NEP03001NEEiE009NE@03001ZeV[F00AZeP03001kEG]E00=kE@05
001oM7mdOg@00004Og@01000OgAoM0000gmd00<007mdOg@00Wmd00D007mdOgAoM00000=oM005001o
M7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@0
1000OgAoM00017md00@007nbOk80009WG003001VnFKi00YVn@03001oogoo0?moodaoo`03001oogoo
06eoo`03001oogoo00Qoo`00DWoo1P00ogoo2goo2P00HWoo00<007ooOol0;goo0P0000H0U@000=L0
003h00051CT010005GTEN@000QEI00<002FI9IT022FI00<0036H<IP03C6H0P00447G00<004GFAMH0
4TGF00<0058FDQH04E8F00<005iFGUH045iF00<005iEGUD00eiE00<006[FJ]H016[F00<007]ENeD0
0g]E00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md000017md00@007mdOg@0
00AoM005001oM7mdOg@00002Og@00`00OgAoM002Og@01@00OgAoM7md00000gmd00@007mdOg@000=o
M005001oM7mdOg@00004Og@01P00Ok9o/P00Ie`000aVn@03001oogoo0?moodioo`03001oogoo06ao
o`03001oogoo00Qoo`00DWoo00<007ooOol0ogoo17oo2P00K7oo00<007ooOol0<7oo0P0000H0U@00
0=L0003h00051CT00`005GT000035ET00`009ITUV@079IT00`00<IPaV00=<IP00`00<GH0000?@ML0
0`00AMI5eP0BAMH00`00DQIB5P0ADQH00`00GUINEP0@GUH00`00GUENE@03GUD00`00J]IZeP04J]H0
0`00NeEkE@02NeD01@00OgAoM7md000017md00D007mdOgAoM00000=oM005001oM7mdOg@00004Og@0
1000OgAoM00017md00D007mdOgAoM000009oM003001oM7md009oM005001oM7mdOg@00002Og@01@00
OgAoM7md00000gmd00D007mdOgAoM00000AoM005001o/WnbOk80000<I_T00`00Oomoo`3oOom@Ool0
0`00Oomoo`1[Ool00`00Oomoo`08Ool0059oo`03001oogoo0?Qoo`/007Ioo`03001oogoo035oo`80
000309D000000080n0030005>@Di00<5>@03000EN@0000<EF@03000UVBFI00HUV@8000haV004000a
MS5f000>@ML00`00AMI5eP0BAMH00`00DQIB5P0BDQH00`00GUINEP0>GUH00`00GUENE@04GUD00`00
J]IZeP03J]H00`00NeEkE@03NeD01@00OgAoM7md000017md00D007mdOgAoM00000=oM005001oM7md
Og@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM003001oM7md009oM004001oM7md
0003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM003001o/Wnb009o/P03001VnFKi00UV
n@03001oogoo0?mooe5oo`03001oogoo06]oo`03001oogoo00Qoo`00DWoo00<007ooOol0kWoo2P00
PGoo00<007ooOol0<Woo0P0000<0U@0000000P3h00<000Di1CT00`Di0P0011EI00<002FI9IT01RFI
0P003C6H00D0035f<GHaMP0000i1e`030015eTGF0155eP03001B5U8F019B5P03001NEUiF00iNEP03
001NEEiE00ANE@03001ZeV[F00=ZeP03001kEG]E00=kE@05001oM7mdOg@00004Og@01000OgAoM000
0gmd00<007mdOg@00Wmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md0000
0gmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01000OgAoM00017md00<007nbOk800Wnb
00<006KiI_T026Ki00<007ooOol0ogooDgoo00<007ooOol0JWoo00<007ooOol027oo001BOol00`00
Oomoo`3TOol:002;Ool00`00Oomoo`0cOol200000`2E000000020?P00`001CT5>@031CT00`005ETE
F@035ET00`009ITUV@059IT00`009GP0000=<IP01@00<GHaMS5f00003D7G00<004GFAMH04DGF00<0
058FDQH04U8F00<005iFGUH03EiF00<005iEGUD01UiE00<006[FJ]H00V[F00<007]ENeD00g]E00D0
07mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md000017md00@007mdOg@000AoM005
001oM7mdOg@00002Og@00`00OgAoM002Og@01@00OgAoM7md00000gmd00@007mdOg@000=oM005001o
M7mdOg@00004Og@01`00Ok9o/Wnb000TK@0000QVn@03001oogoo0?mooeEoo`03001oogoo06Yoo`03
001oogoo00Moo`00DWoo00<007ooOol0fGoo2`00UGoo00<007ooOol0=7oo0P0000<0U@0000000P3h
00<000Di1CT00`Di00<001EI5ET00aEI00<002FI9IT012FI00@002Eh9GP000`aV003000aMS5f008a
MP030011ed7G00Y1e`030015eTGF0155eP03001B5U8F019B5P03001NEUiF00eNEP03001NEEiE00IN
E@03001ZeV[F009ZeP03001kEG]E009kE@05001oM7mdOg@00004Og@01@00OgAoM7md00000gmd00D0
07mdOgAoM00000=oM005001oM7mdOg@00003Og@00`00OgAoM002Og@01000OgAoM00017md00D007md
OgAoM000009oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00<007nbOk800Wnb00<002A]
00001fKi00<007ooOol0ogooEgoo00<007ooOol0JGoo00<007ooOol01goo001AOol00`00Oomoo`3@
Ool:002POol00`00Oomoo`0eOol200000`2E000000020?P00`001CT5>@021CT00`005ETEF@045ET0
0`009ITUV@039IT01@009GPUN2Eh00002c6H00<0035f<GH00c5f00<0047G@ML02D7G00<004GFAMH0
4DGF00<0058FDQH04U8F00<005iFGUH035iF00<005iEGUD01eiE00D006[FJ]IZeP0000EkE@05001o
M7mdOg@00004Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@0
1@00OgAoM7md00000gmd00<007mdOg@00Wmd00@007mdOg@000=oM005001oM7mdOg@00003Og@01@00
OgAoM7md00000gmd00<007nbOk800Wnb00<002A]00001VKi00<007ooOol0ogooF7oo00<007ooOol0
JGoo00<007ooOol01goo001AOol00`00Oomoo`36Ool:002ZOol00`00Oomoo`0fOol200000`2E0000
00020?P00`001CT5>@021CT00`005ETEF@045ET00`009ITUV@039IT010009GPUN0002c6H00<0035f
<GH0135f00<0047G@ML0247G00<004GFAMH04DGF00<0058FDQH04U8F00<005iFGUH02eiF00<005iE
GUD025iE00D006[FJ]IZeP0000EkE@05001oM7mdOg@00004Og@01000OgAoM0000gmd00<007mdOg@0
0Wmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAo
M00000=oM005001oM7mdOg@00003Og@01000OgAoM00017md00D007nbOk9o/P0000<TK@03001VnFKi
009Vn@03001oogoo0?mooeYoo`03001oogoo06Qoo`03001oogoo00Moo`00DGoo00<007ooOol0^goo
2`00]7oo00<007ooOol0=goo0`0000D0]P000?P0n00000<5>@8000HEF@03000UVBFI008UV@05000U
N2Eh9GP0000:<IP00`00<GHaMP05<GH00`00@MM1e`07@ML00`00AMI5eP0AAMH00`00DQIB5P0BDQH0
0`00GUINEP0;GUH00`00GUENE@08GUD01@00J]IZeV[F00001G]E00@007mdOg@000AoM005001oM7md
Og@00003Og@01@00OgAoM7md000017md00@007mdOg@000AoM005001oM7mdOg@00002Og@00`00OgAo
M002Og@01@00OgAoM7md00000gmd00@007mdOg@000=oM005001oM7mdOg@00004Og@01@00Ok9o/Wnb
00000bA]00D006KiI_UVn@000?mooeioo`03001oogoo06Moo`03001oogoo00Moo`00DGoo00<007oo
Ool0/Goo2P00_goo00<007ooOol0>7oo0`0000D0]P000?P0n0000085>@030005600000HEF@05000U
VBFI9IT000049GP00`00<IPaV007<IP00`00<GHaMP06<GH00`00@MM1e`06@ML00`00AMI5eP0AAMH0
0`00DQIB5P0BDQH00`00GUINEP0:GUH00`00GUENE@09GUD01000J]IZeP001G]E00D007mdOgAoM000
00AoM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM003001oM7md
009oM004001oM7md0004Og@01@00OgAoM7md00000Wmd00D007mdOgAoM00000=oM005001oM7mdOg@0
0003Og@00`00Ok9o/P02Ok801@0096dTKBA]00000VKi00<007ooOol0ogooGWoo00<007ooOol0IWoo
00<007ooOol01goo001AOol00`00Oomoo`2WOol:0039Ool00`00Oomoo`0iOol300001@2f0000n03h
00000PDi00<000DH00001QEI00D002FI9ITUV@0000@UN003000aV36H00LaV003000aMS5f00HaMP03
0011ed7G00E1e`030015eTGF0155eP03001B5U8F019B5P03001NEUiF00YNEP03001NEEiE00UNE@04
001ZeV[F0005NeD01@00OgAoM7md000017md00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@0
1@00OgAoM7md00000gmd00D007mdOgAoM00000=oM003001oM7md009oM004001oM7md0003Og@01@00
OgAoM7md00000gmd00D007mdOgAoM00000=oM005001o/WnbOk80000596d2003oOomQOol00`00Oomo
o`1VOol00`00Oomoo`07Ool0055oo`03001oogoo09aoo`/00==oo`03001oogoo03Yoo`<000070;H0
003h0?P000Di00000PDH00<001EI5ET011EI00@002FI9IT000DUN003000aV36H00HaV003000aMS5f
00LaMP030011ed7G00A1e`030015eTGF0155eP03001B5U8F019B5P03001NEUiF00UNEP03001NEEiE
00YNE@04001ZeV[F0005NeD01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM003001oM7md009o
M005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@0
0003Og@01@00OgAoM7md00000gmd00@007mdOg@000AoM005001o/WnbOk80000596d00`00Oomoo`3o
OomQOol00`00Oomoo`1UOol00`00Oomoo`07Ool0055oo`03001oogoo099oo`X00=ioo`03001oogoo
03]oo`<000040;H0003h0?P200031AP00`005ETEF@045ET00`009IT000069GP00`00<IPaV005<IP0
0`00<GHaMP08<GH00`00@MM1e`03@ML00`00AMI5eP0AAMH00`00DQIB5P0BDQH00`00GUINEP09GUH0
0`00GUENE@0:GUD00`00J]H00005NeD01@00OgAoM7md000017md00D007mdOgAoM00000=oM005001o
M7mdOg@00004Og@01000OgAoM00017md00D007mdOgAoM000009oM003001oM7md009oM005001oM7md
Og@00003Og@01000OgAoM0000gmd00D007mdOgAoM00000AoM005001o/WnbOk80000596d00`00Oomo
o`3oOomROol00`00Oomoo`1TOol00`00Oomoo`07Ool0055oo`03001oogoo08Qoo`X00>Qoo`03001o
ogoo03aoo`<000040;H0003h0?P200021AP00`005ETEF@055ET200069GP00`00<IPaV005<IP00`00
<GHaMP09<GH00`00@MM1e`02@ML00`00AMI5eP0AAMH00`00DQIB5P0CDQH00`00GUINEP07GUH00`00
GUENE@0<GUD20005NeD01@00OgAoM7md000017md00D007mdOgAoM00000=oM005001oM7mdOg@00003
Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM003001oM7md009oM005001oM7mdOg@00002
Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001o/WnbOk80000596d00`00Oomoo`3o
OomTOol00`00Oomoo`1SOol00`00Oomoo`07Ool003Aoo`X001=oo`03001oogoo07eoo`/00?9oo`03
001oogoo03eoo`<000050;H0003h0?P000031AP00`005ETEF@055ET200069GP00`00<IPaV004<IP0
0`00<GHaMP0:<GH00`00@MM1e`02@ML00`00AMI5eP0@AMH00`00DQIB5P0CDQH00`00GUINEP07GUH0
0`00GUENE@0<GUD20005NeD01@00OgAoM7md000017md00@007mdOg@000AoM005001oM7mdOg@00003
Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM003001oM7md009oM004001oM7md0003Og@0
1@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001o/WnbOk80000596d00`00Oomoo`3oOomT
Ool00`00Oomoo`1SOol00`00Oomoo`07Ool003Aoo`X001=oo`03001oogoo07=oo`X00?eoo`03001o
ogoo03ioo`<000040;H0003h00041AP00`005ETEF@055ET00`009GPUN0059GP00`00<IPaV003<IP0
0`00<GHaMP0;<GH01@00@MM1ed7G00004dGF00<0058FDQH04U8F00<005iFGUH01UiF00<005iEGUD0
3EiE00<007]ENeD017]E00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@00`00OgAoM002Og@0
1@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md0000
0gmd00@007mdOg@000AoM004001oM7md0004Og@01@00Ok9o/Wnb000012A]00<007ooOol0ogooIWoo
00<007ooOol0HWoo00<007ooOol01goo000hOol2000GOol00`00Oomoo`1YOol:003oOol8Ool00`00
Oomoo`0oOol30000102f0000n00010DH00<001EI5ET011EI00<002Eh9GP01REh00<0036H<IP00c6H
00<0035f<GH02c5f00@0047G@ML001=5eP03001B5U8F019B5P03001NEUiF00ENEP03001NEEiE00iN
E@03001kEG]E00=kE@05001oM7mdOg@00004Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000Ao
M004001oM7md0003Og@00`00OgAoM002Og@01000OgAoM00017md00D007mdOgAoM00000=oM004001o
M7md0003Og@01@00OgAoM7md00000gmd00<007nbOk800Wnb00D002A]96dTK@000?moofYoo`03001o
ogoo065oo`03001oogoo00Moo`00>7oo0P005goo00@007ooOomoo`@005Uoo`/00?mooa9oo`03001o
ogoo041oo`<000040;H0000000041AP00`005ETEF@035ET200089GP00`00<IPaV002<IP00`00<GHa
MP0<<GH00`00@ML0000CAMH00`00DQIB5P0BDQH00`00GUINEP05GUH00`00GUENE@0>GUD00`00NeEk
E@03NeD01@00OgAoM7md000017md00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAo
M7md00000gmd00D007mdOgAoM00000=oM003001oM7md009oM005001oM7mdOg@00002Og@01@00OgAo
M7md00000gmd00D007mdOgAoM00000=oM005001o/WnbOk80000496d00`00Oomoo`3oOomXOol00`00
Oomoo`1QOol00`00Oomoo`07Ool003Qoo`8001Moo`@005=oo`X00?mooaeoo`03001oogoo049oo`80
00040;H0000000041AP00`005ETEF@035ET200089GP01@00<IPaV36H00003c5f0P004dGF00<0058F
DQH04U8F00<005iFGUH015iF00<005iEGUD03eiE0P0017]E00D007mdOgAoM00000AoM004001oM7md
0004Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@00`00OgAo
M002Og@01000OgAoM0000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00Ok9o/Wnb
00000bA]00<007ooOol0ogooJWoo00<007ooOol0H7oo00<007ooOol01goo000hOol2000GOol00`00
Oomoo`1:Ool:003oOolWOol00`00Oomoo`13Ool20000102f0000000010DH00<001EI5ET00QEI00<0
014h00001bEh00D0036H<IPaV000010aMP800195eP03001B5U8F019B5P03001NEUiF00ANEP03001N
EEiE00iNE@03001oM00000AkE@05001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAo
M00000AoM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001o
M7mdOg@00002Og@00`00OgAoM002Og@01000OgAoM00017md00D007nbOk9o/P0000<TK@03001oogoo
0?moof]oo`03001oogoo05moo`03001oogoo00Moo`00>7oo0P005goo00<007ooOol0?goo2`00ogoo
<Goo00<007ooOol0A7oo0P0000@0]P000=L000@56007000EFAEI5ET0014h000022Eh00@0036H<IP0
010aMP03000]E@000155eP03001B5U8F019B5P03001NEUiF00=NEP03001NEEiE00mNE@04001oM7md
0002NeD01@00OgAoM7md000017md00D007mdOgAoM00000=oM005001oM7mdOg@00004Og@01000OgAo
M0000gmd00<007mdOg@00Wmd00@007mdOg@000AoM005001oM7mdOg@00003Og@01000OgAoM0000gmd
00D007mdOgAoM00000=oM005001o/WnbOk80000396d00`00Oomoo`3oOom]Ool00`00Oomoo`1NOol0
0`00Oomoo`07Ool003Qoo`8001Ioo`8003Moo`X00?moocaoo`03001oogoo04Aoo`<000040;H0003G
00031AP01@005ETEFAEI00000Q4h00<002Eh9GP01REh00<0036H0000435f00@002eE;ED00115eP03
001B5U8F019B5P03001NEUiF00=NEP03001NEEiE00mNE@04001oM7md0002NeD01@00OgAoM7md0000
17md00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAo
M00000=oM003001oM7md009oM004001oM7md0003Og@01@00OgAoM7md00000gmd00D007mdOgAoM000
00=oM005001o/WnbOk80000396d00`00Oomoo`3oOom]Ool00`00Oomoo`1NOol00`00Oomoo`07Ool0
03Qoo`8001Ioo`8002eoo`X00?moodIoo`03001oogoo04Eoo`@00080e`05000560DH1AP000035ET0
10004CPA>00022Eh00<0036H00003c5f00D002eE;ED]E@0000m5eP03001B5U8F019B5P03001NEUiF
009NEP03001NEEiE011NE@07001oM7mdOg@007]E00000gmd00<007mdOg@00Wmd00@007mdOg@000Ao
M005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM003001oM7md009o
M004001oM7md0003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001o/WnbOk800002
96d00`00Oomoo`3oOom_Ool00`00Oomoo`1MOol00`00Oomoo`07Ool003Qoo`8001Ioo`80029oo`/0
0?mooe1oo`03001oogoo04Ioo`@00080e`05000560DH1AP000025ET01@004CPA>14h000022Eh0P00
3c5f00<002eE;ED00ReE0P003DGF00<0058FDQH04U8F00<005iFGUH00UiF00<005iEGUD03eiE00<0
07mdOg@00Wmd0P000gmd00<007mdOg@00Wmd00D007mdOgAoM00000=oM005001oM7mdOg@00004Og@0
1@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md0000
0Wmd00<007mdOg@00Wmd00@007mdOg@000AoM004001o/Wnb000296d00`00Oomoo`3oOomaOol00`00
Oomoo`1MOol00`00Oomoo`06Ool003Qoo`8001Ioo`03001oogoo01Moo`X00?mooe]oo`03001oogoo
04Moo`@00080e`07000560DH1AP001EI00000a4h00<002Eh9GP01bEh00<0035f<GH03S5f00<002eE
;ED00beE00<004GFAMH02TGF00<0058FDQH04e8F00@005iFGUH0019NE@03001oM7md00=oM005001o
M7mdOg@00004Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000AoM004001oM7md0003Og@00`00
OgAoM002Og@01000OgAoM00017md00D007mdOgAoM000009oM005001oM7mdOg@00003Og@01@00OgAo
M7md00000gmd00D007nbOk9o/P00008TK@03001oogoo0?moog9oo`03001oogoo05aoo`03001oogoo
00Ioo`00>7oo0P005Woo00<007ooOol03Goo2P00ogooIGoo00<007ooOol0B7oo10000P3G00@000DH
1AP5608000@A>003000UN2Eh00HUN003000aMS5f00haMP03000]EBeE00@]E@030015eTGF00U5eP03
001B5U8F01=B5P03001NEP0001=NE@03001oM7md00=oM005001oM7mdOg@00004Og@01@00OgAoM7md
00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00<007md
Og@00Wmd00@007mdOg@000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00L007nbOk9o
/P0096d0003oOomeOol00`00Oomoo`1LOol00`00Oomoo`06Ool003Qoo`8001Ioo`03001oogoo009o
o`/00?moofmoo`03001oogoo04Uoo`@000030=L000DH00<5608000@A>003000UN2Eh00DUN08000la
MP03000]EBeE00D]E@030015eTGF00Q5eP03001B5U8F01=B5P03001NEP0001=NE@03001oM7md00=o
M080009oM005001oM7mdOg@00003Og@00`00OgAoM002Og@01@00OgAoM7md00000gmd00D007mdOgAo
M00000=oM005001oM7mdOg@00003Og@00`00OgAoM002Og@01000OgAoM0000gmd00D007mdOgAoM000
00=oM005001oM7mdOg@00003Og@01000Ok9o/P000RA]00<007ooOol0ogooM7oo00<007ooOol0Fgoo
00<007ooOol01Woo000hOol2000FOol5003oOomjOol00`00Oomoo`1:Ool400000`3G000560031AP0
0`004CPA>0034CP00`009GPUN0049GP00`007CL0000><GH00`00;ED]E@06;ED20008AMH00`00DQIB
5P0CDQH2000CGUD00`00OgAoM003Og@00`00OgAoM0020004Og@01@00OgAoM7md00000gmd00D007md
OgAoM00000AoM004001oM7md0004Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001o
M7mdOg@00002Og@00`00OgAoM002Og@01000OgAoM0000gmd00L007nbOk9o/P0096d0003oOomhOol0
0`00Oomoo`1JOol00`00Oomoo`06Ool003Qoo`8001Qoo`800?moog]oo`03001oogoo04]oo`800004
09D0003G00031AP00`004CPA>0044CP00`009GPUN0049GP2000><GH00`00;ED]E@08;ED00`00AMI5
eP05AMH00`00DQIB5P0CDQH2000CGUD00`00OgAoM003Og@01000OgAoM7md0P000gmd00D007mdOgAo
M00000=oM005001oM7mdOg@00004Og@01000OgAoM0000gmd00<007mdOg@00Wmd00@007mdOg@000Ao
M005001oM7mdOg@00002Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM007001o/WnbOk80
02A]0000ogooN7oo00<007ooOol0FWoo00<007ooOol01Woo000dOol300000goo0000000JOol2003o
OomiOol00`00Oomoo`1<Ool20000102E0000e`000`DH00<0014h4CP00a4h00<002Eh9GP012Eh00<0
01dg00003C5f00<002eE;ED02BeE00<004GFAMH014GF00<0058FDQH04U8F0P0055iE00<007mdOg@0
0gmd00L007mdOgAoM000Og@00002Og@01000OgAoM00017md00D007mdOgAoM00000=oM005001oM7md
Og@00003Og@01@00OgAoM7md00000gmd00<007mdOg@00Wmd00@007mdOg@000=oM005001oM7mdOg@0
0003Og@01@00OgAoM7md00000gmd00@007nbOk9o/P800?moogYoo`03001oogoo05Uoo`03001oogoo
00Ioo`00=7oo1P0077oo0P00ogooMgoo00<007ooOol0CGoo0P0000@0U@000=L00085608000DA>003
000UN2Eh00<UN004000M=adg000<<GH00`00;ED]E@0:;ED00`00AMI5eP04AMH00`00DQIB5P0>DQH3
00000e7e001NE@0CGUD00`00OgAoM003Og@01@00OgAoM7md00000Wmd0P000gmd00<007mdOg@00Wmd
00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00<007mdOg@00Wmd
00@007mdOg@000=oM005001oM7mdOg@00003Og@01000OgAoM00017md00<007nbOk800P00ogooO7oo
00<007ooOol0F7oo00<007ooOol01Woo000gOol3000NOol2003oOomeOol00`00Oomoo`1>Ool20000
102E0000e`000PDH0P001A4h00<002Eh9GP00REh00@001dg7CL000`aMP03000]EBeE00/]E@030015
eTGF00=5eP03001B5U8F00]B5P<000AAm@03001NEEiE019NE@03001oM7md009oM005001oM7mdOg@0
0004Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000AoM004001oM7md0003Og@00`00OgAoM002
Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM004001oM7md0004Og@01000OgAoM0000gmd
00@007nbOk9o/P800?moogeoo`03001oogoo05Moo`03001oogoo00Ioo`00FWoo0P00ogooLgoo00<0
07ooOol0Cgoo0P0000P0U@000=L000DH0000m`001A4h00D002Eh9GPUN00000<M=`03000aMS5f00Ta
MP03000]EBeE00`]E@8000=5eP03001B5U8F00QB5P<000MAm@03001NEEiE015NE@03001oM7md00=o
M005001oM7mdOg@00004Og@20002Og@01@00OgAoM7md00000gmd00<007mdOg@00Wmd00@007mdOg@0
00=oM003001oM7md009oM004001oM7md0004Og@01@00OgAoM7md00000Wmd00D007mdOgAoM00000=o
M005001oM7mdOg@00003Og@01@00Ok9o/Wnb0000ogooOWoo00<007ooOol0Egoo00<007ooOol01Woo
001LOol2003oOomaOol00`00Oomoo`1@Ool300020=L200020?L00`004CPA>0024CP00`009GPUN002
9GP010007CLM=`00335f00<002eE;ED03BeE00@004GFAMH000MB5P<000YAm@03001NEEiE015NE@03
001oM7md00=oM005001oM7mdOg@00004Og@01000Og@0000017md00D007mdOgAoM00000=oM005001o
M7mdOg@00003Og@01@00OgAoM7md00000gmd00<007mdOg@00Wmd00@007mdOg@000=oM005001oM7md
Og@00003Og@01@00OgAoM7md00000gmd00<007nbOk800P00ogooOgoo00<007ooOol0EWoo00<007oo
Ool01Woo001NOol2003oOom_Ool00`00Oomoo`1AOol300020=L200000`3g000A>0044CP01@009GPU
N2Eh00000adg00<0035f<GH02C5f00<002eE;ED03ReE00<004GF0000158F0`003E7e00<005iEGUD0
4EiE00<007mdOg@00Wmd00<007mdOg@00Wmd00D007mdOgAoM00000=oM08000=oM004001oM7md0004
Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM003001oM7md009oM004001oM7md0003Og@0
1000OgAoM00017md00@007mdOg@000AoM004001o/Wnb003oOon1Ool00`00Oomoo`1EOol00`00Oomo
o`06Ool0061oo`800?moofeoo`03001oogoo059oo`<00080e`040000m`3g00054CP010009GPUN000
11dg00<0035f<GH0235f00<002eE;ED03beE0P0000AB5P000000011Am@03001NEEiE015NE@03001o
M7md009oM005001oM7mdOg@00004Og@01P00OgAoM7md001oM0<000=oM003001oM7md009oM004001o
M7md0003Og@00`00OgAoM002Og@01000OgAoM00017md00D007mdOgAoM00000=oM004001oM7md0004
Og@01000OgAoM0000gmd00D007nbOk9o/P000?mooh9oo`03001oogoo05Aoo`03001oogoo00Ioo`00
HWoo0P00ogooJgoo00<007ooOol0Dgoo0`000P3G00@0003g0?L000DA>003000UN00000@M=`03000a
MS5f00PaMP03000]EBeE010]E@8001=Am@03001NEEiE011NE@03001oM7md00=oM005001oM7mdOg@0
0004Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000AoM004001oM7md0003Og@00`00OgAoM002
Og@01000OgAoM00017md00D007mdOgAoM000009oM005001oM7mdOg@00003Og@01@00OgAoM7md0000
0gmd00@007nbOk800?mooh=oo`03001oogoo05Aoo`03001oogoo00Ioo`00I7oo0P00ogooJ7oo00<0
07ooOol0EGoo0`0000<0e`000?L00P3g00<0014h4CP00Q4h00<002Eh00001Adg00<0035f<GH01c5f
00<002eE;ED042eE00<0057eDOD04U7e00<005iEGUD045iE00<007mdOg@00gmd00D007mdOgAoM000
00AoM004001oM7md0004Og@20002Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001o
M7mdOg@00004Og@01000OgAoM0000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01000
Ok9o/P00ogooQ7oo00<007ooOol0Dgoo00<007ooOol01Woo001VOol20007Ool00`00Oomoo`3oOomL
Ool00`00Oomoo`1FOol300000`3G0000m`020?L00`004CPA>0024CP00`009GP000057CL00`00<GHa
MP06<GH00`00;ED]E@0@;ED00`00DOEAm@0BDOD00`00GUENE@0@GUD00`00OgAoM002Og@00`00OgAo
M002Og@01@00OgAoM7md00000gmd00<007mdOg@00Wmd00@007md000000AoM005001oM7mdOg@00003
Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00002Og@00`00OgAoM002
Og@01000OgAoM00017md00@007nbOk800?moohEoo`03001oogoo059oo`03001oogoo00Ioo`00J7oo
0P001Goo00<007ooOol0ogooG7oo00<007ooOol0Egoo1@000`3g00<0014h4CP00Q4h0P001Adg00<0
035f<GH01S5f00<002eE;ED042eE00<0057eDOD04U7e00<005iEGUD045iE00<007mdOg@00Wmd00D0
07mdOgAoM00000AoM005001oM7mdOg@00003Og@01000OgAoM7md0P000gmd00@007mdOg@000=oM003
001oM7md009oM004001oM7md0004Og@01@00OgAoM7md00000gmd00@007mdOg@000AoM004001oM7md
0003Og@01000Ok9o/P00ogooQWoo00<007ooOol0DWoo00<007ooOol01Woo001ZOol20003Ool00`00
Oomoo`3oOomLOol00`00Oomoo`1HOol500020?L00`004CPA>0034CP00`007CLM=`047CL00`00<GHa
MP05<GH00`00;ED]E@0@;ED00`00DOEAm@0BDOD00`00GUENE@0?GUD00`00OgAoM003Og@01@00OgAo
M7md000017md00D007mdOgAoM00000=oM007001oM7mdOg@007md00000Wmd00@007mdOg@000=oM005
001oM7mdOg@00003Og@00`00OgAoM002Og@01@00OgAoM7md00000Wmd00D007mdOgAoM00000=oM005
001oM7mdOg@00003Og@01000Ok9o/P00ogooQgoo00<007ooOol0DGoo00<007ooOol01Woo001/Ool2
00000goo001oo`3oOomMOol00`00Oomoo`1IOol500020?L00`004CPA>0024CP00`007CLM=`057CL0
0`00<GHaMP04<GH00`00;ED]E@0@;ED00`00DOEAm@0BDOD00`00GUENE@0?GUD00`00OgAoM003Og@0
1@00OgAoM7md000017md00@007mdOg@000AoM005001oM7mdOg@00002Og@20003Og@01@00OgAoM7md
00000gmd00D007mdOgAoM00000AoM004001oM7md0003Og@01@00OgAoM7md00000gmd00D007mdOgAo
M00000=oM004001o/Wnb003oOon8Ool00`00Oomoo`1@Ool00`00Oomoo`06Ool006ioo`800?mooeio
o`03001oogoo05Yoo`<0000509H0003g0?L000044CP00`007CLM=`047CL00`00<GHaMP05<GH00`00
;ED]E@0?;ED00`00DOEAm@0CDOD00`00GUENE@0>GUD00`00OgAoM002Og@01@00OgAoM7md000017md
00D007mdOgAoM00000AoM004001oM7md0004Og@20002Og@01000OgAoM00017md00D007mdOgAoM000
00=oM005001oM7mdOg@00003Og@01000OgAoM00017md00@007mdOg@000=oM005001o/WnbOk80003o
Oon9Ool00`00Oomoo`1@Ool00`00Oomoo`05Ool0071oo`800?mooeaoo`03001oogoo05]oo`<00005
09H0003g0?L000034CP200067CL00`00<GHaMP04<GH00`00;ED]E@0?;ED00`00DOEAm@0CDOD00`00
GUENE@0>GUD00`00OgAoM002Og@01@00OgAoM7md000017md00D007mdOgAoM00000=oM005001oM7md
Og@00004Og@01000Og@000000gmd00<007mdOg@00Wmd00@007mdOg@000AoM005001oM7mdOg@00003
Og@01000OgAoM00017md00@007mdOg@000=oM004001o/Wnb003oOon:Ool00`00Oomoo`1@Ool00`00
Oomoo`05Ool0079oo`800?mooeYoo`03001oogoo05]oo`030000D`000080UP040000m`3g00024CP2
00077CL00`00<GHaMP03<GH00`00;ED]E@0?;ED00`00DOEAm@0CDOD00`00GUENE@0=GUD00`00OgAo
M003Og@01@00OgAoM7md000017md00D007mdOgAoM00000=oM005001oM7mdOg@00004Og@01000OgAo
M0000gmd00D007mdOgAoM00000=oM003001oM7md009oM005001oM7mdOg@00002Og@01@00OgAoM7md
00000gmd00D007mdOgAoM00000=oM004001o/Wnb003oOon;Ool00`00Oomoo`1?Ool00`00Oomoo`05
Ool007Aoo`800?mooeQoo`03001oogoo05aoo`050000D`0009H000030?L00`004CPA>00200067CL0
0`00<GHaMP03<GH00`00;ED]E@0?;ED00`00DOEAm@0CDOD00`00GUENE@0=GUD00`00OgAoM002Og@0
0`00OgAoM002Og@01@00OgAoM7md00000gmd00<007mdOg@00Wmd00D007mdOgAoM00000=oM004001o
M7mdOg@20002Og@01@00OgAoM7md00000gmd00<007mdOg@00Wmd00@007mdOg@000=oM005001oM7md
Og@00003Og@01@00OgAoM7md00000gmd00@007nbOk800?moohaoo`03001oogoo04ioo`03001oogoo
00Eoo`00MWoo0P00ogooEWoo00<007ooOol0GGoo00D0001C0000UP000080m`06000A>14h0004m`00
1Qdg00<0035f<GH00S5f00<002eE;ED03beE00<0057eDOD04e7e00<005iEGUD03EiE00<007mdOg@0
0Wmd00D007mdOgAoM00000AoM005001oM7mdOg@00004Og@01000OgAoM00017md00H007mdOgAoM000
Og@20004Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM004001oM7md0004Og@01000OgAo
M0000gmd00@007nbOk800?moohioo`03001oogoo04eoo`03001oogoo00Eoo`00N7oo0P00ogooE7oo
00<007ooOol0GWoo00D0001C0000UP000080m`03000A>0000084m`03000M=adg00@M=`05000aMS5f
<GH0000A;ED00`00DOEAm@0CDOD00`00GUENE@0=GUD00`00OgAoM002Og@01@00OgAoM7md000017md
00D007mdOgAoM00000=oM005001oM7mdOg@00004Og@01000OgAoM0000gmd0P000gmd00@007mdOg@0
00AoM005001oM7mdOg@00003Og@01000OgAoM00017md00@007mdOg@000=oM004001o/Wnb003oOon>
Ool00`00Oomoo`1=Ool00`00Oomoo`05Ool007Yoo`800?mooe9oo`03001oogoo05moo`050000D`00
09H000020?L01@004CP000Cg00001Qdg00D0035f<GHaMP00014]E@03001AmE7e01=Am@03001NEEiE
00aNE@03001oM7md00=oM005001oM7mdOg@00004Og@01000OgAoM00017md00D007mdOgAoM00000Ao
M004001oM7md0003Og@00`00Og@000020003Og@00`00OgAoM002Og@01000OgAoM0000gmd00D007md
OgAoM00000=oM005001oM7mdOg@00003Og@01000Ok9o/P00ogooSgoo00<007ooOol0C7oo00<007oo
Ool01Goo001lOol2003oOom@Ool00`00Oomoo`1POol30000102F0000m`3g0P000PCg00<001dg7CL0
11dg00@0035f<GH0018]E@03001AmE7e019Am@03001NEEiE00aNE@03001oM7md009oM003001oM7md
009oM005001oM7mdOg@00003Og@00`00OgAoM002Og@01@00OgAoM7md00000gmd00D007mdOgAoM000
00=oM005001oM7mdOg@00003Og@00`00OgAoM002Og@01000OgAoM0000gmd00D007mdOgAoM00000=o
M005001oM7mdOg@00003Og@00`00Ok80003oOonAOol00`00Oomoo`1;Ool00`00Oomoo`05Ool0049o
o`H000eoo`@002Eoo`800?moodioo`03001oogoo065oo`<0000509H0003g0?L000031?L00`007CLM
=`037CL01000<GHaMP004ReE00<0057eDOD04U7e00<005iEGUD035iE00<007mdOg@00Wmd00D007md
OgAoM00000AoM005001oM7mdOg@00003Og@01@00OgAoM7md000017md00D007mdOgAoM000009oM003
001oM7md009oM080009oM005001oM7mdOg@00003Og@01@00OgAoM7md00000Wmd00<007mdOg@00Wmd
00@007mdOg@000=oM004001o/Wnb003oOonBOol00`00Oomoo`1:Ool00`00Oomoo`05Ool0045oo`P0
00Yoo`P002Eoo`800?moodaoo`03001oogoo069oo`<0000509H0003g0?L000021?L00`007CLM=`04
7CL01000<GHaMP004BeE00<0057eDOD04U7e00<005iEGUD035iE00<007mdOg@00Wmd00D007mdOgAo
M00000AoM005001oM7mdOg@00003Og@01@00OgAoM7md000017md00@007mdOg@000=oM003001oM7md
009oM004001oM0000004Og@01@00OgAoM7md00000Wmd00D007mdOgAoM00000AoM004001oM7md0003
Og@01000Ok9o/P00ogooTWoo00<007ooOol0BWoo00<007ooOol01Goo0010Ool30004Ool30009Ool2
0004Ool2000WOol2003oOom:Ool00`00Oomoo`1SOol200001@2F0000m`3g00000`Cg00<001dg7CL0
11dg00<0035f00004BeE00<0057eDOD04U7e00<005iEGUD035iE00<007mdOg@00Wmd00D007mdOgAo
M00000AoM004001oM7md0004Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7md
Og@00003Og@20003Og@01000OgAoM0000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@0
0`00Ok80003oOonDOol00`00Oomoo`19Ool00`00Oomoo`05Ool003moo`<000Ioo`<000Moo`8000Io
o`8002Qoo`8000Moo`03001oogoo0?moocioo`03001oogoo06Aoo`80000509H0003g0?L000031?L0
0`007CLM=`037CL00`00<GH0000A;ED00`00DOEAm@0BDOD00`00GUENE@0;GUD00`00OgAoM002Og@0
0`00OgAoM002Og@01@00OgAoM7md00000gmd00<007mdOg@00Wmd00@007mdOg@000AoM005001oM7md
Og@00003Og@01@00OgAoM7md00000gmd00<007md00000Wmd00@007mdOg@000=oM004001oM7md0004
Og@01@00OgAoM7md00000Wmd00@007nbOk800?mooiEoo`03001oogoo04Qoo`03001oogoo00Eoo`00
?goo0P0027oo0P001goo0P001Woo0P00:Woo0P001Goo00<007ooOol0ogoo?Woo00<007ooOol0I7oo
00H0000A0000UP000?L200021?L00`007CLM=`047CL2000A;ED00`00DOEAm@0BDOD00`00GUENE@0;
GUD00`00OgAoM002Og@01@00OgAoM7md000017md00D007mdOgAoM00000=oM005001oM7mdOg@00004
Og@01@00OgAoM7md00000Wmd00<007mdOg@00Wmd00D007mdOgAoM000009oM08000=oM005001oM7md
Og@00002Og@00`00OgAoM002Og@01000OgAoM0000gmd00@007nbOk800?mooiEoo`03001oogoo04Qo
o`03001oogoo00Eoo`00?goo0P0027oo0P001Woo0P0027oo0P00:goo0P000goo00<007ooOol0ogoo
?Woo00<007ooOol0IGoo0`0000<0UP000?L00P000PCg00<001dg7CL011dg00<002eE;ED03beE00<0
057eDOD04U7e00<005iEGUD02eiE00<007mdOg@00Wmd00D007mdOgAoM00000AoM005001oM7mdOg@0
0003Og@01@00OgAoM7md000017md00@007mdOg@000=oM003001oM7md009oM004001oM7md0004Og@2
0002Og@01000OgAoM0000gmd00<007mdOg@00Wmd00@007mdOg@000=oM004001o/Wnb003oOonFOol0
0`00Oomoo`17Ool00`00Oomoo`05Ool003moo`8000Qoo`8000Ioo`8000Qoo`8002eoo`<00?mood5o
o`03001oogoo06Ioo`<0000409H0000000031?L00`007CLM=`037CL00`00;ED]E@0?;ED00`00DOEA
m@0BDOD00`00GUENE@0;GUD00`00OgAoM002Og@01@00OgAoM7md000017md00@007mdOg@000AoM005
001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM003001oM7md009oM004
001oM0000003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM003001o/P000?mooiQoo`03
001oogoo04Ioo`03001oogoo00Eoo`00?goo0`001Woo0`001Woo0P0027oo0P00;goo0P00ogoo@7oo
00<007ooOol0Igoo0`0000@0UP00000000<4m`03000M=adg008M=`80010]E@03001AmE7e019Am@03
001NEEiE00YNE@03001oM7md009oM003001oM7md009oM005001oM7mdOg@00003Og@00`00OgAoM002
Og@01000OgAoM00017md00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@00`00OgAoM002Og@0
1000OgAoM0000gmd00@007mdOg@000AoM005001oM7mdOg@00002Og@01000Ok9o/P00ogooVGoo00<0
07ooOol0AGoo00<007ooOol01Goo0010Ool30004Ool30007Ool20008Ool2000aOol2003oOolnOol0
0`00Oomoo`1XOol30000102F0000U@000PCg00<001dg7CL00adg00<002eE;ED03ReE00<0057eDOD0
4U7e00<005iEGUD02UiE00<007mdOg@00Wmd00D007mdOgAoM00000AoM005001oM7mdOg@00003Og@0
1@00OgAoM7md000017md00D007mdOgAoM000009oM003001oM7md009oM005001oM7mdOg@00003Og@0
1000OgAoM7md0P000Wmd00@007mdOg@000AoM004001oM7md0003Og@01000Ok9o/P00ogooVGoo00<0
07ooOol0AGoo00<007ooOol01Goo0011Ool80008Ool20008Ool2000cOol00`00Oomoo`3oOolkOol0
0`00Oomoo`1YOol2000209H200031?L00`007CLM=`027CL00`00;ED]E@0>;ED00`00DOEAm@0BDOD0
0`00GUENE@0:GUD00`00OgAoM002Og@01@00OgAoM7md000017md00D007mdOgAoM00000=oM005001o
M7mdOg@00004Og@01000OgAoM0000gmd00D007mdOgAoM00000=oM003001oM7md009oM006001oM7md
Og@007md0P000gmd00<007mdOg@00Wmd00@007mdOg@000=oM003001o/P000?mooi]oo`03001oogoo
04Aoo`03001oogoo00Eoo`00@Goo200027oo0P0027oo0P00=7oo0P00ogoo>goo00<007ooOol0JWoo
0P0000@0UP0009D000<4m`04000M=adg7CL2000?;ED00`00DOEAm@0BDOD00`00GUENE@0:GUD01@00
OgAoM7md000017md00<007mdOg@00Wmd00@007mdOg@000AoM005001oM7mdOg@00003Og@01@00OgAo
M7md00000gmd00D007mdOgAoM00000=oM003001oM7md009oM004001oM7md0003Og@20002Og@01@00
OgAoM7md00000gmd00L007mdOgAoM000Ok80003oOonLOol00`00Oomoo`13Ool00`00Oomoo`05Ool0
041oo`<000Aoo`<000Moo`8000Qoo`8003Ioo`800?moocUoo`03001oogoo06]oo`80000409H0002E
00021?L010007CLM=adg0P003beE00<0057eDOD04U7e00<005iEGUD02EiE00<007mdOg@00Wmd00<0
07mdOg@00Wmd00D007mdOgAoM00000=oM003001oM7md009oM004001oM7md0004Og@01@00OgAoM7md
00000gmd00D007mdOgAoM00000=oM003001oM7md009oM004001oM7md0003Og@01000Og@0000017md
00D007mdOgAoM000009oM004001o/Wnb003oOonMOol00`00Oomoo`13Ool00`00Oomoo`04Ool003mo
o`8000Qoo`8000Ioo`8000Qoo`8003Qoo`800?moocMoo`03001oogoo06aoo`@0000509D000Cg1?L0
00037CL2000>;ED00`00DOEAm@0BDOD00`00GUENE@09GUD00`00OgAoM002Og@01@00OgAoM7md0000
17md00D007mdOgAoM00000=oM005001oM7mdOg@00004Og@01@00OgAoM7md00000Wmd00<007mdOg@0
0Wmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@00`00OgAoM0020003Og@01000OgAoM000
0gmd00<007nb0000ogooWWoo00<007ooOol0@goo00<007ooOol017oo000oOol20008Ool20007Ool2
0006Ool2000kOol2003oOoleOol00`00Oomoo`1]Ool500031?L00`007CLM=`02000>;ED00`00DOEA
m@0BDOD00`00GUENE@09GUD00`00OgAoM002Og@01@00OgAoM7md000017md00D007mdOgAoM00000=o
M005001oM7mdOg@00004Og@01000OgAoM0000gmd00D007mdOgAoM00000=oM003001oM7md009oM005
001oM7mdOg@00002Og@01`00OgAoM7md001oM000009oM004001oM7md0003Og@00`00Ok80003oOonO
Ool00`00Oomoo`12Ool00`00Oomoo`04Ool003moo`8000Qoo`8000Moo`8000Ioo`8003eoo`800?mo
oc=oo`03001oogoo06ioo`<0000509D000Cg1?L000027CL2000>;ED00`00DOEAm@0BDOD00`00GUEN
E@09GUD01@00OgAoM7md000017md00D007mdOgAoM00000=oM003001oM7md009oM005001oM7mdOg@0
0003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM003001oM7md009oM004001oM7md0003
Og@01@00OgAoM7md00000Wmd0P000gmd00@007mdOg@0009o/P03001oogoo0?mooiioo`03001oogoo
045oo`03001oogoo00Aoo`00@7oo0`0017oo100027oo0P0017oo0P00@7oo0P00ogoo<Goo00<007oo
Ool0KWoo100000D0U@001?L4m`00008M=`8000d]E@03001AmE7e019Am@03001NEEiE00QNE@03001o
M7md009oM003001oM7md009oM005001oM7mdOg@00003Og@00`00OgAoM002Og@01000OgAoM00017md
00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM000
009oM003001oM7md009oM080009oM006001oM7md001o/P00ogooXGoo00<007ooOol0@Goo00<007oo
Ool017oo0010Ool:0009Ool80012Ool2003oOol_Ool00`00Oomoo`1_Ool00`0005<0000200031?L0
10007CL000003BeE00<0057eDOD04U7e00<005iEGUD025iE00<007mdOg@00Wmd00D007mdOgAoM000
00AoM005001oM7mdOg@00003Og@01@00OgAoM7md000017md00D007mdOgAoM000009oM003001oM7md
009oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00@007mdOg@000AoM004001oM0000003
Og@00`00Ok80003oOonROol00`00Oomoo`10Ool00`00Oomoo`04Ool0049oo`H000eoo`@004Ioo`80
00Qoo`03001oogoo0?moob9oo`03001oogoo071oo`80000303<0000000<4m`8000032=D002eE00/]
E@03001AmE7e01=Am@03001NEEiE00MNE@03001oM7md009oM005001oM7mdOg@00004Og@01000OgAo
M00017md00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00<007md
Og@00Wmd00D007mdOgAoM000009oM005001oM7mdOg@00004Og@00`00OgAoM0020002Og@3003oOonS
Ool00`00Oomoo`0oOol00`00Oomoo`04Ool00:5oo`8000Ioo`03001oogoo0?moob9oo`03001oogoo
075oo`80000303<000000084m`8000032=D002eE00/]E@03001AmE7e01=Am@03001NEEiE00MNE@05
001oM7mdOg@00004Og@01@00OgAoM7md00000gmd00<007mdOg@00Wmd00D007mdOgAoM00000=oM005
001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00<007mdOg@00Wmd00@007mdOg@000=oM005001o
M7mdOg@00003Og@01P00OgAoM7md001oM0<00003Og@007oo0?mooj=oo`03001oogoo03ioo`03001o
ogoo00Aoo`00Xgoo0P0017oo00<007ooOol0ogoo8Woo00<007ooOol0LWoo0`0000@0U@001?L4m`<0
00`]E@03001AmE7e01=Am@03001NEEiE00INE@03001oM7md009oM005001oM7mdOg@00004Og@01@00
OgAoM7md00000gmd00D007mdOgAoM00000AoM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd
00D007mdOgAoM00000=oM005001oM7mdOg@00002Og@00`00OgAoM002Og@01@00OgAoM7md00000Wmd
00<007md0000ogooYGoo00<007ooOol0?Woo00<007ooOol017oo002UOol20002Ool00`00Oomoo`3o
OolROol00`00Oomoo`1cOol400031?L00`002=D0000;;ED00`00DOEAm@0CDOD00`00GUENE@06GUD0
0`00OgAoM002Og@01@00OgAoM7md000017md00D007mdOgAoM00000=oM005001oM7mdOg@00004Og@0
1@00OgAoM7md00000Wmd00<007mdOg@00Wmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@0
1000OgAoM00017md00@007mdOg@000=oM003001oM0000?moojIoo`03001oogoo03eoo`03001oogoo
00Aoo`00Ygoo0`00ogoo97oo00<007ooOol0M7oo10000PCg00<000SE00002beE00<0057eDOD04e7e
00<005iEGUD01UiE00<007mdOg@00Wmd00D007mdOgAoM00000AoM004001oM7md0004Og@01@00OgAo
M7md00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@00`00OgAoM002Og@01@00OgAo
M7md00000Wmd00D007mdOgAoM00000AoM004001oM7md0003Og@00`00Og@0003oOonWOol00`00Oomo
o`0lOol00`00Oomoo`04Ool00:Uoo`800?moob=oo`03001oogoo07Aoo`030000400000800084m`80
00`]E@03001AmE7e019Am@03001NEEiE00INE@05001oM7mdOg@00004Og@01@00OgAoM7md00000gmd
00<007mdOg@00Wmd00@007mdOg@000AoM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00<0
07mdOg@00Wmd00@007mdOg@000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000Wmd00@007md
Og@00?moojQoo`03001oogoo03]oo`03001oogoo00Aoo`00Zgoo0P00ogoo8Goo00<007ooOol0MGoo
10000PCg00<000SE00002beE00<0057eDOD04U7e00<005iEGUD01UiE00D007mdOgAoM00000=oM003
001oM7md009oM005001oM7mdOg@00003Og@01@00OgAoM7md000017md00D007mdOgAoM00000=oM005
001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM000009oM003001oM7md009oM005
001oM7mdOg@00002Og@01000OgAoM000ogooZ7oo00<007ooOol0>goo00<007ooOol017oo002]Ool2
003oOolOOol00`00Oomoo`1fOol4000010Cg000000002beE00<0057eDOD04U7e00<005iEGUD01EiE
00<007mdOg@00Wmd00D007mdOgAoM00000AoM005001oM7mdOg@00003Og@01@00OgAoM7md000017md
00D007mdOgAoM000009oM005001oM7mdOg@00004Og@01@00OgAoM7md00000gmd00D007mdOgAoM000
009oM003001oM7md009oM004001oM7md0003Og@00`00Og@0003oOonZOol00`00Oomoo`0jOol00`00
Oomoo`04Ool00:moo`800?mooaeoo`03001oogoo07Moo`@000041?L000SE000:;ED00`00DOEAm@0B
DOD00`00GUENE@05GUD01@00OgAoM7md000017md00<007mdOg@00Wmd00@007mdOg@000AoM005001o
M7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM003001oM7md009oM005001o
M7mdOg@00002Og@01@00OgAoM7md000017md00@007mdOg@000=oM003001oM0000?mooj]oo`03001o
ogoo03Uoo`03001oogoo00Aoo`00/Goo0P00ogoo6goo00<007ooOol0N7oo1`002ReE00<0057eDOD0
4U7e00<005iEGUD01EiE00D007mdOgAoM00000AoM005001oM7mdOg@00003Og@00`00OgAoM002Og@0
1000OgAoM00017md00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd
00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01000OgAoM0000Wmd00<007ooOol0ogooZGoo
00<007ooOol0>Goo00<007ooOol017oo002cOol2003oOolHOol00`00Oomoo`1jOol6000:;ED00`00
DOEAm@0BDOD00`00GUENE@05GUD01@00OgAoM7md00000gmd00<007mdOg@00Wmd00D007mdOgAoM000
00=oM005001oM7mdOg@00004Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7md
Og@00003Og@01@00OgAoM7md00000Wmd00<007mdOg@00Wmd00D007mdOgAoM000009oM004001oM7md
003oOon/Ool00`00Oomoo`0hOol00`00Oomoo`04Ool00;Eoo`8000eoo`03001oogoo0?moo`Ioo`03
001oogoo07]oo`H000T]E@03001AmE7e019Am@03001NEEiE00ANE@03001oM7md009oM005001oM7md
Og@00004Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000AoM005001oM7mdOg@00002Og@01@00
OgAoM7md000017md00D007mdOgAoM00000=oM005001oM7mdOg@00002Og@00`00OgAoM002Og@01000
OgAoM0000gmd00<007md0000ogoo[Woo00<007ooOol0=goo00<007ooOol017oo002gOol2000;Ool0
0`00Oomoo`3oOol6Ool00`00Oomoo`1lOol50009;ED00`00DOEAm@0BDOD00`00GUENE@04GUD01@00
OgAoM7md000017md00<007mdOg@00Wmd00@007mdOg@000AoM005001oM7mdOg@00003Og@01@00OgAo
M7md00000gmd00D007mdOgAoM00000=oM003001oM7md009oM004001oM7md0003Og@01@00OgAoM7md
00000gmd00D007mdOgAoM00000=oM003001oM0000?moojmoo`03001oogoo03Ioo`03001oogoo00Ao
o`00^Goo0P002Goo00<007ooOol0ogoo1Woo00<007ooOol0O7oo0`0000<0<`00000022eE00<0057e
DOD04U7e00<005iEGUD015iE00D007mdOgAoM00000AoM005001oM7mdOg@00003Og@00`00OgAoM002
Og@01000OgAoM00017md00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md0000
0gmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01000OgAoM0000Wmd00<007ooOol0ogoo
[Goo00<007ooOol0=goo00<007ooOol00goo002kOol20007Ool00`00Oomoo`3oOol6Ool00`00Oomo
o`1mOol300000`0c000]E@07;ED00`00DOEAm@0BDOD00`00GUENE@04GUD01@00OgAoM7md00000gmd
00<007mdOg@00Wmd00D007mdOgAoM00000=oM005001oM7mdOg@00004Og@01@00OgAoM7md00000gmd
00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000Wmd00<007mdOg@00Wmd
00D007mdOgAoM000009oM004001oM7md003oOon`Ool00`00Oomoo`0fOol00`00Oomoo`03Ool00;eo
o`8000Eoo`03001oogoo0?moo`Ioo`03001oogoo07ioo`@000P]E@03001AmE7e019Am@03001NEEiE
00=NE@03001oM7md009oM005001oM7mdOg@00004Og@01@00OgAoM7md00000gmd00D007mdOgAoM000
00=oM003001oM7md009oM004001oM7md0003Og@00`00OgAoM002Og@01@00OgAoM7md00000gmd00@0
07mdOg@000=oM003001oM7md009oM004001oM7md0003Og@00`00Og@0003oOonbOol00`00Oomoo`0e
Ool00`00Oomoo`03Ool00;moo`8000=oo`03001oogoo0?moo`Ioo`03001oogoo07moo`80000303<0
02eE00H]E@03001AmE7e019Am@03001NEEiE00=NE@05001oM7mdOg@00004Og@01@00OgAoM7md0000
0gmd00<007mdOg@00Wmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md0000
0gmd00<007mdOg@00Wmd00@007mdOg@000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd
00<007md0000ogoo/goo00<007ooOol0=7oo00<007ooOol00goo0031Ool200000goo001oo`3oOol7
Ool00`00Oomoo`20Ool30007;ED00`00DOEAm@0BDOD00`00GUENE@03GUD01@00OgAoM7md000017md
00D007mdOgAoM00000=oM003001oM7md009oM004001oM7md0004Og@01@00OgAoM7md00000gmd00D0
07mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000Wmd00<007mdOg@00Wmd00D0
07mdOgAoM000009oM004001oM7md003oOoncOol00`00Oomoo`0dOol00`00Oomoo`03Ool00<=oo`80
0?moo`Qoo`03001oogoo085oo`030000<`0000H]E@03001AmE7e019Am@03001NEEiE00=NE@05001o
M7mdOg@00003Og@00`00OgAoM002Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000AoM005001o
M7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00002Og@0
0`00OgAoM002Og@01@00OgAoM7md00000Wmd00@007mdOg@00?mookAoo`03001oogoo03=oo`03001o
ogoo00=oo`00aGoo0P00ogoo1Woo00<007ooOol0PWoo0P001ReE00<0057eDOD04U7e00<005iEGUD0
0UiE00D007mdOgAoM00000AoM003001oM7md009oM004001oM7md0004Og@01@00OgAoM7md00000gmd
00<007mdOg@00Wmd00@007mdOg@000=oM003001oM7md009oM005001oM7mdOg@00003Og@01000OgAo
M0000gmd00<007mdOg@00Wmd00@007mdOg@000=oM004001oM7md003oOoneOol00`00Oomoo`0bOol0
0`00Oomoo`03Ool00<Moo`800?moo`Aoo`03001oogoo089oo`8000H]E@03001AmE7e019Am@03001N
EEiE009NE@05001oM7mdOg@00004Og@01@00OgAoM7md00000gmd00<007mdOg@00Wmd00D007mdOgAo
M00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00<007mdOg@00Wmd00@007mdOg@0
00=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00<007md0000ogoo]Woo00<007ooOol0
<Woo00<007ooOol00goo0039Ool2003oOol2Ool00`00Oomoo`23Ool20005;ED00`00DOEAm@0BDOD0
0`00GUENE@02GUD01@00OgAoM7md000017md00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@0
0`00OgAoM002Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@0
1@00OgAoM7md00000Wmd00<007mdOg@00Wmd00D007mdOgAoM000009oM004001oM7md003oOongOol0
0`00Oomoo`0aOol00`00Oomoo`03Ool00<]oo`800?moo`03001oogoo08Aoo`03000]EBeE00<]E@03
001AmE7e019Am@03001NEEiE009NE@05001oM7mdOg@00003Og@00`00OgAoM002Og@01@00OgAoM7md
00000gmd00D007mdOgAoM00000AoM005001oM7mdOg@00002Og@01@00OgAoM7md000017md00D007md
OgAoM00000=oM005001oM7mdOg@00002Og@00`00OgAoM002Og@01000OgAoM0000gmd00@007mdOg@0
0?mookQoo`03001oogoo031oo`03001oogoo00=oo`00cGoo0P00oGoo00<007ooOol0QGoo00<002eE
;ED00ReE00<0057eDOD04U7e00D005iEGUENE@0000=oM003001oM7md009oM003001oM7md009oM004
001oM7md0004Og@01@00OgAoM7md00000gmd00<007mdOg@00Wmd00@007mdOg@000=oM003001oM7md
009oM005001oM7mdOg@00003Og@01000OgAoM0000gmd00<007mdOg@00Wmd00@007mdOg@000=oM004
001oM7md003oOoniOol00`00Oomoo`0_Ool00`00Oomoo`03Ool00<moo`800?]oo`03001oogoo08Eo
o`03000]EBeE008]E@03001AmE7e019Am@05001NEEiEGUD00003Og@00`00OgAoM002Og@01@00OgAo
M7md00000gmd00<007mdOg@00Wmd00@007mdOg@000AoM005001oM7mdOg@00003Og@01@00OgAoM7md
00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00@007md
Og@0009oM003001oogoo0?mookQoo`03001oogoo02moo`03001oogoo00=oo`00dGoo0P00nGoo00<0
07ooOol0QGoo00<002eE;ED00ReE00<0057eDOD04e7e00@005iEGUD000=oM003001oM7md009oM005
001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00<007mdOg@00Wmd00D007mdOgAoM00000=oM005
001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM000009oM003001oM7md009oM005
001oM7mdOg@00002Og@01000OgAoM000ogoo^goo00<007ooOol0;Woo00<007ooOol00goo003COol2
003gOol00`00Oomoo`26Ool01@00;ED]EBeE00005E7e00@005iEGUD000=oM005001oM7mdOg@00004
Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000AoM005001oM7mdOg@00002Og@01@00OgAoM7md
000017md00D007mdOgAoM00000=oM005001oM7mdOg@00002Og@00`00OgAoM002Og@01000OgAoM000
0gmd00@007mdOg@00?mookaoo`03001oogoo02eoo`03001oogoo00=oo`00eGoo0P0027oo00<007oo
Ool0jWoo00<007ooOol0QWoo00D002eE;ED]E@0001EAm@04001NEEiE0002Og@00`00OgAoM002Og@0
0`00OgAoM002Og@01000OgAoM00017md00D007mdOgAoM00000=oM003001oM7md009oM004001oM7md
0003Og@01@00OgAoM7md000017md00D007mdOgAoM000009oM005001oM7mdOg@00004Og@01000OgAo
M0000gmd00@007mdOg@00?mookeoo`03001oogoo02aoo`03001oogoo00=oo`00egoo0P001Woo00<0
07ooOol0jWoo00<007ooOol0QWoo00<002eE;ED00ReE00<0057eDOD04U7e00<005iE00000gmd00<0
07mdOg@00Wmd00D007mdOgAoM00000=oM003001oM7md009oM004001oM7md0004Og@01@00OgAoM7md
00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007md
OgAoM00000=oM004001oM7md0002Og@00`00Oomoo`3oOonlOol00`00Oomoo`0/Ool00`00Oomoo`03
Ool00=Uoo`8000Aoo`03001oogoo0>Yoo`03001oogoo08Moo`05000]EBeE;ED0000DDOD00`00GUD0
0003Og@01@00OgAoM7md000017md00D007mdOgAoM00000=oM005001oM7mdOg@00004Og@01@00OgAo
M7md00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000Wmd00<0
07mdOg@00Wmd00D007mdOgAoM000009oM004001oM7md003oOonoOol00`00Oomoo`0[Ool00`00Oomo
o`03Ool00=]oo`800003Ool007oo0>aoo`03001oogoo08Moo`05000]EBeE;ED0000DDOD00`00GUD0
0003Og@01@00OgAoM7md000017md00D007mdOgAoM00000=oM005001oM7mdOg@00004Og@01@00OgAo
M7md00000Wmd00D007mdOgAoM00000AoM005001oM7mdOg@00003Og@01@00OgAoM7md00000Wmd00<0
07mdOg@00Wmd00@007mdOg@000=oM004001oM7md003oOoo0Ool00`00Oomoo`0ZOol00`00Oomoo`03
Ool00=eoo`800>eoo`03001oogoo08Qoo`04000]EBeE000DDOD00`00GUD00002Og@00`00OgAoM002
Og@00`00OgAoM002Og@01000OgAoM00017md00D007mdOgAoM00000=oM003001oM7md009oM004001o
M7md0003Og@01@00OgAoM7md000017md00D007mdOgAoM000009oM005001oM7mdOg@00004Og@01000
OgAoM0000gmd00@007mdOg@00?mool5oo`03001oogoo02Uoo`03001oogoo00=oo`00gWoo0`00jgoo
00<007ooOol0R7oo00@002eE;ED001AAm@8000=oM003001oM7md009oM005001oM7mdOg@00003Og@0
0`00OgAoM002Og@01000OgAoM00017md00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00
OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01000OgAoM0000gmd00<0
07ooOol0ogoo_goo00<007ooOol0:Woo00<007ooOol00Woo003QOol2003YOol00`00Oomoo`28Ool0
1000;ED]E@00557e0P000gmd00D007mdOgAoM00000AoM005001oM7mdOg@00003Og@01@00OgAoM7md
000017md00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007md
OgAoM000009oM003001oM7md009oM005001oM7mdOg@00002Og@01000OgAoM000ogoo`goo00<007oo
Ool0:Goo00<007ooOol00Woo003SOol2003WOol00`00Oomoo`29Ool00`00;ED0000DDOD20002Og@0
0`00OgAoM002Og@00`00OgAoM002Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM003001o
M7md009oM004001oM7md0003Og@00`00OgAoM002Og@01@00OgAoM7md00000gmd00D007mdOgAoM000
009oM003001oM7md009oM004001oM7md0003Og@01000OgAoM000ogooa7oo00<007ooOol0:7oo00<0
07ooOol00Woo003UOol2003UOol00`00Oomoo`29Ool00`00;ED0000DDOD20002Og@00`00OgAoM002
Og@01@00OgAoM7md00000gmd00<007mdOg@00Wmd00D007mdOgAoM00000=oM003001oM7md009oM004
001oM7md0003Og@01@00OgAoM7md00000gmd00<007mdOg@00Wmd00@007mdOg@000=oM003001oM7md
009oM004001oM7md0003Og@01000OgAoM000ogooa7oo00<007ooOol0:7oo00<007ooOol00Woo003W
Ool2003SOol00`00Oomoo`2:Ool2000DDOD01@00OgAoM7md000017md00D007mdOgAoM00000=oM003
001oM7md009oM004001oM7md0004Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001o
M7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM004001oM7md0003Og@00`00
Oomoo`3oOoo3Ool00`00Oomoo`0WOol00`00Oomoo`02Ool00>Uoo`800>5oo`03001oogoo08Yoo`80
00mAm@L0009oM005001oM7mdOg@00004Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000AoM005
001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00002
Og@00`00OgAoM002Og@01@00OgAoM7md00000Wmd00@007mdOg@00?moolMoo`03001oogoo02Ioo`03
001oogoo009oo`00jgoo0P00ggoo00<007ooOol0RWoo0P00157e2`001c]O0P0017md00<007mdOg@0
0Wmd00@007mdOg@000AoM005001oM7mdOg@00003Og@00`00OgAoM002Og@01000OgAoM0000gmd00<0
07mdOg@00Wmd00D007mdOgAoM00000=oM005001oM7mdOg@00002Og@00`00OgAoM002Og@01000OgAo
M0000gmd00@007mdOg@00?moolQoo`03001oogoo02Eoo`03001oogoo009oo`00kGoo0P00gGoo00<0
07ooOol0Rgoo1@003S]O1`000gmd00D007mdOgAoM00000=oM003001oM7md009oM005001oM7mdOg@0
0003Og@00`00OgAoM002Og@01000OgAoM0000gmd00D007mdOgAoM00000=oM003001oM7md009oM004
001oM7md0003Og@01@00OgAoM7md00000gmd00D007mdOgAoM000009oM003001oogoo0?moolIoo`03
001oogoo02Eoo`03001oogoo009oo`00kgoo0P001goo00<007ooOol0dGoo00<007ooOol0SGoo0P00
1C]O2P001c]O00@007mdOg@000=oM005001oM7mdOg@00003Og@01@00OgAoM7md000017md00D007md
OgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005
001oM7mdOg@00003Og@01000OgAoM0000gmd00<007ooOol0ogooagoo00<007ooOol097oo00<007oo
Ool00Woo002gOol5000=Ool4000TOol20005Ool00`00Oomoo`3AOol00`00Oomoo`2?Ool5000B>el2
0004Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000AoM005001oM7mdOg@00003Og@01000OgAo
M00017md00D007mdOgAoM00000=oM005001oM7mdOg@00002Og@00`00OgAoM002Og@01@00OgAoM7md
00000Wmd00@007mdOg@00?mool]oo`03001oogoo02=oo`03001oogoo009oo`00]Goo20002Woo2000
97oo0P000goo00<007ooOol0dGoo00<007ooOol0T7oo00<003]O>el03c]O1`000gmd00@007mdOg@0
00AoM005001oM7mdOg@00003Og@00`00OgAoM002Og@01000OgAoM0000gmd00<007mdOg@00Wmd00D0
07mdOgAoM00000=oM005001oM7mdOg@00002Og@00`00OgAoM002Og@01000OgAoM0000gmd00@007md
Og@00?moolaoo`03001oogoo029oo`03001oogoo009oo`00]Goo0P0017oo0`002Goo0P0017oo0P00
9Woo0P0000=oo`00Ool0dWoo00<007ooOol0TGoo00<003]O>el00c]O2`001c]O0`000gmd00<007md
Og@00Wmd00@007mdOg@000AoM003001oM7md009oM004001oM7md0003Og@01@00OgAoM7md00000gmd
00<007mdOg@00Wmd00@007mdOg@000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000Wmd00<0
07ooOol0ogoobWoo00<007ooOol08Woo00<007ooOol00Woo002dOol20006Ool30007Ool20006Ool2
000WOol2003COol00`00Oomoo`2BOol5000?>el60003Og@01@00OgAoM7md00000gmd00<007mdOg@0
0Wmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAo
M00000=oM005001oM7mdOg@00003Og@01000OgAoM0000gmd00<007ooOol0ogoobgoo00<007ooOol0
8Goo00<007ooOol00Woo002cOol20008Ool20007Ool20006Ool2000YOol2003AOol00`00Oomoo`2D
Ool20005>el;0006>el01000OgAoM0000gmd00D007mdOgAoM00000AoM005001oM7mdOg@00003Og@0
1000OgAoM00017md00D007mdOgAoM00000=oM005001oM7mdOg@00002Og@00`00OgAoM002Og@01@00
OgAoM7md00000Wmd00D007mdOgAoM0000?moolioo`03001oogoo021oo`03001oogoo009oo`00/goo
0P0027oo0P001Woo0P0027oo0P00:Woo0P00cgoo00<007ooOol0UWoo1@004S]O0P0017md00D007md
OgAoM00000=oM003001oM7md009oM004001oM7md0003Og@00`00OgAoM002Og@01@00OgAoM7md0000
0gmd00D007mdOgAoM000009oM003001oM7md009oM004001oM7md0003Og@01000OgAoM000ogoocgoo
00<007ooOol087oo00<007ooOol00Woo002cOol20008Ool20006Ool20008Ool2000/Ool2003=Ool0
0`00Oomoo`2HOol00`00>elkG`0>>el70003Og@01000OgAoM00017md00<007mdOg@00Wmd00@007md
Og@000=oM005001oM7mdOg@00003Og@00`00OgAoM002Og@01000OgAoM0000gmd00D007mdOgAoM000
00=oM005001oM7mdOg@00002Og@00`00Oomoo`3oOoo>Ool00`00Oomoo`0OOol00`00Oomoo`02Ool0
0;=oo`8000Qoo`8000Ioo`8000Qoo`8002ioo`800<]oo`03001oogoo09Uoo`03000kGc]O00<kG`X0
00LkG`<000=oM003001oM7md009oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007md
OgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00@007mdOg@000=oM003001o
ogoo0?moolmoo`03001oogoo01ioo`03001oogoo009oo`00/goo0`001Woo0`001Woo0P0027oo0P00
<7oo0P00bGoo00<007ooOol0VWoo1@003S]O1P000gmd00D007mdOgAoM00000AoM005001oM7mdOg@0
0002Og@00`00OgAoM002Og@01@00OgAoM7md00000gmd00D007mdOgAoM000009oM003001oM7md009o
M005001oM7mdOg@00002Og@01@00OgAoM7md0000ogoodWoo00<007ooOol07Goo00<007ooOol00Woo
002cOol40004Ool30007Ool20008Ool2000bOol20036Ool00`00Oomoo`2MOol00`00>elkG`03>el;
0006>el01000OgAoM0000gmd00<007mdOg@00Wmd00@007mdOg@000=oM003001oM7md009oM004001o
M7md0004Og@01@00OgAoM7md00000Wmd00<007mdOg@00Wmd00@007mdOg@000=oM004001oM7md003o
OooCOol00`00Oomoo`0MOol00`00Oomoo`02Ool00;=oo`800003Ool0000000D000Qoo`8000Qoo`80
03Aoo`800<Aoo`03001oogoo09ioo`D0018kG`8000AoM003001oM7md009oM004001oM7md0003Og@0
1@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md0000
0gmd00@007mdOg@00?moomAoo`03001oogoo01eoo`03001oogoo005oo`00]7oo00<007ooOol01@00
2Goo0P0027oo0P00=Woo0P0027oo00<007ooOol0]goo00<007ooOol0X7oo0P002S]O30000gmd00D0
07mdOgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=o
M005001oM7mdOg@00003Og@01000OgAoM0000gmd00<007ooOol0ogoodgoo00<007ooOol077oo00<0
07ooOol00Goo002dOol2000?Ool20008Ool2000hOol20006Ool00`00Oomoo`2gOol00`00Oomoo`2R
Ool:000<>el30004Og@01@00OgAoM7md00000Wmd00<007mdOg@00Wmd00D007mdOgAoM00000=oM005
001oM7mdOg@00002Og@00`00OgAoM002Og@01@00OgAoM7md00000Wmd00D007mdOgAoM0000?moomIo
o`03001oogoo01]oo`03001oogoo005oo`00]7oo0`003goo0P001Woo0P00>goo0P0017oo00<007oo
Ool0]goo00<007ooOol0Y7oo00<003]O>el03S]O1`000gmd00@007mdOg@000=oM003001oM7md009o
M004001oM7md0004Og@01000OgAoM0000gmd00<007mdOg@00Wmd00@007mdOg@000=oM005001oM7md
Og@0003oOooFOol00`00Oomoo`0KOol00`00Oomoo`01Ool00;Eoo`<000ioo`8000Ioo`8003eoo`04
001oogoo002jOol00`00Oomoo`2UOol00`00>elkG`03>el:0007>el01000OgAoM0000Wmd00D007md
OgAoM00000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM005
001oM7mdOg@00002Og@00`00Oomoo`3oOooFOol00`00Oomoo`0JOol00`00Oomoo`01Ool00;Ioo`<0
00ioo`8000Aoo`8003moo`<00;Yoo`03001oogoo0:Ioo`D0018kG`8000=oM004001oM7md0004Og@0
1@00OgAoM7md00000gmd00D007mdOgAoM000009oM003001oM7md009oM005001oM7mdOg@00002Og@0
1@00OgAoM7md0000ogoofGoo00<007ooOol06Goo00<007ooOol00Goo002gOol80008Ool80011Ool2
002iOol00`00Oomoo`2XOol00`00>elkG`09>el<0002Og@01000OgAoM00017md00D007mdOgAoM000
00=oM005001oM7mdOg@00002Og@00`00OgAoM002Og@01@00OgAoM7md00000Wmd00D007mdOgAoM000
0?moomUoo`03001oogoo01Uoo`03001oogoo005oo`00^Goo1P002Woo1000AGoo0P00]goo00<007oo
Ool0ZGoo2`0033]O0P000gmd00<007mdOg@00Wmd00@007mdOg@000AoM004001oM7md0003Og@00`00
OgAoM002Og@01000OgAoM0000gmd00D007mdOgAoM0000?moomYoo`03001oogoo01Qoo`03001oogoo
005oo`00ogoo5Goo0P00]Goo00<007ooOol0Zgoo00<003]O>el03S]O1`000Wmd00D007mdOgAoM000
00=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM00000=oM004001oM7md
003oOooLOol00`00Oomoo`0GOol00`00Oomoo`01Ool00?mooaMoo`800;=oo`03001oogoo0:aoo`03
000kGc]O00<kG`X000LkG`8000AoM005001oM7mdOg@00003Og@01@00OgAoM7md00000Wmd00<007md
Og@00Wmd00D007mdOgAoM000009oM005001oM7mdOg@0003oOooMOol00`00Oomoo`0FOol00`00Oomo
o`01Ool00?mooaUoo`8000ioo`03001oogoo0:1oo`03001oogoo0:eoo`D000dkG`L000=oM004001o
M7md0004Og@01@00OgAoM7md00000Wmd00<007mdOg@00Wmd00@007mdOg@000=oM005001oM7mdOg@0
003oOooMOol00`00Oomoo`0FOol00`00Oomoo`01Ool00?mooa]oo`8000aoo`03001oogoo0:1oo`03
001oogoo0:moo`03000kGc]O00<kG`X000LkG`04001oM7md0002Og@00`00OgAoM002Og@01000OgAo
M0000gmd00<007mdOg@00Wmd00@007mdOg@000=oM005001oM7mdOg@0003oOooNOol00`00Oomoo`0E
Ool00`00Oomoo`01Ool00?mooaeoo`8000Yoo`03001oogoo0:1oo`03001oogoo0;1oo`D0018kG`80
00=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00D007mdOgAoM000009oM005001oM7md
Og@0003oOooPOol00`00Oomoo`0DOol00`00Oomoo`01Ool00?mooamoo`8000Qoo`03001oogoo0:1o
o`03001oogoo0;9oo`8000XkG``0009oM005001oM7mdOg@00003Og@01000OgAoM00017md00D007md
OgAoM000009oM005001oM7mdOg@0003oOooQOol00`00Oomoo`0COol00`00Oomoo`01Ool00?moob5o
o`8000Ioo`03001oogoo0:1oo`03001oogoo0;Aoo`X000`kG`8000AoM005001oM7mdOg@00002Og@0
0`00OgAoM002Og@01000OgAoM0000gmd00D007mdOgAoM0000?moon5oo`03001oogoo01=oo`03001o
ogoo005oo`00ogoo8goo0P0017oo00<007ooOol0X7oo00<007ooOol0]Goo00<003]O>el03S]O1`00
0gmd00@007mdOg@000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00<007ooOol0ogoo
h7oo00<007ooOol04Woo00<007ooOol00Goo003oOolUOol20002Ool00`00Oomoo`2POol00`00Oomo
o`2fOol00`00>elkG`03>el:0007>el30003Og@01@00OgAoM7md00000gmd00D007mdOgAoM000009o
M003001oM7md009oM003001oogoo0?moon5oo`03001oogoo015oo`03001oogoo005oo`00ogoo9goo
0`00XWoo00<007ooOol0]goo1@003S]O1P000gmd00@007mdOg@000AoM005001oM7mdOg@00002Og@0
1@00OgAoM7md0000ogooi7oo00<007ooOol04Goo00<007ooOol00Goo003oOolYOol2002QOol00`00
Oomoo`2iOol20005>el:0006>el01000OgAoM0000Wmd00<007mdOg@00Wmd00@007mdOg@000=oM005
001oM7mdOg@0003oOooUOol00`00Oomoo`0@Ool00`00Oomoo`01Ool00?moob]oo`8009moo`03001o
ogoo0;]oo`D0014kG`8000=oM005001oM7mdOg@00003Og@01@00OgAoM7md00000gmd00<007ooOol0
ogooi7oo00<007ooOol047oo0@000Goo0Goo003oOol]Ool2002MOol00`00Oomoo`2mOol00`00>elk
G`08>el<0002Og@01@00OgAoM7md00000gmd00@007mdOg@000AoM003001oogoo0?moonEoo`03001o
ogoo00moo`40005oo`5oo`00ogoo;goo0P00Vgoo00<007ooOol0_Woo2P0033]O0P0017md00D007md
OgAoM000009oM005001oM7mdOg@0003oOooXOol00`00Oomoo`0?Ool10001Ool1Ool00?mooc5oo`80
09Uoo`03001oogoo0<1oo`03000kGc]O00dkG`L000=oM004001oM7md0003Og@01@00OgAoM7md0000
ogoojGoo00<007ooOol03Woo0@000Goo0Goo003oOolcOol2002GOol00`00Oomoo`31Ool00`00>elk
G`03>el90007>el30003Og@01@00OgAoM7md00000gmd00<007ooOol0ogooj7oo00<007ooOol03Goo
0@000Goo0Goo003oOoleOol2002EOol00`00Oomoo`32Ool5000=>el60003Og@01000OgAoM00017md
00<007ooOol0ogoojGoo00<007ooOol037oo0@000Goo0Goo003oOolgOol20007Ool00`00Oomoo`29
Ool00`00Oomoo`34Ool00`00>elkG`03>el:0006>el01000OgAoM0000Wmd00D007mdOgAoM0000?mo
onaoo`03001oogoo00aoo`40005oo`5oo`00ogoo>Goo0P001Goo00<007ooOol0RGoo00<007ooOol0
aGoo1@004C]O0P000gmd00D007mdOgAoM0000?mooneoo`03001oogoo00]oo`40005oo`5oo`00ogoo
>goo0P000goo00<007ooOol0RGoo00<007ooOol0agoo00<003]O>el023]O30000Wmd00D007mdOgAo
M0000?moonioo`03001oogoo00Yoo`40005oo`5oo`00ogoo?Goo0P0000=oo`00Ool0RWoo00<007oo
Ool0b7oo2P0033]O0P0017md00<007ooOol0ogookGoo00<007ooOol02Goo0@000Goo0Goo003oOolo
Ool2002;Ool00`00Oomoo`3:Ool2000:>el;0003Og@00`00Oomoo`3oOoo]Ool00`00Oomoo`09Ool1
0001Ool1Ool00?mood5oo`8008Uoo`03001oogoo0<aoo`X000/kG`<00?mooo5oo`03001oogoo00Qo
o`40005oo`5oo`00ogoo@goo0P00Qgoo00<007ooOol0cGoo00<003]O>el03S]O1P00ogoolWoo00<0
07ooOol01goo0@000Goo0Goo003oOom5Ool20025Ool00`00Oomoo`3>Ool00`00>elkG`03>el:003o
OoohOol00`00Oomoo`07Ool10001Ool1Ool00?moodMoo`8008=oo`03001oogoo0<moo`D00?mooomo
o`Aoo`03001oogoo00Ioo`40005oo`5oo`00ogooBGoo0P00PGoo00<007ooOol0ogooogoofGoo00<0
07ooOol01Goo0@000Goo0Goo003oOom;Ool2001oOol00`00Oomoo`3oOoooOooJOol00`00Oomoo`04
Ool10001Ool1Ool00?moodeoo`8000Qoo`03001oogoo079oo`03001oogoo0?mooomoomYoo`03001o
ogoo00Aoo`40005oo`5oo`00ogooCgoo0P001Woo00<007ooOol0LWoo00<007ooOol0ogooogoofgoo
00<007ooOol00goo0@000Goo0Goo003oOomAOol20004Ool00`00Oomoo`1bOol00`00Oomoo`3oOooo
OooLOol00`00Oomoo`03Ool10001Ool00?mooe=oo`800003Ool007oo07Aoo`03001oogoo0?mooomo
omeoo`03001oogoo009oo`40005oo`00ogooEGoo0P00M7oo00<007ooOol0ogooogoogWoo00<007oo
Ool00Woo0@000Goo003oOolNOol7000:Ool4000TOol2001bOol00`00Oomoo`3oOoooOooOOol01@00
Oomoogoo00000Goo003oOolNOol70008Ool8000TOol2001`Ool00`00Oomoo`3oOoooOooPOol01000
Oomoo`000Goo003oOolQOol2000:Ool20004Ool2000VOol2001^Ool00`00Oomoo`3oOoooOooPOol0
1000Oomoo`000Goo003oOolQOol20009Ool20006Ool2000WOol2001/Ool00`00Oomoo`3oOoooOooQ
Ool00`00Ool00001Ool00?moob5oo`8000Uoo`8000Ioo`8002Uoo`8006Yoo`03001oogoo0?mooomo
on9oo`80005oo`00ogoo6Goo30001Woo0P0027oo0P00:Woo0P00J7oo00<007ooOol0ogooogoog7oo
20000Goo003oOolIOol<0006Ool20008Ool2000/Ool20007Ool00`00Oomoo`1LOol00`00Oomoo`3o
OoooOoo>Ool>0009Ool00?mooaUoo`8000Ioo`800003Ool007oo00Eoo`8000Qoo`8002ioo`8000Eo
o`03001oogoo05aoo`03001oogoo0?mooomool1oo`h001Moo`00ogoo6Woo0P001Goo0P0027oo0P00
27oo0P00<7oo0P000goo00<007ooOol0G7oo00<007ooOol0ogooogoo/Woo3P009Goo003oOolJOol3
0004Ool20008Ool20008Ool2000bOol200000goo001oo`1MOol00`00Oomoo`3oOoooOonTOol>000c
Ool00?mooa]oo`8000Aoo`8000Qoo`8000Qoo`8003Aoo`8005ioo`03001oogoo0?mooomooiIoo`h0
045oo`00ogoo77oo0P000goo0P0027oo0P0027oo0P00=Woo0P00G7oo00<007ooOol0ogooogooR7oo
3P00Cgoo003oOolLOol30002Ool20008Ool20008Ool2000hOol2001JOol00`00Oomoo`3oOoooOomj
Ool>001MOol00?mooaeoo`80009oo`8000Uoo`8000Ioo`8003]oo`8000ioo`03001oogoo04Moo`03
001oogoo0?mooomoofaoo`h006]oo`00ogoo7Woo0P0000=oo`0000002Goo0P001Woo0P00?Goo0P00
37oo00<007ooOol0Agoo00<007ooOol0ogooogooGWoo3P00NGoo003oOolOOol4000:Ool20004Ool2
0010Ool2000:Ool00`00Oomoo`17Ool00`00Oomoo`3oOoooOom@Ool>0027Ool00?mooamoo`@000Yo
o`P0049oo`8000Qoo`03001oogoo04Moo`03001oogoo0?mooomood9oo`h009Eoo`00ogoo87oo0`00
37oo1000AWoo0P001Woo00<007ooOol0Agoo00<007ooOol0ogooogoo=7oo3P00Xgoo003oOomkOol2
0004Ool00`00Oomoo`17Ool00`00Oomoo`3oOoooOolVOol>002aOol00?moogeoo`80009oo`03001o
ogoo04Moo`03001oogoo0?mooomooaQoo`h00;moo`00ogooOgoo0`00BGoo00<007ooOol0ogooogoo
2Woo3P00cGoo003oOon1Ool20018Ool00`00Oomoo`3oOookOol>003KOol00?mooh=oo`8004Ioo`03
001oogoo0?mooneoo`h00>Uoo`00ogooQGoo0P00A7oo00<007ooOol0ogooggoo3P00mgoo003oOon7
Ool20012Ool00`00Oomoo`3oOooAOol>003oOol6Ool00?moohUoo`80041oo`03001oogoo0?mool=o
o`h00?mooaAoo`00ogooRgoo00<007ooOol01goo00<007ooOol0<goo00<007ooOol0ogoo]Goo3P00
ogoo8Woo003oOon<Ool20007Ool00`00Oomoo`0cOol00`00Oomoo`3oOonWOol>003oOol`Ool00?mo
ohioo`8000Eoo`03001oogoo03=oo`03001oogoo0?mooiUoo`h00?moocioo`00ogooT7oo0P000goo
00<007ooOol0<goo00<007ooOol0ogooRgoo3P00ogooC7oo003oOonBOol200000goo001oo`0dOol0
0`00Oomoo`3oOommOol>003oOomJOol00?mooiAoo`8003Eoo`03001oogoo0?moofmoo`h00?moofQo
o`00ogooUWoo0P00<goo00<007ooOol0ogooHWoo3@00ogooMWoo003oOonHOol2000aOol00`00Oomo
o`3oOomDOol>003oOon3Ool00?mooiYoo`8002moo`03001oogoo0?moodIoo`h00?mooi5oo`00ogoo
W7oo0P00;Goo00<007ooOol0ogoo>7oo3P00ogooWgoo003oOonNOol20009Ool00`00Oomoo`0OOol0
0`00Oomoo`3oOolZOol>003oOon]Ool00?mooj1oo`8000Moo`03001oogoo01moo`03001oogoo0?mo
oaaoo`h00?mook]oo`00ogooXWoo0P001Goo00<007ooOol07goo00<007ooOol0ogoo3Woo3P00ogoo
bGoo003oOonTOol20002Ool00`00Oomoo`0OOol00`00Oomoo`3oOol1Ool>003oOooGOol00?moojIo
o`<0025oo`03001oogoo0?9oo`h00?moonEoo`00ogooZ7oo0P0087oo00<007ooOol0i7oo3P00ogoo
lgoo003oOonZOol2000NOol00`00Oomoo`3FOol>003oOoooOol2Ool00?moojaoo`8001aoo`03001o
ogoo0<Qoo`h00?mooomooa1oo`00ogooL7oo30002goo10008goo0P006Woo00<007ooOol0^Woo3P00
ogooogoo7Woo003oOom`Ool<0009Ool8000SOol2000HOol00`00Oomoo`2/Ool>003oOoooOol/Ool0
0?moog5oo`<000Ioo`8000Uoo`8000Aoo`8002Eoo`8000Qoo`03001oogoo00]oo`03001oogoo09io
o`h00?mooomoocYoo`00ogooLWoo0`003goo0P001Woo0P009Woo0P001Woo00<007ooOol02goo00<0
07ooOol0T7oo3P00ogooogooB7oo003oOomcOol3000>Ool20006Ool2000XOol20004Ool00`00Oomo
o`0;Ool00`00Oomoo`22Ool>003oOoooOomFOol00?moogAoo`<000aoo`8000Qoo`8002Uoo`800003
Ool007oo00eoo`03001oogoo07Aoo`h00?mooomoofAoo`00ogooMGoo0`002goo0P0027oo0P00:goo
0P003Woo00<007ooOol0IWoo3P00ogooogooLWoo003oOomfOol3000:Ool20008Ool2000]Ool2000<
Ool00`00Oomoo`1HOol>003oOoooOon0Ool00?moogMoo`<000Uoo`8000Qoo`8002moo`8000Yoo`03
001oogoo04Yoo`h00?mooomoohioo`00ogooN7oo0`0027oo0P0027oo0P00<Goo0P0027oo00<007oo
Ool0?7oo3P00ogooogooW7oo003oOomiOol20008Ool20008Ool2000cOol20006Ool00`00Oomoo`0^
Ool>003oOoooOonZOol00?moogYoo`8000Moo`8000Qoo`8003Eoo`8000Aoo`03001oogoo021oo`h0
0?mooomookQoo`00ogooNWoo0P001goo0P0027oo0P00=goo0P000Woo00<007ooOol04Woo3P00ogoo
ogooaWoo003oOomaOol20007Ool20008Ool20006Ool2000jOol30006Ool>003oOoooOooDOol00?mo
og5oo`<000Ioo`8000Qoo`8000Ioo`8003aoo`L00?mooomoon9oo`00ogooLGoo100017oo0P002Woo
0P0017oo0P00ogooogooogoo9goo003oOombOol8000;Ool8003oOoooOoooOolWOol00?moogAoo`D0
00ioo`@00?mooomooomoobUoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00001\
\>"], "Graphics",
  CellLabel->"From In[37]:=",
  Evaluatable->False,
  ImageSize->{400, 241.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell["\<\
View of the resulting potential including dielectric material. The \
dielectric effects on the potential are evident in the abrupt change of the \
gradient on the flank to the right of the peak. \
\>", "Text",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell["contourplot with fieldlines", "Subsubsection",
  PageBreakAbove->True],

Cell["A contourplot is generated for later display:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cont = 
      ListContourPlot[u, ImageSize \[Rule] 400, PlotRange \[Rule] All, 
        ContourShading \[Rule] False, Contours \[Rule] 15, 
        DisplayFunction \[Rule] Identity]\)], "Input",
  CellLabel->"In[38]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  ContourGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell["\<\
The electric field vector is given as derivative of an interpolated \
function of the potential u :\
\>", "Text"],

Cell[BoxData[{
    \(\(wi = 
        ListInterpolation[Transpose[u], 
          InterpolationOrder \[Rule] 1];\)\[IndentingNewLine] (*\ 
      column\ index\ counts\ increments\ in\ x\ direction, \ 
      row\ index\ counts\ increments\ in\ y\ direction\  \[Rule] \ 
        use\ Transpose\ *) \), "\n", 
    \(\(ex = \(Derivative[1, 0]\)[wi];\)\), "\n", 
    \(\(ey = \(Derivative[0, 1]\)[wi];\)\)}], "Input",
  CellLabel->"In[39]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell["\<\
The lines follow the field from the starting point x0, y0 uphill \
and downhill as far as possible...\
\>", "Text",
  PageBreakAbove->Automatic],

Cell[BoxData[
    \(FieldLine[{ex_InterpolatingFunction, x0_}, {ey_InterpolatingFunction, 
          y0_}] := \[IndentingNewLine]Module[{x = x0, y = y0, 
          l = {{x0, y0}}, \[IndentingNewLine]xxmin = Part[ex, 1, 1, 1], 
          xxmax = Part[ex, 1, 1, 2], \[IndentingNewLine]yymin = 
            Part[ex, 1, 2, 1], yymax = Part[ex, 1, 2, 2], emod10, xn, 
          yn}, \[IndentingNewLine] (*\ 
          search\ uphill\ *) \[IndentingNewLine]Do[{emod10 = 
              10.  \[Sqrt]\((\((ex[x, y])\)\^2 + \((ey[x, y])\)\^2)\); 
            If[emod10 == 0. , Break[]]; \[IndentingNewLine]xn = 
              ex[x, y]/emod10 + x; 
            yn = ey[x, y]/emod10 + y; \[IndentingNewLine]If[
              xn < xxmin || xn > xxmax || yn < yymin || yn > yymax, 
              Break[]]; \[IndentingNewLine]\(l = Append[l, {xn, yn}]; x = xn; 
            y = yn\)}, {n, 1, 5000}]; \[IndentingNewLine]x = x0; 
        y = y0; \[IndentingNewLine] (*\ 
          search\ downhill\ *) \[IndentingNewLine]Do[{emod10 = \(-10. \) \
\[Sqrt]\((\((ex[x, y])\)\^2 + \((ey[x, y])\)\^2)\); 
            If[emod10 == 0. , Break[]]; \[IndentingNewLine]xn = 
              ex[x, y]/emod10 + x; 
            yn = ey[x, y]/emod10 + y; \[IndentingNewLine]If[
              xn < xxmin || xn > xxmax || yn < yymin || yn > yymax, 
              Break[]]; \[IndentingNewLine]\(l = Prepend[l, {xn, yn}]; 
            x = xn; y = yn\)}, {n, 1, 5000}]; \[IndentingNewLine]Line[
          l]]\)], "Input",
  CellLabel->"In[42]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(Needs["\<Graphics`Arrow`\>"]\)], "Input",
  CellLabel->"In[43]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  "Add directional arrows to the fieldlines (",
  StyleBox["Ref. 9",
    FontWeight->"Bold"],
  ", p. 522):"
}], "Text",
  PageBreakAbove->True],

Cell[BoxData[
    \(AddArrow[Line[opts_], d_, 
        num_:  8] := \[IndentingNewLine]Module[{arr = {}, n = 0, 
          pts = Chop[opts]}, \[IndentingNewLine]Fold[\[IndentingNewLine]If[
              First[#1] \[GreaterEqual] d && 
                n < num, \(n++\); \[IndentingNewLine]AppendTo[arr, 
                Arrow[Last[#1], #2, HeadScaling \[Rule] Absolute, 
                  HeadCenter \[Rule] 0.5, 
                  HeadLength \[Rule] 
                    4]]; \[IndentingNewLine]{0, #2}, {First[#1] + 
                  Sqrt[Apply[Plus, \((Last[#1] - #2)\)^2]], #2}] &, {0, 
            First[pts]}, Rest[pts]]; \[IndentingNewLine]arr]\)], "Input",
  CellLabel->"In[44]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell["\<\
We let n fieldlines run up and down from an ellipse with center xe, \
ye and half axes a, b. The density of the field lines is weighted with the \
strength of the field at the starting points. The dielectric area is \
indicated with a grey line. You have to experiment with the parameters to get \
a decent picture...\
\>", "Text",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{

Cell[BoxData[{
    \({xe, ye} = {30, 16.5}; a = 14; b = 10;\), "\[IndentingNewLine]", 
    \(\(n = 21;\) (*\ n/3\ is\ the\ number\ of\ angular\ bins\ *) \), "\n", 
    \(\(eps = 
        ListInterpolation[
          Transpose[\[Epsilon]]];\)\), "\[IndentingNewLine]", 
    \( (*\ sample\ the\ field\ strength\ on\ the\ ellipse\ *) \(ft = 
        Table[eps[a\ Cos[i\ 2  \[Pi]/n] + xe, 
              b\ Sin[i\ 2  \[Pi]/n] + 
                ye] \[Sqrt]\((ex[a\ Cos[i\ 2  \[Pi]/n] + xe, 
                      b\ Sin[i\ 2  \[Pi]/n] + ye]^2 + 
                  ey[a\ Cos[i\ 2  \[Pi]/n] + xe, 
                      b\ Sin[i\ 2  \[Pi]/n] + ye]^2)\), {i, 1, 
            n}];\)\), "\n", 
    \(\(s = Apply[Plus, ft];\)\[IndentingNewLine] (*\ 
      nl[\([i]\)]\ is\ \((number\ of\ lines\  - \ 
            1)\)\ starting\ in\ the\ ith\ angular\ bin\ of\ the\ ellipse\ *) \
\), "\n", 
    \(\(nl = Round[Apply[Plus, Transpose[Partition[ft, 3]]]/s*n];\)\), "\n", 
    \(\(start = {};\)\[IndentingNewLine] (*\ 
      array\ of\ angles\ of\ the\ starting\ points\ on\ the\ ellipse\ *) \), \
"\n", 
    \(\(Do[
        Do[AppendTo[
            start, \((2  \[Pi]/\((n/3)\))\)\ \((\((i - 1)\) + 
                  j\ /\((nl[\([i]\)] + 1)\))\)], {j, 0, nl[\([i]\)]}], {i, 1, 
          n/3}];\)\), "\[IndentingNewLine]", 
    \( (*\ calculate\ lines\ one\ after\ the\ other\ *) \(lines = 
        Table[FieldLine[{ex, a\ Cos[start[\([i]\)]] + xe}, {ey, 
              b\ Sin[start[\([i]\)]] + ye}], {i, 1, 
            Length[start]}];\)\[IndentingNewLine] (*\ 
      add\ single\ lines\ where\ appropriate\ *) \), "\[IndentingNewLine]", 
    \(line1 = FieldLine[{ex, 25}, {ey, 34}]; AppendTo[lines, line1]; 
    line2 = FieldLine[{ex, 34}, {ey, 34}]; AppendTo[lines, line2];\), "\n", 
    \(\(arrows = Map[AddArrow[#, 6] &, lines];\)\[IndentingNewLine] (*\ r1, 
      r2\  : \ electrodes, \ r3 : \ dielectrics\ *) \), "\n", 
    \(r1 = Rectangle[{xl1, yd1}, {xr1, yu1}]; 
    r2 = Rectangle[{xl2, yd2}, {xr2, yu2}]; 
    r3 = {Line[{{exl, eyd}, {exl, eyu}}], Line[{{exl, eyu}, {exr, eyu}}], 
        Line[{{exr, eyu}, {exr, eyd}}], 
        Line[{{exr, eyd}, {exl, eyd}}]};\), "\n", 
    \(Show[Graphics[{GrayLevel[0.8], Thickness[0.015], r3}], cont, 
      Graphics[{lines, arrows, r1, r2}], ImageSize \[Rule] 400, 
      Frame \[Rule] True, 
      DisplayFunction \[Rule] $DisplayFunction]\)}], "Input",
  CellLabel->"In[45]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000B`0002iA000`40O003h00Oogooogooogooogoo
]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOooo
OoooOoooOondOol005=oo`@00?aoo``000]oo`@00?Qoo`L000Yoo`@00?Qoo`D000eoo`@00?Ioo`H0
00eoo`@001Yoo`00DGoo2000nWoo30002Goo2000mWoo1`0027oo2000m7oo20002Woo2000lgoo2000
2Woo200067oo001AOol20004Ool2003kOol30006Ool20009Ool20004Ool2003iOol2000:Ool20004
Ool2003dOol20004Ool30009Ool20004Ool2003bOol30004Ool30009Ool20004Ool2000HOol0051o
o`8000Ioo`800?]oo`<000moo`8000Ioo`800?Qoo`8000Uoo`8000Ioo`800?9oo`8000Ioo`<000Mo
o`8000Ioo`800?1oo`<000Ioo`<000Moo`8000Ioo`8001Moo`00D7oo0P001Woo0P00o7oo0`003Woo
0P001Woo0P00n7oo0P002Goo0P001Woo0P00lGoo0P0027oo0P001goo0P001Woo0P00l7oo0P0027oo
0P001goo0P001Woo0P005goo001?Ool20008Ool2003lOol3000<Ool20008Ool2003_Ool<0006Ool2
0008Ool2003`Ool20008Ool20006Ool20008Ool2003_Ool20008Ool20006Ool20008Ool2000FOol0
04moo`8000Qoo`800?eoo`<000]oo`8000Qoo`800>moo``000Ioo`8000Qoo`800?1oo`8000Qoo`80
00Ioo`8000Qoo`800>moo`8000Qoo`8000Ioo`8000Qoo`8001Ioo`00Cgoo0P0027oo0P00oWoo0`00
2Woo0P0027oo0P00kgoo0P001Woo0P0000=oo`00Ool01Goo0P0027oo0P00l7oo0P0027oo0P001Woo
0P0027oo0P00kgoo0`001Woo0`001Woo0P0027oo0P005Woo001?Ool20008Ool2003oOol30009Ool2
0008Ool2003`Ool20005Ool20008Ool20008Ool2003`Ool30006Ool30006Ool20008Ool2003`Ool3
0004Ool30007Ool20008Ool2000FOol004moo`8000Qoo`800?moo`5oo`<000Qoo`8000Qoo`800?1o
o`<000Aoo`8000Qoo`8000Qoo`800?1oo`@000Aoo`<000Moo`8000Qoo`800?5oo`P000Qoo`8000Qo
o`8001Ioo`00Cgoo0P0027oo0P00ogoo0Woo0P0027oo0P0027oo0P00lGoo0P0017oo0P0027oo0P00
27oo0P00l7oo0P0000=oo`0000001@0027oo0P0027oo0P00lGoo200027oo0P0027oo0P005Woo001?
Ool20008Ool2003oOol3Ool20007Ool20008Ool2003bOol20003Ool20008Ool20008Ool2003aOol0
0`00Oomoo`050009Ool20008Ool2003`Ool30004Ool30007Ool20008Ool2000FOol004moo`8000Qo
o`800?moo`=oo`8000Moo`8000Qoo`800?9oo`<0009oo`8000Qoo`8000Qoo`800?5oo`8000moo`80
00Qoo`800>moo`8000Qoo`8000Ioo`8000Qoo`8001Ioo`00D7oo0P001Woo0P00nWoo0P001goo0P00
27oo0P001Woo0P00m7oo0P000Woo0P002Goo0P001Woo0P00lWoo0`003goo0P001Woo0P00l7oo0P00
27oo0P001goo0P001Woo0P005goo001@Ool20006Ool2003jOol30006Ool20008Ool20006Ool2003e
Ool200000goo00000009Ool20006Ool2003cOol3000>Ool20006Ool2003`Ool20008Ool20007Ool2
0006Ool2000GOol0055oo`8000Aoo`800?]oo`@000Aoo`8000Yoo`8000Aoo`800?Moo`@000Yoo`80
00Aoo`800?Eoo`<000ioo`8000Aoo`800?9oo`<000Aoo`@000Qoo`8000Aoo`8001Qoo`00DGoo2000
o7oo20002goo2000mgoo10002Woo2000mWoo200027oo2000lWoo2P002Goo200067oo001COol4003o
Ool1Ool5000>Ool4003jOol3000<Ool4003jOol6000:Ool4003fOol6000=Ool4000JOol00?mooomo
oomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAo
o`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogoo
ogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo
003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOooo
OoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol0
03Yoool00?l00?l00?l0074000Uoo`00>Woo00<007ooOol067oo00<007ooOol0@7oo00<007ooOol0
@Goo00<007ooOol0@7oo00<007ooOol0@Goo00<007ooOol0@7oo00<007ooOol0@7oo00<007ooOol0
@Goo00<007ooOol0@7oo00<007ooOol0@Goo00<007ooOol0@7oo00<007ooOol0@7oo00<007ooOol0
@Goo00<007ooOol0@7oo00<007ooOol0@Goo00<007ooOol0@7oo00<007ooOol0@7oo00<007ooOol0
67oo00<007ooOol01goo000jOol00`00Oomoo`0HOol00`00Oomoo`10Ool00`00Oomoo`11Ool00`00
Oomoo`10Ool00`00Oomoo`11Ool00`00Oomoo`10Ool00`00Oomoo`10Ool00`00Oomoo`11Ool00`00
Oomoo`10Ool00`00Oomoo`11Ool00`00Oomoo`10Ool00`00Oomoo`10Ool00`00Oomoo`11Ool00`00
Oomoo`10Ool00`00Oomoo`11Ool00`00Oomoo`10Ool00`00Oomoo`10Ool00`00Oomoo`0HOol00`00
Oomoo`07Ool003Yoo`03001oogoo01Qoo`03001oogoo041oo`03001oogoo045oo`03001oogoo041o
o`03001oogoo045oo`03001oogoo041oo`03001oogoo041oo`03001oogoo045oo`03001oogoo041o
o`03001oogoo045oo`03001oogoo041oo`03001oogoo041oo`03001oogoo045oo`03001oogoo041o
o`03001oogoo045oo`03001oogoo041oo`03001oogoo041oo`03001oogoo01Qoo`03001oogoo00Mo
o`00>Woo00<007ooOol067oo00<007ooOol0@7oo00<007ooOol0@Goo00<007ooOol0@7oo00<007oo
Ool0@Goo00<007ooOol0@7oo00<007ooOol0@7oo00<007ooOol0@Goo00<007ooOol0@7oo00<007oo
Ool0@Goo00<007ooOol0@7oo00<007ooOol0@7oo00<007ooOol0@Goo00<007ooOol0@7oo00<007oo
Ool0@Goo00<007ooOol0@7oo00<007ooOol0@7oo00<007ooOol067oo00<007ooOol01goo000jOol0
0`00Oomoo`0HOol00`00Oomoo`3oOol<Ool00`00Oomoo`3oOol;Ool00`00Oomoo`3oOol<Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`0HOol00`00Oomoo`07Ool003Yoo`03001oogoo01Qoo`03001oogoo
0?moo`aoo`03001oogoo0?moo`]oo`03001oogoo0?moo`aoo`03001oogoo0?moo`]oo`03001oogoo
01Qoo`03001oogoo00Moo`00>Woo00<007ooOol067oo00<007ooOol0ogoo37oo00<007ooOol0ogoo
2goo00<007ooOol0ogoo37oo00<007ooOol0ogoo2goo00<007ooOol067oo00<007ooOol01goo000j
Ool00`00Oomoo`3oOoooOoooOoooOom]Ool00`00Oomoo`07Ool003Yoo`03001oogoo0?mooomooomo
oomoofeoo`03001oogoo00Moo`008Goo10005Goo00<007ooOol0ogooogooogooogooKGoo00<007oo
Ool01goo000OOol8000COol00`00Oomoo`3oOoooOoooOoooOom]Ool00`00Oomoo`07Ool001moo`80
00Aoo`8001=oo`03001oogoo0?mooomooomooomoofeoo`03001oogoo00Moo`007Woo0P001Woo0P00
4Woo00<007ooOol0ogooogooogooogooKGoo00<007ooOol01goo000NOol20006Ool2000BOol00`00
Oomoo`3oOoooOoooOoooOom]Ool00`00Oomoo`07Ool001eoo`8000Qoo`80015oo`03001oogoo0?mo
oomooomooomoofeoo`03001oogoo00Moo`007Goo0P0027oo0P004Goo00<007ooOol0ogooogooogoo
ogooKGoo00<007ooOol01goo000MOol20008Ool2000AOol8003oOoooOoooOoooOomQOol80009Ool0
01eoo`8000Qoo`80015oo`03001oogoo0?mooomooomooomoofeoo`03001oogoo00Moo`007Goo0P00
27oo0P004Goo00<007ooOol0ogooogooogooogooKGoo00<007ooOol01goo000MOol20008Ool2000A
Ool00`00Oomoo`3oOoooOoooOoooOom]Ool00`00Oomoo`07Ool001eoo`8000Qoo`80015oo`03001o
ogoo0?mooomooomooomoofeoo`03001oogoo00Moo`007Goo0P0027oo0P004Goo00<007ooOol0ogoo
ogooogooogooKGoo00<007ooOol01goo000NOol20006Ool2000BOol00`00Oomoo`3oOoooOoooOooo
Oom]Ool00`00Oomoo`07Ool001ioo`8000Ioo`80019oo`03001oogoo0?mooomooomooomoofeoo`03
001oogoo00Moo`007goo0P0017oo0P004goo00<007ooOol0ogooogooogooogooKGoo00<007ooOol0
1goo000OOol8000COol00`00Oomoo`3oOoooOoooOoooOom]Ool00`00Oomoo`07Ool0025oo`@001Eo
o`03001oogoo0?mooomooomooomoofeoo`03001oogoo00Moo`00>Woo00<007ooOol0ogooogooogoo
ogooKGoo00<007ooOol01goo000jOol00`00Oomoo`3oOoooOoooOoooOom]Ool00`00Oomoo`07Ool0
03Yoo`03001oogoo0?mooomooomooomoofeoo`03001oogoo00Moo`00>Woo00<007ooOol0ogooogoo
ogooogooKGoo00<007ooOol01goo000jOol00`00Oomoo`3oOoooOoooOoooOom]Ool00`00Oomoo`07
Ool003Yoo`03001oogoo0?moojeoo`03001oogoo0?mooomookaoo`03001oogoo00Moo`00>Woo00<0
07ooOol0kWoo00<007ooOol0<goo00<007ooOol0:goo00<007ooOol0:Woo00<007ooOol0:Woo00<0
07ooOol0:goo00<007ooOol0:Woo00<007ooOol0M7oo00<007ooOol0ogoojGoo00<007ooOol01goo
000jOol00`00Oomoo`2TOol00`00Oomoo`17Ool00`00Oomoo`0cOol00`00Oomoo`0[Ool00`00Oomo
o`0ZOol00`00Oomoo`0ZOol00`00Oomoo`0[Ool00`00Oomoo`0ZOol00`00Oomoo`0/Ool00`00Oomo
o`15Ool00`00Oomoo`1ROol00`00Oomoo`3oOon4Ool00`00Oomoo`07Ool003Yoo`03001oogoo0:Ao
o`03001oogoo04Moo`03001oogoo03=oo`03001oogoo02]oo`03001oogoo02Yoo`03001oogoo02Yo
o`03001oogoo02]oo`03001oogoo02Yoo`03001oogoo02aoo`03001oogoo04Eoo`03001oogoo069o
o`03001oogoo0?moohAoo`03001oogoo00Moo`00>Woo00<007ooOol0Y7oo00<007ooOol0Agoo00<0
07ooOol0<goo00<007ooOol0:goo00<007ooOol0:Woo00<007ooOol0:Woo00<007ooOol0:goo00<0
07ooOol0:Woo00<007ooOol0;7oo00<007ooOol0AGoo00<007ooOol0HWoo00<007ooOol0ogooQ7oo
00<007ooOol01goo000jOol00`00Oomoo`2TOol00`00Oomoo`17Ool00`00Oomoo`0cOol00`00Oomo
o`0[Ool00`00Oomoo`0ZOol00`00Oomoo`0ZOol00`00Oomoo`0[Ool00`00Oomoo`0ZOol00`00Oomo
o`0/Ool00`00Oomoo`15Ool00`00Oomoo`1ROol00`00Oomoo`3oOon4Ool00`00Oomoo`07Ool003Yo
o`03001oogoo0:Aoo`03001oogoo04Moo`03001oogoo03=oo`03001oogoo02]oo`03001oogoo02Yo
o`03001oogoo02Yoo`03001oogoo02]oo`03001oogoo02Yoo`03001oogoo02aoo`03001oogoo04Eo
o`03001oogoo069oo`03001oogoo0?moohAoo`03001oogoo00Moo`00>Woo00<007ooOol0Y7oo00<0
07ooOol0Agoo00<007ooOol0<goo00<007ooOol0:goo00<007ooOol0:Woo00<007ooOol0:Woo00<0
07ooOol0:goo00<007ooOol0:Woo00<007ooOol0;7oo00<007ooOol0AGoo00<007ooOol0HWoo00<0
07ooOol0ogooQ7oo00<007ooOol01goo000jOol00`00Oomoo`2TOol00`00Oomoo`17Ool00`00Oomo
o`0cOol00`00Oomoo`0[Ool00`00Oomoo`0ZOol00`00Oomoo`0ZOol00`00Oomoo`0[Ool00`00Oomo
o`0ZOol00`00Oomoo`0/Ool00`00Oomoo`15Ool00`00Oomoo`1ROol00`00Oomoo`3oOon4Ool00`00
Oomoo`07Ool003Yoo`03001oogoo0:Aoo`03001oogoo04Moo`03001oogoo03=oo`03001oogoo02]o
o`03001oogoo02Yoo`03001oogoo02Yoo`03001oogoo02]oo`03001oogoo02Yoo`03001oogoo02ao
o`03001oogoo04Eoo`03001oogoo069oo`03001oogoo0?moohAoo`03001oogoo00Moo`00>Woo00<0
07ooOol0Y7oo00<007ooOol0Agoo00<007ooOol0<goo00<007ooOol0:goo00<007ooOol0:Woo00<0
07ooOol0:Woo00<007ooOol0:goo00<007ooOol0:Woo00<007ooOol0;7oo00<007ooOol0AGoo00<0
07ooOol0HWoo00<007ooOol0ogooQ7oo00<007ooOol01goo000jOol00`00Oomoo`2TOol00`00Oomo
o`17Ool00`00Oomoo`0cOol00`00Oomoo`0[Ool00`00Oomoo`0ZOol00`00Oomoo`0ZOol00`00Oomo
o`0[Ool00`00Oomoo`0ZOol00`00Oomoo`0/Ool00`00Oomoo`15Ool00`00Oomoo`1ROol00`00Oomo
o`3oOon4Ool00`00Oomoo`07Ool003Yoo`03001oogoo0:Aoo`03001oogoo04Qoo`03001oogoo039o
o`03001oogoo02]oo`03001oogoo00eoohP001eoo`03001oogoo02aoo`03001oogoo04Eoo`03001o
ogoo069oo`03001oogoo0?moohAoo`03001oogoo00Moo`00>Woo00<007ooOol0Y7oo00<007ooOol0
B7oo00<007ooOol0<Woo00<007ooOol08Goo6P007Goo00<007ooOol0:Woo00<007ooOol0:goo00<0
07ooOol03Goo:@008goo00<007ooOol0A7oo00<007ooOol0Hgoo00<007ooOol0ogooQ7oo00<007oo
Ool01goo000jOol00`00Oomoo`2TOol00`00Oomoo`18Ool00`00Oomoo`0bOol00`00Oomoo`06OolK
000:Ool00`00Oomoo`0ZOol00`00Oomoo`0ZOol00`00Oomoo`0[Ool00`00Oomoo`0ZOol00`00Oomo
o`09OolK0008Ool00`00Oomoo`14Ool00`00Oomoo`1SOol00`00Oomoo`3oOon4Ool00`00Oomoo`07
Ool003Yoo`03001oogoo0:Aoo`03001oogoo04Qoo`03001oogoo02eoo`h002Eoo`03001oogoo02Yo
o`03001oogoo02Yoo`03001oogoo02]oo`03001oogoo02Yoo`03001oogoo02Aoo`d0049oo`03001o
ogoo06=oo`03001oogoo0?moohAoo`03001oogoo00Moo`00>Woo00<007ooOol0Y7oo00<007ooOol0
B7oo00<007ooOol087oo3@001Goo00<007ooOol0:goo00<007ooOol0:Woo00<007ooOol0:Woo00<0
07ooOol0:goo00<007ooOol0:Woo00<007ooOol0;7oo00<007ooOol00Woo3P00=7oo00<007ooOol0
Hgoo00<007ooOol0ogooQ7oo00<007ooOol01goo000jOol5002ROol00`00Oomoo`18Ool00`00Oomo
o`0?OolA000BOol00`00Oomoo`0[Ool00`00Oomoo`0ZOol00`00Oomoo`0ZOol00`00Oomoo`0[Ool0
0`00Oomoo`0ZOol00`00Oomoo`0/Ool00`00Oomoo`0@Ool>000VOol00`00Oomoo`1SOol00`00Oomo
o`3oOomoOol60009Ool003Yoo`03001oogoo0:Eoo`03001oogoo04Moo`03001oogoo00Eoo`X002=o
o`03001oogoo02]oo`03001oogoo02Yoo`03001oogoo02Yoo`03001oogoo02]oo`03001oogoo02Yo
o`03001oogoo02aoo`03001oogoo01ioo`d001Uoo`03001oogoo06=oo`03001oogoo0?moohAoo`03
001oogoo00Moo`00>Woo00<007ooOol0YGoo00<007ooOol0AGoo2P00;Goo00<007ooOol0;7oo00<0
07ooOol0:Goo00<007ooOol0:Woo00<007ooOol0:goo00<007ooOol0:Woo00<007ooOol0;7oo00<0
07ooOol0:goo2P003goo00<007ooOol0Hgoo00<007ooOol0ogooQ7oo00<007ooOol01goo000jOol0
0`00Oomoo`2UOol00`00Oomoo`0nOol70002Ool00`00Oomoo`0bOol00`00Oomoo`0/Ool00`00Oomo
o`0YOol00`00Oomoo`0ZOol00`00Oomoo`0[Ool00`00Oomoo`0ZOol00`00Oomoo`0/Ool00`00Oomo
o`0eOol70008Ool00`00Oomoo`1ROol00`00Oomoo`3oOon5Ool00`00Oomoo`07Ool003Yoo`03001o
ogoo0:Eoo`03001oogoo03Moo`L000Uoo`03001oogoo039oo`03001oogoo02aoo`03001oogoo02Uo
o`03001oogoo02Yoo`03001oogoo02]oo`03001oogoo02Yoo`03001oogoo02aoo`03001oogoo03ao
o`H0009oo`03001oogoo069oo`03001oogoo0?moohEoo`03001oogoo00Moo`00>Woo00<007ooOol0
YGoo00<007ooOol0<7oo1`0047oo00<007ooOol0<Woo00<007ooOol0;7oo00<007ooOol0:Goo00<0
07ooOol0:Woo00<007ooOol0:goo00<007ooOol0:Woo00<007ooOol0;7oo00<007ooOol0@Woo1`00
H7oo00<007ooOol0ogooQGoo00<007ooOol01goo000jOol00`00Oomoo`2UOol00`00Oomoo`0ZOol6
000GOol00`00Oomoo`0bOol00`00Oomoo`0/Ool00`00Oomoo`0ZOol00`00Oomoo`0YOol00`00Oomo
o`0[Ool00`00Oomoo`0ZOol00`00Oomoo`0/Ool00`00Oomoo`14Ool00`00Oomoo`02Ool:001FOol0
0`00Oomoo`3oOon5Ool00`00Oomoo`07Ool003Yoo`03001oogoo0:Eoo`03001oogoo02=oo`L001eo
o`03001oogoo03=oo`03001oogoo02]oo`03001oogoo02Yoo`03001oogoo02Uoo`03001oogoo02]o
o`03001oogoo02Yoo`03001oogoo02aoo`03001oogoo04Aoo`03001oogoo00aoo`X004aoo`03001o
ogoo0?moohEoo`03001oogoo00Moo`00>Woo00<007ooOol0YGoo00<007ooOol07Goo1P0097oo00<0
07ooOol0<goo00<007ooOol0:goo00<007ooOol0:Woo00<007ooOol0:Goo00<007ooOol0:goo00<0
07ooOol0:Woo00<007ooOol0;7oo00<007ooOol0A7oo00<007ooOol05Woo1`00AGoo00<007ooOol0
ogooQGoo00<007ooOol01goo000jOol00`00Oomoo`2UOol00`00Oomoo`0HOol5000[Ool00`00Oomo
o`0bOol00`00Oomoo`0[Ool00`00Oomoo`0ZOol00`00Oomoo`0YOol00`00Oomoo`0[Ool00`00Oomo
o`0ZOol00`00Oomoo`0[Ool00`00Oomoo`14Ool00`00Oomoo`0NOol50010Ool00`00Oomoo`3oOon5
Ool00`00Oomoo`07Ool003Yoo`03001oogoo0:Ioo`03001oogoo01=oo`@0031oo`03001oogoo039o
o`03001oogoo02]oo`03001oogoo02Yoo`03001oogoo02Uoo`03001oogoo02]oo`03001oogoo02Yo
o`03001oogoo02]oo`03001oogoo04Aoo`03001oogoo02=oo`D003]oo`03001oogoo0?moohEoo`03
001oogoo00Moo`00>Woo00<007ooOol0YWoo00<007ooOol03goo1000=7oo00<007ooOol0<Woo00<0
07ooOol0:goo00<007ooOol0:Woo00<007ooOol0:Goo00<007ooOol0:goo00<007ooOol0:Woo00<0
07ooOol0:goo00<007ooOol0A7oo00<007ooOol0:7oo1000=Woo00<007ooOol0ogooQWoo00<007oo
Ool01goo000jOol00`00Oomoo`2VOol00`00Oomoo`0:Ool5000hOol00`00Oomoo`0bOol00`00Oomo
o`0[Ool00`00Oomoo`0ZOol00`00Oomoo`0YOol00`00Oomoo`0[Ool00`00Oomoo`0ZOol00`00Oomo
o`0[Ool00`00Oomoo`14Ool00`00Oomoo`0/Ool6000`Ool00`00Oomoo`3oOon6Ool00`00Oomoo`07
Ool003Yoo`03001oogoo0:Ioo`03001oogoo00Eoo`D003eoo`03001oogoo039oo`03001oogoo02]o
o`03001oogoo02Yoo`03001oogoo00QoocL001Qoo`03001oogoo02Yoo`03001oogoo02]oo`03001o
ogoo04Aoo`03001oogoo039oo`L002Uoo`03001oogoo0?moohIoo`03001oogoo00Moo`00>Woo00<0
07ooOol0Ygoo00@007ooOomoo`<0049oo`03001oogoo039oo`03001oogoo02]oo`03001oogoo01Yo
oa/0025oo`03001oogoo01=ooa/002Yoo`03001oogoo02]oo`03001oogoo04Aoo`03001oogoo03Uo
o`D002Aoo`03001oogoo0?moohIoo`03001oogoo00Moo`00>Woo00<007ooOol0Ygoo1000AGoo00<0
07ooOol0<Woo00<007ooOol0:goo00<007ooOol037oo3P0047oo00<007ooOol0:Goo00<007ooOol0
:goo00<007ooOol06`003goo00<007ooOol0:goo00<007ooOol0A7oo00<007ooOol0?Woo100087oo
00<007ooOol0ogooQWoo00<007ooOol01goo000jOol00`00Oomoo`2UOol30018Ool00`00Oomoo`0b
Ool00`00Oomoo`0[Ool00`00Ool0000<000NOol00`00Oomoo`0YOol00`00Oomoo`0[Ool00`00Oomo
o`0KOol:0005Ool00`00Oomoo`0[Ool00`00Oomoo`14Ool00`00Oomoo`12Ool3000MOol00`00Oomo
o`3oOon6Ool00`00Oomoo`07Ool003Yoo`03001oogoo0:5oo`@0009oo`03001oogoo04Ioo`03001o
ogoo039oo`03001oogoo01moo`h002]oo`03001oogoo02Uoo`03001oogoo02]oo`03001oogoo02Eo
o`d002Ioo`03001oogoo04Aoo`03001oogoo04Eoo`H001Moo`03001oogoo0?moohIoo`03001oogoo
00Moo`00>Woo00<007ooOol0WWoo0`001Woo00<007ooOol0Agoo00<007ooOol0<Goo00<007ooOol0
4Woo3@0037oo00<007ooOol0:Woo00<007ooOol0:Goo00<007ooOol0:goo00<007ooOol0:Goo00<0
07ooOol01Woo1`007goo00<007ooOol0A7oo00<007ooOol0Bgoo0`004goo00<007ooOol0ogooQgoo
00<007ooOol01goo000jOol00`00Oomoo`2KOol3000:Ool00`00Oomoo`16Ool00`00Oomoo`0aOol0
0`00Oomoo`08Ool:000IOol00`00Oomoo`0ZOol00`00Oomoo`0YOol00`00Oomoo`0[Ool00`00Oomo
o`0YOol00`00Oomoo`0=Ool:000EOol00`00Oomoo`13Ool00`00Oomoo`1?Ool4000?Ool00`00Oomo
o`3oOon7Ool00`00Oomoo`07Ool003Yoo`03001oogoo09Qoo`<000eoo`03001oogoo04Ioo`03001o
ogoo035oo`04001oogooOol7000SOol00`00Oomoo`0ZOol00`00Oomoo`0YOol00`00Oomoo`0[Ool0
0`00Oomoo`0YOol00`00Oomoo`0GOol:000;Ool00`00Oomoo`13Ool00`00Oomoo`1COol3000<Ool0
0`00Oomoo`3oOon7Ool00`00Oomoo`07Ool003Yoo`03001oogoo09Eoo`<0011oo`03001oogoo04Io
o`03001oogoo02moo`H002Yoo`03001oogoo02Yoo`03001oogoo02Uoo`03001oogoo02Yoo`03001o
ogoo02Yoo`03001oogoo025oo`L000=oo`03001oogoo04Aoo`03001oogoo05Ioo`@000Qoo`03001o
ogoo0?moohMoo`03001oogoo00Moo`00>Woo00<007ooOol0TWoo0`004goo00<007ooOol0AWoo00<0
07ooOol0:7oo1`000goo00<007ooOol0:Woo00<007ooOol0:Woo00<007ooOol0:Goo00<007ooOol0
:Woo00<007ooOol0:Woo00<007ooOol0:7oo1`00@goo00<007ooOol0FWoo1@000goo00<007ooOol0
ogooQgoo00<007ooOol01goo000jOol00`00Oomoo`2@Ool2000FOol00`00Oomoo`16Ool00`00Oomo
o`0ROol6000:Ool00`00Oomoo`0ZOol00`00Oomoo`0ZOol00`00Oomoo`0YOol00`00Oomoo`0ZOol0
0`00Oomoo`0ZOol00`00Oomoo`0[Ool01000Oomoogoo1`00?7oo00<007ooOol0Ggoo1000ogooRGoo
00<007ooOol01goo000jOol00`00Oomoo`2>Ool2000IOol00`00Oomoo`15Ool00`00Oomoo`0MOol5
000@Ool00`00Oomoo`0ZOol00`00Oomoo`0ZOol00`00Oomoo`0YOol00`00Oomoo`0ZOol00`00Oomo
o`0ZOol00`00Oomoo`0[Ool00`00Oomoo`08Ool5000gOol00`00Oomoo`1QOol00`00Ool00003003o
Oon5Ool00`00Oomoo`07Ool003Yoo`03001oogoo08aoo`8001]oo`03001oogoo04Ioo`03001oogoo
01Qoo`@001Eoo`03001oogoo02]oo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo02Yoo`03
001oogoo02Yoo`03001oogoo02]oo`03001oogoo00eoo`D0039oo`03001oogoo065oo`03001oogoo
00=oo`<00?mooh9oo`03001oogoo00Moo`00>Woo00<007ooOol0RWoo0P007Goo00<007ooOol0AWoo
00<007ooOol057oo10006Goo00<007ooOol0:goo00<007ooOol0:Goo00<007ooOol0:Goo00<007oo
Ool0:Woo00<007ooOol0:Woo00<007ooOol0:goo00<007ooOol04Woo1000;Goo00<007ooOol0HWoo
00<007ooOol01Woo1000ogooOWoo00<007ooOol01goo000jOol00`00Oomoo`29Ool00`00Oomoo`0N
Ool00`00Oomoo`15Ool00`00Oomoo`0?Ool5000MOol00`00Oomoo`0[Ool00`00Oomoo`0YOol00`00
Oomoo`0YOol00`00Oomoo`0ZOol00`00Oomoo`0ZOol00`00Oomoo`0[Ool00`00Oomoo`0FOol4000Y
Ool00`00Oomoo`1ROol00`00Oomoo`0:Ool3003oOomkOol00`00Oomoo`07Ool003Yoo`03001oogoo
08Moo`80025oo`03001oogoo04Eoo`03001oogoo00Yoo`D0029oo`03001oogoo02]oo`03001oogoo
02Uoo`03001oogoo02Uoo`03001oogoo02Yoo`03001oogoo02Yoo`03001oogoo02]oo`03001oogoo
01Yoo`D002Aoo`03001oogoo069oo`03001oogoo00eoo`<00?moogQoo`03001oogoo00Moo`00>Woo
00<007ooOol0QGoo0P008goo00<007ooOol0AGoo00<007ooOol01Woo10009goo00<007ooOol0:goo
00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:Woo00<007ooOol0:Woo00<007ooOol0:Woo
00<007ooOol087oo1@007goo00<007ooOol0HGoo00<007ooOol04Goo0`00ogooMGoo00<007ooOol0
1goo000jOol00`00Oomoo`23Ool2000UOol00`00Oomoo`16Ool00`00Oomoo`05000[Ool00`00Oomo
o`0[Ool00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0ZOol00`00Oomoo`0ZOol00`00Oomo
o`0ZOol00`00Oomoo`0UOol4000KOol00`00Oomoo`1QOol00`00Oomoo`0DOol3003oOombOol00`00
Oomoo`07Ool003Yoo`03001oogoo081oo`<002Moo`03001oogoo04Eoo`@0035oo`03001oogoo02Yo
o`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo02Yoo`03001oogoo02Yoo`03001oogoo02Yo
o`03001oogoo02Uoo`D001Eoo`03001oogoo069oo`03001oogoo01Moo`800?moog1oo`03001oogoo
00Moo`00>Woo00<007ooOol0OWoo0P00:goo00<007ooOol0@7oo100000=oo`00Ool0<Woo00<007oo
Ool0:Woo00<007ooOol09WooDP002Woo00<007ooOol0:Goo00<007ooOol0:goo00<007ooOol0;Woo
10004Goo00<007ooOol0HWoo00<007ooOol06Goo0`00ogooKGoo00<007ooOol01goo000jOol5001j
Ool2000]Ool00`00Oomoo`0mOol30005Ool00`00Oomoo`0aOol00`00Oomoo`0ZOol00`00Oomoo`0F
Ool@0003Ool00`00Oomoo`0YOol00`00Oomoo`0POolC000SOol00`00Oomoo`0[Ool00`00Oomoo`0b
Ool5000<Ool00`00Oomoo`1ROol00`00Oomoo`0LOol4003oOomTOol60009Ool003Yoo`03001oogoo
07]oo`03001oogoo02eoo`03001oogoo03Yoo`<000Qoo`03001oogoo035oo`03001oogoo02Yoo`03
001oogoo00]oo`/001=oo`03001oogoo02Uoo`03001oogoo02Yoo`03001oogoo00Ioo`P001]oo`03
001oogoo02]oo`03001oogoo03Moo`<000Uoo`03001oogoo065oo`03001oogoo025oo`<00?moofIo
o`03001oogoo00Moo`00>Woo00<007ooOol0NGoo0P00<Goo00<007ooOol0=goo0P002goo00<007oo
Ool0<Goo00<007ooOol0:Woo00@007ooOomoo`X001ioo`03001oogoo02Uoo`03001oogoo02Yoo`03
001oogoo00ioo`h000eoo`03001oogoo02]oo`03001oogoo03Yoo`<000Ioo`03001oogoo065oo`03
001oogoo02Aoo`800?moofAoo`03001oogoo00Moo`00>Woo00<007ooOol0N7oo00<007ooOol0<Goo
00<007ooOol0=7oo0`003Woo00<007ooOol0<7oo00<007ooOol09goo1`00:7oo00<007ooOol0:Goo
00<007ooOol0:Woo00<007ooOol077oo2P000goo00<007ooOol0:goo00<007ooOol0?Goo0`000goo
00<007ooOol0HGoo00<007ooOol09Woo0P00ogooHWoo00<007ooOol01goo000jOol00`00Oomoo`1g
Ool00`00Oomoo`0bOol00`00Oomoo`0bOol2000AOol00`00Oomoo`0`Ool00`00Oomoo`0QOol60003
Ool00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0ZOol00`00Oomoo`0VOol7000ZOol00`00
Oomoo`10Ool3001TOol00`00Oomoo`0XOol3003oOomOOol00`00Oomoo`07Ool003Yoo`03001oogoo
07Eoo`8003Ioo`03001oogoo02ioo`<001=oo`03001oogoo031oo`03001oogoo01Yoo`L000Uoo`03
001oogoo02Uoo`03001oogoo02Uoo`03001oogoo02Yoo`03001oogoo02Uoo`04001oogooOol6000S
Ool00`00Oomoo`13Ool4001QOol00`00Oomoo`0[Ool2003oOomMOol00`00Oomoo`07Ool003Yoo`03
001oogoo07Aoo`03001oogoo03Ioo`03001oogoo02]oo`<001Ioo`03001oogoo035oo`03001oogoo
01=oo`H0015oo`03001oogoo02Qoo`03001oogoo02Uoo`03001oogoo02Yoo`03001oogoo02Uoo`03
001oogoo00Moo`L001aoo`03001oogoo04=oo`04001oogooOol3001MOol00`00Oomoo`0^Ool3003o
OomJOol00`00Oomoo`07Ool003Yoo`03001oogoo07=oo`03001oogoo03Moo`03001oogoo02Uoo`80
01Uoo`03001oogoo035oo`03001oogoo00aoo`L001Moo`03001oogoo02Qoo`03001oogoo02Uoo`03
001oogoo02Yoo`03001oogoo02Uoo`03001oogoo00ioo`D001Moo`03001oogoo04=oo`03001oogoo
00Aoo`8005]oo`03001oogoo035oo`<00?mooeMoo`03001oogoo00Moo`00>Woo00<007ooOol0LWoo
00<007ooOol0>Goo00<007ooOol09Goo0`0077oo00<007ooOol0<7oo00<007ooOol01Woo1P007Woo
00<007ooOol0:7oo00<007ooOol0:Goo00<007ooOol0:Woo00<007ooOol0:Goo00<007ooOol04goo
1@004Woo00<007ooOol0@goo00<007ooOol01Woo0`00F7oo00<007ooOol0=7oo0P00ogooEGoo00<0
07ooOol01goo000jOol00`00Oomoo`1aOol00`00Oomoo`0jOol00`00Oomoo`0SOol2000OOol00`00
Oomoo`0`Ool01000Oomoogoo1@0097oo00<007ooOol0:7oo00<007ooOol0:Goo00<007ooOol0:Woo
00<007ooOol0:Goo00<007ooOol067oo1@003Goo00<007ooOol0@Woo00<007ooOol02Woo0P00EGoo
00<007ooOol0=goo0`00ogooDWoo00<007ooOol01goo000jOol00`00Oomoo`1`Ool00`00Oomoo`0k
Ool00`00Oomoo`0POol3000QOol00`00Oomoo`0`Ool4000YOol00`00Oomoo`0YOol00`00Oomoo`0X
Ool00`00Oomoo`0ZOol00`00Oomoo`0YOol00`00Oomoo`0MOol40009Ool00`00Oomoo`12Ool00`00
Oomoo`0<Ool3001BOol00`00Oomoo`0jOol2003oOom@Ool00`00Oomoo`07Ool003Yoo`03001oogoo
06moo`03001oogoo03eoo`03001oogoo01eoo`8002Eoo`03001oogoo02]oo`D002aoo`03001oogoo
02Uoo`03001oogoo02Qoo`03001oogoo02Yoo`03001oogoo02Qoo`03001oogoo029oo`D000=oo`03
001oogoo04=oo`03001oogoo00moo`<004moo`03001oogoo03aoo`<00?moodeoo`03001oogoo00Mo
o`00>Woo00<007ooOol0KWoo00<007ooOol0?Woo00<007ooOol06goo0P009goo00<007ooOol09Woo
1@001Goo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:7oo00<007ooOol0:Woo00<007oo
Ool0:7oo00<007ooOol09goo1000A7oo00<007ooOol04goo0P00C7oo00<007ooOol0@7oo0P00ogoo
Bgoo00<007ooOol01goo000jOol00`00Oomoo`1]Ool00`00Oomoo`0oOol00`00Oomoo`0HOol3000Y
Ool00`00Oomoo`0QOol5000:Ool00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0XOol00`00
Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0ZOol50010Ool00`00Oomoo`0EOol30019Ool00`00
Oomoo`12Ool2003oOol]Ool2000JOol00`00Oomoo`07Ool003Yoo`03001oogoo06aoo`03001oogoo
045oo`03001oogoo01Eoo`8002aoo`03001oogoo01ioo`<000moo`03001oogoo02Uoo`03001oogoo
02Uoo`03001oogoo02Qoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo02Yoo`03001oogoo
009oo`D003]oo`03001oogoo01Qoo`8004Moo`03001oogoo04Aoo`<00?moob9oo`P001aoo`03001o
ogoo00Moo`00>Woo00<007ooOol0Jgoo00<007ooOol0@Woo00<007ooOol04goo0P00;Woo00<007oo
Ool06goo0`004Woo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:7oo00<007ooOol0:Goo
00<007ooOol0:Goo00<007ooOol0:Woo00<007ooOol01goo1@00=Woo00<007ooOol06Woo0`00@goo
00<007ooOol0B7oo0P00ogoo77oo100097oo00<007ooOol01goo000jOol00`00Oomoo`1ZOol00`00
Oomoo`14Ool00`00Oomoo`0@Ool2000aOol00`00Oomoo`0GOol3000EOol00`00Oomoo`0YOol00`00
Oomoo`0YOol00`00Oomoo`0XOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0ZOol00`00
Oomoo`0<Ool3000cOol00`00Oomoo`0MOol30010Ool00`00Oomoo`1:Ool00`00Oomoo`3oOolGOol2
000XOol00`00Oomoo`07Ool003Yoo`03001oogoo06Uoo`03001oogoo04Eoo`03001oogoo00ioo`80
03=oo`03001oogoo01=oo`@001Qoo`03001oogoo02Yoo`03001oogoo02Qoo`03001oogoo00Mood@0
00Uoo`03001oogoo02Uoo`03001oogoo02Yoo`03001oogoo00moo`<002moo`03001oogoo025oo`<0
03eoo`03001oogoo04]oo`800?mooaAoo`<002Yoo`03001oogoo00Moo`00>Woo00<007ooOol0JGoo
00<007ooOol0AGoo00<007ooOol037oo0P00=Goo00<007ooOol047oo0`0077oo00<007ooOol0:Woo
00<007ooOol097oo3P008Goo00<007ooOol087oo3P009goo00<007ooOol0:Goo00<007ooOol04goo
1000:goo00<007ooOol097oo0`00>Woo00<007ooOol0CGoo0P00ogoo47oo0P00;Goo00<007ooOol0
1goo000jOol00`00Oomoo`1YOol00`00Oomoo`16Ool00`00Oomoo`09Ool2000hOol00`00Oomoo`0<
Ool3000POol00`00Oomoo`0YOol00`00Oomoo`0GOol=0004Ool00`00Oomoo`0XOol00`00Oomoo`0Y
Ool00`00Oomoo`02Ool:000MOol00`00Oomoo`0YOol00`00Oomoo`0GOol3000XOol00`00Oomoo`0W
Ool2000hOol00`00Oomoo`1?Ool2003oOol;Ool3000_Ool00`00Oomoo`07Ool003Yoo`03001oogoo
06Qoo`03001oogoo04Moo`03001oogoo00Qoo`03001oogoo03Qoo`03001oogoo00Uoo`<002=oo`03
001oogoo02Uoo`03001oogoo00Uoo`h0015oo`03001oogoo02Qoo`03001oogoo02Uoo`03001oogoo
00aoo`L001Ioo`03001oogoo02Uoo`03001oogoo01Yoo`<002Aoo`03001oogoo02Yoo`8003Eoo`03
001oogoo059oo`800?moo`Qoo`03001oogoo031oo`03001oogoo00Moo`00>Woo00<007ooOol0Igoo
00<007ooOol0B7oo00<007ooOol01Woo0P00>goo00<007ooOol01Woo0`009Woo00<007ooOol0:Goo
00<007ooOol02@007goo00<007ooOol0:7oo00<007ooOol0:Goo00<007ooOol04goo1P003goo00<0
07ooOol0:Woo00<007ooOol07Goo0`008Goo00<007ooOol0;7oo0P00<goo00<007ooOol0E7oo0P00
ogoo17oo0P00<goo00<007ooOol01goo000jOol00`00Oomoo`1VOol00`00Oomoo`1:Ool00`00Oomo
o`03Ool2000mOol00`00Oomoo`03Ool3000YOol00`00Oomoo`0WOol5000XOol00`00Oomoo`0XOol0
0`00Oomoo`0YOol00`00Oomoo`0IOol70008Ool00`00Oomoo`0ZOol00`00Oomoo`0POol3000NOol0
0`00Oomoo`0^Ool2000aOol00`00Oomoo`1FOol2003oOol2000eOol00`00Oomoo`07Ool003Yoo`03
001oogoo06Ioo`03001oogoo04]oo`05001oogooOol0000oOol01000Oomoogoo0P00;7oo00<007oo
Ool08goo10000Woo00<007ooOol0:7oo00<007ooOol0:7oo00<007ooOol0:Goo00<007ooOol087oo
1`0000=oo`00Ool0:goo00<007ooOol08goo0`006goo00<007ooOol0<7oo00<007ooOol0;Goo00<0
07ooOol0FGoo0P00o7oo00<007ooOol0=Goo00<007ooOol01goo000jOol00`00Oomoo`1UOol00`00
Oomoo`1<Ool01000Ool00000@Goo0`00;Woo00<007ooOol07Woo1@001Woo00<007ooOol0:7oo00<0
07ooOol0:7oo00<007ooOol0:Goo00<007ooOol09goo1`009Woo00<007ooOol09goo0`0067oo00<0
07ooOol0<Goo0P00;Goo00<007ooOol0Fgoo0P00n7oo0P00>7oo00<007ooOol01goo000jOol00`00
Oomoo`1TOol00`00Oomoo`1=Ool20012Ool2000aOol00`00Oomoo`0FOol7000;Ool00`00Oomoo`0X
Ool00`00Oomoo`0XOol00`00Oomoo`0YOol00`00Oomoo`0XOol00`00Oomoo`03Ool5000QOol00`00
Oomoo`0ZOol2000EOol00`00Oomoo`0dOol2000[Ool00`00Oomoo`1MOol00`00Oomoo`3cOol2000j
Ool00`00Oomoo`07Ool003Yoo`03001oogoo06=oo`03001oogoo04ioo`8003moo`<00003Ool007oo
031oo`03001oogoo015oo`D0019oo`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo02Uoo`03
001oogoo02Qoo`03001oogoo00Qoo`D001aoo`03001oogoo02aoo`8001=oo`03001oogoo03Ioo`80
02Qoo`03001oogoo05moo`800?9oo`03001oogoo03Yoo`03001oogoo00Moo`00>Woo00<007ooOol0
Hgoo00<007ooOol0C7oo0P0000=oo`00Ool0?7oo0P001Goo00<007ooOol0;Woo00<007ooOol037oo
1@0067oo00<007ooOol09goo00<007ooOol0:7oo00<007ooOol0:Goo00<007ooOol0:7oo00<007oo
Ool03Goo100067oo00<007ooOol0;Woo0P004Goo00<007ooOol0>7oo0P009Goo00<007ooOol0HWoo
0P00kWoo0P00?Goo00<007ooOol01goo000jOol00`00Oomoo`1ROol00`00Oomoo`1<Ool00`00Oomo
o`02Ool00`00Oomoo`0hOol20007Ool00`00Oomoo`0^Ool00`00Oomoo`07Ool5000MOol00`00Oomo
o`0WOol00`00Oomoo`0XOol00`00Oomoo`0YOol00`00Oomoo`0XOol00`00Oomoo`0AOol4000DOol0
0`00Oomoo`0`Ool3000=Ool00`00Oomoo`0kOol00`00Oomoo`0ROol00`00Oomoo`1TOol2003[Ool0
0`00Oomoo`0mOol00`00Oomoo`07Ool003Yoo`03001oogoo065oo`03001oogoo04]oo`8000Eoo`03
001oogoo03Ioo`8000Uoo`03001oogoo02ioo`03001oogoo00=oo`@0029oo`03001oogoo02Moo`03
001oogoo02Qoo`03001oogoo02Uoo`03001oogoo02Moo`03001oogoo01Ioo`<0011oo`03001oogoo
03Aoo`8000]oo`03001oogoo03aoo`80029oo`03001oogoo06Ioo`03001oogoo0>Moo`03001oogoo
03ioo`03001oogoo00Moo`00>Woo00<007ooOol0H7oo00<007ooOol0Bgoo00<007ooOol01Goo00<0
07ooOol0=7oo0P0037oo00<007ooOol0;Woo00<007oo00000P009Woo00<007ooOol09goo00<007oo
Ool0:7oo00<007ooOol0:7oo00<007ooOol0:7oo00<007ooOol06Goo100037oo00<007ooOol0=Woo
0P002Goo00<007ooOol0?Woo0P007goo00<007ooOol0J7oo0P00iGoo0P00@Goo00<007ooOol01goo
000jOol00`00Oomoo`1POol00`00Oomoo`1:Ool00`00Oomoo`07Ool00`00Oomoo`0aOol2000>Ool0
0`00Oomoo`0]Ool3000YOol00`00Oomoo`0XOol00`00Oomoo`0WOol00`00Oomoo`0XOol00`00Oomo
o`0XOol00`00Oomoo`0MOol30009Ool00`00Oomoo`0hOol20006Ool00`00Oomoo`11Ool2000MOol0
0`00Oomoo`1ZOol2003QOol20013Ool00`00Oomoo`07Ool003Yoo`03001oogoo05moo`03001oogoo
04Uoo`8000Yoo`03001oogoo031oo`03001oogoo00ioo`03001oogoo02Yoo`<00003Ool007oo02Uo
o`03001oogoo02Qoo`03001oogoo02Moo`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo021o
o`@000Eoo`03001oogoo03Yoo`8000Aoo`03001oogoo04=oo`03001oogoo01Yoo`03001oogoo06ao
o`03001oogoo0=eoo`03001oogoo04=oo`03001oogoo00Moo`00>Woo00<007ooOol0GWoo00<007oo
Ool0BGoo00<007ooOol02Woo00<007ooOol0;Woo0P004Goo00<007ooOol09goo0`0017oo00<007oo
Ool0:7oo00<007ooOol0:7oo00<007ooOol09goo00<007ooOol0:7oo00<007ooOol0:7oo00<007oo
Ool097oo0`000Woo00<007ooOol0?7oo00D007ooOomoo`0004Ioo`8001Uoo`03001oogoo06ioo`03
001oogoo0=]oo`03001oogoo04Aoo`03001oogoo00Moo`00>Woo1@00Fgoo00<007ooOol0B7oo0P00
3Woo00D007ooOomoo`0002Uoo`8001Aoo`03001oogoo02Aoo`8000Moo`03001oogoo02Qoo`03001o
ogoo02Qoo`03001oogoo025oo`h002=oo`03001oogoo02Qoo`03001oogoo02Moo`@003ioo`<004Uo
o`8001Moo`03001oogoo06moo`800=Yoo`03001oogoo041oo`H000Uoo`00>Woo00<007ooOol0GGoo
00<007ooOol0Agoo00<007ooOol03goo00@007ooOol002Moo`8001Ioo`03001oogoo025oo`<000Yo
o`03001oogoo02Moo`03001oogoo02Qoo`03001oogoo00Iooa/000Ioo`03001oogoo00Eooa/000Qo
o`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo00<003eoo`8004Yoo`03001oogoo01Aoo`03
001oogoo075oo`03001oogoo0=Ioo`03001oogoo04Ioo`03001oogoo00Moo`00>Woo00<007ooOol0
G7oo00<007ooOol0Agoo00<007ooOol04Goo00<007oo00009Woo00<007ooOol05Woo00<007ooOol0
7Woo0`003Goo00<007ooOol09goo00<007ooOol08goo3P008Goo00<007ooOol087oo2P00:Goo00<0
07ooOol0:7oo00<007ooOol00goo0P00>goo00<007oo00000P00B7oo0P004goo00<007ooOol0Lgoo
0P00e7oo0P00BGoo00<007ooOol01goo000jOol00`00Oomoo`1KOol00`00Oomoo`17Ool00`00Oomo
o`0>Ool20002Ool01000Ool000008goo0P006Woo00<007oo00006Woo0`0047oo00<007ooOol0:7oo
00<007ooOol05Goo3@001Goo00<007ooOol09goo00<007ooOol0:7oo00<007oo00001P008Goo00<0
07ooOol0:Goo00<007ooOol01Goo0`00=goo00<007ooOol00goo0P00B7oo0P003Goo00D007ooOomo
o`0007Moo`03001oogoo0=1oo`03001oogoo04Uoo`03001oogoo00Moo`00>Woo00<007ooOol0Fgoo
00<007ooOol0AWoo00<007ooOol047oo0P0000=oo`00Ool00P008Woo00<007ooOol06Woo00<007oo
00005goo0`004goo00<007ooOol0:7oo00<007ooOol02goo2P004Woo00<007ooOol09goo00<007oo
Ool0:7oo00<007ooOol01Woo1`006Woo00<007ooOol0:Goo00<007ooOol027oo0`00=7oo00<007oo
Ool01Goo0P00B7oo00<007ooOol02Woo00@007ooOol007Uoo`800<ioo`8004aoo`03001oogoo00Mo
o`00>Woo00<007ooOol0FWoo00<007ooOol0AWoo00<007ooOol04Woo1P0087oo0P006Woo0P0000Ao
o`00Ool001Eoo`8001Ioo`04001oogoo000WOol00`00Oomoo`04Ool7000LOol00`00Oomoo`0WOol0
0`00Oomoo`0XOol00`00Oomoo`0=Ool7000COol00`00Oomoo`0VOol00`00Ool0000>Ool3000^Ool0
1000Oomoo`002Goo00<007ooOol0AWoo0P002Woo00@007ooOol007]oo`03001oogoo0<Yoo`03001o
ogoo04aoo`03001oogoo00Moo`00>Woo00<007ooOol0FWoo00<007ooOol0AGoo00<007ooOol057oo
1@007Woo0P0077oo0`0000=oo`0000004goo0P005Goo00L007ooOomoo`00Ool0000WOol7000SOol0
0`00Oomoo`0WOol00`00Oomoo`0XOol00`00Oomoo`0DOol6000:Ool01000Oomoo`00:7oo00<007oo
00004Goo0`00:goo00<007oo00002goo0P00B7oo0P0027oo00D007ooOol007oo008007Uoo`800<Uo
o`03001oogoo04eoo`03001oogoo00Moo`00>Woo00<007ooOol0FGoo00<007ooOol0AGoo00<007oo
Ool05Woo1@0077oo00<007ooOol07Goo1P003goo0`005goo0P000Woo00<007oo00008goo1@000Woo
00<007ooOol08Goo00@007ooOol0009oo`03001oogoo02Aoo`03001oogoo02Eoo`04001oogoo0002
Ool00`00Oomoo`0GOol70003Ool01000Oomoo`000Woo00<007ooOol08goo00<007oo00000Woo00<0
07ooOol03goo0P00:Goo00@007oo001oo`8000Yoo`8004Qoo`03001oogoo00Aoo`@00004Ool00000
001kOol00`00Oomoo`35Ool00`00Oomoo`1>Ool00`00Oomoo`07Ool003Yoo`03001oogoo05Uoo`03
001oogoo04Aoo`03001oogoo01Qoo`@001Yoo`80025oo`D000eoo`8001]oo`800004Ool007oo000O
Ool400001Goo001oogoo00000Woo00<007ooOol08Goo00@007ooOol0009oo`03001oogoo025oo`04
001oogoo0002Ool00`00Oomoo`0ROol01000Oomoo`000Woo00<007ooOol07Woo1@0000Eoo`00Oomo
o`0002Eoo`03001oo`00009oo`03001oogoo015oo`8002Moo`03001oo`0000<000aoo`03001oogoo
04Ioo`8000Aoo`<00004Ool00000001mOol20033Ool2001AOol00`00Oomoo`07Ool003Yoo`03001o
ogoo05Qoo`03001oogoo04Aoo`03001oogoo01Yoo`<001Qoo`8002=oo`D000]oo`8001eoo`H001]o
o`@000Eoo`04001oogoo0002Ool00`00Oomoo`0ROol01000Ool007oo0P008goo00@007ooOol0009o
o`03001oogoo029oo`800004Ool007oo000TOol7000UOol300000goo001oo`0EOol2000TOol6000>
Ool20018Ool01000Oomoogoo1P00P7oo00<007ooOol0_goo00<007ooOol0DGoo00<007ooOol01goo
000jOol00`00Oomoo`1HOol00`00Oomoo`13Ool00`00Oomoo`0LOol2000GOol00`00Oomoo`0TOol4
0009Ool2000POol5000FOol5000:Ool01000Ool007oo0P0097oo00@007oo001oo`8002=oo`800003
Ool007oo008002Aoo`800004Ool00000000TOol200001Goo00000000Ool01@0087oo0P0000=oo`00
Ool067oo0`008Goo1@004Goo0P00Agoo0P0000=oo`0000000`00PWoo00<007ooOol0_Goo00<007oo
Ool0DWoo00<007ooOol01goo000jOol00`00Oomoo`1HOol00`00Oomoo`12Ool00`00Oomoo`0NOol2
000DOol2000XOol30007Ool2000ROol5000BOol4000?Ool2000017oo0000000097oo1@009Goo00D0
07oo001oo`0002Ioo`800003Ool0000002Aoo`D000Moo`@001aoo`@001aoo`8001moo`D001=oo`03
001oogoo04Ioo`D008Aoo`800;aoo`03001oogoo05=oo`03001oogoo00Moo`00>Woo00<007ooOol0
Egoo00<007ooOol0@Woo00<007ooOol087oo00<007ooOol04Goo00<007ooOol0:Goo0P001Goo0P00
9Goo10003Woo10004goo0P0000Aoo`00000002Eoo`@002Eoo`D002Ioo`@002Eoo`D000]oo`<001Qo
o`@001moo`8001eoo`@001Eoo`8004Moo`<008Moo`03001oogoo0;Qoo`03001oogoo05Aoo`03001o
ogoo00Moo`00>Woo00<007ooOol0Egoo00<007ooOol0@Goo00<007ooOol08Goo00<007ooOol03goo
0P00;7oo0`0000Aoo`00000002Qoo`<000]oo`<001Qoo`D002Eoo`@002Eoo`D002Ioo`@002Ioo`<0
00moo`<001Eoo`@0025oo`8001]oo`<001Qoo`8004Aoo`@008Qoo`800;Moo`03001oogoo05Eoo`03
001oogoo00Moo`00>Woo00<007ooOol0EWoo00<007ooOol0@Goo00<007ooOol08Woo00<007ooOol0
3Woo00<007ooOol0;Goo0`00:goo0`001goo10006goo10009Woo10009Goo1@009Woo10009Woo0`00
4Woo0`004Woo0`0097oo0`0067oo0P006goo00<007ooOol0@Goo0P000Woo0P00R7oo00<007ooOol0
[Woo00<007ooOol00Woo00<007ooOol0EWoo00<007ooOol01goo000jOol00`00Oomoo`1FOol00`00
Oomoo`10Ool00`00Oomoo`0TOol00`00Oomoo`0<Ool00`00Oomoo`0]Ool3000]Ool20004Ool3000P
Ool3000WOol3000VOol3000WOol3000WOol3000EOol5000=Ool2000XOol2000EOol3000LOol20011
Ool00`00Oomoo`03Ool00`00Oomoo`26Ool00`00Oomoo`2]Ool01@00Oomoogoo0000FGoo00<007oo
Ool01goo000jOol00`00Oomoo`1EOol00`00Oomoo`10Ool00`00Oomoo`0VOol00`00Oomoo`09Ool2
000_Ool01000Oomoo`00;Goo1P008goo0`009goo0`009Woo0`009goo0`009goo0P006goo10002Goo
0P00:Woo0P004goo0P007goo0P00?goo00<007ooOol017oo00<007ooOol0QWoo0P00[7oo00D007oo
Oomoo`0005Yoo`03001oogoo00Moo`00>Woo00<007ooOol0EGoo00<007ooOol0@7oo00<007ooOol0
9Woo00<007ooOol027oo00<007ooOol0;Goo0P000goo00<007ooOol0:Woo0`00:7oo0P009goo0P00
9goo0`00:7oo0P009goo0P007goo0`001Woo00<007ooOol0:goo0P004Goo00<007ooOol087oo00<0
07ooOol0>goo00<007ooOol01Woo00<007ooOol0Qgoo00<007ooOol0Z7oo0P0000=oo`000000Fgoo
00<007ooOol01goo000jOol00`00Oomoo`1DOol00`00Oomoo`10Ool00`00Oomoo`0XOol00`00Oomo
o`06Ool00`00Oomoo`0]Ool00`00Oomoo`04Ool00`00Oomoo`0WOol20002Ool00`00Oomoo`0VOol2
000XOol00`00Oomoo`05Oolg000DOol00`00Oomoo`0VOol00`00Oomoo`0QOol30003Ool00`00Oomo
o`0]Ool00`00Oomoo`0>Ool00`00Oomoo`0QOol00`00Oomoo`0jOol00`00Oomoo`07Ool20028Ool0
0`00Oomoo`2WOol00`00Ool0001MOol00`00Oomoo`07Ool003Yoo`03001oogoo05Aoo`03001oogoo
03moo`03001oogoo02Yoo`03001oogoo00Aoo`03001oogoo02aoo`8000Moo`03001oogoo02Eoo`80
00Aoo`03001oogoo02Ioo`80029oo`h0025oo`03001oogoo01=oo`d000Moo`03001oogoo02Ioo`03
001oogoo02Aoo`800003Ool007oo02moo`8000ioo`03001oogoo029oo`03001oogoo03Uoo`03001o
ogoo00Uoo`03001oogoo08Ioo`03001oogoo0:Eoo`<00003Ool00000008005Uoo`03001oogoo00Mo
o`00>Woo00<007ooOol0E7oo00<007ooOol0?Woo00<007ooOol0:goo00<007ooOol00goo00<007oo
Ool0;7oo00<007ooOol01goo00<007ooOol08Woo0`001goo00<007ooOol09Woo00<007ooOol05Woo
2P001Woo00<007ooOol09Woo00<007ooOol087oo2P009Woo00<007ooOol09Woo0P00<Woo0P002goo
00<007ooOol097oo00<007ooOol0=goo00<007ooOol02goo00<007ooOol0QWoo00<007ooOol0Xgoo
1`00Fgoo00<007ooOol01goo000jOol00`00Oomoo`1COol00`00Oomoo`0nOol00`00Oomoo`0/Ool0
0`00Oomoo`02Ool00`00Oomoo`0[Ool2000;Ool00`00Oomoo`0OOol2000:Ool00`00Oomoo`0VOol0
0`00Oomoo`0?Ool7000@Ool00`00Oomoo`0VOol00`00Oomoo`0WOol00`00Oomoo`07000OOol00`00
Oomoo`0VOol01000Ool00000<Woo00<007ooOol01goo00<007ooOol09Woo0P00=Woo00<007ooOol0
3Goo00<007ooOol0QWoo0P00XWoo1P00GGoo00<007ooOol01goo000jOol00`00Oomoo`1COol00`00
Oomoo`0mOol00`00Oomoo`0^Ool01000Oomoo`00;Goo00<007ooOol037oo00<007ooOol06goo0`00
37oo00<007ooOol09Woo00<007ooOol02Woo1@005goo00<007ooOol09Woo00<007ooOol09goo00<0
07ooOol01goo1`0067oo00<007ooOol09Woo00@007ooOomoo`<0031oo`8000Moo`03001oogoo02Qo
o`03001oogoo039oo`03001oogoo00moo`03001oogoo08Moo`03001oogoo09moo`<0061oo`03001o
ogoo00Moo`00>Woo00<007ooOol0Dgoo00<007ooOol0?7oo00<007ooOol0<7oo0P00;Goo00<007oo
Ool03Goo00<007ooOol06Goo0P003goo00<007ooOol09Woo00<007ooOol01Goo1@0077oo00<007oo
Ool09Woo00<007ooOol09goo00<007ooOol03Woo1`0047oo00<007ooOol09goo00<007ooOol017oo
0P00<7oo00<007ooOol017oo00<007ooOol0:Goo0P00<Woo00<007ooOol047oo0P00R7oo00<007oo
Ool0WGoo0P00HWoo00<007ooOol01goo000jOol00`00Oomoo`1BOol00`00Oomoo`0lOol00`00Oomo
o`0aOol2000[Ool2000@Ool00`00Oomoo`0GOol2000BOol00`00Oomoo`0UOol00`00Oomoo`05000Q
Ool00`00Oomoo`0VOol00`00Oomoo`0VOol00`00Oomoo`0FOol5000;Ool00`00Oomoo`0WOol00`00
Oomoo`06Ool2000_Ool20003Ool00`00Oomoo`0/Ool00`00Oomoo`0_Ool00`00Oomoo`0BOol00`00
Oomoo`26Ool00`00Oomoo`2KOol00`00Oomoo`1ROol00`00Oomoo`07Ool003Yoo`03001oogoo059o
o`03001oogoo03aoo`03001oogoo031oo`03001oo`0002Yoo`03001oogoo015oo`03001oogoo01=o
o`<001Aoo`03001oogoo02Aoo`@002Ioo`03001oogoo02Ioo`03001oogoo02Ioo`03001oogoo01]o
o`D000Ioo`03001oogoo02Ioo`03001oogoo00Uoo`8002moo`04001oogoo000_Ool00`00Oomoo`0]
Ool00`00Oomoo`0DOol00`00Oomoo`26Ool00`00Oomoo`2IOol00`00Oomoo`1SOol00`00Oomoo`07
Ool003Yoo`03001oogoo059oo`03001oogoo03]oo`03001oogoo031oo`04001oogoo000XOol2000D
Ool00`00Oomoo`0AOol2000GOol00`00Oomoo`0OOol50002Ool00`00Oomoo`0UOol00`00Oomoo`0V
Ool00`00Oomoo`0VOol00`00Oomoo`0POol40002Ool00`00Oomoo`0VOol00`00Oomoo`0;Ool3000]
Ool2000aOol2000]Ool00`00Oomoo`0EOol00`00Oomoo`26Ool00`00Oomoo`2FOol2001VOol00`00
Oomoo`07Ool003Yoo`03001oogoo055oo`03001oogoo03]oo`03001oogoo031oo`03001oogoo009o
o`03001oogoo02Aoo`03001oogoo01Aoo`03001oogoo00moo`8001Uoo`03001oogoo01]oo`@000Mo
o`03001oogoo02Eoo`03001oogoo02Ioo`03001oogoo02Ioo`03001oogoo02Aoo`@002Moo`03001o
ogoo00ioo`8002aoo`80039oo`03001oogoo02Uoo`03001oogoo01Moo`03001oogoo08Ioo`03001o
ogoo09Aoo`03001oogoo06Ioo`03001oogoo00Moo`00>Woo00<007ooOol0DGoo00<007ooOol0>goo
00<007ooOol0;goo00<007ooOol017oo00<007ooOol08Goo0P0067oo00<007ooOol037oo0P0077oo
00<007ooOol05Woo10002goo00<007ooOol09Goo00<007ooOol09Woo00<007ooOol09Woo00<007oo
Ool09Woo00<007oo000010008Woo00<007ooOol047oo0P00:Woo00<007oo0000<Woo0P00:7oo00<0
07ooOol06Goo00<007ooOol0QWoo00<007ooOol0TWoo00<007ooOol0Igoo00<007ooOol01goo000j
Ool00`00Oomoo`1AOol00`00Oomoo`0jOol00`00Oomoo`0_Ool00`00Oomoo`05Ool00`00Oomoo`0P
Ool00`00Oomoo`0HOol00`00Oomoo`0:Ool2000NOol00`00Oomoo`0AOol5000?Ool00`00Oomoo`0U
Ool00`00Oomoo`0VOol00`00Oomoo`0VOol00`00Oomoo`0UOol00`00Oomoo`05Ool5000LOol00`00
Oomoo`0COol3000VOol01000Oomoogoo0P00<Woo00<007ooOol09Goo00<007ooOol06Woo0P00Qgoo
00<007ooOol0T7oo00<007ooOol0J7oo00<007ooOol01goo000jOol00`00Oomoo`1@Ool00`00Oomo
o`0jOol00`00Oomoo`0_Ool00`00Oomoo`07Ool00`00Oomoo`0NOol00`00Oomoo`0JOol00`00Oomo
o`08Ool00`00Oomoo`0NOol00`00Oomoo`0=Ool4000DOol00`00Oomoo`0VOol00`00Oomoo`0UOol0
0`00Oomoo`0VOol00`00Oomoo`0UOol00`00Oomoo`0:Ool4000HOol00`00Oomoo`0FOol2000SOol0
0`00Oomoo`04Ool00`00Oomoo`0`Ool00`00Oomoo`0TOol00`00Oomoo`0LOol00`00Oomoo`25Ool0
0`00Oomoo`2>Ool00`00Oomoo`1YOol00`00Oomoo`07Ool003Yoo`03001oogoo051oo`03001oogoo
03Yoo`03001oogoo02ioo`03001oogoo00Uoo`03001oogoo01]oo`8001eoo`03001oogoo00Ioo`80
025oo`03001oogoo00Yoo`<001Qoo`03001oogoo02Ioo`03001oogoo02Eoo`03001oogoo02Ioo`03
001oogoo02Eoo`03001oogoo00ioo`<001Eoo`03001oogoo01Qoo`80025oo`03001oogoo00Eoo`80
035oo`03001oogoo029oo`03001oogoo01ioo`03001oogoo08Eoo`03001oogoo08aoo`03001oogoo
06Yoo`03001oogoo00Moo`00>Woo00<007ooOol0D7oo00<007ooOol0>Goo00<007ooOol0;Woo00<0
07ooOol02goo00<007ooOol06Goo00<007ooOol07Goo00<007ooOol017oo0P0097oo00<007ooOol0
1Woo0`006goo00<007ooOol09Woo00<007ooOol09Goo00<007ooOol09Woo00<007ooOol09Goo00<0
07ooOol04Goo0`004Goo00<007ooOol06goo00<007ooOol07Woo00<007ooOol01goo00<007ooOol0
;goo00<007ooOol087oo00<007ooOol087oo00<007ooOol0QGoo00<007ooOol0RWoo00<007ooOol0
Jgoo00<007ooOol01goo000jOol5001=Ool00`00Oomoo`0iOol00`00Oomoo`0^Ool00`00Oomoo`0<
Ool00`00Oomoo`0GOol2000QOol00`00Oomoo`02Ool00`00Oomoo`0TOol00`00Oomoo`04Ool2000O
Ool00`00Oomoo`0UOol00`00Oomoo`0UOol00`00Oomoo`0VOol00`00Oomoo`0UOol00`00Oomoo`0D
Ool3000>Ool00`00Oomoo`0LOol2000MOol00`00Oomoo`09Ool2000`Ool00`00Oomoo`0NOol00`00
Oomoo`0ROol00`00Oomoo`25Ool00`00Oomoo`28Ool00`00Oomoo`1WOol60009Ool003Yoo`03001o
ogoo04moo`03001oogoo03Uoo`03001oogoo02ioo`03001oogoo00aoo`03001oogoo01Ioo`03001o
ogoo025oo`05001oogooOol0000WOol01000Oomoogoo0`008Goo00<007ooOol09Goo00<007ooOol0
9Goo00<007ooOol09Woo00<007ooOol09Goo00<007ooOol05goo0`002goo00<007ooOol07Woo0P00
6Woo00<007ooOol037oo00<007ooOol0;Woo00<007ooOol07Goo00<007ooOol08goo00<007ooOol0
QGoo00<007ooOol0QWoo00<007ooOol0KGoo00<007ooOol01goo000jOol00`00Oomoo`1>Ool00`00
Oomoo`0iOol00`00Oomoo`0^Ool00`00Oomoo`0>Ool00`00Oomoo`0DOol00`00Oomoo`0ROol01000
Ool00000:7oo100097oo00<007ooOol09Goo00<007ooOol017oo=`004goo00<007ooOol09Goo00<0
07ooOol06Woo0`0027oo00<007ooOol087oo00<007ooOol05goo00<007ooOol03Goo00<007ooOol0
;Woo00<007ooOol06goo00<007ooOol09Goo00<007ooOol0QGoo00<007ooOol0Q7oo00<007ooOol0
KWoo00<007ooOol01goo000jOol00`00Oomoo`1>Ool00`00Oomoo`0iOol00`00Oomoo`0]Ool00`00
Oomoo`0@Ool00`00Oomoo`0BOol00`00Oomoo`0TOol00`00Oomoo`0VOol4000VOol00`00Oomoo`0R
Ool:000QOol00`00Oomoo`0COol=0006Ool00`00Oomoo`0TOol00`00Oomoo`0NOol20005Ool00`00
Oomoo`0ROol2000GOol00`00Oomoo`0>Ool2000_Ool00`00Oomoo`0JOol00`00Oomoo`0VOol00`00
Oomoo`25Ool00`00Oomoo`21Ool2001aOol00`00Oomoo`07Ool003Yoo`03001oogoo04ioo`03001o
ogoo03Qoo`03001oogoo02ioo`03001oogoo011oo`03001oogoo019oo`03001oogoo029oo`800003
Ool007oo02Aoo`8000=oo`03001oogoo02Aoo`03001oogoo01]oo`L000=oo`03001oogoo02Eoo`03
001oogoo021oo`X002=oo`03001oogoo021oo`8000=oo`03001oogoo02Aoo`8001Aoo`03001oogoo
015oo`03001oogoo02eoo`03001oogoo01Qoo`03001oogoo02Qoo`03001oogoo08Eoo`03001oogoo
07moo`03001oogoo075oo`03001oogoo00Moo`00>Woo00<007ooOol0CWoo00<007ooOol0=goo00<0
07ooOol0;Woo00<007ooOol04Woo00<007ooOol047oo00<007ooOol08Woo00D007ooOomoo`0002=o
o`8000Eoo`03001oogoo02Aoo`03001oogoo01Aoo`L000Yoo`03001oogoo02Eoo`03001oogoo02Eo
o`03001oogoo009oo`L001aoo`03001oogoo029oo`@002Qoo`03001oogoo015oo`03001oogoo019o
o`03001oogoo02eoo`03001oogoo01Moo`03001oogoo02Uoo`03001oogoo08Eoo`03001oogoo07eo
o`03001oogoo079oo`03001oogoo00Moo`00>Woo00<007ooOol0CGoo00<007ooOol0>7oo00<007oo
Ool0;Goo00<007ooOol057oo00<007ooOol03Woo00<007ooOol08Goo0P0017oo00<007ooOol07Woo
0`001goo00<007ooOol097oo00<007ooOol03Goo1`004Goo00<007ooOol09Goo00<007ooOol09Goo
00<007ooOol02Goo1`005Goo00<007ooOol09Goo0P00:7oo0P0047oo00<007ooOol057oo00<007oo
Ool0;Goo00<007ooOol05Goo00<007ooOol0:goo00<007ooOol0QGoo00<007ooOol0Ngoo00<007oo
Ool0Lgoo00<007ooOol01goo000jOol00`00Oomoo`1=Ool00`00Oomoo`0gOol00`00Oomoo`0]Ool0
0`00Oomoo`0FOol00`00Oomoo`0<Ool00`00Oomoo`0POol20007Ool00`00Oomoo`0KOol2000;Ool0
0`00Oomoo`0SOol00`00Oomoo`07Ool6000HOol00`00Oomoo`0UOol00`00Oomoo`0UOol00`00Oomo
o`0@Ool7000>Ool00`00Oomoo`0TOol00`00Oomoo`02000XOol00`00Oomoo`0=Ool00`00Oomoo`0E
Ool00`00Oomoo`0]Ool00`00Oomoo`0COol00`00Oomoo`0]Ool00`00Oomoo`25Ool00`00Oomoo`1i
Ool00`00Oomoo`1dOol00`00Oomoo`07Ool003Yoo`03001oogoo04eoo`03001oogoo03Moo`03001o
ogoo02aoo`03001oogoo01Qoo`03001oogoo00Yoo`03001oogoo021oo`03001oogoo00Moo`03001o
ogoo01Uoo`8000eoo`03001oogoo02Aoo`03001oo`0000H001ioo`03001oogoo02Eoo`03001oogoo
02Eoo`03001oogoo01Moo`D000Uoo`03001oogoo02Aoo`03001oogoo009oo`8002Moo`8000aoo`03
001oogoo01Moo`03001oogoo02eoo`03001oogoo015oo`03001oogoo02moo`03001oogoo08Eoo`03
001oogoo07Moo`03001oogoo07Eoo`03001oogoo00Moo`00>Woo00<007ooOol0CGoo00<007ooOol0
=Woo00<007ooOol0;Goo00<007ooOol067oo00<007ooOol02Goo00<007ooOol07goo0P002Woo00<0
07ooOol05goo0P003goo00<007ooOol087oo1P009Goo00<007ooOol09Goo00<007ooOol09Goo00<0
07ooOol077oo0`001Woo00<007ooOol097oo00<007ooOol017oo0P009goo00<007ooOol02Goo00<0
07ooOol067oo00<007ooOol0;Goo00<007ooOol047oo00<007ooOol0<7oo00<007ooOol0Q7oo00<0
07ooOol0MWoo00<007ooOol0MWoo00<007ooOol01goo000jOol00`00Oomoo`1=Ool00`00Oomoo`0e
Ool00`00Oomoo`0]Ool00`00Oomoo`0JOol00`00Oomoo`07Ool00`00Oomoo`0OOol00`00Oomoo`0;
Ool00`00Oomoo`0DOol2000AOol00`00Oomoo`0MOol30004Ool00`00Oomoo`0TOol00`00Oomoo`0U
Ool00`00Oomoo`0UOol00`00Oomoo`0OOol30002Ool00`00Oomoo`0TOol00`00Oomoo`07Ool2000V
Ool00`00Oomoo`07Ool00`00Oomoo`0JOol00`00Oomoo`0]Ool00`00Oomoo`0>Ool00`00Oomoo`0a
Ool00`00Oomoo`25Ool00`00Oomoo`1dOol00`00Oomoo`1gOol00`00Oomoo`07Ool003Yoo`03001o
ogoo04aoo`03001oogoo03Ioo`03001oogoo02aoo`03001oogoo01]oo`03001oogoo00Ioo`03001o
ogoo01ioo`8000ioo`03001oogoo019oo`8001Aoo`03001oogoo01Uoo`<000Moo`03001oogoo02Ao
o`03001oogoo02Eoo`03001oogoo02Eoo`03001oogoo029oo`<002Ioo`03001oogoo00Uoo`03001o
ogoo02Aoo`8000Moo`03001oogoo01]oo`03001oogoo02eoo`03001oogoo00aoo`03001oogoo03=o
o`03001oogoo08Eoo`03001oogoo075oo`8007Yoo`03001oogoo00Moo`00>Woo00<007ooOol0C7oo
00<007ooOol0=Goo00<007ooOol0;7oo00<007ooOol07Goo00<007ooOol017oo00<007ooOol07Woo
00<007ooOol03goo00<007ooOol03goo0P005Woo00<007ooOol05Woo0`002Woo00<007ooOol097oo
00<007ooOol09Goo00<007ooOol09Goo00<007ooOol097oo1@008Woo00<007ooOol02Woo0P009Woo
00<007ooOol017oo00<007ooOol077oo00<007ooOol0;Goo00<007ooOol02goo00<007ooOol0=7oo
00<007ooOol0QGoo00<007ooOol0KWoo0P00O7oo00<007ooOol01goo000jOol00`00Oomoo`1<Ool0
0`00Oomoo`0eOol00`00Oomoo`0/Ool00`00Oomoo`0NOol00`00Oomoo`02Ool00`00Oomoo`0NOol0
0`00Oomoo`0@Ool00`00Oomoo`0=Ool2000HOol00`00Oomoo`0BOol4000=Ool00`00Oomoo`0TOol0
0`00Oomoo`0UOol00`00Oomoo`0UOol00`00Oomoo`0TOol00`00Oomoo`02Ool3000OOol00`00Oomo
o`0<Ool2000UOol20003Ool00`00Oomoo`0NOol00`00Oomoo`0]Ool00`00Oomoo`09Ool00`00Oomo
o`0fOol00`00Oomoo`25Ool00`00Oomoo`1/Ool00`00Oomoo`1lOol00`00Oomoo`07Ool003Yoo`03
001oogoo04aoo`03001oogoo03Aoo`03001oogoo02aoo`03001oogoo01moo`05001oogooOol0000P
Ool00`00Oomoo`0AOol00`00Oomoo`0;Ool2000JOol00`00Oomoo`0?Ool3000AOol00`00Oomoo`0T
Ool00`00Oomoo`0UOol00`00Oomoo`0UOol00`00Oomoo`0TOol00`00Oomoo`05Ool4000JOol00`00
Oomoo`0?Ool2000UOol00`00Ool0000ROol00`00Oomoo`0]Ool00`00Oomoo`08Ool00`00Oomoo`0g
Ool00`00Oomoo`24Ool00`00Oomoo`1[Ool00`00Oomoo`1mOol00`00Oomoo`07Ool003Yoo`03001o
ogoo04aoo`03001oogoo03=oo`03001oogoo02aoo`03001oogoo025oo`03001oo`00021oo`03001o
ogoo01=oo`03001oogoo00Qoo`8001eoo`03001oogoo00]oo`<001Eoo`03001oogoo02=oo`03001o
ogoo02Eoo`03001oogoo02Eoo`03001oogoo02Aoo`03001oogoo00Uoo`<001Moo`03001oogoo015o
o`8002Aoo`8002=oo`03001oogoo02eoo`03001oogoo00Ioo`03001oogoo03Uoo`03001oogoo08Ao
o`03001oogoo06Uoo`03001oogoo07ioo`03001oogoo00Moo`00>Woo00<007ooOol09Woo1`007Woo
00<007ooOol0=7oo00<007ooOol0:goo00<007ooOol08goo00<007ooOol07Woo00<007ooOol05Goo
00<007ooOol01Woo00<007ooOol07Goo00<007ooOol027oo0`0067oo00<007ooOol08goo00<007oo
Ool09Goo00<007ooOol09Goo00<007ooOol08goo00<007ooOol03Goo10004goo00<007ooOol04goo
00<007ooOol08Goo0P0097oo00<007ooOol0;Goo00<007ooOol017oo00<007ooOol0>goo00<007oo
Ool0Q7oo00<007ooOol0Igoo00<007ooOol0Ogoo00<007ooOol01goo000jOol00`00Oomoo`0]Ool9
000EOol00`00Oomoo`0cOol00`00Oomoo`0[Ool00`00Oomoo`0SOol00`00Ool0000NOol00`00Oomo
o`0FOol00`00Oomoo`05Ool2000OOol00`00Oomoo`05Ool3000KOol00`00Oomoo`0TOol00`00Oomo
o`0TOol00`00Oomoo`0UOol00`00Oomoo`0SOol00`00Oomoo`0AOol2000AOol00`00Oomoo`0DOol2
000QOol3000TOol2000^Ool00`00Oomoo`02Ool00`00Oomoo`0mOol00`00Oomoo`24Ool00`00Oomo
o`1UOol00`00Oomoo`20Ool00`00Oomoo`07Ool003Yoo`03001oogoo03Ioo`L000ioo`03001oogoo
03=oo`03001oogoo02Yoo`03001oogoo02Aoo`04001oogoo000LOol00`00Oomoo`0GOol00`00Oomo
o`04Ool00`00Oomoo`0OOol00`00Oomoo`02Ool3000NOol00`00Oomoo`0TOol00`00Oomoo`0@OolL
000POol00`00Oomoo`0SOol00`00Oomoo`0COol3000=Ool00`00Oomoo`0GOol2000NOol01@00Oomo
ogoo00009Goo00<007ooOol0:goo00D007ooOomoo`00041oo`03001oogoo08Aoo`03001oogoo06Ao
o`03001oogoo085oo`03001oogoo00Moo`00>Woo00<007ooOol0?Goo10002Woo00<007ooOol0<Woo
00<007ooOol0:Woo00<007ooOol097oo00D007ooOomoo`0001]oo`03001oogoo01Uoo`04001oogoo
Ool2000SOol4000QOol00`00Oomoo`0TOol00`00Oomoo`03Ool=000DOol00`00Oomoo`05Ool>000B
Ool00`00Oomoo`0SOol00`00Oomoo`0FOol2000;Ool00`00Oomoo`0IOol2000LOol00`00Oomoo`02
Ool00`00Oomoo`0ROol00`00Oomoo`0/Ool00`00Ool00012Ool00`00Oomoo`24Ool00`00Oomoo`1R
Ool00`00Oomoo`22Ool00`00Oomoo`07Ool003Yoo`03001oogoo045oo`@000Eoo`03001oogoo03=o
o`03001oogoo02Uoo`03001oogoo02Aoo`03001oogoo00=oo`03001oogoo01Moo`03001oogoo01]o
o`03001oo`0002=oo`<002Aoo`03001oogoo01aoo`h0025oo`03001oogoo01=oo`d000Eoo`03001o
ogoo02=oo`03001oogoo01Qoo`<000Qoo`03001oogoo01]oo`03001oogoo01Qoo`03001oogoo00Ao
o`03001oogoo029oo`03001oogoo02aoo`8004=oo`03001oogoo08Aoo`03001oogoo061oo`03001o
ogoo08=oo`03001oogoo00Moo`00>Woo00<007ooOol0AGoo0`000Woo00<007ooOol0<Woo00<007oo
Ool0:Woo00<007ooOol08goo00<007ooOol01Goo00<007ooOol05Goo00<007ooOol077oo0P008Goo
0`000Woo00<007ooOol08Woo00<007ooOol04Woo2P0027oo00<007ooOol097oo00<007ooOol087oo
2P008Goo00<007ooOol06goo0P001Goo00<007ooOol07Goo0P005goo00<007ooOol01Woo00<007oo
Ool08Woo00<007ooOol0:goo0P00A7oo00<007ooOol0Q7oo00<007ooOol0GGoo0P00QWoo00<007oo
Ool01goo000jOol00`00Oomoo`18Ool3000dOol00`00Oomoo`0YOol00`00Oomoo`0SOol00`00Oomo
o`07Ool00`00Oomoo`0COol00`00Oomoo`0LOol2000POol20006Ool00`00Oomoo`0QOol00`00Oomo
o`0;Ool7000BOol00`00Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`03Ool7000JOol00`00Oomo
o`0MOol30002Ool00`00Oomoo`0OOol2000EOol00`00Oomoo`07Ool00`00Oomoo`0ROol00`00Oomo
o`0YOol01000Oomoo`00A7oo00<007ooOol0Q7oo00<007ooOol0Fgoo00<007ooOol0QWoo00<007oo
Ool01goo000jOol00`00Oomoo`1:Ool5000`Ool00`00Oomoo`0XOol00`00Oomoo`0TOol00`00Oomo
o`07Ool00`00Oomoo`0BOol00`00Oomoo`0LOol01000Oomoo`007Goo0P0027oo00<007ooOol08Woo
00<007ooOol01Goo1@006Goo00<007ooOol097oo00<007ooOol097oo00<007ooOol02Woo1`004Woo
00<007ooOol08Goo0`008goo00<007ooOol04Woo00<007ooOol027oo00<007ooOol08Woo00<007oo
Ool09goo00<007ooOol00Woo00<007ooOol0@Woo00<007ooOol0Q7oo00<007ooOol0FGoo00<007oo
Ool0Qgoo00<007ooOol01goo000jOol00`00Oomoo`19Ool00`00Oomoo`03Ool3000/Ool00`00Oomo
o`0YOol00`00Oomoo`0SOol00`00Oomoo`09Ool00`00Oomoo`0@Ool00`00Oomoo`0KOol20003Ool0
0`00Oomoo`0IOol2000:Ool00`00Oomoo`0ROol00`00Oomoo`05000NOol00`00Oomoo`0TOol00`00
Oomoo`0TOol00`00Oomoo`0AOol7000;Ool00`00Oomoo`0ROol3000SOol00`00Oomoo`0@Ool00`00
Oomoo`0:Ool00`00Oomoo`0ROol00`00Oomoo`0UOol00`00Oomoo`04Ool00`00Oomoo`12Ool00`00
Oomoo`24Ool00`00Oomoo`1GOol00`00Oomoo`28Ool00`00Oomoo`07Ool003Yoo`03001oogoo04Uo
o`03001oogoo00Ioo`8002Yoo`03001oogoo02Qoo`03001oogoo02=oo`03001oogoo00Yoo`03001o
ogoo00moo`03001oogoo01]oo`03001oogoo00Aoo`03001oogoo01Ioo`8000aoo`03001oogoo021o
o`D002=oo`03001oogoo02Aoo`03001oogoo02Aoo`03001oogoo01Qoo`D000Ioo`03001oogoo029o
o`03001oogoo00<0025oo`03001oogoo00ioo`03001oogoo00aoo`03001oogoo029oo`03001oogoo
02Aoo`03001oogoo00Eoo`03001oogoo045oo`03001oogoo08Aoo`03001oogoo05Ioo`03001oogoo
08Uoo`03001oogoo00Moo`0037oo2P002goo10005Goo00<007ooOol0BGoo00<007ooOol027oo0`00
9Woo00<007ooOol0:Goo00<007ooOol08Woo00<007ooOol037oo00<007ooOol03Goo00<007ooOol0
6Woo0P001goo00<007ooOol05Goo00<007ooOol037oo00<007ooOol077oo10000Woo00<007ooOol0
8goo00<007ooOol097oo00<007ooOol097oo00<007ooOol07Goo0`000goo00<007ooOol08Woo00<0
07ooOol00goo0P0087oo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol08Woo00<007ooOol0
8goo00<007ooOol01Woo00<007ooOol0@Goo00<007ooOol0Q7oo00<007ooOol0E7oo00<007ooOol0
RWoo00<007ooOol01goo000<Ool:0009Ool8000COol00`00Oomoo`19Ool00`00Oomoo`0;Ool2000T
Ool00`00Oomoo`0XOol00`00Oomoo`0ROol00`00Oomoo`0>Ool00`00Oomoo`0;Ool00`00Oomoo`0J
Ool00`00Oomoo`07Ool00`00Oomoo`0COol2000@Ool00`00Oomoo`0HOol30006Ool00`00Oomoo`0S
Ool00`00Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0POol4000SOol00`00Oomoo`06Ool2000O
Ool2000<Ool00`00Oomoo`0?Ool00`00Oomoo`0QOol00`00Oomoo`0ROol00`00Oomoo`07Ool00`00
Oomoo`12Ool00`00Oomoo`24Ool00`00Oomoo`1BOol00`00Oomoo`2;Ool00`00Oomoo`07Ool0011o
o`8000eoo`8000Aoo`8001=oo`03001oogoo04Qoo`03001oogoo00ioo`<0021oo`03001oogoo02Qo
o`03001oogoo029oo`03001oogoo011oo`03001oogoo00Uoo`03001oogoo01Yoo`03001oogoo00Uo
o`03001oogoo011oo`80019oo`03001oogoo01Eoo`<000Uoo`03001oogoo02=oo`03001oogoo02Ao
o`03001oogoo02Aoo`03001oogoo02=oo`<0025oo`03001oogoo00Qoo`8001moo`03001oogoo00Qo
o`03001oogoo015oo`03001oogoo025oo`03001oogoo021oo`03001oogoo00Uoo`03001oogoo049o
o`03001oogoo08Aoo`03001oogoo051oo`03001oogoo08aoo`03001oogoo00Moo`0047oo0P0037oo
0P001Woo0P004Woo00<007ooOol0B7oo00<007ooOol04Goo0P007Woo00<007ooOol0:7oo00<007oo
Ool08Woo00<007ooOol04Goo00<007ooOol01goo00<007ooOol06Goo0P003Goo00<007ooOol03Goo
0P0057oo00<007ooOol04Woo0`0037oo00<007ooOol08goo00<007ooOol097oo00<007ooOol097oo
00<007ooOol08Woo00@007ooOomoo`@001eoo`03001oogoo00Yoo`8001ioo`03001oogoo00Moo`03
001oogoo019oo`80029oo`03001oogoo01ioo`03001oogoo00]oo`03001oogoo049oo`03001oogoo
08Aoo`03001oogoo04aoo`<008moo`03001oogoo00Moo`0047oo0P0037oo0P001Woo0P004Woo00<0
07ooOol0B7oo00<007ooOol04goo0P0077oo00<007ooOol09goo00<007ooOol08Woo00<007ooOol0
4Woo00<007ooOol01Woo00<007ooOol06Goo00<007ooOol03Goo00<007ooOol02goo0P005goo00<0
07ooOol03Goo10003goo00<007ooOol08goo00<007ooOol097oo00<007ooOol097oo00<007ooOol0
8Woo00<007ooOol01Goo0`006Goo00<007ooOol03Goo00<007ooOol077oo00<007ooOol01Woo00<0
07ooOol057oo00<007ooOol087oo00<007ooOol077oo00<007ooOol03Goo00<007ooOol0@Goo00<0
07ooOol0Q7oo00<007ooOol0Bgoo00<007ooOol0T7oo00<007ooOol01goo000@Ool2000;Ool20008
Ool2000AOol00`00Oomoo`18Ool00`00Oomoo`0EOol2000IOol00`00Oomoo`0XOol00`00Oomoo`0Q
Ool00`00Oomoo`0DOol00`00Oomoo`04Ool00`00Oomoo`0IOol00`00Oomoo`0>Ool00`00Oomoo`0:
Ool00`00Oomoo`0GOol00`00Oomoo`09Ool4000DOol00`00Oomoo`0ROol00`00Oomoo`0TOol00`00
Oomoo`0TOol00`00Oomoo`0ROol00`00Oomoo`08Ool4000EOol00`00Oomoo`0>Ool2000MOol00`00
Oomoo`04Ool00`00Oomoo`0FOol00`00Oomoo`0POol00`00Oomoo`0JOol00`00Oomoo`0?Ool00`00
Oomoo`11Ool00`00Oomoo`24Ool00`00Oomoo`19Ool00`00Oomoo`2AOol00`00Oomoo`07Ool0011o
o`8000]oo`8000Qoo`80015oo`03001oogoo04Moo`03001oogoo01Qoo`<001Ioo`03001oogoo02Mo
o`03001oogoo025oo`03001oogoo01Ioo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo011o
o`03001oogoo00Moo`8001Yoo`03001oogoo00Ioo`<001Qoo`03001oogoo029oo`03001oogoo02Ao
o`03001oogoo02Aoo`03001oogoo029oo`03001oogoo00aoo`<0019oo`03001oogoo011oo`8001ao
o`03001oogoo009oo`03001oogoo01Qoo`03001oogoo021oo`03001oogoo01Uoo`03001oogoo011o
o`03001oogoo045oo`03001oogoo08Aoo`03001oogoo04Moo`03001oogoo099oo`03001oogoo00Mo
o`0047oo0P002goo0P0027oo0P004Goo2000@Woo00<007ooOol06goo00<007ooOol017oo0P0037oo
00<007ooOol09goo00<007ooOol08Goo00<007ooOol067oo00@007ooOol001]oo`03001oogoo019o
o`03001oogoo00Aoo`8001aoo`03001oogoo00=oo`<001]oo`03001oogoo029oo`03001oogoo02Ao
o`03001oogoo02Aoo`03001oogoo029oo`03001oogoo00moo`<000ioo`03001oogoo01=oo`03001o
ogoo01Yoo`800003Ool007oo01]oo`03001oogoo021oo`03001oogoo01Moo`03001oogoo019oo`03
001oogoo045oo`03001oogoo08Aoo`03001oogoo04Eoo`03001oogoo08aoo`P000Uoo`0047oo0P00
2goo0P0027oo0P004Goo00<007ooOol0Agoo00<007ooOol077oo0`000goo0`002goo00<007ooOol0
9goo00<007ooOol087oo00<007ooOol06Woo00<007oo00006Woo00<007ooOol04goo00<007ooOol0
0goo00<007ooOol07Goo00<007ooOol00P007Woo00<007ooOol08Woo00<007ooOol097oo00<007oo
Ool097oo00<007ooOol08Woo00<007ooOol04Woo0P0037oo00<007ooOol057oo00<007ooOol06goo
0P0077oo00<007ooOol087oo00<007ooOol05Woo00<007ooOol04goo00<007ooOol0@Goo00<007oo
Ool0Q7oo00<007ooOol0A7oo00<007ooOol0U7oo00<007ooOol01goo000@Ool2000;Ool20008Ool2
000AOol00`00Oomoo`17Ool00`00Oomoo`0OOol20002Ool30009Ool00`00Oomoo`0WOol00`00Oomo
o`0QOol00`00Oomoo`0KOol00`00Oomoo`0HOol00`00Oomoo`0EOol00`00Oomoo`02000POol3000P
Ool00`00Oomoo`0ROol00`00Oomoo`03Oolg000AOol00`00Oomoo`0ROol00`00Oomoo`0DOol2000:
Ool00`00Oomoo`0EOol2000LOol00`00Oomoo`0KOol00`00Oomoo`0OOol00`00Oomoo`0EOol00`00
Oomoo`0EOol00`00Oomoo`11Ool00`00Oomoo`24Ool00`00Oomoo`12Ool00`00Oomoo`2EOol00`00
Oomoo`07Ool0011oo`8000]oo`8000Qoo`80015oo`03001oogoo04Moo`03001oogoo025oo`H000Qo
o`03001oogoo02Moo`03001oogoo021oo`03001oogoo01]oo`03001oo`0001Qoo`03001oogoo01Io
o`03001oo`00021oo`<0029oo`03001oogoo01ioo`X0025oo`03001oogoo01=oo`d000=oo`03001o
ogoo029oo`03001oogoo01Moo`<000Ioo`03001oogoo01Qoo`03001oogoo01Qoo`03001oo`0001eo
o`03001oogoo01moo`03001oogoo01=oo`03001oogoo01Ioo`03001oogoo049oo`03001oogoo08Ao
o`03001oogoo041oo`03001oogoo09Ioo`03001oogoo00Moo`0047oo0P002goo0P0027oo0P004Goo
00<007ooOol0Agoo00<007ooOol097oo10001goo00<007ooOol09Woo00<007ooOol08Goo00<007oo
Ool06Woo00@007ooOol001Moo`03001oogoo01Moo`8001moo`80009oo`03001oogoo021oo`03001o
ogoo01Moo`L000Aoo`03001oogoo02Aoo`03001oogoo021oo`X001ioo`03001oogoo01Yoo`8000Ao
o`03001oogoo01Uoo`8001Moo`05001oogooOol0000MOol00`00Oomoo`0OOol00`00Oomoo`0AOol0
0`00Oomoo`0HOol00`00Oomoo`11Ool00`00Oomoo`24Ool00`00Oomoo`0nOol2002IOol00`00Oomo
o`07Ool0011oo`8000]oo`8000Qoo`80015oo`03001oogoo04Ioo`03001oogoo021oo`X000Eoo`03
001oogoo02Moo`03001oogoo021oo`03001oogoo01Yoo`03001oogoo009oo`03001oogoo01=oo`03
001oogoo01Moo`<001aoo`<000Eoo`03001oogoo021oo`03001oogoo00moo`L000]oo`03001oogoo
02Aoo`03001oogoo02=oo`03001oogoo00Aoo`L001Moo`03001oogoo01aoo`80009oo`03001oogoo
01]oo`03001oogoo01Aoo`03001oogoo009oo`03001oogoo01]oo`03001oogoo01moo`03001oogoo
00moo`03001oogoo01Yoo`03001oogoo045oo`03001oogoo08Aoo`03001oogoo03aoo`03001oogoo
09Uoo`03001oogoo00Moo`0047oo0P0037oo0P001Woo0P004Woo00<007ooOol0AWoo00<007ooOol0
8goo200017oo00<007ooOol09Woo00<007ooOol087oo00<007ooOol06goo00<007ooOol00goo00<0
07ooOol04Woo00<007ooOol05Woo00@007ooOol001Yoo`8000Qoo`03001oogoo021oo`03001oogoo
00Qoo`L001=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo00]oo`D0019oo`03001oogoo
01ioo`8001moo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo01]oo`03001oogoo01ioo`03
001oogoo00ioo`03001oogoo01]oo`03001oogoo049oo`03001oogoo08Aoo`03001oogoo03Uoo`80
09aoo`03001oogoo00Moo`0047oo0P0037oo0P001Woo0P004Woo00<007ooOol0AWoo00<007ooOol0
9goo1@000Woo00<007ooOol09goo00<007ooOol087oo00<007ooOol06Woo00<007ooOol01Goo00<0
07ooOol047oo00<007ooOol05Woo00D007ooOomoo`0001Qoo`8000Yoo`03001oogoo021oo`03001o
ogoo009oo`H001Yoo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo011oo`D000eoo`03001o
ogoo01moo`<001ioo`80015oo`03001oogoo00Ioo`03001oogoo01Yoo`03001oogoo01moo`03001o
ogoo00aoo`03001oogoo01eoo`03001oogoo049oo`03001oogoo08=oo`03001oogoo03Aoo`05001o
ogooOol0002NOol00`00Oomoo`07Ool000aoo`<00003Ool0000000eoo`8000Aoo`8001=oo`03001o
ogoo04Ioo`03001oogoo02]oo`@002Uoo`03001oogoo01moo`03001oogoo01Yoo`03001oogoo00Mo
o`03001oogoo00ioo`03001oogoo01Ioo`03001oogoo00=oo`03001oogoo01Aoo`03001oogoo00]o
o`03001oogoo01eoo`L0021oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo01Eoo`D000Qo
o`03001oogoo01moo`03001oogoo008001ioo`03001oogoo00eoo`03001oogoo00Qoo`03001oogoo
01Yoo`03001oogoo01moo`03001oogoo00Yoo`03001oogoo01ioo`03001oogoo049oo`03001oogoo
08Aoo`03001oogoo03=oo`04001oogoo002OOol00`00Oomoo`07Ool000aoo`H000eoo`P001=oo`03
001oogoo04Ioo`03001oogoo02ioo`8002Moo`03001oogoo021oo`03001oogoo01Yoo`03001oogoo
00Qoo`03001oogoo00aoo`03001oogoo01Ioo`03001oogoo00Eoo`03001oogoo015oo`8000ioo`03
001oogoo01Moo`H0009oo`03001oogoo029oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo
01Yoo`@000=oo`03001oogoo01moo`03001oogoo00=oo`8001eoo`8000eoo`03001oogoo00Uoo`03
001oogoo01Yoo`03001oogoo01moo`03001oogoo00Qoo`03001oogoo021oo`03001oogoo049oo`03
001oogoo08=oo`03001oogoo039oo`04001oogoo002POol00`00Oomoo`07Ool000moo`<000moo`@0
01Eoo`03001oogoo04Ioo`03001oogoo02eoo`03001oogoo008002Eoo`03001oogoo01moo`03001o
ogoo01Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo01Eoo`8000Qoo`03001oogoo00mo
o`80011oo`03001oogoo01Aoo`<000Qoo`03001oogoo029oo`03001oogoo02=oo`03001oogoo02=o
o`03001oogoo01ioo`D0021oo`03001oogoo00Eoo`8001eoo`03001oogoo00Yoo`03001oogoo00Yo
o`03001oogoo01Yoo`03001oogoo01ioo`03001oogoo00Moo`03001oogoo029oo`03001oogoo049o
o`03001oogoo08=oo`03001oogoo031oo`800003Ool007oo0:1oo`03001oogoo00Moo`00>Woo00<0
07ooOol0AWoo00<007ooOol0;Goo00<007ooOol00Woo00<007ooOol08Goo00<007ooOol087oo00<0
07ooOol06Goo00<007ooOol02goo00D007ooOomoo`0000Moo`03001oogoo01Eoo`03001oogoo00Uo
o`03001oogoo00eoo`03001oogoo011oo`03001oogoo015oo`<000]oo`03001oogoo029oo`03001o
ogoo02=oo`03001oogoo02=oo`03001oogoo025oo`03001oo`0000<001aoo`03001oogoo00Moo`80
01aoo`03001oogoo00Qoo`03001oogoo00aoo`03001oogoo01Yoo`03001oogoo01ioo`03001oogoo
00Ioo`03001oogoo029oo`03001oogoo049oo`03001oogoo08Aoo`03001oogoo02ioo`@00004Ool0
0000002NOol00`00Oomoo`07Ool003Yoo`03001oogoo04Ioo`03001oogoo02eoo`03001oogoo00=o
o`<0021oo`03001oogoo01moo`03001oogoo01Yoo`03001oogoo00]oo`05001oogooOol00007Ool0
0`00Oomoo`0DOol00`00Oomoo`0:Ool00`00Oomoo`0;Ool2000DOol00`00Oomoo`0=Ool3000>Ool0
0`00Oomoo`0ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0QOol00`00Oomoo`03Ool3
000IOol00`00Oomoo`09Ool2000KOol00`00Oomoo`06Ool00`00Oomoo`0>Ool00`00Oomoo`0IOol0
0`00Oomoo`0OOol00`00Oomoo`04Ool00`00Oomoo`0TOol00`00Oomoo`12Ool00`00Oomoo`23Ool0
0`00Oomoo`0]Ool7002POol00`00Oomoo`07Ool003Yoo`03001oogoo04Ioo`03001oogoo02aoo`03
001oogoo00Moo`03001oogoo01aoo`03001oogoo021oo`03001oogoo01Uoo`03001oogoo00eoo`03
001oogoo008000Eoo`03001oogoo01Aoo`03001oogoo00aoo`03001oogoo00Qoo`8001Ioo`03001o
ogoo00Yoo`<0019oo`03001oogoo025oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo025o
o`03001oogoo00Ioo`<001Eoo`03001oogoo00aoo`8001Yoo`03001oogoo00Aoo`03001oogoo011o
o`03001oogoo01Uoo`03001oogoo01moo`03001oogoo009oo`03001oogoo02Eoo`03001oogoo049o
o`03001oogoo08Aoo`03001oogoo02aoo`D00:9oo`03001oogoo00Moo`00>Woo00<007ooOol0AGoo
00<007ooOol0;Goo00<007ooOol027oo0`006goo00<007ooOol07goo00<007ooOol06Goo00<007oo
Ool03goo00@007oo000000Aoo`03001oogoo01Aoo`03001oogoo00eoo`03001oogoo00Moo`03001o
ogoo01Ioo`03001oogoo00Moo`<001Eoo`03001oogoo025oo`03001oogoo02=oo`03001oogoo02=o
o`03001oogoo021oo`03001oogoo00Yoo`<0019oo`03001oogoo00ioo`03001oogoo01Qoo`03001o
ogoo00=oo`03001oogoo011oo`03001oogoo01Yoo`03001oogoo01ioo`03001oogoo008002Uoo`03
001oogoo049oo`03001oogoo08=oo`03001oogoo02]oo`<00:Eoo`03001oogoo00Moo`00>Woo00<0
07ooOol0AGoo00<007ooOol0;Goo00<007ooOol02goo00<007ooOol05goo00<007ooOol07goo00<0
07ooOol06Woo00<007ooOol037oo0`0000=oo`00Ool00P000Woo00<007ooOol057oo00<007ooOol0
3goo00<007ooOol017oo0P006Woo00<007ooOol00goo0`0067oo00<007ooOol08Goo00<007ooOol0
8goo00<007ooOol08goo00<007ooOol087oo00<007ooOol03Goo0`003goo00<007ooOol03goo0P00
6Goo00D007ooOomoo`0001Aoo`03001oogoo01Uoo`03001oogoo01eoo`04001oo`00000/Ool00`00
Oomoo`12Ool00`00Oomoo`23Ool00`00Oomoo`0YOol2002WOol00`00Oomoo`07Ool003Yoo`03001o
ogoo04Eoo`03001oogoo02aoo`03001oogoo00eoo`8001Moo`03001oogoo01moo`03001oogoo01Uo
o`03001oogoo00moo`H00003Ool007oo01Eoo`03001oogoo011oo`03001oogoo009oo`8001aoo`03
001oogoo00<001]oo`03001oogoo025oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo021o
o`03001oogoo011oo`<000]oo`03001oogoo019oo`03001oogoo01Moo`03001oo`0001Ioo`03001o
ogoo01Uoo`03001oogoo01]oo`800003Ool0000002eoo`03001oogoo045oo`03001oogoo08=oo`03
001oogoo02Qoo`03001oogoo0:Moo`03001oogoo00Moo`00>Woo00<007ooOol0AGoo00<007ooOol0
;7oo00<007ooOol03goo0P0057oo00<007ooOol07goo00<007ooOol06Goo00<007ooOol04Goo1P00
5Woo00<007ooOol04Goo00<007ooOol00P007Woo0`007Woo00<007ooOol08Goo00<007ooOol03goo
70007Woo00<007ooOol087oo00<007ooOol04goo0`0027oo00<007ooOol04goo0P0067oo0P005goo
00<007ooOol06Goo00<007ooOol06Woo00<007oo00000Woo00<007ooOol0:goo00<007ooOol0@Goo
00<007ooOol0Pgoo00<007ooOol09Goo0P00ZWoo00<007ooOol01goo000jOol00`00Oomoo`15Ool0
0`00Oomoo`0/Ool00`00Oomoo`0AOol2000BOol00`00Oomoo`0OOol00`00Oomoo`0IOol00`00Oomo
o`0COol4000FOol00`00Oomoo`0BOol2000OOol2000POol00`00Oomoo`0QOol00`00Oomoo`02Ool=
000DOol00`00Oomoo`05OolH0005Ool00`00Oomoo`0QOol00`00Oomoo`0FOol30005Ool00`00Oomo
o`0EOol00`00Oomoo`0EOol2000GOol00`00Oomoo`0IOol00`00Oomoo`0IOol30002Ool3000/Ool0
0`00Oomoo`11Ool00`00Oomoo`23Ool00`00Oomoo`0TOol00`00Oomoo`2ZOol00`00Oomoo`07Ool0
03Yoo`03001oogoo04Eoo`03001oogoo02aoo`03001oogoo01=oo`03001oogoo00ioo`03001oogoo
01moo`03001oogoo01Uoo`03001oogoo01Eoo`<001Eoo`03001oogoo01=oo`8001aoo`<0009oo`03
001oogoo01ioo`03001oogoo01Moo`h0025oo`03001oogoo01eoo`L0029oo`03001oogoo01Uoo`80
00=oo`03001oogoo01Ioo`8001Eoo`8001Qoo`03001oogoo01Uoo`03001oogoo01Moo`L00003Ool0
07oo02aoo`03001oogoo045oo`03001oogoo08=oo`03001oogoo029oo`03001oogoo0:]oo`03001o
ogoo00Moo`00>Woo00<007ooOol0AGoo00<007ooOol0:goo00<007ooOol05Goo0`003Goo00<007oo
Ool07goo00<007ooOol06Goo00<007ooOol05Goo10004goo00<007ooOol04goo00<007oo00006Woo
0P001Goo00<007ooOol07Woo00<007ooOol03Goo2P002Goo00<007ooOol08goo00<007ooOol08Woo
00<007oo00001@0077oo00<007ooOol06goo0`006goo00<007ooOol04Goo00@007ooOol001Qoo`03
001oogoo01Uoo`03001oogoo01Ioo`D000Aoo`03001oogoo02Yoo`03001oogoo045oo`03001oogoo
08=oo`03001oogoo025oo`03001oogoo0:aoo`03001oogoo00Moo`00>Woo00<007ooOol0AGoo00<0
07ooOol0:goo00<007ooOol067oo00<007ooOol02Woo00<007ooOol07Woo00<007ooOol06Goo00<0
07ooOol05Goo00D007ooOomoo`00019oo`03001oogoo019oo`80009oo`03001oogoo01Ioo`8000Mo
o`03001oogoo01ioo`03001oogoo00Ioo`L001=oo`03001oogoo02=oo`03001oogoo029oo`03001o
ogoo00Eoo`L001Aoo`03001oogoo01ioo`<001Yoo`03001oogoo00moo`03001oogoo009oo`03001o
ogoo01Eoo`03001oogoo01Uoo`03001oogoo01Eoo`@000Ioo`03001oogoo02]oo`03001oogoo045o
o`03001oogoo08=oo`03001oogoo01ioo`800:moo`03001oogoo00Moo`00>Woo00<007ooOol0A7oo
00<007ooOol0;7oo00<007ooOol06Goo0`0027oo00<007ooOol07goo00<007ooOol067oo00<007oo
Ool05Woo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol04Woo00<007ooOol00goo00<007oo
Ool04Woo0`002Goo00<007ooOol07Woo00@007ooOomoo`D001Yoo`03001oogoo02=oo`03001oogoo
029oo`03001oogoo00aoo`L000eoo`03001oogoo01ioo`03001oogoo008001Uoo`03001oogoo00io
o`03001oogoo00=oo`03001oogoo01Eoo`03001oogoo01Uoo`03001oogoo01Aoo`<000Qoo`03001o
ogoo02Yoo`03001oogoo049oo`03001oogoo089oo`03001oogoo01aoo`800;5oo`03001oogoo00Mo
o`00>Woo00<007ooOol0A7oo00<007ooOol0;7oo00<007ooOol077oo00<007ooOol01Goo00<007oo
Ool07Woo00<007ooOol06Goo00<007ooOol05Goo00<007ooOol017oo00<007ooOol037oo00<007oo
Ool04Woo00<007ooOol01Goo00<007ooOol03goo0P0037oo00<007ooOol07Goo1@007goo00<007oo
Ool08goo00<007ooOol08Woo00<007ooOol04goo1`001Woo00<007ooOol07Woo00<007ooOol00Woo
0P0067oo00<007ooOol037oo00<007ooOol01Goo00<007ooOol05Goo00<007ooOol067oo00<007oo
Ool04goo0P002Woo00<007ooOol0:goo00<007ooOol0@Goo00<007ooOol0Pgoo00<007ooOol06Woo
00<007ooOol0/Goo00<007ooOol01goo000jOol00`00Oomoo`14Ool00`00Oomoo`0[Ool00`00Oomo
o`0NOol20005Ool00`00Oomoo`0NOol00`00Oomoo`0HOol00`00Oomoo`0EOol00`00Oomoo`06Ool0
0`00Oomoo`0:Ool00`00Oomoo`0BOol00`00Oomoo`06Ool00`00Oomoo`0=Ool2000?Ool00`00Oomo
o`0GOol500000goo001oo`0QOol00`00Oomoo`0SOol00`00Oomoo`0ROol00`00Oomoo`0JOol50000
0goo001oo`0NOol00`00Oomoo`05Ool00`00Oomoo`0FOol00`00Oomoo`07Ool01000Oomoo`002Goo
00<007ooOol057oo00<007ooOol06Goo00<007ooOol04Goo00<007ooOol02goo00<007ooOol0:Woo
00<007ooOol0@Woo00<007ooOol0PWoo00<007ooOol06Goo00<007ooOol0/Woo00<007ooOol01goo
000jOol00`00Oomoo`14Ool00`00Oomoo`0[Ool00`00Oomoo`0POol01@00Oomoogoo000087oo00<0
07ooOol06Goo00<007ooOol05Goo00<007ooOol01goo00<007ooOol027oo00<007ooOol04Woo00<0
07ooOol01goo00<007ooOol037oo00<007ooOol03goo00<007ooOol04goo10001Woo00<007ooOol0
87oo00<007ooOol08goo00<007ooOol08Woo00<007ooOol07goo0`007Woo00<007ooOol01Woo0P00
5goo00<007ooOol01Woo00<007oo00002goo00<007ooOol057oo00<007ooOol06Goo00<007ooOol0
3goo00<007ooOol037oo00<007ooOol0:goo00<007ooOol0@Goo00<007ooOol0Pgoo00<007ooOol0
5goo00<007ooOol0/goo00<007ooOol01goo000jOol00`00Oomoo`14Ool00`00Oomoo`0[Ool00`00
Oomoo`0QOol4000POol00`00Oomoo`0HOol00`00Oomoo`0EOol00`00Oomoo`09Ool00`00Oomoo`07
Ool00`00Oomoo`0AOol00`00Oomoo`09Ool01@00Oomoogoo00001goo0P004Woo00<007ooOol03Woo
1@002Woo00<007ooOol087oo00<007ooOol08goo00<007ooOol08Woo00<007ooOol087oo00<007oo
00000P006goo00<007ooOol027oo0P005Woo00<007ooOol017oo0P0000=oo`00Ool02goo00<007oo
Ool057oo00<007ooOol067oo00<007ooOol03Goo0P0047oo00<007ooOol0:goo00<007ooOol0@Goo
00<007ooOol0PWoo00<007ooOol05Goo0P00]Woo00<007ooOol01goo000jOol00`00Oomoo`14Ool0
0`00Oomoo`0[Ool00`00Oomoo`0TOol00`00Oomoo`0MOol00`00Oomoo`0IOol00`00Oomoo`0EOol0
0`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool01@00Oomoogoo0000
1Goo0P005Goo00<007ooOol02Goo10003goo00<007ooOol087oo00<007ooOol08goo00<007ooOol0
8Woo00<007ooOol07goo00<007ooOol00goo0`005goo00<007ooOol02goo0P005Goo00<007ooOol0
0goo0P0000=oo`00Ool00P002Goo00<007ooOol057oo00<007ooOol06Goo00<007ooOol02Woo0P00
4Woo00<007ooOol0:goo00<007ooOol0@Goo00<007ooOol0PWoo00<007ooOol04goo0P00^7oo00<0
07ooOol01goo000jOol00`00Oomoo`14Ool00`00Oomoo`0[Ool00`00Oomoo`0SOol00`00Ool00002
000LOol00`00Oomoo`0HOol00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomo
o`0AOol00`00Oomoo`09Ool200001Goo001oogoo000017oo00<007ooOol05Goo00<007ooOol01Woo
0`0057oo00<007ooOol087oo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo00<007oo
Ool01Woo10004goo00<007ooOol03Goo00<007ooOol04goo00<007ooOol00Woo00<007oo00000P00
37oo00<007ooOol057oo00<007ooOol067oo00<007ooOol02Goo00<007ooOol04goo00<007ooOol0
:goo00<007ooOol0@Goo00<007ooOol0PWoo00<007ooOol04Goo00<007ooOol0^7oo00<007ooOol0
1goo000jOol00`00Oomoo`14Ool00`00Oomoo`0ZOol00`00Oomoo`0TOol00`00Oomoo`02Ool00`00
Oomoo`0HOol00`00Oomoo`0IOol00`00Oomoo`0DOol00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00
Oomoo`0AOol00`00Oomoo`0:Ool3000017oo001oo`000Woo0P0067oo00<007ooOol00goo0`005goo
00<007ooOol087oo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo00<007ooOol02Woo
0`0047oo00<007ooOol03Woo0P0057oo00<007ooOol01@003Woo00<007ooOol057oo00<007ooOol0
67oo00<007ooOol01goo00<007ooOol057oo00<007ooOol0:goo00<007ooOol0@Goo00<007ooOol0
PWoo00<007ooOol047oo00<007ooOol0^Goo00<007ooOol01goo000jOol00`00Oomoo`14Ool00`00
Oomoo`0ZOol00`00Oomoo`0TOol00`00Oomoo`03Ool2000HOol00`00Oomoo`0HOol00`00Oomoo`0E
Ool00`00Oomoo`0>Ool01000Oomoo`004goo00<007ooOol037oo20006Woo00<007ooOol00`006Woo
00<007ooOol087oo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo00<007ooOol03Goo
10002goo00<007ooOol04Goo00<007ooOol04Woo00<007oo00000`0047oo00<007ooOol04goo00<0
07ooOol06Goo00<007ooOol01Goo00<007ooOol05Woo00<007ooOol0:goo00<007ooOol0@Goo00<0
07ooOol0PWoo00<007ooOol03Woo00<007ooOol0^Woo00<007ooOol01goo000jOol00`00Oomoo`13
Ool00`00Oomoo`0[Ool00`00Oomoo`0SOol00`00Oomoo`06Ool2000FOol00`00Oomoo`0HOol00`00
Oomoo`0DOol00`00Oomoo`0@Ool2000COol00`00Oomoo`0>Ool5000LOol3000MOol00`00Oomoo`0P
Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol00`00Oomoo`0AOol30008Ool00`00
Oomoo`0BOol00`00Oomoo`0BOol4000AOol00`00Oomoo`0DOol00`00Oomoo`0HOol00`00Oomoo`04
Ool00`00Oomoo`0GOol00`00Oomoo`0[Ool00`00Oomoo`12Ool00`00Oomoo`21Ool00`00Oomoo`0<
Ool2002mOol00`00Oomoo`07Ool003Yoo`03001oogoo04=oo`03001oogoo02]oo`03001oogoo02=o
o`03001oogoo00Qoo`8001=oo`03001oogoo01Qoo`03001oogoo01Eoo`03001oogoo011oo`80019o
o`03001oogoo00moo`D001Yoo`@001ioo`03001oogoo021oo`03001oogoo029oo`03001oogoo029o
o`03001oogoo01ioo`03001oogoo01Eoo`<000Eoo`03001oogoo01=oo`03001oogoo015oo`<001=o
o`03001oogoo01Aoo`03001oogoo01Qoo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo02]o
o`03001oogoo045oo`03001oogoo089oo`03001oogoo00Uoo`800;moo`03001oogoo00Moo`00>Woo
00<007ooOol0@goo00<007ooOol0:Woo00<007ooOol097oo00<007ooOol02Woo00<007ooOol047oo
00<007ooOol067oo00<007ooOol057oo00<007ooOol04Goo00<007oo000047oo00<007ooOol04Goo
1@005goo0P000goo00<007ooOol077oo00<007ooOol087oo00<007ooOol00Woo=P003goo00<007oo
Ool07Woo00<007ooOol067oo0P000Woo00<007ooOol05Goo00<007ooOol047oo0`0057oo00<007oo
Ool04goo00<007ooOol067oo00D007ooOomoo`0001aoo`03001oogoo02]oo`03001oogoo049oo`03
001oogoo085oo`03001oogoo00Qoo`03001oogoo0;moo`03001oogoo00Moo`00>Woo1@00@Goo00<0
07ooOol0:Woo00<007ooOol08goo00<007ooOol037oo0`003Woo00<007ooOol067oo00<007ooOol0
57oo00<007ooOol04Goo00D007ooOomoo`0000ioo`03001oogoo015oo`H001Eoo`8000Eoo`03001o
ogoo01aoo`03001oogoo01Ioo`l0021oo`03001oogoo01=oo`d00003Ool007oo021oo`03001oogoo
01Yoo`<001Qoo`8000moo`80009oo`8001=oo`03001oogoo01=oo`03001oogoo01Qoo`<001ioo`03
001oogoo02]oo`03001oogoo045oo`03001oogoo089oo`03001oogoo00Ioo`03001oogoo0;]oo`H0
00Uoo`00>Woo00<007ooOol0@goo00<007ooOol0:Woo00<007ooOol08goo00<007ooOol03goo00<0
07ooOol02goo00<007ooOol067oo00<007ooOol057oo00<007ooOol04Goo00<007ooOol00Woo00<0
07ooOol02goo00<007ooOol047oo00@007ooOomoo`<0019oo`<000Moo`03001oogoo01aoo`03001o
ogoo00aoo`X000Yoo`03001oogoo029oo`03001oogoo021oo`X001Uoo`03001oogoo01Uoo`03001o
ogoo008001Uoo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo011oo`03001oogoo01=oo`03
001oogoo01Qoo`03001oogoo01ioo`03001oogoo02]oo`03001oogoo045oo`03001oogoo089oo`03
001oogoo00Aoo`800<=oo`03001oogoo00Moo`00>Woo00<007ooOol0@goo00<007ooOol0:Woo00<0
07ooOol08goo00<007ooOol047oo0P002goo00<007ooOol05goo00<007ooOol057oo00<007ooOol0
4Goo00<007ooOol017oo00<007ooOol02Goo00<007ooOol047oo00<007ooOol00Woo0`0047oo0P00
2Woo00@007ooOol001aoo`03001oogoo00Aoo`L001Aoo`03001oogoo029oo`03001oogoo025oo`03
001oogoo00Ioo`L0019oo`03001oogoo01Uoo`05001oogoo001oo`03000GOol00`00Oomoo`0;Ool0
0`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`0COol00`00Oomoo`0FOol00`00Ool0000POol0
0`00Oomoo`0[Ool00`00Oomoo`11Ool00`00Oomoo`22Ool01000Oomoogoo0P00aGoo00<007ooOol0
1goo000jOol00`00Oomoo`13Ool00`00Oomoo`0ZOol00`00Oomoo`0ROol00`00Oomoo`0COol30007
Ool00`00Oomoo`0HOol00`00Oomoo`0DOol00`00Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`07
Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool2000>Ool20009Ool01`00Oomoogoo001oo`0001aoo`03
001oo`0000@001]oo`03001oogoo029oo`03001oogoo025oo`03001oogoo00eoo`L000]oo`03001o
ogoo01Uoo`05001oogoo001oo`0200000goo0000000FOol2000:Ool00`00Oomoo`05Ool00`00Oomo
o`0AOol00`00Oomoo`0BOol00`00Oomoo`0DOol20002Ool00`00Oomoo`0NOol00`00Oomoo`0[Ool0
0`00Oomoo`11Ool00`00Oomoo`22Ool01000Oomoo`00agoo00<007ooOol01goo000jOol00`00Oomo
o`13Ool00`00Oomoo`0YOol00`00Oomoo`0SOol00`00Oomoo`0FOol00`00Oomoo`04Ool00`00Oomo
o`0GOol00`00Oomoo`0DOol00`00Oomoo`0AOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`0@Ool00`00Oomoo`06Ool00`00Oomoo`09Ool3000;Ool01`00Oomoogoo001oo`0001Uoo`D0021o
o`03001oogoo029oo`03001oogoo025oo`03001oogoo01Aoo`L000Aoo`03001oogoo01Uoo`04001o
o`00Ool20004Ool2000FOol00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomo
o`0COol00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`0NOol00`00Oomoo`0[Ool00`00Oomo
o`11Ool00`00Oomoo`22Ool20038Ool00`00Oomoo`07Ool003Yoo`03001oogoo04=oo`03001oogoo
02Uoo`03001oogoo02=oo`03001oogoo01Moo`<000=oo`04001oo`00000FOol00`00Oomoo`0DOol0
0`00Oomoo`0@Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool2000:Ool00`00Oomo
o`06Ool2000?Ool01P00Oomoo`00Ool001Aoo`D000=oo`03001oogoo01moo`03001oogoo029oo`03
001oogoo025oo`03001oogoo01]oo`D001]oo`D000Moo`8001Eoo`03001oogoo00Aoo`03001oogoo
00Uoo`03001oogoo011oo`03001oogoo01=oo`03001oogoo00moo`8000Ioo`03001oogoo01ioo`03
001oogoo02]oo`03001oogoo045oo`03001oogoo085oo`800<Uoo`03001oogoo00Moo`00>Woo00<0
07ooOol0@goo00<007ooOol0:Goo00<007ooOol08goo00<007ooOol06Woo00<007oo00000Woo0`00
5Goo00<007ooOol04goo00<007ooOol04Goo00<007ooOol02Goo00<007ooOol00goo00<007ooOol0
3Woo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol03goo0P0000Aoo`000000011oo`@000Qo
o`03001oogoo01moo`03001oogoo029oo`03001oogoo025oo`03001oogoo01]oo`05001oogoo001o
o`05000FOol50009Ool00`00Oomoo`0COol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0A
Ool00`00Oomoo`0BOol00`00Oomoo`0>Ool00`00Oomoo`06Ool00`00Oomoo`0NOol00`00Oomoo`0/
Ool00`00Oomoo`11Ool00`00Oomoo`1nOol20002Ool00`00Oomoo`36Ool00`00Oomoo`07Ool003Yo
o`03001oogoo04=oo`03001oogoo02Uoo`03001oogoo029oo`03001oogoo01aoo`8000=oo`<001=o
o`03001oogoo01=oo`03001oogoo015oo`03001oogoo00]oo`05001oogooOol0000@Ool00`00Oomo
o`0<Ool00`00Oomoo`02Ool2000COol5000;Ool5000<Ool00`00Oomoo`0OOol00`00Oomoo`0ROol0
0`00Oomoo`0QOol00`00Oomoo`0KOol01000Oomoo`000Woo00@007ooOomoo`@0019oo`@000]oo`80
01Aoo`05001oogooOol0000=Ool00`00Oomoo`0@Ool00`00Oomoo`0COol00`00Oomoo`0<Ool00`00
Oomoo`08Ool00`00Oomoo`0NOol00`00Oomoo`0[Ool00`00Oomoo`11Ool00`00Oomoo`1mOol00`00
Oomoo`02Ool00`00Oomoo`36Ool00`00Oomoo`07Ool003Yoo`03001oogoo04=oo`03001oogoo02Uo
o`03001oogoo029oo`03001oogoo01eoo`<0009oo`<0019oo`03001oogoo01=oo`03001oogoo011o
o`03001oogoo00eoo`03001oo`00011oo`03001oogoo00eoo`05001oogooOol0000EOol50007Ool4
000AOol00`00Oomoo`0LOol01000Oomoo`000Woo00<007ooOol07goo00<007ooOol08Goo00<007oo
Ool06goo0P0000Aoo`00Ool000Qoo`@000eoo`@000ioo`80019oo`04001oogoo000?Ool00`00Oomo
o`0@Ool00`00Oomoo`0BOol00`00Oomoo`0:Ool2000;Ool00`00Oomoo`0NOol00`00Oomoo`0[Ool0
0`00Oomoo`12Ool00`00Oomoo`1jOol20005Ool00`00Oomoo`36Ool00`00Oomoo`07Ool003Yoo`03
001oogoo049oo`03001oogoo02Uoo`03001oogoo02=oo`03001oogoo01aoo`04001oogooOol6000@
Ool00`00Oomoo`0COol00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>
Ool01000Ool000005goo10000goo10005Goo00D007ooOomoo`0001Yoo`04001oogoo0002Ool00`00
Oomoo`0LOol01000Oomoo`000Woo00<007ooOol07Woo00<007ooOol06goo0P0000Aoo`00000000ao
o`<000Yoo`@0011oo`80015oo`80015oo`03001oogoo011oo`03001oogoo019oo`03001oogoo00Qo
o`03001oogoo00aoo`03001oogoo01ioo`03001oogoo02]oo`03001oogoo045oo`03001oogoo07Uo
o`03001oogoo00Ioo`03001oogoo0<Eoo`03001oogoo00Moo`00>Woo00<007ooOol0@Woo00<007oo
Ool0:Goo00<007ooOol08goo00<007ooOol077oo00<007ooOol00goo1@003goo00<007ooOol04goo
00<007ooOol047oo00<007ooOol03goo0P003Woo00<007ooOol047oo00<007ooOol067oo1P005goo
00@007ooOol0009oo`03001oogoo01Uoo`04001oo`00Ool2000NOol01000Oomoo`000Woo00<007oo
Ool06goo00@007ooOol0009oo`03001oogoo01Qoo`800004Ool00000000?Ool40006Ool3000COol0
0`00Oomoo`0>Ool2000AOol00`00Oomoo`0@Ool00`00Oomoo`0BOol00`00Oomoo`06Ool2000?Ool0
0`00Oomoo`0NOol00`00Oomoo`0[Ool00`00Oomoo`12Ool00`00Oomoo`1fOol20009Ool00`00Oomo
o`35Ool00`00Oomoo`07Ool003Yoo`03001oogoo049oo`03001oogoo02Uoo`03001oogoo029oo`03
001oogoo01eoo`03001oo`0000T000eoo`03001oogoo01=oo`03001oogoo011oo`03001oogoo00mo
o`04001oogoo000<Ool00`00Oomoo`0@Ool00`00Ool0000IOol3000JOol01@00Oomoo`00Ool00P00
6goo00@007oo001oo`8001ioo`800003Ool007oo008001eoo`04001oogoo0002Ool00`00Oomoo`0H
Ool5000DOol30003Ool3000DOol2000>Ool00`00Ool0000AOol00`00Oomoo`0@Ool00`00Oomoo`0B
Ool00`00Oomoo`04Ool00`00Oomoo`0@Ool00`00Oomoo`0NOol00`00Oomoo`0[Ool00`00Oomoo`11
Ool00`00Oomoo`1dOol2000<Ool00`00Oomoo`34Ool00`00Oomoo`07Ool003Yoo`03001oogoo049o
o`03001oogoo02Uoo`03001oogoo029oo`03001oogoo01aoo`03001oogoo00=oo`P000aoo`03001o
ogoo01=oo`03001oogoo011oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Qoo`03001o
ogoo00moo`80009oo`03001oogoo01Aoo`<00003Ool0000001]oo`04001oo`00Ool2000KOol5000P
Ool01@00Ool007oo00007Woo0P0000Aoo`00Ool001aoo`@001Moo`D001Moo`8000aoo`04001oogoo
000AOol00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomo
o`0NOol00`00Oomoo`0[Ool00`00Oomoo`12Ool00`00Oomoo`1bOol00`00Oomoo`0<Ool00`00Oomo
o`34Ool00`00Oomoo`07Ool003Yoo`03001oogoo049oo`03001oogoo02Uoo`03001oogoo029oo`03
001oogoo01aoo`03001oogoo00Moo`D000]oo`03001oogoo019oo`03001oogoo011oo`03001oogoo
00moo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00moo`03001oogoo009oo`03001oogoo
015oo`<000Aoo`8001]oo`03001oo`00008001eoo`@0021oo`D001ioo`800004Ool007oo000LOol3
000KOol2000IOol00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`0@Ool0
0`00Oomoo`0BOol01@00Oomoogoo000057oo00<007ooOol07Woo00<007ooOol0;7oo00<007ooOol0
@Goo00<007ooOol0LGoo00<007ooOol03Woo00<007ooOol0`goo00<007ooOol01goo000jOol00`00
Oomoo`12Ool00`00Oomoo`0XOol00`00Oomoo`0SOol00`00Oomoo`0LOol00`00Oomoo`0;Ool20009
Ool00`00Oomoo`0COol00`00Oomoo`0@Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`0>Ool20006Ool00`00Oomoo`0=Ool30008Ool00`00Oomoo`0IOol5000MOol40000
0goo0000000e000<Ool5000LOol3000KOol00`00Ool00002000GOol00`00Oomoo`06Ool00`00Oomo
o`04Ool00`00Oomoo`0>Ool00`00Oomoo`0@Ool00`00Oomoo`0BOol3000FOol00`00Oomoo`0NOol0
0`00Oomoo`0[Ool00`00Oomoo`12Ool00`00Oomoo`1]Ool3000AOol00`00Oomoo`33Ool00`00Oomo
o`07Ool003Yoo`03001oogoo049oo`03001oogoo02Qoo`03001oogoo029oo`03001oogoo01aoo`03
001oogoo00ioo`8000Moo`03001oogoo01=oo`03001oogoo00moo`03001oogoo00ioo`03001oogoo
00Ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00Ioo`03001oogoo00Yoo`<000]oo`03
001oogoo01Yoo`@001Aoo`h001moo`D001=ooa0001eoo`8001aoo`03001oogoo009oo`8001Ioo`03
001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00ioo`03001oogoo00moo`03001oogoo015oo`80
01Qoo`03001oogoo01ioo`03001oogoo02]oo`03001oogoo049oo`03001oogoo06aoo`03001oogoo
019oo`03001oogoo0<=oo`03001oogoo00Moo`00>Woo00<007ooOol0@Woo00<007ooOol0:7oo00<0
07ooOol08Woo00<007ooOol077oo00<007ooOol047oo0`000goo00<007ooOol04goo00<007ooOol0
3goo00<007ooOol03Woo00<007ooOol027oo00D007ooOomoo`00011oo`03001oogoo00Qoo`03001o
ogoo00Moo`8000moo`03001oogoo01Uoo`@000Eoo`l000Yoo`<0025oo`<0021ooa8000moo`8001]o
o`03001oogoo00Eoo`8001Eoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00ioo`03001o
ogoo00moo`03001oogoo00moo`04001oogoo000HOol00`00Oomoo`0NOol00`00Oomoo`0[Ool00`00
Oomoo`12Ool00`00Oomoo`1ZOol00`00Oomoo`0DOol00`00Oomoo`32Ool00`00Oomoo`07Ool003Yo
o`03001oogoo049oo`03001oogoo02Qoo`03001oogoo029oo`03001oogoo01aoo`03001oogoo01=o
o`04001oogoo000EOol00`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`09Ool01000Oomoo`00
3goo00<007ooOol02Goo00<007ooOol01Goo0P004Goo00<007ooOol06Goo2@006Goo0`008Goo0`00
87oo10003Woo1`0027oo0P006goo00<007ooOol01goo0P004goo00<007ooOol00Woo00<007ooOol0
27oo00<007ooOol03Woo00<007ooOol03goo00<007ooOol03Goo0P000goo00<007ooOol05Woo00<0
07ooOol07Woo00<007ooOol0:goo00<007ooOol0@Woo00<007ooOol0Igoo0`005goo00<007ooOol0
`Woo00<007ooOol01goo000jOol00`00Oomoo`12Ool00`00Oomoo`0XOol00`00Oomoo`0QOol00`00
Oomoo`0MOol00`00Oomoo`0DOol3000DOol00`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`0;
Ool2000?Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool2000COol00`00Oomoo`0FOol7000NOol2000R
Ool3000POol3000FOol700000goo001oo`0KOol00`00Oomoo`09Ool2000BOol01000Oomoo`0037oo
00<007ooOol03Woo00<007ooOol03goo00<007ooOol02goo00<007ooOol017oo00<007ooOol05Goo
00<007ooOol07goo00<007ooOol0:Woo00<007ooOol0@goo00<007ooOol0IGoo00<007ooOol06Goo
00<007ooOol0`Goo00<007ooOol01goo000jOol00`00Oomoo`12Ool00`00Oomoo`0XOol00`00Oomo
o`0QOol00`00Oomoo`0LOol00`00Oomoo`0FOol01000Ool000004Woo00<007ooOol03goo00<007oo
Ool03Woo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol00P005Goo00<0
07ooOol04Goo1@0017oo0`007Woo0P008Woo0`0087oo0`007Goo1@006Goo00<007ooOol02goo00<0
07ooOol047oo00<007oo00003Goo00<007ooOol03Goo00<007ooOol03goo00<007ooOol02Goo0P00
1goo00<007ooOol05Woo00<007ooOol07Woo00<007ooOol0:goo00<007ooOol0@Woo00<007ooOol0
Hgoo0P0077oo00<007ooOol0`Goo00<007ooOol01goo000jOol00`00Oomoo`12Ool00`00Oomoo`0W
Ool00`00Oomoo`0ROol00`00Oomoo`0LOol00`00Oomoo`0FOol01000Oomoogoo0`003goo00<007oo
Ool03goo00<007ooOol03Goo00<007ooOol037oo00<007oo000037oo00<007ooOol03Goo00<007oo
00005goo00<007ooOol037oo1@002Goo0P0087oo00<007ooOol08Goo00<007ooOol087oo0P007Woo
00@007ooOomoo`D001Aoo`03001oogoo00aoo`80015oo`8000ioo`03001oogoo00eoo`03001oogoo
00ioo`03001oogoo00Moo`8000Uoo`03001oogoo01Ioo`03001oogoo01ioo`03001oogoo02]oo`03
001oogoo049oo`03001oogoo065oo`8001ioo`03001oogoo0<5oo`03001oogoo00Moo`00>Woo00<0
07ooOol0@Woo00<007ooOol09goo00<007ooOol08Goo00<007ooOol07Goo00<007ooOol05Woo00<0
07ooOol017oo00<007ooOol02goo00<007ooOol03goo00<007ooOol03Woo00<007ooOol02goo00D0
07ooOomoo`0000Yoo`03001oogoo00ioo`8001Uoo`03001oogoo00Aoo`L000moo`03001oogoo01io
o`03001oogoo025oo`03001oogoo021oo`03001oogoo01eoo`03001oogoo00Ioo`@000moo`03001o
ogoo00moo`03001oogoo00ioo`8000ioo`03001oogoo00eoo`03001oogoo00moo`03001oogoo00Eo
o`03001oogoo00Yoo`03001oogoo01Eoo`03001oogoo01moo`03001oogoo02Yoo`03001oogoo04=o
o`03001oogoo05Moo`8000Eoo`80025oo`03001oogoo0<1oo`03001oogoo00Moo`00>Woo00<007oo
Ool0@Woo00<007ooOol09goo00<007ooOol08Goo00<007ooOol07Goo00<007ooOol05Goo00<007oo
Ool01Woo0P002goo00<007ooOol03goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol00Woo
00<007ooOol01Woo00<007ooOol03Woo00<007oo00006Goo00<007oo000010005Woo00<007ooOol0
7Woo00<007ooOol08Goo00<007ooOol087oo00<007ooOol07Goo00<007ooOol02Woo10002goo00<0
07ooOol047oo0P003Goo00@007ooOol000ioo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo
00Aoo`03001oogoo00]oo`03001oogoo01Ioo`03001oogoo01ioo`03001oogoo02]oo`03001oogoo
049oo`03001oogoo05Ioo`<000Aoo`03001oogoo025oo`03001oogoo0<1oo`03001oogoo00Moo`00
>Woo00<007ooOol0@Woo00<007ooOol09goo00<007ooOol08Goo00<007ooOol077oo00<007ooOol0
5Woo00<007ooOol027oo0`0027oo00<007ooOol03goo00<007ooOol037oo00<007ooOol037oo00<0
07ooOol00goo00<007ooOol01Goo00<007ooOol03Goo0P000goo00<007ooOol05Goo0`006goo00<0
07ooOol07Woo00<007ooOol08Goo00<007ooOol087oo00<007ooOol07Goo00<007ooOol03Woo0`00
27oo00<007ooOol04Woo0P002Woo00<007ooOol00Woo00<007ooOol037oo00<007ooOol037oo00<0
07ooOol03Woo00@007ooOomoo`<000moo`03001oogoo01Eoo`03001oogoo01ioo`03001oogoo02]o
o`03001oogoo049oo`03001oogoo05Eoo`<0009oo`<002Aoo`03001oogoo0<1oo`03001oogoo00Mo
o`00>Woo00<007ooOol0@Woo00<007ooOol09goo00<007ooOol08Goo00<007ooOol077oo00<007oo
Ool05Woo00<007ooOol02goo0`0017oo00<007ooOol03goo00<007ooOol03Goo00<007ooOol037oo
00<007ooOol017oo00<007ooOol00goo00<007ooOol03Goo00<007ooOol00goo00<007ooOol04Woo
0`0000=oo`00Ool06goo00<007ooOol07Woo00<007ooOol08Goo00<007ooOol087oo00<007ooOol0
7Goo00<007ooOol04Goo10000goo00<007ooOol05Goo00<007ooOol01goo00<007ooOol00goo00<0
07ooOol037oo00<007ooOol037oo00<007ooOol03Woo00<007oo00004Woo00<007ooOol05Goo00<0
07ooOol07goo00<007ooOol0:Woo00<007ooOol0@goo00<007ooOol0Dgoo100000=oo`00Ool09goo
00<007ooOol0_goo00<007ooOol01goo000jOol00`00Oomoo`11Ool00`00Oomoo`0WOol00`00Oomo
o`0ROol00`00Oomoo`0LOol00`00Oomoo`0EOol00`00Oomoo`0?Ool01@00Oomoogoo00004Goo00<0
07ooOol037oo00<007ooOol037oo00<007ooOol01Woo00D007ooOomoo`0000moo`03001oogoo00Ao
o`03001oogoo00moo`<000Aoo`03001oogoo01Yoo`03001oogoo01ioo`03001oogoo025oo`03001o
ogoo021oo`03001oogoo01eoo`03001oogoo01Eoo`@001Qoo`8000Ioo`03001oogoo00Eoo`03001o
ogoo00]oo`03001oogoo00aoo`03001oogoo00eoo`<001=oo`03001oogoo01Ioo`03001oogoo01io
o`03001oogoo02]oo`03001oogoo049oo`03001oogoo059oo`H002Uoo`03001oogoo0;moo`03001o
ogoo00Moo`00>Woo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol08Goo00<007ooOol07Goo
00<007ooOol05Goo00<007ooOol047oo0P0000=oo`00Ool047oo00<007ooOol037oo00<007ooOol0
2goo00<007ooOol027oo00<007oo00003Woo0P0027oo00<007ooOol02goo0`001goo00<007ooOol0
6Woo00<007ooOol07Woo00<007ooOol08Goo00<007ooOol087oo00<007ooOol07Goo00<007ooOol0
67oo0`0067oo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol037oo00<007ooOol037oo00<0
07ooOol02goo00<007oo00005Goo00<007ooOol05Goo00<007ooOol07Woo00<007ooOol0:goo00<0
07ooOol0@Woo00<007ooOol0DGoo1@0000=oo`0000000P009Woo00<007ooOol0_goo00<007ooOol0
1goo000jOol00`00Oomoo`11Ool00`00Oomoo`0WOol00`00Oomoo`0QOol00`00Oomoo`0MOol00`00
Oomoo`0EOol00`00Oomoo`0BOol3000?Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`09
Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`08Ool3000;Ool00`00Oomoo`0IOol00`00
Oomoo`0NOol00`00Oomoo`0QOol00`00Oomoo`0POol00`00Oomoo`0MOol00`00Oomoo`0HOol00`00
Oomoo`03000FOol20002Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomo
o`0:Ool01@00Oomoogoo000057oo00<007ooOol05Goo00<007ooOol07goo00<007ooOol0:Woo00<0
07ooOol0@goo00<007ooOol0Cgoo2000:Woo00<007ooOol0_Woo00<007ooOol01goo000jOol00`00
Oomoo`11Ool00`00Oomoo`0WOol00`00Oomoo`0QOol00`00Oomoo`0LOol00`00Oomoo`0FOol00`00
Oomoo`0BOol01000Oomoo`003Woo00<007ooOol037oo00<007ooOol02goo00<007ooOol02Woo0P00
2goo0P002goo00<007ooOol01Woo0P003Woo00<007ooOol06Woo00<007ooOol07Goo00<007ooOol0
3Goo70006goo00<007ooOol07Goo00<007ooOol067oo00<007ooOol00goo0`005Goo0P002goo00<0
07ooOol02goo00<007ooOol02goo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol04Woo00<0
07ooOol05Woo00<007ooOol07Woo00<007ooOol0:Woo00<007ooOol0@goo00<007ooOol0CWoo1@00
;Woo00<007ooOol0_Woo00<007ooOol01goo000jOol00`00Oomoo`11Ool00`00Oomoo`0WOol00`00
Oomoo`0QOol00`00Oomoo`0LOol00`00Oomoo`0FOol00`00Oomoo`0BOol01000Oomoogoo0`002goo
00<007ooOol02goo00<007ooOol037oo00<007ooOol02Goo00@007ooOol000Uoo`03001oogoo00ao
o`03001oogoo00=oo`80011oo`03001oogoo01Yoo`03001oogoo019ooa/001Aoo`03001oogoo00Eo
oa`001ioo`03001oogoo01Uoo`03001oogoo00Ioo`8001Aoo`03001oogoo00Yoo`03001oogoo00]o
o`03001oogoo00]oo`03001oogoo00Eoo`<000Eoo`03001oogoo01=oo`03001oogoo01Eoo`03001o
ogoo01ioo`03001oogoo02]oo`03001oogoo049oo`03001oogoo04eoo`<0035oo`03001oogoo0;io
o`03001oogoo00Moo`00>Woo00<007ooOol0@Goo00<007ooOol09goo00<007ooOol08Goo00<007oo
Ool077oo00<007ooOol05Goo00<007ooOol04Woo00<007ooOol01Goo00<007ooOol01goo00<007oo
Ool037oo00<007ooOol02goo00<007ooOol02Goo00D007ooOomoo`0000Qoo`03001oogoo00ioo`03
001oo`000080019oo`03001oogoo01Yoo`03001oogoo00Eoo`d000]oo`03001oogoo025oo`03001o
ogoo021oo`h0015oo`03001oogoo01Uoo`03001oogoo00Qoo`<0011oo`03001oo`0000]oo`03001o
ogoo00]oo`03001oogoo00]oo`<000Aoo`03001oogoo00Moo`03001oogoo019oo`03001oogoo01Eo
o`03001oogoo01moo`03001oogoo02Yoo`03001oogoo04=oo`03001oogoo04]oo`03001oogoo03=o
o`03001oogoo0;eoo`03001oogoo00Moo`00>Woo00<007ooOol0@Goo00<007ooOol09Woo00<007oo
Ool08Goo00<007ooOol07Goo00<007ooOol05Goo00<007ooOol04Woo00<007ooOol01Woo0P001goo
00<007ooOol037oo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol017oo
00<007ooOol03goo0P005Goo00<007ooOol067oo2P0067oo00<007ooOol08Goo00<007ooOol087oo
00<007ooOol02goo2P001goo00<007ooOol067oo00<007ooOol037oo0P003Goo00D007ooOomoo`00
00]oo`03001oogoo00]oo`03001oogoo00Yoo`<000=oo`03001oogoo00Qoo`03001oogoo019oo`03
001oogoo01Ioo`03001oogoo01ioo`03001oogoo02Yoo`03001oogoo04=oo`03001oogoo04Qoo`<0
03Ioo`03001oogoo0;eoo`03001oogoo00Moo`00>Woo00<007ooOol0@Goo00<007ooOol09Woo00<0
07ooOol08Goo00<007ooOol077oo00<007ooOol05Woo00<007ooOol04Woo00<007ooOol027oo0`00
17oo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Goo00<007ooOol017oo00<007ooOol0
0Woo00<007ooOol03Woo0`005goo00<007ooOol047oo1`000Woo00<007ooOol07Goo00<007ooOol0
8Goo00<007ooOol087oo00<007ooOol05Goo20006Woo00<007ooOol03Woo0P002Woo00<007ooOol0
0goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo0`000Woo0P002goo00<007ooOol0
4goo00<007ooOol05Goo00<007ooOol07Woo00<007ooOol0:goo00<007ooOol0@Woo00<007ooOol0
Agoo00<007ooOol0=goo00<007ooOol0_Goo00<007ooOol01goo000jOol5000oOol00`00Oomoo`0V
Ool00`00Oomoo`0QOol00`00Oomoo`0LOol00`00Oomoo`0FOol00`00Oomoo`0AOol00`00Oomoo`0<
Ool200000goo001oo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`06Ool01000Oomo
o`003goo0P000Woo00<007ooOol05Goo00<007ooOol02Goo1`002Goo00<007ooOol07Goo00<007oo
Ool08Goo00<007ooOol087oo00<007ooOol077oo1`0057oo00<007ooOol047oo0P0027oo00<007oo
Ool017oo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol01goo0`0000=oo`0000003Woo00<0
07ooOol04Woo00<007ooOol05Woo00<007ooOol07Woo00<007ooOol0:Woo00<007ooOol0@goo00<0
07ooOol0A7oo0P00>goo00<007ooOol0]goo1P002Goo000jOol00`00Oomoo`11Ool00`00Oomoo`0V
Ool00`00Oomoo`0QOol00`00Oomoo`0LOol00`00Oomoo`0FOol00`00Oomoo`0AOol00`00Oomoo`0>
Ool3000=Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Ool0000>Ool00`00
Oomoo`02Ool00`00Oomoo`0EOol00`00Oomoo`02Ool7000@Ool00`00Oomoo`0MOol00`00Oomoo`0Q
Ool00`00Oomoo`0POol00`00Oomoo`0LOol00`00Oomoo`04Ool6000>Ool00`00Oomoo`0BOol20005
Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool6000?Ool00`00
Oomoo`0BOol00`00Oomoo`0FOol00`00Oomoo`0NOol00`00Oomoo`0ZOol00`00Oomoo`13Ool00`00
Oomoo`11Ool3000mOol00`00Oomoo`2lOol00`00Oomoo`07Ool003Yoo`03001oogoo045oo`03001o
ogoo02Ioo`03001oogoo025oo`03001oogoo01]oo`03001oogoo01Moo`03001oogoo015oo`03001o
ogoo00moo`03001oo`00008000Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`80
00eoo`8000Ioo`03001oogoo01Aoo`D001Moo`03001oogoo01eoo`03001oogoo025oo`03001oogoo
021oo`03001oogoo01aoo`03001oogoo00Yoo`D000Uoo`03001oogoo01Aoo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Aoo`@0009oo`03001oogoo
00eoo`03001oogoo019oo`03001oogoo01Ioo`03001oogoo01ioo`03001oogoo02Yoo`03001oogoo
04=oo`03001oogoo03moo`80041oo`03001oogoo0;aoo`03001oogoo00Moo`00>Woo00<007ooOol0
@Goo00<007ooOol09Woo00<007ooOol08Goo00<007ooOol06goo00<007ooOol05goo00<007ooOol0
4Goo00<007ooOol03Woo00<007ooOol00goo0P001goo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol027oo0P002goo0P0027oo00<007ooOol03goo1P006goo00<007ooOol07Goo00<007ooOol0
8Goo00<007ooOol087oo00<007ooOol077oo00<007ooOol03goo1@000goo00<007ooOol05Woo0P00
0Woo00<007ooOol01goo00<007ooOol027oo00<007ooOol02Woo00<007ooOol00goo2`003Goo00<0
07ooOol04Goo00<007ooOol05Woo00<007ooOol07Woo00<007ooOol0:goo00<007ooOol0@goo00<0
07ooOol0?7oo0P00@goo00<007ooOol0^goo00<007ooOol01goo000jOol00`00Oomoo`10Ool00`00
Oomoo`0WOol00`00Oomoo`0QOol00`00Oomoo`0KOol00`00Oomoo`0FOol00`00Oomoo`0AOol00`00
Oomoo`0?Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool01000Oomoo`002Goo00<007ooOol027oo00<007ooOol02goo10001Goo00<007ooOol0
6Goo00<007ooOol07Goo00<007ooOol08Goo00<007ooOol087oo00<007ooOol077oo00<007ooOol0
57oo1@006Goo0P002Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol00Woo200000=oo`00
Ool03Woo00<007ooOol04Woo00<007ooOol05Woo00<007ooOol07Woo00<007ooOol0:Woo00<007oo
Ool0@goo00<007ooOol0>Woo0P00AGoo00<007ooOol0^goo00<007ooOol01goo000jOol00`00Oomo
o`10Ool00`00Oomoo`0WOol00`00Oomoo`0POol00`00Oomoo`0LOol00`00Oomoo`0FOol00`00Oomo
o`0AOol00`00Oomoo`0?Ool00`00Oomoo`06Ool30003Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`07Ool01@00Oomoogoo00001goo0P002goo00<007ooOol027oo0`002Goo00<007ooOol0
6Goo00<007ooOol07Goo00<007ooOol08Goo00<007ooOol087oo00<007ooOol077oo00<007ooOol0
5goo00<007oo00000`005Woo0P002Woo00<007ooOol027oo00<007ooOol02Woo00<007oo00000`00
1goo00<007ooOol03Goo00<007ooOol04Woo00<007ooOol05Woo00<007ooOol07Woo00<007ooOol0
:Woo00<007ooOol0@goo00<007ooOol0=goo0`00Agoo00<007ooOol0^goo00<007ooOol01goo000j
Ool00`00Oomoo`10Ool00`00Oomoo`0WOol00`00Oomoo`0POol00`00Oomoo`0LOol00`00Oomoo`0F
Ool00`00Oomoo`0AOol00`00Oomoo`0?Ool00`00Oomoo`09Ool3000<Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool3000=
Ool00`00Oomoo`0HOol00`00Oomoo`0MOol00`00Oomoo`0QOol00`00Oomoo`0POol00`00Oomoo`0L
Ool00`00Oomoo`0GOol00`00Oomoo`03Ool3000COol00`00Ool0000:Ool00`00Oomoo`08Ool00`00
Oomoo`09Ool2000<Ool00`00Oomoo`0<Ool00`00Oomoo`0BOol00`00Oomoo`0FOol00`00Oomoo`0N
Ool00`00Oomoo`0ZOol00`00Oomoo`13Ool00`00Oomoo`0eOol2001;Ool00`00Oomoo`2jOol00`00
Oomoo`07Ool003Yoo`03001oogoo041oo`03001oogoo02Moo`03001oogoo021oo`03001oogoo01]o
o`03001oogoo01Moo`03001oogoo015oo`03001oogoo00ioo`03001oogoo00aoo`<000Yoo`03001o
ogoo00Qoo`03001oogoo00Moo`03001oogoo00=oo`04001oogooOol2000?Ool01000Oomoogoo0`00
47oo00<007ooOol06Goo00<007ooOol077oo00<007ooOol08Goo00<007ooOol087oo00<007ooOol0
77oo00<007ooOol05goo00<007ooOol01Woo0`003goo00@007ooOol000Yoo`03001oogoo00Qoo`03
001oogoo00Qoo`8000eoo`03001oogoo00eoo`03001oogoo015oo`03001oogoo01Ioo`03001oogoo
01ioo`03001oogoo02]oo`03001oogoo04=oo`03001oogoo039oo`8004eoo`03001oogoo0;Yoo`03
001oogoo00Moo`00>Woo00<007ooOol0@7oo00<007ooOol09Woo00<007ooOol08Goo00<007ooOol0
6goo00<007ooOol05goo00<007ooOol04Goo00<007ooOol03Woo00<007ooOol037oo00@007ooOol0
00Qoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Eoo`03001oo`00015oo`@001=oo`03
001oogoo01Uoo`03001oogoo01aoo`03001oogoo025oo`03001oogoo021oo`03001oogoo01aoo`03
001oogoo01Moo`03001oogoo00Uoo`<000aoo`05001oogooOol0000:Ool00`00Oomoo`08Ool00`00
Oomoo`06Ool01000Oomoo`0037oo00<007ooOol03Goo00<007ooOol04Goo00<007ooOol05Woo00<0
07ooOol07Woo00<007ooOol0:goo00<007ooOol0@goo00<007ooOol0<7oo0P00Cgoo00<007ooOol0
^Woo00<007ooOol01goo000jOol00`00Oomoo`10Ool00`00Oomoo`0VOol00`00Oomoo`0QOol00`00
Oomoo`0KOol00`00Oomoo`0FOol00`00Oomoo`0AOol00`00Oomoo`0?Ool00`00Oomoo`0;Ool00`00
Oomoo`02Ool30005Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0>
Ool3000FOol00`00Oomoo`0IOol00`00Oomoo`0LOol00`00Oomoo`0QOol00`00Oomoo`0POol00`00
Oomoo`0LOol00`00Oomoo`0GOol00`00Oomoo`0<Ool30009Ool00`00Oomoo`02Ool00`00Oomoo`08
Ool00`00Oomoo`07Ool00`00Oomoo`03Ool30003Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00
Oomoo`0BOol00`00Oomoo`0FOol00`00Oomoo`0NOol00`00Oomoo`0ZOol00`00Oomoo`13Ool00`00
Oomoo`0]Ool3001BOol00`00Oomoo`2iOol00`00Oomoo`07Ool003Yoo`03001oogoo041oo`03001o
ogoo02Ioo`03001oogoo025oo`03001oogoo01]oo`03001oogoo01Ioo`03001oogoo015oo`03001o
ogoo00moo`03001oogoo00]oo`03001oogoo00Eoo`8000=oo`8000Uoo`03001oogoo00Eoo`03001o
ogoo00Moo`03001oo`0000eoo`80009oo`03001oogoo01Aoo`03001oogoo01Uoo`03001oogoo015o
oe<001eoo`03001oogoo01Qoo`03001oogoo00moo`8000Ioo`03001oogoo00Aoo`03001oogoo00Mo
o`03001oogoo00Qoo`05001oogooOol00006Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomo
o`0BOol00`00Oomoo`0FOol00`00Oomoo`0NOol00`00Oomoo`0ZOol00`00Oomoo`13Ool00`00Oomo
o`0[Ool2001EOol00`00Oomoo`2iOol00`00Oomoo`07Ool003Yoo`03001oogoo041oo`03001oogoo
02Ioo`03001oogoo025oo`03001oogoo01]oo`03001oogoo01Ioo`03001oogoo015oo`03001oogoo
00moo`03001oogoo00]oo`03001oogoo00Moo`H000Moo`03001oogoo00Ioo`03001oogoo00Ioo`05
001oogooOol0000:Ool20004Ool00`00Oomoo`0DOol00`00Oomoo`0IOol00`00Oomoo`04Ool=000;
Ool00`00Oomoo`0QOol00`00Oomoo`0POol>000@Ool00`00Oomoo`0GOol00`00Oomoo`0BOol20004
Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`07Ool01000Oomoo`0027oo00<007ooOol0
2Woo00<007ooOol037oo00<007ooOol04Woo00<007ooOol05Woo00<007ooOol07Woo00<007ooOol0
:goo00<007ooOol0@Woo00<007ooOol0:7oo0`00Egoo00<007ooOol0^Goo00<007ooOol01goo000j
Ool00`00Oomoo`10Ool00`00Oomoo`0VOol00`00Oomoo`0QOol00`00Oomoo`0KOol00`00Oomoo`0F
Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`0<Ool00`00Oomoo`09Ool50006Ool00`00
Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`05Ool20007Ool00`00Oomoo`0D
Ool00`00Oomoo`0AOol>000HOol00`00Oomoo`0QOol00`00Oomoo`0OOol00`00Oomoo`0<Ool=0003
Ool00`00Oomoo`0GOol00`00Oomoo`0DOol20002Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00
Oomoo`08Ool20009Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool00`00Oomoo`0AOol00`00Oomoo`0F
Ool00`00Oomoo`0NOol00`00Oomoo`0[Ool00`00Oomoo`13Ool00`00Oomoo`0UOol2001JOol00`00
Oomoo`2iOol00`00Oomoo`07Ool003Yoo`03001oogoo041oo`03001oogoo02Ioo`03001oogoo025o
o`03001oogoo01]oo`03001oogoo01Ioo`03001oogoo015oo`03001oogoo00ioo`03001oogoo00]o
o`03001oogoo00Yoo`03001oo`0000<000Aoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo009oo`<000Uoo`03001oogoo01Aoo`03001oogoo00Aoo`d000Moo`03001oogoo
01aoo`03001oogoo025oo`03001oogoo01moo`03001oogoo01Uoo`h000moo`03001oogoo01Ioo`80
00Yoo`03001oogoo00Ioo`03001oogoo00Eoo`<000Yoo`03001oogoo00]oo`03001oogoo00aoo`03
001oogoo015oo`03001oogoo01Ioo`03001oogoo01ioo`03001oogoo02]oo`03001oogoo04=oo`03
001oogoo02=oo`8005aoo`03001oogoo0;Uoo`03001oogoo00Moo`00>Woo00<007ooOol0@7oo00<0
07ooOol09Woo00<007ooOol087oo00<007ooOol06goo00<007ooOol05goo00<007ooOol04Goo00<0
07ooOol03Woo00<007ooOol02goo00<007ooOol02Goo00@007ooOomoo`D0009oo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo008000aoo`03001oogoo019oo`T001Aoo`03
001oogoo01aoo`03001oogoo025oo`03001oogoo01moo`03001oogoo01aoo`03001oogoo00Qoo`X0
00Eoo`03001oogoo01Moo`<000Uoo`03001oogoo00Eoo`03001oogoo00Aoo`05001oogooOol0000:
Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0AOol00`00Oomoo`0FOol00`00Oomoo`0N
Ool00`00Oomoo`0[Ool00`00Oomoo`13Ool00`00Oomoo`0QOol2001OOol00`00Oomoo`2hOol00`00
Oomoo`07Ool003Yoo`03001oogoo041oo`03001oogoo02Ioo`03001oogoo021oo`03001oogoo01]o
o`03001oogoo01Ioo`03001oogoo015oo`03001oogoo00moo`03001oogoo00]oo`03001oogoo00Uo
o`03001oogoo00P000Qoo`03001oogoo00Aoo`03001oogoo00Ioo`<000ioo`03001oogoo00eoo`D0
009oo`03001oogoo01Qoo`03001oogoo01aoo`03001oogoo025oo`03001oogoo01moo`03001oogoo
01aoo`03001oogoo019oo`L001Qoo`03001oogoo008000Qoo`03001oogoo00Eoo`03001oogoo009o
o`03001oogoo009oo`03001oogoo00Qoo`03001oogoo00Yoo`03001oogoo00aoo`03001oogoo019o
o`03001oogoo01Ioo`03001oogoo01ioo`03001oogoo02Yoo`03001oogoo04=oo`03001oogoo01io
o`<0065oo`03001oogoo0;Qoo`03001oogoo00Moo`00>Woo00<007ooOol0@7oo00<007ooOol09Woo
00<007ooOol087oo00<007ooOol06goo00<007ooOol05Woo00<007ooOol04Goo00<007ooOol03Woo
00<007ooOol02goo00<007ooOol02Goo300027oo00<007ooOol00goo00<007ooOol01goo0P003goo
00<007ooOol02Goo10001goo00<007ooOol067oo00<007ooOol077oo00<007ooOol08Goo00<007oo
Ool07goo00<007ooOol077oo00<007ooOol05goo00<007oo00000`004goo00<007ooOol00goo00<0
07ooOol01Woo00<007ooOol017oo00<007ooOol00P001Woo00<007ooOol01goo00<007ooOol02goo
00<007ooOol037oo00<007ooOol04Goo00<007ooOol05Woo00<007ooOol07Woo00<007ooOol0:goo
00<007ooOol0@goo00<007ooOol06goo0P00I7oo00<007ooOol0^7oo00<007ooOol01goo000jOol0
0`00Oomoo`10Ool00`00Oomoo`0VOol00`00Oomoo`0POol00`00Oomoo`0KOol00`00Oomoo`0FOol0
0`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool01000Oomoogoo2@00
1Woo00<007ooOol00goo00<007ooOol01goo00<007oo000047oo00<007ooOol00Woo1P002goo00<0
07ooOol067oo00<007ooOol077oo00<007ooOol08Goo00<007ooOol07goo00<007ooOol077oo00<0
07ooOol05goo00<007ooOol00goo10003goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol0
17oo0P0027oo00<007ooOol027oo00<007ooOol02Woo00<007ooOol037oo00<007ooOol04Goo00<0
07ooOol05Woo00<007ooOol07Woo00<007ooOol0:goo00<007ooOol0@goo00<007ooOol05goo1000
IWoo00<007ooOol0^7oo00<007ooOol01goo000jOol00`00Oomoo`10Ool00`00Oomoo`0VOol00`00
Oomoo`0POol00`00Oomoo`0KOol00`00Oomoo`0FOol00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00
Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`07Ool50004Ool00`00Oomoo`03Ool00`00Oomoo`07
Ool00`00Ool00003Ool00`00Oomoo`08Ool7000AOol00`00Oomoo`0HOol00`00Oomoo`0LOol00`00
Oomoo`0QOol00`00Oomoo`0OOol00`00Oomoo`0LOol00`00Oomoo`0GOol00`00Oomoo`07Ool5000:
Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool20009Ool00`00Oomoo`08Ool00`00
Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0AOol00`00Oomoo`0FOol00`00Oomoo`0NOol00`00
Oomoo`0[Ool00`00Oomoo`13Ool00`00Oomoo`0DOol3001ZOol00`00Oomoo`2hOol00`00Oomoo`07
Ool003Yoo`03001oogoo041oo`03001oogoo02Ioo`03001oogoo021oo`03001oogoo01]oo`03001o
ogoo01Ioo`03001oogoo015oo`03001oogoo00ioo`03001oogoo00]oo`03001oogoo00Uoo`03001o
ogoo00Moo`03001oogoo009oo`<00003Ool007oo00=oo`03001oogoo00Moo`80009oo`04001oogoo
0005Ool50002Ool00`00Oomoo`0COol00`00Oomoo`0HOol00`00Oomoo`0LOol00`00Oomoo`0QOol0
0`00Oomoo`0OOol00`00Oomoo`0LOol00`00Oomoo`0GOol00`00Oomoo`0<Ool50004Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool01`00Oomoogoo001oo`0000Uoo`03001oogoo00Qoo`03001oogoo00Yo
o`03001oogoo00aoo`03001oogoo015oo`03001oogoo01Ioo`03001oogoo01ioo`03001oogoo02]o
o`03001oogoo04=oo`03001oogoo019oo`8006eoo`03001oogoo0;Qoo`03001oogoo00Moo`00>Woo
00<007ooOol0@7oo00<007ooOol09Woo00<007ooOol087oo00<007ooOol06goo00<007ooOol05Woo
00<007ooOol04Goo00<007ooOol03Woo00<007ooOol02goo00<007ooOol02Goo00<007ooOol01Woo
00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Woo00<007oo00000Woo00<007oo00001P00
1goo00<007ooOol04goo00<007ooOol067oo00<007ooOol077oo00<007ooOol08Goo00<007ooOol0
7goo00<007ooOol077oo00<007ooOol05goo00<007ooOol04Goo1@002Goo00<007ooOol01Goo00@0
07oo000000=oo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Yoo`03001oogoo00eoo`03
001oogoo011oo`03001oogoo01Ioo`03001oogoo01ioo`03001oogoo02]oo`03001oogoo04Aoo`03
001oogoo00eoo`@006moo`03001oogoo0;Qoo`03001oogoo00Moo`00>Woo00<007ooOol0@7oo00<0
07ooOol09Woo00<007ooOol087oo00<007ooOol06goo00<007ooOol05Woo00<007ooOol04Goo00<0
07ooOol03Woo00<007ooOol02goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol01Woo0`00
0goo00<007ooOol01Woo00D007ooOol007oo00@000aoo`03001oogoo01=oo`03001oogoo01Qoo`03
001oogoo01aoo`03001oogoo025oo`03001oogoo01moo`03001oogoo01aoo`03001oogoo01Ioo`03
001oogoo01Ioo`H000Aoo`03001oogoo00Eoo`8000Eoo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Yoo`03001oogoo00eoo`03001oogoo011oo`03001oogoo01Ioo`03001oogoo01ioo`03
001oogoo02aoo`03001oogoo04=oo`03001oogoo009oo`8000Ioo`<007Aoo`03001oogoo0;Moo`03
001oogoo00Moo`00>Woo00<007ooOol0@7oo00<007ooOol09Woo00<007ooOol087oo00<007ooOol0
6goo00<007ooOol05Woo00<007ooOol04Goo00<007ooOol03Woo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol01goo00<007ooOol01Woo00H007ooOol007oo0008Ool01000Oomoogoo0`0000=o
o`00Ool037oo00<007ooOol04goo00<007ooOol067oo00<007ooOol077oo00<007ooOol08Goo00<0
07ooOol07goo00<007ooOol077oo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol00goo0P00
0goo00<007ooOol00goo00<007oo00001Goo00<007ooOol01goo00<007ooOol027oo00<007ooOol0
2Goo00<007ooOol03Goo00<007ooOol04Goo00<007ooOol05Woo00<007ooOol07Woo00<007ooOol0
:goo00<007ooOol0@goo00<007ooOol00P0017oo1000Mgoo00<007ooOol0]goo00<007ooOol01goo
000jOol00`00Oomoo`10Ool00`00Oomoo`0VOol00`00Oomoo`0POol00`00Oomoo`0KOol00`00Oomo
o`0FOol00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`07Ool00`00Oomoo`05Ool00`00Oomoo`02Ool20008Ool01000Oomoogoo1@003Goo00<007ooOol0
4goo00<007ooOol067oo00<007ooOol077oo00<007ooOol0=`0037oo00<007ooOol077oo00<007oo
Ool05Woo00<007ooOol05Woo00<007ooOol017oo00D007ooOomoo`0000Aoo`04001oogoo0006Ool0
0`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`0=Ool00`00Oomoo`0AOol0
0`00Oomoo`0FOol00`00Oomoo`0NOol00`00Oomoo`0[Ool00`00Oomoo`13Ool40003Ool2001kOol0
0`00Oomoo`2gOol00`00Oomoo`07Ool003Yoo`03001oogoo041oo`03001oogoo02Ioo`03001oogoo
021oo`03001oogoo01]oo`03001oogoo01Ioo`03001oogoo015oo`03001oogoo00ioo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`<000Eoo`06
001oogooOol007oo10003Goo00<007ooOol04goo00<007ooOol04Goo:@008Goo00<007ooOol04goo
=P003Woo00<007ooOol05Goo00<007ooOol01Woo00D007ooOomoo`00009oo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00eoo`03
001oogoo015oo`03001oogoo01Ioo`03001oogoo01ioo`03001oogoo02]oo`03001oogoo04=oo`L0
07eoo`03001oogoo0;Moo`03001oogoo00Moo`00>Woo00<007ooOol0@7oo00<007ooOol09Woo00<0
07ooOol087oo00<007ooOol06goo00<007ooOol05Woo00<007ooOol04Goo00<007ooOol03Woo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol00Woo00D0
07ooOomoo`0000=oo`05001oogooOol00002Ool4000=Ool00`00Oomoo`0=OolJ0007Ool00`00Oomo
o`0LOol00`00Oomoo`0QOol00`00Oomoo`0OOol00`00Oomoo`0LOol00`00Oomoo`08Ool=00000goo
001oo`0FOol00`00Oomoo`07Ool01000Oomoogoo0P001Goo00<007ooOol00goo00<007ooOol01Woo
00<007ooOol027oo00<007ooOol02Goo00<007ooOol03Goo00<007ooOol04Goo00<007ooOol05Woo
00<007ooOol07Woo00<007ooOol0:goo00<007ooOol0@Goo1`00Ogoo00<007ooOol0]goo00<007oo
Ool01goo000jOol00`00Oomoo`10Ool00`00Oomoo`0UOol00`00Oomoo`0POol00`00Oomoo`0KOol0
0`00Oomoo`0FOol00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool0
0`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOomoo`@000eoo`03001oo`0000d000Ioo`03001oogoo01Qoo`03001oogoo01aoo`03001o
ogoo025oo`03001oogoo01moo`03001oogoo01aoo`03001oogoo01Eoo`h000]oo`03001oogoo00Mo
o`05001oogooOol00006Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0AOol00`00Oomoo`0FOol00`00Oomoo`0NOol00`00Oomo
o`0/Ool00`00Oomoo`0nOol<001mOol00`00Oomoo`2fOol00`00Oomoo`07Ool003Yoo`03001oogoo
041oo`03001oogoo02Eoo`03001oogoo021oo`03001oogoo01]oo`03001oogoo01Ioo`03001oogoo
015oo`03001oogoo00ioo`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo
00Eoo`03001oogoo00=oo`03001oogoo00=oo`8000=oo`03001oogoo009oo`<000Eoo`X001Eoo`03
001oogoo01Moo`03001oogoo01aoo`03001oogoo025oo`03001oogoo01moo`03001oogoo01aoo`03
001oogoo01Ioo`03001oogoo00Yoo`d000Uoo`05001oo`00Ool00006Ool00`00Oomoo`03Ool00`00
Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0AOol00`00
Oomoo`0FOol00`00Oomoo`0NOol00`00Oomoo`0/Ool00`00Oomoo`0jOol:0023Ool00`00Oomoo`2f
Ool00`00Oomoo`07Ool003Yoo`03001oogoo041oo`03001oogoo02Eoo`03001oogoo021oo`03001o
ogoo01]oo`03001oogoo01Ioo`03001oogoo015oo`03001oogoo00ioo`03001oogoo00]oo`03001o
ogoo00Uoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=oo`05001o
o`00Ool00005Ool80009Ool00`00Oomoo`0COol00`00Oomoo`0GOol00`00Oomoo`0LOol00`00Oomo
o`0QOol00`00Oomoo`0OOol00`00Oomoo`0LOol00`00Oomoo`0FOol00`00Oomoo`0EOol00`00Ool0
00060003Ool01@00Oomoogoo00001Goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol01goo
00<007ooOol02Woo00<007ooOol03Goo00<007ooOol047oo00<007ooOol05Woo00<007ooOol07Woo
00<007ooOol0;7oo00<007ooOol0=goo0`002Woo00<007ooOol0P7oo00<007ooOol0]Woo00<007oo
Ool01goo000jOol00`00Oomoo`10Ool00`00Oomoo`0UOol00`00Oomoo`0POol00`00Oomoo`0KOol0
0`00Oomoo`0FOol00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool0
0`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`0017oo
10003goo00<007ooOol04goo00<007ooOol05goo00<007ooOol077oo00<007ooOol08Goo00<007oo
Ool07goo00<007ooOol077oo00<007ooOol05Woo00<007ooOol05Goo00<007ooOol01Goo00<007oo
Ool00P000goo00<007ooOol00goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01goo00<0
07ooOol02Woo00<007ooOol03Goo00<007ooOol047oo00<007ooOol05Woo00<007ooOol07Woo00<0
07ooOol0;7oo00<007ooOol0=7oo0`003Goo00<007ooOol0P7oo00<007ooOol0]Woo00<007ooOol0
1goo000jOol00`00Oomoo`10Ool00`00Oomoo`0UOol00`00Oomoo`0POol00`00Oomoo`0KOol00`00
Oomoo`0FOol00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Oomoogoo0P000goo
00@007ooOol000moo`03001oogoo01=oo`03001oogoo01Moo`03001oogoo01aoo`03001oogoo025o
o`03001oogoo01moo`03001oogoo01aoo`03001oogoo01Ioo`03001oogoo01Eoo`03001oogoo00Io
o`80009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`08Ool0
0`00Oomoo`09Ool00`00Oomoo`0=Ool00`00Oomoo`0AOol00`00Oomoo`0FOol00`00Oomoo`0NOol0
0`00Oomoo`0[Ool00`00Oomoo`0aOol3000@Ool00`00Oomoo`20Ool00`00Oomoo`2fOol00`00Oomo
o`07Ool003Yoo`03001oogoo041oo`03001oogoo02Eoo`03001oogoo021oo`03001oogoo01]oo`03
001oogoo01Ioo`03001oogoo015oo`03001oogoo00ioo`03001oogoo00Yoo`03001oogoo00Uoo`03
001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=oo`04001oogoo0002Ool0
0`00Ool00003Ool00`00Oomoo`0=Ool00`00Oomoo`0COol00`00Oomoo`0GOol00`00Oomoo`0LOol0
0`00Oomoo`0QOol00`00Oomoo`0OOol00`00Oomoo`0LOol00`00Oomoo`0FOol00`00Oomoo`0EOol0
0`00Oomoo`05Ool30002Ool01@00Oomoogoo000017oo00<007ooOol00Woo10001goo00<007ooOol0
1goo00<007ooOol02Goo00<007ooOol03Goo00<007ooOol04Goo00<007ooOol05Woo00<007ooOol0
7Woo00<007ooOol0;7oo00<007ooOol0;7oo10004goo00<007ooOol0PGoo00<007ooOol0]Goo00<0
07ooOol01goo000jOol00`00Oomoo`10Ool00`00Oomoo`0UOol00`00Oomoo`0POol00`00Oomoo`0K
Ool00`00Oomoo`0FOol00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`0:Ool00`00Oomoo`09
Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Oomoo`00
17oo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol04goo00<007ooOol05goo00<007ooOol0
77oo00<007ooOol08Goo00<007ooOol07goo00<007ooOol077oo00<007ooOol05Woo00<007ooOol0
5Goo00<007ooOol017oo00@007ooOol000=oo`05001oogooOol00002Ool800000goo001oo`06Ool0
0`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`0=Ool00`00Oomoo`0AOol00`00Oomoo`0FOol0
0`00Oomoo`0NOol00`00Oomoo`0/Ool00`00Oomoo`0XOol4000HOol00`00Oomoo`20Ool00`00Oomo
o`2eOol00`00Oomoo`07Ool003Yoo`D003ioo`03001oogoo02Eoo`03001oogoo021oo`03001oogoo
01]oo`03001oogoo01Ioo`03001oogoo015oo`03001oogoo00ioo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oo`0000@000Aoo`04001oogoo0004Ool00`00
Ool00003Ool00`00Oomoo`0=Ool00`00Oomoo`0COol00`00Oomoo`0GOol00`00Oomoo`0LOol00`00
Oomoo`0QOol00`00Oomoo`0OOol00`00Oomoo`0LOol00`00Oomoo`0FOol00`00Oomoo`0EOol00`00
Oomoo`04Ool01@00Oomoogoo00000goo00<007oo0000200017oo00<007ooOol01Goo00<007ooOol0
1goo00<007ooOol02Goo00<007ooOol03Goo00<007ooOol04Goo00<007ooOol05Woo00<007ooOol0
7Woo00<007ooOol0;7oo00<007ooOol097oo100077oo00<007ooOol0P7oo00<007ooOol0/7oo1P00
2Goo000jOol00`00Oomoo`10Ool00`00Oomoo`0UOol00`00Oomoo`0POol00`00Oomoo`0KOol00`00
Oomoo`0FOol00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`02Ool800000goo001oo`03Ool00`00Oomoo`3o000:
0002Ool90002Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`0=Ool0
0`00Oomoo`0AOol00`00Oomoo`0FOol00`00Oomoo`0NOol00`00Oomoo`0/Ool00`00Oomoo`0MOol7
000POol00`00Oomoo`20Ool00`00Oomoo`2eOol00`00Oomoo`07Ool003Yoo`03001oogoo041oo`03
001oogoo02Eoo`03001oogoo021oo`03001oogoo01]oo`03001oogoo01Ioo`03001oogoo015oo`03
001oogoo00ioo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Aoo`03
001oogoo00=oo`03001oo`000?l000h000=oo`05001oogooOol00003Ool01000Oomoogoo100000=o
o`0000001@000goo00<007ooOol01goo00<007ooOol02Goo00<007ooOol03Goo00<007ooOol04Goo
00<007ooOol05Woo00<007ooOol07Woo00<007ooOol0;7oo00<007ooOol05goo1P009goo00<007oo
Ool0P7oo00<007ooOol0]Goo00<007ooOol01goo000jOol00`00Oomoo`10Ool00`00Oomoo`0UOol0
0`00Oomoo`0POol00`00Oomoo`0KOol00`00Oomoo`0FOol00`00Oomoo`0AOol00`00Oomoo`0>Ool0
0`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Ool0000<0004
Ool00`00Oomoo`3o00010003Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`<00003Ool0
07oo00=oo`D000Qoo`03001oogoo00Uoo`03001oogoo00eoo`03001oogoo015oo`03001oogoo01Io
o`03001oogoo01ioo`03001oogoo02aoo`03001oogoo011oo`L002eoo`03001oogoo081oo`03001o
ogoo0;Eoo`03001oogoo00Moo`00>Woo00<007ooOol0@7oo00<007ooOol09Goo00<007ooOol087oo
00<007ooOol06goo00<007ooOol05Woo00<007ooOol04Goo00<007ooOol03Woo00<007ooOol02Woo
00<007ooOol02Goo00<007ooOol01Woo00<007oo00001P000goo1`000Woo00<007ooOol00Woo00<0
07ooOol0o`000@000goo00D007ooOomoo`0000=oo`05001oogooOol00005Ool20007Ool00`00Ool0
00050002Ool00`00Oomoo`09Ool00`00Oomoo`0=Ool00`00Oomoo`0AOol00`00Oomoo`0FOol00`00
Oomoo`0NOol00`00Oomoo`0TOol20006Ool00`00Oomoo`09Ool7000dOol00`00Oomoo`21Ool00`00
Oomoo`2dOol00`00Oomoo`07Ool003Yoo`03001oogoo041oo`03001oogoo02Eoo`03001oogoo021o
o`03001oogoo01]oo`03001oogoo01Ioo`03001oogoo015oo`03001oogoo00ioo`03001oogoo00]o
o`03001oogoo00Qoo`03001oogoo009oo`H000Ioo`03001oogoo00@000=oo`04001oogoo0004Ool0
0`00Oomoo`3o00010003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Eoo`03001oogoo00Eo
o`03001oogoo00Ioo`H000Qoo`03001oogoo00eoo`03001oogoo015oo`03001oogoo01Ioo`03001o
ogoo01ioo`03001oogoo025oo`<000Qoo`04001oogooOol8000lOol00`00Oomoo`20Ool00`00Oomo
o`2dOol00`00Oomoo`07Ool003Yoo`03001oogoo041oo`03001oogoo02Eoo`03001oogoo021oo`03
001oogoo01]oo`03001oogoo01Ioo`03001oogoo015oo`03001oogoo00ioo`03001oogoo00]oo`03
001oogoo00Ioo`L000Aoo`03001oogoo00Eoo`04001oo`000002Ool01@00Oomoogoo00000Woo00<0
07ooOol00Woo00<007ooOol0o`000@000goo00D007ooOomoo`0000=oo`05001oogooOol00005Ool0
0`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`02Ool700000goo001oo`0>Ool00`00Oomoo`0A
Ool00`00Oomoo`0FOol00`00Oomoo`0NOol00`00Oomoo`0NOol40006Ool80014Ool00`00Oomoo`20
Ool00`00Oomoo`2dOol00`00Oomoo`07Ool003Yoo`03001oogoo041oo`03001oogoo02Eoo`03001o
ogoo021oo`03001oogoo01]oo`03001oogoo01Ioo`03001oogoo015oo`03001oogoo00ioo`03001o
ogoo00]oo`04001oogooOol50002Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`03Ool0
1@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol0o`000@000goo00D007ooOomoo`0000=o
o`05001oogooOol00005Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`09Ool7000:Ool0
0`00Oomoo`0AOol00`00Oomoo`0FOol00`00Oomoo`0NOol00`00Oomoo`0KOol=0004Ool00`00Oomo
o`15Ool00`00Oomoo`20Ool00`00Oomoo`2dOol00`00Oomoo`07Ool003Yoo`03001oogoo041oo`03
001oogoo02Eoo`03001oogoo021oo`03001oogoo01]oo`03001oogoo01Ioo`03001oogoo015oo`03
001oogoo00ioo`03001oogoo00Moo`P000Moo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo
00=oo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`3o00010003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000Eoo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Yoo`03
001oogoo00=oo`X001Aoo`03001oogoo00]oo`@000Moo`03001oogoo01ioo`03001oogoo01Aooa00
00Qoo`03001oogoo04Eoo`03001oogoo081oo`03001oogoo0;Aoo`03001oogoo00Moo`00>Woo00<0
07ooOol0@7oo00<007ooOol09Goo00<007ooOol087oo00<007ooOol06goo00<007ooOol05Goo0`00
4goo00<007ooOol03Woo2@0017oo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol017oo00<0
07ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol00002Oooo00010003Ool01000Oomoo`00
0goo00D007ooOomoo`0000Ioo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Uoo`03001o
ogoo00eoo`/000Uoo`03001oogoo00Ioo`P000Uoo`03001oogoo01moo`03001oogoo00Ioo`d000Yo
o`P000Moo`03001oogoo04Aoo`03001oogoo085oo`03001oogoo0;=oo`03001oogoo00Moo`00>Woo
00<007ooOol0@7oo00<007ooOol09Goo00<007ooOol00Woo0`006goo00<007ooOol06goo00<007oo
Ool05Woo1P003goo00<007ooOol01Goo2P0037oo00<007ooOol02Goo00<007ooOol01Woo00<007oo
Ool017oo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol00002Oooo00010003Ool0
1000Oomoo`000goo00D007ooOomoo`0000Ioo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo
00Uoo`03001oogoo00eoo`03001oogoo00QooaP000]oo`03001oogoo01Iooa8001eoo`<000Ioo`03
001oogoo04Aoo`03001oogoo085oo`03001oogoo0;=oo`03001oogoo00Moo`00>Woo00<007ooOol0
@7oo00<007ooOol09Goo00<007ooOol017oo1@005goo00<007ooOol06goo00<007ooOol05Woo00<0
07ooOol01`001goo30002Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01Woo00<007oo
Ool017oo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol00002Oooo00010003Ool0
1000Oomoo`000goo00D007ooOomoo`0000Ioo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo
00Uoo`03001oogoo00eoo`03001oogoo015oo`03001oogoo00Aoob`000Uoo`03001oogoo02aoo`03
001oogoo04Aoo`03001oogoo085oo`03001oogoo0;=oo`03001oogoo00Moo`00>Woo00<007ooOol0
9WooB0000goo1`004goo00<007ooOol06goo00<007ooOol057oo4`0017oo00<007ooOol03Woo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00goo00D0
07ooOomoo`0000=oo`05001oogooOol00002Oooo00010003Ool01000Oomoo`000goo00D007ooOomo
o`0000Ioo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00eoo`03001o
ogoo015oo`03001oogoo00Qoo`D000Yoo`03001oogoo01moo`03001oogoo02aoo`03001oogoo04Ao
o`03001oogoo085oo`03001oogoo0;=oo`03001oogoo00Moo`00>Woo00<007ooOol0@7oo00<007oo
Ool09Goo00<007ooOol00gooDP000Woo00<007oo00001P0037oo00<007ooOol03Woo00<007ooOol0
2Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00goo00D007ooOomo
o`0000=oo`05001oogooOol00002Oooo00010003Ool01000Oomoo`000goo00D007ooOomoo`0000Io
o`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00eoo`03001oogoo015o
o`03001oogoo00]oo`<000Uoo`03001oogoo01moo`03001oogoo02aoo`03001oogoo04Aoo`03001o
ogoo085oo`03001oogoo0;=oo`03001oogoo00Moo`00>Woo00<007ooOol0@7oo00<007ooOol09Goo
00<007ooOol01Goo1`0057oo00<007ooOol06goo00<007ooOol05Woo1@0047oo00<007ooOol03Woo
00<007ooOol02goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol00goo
00<007oo00000P000Woo00D007ooOomoo`00009oool0004000=oo`04001oogoo0003Ool01@00Oomo
ogoo00001Goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol02Woo00<007ooOol03Goo00<0
07ooOol04Goo00<007ooOol03Woo00<007ooOol01Woo00<007ooOol07goo00<007ooOol0;7oo00<0
07ooOol0AGoo00<007ooOol0P7oo00<007ooOol0/goo00<007ooOol01goo000jOol00`00Oomoo`10
Ool00`00Oomoo`0UOol00`00Oomoo`03Ool5000HOol00`00Oomoo`0KOol00`00Oomoo`0EOol2000D
Ool00`00Oomoo`0>Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`05
Ool00`00Oomoo`03Ool00`00Oomoo`3o000I00000goo001oo`04Ool00`00Oomoo`05Ool00`00Oomo
o`07Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool00`00Oomoo`0AOol00`00Oomoo`0GOol00`00Oomo
o`0OOol00`00Oomoo`0/Ool00`00Oomoo`15Ool00`00Oomoo`21Ool00`00Oomoo`2bOol00`00Oomo
o`07Ool003Yoo`03001oogoo041oo`03001oogoo02Eoo`03001oogoo009oo`8001aoo`03001oogoo
01]oo`03001oogoo01Ioo`03001oogoo019oo`03001oogoo00ioo`03001oogoo00]oo`03001oogoo
00Qoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo009oo`h00003Ool000000?l000H000=o
o`03001oogoo00P000Moo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00eoo`03001oogoo
015oo`03001oogoo01Moo`03001oogoo01moo`03001oogoo02aoo`03001oogoo04Eoo`03001oogoo
085oo`03001oogoo0;9oo`03001oogoo00Moo`00>Woo00<007ooOol0@7oo00<007ooOol09Goo00<0
07ooOol087oo00<007ooOol06goo00<007ooOol05Woo00<007ooOol04Woo00<007ooOol03Woo00<0
07ooOol02goo00<007ooOol027oo00<007ooOol01Woo0P001Woo00L007ooOomoo`00Ool00002Ool0
1000Oomoogooo`00200000Aoo`00Ool0009oo`05001oogooOol00003Ool00`00Oomoo`03Ool30005
Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool00`00Oomoo`0AOol00`00Oomoo`0G
Ool00`00Oomoo`0OOol00`00Oomoo`0/Ool00`00Oomoo`15Ool00`00Oomoo`21Ool00`00Oomoo`2b
Ool00`00Oomoo`07Ool003Yoo`03001oogoo041oo`03001oogoo02Eoo`03001oogoo021oo`03001o
ogoo01]oo`03001oogoo01Ioo`03001oogoo019oo`03001oogoo00ioo`03001oogoo00]oo`03001o
ogoo00Qoo`03001oogoo00Moo`03001oogoo00Aoo`04001oogoo0002Ool01000Oomoogoo2@004Goo
00<007ooOol097oo00<007ooOol097oo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol07Woo
00<007ooOol07Goo00<007ooOol077oo00@007oo000000=oo`80009oo`05001oogooOol00005Ool0
0`00Oomoo`020003Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool00`00Oomoo`0A
Ool00`00Oomoo`0GOol00`00Oomoo`0OOol00`00Oomoo`0/Ool00`00Oomoo`15Ool00`00Oomoo`21
Ool00`00Oomoo`2bOol00`00Oomoo`07Ool003Yoo`03001oogoo041oo`03001oogoo02Eoo`03001o
ogoo021oo`03001oogoo01]oo`03001oogoo01Ioo`03001oogoo019oo`03001oogoo00ioo`03001o
ogoo00]oo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Aoo`8000Aoo`03001oo`0000@0
0003Ool0000000<0011oo`03001oogoo02Aoo`03001oogoo02Aoo`03001oogoo01ioo`03001oogoo
01eoo`03001oogoo01ioo`03001oogoo01eoo`03001oogoo01aoo`04001oo`000002Ool00`00Oomo
o`020003Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Oomoo`0027oo00<007ooOol02Woo00<0
07ooOol03Woo00<007ooOol04Goo00<007ooOol05goo00<007ooOol07goo00<007ooOol0;7oo00<0
07ooOol0AGoo00<007ooOol0PGoo00<007ooOol0/Woo00<007ooOol01goo000jOol00`00Oomoo`10
Ool00`00Oomoo`0UOol00`00Oomoo`0POol00`00Oomoo`0KOol00`00Oomoo`0FOol00`00Oomoo`0B
Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`03
Ool20006Ool20002Ool00`00Oomoo`030002Oooo00020002Ool20003Ool20002Ool00`00Oomoo`04
Ool00`00Oomoo`04Ool20009Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool00`00Oomoo`0BOol00`00
Oomoo`0GOol00`00Oomoo`0OOol00`00Oomoo`0/Ool00`00Oomoo`15Ool00`00Oomoo`21Ool00`00
Oomoo`2bOol00`00Oomoo`07Ool003Yoo`03001oogoo041oo`03001oogoo02Eoo`03001oogoo021o
o`03001oogoo01]oo`03001oogoo01Ioo`03001oogoo01=oo`03001oogoo00ioo`03001oogoo00]o
o`03001oogoo00Uoo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`04Ool01P00Oomo
ogoo001oo`<0019oo`03001oogoo02Aoo`03001oogoo02Aoo`03001oogoo01ioo`03001oogoo01eo
o`03001oogoo01ioo`03001oogoo01eoo`03001oogoo01aoo`04001oogooOol3000017oo001oogoo
0P001Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol03Goo00<007oo
Ool04Goo00<007ooOol067oo00<007ooOol07goo00<007ooOol0;7oo00<007ooOol0AGoo00<007oo
Ool0PGoo00<007ooOol0/Woo00<007ooOol01goo000jOol00`00Oomoo`10Ool00`00Oomoo`0UOol0
0`00Oomoo`0POol00`00Oomoo`0KOol00`00Oomoo`0GOol00`00Oomoo`0BOol00`00Oomoo`0>Ool0
0`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Ool00003Ool00`00Oomoo`05Ool0
1000Oomoogoo0P000Woo00<007ooOol03goo00<007ooOol097oo00<007ooOol097oo00<007ooOol0
7Woo00<007ooOol07Goo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol077oo00D007ooOol0
07oo00<000=oo`8000Eoo`03001oogoo00Moo`<000Ioo`03001oogoo00Yoo`03001oogoo00ioo`03
001oogoo015oo`03001oogoo01Moo`03001oogoo021oo`03001oogoo02aoo`03001oogoo04Eoo`03
001oogoo085oo`03001oogoo0;9oo`03001oogoo00Moo`00>Woo00<007ooOol0@7oo00<007ooOol0
9Goo00<007ooOol087oo00<007ooOol06goo00<007ooOol05goo00<007ooOol04Woo00<007ooOol0
3Woo00<007ooOol037oo00<007ooOol02Goo00<007ooOol01goo0P001Goo00<007ooOol01Goo00<0
07oo00000P000goo00<007ooOol03Woo00<007ooOol097oo00<007ooOol097oo00<007ooOol07Woo
00<007ooOol07Goo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol077oo00<007oo00000Woo
100000Eoo`00Oomoo`0000Aoo`03001oogoo00Ioo`05001oogooOol00005Ool00`00Oomoo`0:Ool0
0`00Oomoo`0>Ool00`00Oomoo`0AOol00`00Oomoo`0GOol00`00Oomoo`0POol00`00Oomoo`0/Ool0
0`00Oomoo`15Ool00`00Oomoo`21Ool00`00Oomoo`2bOol00`00Oomoo`07Ool003Yoo`03001oogoo
041oo`03001oogoo02Eoo`03001oogoo021oo`03001oogoo01]oo`03001oogoo01Moo`03001oogoo
019oo`03001oogoo00moo`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo00Moo`8000Ioo`03
001oogoo00Eoo`03001oo`00008000=oo`P000Qoo`03001oogoo02Aoo`03001oogoo02Aoo`03001o
ogoo01ioo`03001oogoo01eoo`03001oogoo01ioo`03001oogoo01eoo`03001oogoo01Ioo`P000=o
o`D000Aoo`04001oogoo0008Ool00`00Oomoo`03Ool20002Ool00`00Oomoo`0;Ool00`00Oomoo`0=
Ool00`00Oomoo`0BOol00`00Oomoo`0GOol00`00Oomoo`0POol00`00Oomoo`0/Ool00`00Oomoo`15
Ool00`00Oomoo`21Ool00`00Oomoo`2bOol00`00Oomoo`07Ool003Yoo`03001oogoo041oo`03001o
ogoo02Eoo`03001oogoo021oo`03001oogoo01]oo`03001oogoo01Moo`03001oogoo019oo`03001o
ogoo00moo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Eoo`03001oo`0000Ioo`03001o
ogoo00Aoo`04001oo`000002Ool00`00Oomoo`08Oooa0006Ool01P00Oomoogoo001oo`D000=oo`04
001oogoo0008Ool00`00Oomoo`05Ool00`00Ool0000<Ool00`00Oomoo`0>Ool00`00Oomoo`0BOol0
0`00Oomoo`0GOol00`00Oomoo`0POol00`00Oomoo`0/Ool00`00Oomoo`15Ool00`00Oomoo`21Ool0
0`00Oomoo`2bOol00`00Oomoo`07Ool003Yoo`03001oogoo041oo`03001oogoo02Eoo`03001oogoo
025oo`03001oogoo01]oo`03001oogoo01Ioo`03001oogoo01=oo`03001oogoo00ioo`03001oogoo
00aoo`03001oogoo00Uoo`03001oogoo00=oo`8000=oo`03001oogoo00Aoo`03001oogoo00=oo`04
001oo`000003Ool00`00Oomoo`0?Ool00`00Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0NOol0
0`00Oomoo`0MOol00`00Oomoo`0NOol00`00Oomoo`0MOol00`00Oomoo`0LOol01000Oomoo`000goo
1@000goo0P0027oo00<007ooOol01goo00<007ooOol02goo00<007ooOol03Woo00<007ooOol04Goo
00<007ooOol067oo00<007ooOol07goo00<007ooOol0;Goo00<007ooOol0AWoo00<007ooOol0PGoo
00<007ooOol0/Goo00<007ooOol01goo000jOol00`00Oomoo`10Ool00`00Oomoo`0UOol00`00Oomo
o`0QOol00`00Oomoo`0KOol00`00Oomoo`0FOol00`00Oomoo`0COol00`00Oomoo`0>Ool00`00Oomo
o`0<Ool00`00Oomoo`09Ool01000Oomoogoo100017oo00<007ooOol00goo00<007ooOol00Woo00<0
07oo00000Woo00D007ooOomoo`00011oo`03001oogoo02Aoo`03001oogoo02Aoo`03001oogoo01io
o`03001oogoo01eoo`03001oogoo01ioo`03001oogoo01eoo`03001oogoo01aoo`03001oo`0000=o
o`<00004Ool000000002Ool20007Ool00`00Oomoo`08Ool3000;Ool00`00Oomoo`0>Ool00`00Oomo
o`0AOol00`00Oomoo`0HOol00`00Oomoo`0OOol00`00Oomoo`0]Ool00`00Oomoo`16Ool00`00Oomo
o`21Ool00`00Oomoo`2aOol00`00Oomoo`07Ool003Yoo`03001oogoo041oo`03001oogoo02Eoo`03
001oogoo025oo`03001oogoo01]oo`03001oogoo01Ioo`03001oogoo01=oo`03001oogoo00ioo`03
001oogoo00aoo`03001oogoo00Yoo`H000Eoo`03001oogoo00Aoo`800005Ool007ooOol00003Ool0
1000Oomoogoo200027oo00<007ooOol097oo00<007ooOol097oo00<007ooOol07Woo00<007ooOol0
7Goo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol05Woo20000goo00<007oo00000P000Woo
0P0000Aoo`00Ool000Eoo`03001oogoo00Uoo`03001oogoo008000Qoo`03001oogoo00moo`03001o
ogoo015oo`03001oogoo01Qoo`03001oogoo01moo`03001oogoo02eoo`03001oogoo04Ioo`03001o
ogoo085oo`03001oogoo0;5oo`03001oogoo00Moo`00>Woo00<007ooOol0@7oo00<007ooOol09Goo
00<007ooOol08Goo00<007ooOol06goo00<007ooOol05Woo00<007ooOol04goo00<007ooOol03goo
00<007ooOol02goo00<007ooOol02Woo1@001goo00<007ooOol01Goo0P0000=oo`00Ool017oo00<0
07ooOol027ool@001Woo00D007ooOomoo`0000=oo`8000=oo`8000=oo`03001oogoo009oo`03001o
ogoo00Qoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00ioo`03001oogoo019oo`03001o
ogoo01Qoo`03001oogoo01moo`03001oogoo02eoo`03001oogoo04Ioo`03001oogoo085oo`03001o
ogoo0;5oo`03001oogoo00Moo`00>Woo00<007ooOol0@7oo00<007ooOol09Goo00<007ooOol08Goo
00<007ooOol06goo00<007ooOol05Woo00<007ooOol04goo00<007ooOol03goo00<007ooOol037oo
00<007ooOol01goo1`001goo00<007ooOol01Woo0`001Woo00<007ooOol03goo00<007ooOol097oo
00<007ooOol097oo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol07Woo00<007ooOol07Goo
00<007ooOol077oo00@007ooOol000Aoo`<00003Ool007oo00Aoo`05001oogooOol0000;Ool00`00
Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`0BOol00`00Oomoo`0HOol00`00
Oomoo`0OOol00`00Oomoo`0]Ool00`00Oomoo`16Ool00`00Oomoo`21Ool00`00Oomoo`2aOol00`00
Oomoo`07Ool003Yoo`03001oogoo041oo`03001oogoo02Eoo`03001oogoo025oo`03001oogoo01]o
o`03001oogoo01Moo`03001oogoo019oo`03001oogoo00moo`03001oogoo00aoo`03001oogoo00Eo
o`P000Uoo`03001oogoo00Aoo`04001oo`000007Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00
Oomoo`0TOol00`00Oomoo`0NOol00`00Oomoo`0MOol00`00Oomoo`0NOol00`00Oomoo`0MOol00`00
Oomoo`0LOol00`00Ool00005Ool40006Ool01000Oomoo`002goo00<007ooOol01Woo00<007ooOol0
0Woo00<007ooOol03goo00<007ooOol04Woo00<007ooOol05goo00<007ooOol087oo00<007ooOol0
;Goo00<007ooOol0AWoo00<007ooOol0PGoo00<007ooOol0/Goo00<007ooOol01goo000jOol00`00
Oomoo`10Ool00`00Oomoo`0UOol00`00Oomoo`0QOol00`00Oomoo`0KOol00`00Oomoo`0GOol00`00
Oomoo`0COol00`00Oomoo`0>Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool200000goo001oo`03000;
Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000Moo`P000Qoo`03001oogoo02Aoo`03001oogoo02=o
o`<001moo`03001oogoo01aoo`<001moo`03001oogoo01eoo`03001oogoo01Ioo`P000Moo`<000Mo
o`03001oo`0000]oo`03001oogoo00Moo`<00003Ool007oo011oo`03001oogoo015oo`03001oogoo
01Qoo`03001oogoo021oo`03001oogoo02eoo`03001oogoo04Ioo`03001oogoo085oo`03001oogoo
0;5oo`03001oogoo00Moo`00>Woo00<007ooOol0@7oo00<007ooOol09Goo00<007ooOol08Goo00<0
07ooOol06goo00<007ooOol05goo00<007ooOol04goo00<007ooOol03goo00<007ooOol037oo00<0
07ooOol01Goo00<007ooOol00`002goo00D007ooOomoo`00009oo`05001oogooOol0000>Oooa0006
Ool00`00Oomoo`06Ool00`00Ool00008Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool2000@Ool00`00
Oomoo`0BOol00`00Oomoo`0HOol00`00Oomoo`0POol00`00Oomoo`0]Ool00`00Oomoo`16Ool00`00
Oomoo`21Ool00`00Oomoo`2aOol00`00Oomoo`07Ool003Yoo`D003ioo`03001oogoo02Eoo`03001o
ogoo025oo`03001oogoo01]oo`03001oogoo01Moo`03001oogoo01=oo`03001oogoo00moo`03001o
ogoo00aoo`03001oogoo00Aoo`04001oogooOol200000goo001oo`0:Ool200001Goo001oogoo0000
17oo0`004goo00<007ooOol08goo0`0097oo0`007Woo0`007Goo0`007Woo0`007Goo0`007Goo00<0
07ooOol00goo0`000Woo00<007ooOol017oo0P0000=oo`00Ool02Goo00<007ooOol02goo0P0047oo
00<007ooOol04Woo00<007ooOol067oo00<007ooOol087oo00<007ooOol0;Goo00<007ooOol0AWoo
00<007ooOol0PGoo00<007ooOol0[7oo1P002Goo000jOol00`00Oomoo`10Ool00`00Oomoo`0UOol0
0`00Oomoo`0QOol00`00Oomoo`0KOol00`00Oomoo`0GOol00`00Oomoo`0COol00`00Oomoo`0?Ool0
0`00Oomoo`0<Ool00`00Oomoo`02Ool20003Ool20003Ool00`00Oomoo`0:Ool01@00Oomoogoo0000
1goo0`003goo0`0097oo0`0097oo0`007Woo0`007Goo0`007Woo0`007Goo0`007Goo00<007ooOol0
0`001Woo00@007ooOomoo`8000=oo`03001oogoo00Qoo`03001oogoo00]oo`03001oo`0000moo`03
001oogoo019oo`03001oogoo01Qoo`03001oogoo021oo`03001oogoo02eoo`03001oogoo04Ioo`03
001oogoo085oo`03001oogoo0;5oo`03001oogoo00Moo`00>Woo00<007ooOol0@7oo00<007ooOol0
9Goo00<007ooOol08Goo00<007ooOol06goo00<007ooOol05goo00<007ooOol04goo00<007ooOol0
47oo00<007ooOol037oo00@007ooOol000Eoo`03001oogoo00=oo`8000Yoo`@000]ooaD0025oo`<0
02=oo`D001eoo`<001aoo`D001eoo`<001eoo`<001Moo`T000Uoo`04001oogoo0006Ool00`00Oomo
o`06Ool00`00Oomoo`0;Ool01@00Oomoogoo00003Goo00<007ooOol04goo00<007ooOol067oo00<0
07ooOol087oo00<007ooOol0;Goo00<007ooOol0AWoo00<007ooOol0PGoo00<007ooOol0/Goo00<0
07ooOol01goo000jOol00`00Oomoo`10Ool00`00Oomoo`0UOol00`00Oomoo`0QOol00`00Oomoo`0K
Ool00`00Oomoo`0HOol00`00Oomoo`0COol00`00Oomoo`0?Ool00`00Oomoo`0=Ool2000>Ool00`00
Oomoo`07Ool00`00Ool00004000GOol30003OooT0006Ool00`00Oomoo`09Ool30008Ool00`00Oomo
o`04Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool3000:Ool00`00Oomoo`0BOol00`00Oomoo`0IOol0
0`00Oomoo`0POol00`00Oomoo`0]Ool00`00Oomoo`16Ool00`00Oomoo`21Ool00`00Oomoo`2aOol0
0`00Oomoo`07Ool003Yoo`03001oogoo041oo`03001oogoo02Eoo`03001oogoo025oo`03001oogoo
01aoo`03001oogoo01Moo`03001oogoo01=oo`03001oogoo011oo`03001oogoo00aoo`03001oogoo
00ioo`8000Ioo`03001oogoo008000=oo`@001=oo`<002=oo`D0029oo`D001aoo`D001]oo`D001ao
o`D001]oo`D001aoo`03001oogoo00Aoo`D00003Ool007oo00Qoo`03001oogoo00=oo`03001oogoo
00aoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo01=oo`03001oogoo01Qoo`03001oogoo
025oo`03001oogoo02eoo`03001oogoo04Ioo`03001oogoo085oo`03001oogoo0;5oo`03001oogoo
00Moo`00>Woo00<007ooOol0@7oo00<007ooOol09Goo00<007ooOol08Woo00<007ooOol06goo00<0
07ooOol05goo00<007ooOol04goo00<007ooOol047oo00<007ooOol02goo00<007oo00004Goo00<0
07ooOol00Woo00D007ooOomoo`0000Qoo`<000moo`D0029oo`D0029oo`05001oo`00Ool0000LOol5
000KOol01@00Ool007oo000077oo1@006goo1@007Goo00<007oo00000`001Woo00<007ooOol01goo
0P000Woo0P003Woo00<007ooOol027oo00<007ooOol01Goo00<007ooOol04goo00<007ooOol067oo
00<007ooOol087oo00<007ooOol0;Woo00<007ooOol0AWoo00<007ooOol0PGoo00<007ooOol0/Goo
00<007ooOol01goo000jOol00`00Oomoo`10Ool00`00Oomoo`0UOol00`00Oomoo`0ROol00`00Oomo
o`0KOol00`00Oomoo`0GOol00`00Oomoo`0DOol00`00Oomoo`0?Ool00`00Oomoo`0:Ool01@00Oomo
ogoo00004Goo0P000Woo00D007ooOomoo`0000]oo`T000Ioo`D0029oo`05001oo`00Ool0000QOol2
00000goo001oo`02000KOol01@00Ool007oo00006Woo0P0000=oo`00Ool00P006goo00D007oo001o
o`0001]oo`05001oo`00Ool0000FOol9000:Ool00`00Oomoo`08Ool3000@Ool00`00Oomoo`09Ool0
0`00Oomoo`03Ool00`00Oomoo`0DOol00`00Oomoo`0HOol00`00Oomoo`0POol00`00Oomoo`0^Ool0
0`00Oomoo`16Ool00`00Oomoo`21Ool00`00Oomoo`2aOol00`00Oomoo`07Ool003Yoo`03001oogoo
041oo`03001oogoo02Eoo`03001oogoo029oo`03001oogoo01]oo`03001oogoo01Moo`03001oogoo
01Aoo`03001oogoo011oo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo011oo`03001oo`00
00=oo`03001oogoo019ooo4000Moo`03001oogoo00Yoo`03001oogoo00Ioo`@000moo`03001oogoo
00]oo`03001oogoo009oo`03001oogoo01=oo`03001oogoo01Uoo`03001oogoo021oo`03001oogoo
02ioo`03001oogoo04Ioo`03001oogoo085oo`03001oogoo0;5oo`03001oogoo00Moo`00>Woo00<0
07ooOol0@7oo00<007ooOol09Woo00<007ooOol08Goo00<007ooOol06goo00<007ooOol067oo00<0
07ooOol04goo00<007ooOol047oo00<007ooOol01goo00<007ooOol017oo00<007ooOol04Goo00@0
07ooOomoo`8001Yoo`05001oo`00Ool0000QOol01000Oomoo`000Woo00<007ooOol08Goo00<007oo
Ool06goo00@007ooOol0009oo`03001oogoo01Yoo`03001oogoo01]oo`04001oogoo0002Ool00`00
Oomoo`0GOol01000Oomoo`000Woo00<007ooOol06Woo00<007ooOol02Woo00<007ooOol017oo0P00
00=oo`0000000P003Woo00<007ooOol037oo10005Woo00<007ooOol06Goo00<007ooOol087oo00<0
07ooOol0;Woo00<007ooOol0AWoo00<007ooOol0PGoo00<007ooOol0/Goo00<007ooOol01goo000j
Ool00`00Oomoo`10Ool00`00Oomoo`0VOol00`00Oomoo`0QOol00`00Oomoo`0KOol00`00Oomoo`0H
Ool00`00Oomoo`0DOol00`00Oomoo`0@Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`0?
Ool01@00Ool00000Ool00P006Goo0P0000=oo`00Ool00P008goo00<007ooOol097oo00<007ooOol0
7Woo00<007ooOol07Goo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol07Goo00<007ooOol0
2Woo00<007ooOol00Woo0P000goo0`0000=oo`00Ool02goo00<007ooOol047oo00<007ooOol057oo
00<007ooOol067oo00<007ooOol08Goo00<007ooOol0;Goo00<007ooOol0AWoo00<007ooOol0Pgoo
00<007ooOol0/7oo00<007ooOol01goo000jOol00`00Oomoo`10Ool00`00Oomoo`0VOol00`00Oomo
o`0QOol00`00Oomoo`0LOol00`00Oomoo`0GOol00`00Oomoo`0DOol00`00Oomoo`0@Ool00`00Oomo
o`04Ool00`00Oomoo`08Ool00`00Oomoo`0>Ool01000Oomoogoo0`006Goo00@007ooOol0009oo`03
001oogoo025oo`03001oogoo02Aoo`03001oogoo01ioo`03001oogoo01eoo`03001oogoo01ioo`03
001oogoo01eoo`03001oogoo01eoo`03001oogoo00Yoo`03001oogoo008000Ioo`80009oo`03001o
ogoo00Uoo`03001oogoo00moo`03001oo`0001Eoo`03001oogoo01Qoo`03001oogoo025oo`03001o
ogoo02eoo`03001oogoo04Ioo`03001oogoo08=oo`03001oogoo0;1oo`03001oogoo00Moo`00>Woo
00<007ooOol0@7oo00<007ooOol09Woo00<007ooOol08Goo00<007ooOol077oo00<007ooOol05goo
00<007ooOol057oo00<007ooOol04Goo00@007ooOomoo`8000aoo`03001oogoo00eoo`03001oogoo
009oool001L000Eoo`<000Qoo`<0009oo`03001oogoo00Moo`03001oogoo011oo`04001oogoo000D
Ool00`00Oomoo`0HOol00`00Oomoo`0QOol00`00Oomoo`0]Ool00`00Oomoo`16Ool00`00Oomoo`23
Ool00`00Oomoo`2`Ool00`00Oomoo`07Ool003Yoo`03001oogoo041oo`03001oogoo02Ioo`03001o
ogoo025oo`03001oogoo01aoo`03001oogoo01Moo`03001oogoo01Eoo`03001oogoo011oo`04001o
ogoo000?Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0KOol00`00Oomoo`0TOol00`00
Oomoo`0TOol00`00Oomoo`0NOol00`00Oomoo`0MOol00`00Oomoo`0NOol00`00Oomoo`0MOol00`00
Oomoo`0MOol00`00Oomoo`05Ool6000:Ool30003Ool00`00Oomoo`05Ool00`00Oomoo`0@Ool00`00
Oomoo`02Ool4000?Ool00`00Oomoo`0IOol00`00Oomoo`0QOol00`00Oomoo`0]Ool00`00Oomoo`16
Ool00`00Oomoo`23Ool00`00Oomoo`2`Ool00`00Oomoo`07Ool003Yoo`03001oogoo041oo`03001o
ogoo02Ioo`03001oogoo029oo`03001oogoo01]oo`03001oogoo01Qoo`03001oogoo01Aoo`03001o
ogoo015oo`80011oo`03001oogoo00]oo`8000Aoo`03001oogoo01]oo`03001oogoo02Aoo`03001o
ogoo02Aoo`03001oogoo01ioo`03001oogoo01eoo`03001oogoo01ioo`03001oogoo01eoo`03001o
ogoo01eoo`03001oogoo00Yoo`03001oogoo00Qoo`800003Ool007oo00Qoo`03001oogoo015oo`03
001oogoo00Aoo`D000aoo`03001oogoo01Uoo`03001oogoo021oo`03001oogoo02ioo`03001oogoo
04Ioo`03001oogoo08=oo`03001oogoo0;1oo`03001oogoo00Moo`00>Woo00<007ooOol0@7oo00<0
07ooOol09Woo00<007ooOol08Woo00<007ooOol06goo00<007ooOol067oo00<007ooOol057oo00<0
07ooOol047oo0P004Woo00<007ooOol02Goo0`0017oo00<007ooOol06goo00<007ooOol097oo00<0
07ooOol097oo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol07Woo00<007ooOol07Goo00<0
07ooOol07Goo00<007ooOol02Woo00<007ooOol02Goo00@007ooOol000Moo`03001oogoo015oo`03
001oogoo00Ioo`L000Uoo`03001oogoo01Qoo`03001oogoo025oo`03001oogoo02ioo`03001oogoo
04Ioo`03001oogoo08=oo`03001oogoo0;1oo`03001oogoo00Moo`00>Woo00<007ooOol0@7oo00<0
07ooOol09Woo00<007ooOol08Woo00<007ooOol077oo00<007ooOol05goo00<007ooOol05Goo00<0
07ooOol03Woo00<007oo00004goo00<007ooOol027oo0`0017oo00<007ooOol06goo00<007ooOol0
97oo00<007ooOol097oo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol07Woo00<007ooOol0
7Goo00<007ooOol077oo0P0037oo00<007ooOol02Goo00@007ooOol000Ioo`03001oogoo019oo`03
001oogoo00Moo`T000Eoo`03001oogoo01Uoo`03001oogoo025oo`03001oogoo02ioo`03001oogoo
04Ioo`03001oogoo08=oo`03001oogoo0;1oo`03001oogoo00Moo`00>Woo00<007ooOol0@7oo00<0
07ooOol09Woo00<007ooOol08Woo00<007ooOol077oo00<007ooOol067oo00<007ooOol057oo00<0
07ooOol03Goo00D007ooOomoo`0001=oo`8000Moo`@000Aoo`03001oogoo01]oo`03001oogoo0<`0
0003Ool007oo01eoo`8000aoo`03001oogoo00aoo`03001oogoo009oo`8001Aoo`03001oogoo00Uo
o`T000=oo`03001oogoo01Yoo`03001oogoo025oo`03001oogoo02ioo`03001oogoo04Ioo`03001o
ogoo08=oo`03001oogoo0;1oo`03001oogoo00Moo`00>Woo00<007ooOol0@7oo00<007ooOol09Woo
00<007ooOol08Woo00<007ooOol077oo00<007ooOol067oo00<007ooOol057oo00<007ooOol02goo
0P0017oo00<007ooOol04goo00<007ooOol00goo1@0017oo00<007ooOol04Woo300097oo00<007oo
Ool097oo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol07Woo00<007ooOol077oo600027oo
0P0037oo00<007ooOol03Goo00@007ooOol001Ioo`03001oogoo00Yoo`800003Ool007oo00Ioo`03
001oogoo01Uoo`03001oogoo029oo`03001oogoo02ioo`03001oogoo04Ioo`03001oogoo08=oo`03
001oogoo0;1oo`03001oogoo00Moo`00>Woo00<007ooOol0@7oo00<007ooOol09Woo00<007ooOol0
8Woo00<007ooOol077oo00<007ooOol067oo00<007ooOol05Goo00<007ooOol02Goo00<007ooOol0
1Goo00<007ooOol04goo00<007ooOol00Woo10001Goo00<007ooOol02Woo20002Goo00<007ooOol0
97oo00<007ooOol097oo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol07Woo00<007ooOol0
7Goo00<007ooOol057oo1`0000Aoo`00000000]oo`03001oogoo00ioo`8001Moo`03001oogoo00]o
o`800003Ool007oo00Aoo`03001oogoo01Yoo`03001oogoo029oo`03001oogoo02ioo`03001oogoo
04Ioo`03001oogoo08=oo`03001oogoo0;1oo`03001oogoo00Moo`00>Woo00<007ooOol0@7oo00<0
07ooOol09Woo00<007ooOol08Woo00<007ooOol07Goo00<007ooOol067oo00<007ooOol057oo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol04goo0P0000=oo`0000000`001Goo00<007ooOol0
27oo0P004Goo00<007ooOol097oo00<007ooOol097oo00<007ooOol07Woo00<007ooOol07Goo00<0
07ooOol07Woo00<007ooOol07Goo00<007ooOol06goo10002goo00<007ooOol03Woo00<007ooOol0
5Goo00<007ooOol03Goo0P0000=oo`0000000goo00<007ooOol06Woo00<007ooOol08Goo00<007oo
Ool0;goo00<007ooOol0AWoo00<007ooOol0Pgoo00<007ooOol0/7oo00<007ooOol01goo000jOol0
0`00Oomoo`10Ool00`00Oomoo`0VOol00`00Oomoo`0ROol00`00Oomoo`0MOol00`00Oomoo`0HOol0
0`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`0DOol2000017oo00000000
1Goo00<007ooOol01goo00<007ooOol04Goo00<007ooOol097oo00<007ooOol097oo00<007ooOol0
7Woo00<007ooOol07Goo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol06goo1@002Woo00<0
07ooOol03Goo00<007oo00005Woo00<007ooOol03Woo00@007ooOomoo`<001aoo`03001oogoo029o
o`03001oogoo02ioo`03001oogoo04Moo`03001oogoo08=oo`03001oogoo0;1oo`03001oogoo00Mo
o`00>Woo00<007ooOol0@7oo00<007ooOol09goo00<007ooOol08Woo00<007ooOol077oo00<007oo
Ool067oo00<007ooOol05Goo00<007ooOol017oo0P0037oo00<007ooOol057oo00H007oo000007oo
0005Ool00`00Oomoo`05Ool2000DOol00`00Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0NOol0
0`00Oomoo`0MOol00`00Oomoo`0NOol00`00Oomoo`0MOol00`00Oomoo`0KOol400000goo00000008
Ool00`00Oomoo`0<Ool01@00Oomoogoo00005Goo00<007ooOol03goo00<007ooOol00Woo00<007oo
Ool06Woo00<007ooOol08Woo00<007ooOol0;Woo00<007ooOol0Agoo00<007ooOol0Pgoo00<007oo
Ool0/7oo00<007ooOol01goo000jOol00`00Oomoo`10Ool00`00Oomoo`0WOol00`00Oomoo`0ROol0
0`00Oomoo`0LOol00`00Oomoo`0IOol00`00Oomoo`0DOol00`00Oomoo`03Ool00`00Oomoo`0=Ool0
0`00Oomoo`0BOol01@00Oomoo`00Ool00P001Goo00<007ooOol00goo0P005Woo00<007ooOol097oo
00<007ooOol097oo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol07Woo00<007ooOol07Goo
00<007ooOol06Woo0P0000=oo`0000000goo00<007ooOol01Goo00<007ooOol02Woo0P0017oo00<0
07ooOol04Woo00<007ooOol057oo00<007oo00006goo00<007ooOol08Woo00<007ooOol0;Woo00<0
07ooOol0Agoo00<007ooOol0Pgoo00<007ooOol0/7oo00<007ooOol01goo000jOol00`00Oomoo`10
Ool00`00Oomoo`0WOol00`00Oomoo`0ROol00`00Oomoo`0MOol00`00Oomoo`0HOol00`00Oomoo`0D
Ool01000Oomoogoo0P004Goo00<007ooOol057oo00<007ooOol00P0017oo00@007ooOomoo`8001Qo
o`03001oogoo02Aoo`03001oogoo02Aoo`03001oogoo01ioo`03001oogoo01eoo`03001oogoo01io
o`03001oogoo01eoo`03001oogoo01Yoo`800003Ool0000000Aoo`8000Eoo`03001oogoo00Moo`<0
00Ioo`03001oogoo015oo`03001oogoo01Eoo`03001oogoo008001Qoo`03001oogoo029oo`03001o
ogoo02moo`03001oogoo04Moo`03001oogoo08=oo`03001oogoo0;1oo`03001oogoo00Moo`00>Woo
00<007ooOol0@7oo00<007ooOol09goo00<007ooOol08Woo00<007ooOol07Goo00<007ooOol067oo
00<007ooOol05Goo00<007oo00004goo00<007ooOol057oo00<007ooOol00Woo0P000Woo0P0000=o
o`00Ool06Goo00<007ooOol097oo00<007ooOol097oo00<007ooOol07Woo00<007ooOol07Goo00<0
07ooOol07Woo00<007ooOol07Goo00<007ooOol06Woo0P000Woo0P001Goo00<007ooOol00Woo00<0
07ooOol01Goo0P002Woo00<007ooOol03goo00<007ooOol05Goo00<007ooOol00goo0P005Woo00<0
07ooOol08Woo00<007ooOol0;goo00<007ooOol0Agoo00<007ooOol0Pgoo00<007ooOol0/7oo00<0
07ooOol01goo000jOol00`00Oomoo`10Ool00`00Oomoo`0WOol00`00Oomoo`0ROol00`00Oomoo`0M
Ool00`00Oomoo`0IOol00`00Oomoo`0DOol2000EOol00`00Oomoo`0BOol00`00Oomoo`05Ool5000L
Ool00`00Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`0NOol00`00Oomoo`0MOol00`00Oomoo`0M
Ool00`00Oomoo`0NOol00`00Oomoo`0IOol30002Ool20006Ool01@00Oomoogoo00001Goo0P003Goo
00<007ooOol03Woo00<007ooOol05Goo00<007ooOol01Goo00<007ooOol04goo00<007ooOol08Woo
00<007ooOol0;Woo00<007ooOol0Agoo00<007ooOol0Q7oo00<007ooOol0/7oo00<007ooOol01goo
000:Ool<000;Ool4000EOol00`00Oomoo`10Ool00`00Oomoo`0WOol00`00Oomoo`0ROol00`00Oomo
o`0MOol00`00Oomoo`0IOol00`00Oomoo`0COol3000FOol00`00Oomoo`0@Ool00`00Oomoo`08Ool2
0004OolIIcT00`00IcUW>@0SIcT00`00IcUW>@0TIcT00`00IcUW>@0NIcT00`00IcUW>@0MIcT00`00
IcUW>@0MIcT00`00IcUW>@0MIcT00`00IcUW>@0JIcT00`00IcT00003IcT00`00IcUW>@03IcT2Ool2
000017oo001oogoo0`0047oo00<007ooOol037oo00<007ooOol05Woo00<007ooOol01Woo00<007oo
Ool04Goo00<007ooOol08goo00<007ooOol0;Woo00<007ooOol0Agoo00<007ooOol0Q7oo00<007oo
Ool0/7oo00<007ooOol01goo000:Ool<0009Ool8000COol00`00Oomoo`10Ool00`00Oomoo`0WOol0
0`00Oomoo`0ROol00`00Oomoo`0MOol00`00Oomoo`0IOol00`00Oomoo`0BOol01000Oomoo`005goo
00<007ooOol03goo00<007ooOol02Goo00<007ooOol00Woo6FLi00<006LiIcT08fLi00<006LiIcT0
96Li00<006LiIcT07VLi00<006LiIcT07FLi00<006LiIcT07FLi00<006LiIcT07FLi00<006LiIcT0
76Li00<006LiIcT01fLi17oo10004goo00<007ooOol02goo00<007ooOol05Woo00<007ooOol027oo
0P004Goo00<007ooOol08goo00<007ooOol0;Woo00<007ooOol0Agoo00<007ooOol0Q7oo00<007oo
Ool0/7oo00<007ooOol01goo000;Ool30006Ool20009Ool20004Ool2000COol00`00Oomoo`10Ool0
0`00Oomoo`0WOol00`00Oomoo`0ROol00`00Oomoo`0NOol00`00Oomoo`0HOol00`00Oomoo`0@Ool2
0004Ool00`00Oomoo`0DOol00`00Oomoo`0?Ool00`00Oomoo`09Ool00`00Oomoo`02OolIIcT00`00
IcUW>@0SIcT00`00IcUW>@0TIcT00`00IcUW>@0NIcT00`00IcUW>@0MIcT00`00IcUW>@0MIcT00`00
IcUW>@0MIcT00`00IcUW>@0KIcT00`00IcUW>@08IcT5Ool00`00Oomoo`0DOol00`00Oomoo`09Ool0
0`00Oomoo`0GOol00`00Oomoo`0:Ool00`00Oomoo`0>Ool00`00Oomoo`0ROol00`00Oomoo`0_Ool0
0`00Oomoo`17Ool00`00Oomoo`24Ool00`00Oomoo`2`Ool00`00Oomoo`07Ool000aoo`<000moo`80
00Ioo`80019oo`03001oogoo041oo`03001oogoo02Moo`03001oogoo029oo`03001oogoo01ioo`03
001oogoo01Uoo`03001oogoo00ioo`03001oogoo00Eoo`03001oogoo01Aoo`03001oogoo00eoo`03
001oogoo00Uoo`03001oo`0000=ooaUW>@03001W>FLi02=W>@03001W>FLi02AW>@03001W>FLi01iW
>@03001W>FLi01eW>@03001W>FLi01eW>@03001W>FLi01eW>@03001W>FLi01]W>@03001W>FLi00QW
>@Eoo`03001oogoo01Aoo`03001oogoo00Qoo`03001oogoo01Moo`03001oogoo00aoo`8000eoo`03
001oogoo02=oo`03001oogoo02moo`03001oogoo04Moo`03001oogoo08Aoo`03001oogoo0;1oo`03
001oogoo00Moo`003Goo0`003Woo0P001Woo0P004Woo00<007ooOol0@Goo00<007ooOol09goo00<0
07ooOol08Woo00<007ooOol07Goo00<007ooOol06Goo00<007ooOol03Goo00<007ooOol01Woo00<0
07ooOol05Goo00<007ooOol037oo00<007ooOol02Goo00<007oo00000goo6FLi00<006LiIcT08fLi
00<006LiIcT096Li00<006LiIcT07VLi00<006LiIcT07FLi00<006LiIcT07FLi00<006LiIcT07FLi
00<006LiIcT06fLi00<006LiIcT026Li1Goo00<007ooOol05Goo00<007ooOol01goo00<007ooOol0
5goo00<007ooOol03Woo0P002goo00<007ooOol08goo00<007ooOol0;goo00<007ooOol0Agoo00<0
07ooOol0Q7oo00<007ooOol0/7oo00<007ooOol01goo000>Ool3000<Ool20008Ool2000AOol00`00
Oomoo`11Ool00`00Oomoo`0WOol00`00Oomoo`0ROol00`00Oomoo`0MOol00`00Oomoo`0IOol00`00
Oomoo`0;Ool2000:Ool00`00Oomoo`0DOol00`00Oomoo`0<Ool00`00Oomoo`09Ool00`00Ool00003
OolIIcT00`00IcUW>@0SIcT00`00IcUW>@0TIcT00`00IcUW>@0MIcT00`00IcUW>@0NIcT00`00IcUW
>@0MIcT00`00IcUW>@0MIcT00`00IcUW>@0KIcT00`00IcUW>@08IcT5Ool00`00Oomoo`0EOol00`00
Oomoo`06Ool00`00Oomoo`0GOol00`00Oomoo`0AOol00`00Oomoo`08Ool00`00Oomoo`0SOol00`00
Oomoo`0^Ool00`00Oomoo`18Ool00`00Oomoo`24Ool00`00Oomoo`2`Ool00`00Oomoo`07Ool000mo
o`<000]oo`8000Qoo`80015oo`03001oogoo045oo`03001oogoo02Moo`03001oogoo029oo`03001o
ogoo01ioo`03001oogoo01Uoo`03001oogoo00Qoo`8000aoo`03001oogoo01Eoo`03001oogoo00Yo
o`03001oogoo00Yoo`03001oo`0000=ooaUW>@03001W>FLi02=W>@03001W>FLi02AW>@03001W>FLi
01eW>@03001W>FLi01iW>@03001W>FLi01eW>@03001W>FLi01eW>@03001W>FLi01]W>@03001W>FLi
00QW>@Eoo`03001oogoo01Ioo`03001oogoo00Aoo`03001oogoo01Qoo`03001oogoo019oo`8000Mo
o`03001oogoo02=oo`03001oogoo02moo`03001oogoo04Qoo`03001oogoo08Aoo`03001oogoo0;1o
o`03001oogoo00Moo`0047oo0`002Woo0P0027oo0P004Goo2000?7oo00<007ooOol09goo00<007oo
Ool08Woo00<007ooOol07Woo00<007ooOol06Goo00<007ooOol01goo00<007ooOol03Goo00<007oo
Ool05Goo0P002Woo00<007ooOol02Woo00<007oo00000goo6FLi00<006LiIcT08fLi00<006LiIcT0
96Li00<006LiIcT07FLi00<006LiIcT07VLi00<006LiIcT07FLi00<006LiIcT07FLi00<006LiIcT0
6fLi00<006LiIcT026Li1Goo00<007ooOol05goo00@007ooOomoo`8001Yoo`03001oogoo01Eoo`80
00Eoo`03001oogoo02=oo`03001oogoo02moo`03001oogoo04Qoo`03001oogoo08Aoo`03001oogoo
0:Uoo`P000Uoo`004Goo0`002Goo0P0027oo0P004Goo00<007ooOol0@Goo00<007ooOol09goo00<0
07ooOol08Woo00<007ooOol07Woo00<007ooOol06Goo00<007ooOol01Goo0P0047oo00<007ooOol0
5goo00<007ooOol01goo00<007ooOol02Woo00<007oo00000goo6FLi00<006LiIcT08fLi00<006Li
IcT096Li00<006LiIcT07FLi00<006LiIcT07VLi00<006LiIcT07FLi00<006LiIcT07FLi00<006Li
IcT06fLi00<006LiIcT026Li1Goo00<007ooOol067oo00<007oo000077oo00<007ooOol05goo00<0
07ooOol00Woo00<007ooOol08goo00<007ooOol0;goo00<007ooOol0B7oo00<007ooOol0Q7oo00<0
07ooOol0/7oo00<007ooOol01goo000BOol30008Ool20008Ool2000AOol00`00Oomoo`11Ool00`00
Oomoo`0WOol00`00Oomoo`0ROol00`00Oomoo`0NOol00`00Oomoo`0JOol00`00Oomoo`03Ool00`00
Oomoo`0AOol00`00Oomoo`0GOol00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Ool00003OolIIcT0
0`00IcUW>@0SIcT00`00IcUW>@0TIcT00`00IcUW>@0MIcT00`00IcUW>@0NIcT00`00IcUW>@0MIcT0
0`00IcUW>@0MIcT00`00IcUW>@0KIcT00`00IcUW>@08IcT5Ool00`00Oomoo`0HOol2000LOol00`00
Oomoo`0IOol01000Oomoo`009Goo00<007ooOol0<7oo00<007ooOol0B7oo00<007ooOol0Q7oo00<0
07ooOol0/7oo00<007ooOol01goo000COol20008Ool20008Ool2000AOol00`00Oomoo`11Ool00`00
Oomoo`0WOol00`00Oomoo`0SOol00`00Oomoo`0NOol00`00Oomoo`0IOol01000Oomoogoo0P005Goo
00<007ooOol05goo00<007ooOol00goo00<007ooOol037oo00@007ooOol0009ooaUW>@03001W>FLi
02=W>@03001W>FLi02AW>@03001W>FLi01eW>@03001W>FLi01iW>@03001W>FLi01eW>@03001W>FLi
01eW>@03001W>FLi01]W>@03001W>FLi00QW>@Eoo`03001oogoo01Moo`8001eoo`03001oogoo01Yo
o`03001oo`0002Eoo`03001oogoo02moo`03001oogoo04Uoo`03001oogoo08Aoo`03001oogoo0;1o
o`03001oogoo00Moo`0057oo0P001goo0P0027oo0P004Goo00<007ooOol0@Goo00<007ooOol09goo
00<007ooOol08goo00<007ooOol07Woo00<007ooOol06Woo00<007oo00005goo00<007ooOol067oo
00<007ooOol00Woo00<007ooOol03Goo00<007oo00000Woo6FLi00<006LiIcT08fLi00<006LiIcT0
96Li00<006LiIcT07FLi00<006LiIcT07VLi00<006LiIcT07FLi00<006LiIcT07FLi00<006LiIcT0
6fLi00<006LiIcT026Li1Goo00<007ooOol05Woo00@007ooOol001]oo`03001oogoo01aoo`<002Ao
o`03001oogoo02moo`03001oogoo04Uoo`03001oogoo08Aoo`03001oogoo0;1oo`03001oogoo00Mo
o`0057oo0P001goo0P0027oo0P004Goo00<007ooOol0@Goo00<007ooOol0:7oo00<007ooOol08Woo
00<007ooOol07Woo00<007ooOol06Woo0P006Goo00<007ooOol067oo0P0000=oo`00Ool03goo00<0
07oo00000Woo6FLi00<006LiIcT08fLi00<006LiIcT096Li00<006LiIcT07FLi00<006LiIcT07VLi
00<006LiIcT07FLi00<006LiIcT07FLi00<006LiIcT06VLi00<006LiIcT02FLi1Goo00<007ooOol0
5Goo00<007ooOol00Woo00<007ooOol05goo00<007ooOol07Goo00@007ooOol0029oo`03001oogoo
031oo`03001oogoo04Qoo`03001oogoo08Eoo`03001oogoo0;1oo`03001oogoo00Moo`002goo0P00
1goo0P0027oo0P001Woo0P004Woo00<007ooOol0@Goo00<007ooOol0:7oo00<007ooOol08Woo00<0
07ooOol07goo00<007ooOol067oo00<007oo00006Woo00<007ooOol06Goo00<007ooOol03goo00<0
07oo00000Woo6FLi00<006LiIcT08fLi00<006LiIcT096Li00<006LiIcT07FLi00<006LiIcT07VLi
00<006LiIcT07FLi00<006LiIcT07FLi00<006LiIcT06VLi00<006LiIcT02FLi1Goo00<007ooOol0
57oo00<007ooOol017oo00<007ooOol05Woo00<007ooOol077oo00<007ooOol00Woo00<007ooOol0
7goo00<007ooOol0<7oo00<007ooOol0B7oo00<007ooOol0QGoo00<007ooOol0/7oo00<007ooOol0
1goo000;Ool30006Ool20008Ool20006Ool2000BOol00`00Oomoo`11Ool00`00Oomoo`0XOol00`00
Oomoo`0ROol00`00Oomoo`0OOol00`00Oomoo`0GOol01000Oomoo`006Woo00<007ooOol067oo00<0
07oo000047oo00<007oo00000Woo6FLi00<006LiIcT08fLi00<006LiIcT096Li00<006LiIcT07FLi
00<006LiIcT07VLi00<006LiIcT07FLi00<006LiIcT07FLi00<006LiIcT06VLi00<006LiIcT02FLi
1Goo00<007ooOol04goo00<007ooOol01Goo00<007ooOol05Goo00<007ooOol07Goo00<007ooOol0
0goo00<007ooOol07Woo00<007ooOol0<7oo00<007ooOol0B7oo00<007ooOol0QGoo00<007ooOol0
/7oo00<007ooOol01goo000;Ool40004Ool2000:Ool20004Ool2000COol00`00Oomoo`11Ool00`00
Oomoo`0XOol00`00Oomoo`0SOol00`00Oomoo`0NOol00`00Oomoo`0EOol20004Ool00`00Oomoo`0H
Ool00`00Oomoo`0GOol01000Oomoo`003goo00<007oo00000Woo6FLi00<006LiIcT08fLi00<006Li
IcT096Li00<006LiIcT07FLi00<006LiIcT07VLi00<006LiIcT07FLi00<006LiIcT07FLi00<006Li
IcT06VLi00<006LiIcT02FLi1Goo00<007ooOol04Goo0P002Goo00<007ooOol057oo00<007ooOol0
77oo00<007ooOol01Goo0`0077oo00<007ooOol0<7oo00<007ooOol0BGoo00<007ooOol0QGoo00<0
07ooOol0/7oo00<007ooOol01goo000<Ool8000;Ool8000COol00`00Oomoo`12Ool00`00Oomoo`0W
Ool00`00Oomoo`0SOol00`00Oomoo`0OOol00`00Oomoo`0BOol20006Ool00`00Oomoo`0HOol00`00
Oomoo`0GOol01@00Oomoogoo00003Woo00D007ooOol007oo011W>@Uoo`03001oogoo02=oo`03001o
ogoo02Aoo`03001oogoo01eoo`03001oogoo01ioo`03001oogoo01eoo`03001oogoo01eoo`03001o
ogoo01Ioo`AW>@03001W>FLi00UW>@Eoo`03001oogoo011oo`03001oogoo00Yoo`03001oogoo019o
o`03001oogoo01eoo`03001oogoo00Qoo`03001oogoo01Uoo`03001oogoo031oo`03001oogoo04Uo
o`03001oogoo08Aoo`03001oogoo0;5oo`03001oogoo00Moo`003Woo1@003Woo10005Goo00<007oo
Ool0@Woo00<007ooOol09goo00<007ooOol08goo00<007ooOol07goo00<007ooOol04Goo00<007oo
Ool01goo00<007ooOol067oo00<007ooOol05Goo00<007ooOol00goo0P0037oo00D007ooOol007oo
011W>@Yoo`03001oogoo029oo`03001oogoo02Aoo`03001oogoo01eoo`03001oogoo01ioo`03001o
ogoo01eoo`03001oogoo01eoo`03001oogoo01Ioo`AW>@03001W>FLi00UW>@Eoo`03001oogoo00mo
o`03001oogoo00aoo`03001oogoo011oo`03001oogoo01ioo`03001oogoo00Uoo`03001oogoo01Mo
o`03001oogoo035oo`03001oogoo04Uoo`03001oogoo08Aoo`03001oogoo0;5oo`03001oogoo00Mo
o`00>Woo00<007ooOol0@Woo00<007ooOol09goo00<007ooOol08goo00<007ooOol07goo00<007oo
Ool047oo00<007ooOol027oo00<007ooOol06Goo00<007ooOol04goo00<007ooOol01Woo00<007oo
Ool02Goo00D007ooOol007oo011W>@Yoo`03001oogoo029oo`03001oogoo02Aoo`03001oogoo01eo
o`03001oogoo01ioo`03001oogoo01eoo`03001oogoo01eoo`03001oogoo01Ioo`AW>@03001W>FLi
00UW>@Eoo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00moo`03001oogoo01eoo`03001o
ogoo00]oo`<001Ioo`03001oogoo035oo`03001oogoo04Uoo`03001oogoo08Aoo`03001oogoo0;5o
o`03001oogoo00Moo`00>Woo00<007ooOol0@Woo00<007ooOol09goo00<007ooOol097oo00<007oo
Ool07Woo00<007ooOol037oo100037oo00<007ooOol067oo00<007ooOol04goo00<007ooOol01goo
00<007ooOol02Goo00@007oo001ooa1W>@Yoo`03001oogoo029oo`03001oogoo02Aoo`03001oogoo
01eoo`03001oogoo01ioo`03001oogoo01eoo`03001oogoo01eoo`03001oogoo01Ioo`AW>@03001W
>FLi00UW>@Eoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo00ioo`03001oogoo01ioo`03
001oogoo00ioo`03001oogoo01=oo`03001oogoo031oo`03001oogoo04Yoo`03001oogoo08Aoo`03
001oogoo0;5oo`03001oogoo00Moo`00>Woo00<007ooOol0@Woo00<007ooOol09goo00<007ooOol0
97oo00<007ooOol07goo00<007ooOol027oo1@003Woo00<007ooOol06Goo00<007ooOol04Goo00<0
07ooOol02Goo00<007ooOol027oo00@007oo001ooa1W>@Yoo`03001oogoo029oo`03001oogoo02Ao
o`03001oogoo01eoo`03001oogoo01ioo`03001oogoo01eoo`03001oogoo01eoo`03001oogoo01Io
o`AW>@03001W>FLi00UW>@Aoo`8000ioo`03001oogoo011oo`03001oogoo00eoo`03001oogoo01io
o`03001oogoo011oo`03001oogoo015oo`03001oogoo035oo`03001oogoo04Yoo`03001oogoo08Ao
o`03001oogoo0;5oo`03001oogoo00Moo`00>Woo00<007ooOol0@Woo00<007ooOol0:7oo00<007oo
Ool08goo00<007ooOol07goo00<007ooOol01Goo1`0047oo00<007ooOol06Goo00<007ooOol03goo
00<007ooOol02goo00<007ooOol01goo00@007oo001ooa1W>@Yoo`03001oogoo029oo`03001oogoo
02Aoo`03001oogoo01eoo`03001oogoo01ioo`03001oogoo01eoo`03001oogoo01eoo`03001oogoo
01Ioo`AW>@03001W>FLi00UW>@Aoo`8000aoo`8001Aoo`03001oogoo00]oo`03001oogoo01moo`03
001oogoo015oo`80015oo`03001oogoo035oo`03001oogoo04Uoo`03001oogoo08Eoo`03001oogoo
0;5oo`03001oogoo00Moo`00>Woo00<007ooOol0@Woo00<007ooOol0:7oo00<007ooOol08goo00<0
07ooOol07goo00<007ooOol00Woo2@004Goo00<007ooOol06Goo00<007ooOol03goo00<007ooOol0
37oo00<007ooOol01Woo00@007oo001ooa1W>@Yoo`03001oogoo029oo`03001oogoo02Aoo`03001o
ogoo01eoo`03001oogoo01ioo`03001oogoo01eoo`03001oogoo01eoo`03001oogoo01Ioo`AW>@03
001W>FLi00UW>@Aoo`8000]oo`03001oogoo01Eoo`03001oogoo00Yoo`03001oogoo01ioo`03001o
ogoo01Aoo`8000moo`03001oogoo035oo`03001oogoo04Uoo`03001oogoo08Eoo`03001oogoo0;5o
o`03001oogoo00Moo`00>Woo00<007ooOol0@Woo00<007ooOol0:7oo00<007ooOol097oo00<007oo
Ool07goo00<007ooOol02@004goo00<007ooOol06Goo00<007ooOol03Woo00<007ooOol03Goo00<0
07ooOol01Goo100046Li2Woo00<007ooOol08Woo00<007ooOol097oo00<007ooOol07Goo00<007oo
Ool07Woo00<007ooOol07Goo00<007ooOol07Goo00<007ooOol05Woo16Li00<006LiIcT02FLi17oo
0P002Woo00<007ooOol05goo00<007ooOol027oo00<007ooOol07goo00<007ooOol05Woo00<007oo
Ool02goo00<007ooOol0<Goo00<007ooOol0BWoo00<007ooOol0QGoo00<007ooOol0/Goo00<007oo
Ool01goo000jOol00`00Oomoo`12Ool00`00Oomoo`0XOol00`00Oomoo`0TOol00`00Oomoo`0OOol0
0`00Oomoo`03Ool200000goo0000000DOol00`00Oomoo`0JOol00`00Oomoo`0<Ool00`00Oomoo`0?
Ool20005Ool4000@IcT:Ool00`00Oomoo`0ROol00`00Oomoo`0TOol00`00Oomoo`0MOol00`00Oomo
o`0NOol00`00Oomoo`0MOol00`00Oomoo`0MOol00`00Oomoo`0FOol3IcT00`00IcUW>@0:IcT3Ool3
0008Ool2000JOol00`00Oomoo`07Ool00`00Oomoo`0OOol00`00Oomoo`0HOol00`00Oomoo`0:Ool0
0`00Oomoo`0aOol00`00Oomoo`1:Ool00`00Oomoo`25Ool00`00Oomoo`2aOol00`00Oomoo`07Ool0
03Yoo`03001oogoo049oo`03001oogoo02Qoo`03001oogoo02Aoo`03001oogoo01moo`04001oogoo
Ool20002Ool2000EOol00`00Oomoo`0JOol00`00Oomoo`0;Ool00`00Oomoo`0BOol20003Ool4000@
IcT:Ool00`00Ool0001N000;Ool00`00Oomoo`0NOol00`00Oomoo`0MOol00`00Oomoo`0LOol00`00
Oomoo`0GOol3IcT00`00IcUW>@0:IcT3Ool40005Ool2000MOol00`00Oomoo`06Ool00`00Oomoo`0O
Ool00`00Oomoo`0IOol2000:Ool00`00Oomoo`0aOol00`00Oomoo`1:Ool00`00Oomoo`25Ool00`00
Oomoo`2aOol00`00Oomoo`07Ool003Yoo`03001oogoo049oo`03001oogoo02Qoo`03001oogoo02Ao
o`03001oogoo021oo`03001oo`0000=oo`8001Moo`03001oogoo01Yoo`03001oogoo00Uoo`03001o
ogoo01Eoo`03001oogoo020002=oo`03001oogoo02Aoo`03001oogoo019ooel000aoo`03001oogoo
01Moo`=W>@03001W>FLi00YW>@=oo`@000=oo`80021oo`03001oogoo00Aoo`03001oogoo01moo`03
001oogoo01aoo`03001oogoo00Ioo`03001oogoo039oo`03001oogoo04Yoo`03001oogoo08Eoo`03
001oogoo0;5oo`03001oogoo00Moo`00>Woo00<007ooOol0@Woo00<007ooOol0:7oo00<007ooOol0
9Goo00<007ooOol07goo0P0017oo00<007ooOol05goo00<007ooOol06Woo00<007ooOol01goo00<0
07ooOol05goo1`003fLi2Woo00<007ooOol08Woo00<007ooOol097oo00<007ooOol07Goo00<007oo
Ool07Woo00<007ooOol07Goo00<007ooOol047oo6`002goo0fLi00<006LiIcT02VLi0goo100000=o
o`0000008goo00<007ooOol00Woo00<007ooOol07goo00<007ooOol07Woo0P001Woo00<007ooOol0
<Goo00<007ooOol0BWoo00<007ooOol0QWoo00<007ooOol0/Goo00<007ooOol01goo000jOol00`00
Oomoo`12Ool00`00Oomoo`0YOol00`00Oomoo`0TOol00`00Oomoo`0NOol00`00Ool00003Ool00`00
Oomoo`0HOol00`00Oomoo`0KOol00`00Oomoo`06Ool00`00Oomoo`0IOol5000?IcT:Ool00`00Oomo
o`0ROol00`00Oomoo`0TOol00`00Oomoo`0MOol00`00Oomoo`0NOol00`00Oomoo`0MOol00`00Oomo
o`0LOol00`00Oomoo`0<Ool=00000fLi001W>@0;IcT2Ool6000VOol01000Oomoo`008Woo00<007oo
Ool087oo00<007ooOol00Woo00<007ooOol0<Woo00<007ooOol0BWoo00<007ooOol0QWoo00<007oo
Ool0/Goo00<007ooOol01goo000jOol00`00Oomoo`12Ool00`00Oomoo`0YOol00`00Oomoo`0TOol0
0`00Oomoo`0LOol20002Ool00`00Oomoo`0MOol00`00Oomoo`0KOol00`00Oomoo`04Ool00`00Oomo
o`0JOol300000goo001W>@0>IcT:Ool00`00Oomoo`0ROol00`00Oomoo`0TOol00`00Oomoo`0MOol0
0`00Oomoo`0NOol00`00Oomoo`0MOol00`00Oomoo`0LOol00`00Oomoo`0GOol2IcTE00000goo001o
o`0TOol01000Oomoo`008Goo00<007ooOol08Woo00D007ooOomoo`0003Aoo`03001oogoo04Yoo`03
001oogoo08Eoo`03001oogoo0;9oo`03001oogoo00Moo`00>Woo00<007ooOol0@Woo00<007ooOol0
:Goo00<007ooOol09Goo00<007ooOol06Goo0P001Goo00<007ooOol077oo00<007ooOol077oo00<0
07ooOol00Woo00<007ooOol06goo00@007oo001oo`8000iW>@Yoo`03001oogoo029oo`03001oogoo
02Aoo`03001oogoo01eoo`03001oogoo01ioo`03001oogoo01eoo`03001oogoo01aoo`03001oogoo
01Moo`=W>@03001W>FLi00YW>@9oo`D00003Ool007oo02Eoo`80029oo`03001oogoo02=oo`800003
Ool007oo039oo`03001oogoo04]oo`03001oogoo08Eoo`03001oogoo0;9oo`03001oogoo00Moo`00
>Woo00<007ooOol0@Woo00<007ooOol0:Goo00<007ooOol09Goo00<007ooOol067oo00<007ooOol0
1Goo00<007ooOol07Goo00<007ooOol077oo00D007ooOomoo`0001aoo`800005Ool007ooIcT0000>
IcT:Ool00`00Oomoo`0ROol00`00Oomoo`0TOol00`00Oomoo`0MOol00`00Oomoo`0NOol00`00Oomo
o`0MOol00`00Oomoo`0LOol00`00Oomoo`0GOol3IcT00`00IcUW>@0:IcT2Ool01`00Ool007oo001o
o`0002Ioo`80025oo`03001oogoo02Ioo`03001oogoo039oo`03001oogoo04Yoo`03001oogoo08Io
o`03001oogoo0;9oo`03001oogoo00Moo`00>Woo00<007ooOol0@Woo00<007ooOol0:Goo00<007oo
Ool09Goo00<007ooOol05goo00<007ooOol01goo00<007ooOol07Goo00<007ooOol06goo00@007oo
Ool001eoo`800003Ool007oo011W>@Yoo`03001oogoo029oo`03001oogoo02Aoo`03001oogoo01eo
o`03001oogoo01ioo`03001oogoo01eoo`03001oogoo01aoo`03001oogoo01Moo`=W>@03001W>FLi
00YW>@07Ool00000Ool007oo00000Woo00<007ooOol08Goo0P0000=oo`00Ool07goo00<007ooOol0
9goo0`00<Woo00<007ooOol0BWoo00<007ooOol0QWoo00<007ooOol0/Woo00<007ooOol01goo000j
Ool00`00Oomoo`13Ool00`00Oomoo`0YOol00`00Oomoo`0UOol00`00Oomoo`0COol3000:Ool00`00
Oomoo`0MOol00`00Oomoo`0LOol00`00Ool0000NOol01000Ool007oo46Li2Woo00<007ooOol08Woo
00<007ooOol097oo00<007ooOol07Goo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol077oo
00<007ooOol05goo0fLi00<006LiIcT02VLi00Ioo`00Oomoo`00Ool200000goo001oo`0QOol00`00
Oomoo`02Ool00`00Oomoo`0MOol00`00Oomoo`0VOol01@00Oomoogoo0000<7oo00<007ooOol0Bgoo
00<007ooOol0QWoo00<007ooOol0/Woo00<007ooOol01goo000jOol00`00Oomoo`13Ool00`00Oomo
o`0YOol00`00Oomoo`0UOol00`00Oomoo`0BOol00`00Oomoo`0<Ool00`00Oomoo`0MOol00`00Oomo
o`0LOol00`00Oomoo`0MOol01000Ool007oo46Li2Woo00<007ooOol08Woo00<007ooOol097oo00<0
07ooOol07Goo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol077oo00<007ooOol05goo0fLi
00<006LiIcT02VLi17oo00H007ooOol007oo000QOol00`00Oomoo`03Ool00`00Oomoo`0LOol00`00
Oomoo`0WOol00`00Oomoo`02Ool3000]Ool00`00Oomoo`1;Ool00`00Oomoo`26Ool00`00Oomoo`2b
Ool00`00Oomoo`07Ool003Yoo`03001oogoo04=oo`03001oogoo02Uoo`03001oogoo02Eoo`03001o
ogoo00moo`<000moo`03001oogoo01ioo`03001oogoo01Yoo`03001oo`0001ioo`04001oo`00Ool@
IcT:Ool00`00Oomoo`0ROol00`00Oomoo`0TOol00`00Oomoo`0MOol00`00Oomoo`0NOol00`00Oomo
o`0MOol00`00Oomoo`0LOol00`00Oomoo`0GOol3IcT00`00IcUW>@0:IcT4Ool00`00Oomoo`03Ool0
0`00Oomoo`0MOol00`00Oomoo`05Ool00`00Oomoo`0JOol00`00Oomoo`0WOol00`00Oomoo`04Ool4
000[Ool00`00Oomoo`1:Ool00`00Oomoo`27Ool00`00Oomoo`2bOol00`00Oomoo`07Ool003Yoo`03
001oogoo04=oo`03001oogoo02Uoo`03001oogoo02Ioo`03001oogoo00eoo`03001oogoo011oo`03
001oogoo01ioo`03001oogoo01Uoo`05001oogooOol0000MOol01000Ool007oo46Li2Woo00<007oo
Ool08Woo00<007ooOol097oo00<007ooOol07Goo00<007ooOol07Woo00<007ooOol07Goo00<007oo
Ool077oo00<007ooOol05goo0fLi00<006LiIcT02VLi17oo00<007ooOol017oo00<007ooOol06goo
00<007ooOol01goo00<007ooOol06Goo00<007ooOol09goo00<007ooOol01Goo1P009goo00<007oo
Ool0Bgoo00<007ooOol0Qgoo00<007ooOol0/Woo00<007ooOol01goo000jOol00`00Oomoo`13Ool0
0`00Oomoo`0YOol00`00Oomoo`0VOol00`00Oomoo`0;Ool2000DOol00`00Oomoo`0NOol00`00Oomo
o`0GOol00`00Oomoo`03Ool00`00Oomoo`0JOol01000Ool007oo46Li2Woo00<007ooOol08Woo00<0
07ooOol097oo00<007ooOol07Goo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol077oo00<0
07ooOol05goo0fLi00<006LiIcT02VLi17oo00<007ooOol017oo00<007ooOol06Woo00<007ooOol0
2Goo00<007ooOol05goo00<007ooOol0:7oo00<007ooOol01Woo1`009Goo00<007ooOol0Bgoo00<0
07ooOol0QWoo00<007ooOol0/goo00<007ooOol01goo000jOol00`00Oomoo`13Ool00`00Oomoo`0Z
Ool00`00Oomoo`0UOol00`00Oomoo`09Ool2000FOol00`00Oomoo`0NOol00`00Oomoo`0GOol00`00
Oomoo`04Ool00`00Oomoo`0IOol01000Ool007oo46Li2Woo00<007ooOol08Woo00<007ooOol097oo
00<007ooOol07Goo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol077oo00<007ooOol05goo
0fLi00<006LiIcT02VLi17oo00<007ooOol017oo00<007ooOol06Goo00<007ooOol02goo00<007oo
Ool05Woo00<007ooOol09goo00<007ooOol027oo20008goo00<007ooOol0Bgoo00<007ooOol0QWoo
00<007ooOol0/goo00<007ooOol01goo000jOol00`00Oomoo`13Ool00`00Oomoo`0ZOol00`00Oomo
o`0VOol00`00Oomoo`06Ool2000HOol00`00Oomoo`0OOol00`00Oomoo`0EOol00`00Oomoo`06Ool0
0`00Oomoo`0HOol01000Ool007oo46Li2Woo00<007ooOol08Woo00<007ooOol097oo00<007ooOol0
7Goo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol077oo00<007ooOol05goo0fLi00<006Li
IcT02VLi17oo00<007ooOol01Goo00<007ooOol05goo00<007ooOol03Goo00<007ooOol057oo00<0
07ooOol0:7oo00<007ooOol02Goo0P0000=oo`00Ool00`008Goo00<007ooOol0Bgoo00<007ooOol0
Qgoo00<007ooOol0/goo00<007ooOol01goo000jOol50011Ool00`00Oomoo`0ZOol00`00Oomoo`0V
Ool00`00Oomoo`05Ool00`00Oomoo`0IOol00`00Oomoo`0OOol00`00Oomoo`0COol00`00Oomoo`08
Ool00`00Oomoo`0GOol01000Ool007oo46Li2Woo00<007ooOol08Woo00<007ooOol097oo00<007oo
Ool07Goo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol077oo00<007ooOol05goo0fLi00<0
06LiIcT02VLi17oo00<007ooOol01Goo00<007ooOol05Woo00<007ooOol03Woo00<007ooOol04goo
00<007ooOol0:7oo00<007ooOol02Woo0`0000=oo`00Ool08goo00<007ooOol0Bgoo00<007ooOol0
Qgoo00<007ooOol0[Woo1P002Goo000jOol00`00Oomoo`13Ool00`00Oomoo`0ZOol00`00Oomoo`0V
Ool00`00Oomoo`02Ool3000LOol00`00Oomoo`0OOol00`00Oomoo`0BOol00`00Oomoo`0:Ool00`00
Oomoo`0EOol01@00Oomoo`00Ool046Li2Woo00<007ooOol08Woo00<007ooOol097oo00<007ooOol0
7Goo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol077oo00<007ooOol05goo0fLi00<006Li
IcT02VLi17oo00<007ooOol01Woo00<007ooOol057oo00<007ooOol047oo00<007ooOol04Woo00<0
07ooOol0:7oo00<007ooOol02goo0P000Woo0P008Woo00<007ooOol0Bgoo00<007ooOol0Qgoo00<0
07ooOol0/goo00<007ooOol01goo000jOol00`00Oomoo`13Ool00`00Oomoo`0ZOol00`00Oomoo`0W
Ool01000Oomoo`0087oo00<007ooOol07goo00<007ooOol047oo00<007ooOol037oo00<007ooOol0
57oo00D007ooOol007oo011W>@Yoo`03001oogoo029oo`03001oogoo02Aoo`03001oogoo01eoo`03
001oogoo01ioo`03001oogoo01eoo`03001oogoo01aoo`03001oogoo01Moo`=W>@03001W>FLi00YW
>@Aoo`03001oogoo00Ioo`03001oogoo01=oo`03001oogoo019oo`03001oogoo011oo`03001oogoo
02Qoo`03001oogoo00eoo`8000=oo`8001moo`03001oogoo04aoo`03001oogoo08Moo`03001oogoo
0;=oo`03001oogoo00Moo`00>Woo00<007ooOol0@goo00<007ooOol0:goo00<007ooOol09Woo0`00
8Goo00<007ooOol087oo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol04goo00D007ooOol0
07oo011W>@Yoo`03001oogoo029oo`03001oogoo02Aoo`03001oogoo01eoo`03001oogoo01ioo`03
001oogoo01eoo`03001oogoo01aoo`03001oogoo01Moo`=W>@03001W>FLi00YW>@Aoo`03001oogoo
00Ioo`03001oogoo019oo`03001oogoo01Aoo`03001oogoo00ioo`03001oogoo02Qoo`03001oogoo
00moo`03001oogoo00=oo`03001oogoo01aoo`03001oogoo04]oo`03001oogoo08Qoo`03001oogoo
0;=oo`03001oogoo00Moo`00>Woo00<007ooOol0@goo00<007ooOol0:goo00<007ooOol09Goo0P00
97oo00<007ooOol07goo00<007ooOol03Woo00<007ooOol03goo00<007ooOol04Woo00<007oo0000
0Woo46Li2Woo00<007ooOol08Woo00<007ooOol097oo00<007ooOol07Goo00<007ooOol07Woo00<0
07ooOol07Goo00<007ooOol077oo00<007ooOol05goo0fLi00<006LiIcT02VLi17oo00<007ooOol0
1goo00<007ooOol047oo00<007ooOol05Woo00<007ooOol03Goo00<007ooOol0:7oo00<007ooOol0
47oo00<007ooOol00goo00<007ooOol06goo00<007ooOol0Bgoo00<007ooOol0R7oo00<007ooOol0
/goo00<007ooOol01goo000jOol00`00Oomoo`13Ool00`00Oomoo`0[Ool00`00Oomoo`0SOol20002
Ool00`00Oomoo`0QOol00`00Oomoo`0POol00`00Oomoo`0<Ool00`00Oomoo`0AOol00`00Oomoo`0A
Ool00`00Ool00002Ool@IcT:Ool00`00Oomoo`0ROol00`00Oomoo`0TOol00`00Oomoo`0MOol00`00
Oomoo`0NOol00`00Oomoo`0MOol00`00Oomoo`0LOol00`00Oomoo`0GOol3IcT00`00IcUW>@0:IcT4
Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool2000IOol00`00Oomoo`0<Ool00`00Oomoo`0XOol00`00
Oomoo`0HOol00`00Oomoo`0IOol00`00Oomoo`1<Ool00`00Oomoo`27Ool00`00Oomoo`2dOol00`00
Oomoo`07Ool003Yoo`03001oogoo04=oo`03001oogoo02]oo`03001oogoo029oo`03001oogoo009o
o`03001oogoo029oo`03001oogoo01moo`03001oogoo00]oo`03001oogoo01=oo`03001oogoo011o
o`03001oo`00009ooa1W>@Yoo`03001oogoo029oo`03001oogoo02Aoo`03001oogoo01eoo`03001o
ogoo01ioo`03001oogoo01eoo`03001oogoo01aoo`03001oogoo01Moo`=W>@03001W>FLi00YW>@Ao
o`03001oogoo00Qoo`03001oogoo00aoo`03001oogoo01Uoo`03001oogoo00aoo`03001oogoo02Qo
o`03001oogoo01Uoo`8001Uoo`03001oogoo04aoo`03001oogoo08Moo`03001oogoo0;Aoo`03001o
ogoo00Moo`00>Woo00<007ooOol0@goo00<007ooOol0;7oo00<007ooOol07Woo0`001Goo00<007oo
Ool08Woo00<007ooOol087oo00<007ooOol02Woo00<007ooOol057oo00<007ooOol03goo00<007oo
00000Woo46Li2Woo00<007ooOol08Woo00<007ooOol097oo00<007ooOol07Goo00<007ooOol07Woo
00<007ooOol07Goo00<007ooOol077oo00<007ooOol05goo0fLi00<006LiIcT02VLi17oo00<007oo
Ool027oo00<007ooOol02goo00<007ooOol06goo00<007ooOol02Woo00<007ooOol0:7oo00<007oo
Ool077oo00<007ooOol05Goo00<007ooOol0C7oo00<007ooOol0R7oo00<007ooOol0]7oo00<007oo
Ool01goo000jOol00`00Oomoo`13Ool00`00Oomoo`0/Ool00`00Oomoo`0MOol00`00Oomoo`07Ool0
0`00Oomoo`0ROol00`00Oomoo`0POol00`00Oomoo`08Ool00`00Oomoo`0FOol00`00Oomoo`0>Ool0
0`00Ool00002Ool@IcT:Ool00`00Oomoo`0ROol00`00Oomoo`0TOol00`00Oomoo`0MOol00`00Oomo
o`0NOol00`00Oomoo`0MOol00`00Oomoo`0LOol00`00Oomoo`0GOol3IcT00`00IcUW>@0:IcT4Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0MOol00`00Oomoo`08Ool00`00Oomoo`0XOol0
0`00Oomoo`0NOol2000EOol00`00Oomoo`1<Ool00`00Oomoo`28Ool00`00Oomoo`2dOol00`00Oomo
o`07Ool003Yoo`03001oogoo04Aoo`03001oogoo02]oo`03001oogoo01Yoo`<000Yoo`03001oogoo
02=oo`03001oogoo021oo`03001oogoo00Ioo`03001oogoo01Qoo`03001oogoo00eoo`03001oo`00
009ooa1W>@Yoo`03001oogoo025oo`03001oogoo02Eoo`03001oogoo01eoo`03001oogoo01ioo`03
001oogoo01eoo`03001oogoo01aoo`03001oogoo01Moo`=W>@03001W>FLi00YW>@Aoo`03001oogoo
00Uoo`03001oogoo00Qoo`03001oogoo01moo`03001oogoo00Ioo`03001oogoo02Uoo`03001oogoo
021oo`03001oogoo019oo`03001oogoo04aoo`03001oogoo08Qoo`03001oogoo0;Aoo`03001oogoo
00Moo`00>Woo00<007ooOol0A7oo00<007ooOol0:goo00<007ooOol06Goo00<007ooOol037oo00<0
07ooOol08Woo00<007ooOol087oo00<007ooOol01Woo00<007ooOol06Goo00<007ooOol037oo00<0
07oo00000Woo46Li2Woo00<007ooOol08Goo00<007ooOol09Goo00<007ooOol07Goo00<007ooOol0
7Woo00<007ooOol07Goo00<007ooOol077oo00<007ooOol05goo0fLi00<006LiIcT02VLi17oo00<0
07ooOol02Woo00<007ooOol01Goo0P008goo00<007ooOol017oo00<007ooOol0:Goo00<007ooOol0
8Woo00<007ooOol047oo00<007ooOol0CGoo00<007ooOol0R7oo00<007ooOol0]7oo00<007ooOol0
1goo000jOol00`00Oomoo`14Ool00`00Oomoo`0[Ool00`00Oomoo`0GOol2000?Ool00`00Oomoo`0S
Ool00`00Oomoo`0POol00`00Oomoo`04Ool00`00Oomoo`0KOol00`00Oomoo`0;Ool00`00Ool00002
Ool@IcT:Ool00`00Oomoo`0QOol00`00Oomoo`0UOol00`00Oomoo`0MOol00`00Oomoo`0NOol00`00
Oomoo`0MOol00`00Oomoo`0LOol00`00Oomoo`0GOol3IcT00`00IcUW>@0:IcT5Ool00`00Oomoo`09
Ool00`00Oomoo`04Ool00`00Oomoo`0SOol00`00Oomoo`03Ool00`00Oomoo`0ZOol00`00Oomoo`0S
Ool2000@Ool00`00Oomoo`1<Ool00`00Oomoo`29Ool00`00Oomoo`2dOol00`00Oomoo`07Ool003Yo
o`03001oogoo04Aoo`03001oogoo02aoo`03001oogoo01=oo`<0015oo`03001oogoo02=oo`03001o
ogoo025oo`03001oogoo009oo`03001oogoo01eoo`03001oogoo00Yoo`03001oo`00009ooa1W>@Yo
o`03001oogoo025oo`03001oogoo02Eoo`03001oogoo01eoo`03001oogoo01ioo`03001oogoo01eo
o`03001oogoo01aoo`03001oogoo01Moo`=W>@03001W>FLi00YW>@Eoo`03001oogoo00Yoo`03001o
ogoo009oo`03001oogoo02Eoo`05001oogooOol0000/Ool00`00Oomoo`0VOol00`00Oomoo`0<Ool0
0`00Oomoo`1=Ool00`00Oomoo`29Ool00`00Oomoo`2dOol00`00Oomoo`07Ool003Yoo`03001oogoo
04Aoo`03001oogoo02aoo`03001oogoo019oo`03001oogoo01=oo`03001oogoo02=oo`03001oogoo
025oo`04001oogoo000QOol00`00Oomoo`09Ool00`00Ool00002Ool@IcT:Ool00`00Oomoo`0QOol0
0`00Oomoo`0UOol00`00Oomoo`0MOol00`00Oomoo`0NOol00`00Oomoo`0MOol00`00Oomoo`0LOol0
0`00Oomoo`0GOol3IcT00`00IcUW>@0:IcT6Ool00`00Oomoo`09Ool01@00Oomoogoo0000:Goo00<0
07oo0000;Goo00<007ooOol09goo00<007ooOol02goo00<007ooOol0CGoo00<007ooOol0RGoo00<0
07ooOol0]7oo00<007ooOol01goo000jOol00`00Oomoo`14Ool00`00Oomoo`0/Ool00`00Oomoo`0?
Ool3000FOol00`00Oomoo`0SOol00`00Oomoo`0QOol00`00Ool0000SOol00`00Oomoo`07Ool20000
17oo001oogoo46Li2Woo00<007ooOol08Goo00<007ooOol09Goo00<007ooOol07Goo00<007ooOol0
7Woo00<007ooOol07Goo00<007ooOol077oo00<007ooOol05goo0fLi00<006LiIcT02VLi1goo00<0
07ooOol02Goo00<007oo0000:goo00<007ooOol0:goo00<007ooOol0:Goo0P002goo00<007ooOol0
C7oo00<007ooOol0RGoo00<007ooOol0]Goo00<007ooOol01goo000jOol00`00Oomoo`14Ool00`00
Oomoo`0/Ool00`00Oomoo`0=Ool2000IOol00`00Oomoo`0TOol00`00Oomoo`0QOol00`00Oomoo`0S
Ool00`00Oomoo`06Ool2000017oo001oogoo46Li2Woo00<007ooOol08Goo00<007ooOol09Goo00<0
07ooOol07Goo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol077oo00<007ooOol05goo0fLi
00<006LiIcT02VLi1goo00<007ooOol02Goo0P00:goo00@007oo000002Yoo`03001oogoo02aoo`03
001oogoo00Moo`03001oogoo04eoo`03001oogoo08Uoo`03001oogoo0;Eoo`03001oogoo00Moo`00
>Woo00<007ooOol0A7oo00<007ooOol0;Goo00<007ooOol02Goo0`0077oo00<007ooOol08goo00<0
07ooOol087oo00<007oo00009Goo00<007ooOol01Goo10000Woo46Li2Woo00<007ooOol08Goo00<0
07ooOol09Goo00<007ooOol07Goo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol077oo00<0
07ooOol05goo0fLi00<006LiIcT02VLi1goo00<007ooOol027oo0`00:Woo00<007ooOol00`00:Goo
00<007ooOol0;Goo00<007ooOol01Woo00<007ooOol0CGoo00<007ooOol0RGoo00<007ooOol0]Goo
00<007ooOol01goo000jOol00`00Oomoo`14Ool00`00Oomoo`0]Ool00`00Oomoo`08Ool00`00Oomo
o`0MOol00`00Oomoo`0TOol00`00Oomoo`0OOol01000Oomoo`009Goo0P0017oo1@000Woo46Li2Woo
00<007ooOol08Goo00<007ooOol09Goo00<007ooOol07Goo00<007ooOol07Woo00<007ooOol07Goo
00<007ooOol077oo00<007ooOol05goo0fLi00<006LiIcT02VLi27oo00<007ooOol01Goo0P0000Ao
o`00000002Qoo`03001oogoo009oo`<002Moo`03001oogoo02moo`8000Eoo`03001oogoo04eoo`03
001oogoo08Yoo`03001oogoo0;Eoo`03001oogoo00Moo`00>Woo00<007ooOol0A7oo00<007ooOol0
;Goo00<007ooOol01Woo0P0087oo00<007ooOol09Goo00<007ooOol07Goo00<007ooOol00Woo00<0
07ooOol097oo00@007ooOomoo`D0009ooa1W>@Yoo`03001oogoo025oo`03001oogoo02Eoo`03001o
ogoo01eoo`03001oogoo01ioo`03001oogoo01eoo`03001oogoo01aoo`03001oogoo01Moo`=W>@03
001W>FLi00YW>@Uoo`03001oogoo00=oo`03001oogoo009oo`<002Ioo`03001oogoo00=oo`@002Io
o`03001oogoo035oo`03001oogoo009oo`03001oogoo04eoo`03001oogoo08Yoo`03001oogoo0;Eo
o`03001oogoo00Moo`00>Woo00<007ooOol0A7oo00<007ooOol0;Goo00<007ooOol00goo0`008goo
00<007ooOol097oo00<007ooOol077oo00<007ooOol017oo00<007ooOol097oo00<007ooOol01@00
0Woo46Li2Woo00<007ooOol08Goo00<007ooOol09Goo00<007ooOol07Goo00<007ooOol07Woo00<0
07ooOol07Goo00<007ooOol077oo00<007ooOol05goo0fLi00<006LiIcT02VLi2Goo00<007ooOol0
0Woo00<007ooOol00goo100097oo00<007ooOol017oo1@0097oo00<007ooOol0<goo00@007ooOol0
04moo`03001oogoo08]oo`03001oogoo0;Eoo`03001oogoo00Moo`00>Woo00<007ooOol0A7oo00<0
07ooOol0;Woo1@009Woo00<007ooOol09Goo00<007ooOol06Woo00<007ooOol01Woo00<007ooOol0
97oo1`000Woo46Li2Woo00<007ooOol08Goo00<007ooOol09Goo00<007ooOol07Goo00<007ooOol0
7Woo00<007ooOol07Goo00<007ooOol077oo00<007ooOol05goo0fLi00<006LiIcT02VLi2Goo00<0
07ooOol00P001Woo0P0000=oo`00Ool08Woo00<007ooOol01Woo1@008Woo00<007ooOol0=Goo00<0
07oo0000Cgoo00<007ooOol0RWoo00<007ooOol0]Woo00<007ooOol01goo000jOol00`00Oomoo`14
Ool00`00Oomoo`0[Ool5000ZOol00`00Oomoo`0UOol00`00Oomoo`0HOol00`00Oomoo`08Ool00`00
Oomoo`0TOol50003Ool@IcT:Ool00`00Oomoo`0QOol00`00Oomoo`0UOol00`00Oomoo`0MOol00`00
Oomoo`0NOol00`00Oomoo`0MOol00`00Oomoo`0LOol00`00Oomoo`0GOol3IcT00`00IcUW>@0:IcT:
Ool20008Ool300000goo001oo`0POol00`00Oomoo`07Ool2000017oo0000000087oo00<007ooOol0
=goo0P00Cgoo00<007ooOol0RWoo00<007ooOol0]Woo00<007ooOol01goo000jOol00`00Oomoo`15
Ool00`00Oomoo`0VOol8000[Ool00`00Oomoo`0UOol00`00Oomoo`0GOol00`00Oomoo`0:Ool00`00
Oomoo`0SOol300000goo001oo`02Ool@IcT:Ool00`00Oomoo`0QOol00`00Oomoo`0UOol00`00Oomo
o`0MOol00`00Oomoo`0NOol00`00Oomoo`0MOol00`00Oomoo`0LOol00`00Oomoo`0GOol3IcT00`00
IcUW>@0:IcT:Ool00`00Oomoo`07Ool2000017oo001oo`007goo00<007ooOol027oo0`000Woo0P00
7Woo00<007ooOol0>7oo00<007oo0000CGoo00<007ooOol0Rgoo00<007ooOol0]Woo00<007ooOol0
1goo000jOol00`00Oomoo`15Ool00`00Oomoo`0TOol:000/Ool00`00Oomoo`0UOol00`00Oomoo`0E
Ool00`00Oomoo`0;Ool00`00Oomoo`0ROol200000goo0000000300000gooIcUW>@0>IcT:Ool00`00
Oomoo`0QOol00`00Oomoo`0UOol00`00Oomoo`0MOol00`00Oomoo`0NOol00`00Oomoo`0MOol00`00
Oomoo`0LOol00`00Oomoo`0GOol3IcT00`00IcUW>@0:IcT8Ool200000goo001oo`07Ool200001Goo
001oogoo00007Goo00<007ooOol02Woo00<007oo00000goo00<007ooOol06Woo00<007ooOol0>7oo
00@007ooOomoo`8004]oo`03001oogoo08]oo`03001oogoo0;Ioo`03001oogoo00Moo`00>Woo00<0
07ooOol0AGoo00<007ooOol09Woo0`0000Eoo`00001oo`0002aoo`03001oogoo02Ioo`03001oogoo
01Aoo`03001oogoo00aoo`03001oogoo025oo`05001oogoo001oo`0200000goo00000005000:IcT9
Ool00`00Oomoo`0ROol00`00Oomoo`0UOol00`00Oomoo`0MOol00`00Oomoo`0NOol00`00Oomoo`0M
Ool00`00Oomoo`0LOol00`00Oomoo`0GOol3IcT00`00IcUW>@0:IcT7Ool01@00Oomoogoo00002Goo
00@007ooOol001ioo`03001oogoo00]oo`800003Ool007oo01ioo`03001oogoo03Qoo`03001oogoo
00=oo`03001oogoo04Qoo`03001oogoo08Yoo`03001oogoo0;Moo`03001oogoo00Moo`00>Woo00<0
07ooOol0AGoo00<007ooOol08goo0`000goo00<007ooOol00Woo00<007ooOol0:Woo00<007ooOol0
9Goo00<007ooOol04goo00<007ooOol03Woo00<007ooOol08Woo00<007ooOol00P000Woo1VLi2P00
2Goo00<007ooOol08Woo00<007ooOol09Goo00<007ooOol07Goo00<007ooOol07Woo00<007ooOol0
7Goo00<007ooOol077oo00<007ooOol05goo0fLi00<006LiIcT02VLi1Woo00<007ooOol00goo00<0
07ooOol01Woo00@007ooOol001eoo`03001oogoo00aoo`80009oo`03001oogoo01]oo`03001oogoo
03Qoo`03001oogoo00Eoo`03001oogoo04Ioo`03001oogoo08]oo`03001oogoo0;Moo`03001oogoo
00Moo`00>Woo00<007ooOol0AGoo00<007ooOol087oo0`001Goo00<007ooOol00goo00<007ooOol0
:Woo00<007ooOol09Woo00<007ooOol047oo0P004Woo00<007ooOol08Goo00@007ooOol000=ooa1W
>@d0025oo`03001oogoo02Eoo`03001oogoo01eoo`03001oogoo01ioo`03001oogoo01eoo`03001o
ogoo01aoo`03001oogoo01Moo`=W>@03001W>FLi00UW>@L000Ioo`03001oogoo00Ioo`04001oogoo
000LOol00`00Oomoo`0>Ool01000Oomoo`0077oo00<007ooOol0>7oo00<007ooOol01goo00<007oo
Ool0AGoo00<007ooOol0Rgoo00<007ooOol0]goo00<007ooOol01goo000jOol00`00Oomoo`15Ool0
0`00Oomoo`0MOol30007Ool00`00Oomoo`04Ool00`00Oomoo`0ZOol00`00Oomoo`0WOol00`00Oomo
o`0>Ool3000COol00`00Oomoo`0OOol01@00Oomoogoo00000goo46Li2Goo00@007ooOomooa/000Io
o`03001oogoo02Eoo`03001oogoo01eoo`03001oogoo01ioo`03001oogoo01eoo`03001oogoo01ao
o`03001oogoo01Moo`03IcT0000000`00003IcUoogoo00]oo`03001oogoo00Uoo`03001oogoo01Qo
o`03001oogoo00moo`05001oogooOol0000JOol00`00Oomoo`0iOol00`00Oomoo`08Ool00`00Oomo
o`14Ool00`00Oomoo`2;Ool00`00Oomoo`2gOol00`00Oomoo`07Ool003Yoo`03001oogoo04Eoo`03
001oogoo01]oo`8000Uoo`03001oogoo00Eoo`03001oogoo02]oo`03001oogoo02Moo`03001oogoo
00]oo`@001Eoo`03001oogoo01ioo`05001oogooOol00003Ool@IcT9Ool00`00Oomoo`0LOol=000Q
Ool00`00Oomoo`0MOol00`00Oomoo`0NOol00`00Oomoo`0MOol00`00Oomoo`0LOolK0002IcT00`00
IcUW>@0:IcT>Ool00`00Oomoo`09Ool00`00Oomoo`0FOol00`00Oomoo`0EOol00`00Oomoo`0FOol0
0`00Oomoo`0iOol00`00Oomoo`0:Ool00`00Oomoo`12Ool00`00Oomoo`2<Ool00`00Oomoo`2gOol0
0`00Oomoo`07Ool003Yoo`03001oogoo04Eoo`03001oogoo01Moo`@001=oo`03001oogoo02]oo`03
001oogoo02Moo`03001oogoo00Yoo`D001Eoo`03001oogoo01eoo`03001oogoo009oo`04001oogoo
Ool@IcT9Ool00`00Oomoo`0ROol00`00Oomoo`04OolK0006Ool00`00Oomoo`0MOol00`00Oomoo`0N
Ool00`00Oomoo`0MOol01000Oomoogoo6`0000=oo`00Ool05goo16Li00<006LiIcT02FLi3Woo00<0
07ooOol02Goo00<007ooOol05Goo00<007ooOol05goo00<007ooOol057oo00<007ooOol0>Woo00<0
07ooOol02goo00<007ooOol0@Goo00<007ooOol0Rgoo00<007ooOol0^7oo00<007ooOol01goo000j
Ool00`00Oomoo`15Ool00`00Oomoo`0DOol3000HOol00`00Oomoo`0[Ool00`00Oomoo`0WOol00`00
Oomoo`08Ool5000GOol00`00Oomoo`0LOol00`00Oomoo`02Ool01000Oomoogoo46Li2Goo00<007oo
Ool08Woo00<007ooOol07gooJ`0077oo00<007ooOol05Woo16Li00<006LiIcT02FLi3Woo00<007oo
Ool02Goo00<007ooOol057oo00<007ooOol067oo00<007ooOol057oo00<007ooOol0>Goo00<007oo
Ool03Goo00<007ooOol0@7oo00<007ooOol0Rgoo00<007ooOol0^7oo00<007ooOol01goo000jOol0
0`00Oomoo`16Ool00`00Oomoo`0?Ool4000KOol00`00Oomoo`0[Ool00`00Oomoo`0XOol00`00Oomo
o`05Ool7000HOol00`00Oomoo`0JOol00`00Oomoo`03Ool01000Oomoogoo46Li2Goo00<007ooOol0
8Woo00<007ooOol09Goo00<007ooOol07Goo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol0
7Goo00<007ooOol05Woo16Li00<006LiIcT02FLi3goo00<007ooOol02Goo00<007ooOol04Woo00<0
07ooOol06Goo00<007ooOol04goo00<007ooOol0>Woo00<007ooOol03Woo0`00?Woo00<007ooOol0
S7oo00<007ooOol0^7oo00<007ooOol01goo000jOol00`00Oomoo`16Ool00`00Oomoo`0;Ool4000O
Ool00`00Oomoo`0/Ool00`00Oomoo`0WOol00`00Oomoo`04Ool400000goo0000000JOol00`00Oomo
o`0HOol00`00Oomoo`04Ool01000Oomoogoo46Li2Goo00<007ooOol08Woo00<007ooOol09Goo00<0
07ooOol07Goo00<007ooOol07Woo0P007Woo00<007ooOol07Goo00<007ooOol05Woo16Li00<006Li
IcT02FLi3goo00<007ooOol02Woo00<007ooOol047oo00<007ooOol06goo00<007ooOol04Goo00<0
07ooOol0>Woo00<007ooOol04Woo00<007ooOol0>goo00<007ooOol0S7oo00<007ooOol0^7oo00<0
07ooOol01goo000jOol00`00Oomoo`16Ool00`00Oomoo`07Ool4000TOol00`00Oomoo`0[Ool00`00
Oomoo`0XOol00`00Oomoo`02Ool20003Ool3000KOol00`00Oomoo`0FOol00`00Oomoo`04Ool00`00
Oomoo`02Ool@IcT9Ool00`00Oomoo`0ROol00`00Oomoo`0UOol00`00Oomoo`0MOol00`00Oomoo`0N
Ool2000NOol00`00Oomoo`0MOol00`00Oomoo`0FOol4IcT00`00IcUW>@09IcT@Ool00`00Oomoo`09
Ool00`00Oomoo`0?Ool00`00Oomoo`0MOol00`00Oomoo`0@Ool00`00Oomoo`0jOol00`00Oomoo`0C
Ool00`00Oomoo`0jOol00`00Oomoo`2;Ool00`00Oomoo`2iOol00`00Oomoo`07Ool003Yoo`D004Ao
o`03001oogoo00=oo`@002Qoo`03001oogoo02aoo`03001oogoo02Qoo`03001oogoo00Eoo`04001o
o`00000LOol2000FOol00`00Oomoo`04Ool00`00Oomoo`02Ool@IcT9Ool00`00Oomoo`0ROol00`00
Oomoo`0TOol2000OOol00`00Oomoo`0MOol3000NOol00`00Oomoo`0MOol00`00Oomoo`0FOol4IcT0
0`00IcUW>@09IcT@Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool2000QOol00`00Oomoo`0>Ool00`00
Oomoo`0jOol00`00Oomoo`0EOol00`00Oomoo`0hOol00`00Oomoo`2<Ool00`00Oomoo`2dOol60009
Ool003Yoo`03001oogoo04Ioo`H002aoo`03001oogoo02aoo`03001oogoo02Uoo`03001oogoo00=o
o`04001oogoo000OOol00`00Oomoo`0BOol00`00Oomoo`05Ool00`00Oomoo`02Ool@IcT9Ool00`00
Oomoo`0ROol00`00Oomoo`0TOol2000OOol00`00Oomoo`0MOol4000LOol3000MOol3000GOol4IcT0
0`00IcUW>@09IcTAOol00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`0ROol00`00Oomoo`0<
Ool00`00Oomoo`0kOol00`00Oomoo`0FOol00`00Oomoo`0gOol00`00Oomoo`2<Ool00`00Oomoo`2i
Ool00`00Oomoo`07Ool003Yoo`03001oogoo049oo`D0039oo`03001oogoo02aoo`03001oogoo02Uo
o`05001oogooOol00002Ool2000POol2000BOol00`00Oomoo`05Ool00`00Oomoo`02Ool@IcT8Ool2
000TOol00`00Oomoo`0TOol2000NOol3000NOol4000LOol3000MOol3000GOol4IcT00`00IcUW>@09
IcTAOol00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0SOol00`00Oomoo`0;Ool00`00Oomo
o`0kOol00`00Oomoo`0HOol00`00Oomoo`0eOol00`00Oomoo`2=Ool00`00Oomoo`2iOol00`00Oomo
o`07Ool003Yoo`03001oogoo03]oo`L000Aoo`03001oogoo031oo`03001oogoo02aoo`03001oogoo
02Yoo`04001oogoo0002Ool00`00Oomoo`0QOol00`00Oomoo`0>Ool00`00Oomoo`06Ool00`00Oomo
o`02Ool@IcT8Ool2000SOol3000UOol3000MOol3000NOol4000LOol3000MOol3000GOol4IcT00`00
IcUW>@09IcTBOol00`00Oomoo`09Ool00`00Oomoo`07Ool2000WOol00`00Oomoo`09Ool00`00Oomo
o`0kOol00`00Oomoo`0JOol00`00Oomoo`0dOol00`00Oomoo`2=Ool00`00Oomoo`2iOol00`00Oomo
o`07Ool003Yoo`03001oogoo031oo`/000]oo`03001oogoo031oo`03001oogoo02eoo`03001oogoo
02Uoo`03001oo`0002Qoo`03001oogoo00eoo`03001oogoo00Ioo`03001oogoo009ooa1W>@Qoo`<0
029oo`<002Aoo`@001eoo`<001ioo`D001]oo`<001eoo`<001Moo`AW>@03001W>FLi00UW>A9oo`03
001oogoo00Yoo`03001oogoo00Eoo`03001oogoo02Qoo`03001oogoo00Moo`03001oogoo03]oo`03
001oogoo01aoo`03001oogoo039oo`03001oogoo08ioo`03001oogoo0;Uoo`03001oogoo00Moo`00
>Woo00<007ooOol09Woo2P005goo00<007ooOol0<7oo00<007ooOol0;Goo00<007ooOol0:Goo00<0
07ooOol0:7oo00<007ooOol02goo00<007ooOol01goo00<007ooOol00Woo46Li1goo10008Woo0`00
97oo10007Goo0`007Woo0P0000=oo`0000006Woo1@006goo1@005Woo16Li00<006LiIcT02FLi4Woo
00<007ooOol02goo00<007ooOol00goo00<007ooOol0:Goo00<007ooOol01Woo00<007ooOol0>goo
00<007ooOol07Woo0P00<Woo00<007ooOol0SGoo00<007ooOol0^Woo00<007ooOol01goo000jOol0
0`00Oomoo`17Ool00`00Oomoo`0`Ool00`00Oomoo`0]Ool00`00Oomoo`0XOol00`00Ool0000ZOol0
0`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`02Ool@IcT7Ool4000ROol3000TOol4000LOol5
000LOol300000goo0000000JOol200000goo0000000KOol5000FOol4IcT00`00IcUW>@09IcTCOol0
0`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol00`00Oomoo`05Ool00`00Oomoo`0lOol0
0`00Oomoo`0POol00`00Oomoo`0^Ool00`00Oomoo`2>Ool00`00Oomoo`2jOol00`00Oomoo`07Ool0
03Yoo`03001oogoo04Moo`03001oogoo031oo`03001oogoo02ioo`03001oogoo02Ioo`05001oogoo
Ool0000ZOol00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`03Ool@IcT7Ool4000QOol5000R
Ool5000LOol5000LOol00`00Ool00002Ool2000IOol200000goo0000000KOol5000FOol4IcT00`00
IcUW>@09IcTDOol00`00Oomoo`09Ool00`00Oomoo`02000^Ool00`00Oomoo`03Ool00`00Oomoo`0l
Ool00`00Oomoo`0ROol00`00Oomoo`0]Ool00`00Oomoo`2>Ool00`00Oomoo`2jOol00`00Oomoo`07
Ool003Yoo`03001oogoo04Moo`03001oogoo035oo`03001oogoo02eoo`03001oogoo02Eoo`03001o
ogoo00=oo`03001oogoo02Qoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Aooa1W>@Io
o`D0025oo`800003Ool00000029oo`D001aoo`D001aoo`03001oo`0000=oo`03001oogoo01Moo`03
001oogoo008001]oo`05001oo`00Ool0000FOol4IcT00`00IcUW>@09IcTDOol00`00Oomoo`0:Ool2
000aOol01@00Oomoogoo0000?Woo00<007ooOol097oo00<007ooOol0:goo00<007ooOol0SWoo00<0
07ooOol0^goo00<007ooOol01goo000jOol00`00Oomoo`17Ool00`00Oomoo`0aOol00`00Oomoo`0^
Ool00`00Oomoo`0TOol00`00Oomoo`04Ool00`00Oomoo`0XOol00`00Oomoo`05Ool00`00Oomoo`06
Ool00`00Oomoo`05Ool@IcT6Ool200000goo0000000QOol200000goo0000000ROol01000Ool007oo
0P006goo00D007oo001oo`0001ioo`03001oogoo01Yoo`80009oo`<001Uoo`800003Ool007oo0080
01Eoo`AW>@03001W>FLi00UW>AEoo`03001oogoo00Uoo`80039oo`03001oo`0003ioo`03001oogoo
02Ioo`03001oogoo02Yoo`03001oogoo08ioo`03001oogoo0;]oo`03001oogoo00Moo`00>Woo00<0
07ooOol0Agoo00<007ooOol0<Woo00<007ooOol0;Goo00<007ooOol08goo00<007ooOol01Woo00<0
07ooOol0:7oo00<007ooOol00goo00<007ooOol01goo00<007ooOol01Goo46Li1Woo0`0000=oo`00
000087oo0P000Woo00<007ooOol07goo0P0000=oo`00Ool00P006Woo0P0000=oo`00Ool00P007Goo
00<007ooOol06Woo00L007ooOomoo`00Ool0000IOol01000Oomoo`000Woo00<007ooOol04goo16Li
00<006LiIcT02FLi5Goo00<007ooOol01goo0P0000=oo`00Ool0<Goo0P00?goo00<007ooOol09goo
00<007ooOol0:7oo00<007ooOol0Sgoo00<007ooOol0^goo00<007ooOol01goo000jOol00`00Oomo
o`17Ool00`00Oomoo`0bOol00`00Oomoo`0^Ool00`00Oomoo`0QOol00`00Oomoo`07Ool00`00Oomo
o`0YOol01@00Oomoogoo00002Woo00<007ooOol01Goo46Li1Goo0P0000Eoo`00Oomoo`0001moo`<0
009oo`80021oo`04001oogoo0002Ool00`00Oomoo`0HOol01000Oomoo`000Woo00<007ooOol06goo
00<007ooOol07Woo00<007ooOol077oo00<007ooOol05Woo16Li00<006LiIcT02FLi5Woo00<007oo
Ool01Goo00D007ooOomoo`00035oo`03001oo`0003ioo`03001oogoo02Uoo`03001oogoo02Moo`03
001oogoo08moo`03001oogoo0;]oo`03001oogoo00Moo`00>Woo00<007ooOol0Agoo00<007ooOol0
<Woo00<007ooOol0;goo00<007ooOol07goo00<007ooOol02Goo00<007ooOol0:Goo00@007ooOol0
00Uoo`03001oogoo00Iooa1W>@Eoo`04001oogoo0002Ool00`00Oomoo`0MOol00`00Ool00003Ool0
0`00Oomoo`0QOol00`00Oomoo`0NOol00`00Oomoo`0NOol00`00Oomoo`0NOol00`00Oomoo`0LOol0
0`00Oomoo`0FOol4IcT00`00IcUW>@09IcTFOol00`00Oomoo`03Ool20005Ool00`00Oomoo`0]Ool0
1@00Oomoogoo0000?7oo00<007ooOol0:goo00<007ooOol09Goo00<007ooOol0Sgoo00<007ooOol0
_7oo00<007ooOol01goo000jOol00`00Oomoo`18Ool00`00Oomoo`0bOol00`00Oomoo`0_Ool00`00
Oomoo`0MOol00`00Oomoo`0;Ool00`00Oomoo`0YOol20009Ool00`00Oomoo`07Ool@IcT8Ool00`00
Oomoo`0ROol00`00Oomoo`0UOol00`00Oomoo`0NOol00`00Oomoo`0NOol00`00Oomoo`0NOol00`00
Oomoo`0LOol00`00Oomoo`0FOol4IcT00`00IcUW>@09IcTGOol01@00Oomoogoo00001goo00<007oo
Ool0;7oo00<007ooOol00Woo00<007ooOol0>Woo00<007ooOol0;7oo00<007ooOol097oo00<007oo
Ool0Sgoo00<007ooOol0_7oo00<007ooOol01goo000jOol00`00Oomoo`18Ool00`00Oomoo`0bOol0
0`00Oomoo`0_Ool00`00Oomoo`0LOol00`00Oomoo`0=Ool00`00Oomoo`0XOol20009Ool00`00Oomo
o`07Ool@IcT8Ool00`00Oomoo`0ROol00`00Oomoo`0UOol00`00Oomoo`0NOol00`00Oomoo`0NOol0
0`00Oomoo`0NOol00`00Oomoo`0LOol00`00Oomoo`0FOol4IcT00`00IcUW>@09IcTGOol01000Ool0
00002Goo00<007ooOol0:Woo00<007ooOol00goo00<007ooOol0>Goo00<007ooOol0;Woo00<007oo
Ool08Woo00<007ooOol0T7oo00<007ooOol0_7oo00<007ooOol01goo000jOol00`00Oomoo`18Ool0
0`00Oomoo`0bOol00`00Oomoo`0`Ool00`00Oomoo`0KOol00`00Oomoo`0>Ool00`00Oomoo`0VOol0
1000Oomoo`001goo00<007ooOol027oo46Li27oo00<007ooOol08Woo00<007ooOol09Goo00<007oo
Ool07Woo00<007ooOol07Woo00<007ooOol07Woo00<007ooOol077oo00<007ooOol05Woo1FLi00<0
06LiIcT026Li5goo0P002goo00<007ooOol0:Goo00<007ooOol01Goo00<007ooOol0=goo00<007oo
Ool0<7oo100087oo00<007ooOol0Sgoo00<007ooOol0_Goo00<007ooOol01goo000jOol00`00Oomo
o`18Ool00`00Oomoo`0cOol00`00Oomoo`0`Ool00`00Oomoo`0IOol00`00Oomoo`0@Ool00`00Oomo
o`0UOol01@00Oomoogoo00001Goo00<007ooOol02Goo46Li27oo00<007ooOol08Woo00<007ooOol0
9Goo00<007ooOol07Woo00<007ooOol07Woo00<007ooOol07Woo00<007ooOol077oo00<007ooOol0
5Woo1FLi00<006LiIcT026Li5goo0P002goo00<007ooOol0:7oo00<007ooOol01goo00<007ooOol0
=Goo00<007ooOol0<goo10007Goo00<007ooOol0T7oo00<007ooOol0_Goo00<007ooOol01goo000j
Ool00`00Oomoo`18Ool00`00Oomoo`0cOol00`00Oomoo`0`Ool00`00Oomoo`0HOol00`00Oomoo`0B
Ool00`00Oomoo`0TOol00`00Oomoo`02Ool01@00Oomoogoo000037oo46Li27oo00<007ooOol08Woo
00<007ooOol09Goo00<007ooOol07Woo00<007ooOol07Woo00<007ooOol07Woo00<007ooOol077oo
00<007ooOol05Woo1FLi00<006LiIcT026Li5Woo00@007ooOol000]oo`03001oogoo02Ioo`03001o
ogoo00Uoo`03001oogoo03Aoo`03001oogoo03Aoo`D001]oo`03001oogoo091oo`03001oogoo0;eo
o`03001oogoo00Moo`00>Woo00<007ooOol0B7oo00<007ooOol0=7oo00<007ooOol0<7oo00<007oo
Ool05goo00<007ooOol04goo0P008goo00<007ooOol017oo00@007ooOol000aooa1W>@Qoo`03001o
ogoo029oo`03001oogoo02Eoo`03001oogoo01ioo`03001oogoo01ioo`03001oogoo01ioo`03001o
ogoo01eoo`03001oogoo01Eoo`AW>@<000UW>AEoo`05001oogooOol0000<Ool00`00Oomoo`0TOol0
0`00Oomoo`0:Ool00`00Oomoo`0cOol00`00Oomoo`0fOol5000IOol00`00Oomoo`2@Ool00`00Oomo
o`2nOol00`00Oomoo`07Ool003Yoo`03001oogoo04Qoo`03001oogoo03Aoo`03001oogoo035oo`03
001oogoo01Eoo`03001oogoo01Ioo`03001oogoo01moo`03001oogoo00Ioo`03001oo`0000aooa1W
>@Qoo`03001oogoo029oo`03001oogoo02Eoo`03001oogoo01ioo`03001oogoo01ioo`03001oogoo
01ioo`03001oogoo01eoo`03001oogoo01Eoo`AW>@<000UW>AAoo`03001oogoo009oo`03001oogoo
00Yoo`03001oogoo02=oo`03001oogoo00aoo`03001oogoo035oo`03001oogoo03Moo`L001Moo`03
001oogoo091oo`03001oogoo0;ioo`03001oogoo00Moo`00>Woo00<007ooOol0BGoo00<007ooOol0
=7oo00<007ooOol0<7oo00<007ooOol057oo00<007ooOol067oo00<007ooOol07Woo00<007ooOol0
1goo00<007ooOol02goo46Li27oo00<007ooOol08Woo00<007ooOol09Goo00<007ooOol07Woo00<0
07ooOol07Woo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol05Goo16Li0`002FLi4Woo0P00
1Woo00<007ooOol02Goo00<007ooOol08Woo00<007ooOol03Woo00<007ooOol0;goo00<007ooOol0
>Goo0`0000=oo`0000000P0057oo00<007ooOol0TGoo00<007ooOol0_Woo00<007ooOol01goo000j
Ool00`00Oomoo`19Ool00`00Oomoo`0dOol00`00Oomoo`0aOol00`00Oomoo`0COol00`00Oomoo`0I
Ool00`00Oomoo`0LOol00`00Oomoo`07Ool00`00Ool0000<Ool@IcT8Ool00`00Oomoo`0ROol00`00
Oomoo`0UOol00`00Oomoo`0NOol00`00Oomoo`0NOol00`00Oomoo`0NOol00`00Oomoo`0MOol00`00
Oomoo`0EOol4IcT30009IcTAOol00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`0POol00`00
Oomoo`0?Ool00`00Oomoo`0_Ool00`00Oomoo`0jOol30003Ool2000BOol00`00Oomoo`2AOol00`00
Oomoo`2oOol00`00Oomoo`07Ool003Yoo`03001oogoo04Uoo`03001oogoo03Aoo`03001oogoo039o
o`03001oogoo015oo`03001oogoo01]oo`03001oogoo01]oo`03001oogoo00Ioo`05001oogooOol0
000;Ool@IcT8Ool00`00Oomoo`0ROol00`00Oomoo`0UOol00`00Oomoo`0NOol00`00Oomoo`0NOol0
0`00Oomoo`0NOol00`00Oomoo`0MOol00`00Oomoo`0EOol3IcT50008IcT?Ool2000:Ool00`00Oomo
o`0:Ool00`00Oomoo`0MOol2000BOol00`00Oomoo`0^Ool00`00Oomoo`0kOol200000goo001oo`0E
Ool00`00Oomoo`2AOol00`00Oomoo`2oOol00`00Oomoo`07Ool003Yoo`03001oogoo04Uoo`03001o
ogoo03Eoo`03001oogoo039oo`03001oogoo00moo`03001oogoo01eoo`03001oogoo01Uoo`03001o
ogoo00Moo`03001oogoo009oo`03001oogoo00Qooa1W>@Moo`03001oogoo02=oo`03001oogoo02Eo
o`03001oogoo01ioo`03001oogoo01ioo`03001oogoo01ioo`03001oogoo01eoo`03001oogoo01Eo
o`=W>@D000QW>@ioo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo01aoo`03001oogoo01=o
o`03001oogoo02aoo`03001oogoo03eoo`800003Ool007oo01=oo`03001oogoo099oo`03001oogoo
0;moo`03001oogoo00Moo`00>Woo00<007ooOol0BGoo00<007ooOol0=Goo00<007ooOol0<Woo00<0
07ooOol03Woo00<007ooOol07goo00<007ooOol067oo00<007ooOol01Woo00<007ooOol017oo00<0
07ooOol01goo46Li1goo00<007ooOol08goo00<007ooOol09Goo00<007ooOol07Woo00<007ooOol0
7Woo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol05Goo0fLi1@0026Li3Goo00<007ooOol0
37oo00<007ooOol02Goo00<007ooOol06Woo0P005goo00<007ooOol0:goo00<007ooOol0?Goo0P00
0Woo00<007ooOol04Goo00<007ooOol0TGoo00<007ooOol0`7oo00<007ooOol01goo000jOol00`00
Oomoo`1:Ool00`00Oomoo`0eOol00`00Oomoo`0bOol00`00Oomoo`0<Ool00`00Oomoo`0QOol00`00
Oomoo`0FOol00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`06Ool@IcT7Ool00`00Oomoo`0R
Ool00`00Oomoo`0VOol00`00Oomoo`0NOol00`00Oomoo`0NOol00`00Oomoo`0NOol00`00Oomoo`0M
Ool00`00Oomoo`0EOol3IcT01@00IcT006Li000026Li2goo0P003goo00<007ooOol02Woo00<007oo
Ool067oo00<007ooOol067oo00<007ooOol0:Goo00<007ooOol0?goo00@007ooOol0019oo`03001o
ogoo099oo`03001oogoo0<1oo`03001oogoo00Moo`00>Woo00<007ooOol0BWoo00<007ooOol0=Goo
00<007ooOol0<goo00<007ooOol02Woo00<007ooOol08goo00<007ooOol057oo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01Goo46Li1goo00<007ooOol08Woo00<007ooOol09Woo00<007oo
Ool07Woo00<007ooOol07goo00<007ooOol07Goo00<007ooOol07Goo00<007ooOol05Goo0VLi0P00
00=W>@00IcT00P001fLi2Woo00<007ooOol047oo00<007ooOol02Goo00<007ooOol05goo00<007oo
Ool06Goo00<007ooOol0:7oo00<007ooOol0@Goo00@007ooOol0011oo`03001oogoo09=oo`03001o
ogoo0<1oo`03001oogoo00Moo`00>Woo00<007ooOol0BWoo00<007ooOol0=Woo00<007ooOol0<Woo
00<007ooOol02Woo00<007ooOol097oo00<007ooOol04Woo00<007ooOol027oo00<007ooOol027oo
00<007ooOol017oo46Li1goo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol07Woo00<007oo
Ool07goo00<007ooOol07Goo00<007ooOol07Goo00<007ooOol05Goo0VLi00@006LiIcT0009W>@03
001W>FLi00EW>@Qoo`8001=oo`03001oogoo00Yoo`03001oogoo01Aoo`8001aoo`03001oogoo02Mo
o`03001oogoo04Ioo`03001oogoo00eoo`03001oogoo099oo`03001oogoo0<5oo`03001oogoo00Mo
o`00>Woo00<007ooOol0BWoo00<007ooOol0=Woo00<007ooOol0<goo00<007ooOol027oo00<007oo
Ool09Woo00<007ooOol04Goo00<007ooOol01goo00<007ooOol02Woo1@0000=oofLiIcT03VLi1goo
00<007ooOol08Woo00<007ooOol09Woo00<007ooOol07Woo00<007ooOol07goo00<007ooOol07Goo
00<007ooOol07Goo00<007ooOol05Goo1VLi00<006LiIcT01fLi1goo00<007ooOol04goo00<007oo
Ool02Woo00<007ooOol04goo00<007ooOol07Goo00<007ooOol09Goo00<007ooOol0B7oo0P0037oo
00<007ooOol0Tgoo00<007ooOol0`Goo00<007ooOol01goo000jOol00`00Oomoo`1:Ool00`00Oomo
o`0fOol00`00Oomoo`0dOol00`00Oomoo`06Ool00`00Oomoo`0XOol00`00Oomoo`0@Ool00`00Oomo
o`06Ool00`00Oomoo`0@Ool7000:IcT7Ool00`00Oomoo`0ROol00`00Oomoo`0VOol00`00Oomoo`0N
Ool00`00Oomoo`0OOol00`00Oomoo`0MOol00`00Oomoo`0MOol00`00Oomoo`0EOol6IcT00`00IcUW
>@07IcT6Ool00`00Oomoo`0EOol00`00Oomoo`09Ool00`00Oomoo`0AOol2000QOol00`00Oomoo`0S
Ool00`00Oomoo`1;Ool00`00Oomoo`09Ool00`00Oomoo`2COol00`00Oomoo`31Ool00`00Oomoo`07
Ool003Yoo`03001oogoo04Yoo`03001oogoo03Moo`03001oogoo03=oo`03001oogoo00Eoo`03001o
ogoo02Yoo`03001oogoo00ioo`03001oogoo00Moo`03001oogoo015oo`IW>@H000AW>@Moo`03001o
ogoo029oo`03001oogoo02Ioo`03001oogoo01ioo`03001oogoo01moo`03001oogoo01ioo`03001o
ogoo01aoo`03001oogoo01Eoo`IW>@03001W>FLi00MW>@9oo`@001Uoo`03001oogoo00Uoo`03001o
ogoo00moo`03001oogoo025oo`03001oogoo029oo`03001oogoo04eoo`03001oogoo00Moo`03001o
ogoo09=oo`03001oogoo0<9oo`03001oogoo00Moo`00>Woo00<007ooOol0Bgoo00<007ooOol0=Woo
00<007ooOol0=7oo00<007ooOol00goo00<007ooOol0;7oo00<007ooOol03Goo00<007ooOol01Woo
00<007ooOol04Woo36Li1`0017oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol07Woo00<0
07ooOol07goo00<007ooOol07Woo00<007ooOol077oo00<007ooOol05Goo1VLi00<006LiIcT00VLi
1`007Goo00<007ooOol02Woo00<007ooOol03Goo00<007ooOol08goo00<007ooOol087oo00<007oo
Ool0Cgoo00<007ooOol01Goo00<007ooOol0U7oo00<007ooOol0`Woo00<007ooOol01goo000jOol0
0`00Oomoo`1;Ool00`00Oomoo`0gOol00`00Oomoo`0dOol00`00Oomoo`02Ool00`00Oomoo`0]Ool0
0`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`0BOol@IcT3Ool5000TOol00`00Oomoo`0VOol0
0`00Oomoo`0NOol00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0LOol00`00Oomoo`0EOol6
IcT50005IcTOOol00`00Oomoo`0:Ool00`00Oomoo`0;Ool2000WOol00`00Oomoo`0NOol00`00Oomo
o`1AOol00`00Oomoo`04Ool00`00Oomoo`2DOol00`00Oomoo`32Ool00`00Oomoo`07Ool003Yoo`D0
04Uoo`03001oogoo03Moo`03001oogoo03Eoo`04001oogoo000aOol2000:Ool00`00Oomoo`07Ool0
0`00Oomoo`0COol@IcT6Ool00`00Ool00006000MOol00`00Oomoo`0VOol00`00Oomoo`0NOol00`00
Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0MOol00`00Oomoo`0COol80009IcTPOol00`00Oomo
o`09Ool00`00Oomoo`09Ool2000YOol00`00Oomoo`0LOol2001EOol00`00Oomoo`02Ool00`00Oomo
o`2DOol00`00Oomoo`2nOol60009Ool003Yoo`03001oogoo04]oo`03001oogoo03Moo`03001oogoo
03Ioo`03001oo`0003=oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo01=ooa1W>@Ioo`03
001oogoo00Ioo`P001Eoo`03001oogoo02Eoo`03001oogoo01moo`03001oogoo01moo`03001oogoo
01ioo`03001oogoo01eoo`03001oogoo00]oo`P00003OomW>FLi00AW>@03001W>FLi00MW>B1oo`03
001oogoo00Yoo`03001oogoo00Moo`03001oogoo02Uoo`03001oogoo01]oo`03001oogoo05Ioo`05
001oogooOol0002FOol00`00Oomoo`33Ool00`00Oomoo`07Ool003Yoo`03001oogoo04]oo`03001o
ogoo03Qoo`03001oogoo03Ioo`03001oogoo03=oo`03001oogoo00Ioo`03001oogoo00Ioo`03001o
ogoo01Aooa1W>@Ioo`03001oogoo00ioo`L000ioo`03001oogoo02Eoo`03001oogoo01moo`03001o
ogoo01moo`03001oogoo01ioo`03001oogoo01eoo`03001oogoo00Aoo`L000Uoo`IW>@03001W>FLi
00MW>B5oo`03001oogoo00Uoo`03001oogoo00Eoo`8002eoo`03001oogoo01Uoo`03001oogoo05Qo
o`03001oo`0009Ioo`03001oogoo0<Aoo`03001oogoo00Moo`00>Woo00<007ooOol0Bgoo00<007oo
Ool0>7oo00<007ooOol0=Goo00<007oo0000=Goo0P001Goo00<007ooOol01goo00<007ooOol057oo
46Li1Woo00<007ooOol05Goo1P0027oo00<007ooOol09Goo00<007ooOol07goo00<007ooOol07goo
00<007ooOol07Woo00<007ooOol07Goo1`0047oo1VLi00<006LiIcT01fLi8Goo00<007ooOol02Woo
00<007ooOol00Woo0P00<7oo00<007ooOol05goo00<007ooOol0FWoo0P00UWoo00<007ooOol0a7oo
00<007ooOol01goo000jOol00`00Oomoo`1<Ool00`00Oomoo`0hOol00`00Oomoo`0cOol01@00Oomo
ogoo0000=Woo00D007ooOomoo`0000Yoo`03001oogoo01Aooa1W>@Ioo`03001oogoo01]oo`L00003
Ool007oo02Ioo`03001oogoo01moo`03001oogoo01moo`03001oogoo01ioo`03001oogoo01Moo`L0
01Ioo`IW>@03001W>FLi00MW>B5oo`03001oogoo00Yoo`05001oogooOol0000bOol00`00Oomoo`0E
Ool2001MOol2002FOol00`00Oomoo`34Ool00`00Oomoo`07Ool003Yoo`03001oogoo04aoo`03001o
ogoo03Qoo`03001oogoo03=oo`03001oogoo009oo`03001oogoo03Aoo`800003Ool007oo00Qoo`03
001oogoo01Eooa1W>@Ioo`03001oogoo029oo`X001moo`03001oogoo01moo`03001oogoo01moo`03
001oogoo01ioo`03001oogoo00eoo`X000Ioo`03001oogoo01Aoo`IW>@03001W>FLi00MW>B9oo`03
001oogoo00Uoo`04001oo`00000cOol00`00Oomoo`0DOol00`00Oomoo`1LOol01000Oomoo`00U7oo
00<007ooOol0aGoo00<007ooOol01goo000jOol00`00Oomoo`1<Ool00`00Oomoo`0iOol00`00Oomo
o`0aOol00`00Oomoo`04Ool00`00Oomoo`0eOol00`00Oomoo`07Ool00`00Oomoo`0FOol@IcT6Ool0
0`00Oomoo`0ROol00`00Oomoo`07Ool>000AOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0NOol00`00Ool0000=000@Ool00`00Oomoo`0DOol6IcT00`00IcUW>@07IcTROol00`00Oomoo`0:
Ool00`00Oomoo`0dOol00`00Oomoo`0BOol00`00Oomoo`1MOol01@00Oomoogoo0000Tgoo00<007oo
Ool0aGoo00<007ooOol01goo000jOol00`00Oomoo`1<Ool00`00Oomoo`0iOol00`00Oomoo`0`Ool0
0`00Oomoo`06Ool00`00Oomoo`0dOol20007Ool00`00Oomoo`0GOol@IcT6Ool00`00Oomoo`0ROol0
0`00Oomoo`0EOol=0004Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0COol=000NOol0
0`00Oomoo`0DOol7IcT00`00IcUW>@06IcTROol00`00Oomoo`08Ool3000gOol00`00Oomoo`0@Ool0
0`00Oomoo`1MOol00`00Oomoo`03Ool00`00Oomoo`2?Ool00`00Oomoo`36Ool00`00Oomoo`07Ool0
03Yoo`03001oogoo04aoo`03001oogoo03Yoo`03001oogoo02ioo`03001oogoo00Qoo`03001oogoo
039oo`03001oogoo008000Eoo`03001oogoo01Mooa1W>@Ioo`03001oogoo029oo`03001oogoo029o
o`h001Qoo`03001oogoo01moo`03001oogoo00Eoo`h000]oo`03001oogoo01eoo`03001oogoo01Ao
o`MW>@03001W>FLi00IW>B9oo`8000Moo`80009oo`03001oogoo03Eoo`03001oogoo00moo`03001o
ogoo05eoo`03001oogoo00Eoo`03001oogoo08ioo`03001oogoo0<Ioo`03001oogoo00Moo`00>Woo
00<007ooOol0CGoo00<007ooOol0>Woo00<007ooOol0;7oo00<007ooOol02Woo00<007ooOol0<Goo
00<007ooOol00Woo00@007ooOomoo`8001Uooa1W>@Ioo`03001oogoo029oo`03001oogoo02Ioo`03
001oogoo00Mood8001Uoo`03001oogoo01eoo`03001oogoo01Aoo`MW>@03001W>FLi00IW>B9oo`<0
00Aoo`8000Eoo`03001oogoo03Eoo`03001oogoo00aoo`80061oo`03001oogoo00Ioo`03001oogoo
08eoo`03001oogoo0<Ioo`03001oogoo00Moo`00>Woo00<007ooOol0CGoo00<007ooOol0>Woo00<0
07ooOol0;7oo00<007ooOol02goo00<007ooOol0;goo00<007ooOol017oo00<007oo00000P006Goo
46Li1Goo00<007ooOol08goo00<007ooOol09Woo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool07Woo00<007ooOol07Goo00<007ooOol057oo1fLi00<006LiIcT01VLi8goo0P000Woo0P001goo
00<007ooOol0=Goo00<007ooOol02goo00<007ooOol0Ggoo00<007ooOol027oo00<007ooOol0Rgoo
00<007ooOol0agoo00<007ooOol01goo000jOol00`00Oomoo`1=Ool00`00Oomoo`0kOol00`00Oomo
o`0ZOol00`00Oomoo`0=Ool00`00Oomoo`0^Ool00`00Oomoo`05Ool3000JOol@IcT5Ool00`00Oomo
o`0SOol00`00Oomoo`0VOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomo
o`0NOol00`00Oomoo`0COol7IcT00`00IcUW>@06IcTSOol40009Ool00`00Oomoo`0eOol00`00Oomo
o`0:Ool00`00Oomoo`1OOol00`00Oomoo`0:Ool00`00Oomoo`2:Ool00`00Oomoo`37Ool00`00Oomo
o`07Ool003Yoo`03001oogoo04eoo`03001oogoo03]oo`03001oogoo02Uoo`03001oogoo00moo`03
001oogoo02eoo`03001oogoo00Aoo`@001Yooa1W>@Eoo`03001oogoo02=oo`03001oogoo02Ioo`03
001oogoo01moo`03001oogoo01moo`03001oogoo01ioo`03001oogoo01ioo`03001oogoo01=oo`MW
>@03001W>FLi00IW>B=oo`@000Yoo`03001oogoo03Eoo`03001oogoo00Qoo`03001oogoo061oo`03
001oogoo00]oo`03001oogoo08Qoo`03001oogoo0<Qoo`03001oogoo00Moo`00>Woo00<007ooOol0
CGoo00<007ooOol0?7oo00<007ooOol09goo00<007ooOol04Goo00<007ooOol0:goo00<007ooOol0
1Goo1@006Goo46Li1Goo00<007ooOol08goo00<007ooOol09Woo00<007ooOol07goo00<007ooOol0
7goo00<007ooOol07Woo00<007ooOol07Woo00<007ooOol04goo1fLi00<006LiIcT01VLi8Goo1000
00=oo`0000002Goo00<007ooOol0=Woo00<007ooOol01Woo00<007ooOol0H7oo00<007ooOol037oo
00<007ooOol0R7oo00<007ooOol0b7oo00<007ooOol01goo000jOol00`00Oomoo`1=Ool00`00Oomo
o`0lOol00`00Oomoo`0WOol00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`05Ool2000017oo
000007oo0P005goo46Li1Goo00<007ooOol08goo00<007ooOol09Woo00<007ooOol07goo00<007oo
Ool07goo00<007ooOol07Woo00<007ooOol07Woo00<007ooOol04goo1fLi00<006LiIcT01VLi7goo
0P000Woo0`0000=oo`00Ool027oo00<007ooOol0=Woo00<007ooOol01Goo00<007ooOol0H7oo00<0
07ooOol03Woo00<007ooOol0QWoo00<007ooOol0bGoo00<007ooOol01goo000jOol00`00Oomoo`1>
Ool00`00Oomoo`0lOol00`00Oomoo`0VOol00`00Oomoo`0COol00`00Oomoo`0XOol00`00Oomoo`04
Ool2000017oo000000000goo00<007ooOol057oo46Li1Goo00<007ooOol08goo00<007ooOol09Woo
00<007ooOol07goo00<007ooOol07goo00<007ooOol07Woo00<007ooOol07Woo00<007ooOol04goo
26Li00<006LiIcT01FLi7Goo0P0017oo0`000Woo00<007ooOol01goo00<007ooOol0=Goo00<007oo
Ool017oo00<007ooOol0HGoo00<007ooOol03goo00<007ooOol0QGoo00<007ooOol0bGoo00<007oo
Ool01goo000jOol00`00Oomoo`1>Ool00`00Oomoo`0lOol00`00Oomoo`0UOol00`00Oomoo`0EOol0
0`00Oomoo`0WOol00`00Oomoo`03Ool01@00Oomoo`00Ool00P0017oo00<007ooOol04goo46Li17oo
00<007ooOol097oo00<007ooOol09Woo00<007ooOol07goo00<007ooOol07goo00<007ooOol07Woo
00<007ooOol07Woo00<007ooOol04goo26Li00<006LiIcT01FLi77oo00<007ooOol01Goo0P000goo
00<007ooOol01Woo00<007ooOol0=Woo00<007ooOol00Woo00<007ooOol0HGoo00<007ooOol04Goo
00<007ooOol0Q7oo00<007ooOol0bGoo00<007ooOol01goo000jOol00`00Oomoo`1>Ool00`00Oomo
o`0mOol00`00Oomoo`0SOol00`00Oomoo`0GOol2000VOol00`00Oomoo`03Ool01P00Oomoogoo001o
o`8000Eoo`8001=ooa1W>@Aoo`03001oogoo02=oo`03001oogoo02Moo`03001oogoo01moo`03001o
ogoo01moo`03001oogoo01moo`03001oogoo01eoo`03001oogoo01=oo`QW>@03001W>FLi00EW>AYo
o`8000Qoo`03001oo`0000]oo`03001oogoo03Moo`04001oo`00001SOol00`00Oomoo`0COol00`00
Oomoo`22Ool00`00Oomoo`3:Ool00`00Oomoo`07Ool003Yoo`03001oogoo04ioo`03001oogoo03eo
o`03001oogoo029oo`03001oogoo01Yoo`03001oogoo02=oo`03001oogoo00Moo`03001oo`0000Qo
o`80015ooa1W>@Aoo`03001oogoo02=oo`03001oogoo02Moo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo01moo`03001oogoo01eoo`03001oogoo01=oo`QW>@03001W>FLi00EW>AQoo`8000Yo
o`03001oo`0000aoo`03001oogoo03Ioo`8006Aoo`03001oogoo01Eoo`03001oogoo085oo`03001o
ogoo0<Yoo`03001oogoo00Moo`00>Woo00<007ooOol0CWoo00<007ooOol0?Woo00<007ooOol087oo
00<007ooOol077oo0P008goo00<007ooOol01Woo00@007ooOol000Yoo`03001oogoo00iooa1W>@Ao
o`03001oogoo02=oo`03001oogoo02Moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo01eoo`03001oogoo01=oo`QW>@03001W>FLi00EW>AIoo`8000ioo`03001oogoo00Yo
o`03001oogoo03Eoo`8006Aoo`03001oogoo01Moo`03001oogoo07moo`03001oogoo0<]oo`03001o
ogoo00Moo`00>Woo00<007ooOol0Cgoo00<007ooOol0?Woo00<007ooOol07goo00<007ooOol07Woo
00<007ooOol07goo00<007ooOol01Woo00D007ooOomoo`0000]oo`03001oogoo00eooa1W>@Aoo`03
001oogoo02=oo`03001oogoo02Moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03
001oogoo01eoo`03001oogoo01=oo`QW>@03001W>FLi00EW>AAoo`80015oo`03001oogoo00Uoo`03
001oogoo03=oo`80009oo`03001oogoo061oo`03001oogoo01Uoo`03001oogoo07ioo`03001oogoo
0<]oo`03001oogoo00Moo`00>Woo00<007ooOol0Cgoo00<007ooOol0?Woo00<007ooOol07Woo00<0
07ooOol087oo00<007ooOol07Woo00<007ooOol01Woo00<007ooOol03Woo0P003Goo46Li17oo00<0
07ooOol08goo00<007ooOol09goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol07Woo00<007ooOol04Woo2FLi00<006LiIcT016Li4Woo0P004goo00<007ooOol02Woo00<0
07ooOol0<7oo0P0017oo00<007ooOol0Ggoo00<007ooOol06goo00<007ooOol0O7oo00<007ooOol0
c7oo00<007ooOol01goo000jOol00`00Oomoo`1?Ool00`00Oomoo`0oOol00`00Oomoo`0LOol00`00
Oomoo`0ROol2000MOol00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool@IcT4Ool00`00
Oomoo`0SOol00`00Oomoo`0WOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0NOol00`00Oomoo`0BOol9IcT00`00IcUW>@04IcTAOol00`00Oomoo`0COol00`00Oomoo`0:
Ool00`00Oomoo`0_Ool00`00Oomoo`05Ool00`00Oomoo`1NOol00`00Oomoo`0LOol00`00Oomoo`1k
Ool00`00Oomoo`3<Ool00`00Oomoo`07Ool003Yoo`03001oogoo04moo`03001oogoo03moo`03001o
ogoo01]oo`03001oogoo02Eoo`03001oogoo01Yoo`03001oogoo00Ioo`03001oogoo019oo`03001o
ogoo00Uooa1W>@=oo`03001oogoo02Aoo`03001oogoo02Moo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo01moo`03001oogoo01ioo`03001oogoo019oo`UW>@03001W>FLi00AW>@moo`8001Mo
o`03001oogoo00Uoo`03001oogoo02eoo`8000Qoo`03001oogoo05eoo`03001oogoo01eoo`03001o
ogoo07Yoo`03001oogoo0<eoo`03001oogoo00Moo`00>Woo00<007ooOol0D7oo00<007ooOol0?goo
00<007ooOol06Goo00<007ooOol09goo0P006Woo00<007ooOol01Woo00<007ooOol04goo00<007oo
Ool027oo46Li0goo00<007ooOol097oo00<007ooOol09goo00<007ooOol07goo00<007ooOol07goo
00<007ooOol07goo00<007ooOol07Woo00<007ooOol04Woo2FLi00<006LiIcT016Li3Woo00<007oo
Ool05goo00<007ooOol02Woo00<007ooOol0:Woo0P002Woo00<007ooOol0G7oo00<007ooOol07goo
00<007ooOol0NGoo00<007ooOol0cGoo00<007ooOol01goo000jOol00`00Oomoo`1@Ool00`00Oomo
o`10Ool00`00Oomoo`0HOol00`00Oomoo`0YOol2000GOol00`00Oomoo`07Ool00`00Oomoo`0DOol2
0008Ool@IcT3Ool00`00Oomoo`0TOol00`00Oomoo`0WOol00`00Oomoo`0OOol00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0BOol:IcT00`00IcUW>@03IcT<Ool2000JOol0
0`00Oomoo`0:Ool00`00Oomoo`0YOol00`00Oomoo`0;Ool00`00Oomoo`1JOol00`00Oomoo`0QOol0
0`00Oomoo`1gOol00`00Oomoo`3>Ool00`00Oomoo`07Ool003Yoo`03001oogoo051oo`03001oogoo
045oo`03001oogoo01Moo`03001oogoo02]oo`03001oogoo01Aoo`03001oogoo00Ioo`03001oogoo
01Moo`03001oogoo00Eooa=W>@03001W>FLi02AW>@03001W>FLi02MW>@03001W>FLi01mW>@03001W
>FLi01mW>@03001W>FLi01mW>@03001W>FLi01iW>@03001W>FLi01aW>@03001W>FLi00=W>@Yoo`80
01eoo`03001oogoo00Uoo`03001oogoo02Moo`8000moo`03001oogoo05Qoo`03001oogoo02=oo`03
001oogoo07Ioo`03001oogoo0<ioo`03001oogoo00Moo`00>Woo00<007ooOol0D7oo00<007ooOol0
@Goo00<007ooOol05Woo00<007ooOol0;Goo0P0057oo00<007ooOol01Woo00<007ooOol067oo00<0
07ooOol017oo4fLi00<006LiIcT096Li00<006LiIcT09VLi00<006LiIcT086Li00<006LiIcT07fLi
00<006LiIcT07fLi00<006LiIcT07VLi00<006LiIcT076Li00<006LiIcT00fLi2Goo00<007ooOol0
7Goo00<007ooOol02Woo00<007ooOol097oo0P004Goo00<007ooOol0Egoo00<007ooOol09Goo00<0
07ooOol0M7oo00<007ooOol0cgoo00<007ooOol01goo000jOol00`00Oomoo`1AOol00`00Oomoo`11
Ool00`00Oomoo`0DOol00`00Oomoo`0`Ool2000AOol00`00Oomoo`07Ool00`00Oomoo`0IOol20004
OolBIcT00`00IcUW>@0TIcT00`00IcUW>@0WIcT00`00IcUW>@0PIcT00`00IcUW>@0OIcT00`00IcUW
>@0OIcT00`00IcUW>@0NIcT00`00IcUW>@0LIcT00`00IcUW>@03IcT7Ool2000POol00`00Oomoo`0:
Ool00`00Oomoo`0SOol00`00Oomoo`0AOol00`00Oomoo`1FOol00`00Oomoo`0WOol00`00Oomoo`1c
Ool00`00Oomoo`3?Ool00`00Oomoo`07Ool003Yoo`03001oogoo055oo`03001oogoo049oo`03001o
ogoo019oo`03001oogoo03=oo`03001oogoo00ioo`03001oogoo00Moo`03001oogoo01]oo`80009o
oa9W>@03001W>FLi02AW>@03001W>FLi02MW>@03001W>FLi021W>@03001W>FLi01mW>@03001W>FLi
01mW>@03001W>FLi01iW>@03001W>FLi01eW>@03001W>FLi009W>@Ioo`03001oogoo021oo`03001o
ogoo00Yoo`03001oogoo025oo`8001Eoo`03001oogoo05Aoo`03001oogoo02Uoo`03001oogoo075o
o`03001oogoo0=1oo`03001oogoo00Moo`00>Woo00<007ooOol0DGoo00<007ooOol0@Woo00<007oo
Ool04Woo00<007ooOol0=7oo0P003Woo00<007ooOol01Woo00<007ooOol07Woo0P004VLi00<006Li
IcT096Li00<006LiIcT09fLi00<006LiIcT086Li00<006LiIcT07fLi00<006LiIcT07fLi00<006Li
IcT07fLi00<006LiIcT076Li00<006LiIcT00VLi17oo0P008goo00<007ooOol02Woo00<007ooOol0
7goo0P005goo00<007ooOol0Dgoo00<007ooOol0:goo00<007ooOol0L7oo00<007ooOol0d7oo00<0
07ooOol01goo000jOol00`00Oomoo`1AOol00`00Oomoo`13Ool00`00Oomoo`0@Ool00`00Oomoo`0g
Ool2000;Ool00`00Oomoo`07Ool00`00Oomoo`0POol2000?IcT00`00IcUW>@0UIcT00`00IcUW>@0W
IcT00`00IcUW>@0PIcT00`00IcUW>@0OIcT00`00IcUW>@0OIcT00`00IcUW>@0OIcT00`00IcUW>@0L
IcT00`00IcUW>@02IcT2Ool2000VOol00`00Oomoo`09Ool00`00Oomoo`0NOol00`00Oomoo`0HOol0
0`00Oomoo`1AOol00`00Oomoo`0]Ool00`00Oomoo`1^Ool00`00Oomoo`3AOol00`00Oomoo`07Ool0
03Yoo`03001oogoo059oo`03001oogoo04=oo`03001oogoo00ioo`03001oogoo03Yoo`8000Uoo`03
001oogoo00Moo`03001oogoo021oo`9W>@8000eW>@03001W>FLi02EW>@03001W>FLi02MW>@03001W
>FLi021W>@03001W>FLi01mW>@03001W>FLi01mW>@03001W>FLi01mW>@03001W>FLi01eW>@04001W
>FLiIcT2000XOol00`00Oomoo`0:Ool00`00Oomoo`0KOol2000KOol00`00Oomoo`1@Ool00`00Oomo
o`0^Ool00`00Oomoo`1^Ool00`00Oomoo`3AOol00`00Oomoo`07Ool003Yoo`D0051oo`03001oogoo
04Aoo`03001oogoo00]oo`8003moo`8000Moo`03001oogoo00Ioo`03001oogoo025oo`AW>@03001W
>FLi00YW>@03001W>FLi02EW>@03001W>FLi02MW>@03001W>FLi021W>@03001W>FLi01mW>@03001W
>FLi021W>@03001W>FLi01iW>@03001W>FLi01eW>@04001W>FLi000ZOol00`00Oomoo`0:Ool00`00
Oomoo`0HOol3000MOol00`00Oomoo`1?Ool00`00Oomoo`0`Ool00`00Oomoo`1/Ool00`00Oomoo`3=
Ool60009Ool003Yoo`03001oogoo059oo`03001oogoo04Aoo`03001oogoo00Yoo`<0045oo`8000Ao
o`03001oogoo00Moo`03001oogoo025oo`EW>@03001W>FLi00UW>@03001W>FLi02EW>@03001W>FLi
02MW>@03001W>FLi021W>@03001W>FLi01mW>@03001W>FLi021W>@03001W>FLi01iW>@03001W>FLi
01iW>@800003IcUoogoo02Qoo`03001oogoo00Yoo`03001oogoo01Eoo`<0021oo`80051oo`03001o
ogoo035oo`03001oogoo06]oo`03001oogoo0=9oo`03001oogoo00Moo`00>Woo00<007ooOol0DWoo
00<007ooOol0AGoo00<007ooOol027oo0`00A7oo0P000Woo00<007ooOol01goo00<007ooOol08Goo
1VLi00<006LiIcT026Li00<006LiIcT09FLi00<006LiIcT09fLi00<006LiIcT086Li00<006LiIcT0
7fLi00<006LiIcT086Li00<006LiIcT07VLi00<006LiIcT07VLi00<006LiIcT0:Woo00<007ooOol0
2Woo00<007ooOol04goo0P008goo0`00CWoo00<007ooOol0<goo00<007ooOol0JGoo00<007ooOol0
dgoo00<007ooOol01goo000jOol00`00Oomoo`1COol00`00Oomoo`15Ool00`00Oomoo`06Ool40016
Ool30009Ool00`00Oomoo`0QOol7IcT00`00IcUW>@06IcT00`00IcUW>@0VIcT00`00IcUW>@0WIcT0
0`00IcUW>@0PIcT00`00IcUW>@0OIcT00`00IcUW>@0PIcT00`00IcUW>@0NIcT00`00IcUW>@0MIcT2
0002IcT[Ool00`00Oomoo`09Ool00`00Oomoo`0@Ool3000VOol2001<Ool2000gOol00`00Oomoo`1X
Ool00`00Oomoo`3COol00`00Oomoo`07Ool003Yoo`03001oogoo05=oo`03001oogoo04Ioo`03001o
ogoo00Aoo`D004Moo`@000Moo`03001oogoo025oo`QW>@8000IW>@03001W>FLi02IW>@03001W>FLi
02MW>@03001W>FLi021W>@03001W>FLi01mW>@03001W>FLi021W>@03001W>FLi01iW>@03001W>FLi
01aW>@03001W>@00009W>B]oo`03001oogoo00Yoo`03001oogoo00aoo`<002Uoo`<004Yoo`03001o
ogoo03Qoo`03001oogoo06Ioo`03001oogoo0=Aoo`03001oogoo00Moo`00>Woo00<007ooOol0Dgoo
00<007ooOol0Agoo00<007ooOol00Woo1@00Agoo0`000Woo0`000goo00<007ooOol08Woo2VLi0P00
16Li00<006LiIcT09FLi00<006LiIcT0:6Li00<006LiIcT086Li00<006LiIcT07fLi00<006LiIcT0
86Li00<006LiIcT07fLi00<006LiIcT06VLi00@006LiIcT0009W>B]oo`03001oogoo00Yoo`03001o
ogoo00Uoo`<002aoo`@004Qoo`03001oogoo03Yoo`03001oogoo06Eoo`03001oogoo0=Aoo`03001o
ogoo00Moo`00>Woo00<007ooOol0Dgoo00<007ooOol0B7oo00<007ooOol01P00Agoo0`001Goo1000
97oo36Li0P000VLi00<006LiIcT09FLi00<006LiIcT0:6Li00<006LiIcT086Li00<006LiIcT07fLi
00<006LiIcT086Li00<006LiIcT07fLi00<006LiIcT06FLi00<006LiIcT00VLi00<006LiOol0:Woo
00<007ooOol02Woo00<007ooOol01Goo1000;goo1@00AWoo00<007ooOol0>goo00<007ooOol0I7oo
00<007ooOol0eGoo00<007ooOol01goo000jOol00`00Oomoo`1DOol00`00Oomoo`18Ool30002Ool3
0016Ool40008Ool3000ROol>IcT3000WIcT00`00IcUW>@0XIcT00`00IcUW>@0PIcT00`00IcUW>@0O
IcT00`00IcUW>@0PIcT00`00IcUW>@0OIcT00`00IcUW>@0GIcT20005IcT00`00IcUoo`0ZOol00`00
Oomoo`0:Ool00`00Oomoo`02Ool3000cOol300000goo001oo`14Ool00`00Oomoo`0mOol00`00Oomo
o`1ROol00`00Oomoo`3FOol00`00Oomoo`07Ool003Yoo`03001oogoo05Aoo`03001oogoo04Qoo`07
001oogooOol007oo0000AWoo1@001goo00@007ooOomoo`@001ioo`mW>@8002MW>@03001W>FLi02QW
>@03001W>FLi021W>@03001W>FLi01mW>@03001W>FLi021W>@03001W>FLi01mW>@03001W>FLi01AW
>@<000MW>@03001W>Goo02Yoo`03001oogoo00Yoo`D003Ioo`800004Ool007oo0013Ool00`00Oomo
o`0oOol00`00Oomoo`1QOol00`00Oomoo`3FOol00`00Oomoo`07Ool003Yoo`03001oogoo05Aoo`03
001oogoo04Uoo`04001oo`00Ool20016Ool50007Ool00`00Oomoo`05Ool3000ZOol01000Ool00000
9Goo00<007ooOol0:7oo00<007ooOol087oo00<007ooOol07goo00<007ooOol087oo00<007ooOol0
7goo00<007ooOol04Goo0`002goo00<007ooOol0:Goo00<007ooOol01Woo1P00>Woo00<007oo0000
0Woo00<007ooOol0?Woo0P00@goo00<007ooOol0Ggoo00<007ooOol0egoo00<007ooOol01goo000j
Ool00`00Oomoo`1DOol00`00Oomoo`1:Ool00`00Oomoo`020015Ool2000017oo000000001goo00<0
07ooOol027oo10009Woo00@007ooOomoo`8002=oo`03001oogoo02Qoo`03001oogoo021oo`03001o
ogoo01moo`03001oogoo021oo`03001oogoo01moo`03001oogoo00ioo`<000moo`03001oogoo02Qo
o`03001oogoo009oo`@000Aoo`<003Uoo`03001oo`00049oo`03001oogoo04Aoo`03001oogoo05io
o`03001oogoo0=Moo`03001oogoo00Moo`00>Woo00<007ooOol0E7oo00<007ooOol0BGoo00D007oo
001oo`0004Ioo`06001oogoo001oo`001goo00<007ooOol037oo0`008Woo00<007ooOol017oo0`00
87oo00<007ooOol0:7oo00<007ooOol087oo00<007ooOol07goo00<007ooOol087oo00<007ooOol0
7goo00<007ooOol02goo0`004Woo00<007ooOol0:7oo1@0027oo0`00>Goo00@007ooOol0041oo`03
001oogoo04Ioo`03001oogoo05aoo`03001oogoo0=Qoo`03001oogoo00Moo`00>Woo00<007ooOol0
EGoo00<007ooOol0B7oo00<007ooOol00P00AGoo00@007ooOol0009oo`03001oogoo00Eoo`03001o
ogoo00moo`@001ioo`03001oogoo00Moo`D001]oo`03001oogoo02Qoo`03001oogoo021oo`03001o
ogoo01moo`03001oogoo021oo`03001oogoo01moo`03001oogoo00Moo`@001Eoo`03001oogoo025o
o`L00003Ool007oo00Yoo`@003]oo`03001oogoo03eoo`03001oogoo04Moo`03001oogoo05]oo`03
001oogoo0=Uoo`03001oogoo00Moo`00>Woo00<007ooOol0EGoo00<007ooOol0Agoo00<007ooOol0
0Woo00<007ooOol0AWoo00@007ooOol000Moo`03001oogoo01=oo`<001]oo`03001oogoo00aoo`D0
01Ioo`03001oogoo02Qoo`03001oogoo021oo`03001oogoo01moo`03001oogoo021oo`03001oogoo
021oo`03001oo`0000H001Yoo`03001oogoo01Ioo`X000Qoo`03001oogoo00Qoo`D003]oo`03001o
ogoo03aoo`03001oogoo04Uoo`03001oogoo05Yoo`03001oogoo0=Uoo`03001oogoo00Moo`00>Woo
00<007ooOol0EGoo00<007ooOol0AWoo00<007ooOol017oo00<007ooOol0AGoo00<007ooOol01goo
00<007ooOol05goo0`0067oo00<007ooOol04Goo2@003Goo00<007ooOol0:7oo00<007ooOol087oo
00<007ooOol07goo00<007ooOol087oo00<007ooOol067oo2P008Goo00<007ooOol03Goo2@004Woo
00<007ooOol027oo1@00?7oo00<007ooOol0>Woo00<007ooOol0Bgoo00<007ooOol0F7oo00<007oo
Ool0fWoo00<007ooOol01goo000jOol00`00Oomoo`1EOol00`00Oomoo`16Ool00`00Oomoo`05Ool0
0`00Oomoo`14Ool00`00Oomoo`07Ool00`00Oomoo`0JOol3000EOol00`00Oomoo`0JOolJ000NOol0
0`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0;Ool=0008Ool00`00Oomo
o`0QOol00`00Oomoo`07Ool5000KOol00`00Oomoo`08Ool300000goo0000000kOol00`00Oomoo`0i
Ool00`00Oomoo`1=Ool00`00Oomoo`1GOol00`00Oomoo`3JOol00`00Oomoo`07Ool003Yoo`03001o
ogoo05Ioo`03001oogoo04Aoo`03001oogoo00Moo`03001oogoo04=oo`03001oogoo00Moo`03001o
ogoo01eoo`D000moo`03001oogoo02Qoo`03001oogoo00Yooi@001Eoo`03001oogoo025oo`03001o
ogoo009oo`D0021oo`03001oogoo00Qoo`<0009oo`03001oogoo03Yoo`03001oogoo03Moo`03001o
ogoo04moo`03001oogoo05Eoo`03001oogoo0=]oo`03001oogoo00Moo`00>Woo00<007ooOol0EWoo
00<007ooOol0A7oo00<007ooOol027oo0P00@Woo00<007ooOol027oo00<007ooOol08Woo10002goo
00<007ooOol0:7oo00<007ooOol0:7oo00<007ooOol087oo00<007ooOol07goo00<007ooOol087oo
00<007ooOol087oo00<007ooOol08Woo10009Goo00<007ooOol027oo00@007ooOol0009oo`03001o
ogoo03Uoo`03001oogoo03Eoo`80059oo`8005Eoo`03001oogoo0=aoo`03001oogoo00Moo`00>Woo
00<007ooOol0EWoo00<007ooOol0@goo00<007ooOol02goo00<007ooOol0?goo00<007ooOol027oo
00<007ooOol09Woo1@001Woo00<007ooOol09goo00<007ooOol0:Goo00<007ooOol087oo00<007oo
Ool07goo00<007ooOol087oo00<007ooOol08Goo00<007ooOol077oo1P00:7oo00<007ooOol027oo
00@007ooOol003ioo`03001oogoo03Aoo`03001oogoo059oo`<005Aoo`03001oogoo0=aoo`03001o
ogoo00Moo`00>Woo00<007ooOol0Egoo00<007ooOol0@Goo00<007ooOol03Goo00<007ooOol0?Woo
00<007ooOol027oo00<007ooOol0:goo2@009goo00<007ooOol0:Goo00<007ooOol087oo00<007oo
Ool07goo00<007ooOol087oo00<007ooOol08Goo00<007ooOol067oo10001Goo00<007ooOol09Woo
00<007ooOol02goo00<007ooOol0?Goo00<007ooOol0<Woo00<007ooOol0E7oo0`00DWoo00<007oo
Ool0gGoo00<007ooOol01goo000jOol00`00Oomoo`1GOol00`00Oomoo`10Ool00`00Oomoo`0?Ool2
000nOol00`00Oomoo`08Ool00`00Oomoo`0`Ool01000Oomoogoo3@006Woo00<007ooOol0:Goo00<0
07ooOol087oo00<007ooOol07goo00<007ooOol087oo00<007ooOol08Goo00<007ooOol00Woo5P00
2Goo00<007ooOol09Woo00<007ooOol02goo00<007ooOol0?Goo00<007ooOol0<Goo00<007ooOol0
EGoo1000D7oo00<007ooOol0gWoo00<007ooOol01goo000jOol00`00Oomoo`1GOol00`00Oomoo`0o
Ool00`00Oomoo`0BOol00`00Oomoo`0kOol00`00Oomoo`08Ool00`00Oomoo`0`Ool00`00Oomoo`0>
OooG000OOol00`00Oomoo`0VOol00`00Oomoo`0;Ool00`00Oomoo`0mOol00`00Oomoo`0_Ool2001H
Ool6001=Ool00`00Oomoo`3OOol00`00Oomoo`07Ool003Yoo`03001oogoo05Qoo`03001oogoo03io
o`03001oogoo01=oo`8003]oo`03001oogoo00Qoo`03001oogoo031oo`03001oogoo02Qoo`03001o
ogoo02Uoo`03001oogoo021oo`03001oogoo01moo`03001oogoo021oo`03001oogoo025oo`03001o
ogoo029oo`03001oogoo02Eoo`03001oogoo00]oo`03001oogoo03ioo`03001oogoo02eoo`03001o
ogoo05Uoo`H004aoo`03001oogoo0=moo`03001oogoo00Moo`00>Woo00<007ooOol0F7oo00<007oo
Ool0?Goo00<007ooOol05Woo00<007ooOol0=goo00<007ooOol02Goo00<007ooOol0<7oo00<007oo
Ool0:7oo00<007ooOol0:Goo00<007ooOol087oo00<007ooOol07goo00<007ooOol087oo00<007oo
Ool08Goo00<007ooOol08Woo00<007ooOol09Goo00<007ooOol02goo00<007ooOol0?Woo00<007oo
Ool0;7oo00<007ooOol0FWoo0`0000Aoo`00000004Yoo`03001oogoo0>1oo`03001oogoo00Moo`00
>Woo00<007ooOol0F7oo00<007ooOol0?7oo00<007ooOol067oo00<007ooOol0=Woo00<007ooOol0
2Goo00<007ooOol0:Goo2`009goo00<007ooOol0:Goo00<007ooOol087oo00<007ooOol07goo00<0
07ooOol087oo00<007ooOol08Goo00<007ooOol08Goo00<007ooOol09Woo00<007ooOol02goo00<0
07ooOol0?Woo00<007ooOol0:goo00<007ooOol0G7oo0`000Woo0P00B7oo00<007ooOol0hGoo00<0
07ooOol01goo000jOol00`00Oomoo`1IOol00`00Oomoo`0jOol00`00Oomoo`0JOol2000fOol00`00
Oomoo`09Ool00`00Oomoo`0ROol70007Ool01000Oomoogoo:000:goo00<007ooOol087oo00<007oo
Ool07goo00<007ooOol087oo00<007ooOol067oo9P001goo00<007ooOol09Woo00<007ooOol02goo
00<007ooOol0?goo00<007ooOol0:Goo00<007ooOol0GGoo0P0000=oo`00Ool00Woo00<007ooOol0
A7oo00<007ooOol0hWoo00<007ooOol01goo000>Ool5000>Ool4000EOol00`00Oomoo`1IOol00`00
Oomoo`0iOol00`00Oomoo`0MOol00`00Oomoo`0cOol00`00Oomoo`09Ool00`00Oomoo`0MOol5000>
Ool00`00Oomoo`0XOon_0009Ool00`00Oomoo`0JOol8000XOol00`00Oomoo`0;Ool00`00Oomoo`0o
Ool00`00Oomoo`0WOol2001QOol200000goo001oo`18Ool00`00Oomoo`3ROol00`00Oomoo`07Ool0
00aoo`T000Yoo`P001=oo`03001oogoo05Uoo`03001oogoo03Uoo`03001oogoo01ioo`8003=oo`03
001oogoo00Uoo`03001oogoo01aoo`03001oogoo015oo`03001oogoo02Qoo`03001oogoo02Uoo`03
001oogoo021oo`03001oogoo01moo`03001oogoo021oo`03001oogoo025oo`03001oogoo025oo`@0
02Eoo`03001oogoo00]oo`03001oogoo03moo`03001oogoo02Eoo`8006=oo`80009oo`03001oogoo
04Eoo`03001oogoo0>=oo`03001oogoo00Moo`002goo100017oo0`002Goo0P0017oo0P004goo00<0
07ooOol0FWoo00<007ooOol0>7oo00<007ooOol087oo00<007ooOol0<7oo00<007ooOol02Goo00<0
07ooOol06Woo0P0057oo00<007ooOol0:7oo00<007ooOol0:Goo00<007ooOol087oo00<007ooOol0
7goo00<007ooOol087oo00<007ooOol08Goo00<007ooOol08Goo00D007ooOomoo`0002Aoo`03001o
ogoo00]oo`03001oogoo041oo`03001oogoo02=oo`03001oogoo06=oo`80009oo`03001oogoo04Ao
o`03001oogoo0>Aoo`03001oogoo00Moo`002goo0P001goo0`001goo0P001Woo0P004Woo00<007oo
Ool0FWoo00<007ooOol0=goo00<007ooOol08Woo00<007ooOol0;goo00<007ooOol02Goo00<007oo
Ool067oo0P005Woo00<007ooOol0:7oo00<007ooOol0:Goo00<007ooOol087oo00<007ooOol07goo
00<007ooOol087oo00<007ooOol08Goo00<007ooOol087oo00<007ooOol00goo00<007ooOol08Goo
00<007ooOol02goo00<007ooOol0@7oo00<007ooOol08Goo0P00Igoo00D007ooOomoo`0004Aoo`03
001oogoo0>Eoo`03001oogoo00Moo`005Goo0P001goo0P001Woo0P004Woo00<007ooOol0FWoo00<0
07ooOol0=Woo00<007ooOol097oo0P00;goo00<007ooOol02Goo00<007ooOol05goo00<007ooOol0
4Gooo`00100027oo00<007ooOol017oo0P008Goo00<007ooOol02goo00<007ooOol0@7oo00<007oo
Ool07goo0P00KGoo00<007ooOol0@Woo00<007ooOol0iGoo00<007ooOol01goo000EOol20006Ool2
0008Ool2000AOol00`00Oomoo`1KOol00`00Oomoo`0dOol00`00Oomoo`0WOol2000]Ool00`00Oomo
o`09Ool00`00Oomoo`0EOol2000AOol30005Ool00`00Oomoo`0XOol00`00Oomoo`0YOol00`00Oomo
o`0POol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0QOol00`00Oomoo`0HOol20006Ool0
0`00Oomoo`06Ool00`00Oomoo`0MOol00`00Oomoo`0<Ool00`00Oomoo`11Ool00`00Oomoo`0MOol0
0`00Oomoo`1^Ool00`00Oomoo`10Ool00`00Oomoo`3VOol00`00Oomoo`07Ool001Eoo`8000Ioo`80
00Qoo`80015oo`03001oogoo05]oo`03001oogoo03=oo`03001oogoo02Yoo`03001oogoo02Yoo`03
001oogoo00Uoo`03001oogoo01Aoo`03001oogoo00moo`8000Qoo`03001oogoo02Qoo`03001oogoo
02Uoo`03001oogoo021oo`03001oogoo01moo`03001oogoo021oo`03001oogoo025oo`03001oogoo
01Yoo`8000=oo`03001oogoo00Qoo`03001oogoo01aoo`03001oogoo00aoo`03001oogoo045oo`03
001oogoo01]oo`80079oo`03001oogoo03ioo`03001oogoo0>Moo`03001oogoo00Moo`0057oo0`00
1Woo0P0027oo0P004Goo2000Egoo00<007ooOol0<Woo00<007ooOol0:goo0P00:Goo00<007ooOol0
2Woo00<007ooOol04Woo0P004Goo00<007ooOol027oo00<007ooOol0:7oo00<007ooOol0:Goo00<0
07ooOol087oo00<007ooOol07goo00<007ooOol087oo00<007ooOol08Goo00<007ooOol077oo00<0
07oo000037oo0P0077oo00<007ooOol037oo00<007ooOol0@Goo00<007ooOol06Goo0P00M7oo00<0
07ooOol0?Goo00<007ooOol0hGoo20002Goo000COol30007Ool20008Ool2000AOol00`00Oomoo`1L
Ool00`00Oomoo`0aOol00`00Oomoo`0^Ool2000WOol00`00Oomoo`0:Ool00`00Oomoo`0@Ool2000C
Ool00`00Oomoo`04Oooo00010006Ool00`00Ool0000>Ool00`00Oomoo`0IOol00`00Oomoo`0<Ool0
0`00Oomoo`12Ool00`00Oomoo`0FOol2001gOol00`00Oomoo`0lOol00`00Oomoo`3XOol00`00Oomo
o`07Ool0011oo`D000Qoo`8000Qoo`80015oo`03001oogoo05eoo`03001oogoo02moo`03001oogoo
035oo`8002Eoo`03001oogoo00Yoo`03001oogoo00eoo`<001Eoo`03001oogoo00Aoool0004000Eo
o`@000moo`8001Uoo`03001oogoo00aoo`03001oogoo049oo`03001oogoo01Eoo`03001oogoo07Qo
o`03001oogoo03Yoo`03001oogoo0>Uoo`03001oogoo00Moo`0047oo10002Goo0P0027oo0P004Goo
00<007ooOol0GGoo00<007ooOol0;Woo00<007ooOol0=7oo0P008goo00<007ooOol02Woo00<007oo
Ool02goo0P005goo00<007ooOol01Gooo`001P000Woo00<007ooOol047oo00<007ooOol05Woo00<0
07ooOol037oo00<007ooOol0@Woo00<007ooOol04goo0P00O7oo00<007ooOol0>7oo00<007ooOol0
jWoo00<007ooOol01goo000COol20008Ool20008Ool2000AOol00`00Oomoo`1MOol00`00Oomoo`0]
Ool00`00Oomoo`0gOol2000QOol00`00Oomoo`0:Ool00`00Oomoo`09Ool2000IOol00`00Oomoo`05
Oooo00010007Ool00`00Oomoo`0AOol2000FOol00`00Oomoo`0<Ool00`00Oomoo`13Ool00`00Oomo
o`0@Ool2001oOol00`00Oomoo`0fOol00`00Oomoo`3[Ool00`00Oomoo`07Ool001Aoo`8000Moo`80
00Qoo`80015oo`03001oogoo05ioo`03001oogoo02]oo`03001oogoo03Yoo`<001ioo`03001oogoo
00Yoo`03001oogoo00Ioo`<001]oo`03001oogoo00Eoool0004000Moo`03001oogoo01=oo`03001o
ogoo019oo`03001oogoo00eoo`03001oogoo04=oo`03001oogoo00moo`03001oogoo07moo`03001o
ogoo03Eoo`03001oogoo0>aoo`03001oogoo00Moo`0057oo0P0027oo0P001Woo0P004Woo00<007oo
Ool0GWoo00<007ooOol0:goo00<007ooOol0?Goo0`006goo00<007ooOol02Woo00<007ooOol017oo
0P007Goo00<007ooOol01Wooo`000@001goo00<007ooOol057oo0P004Woo00<007ooOol03Goo00<0
07ooOol0@goo00<007ooOol03Goo0P00PWoo00<007ooOol0=Goo00<007ooOol0k7oo00<007ooOol0
1goo000<Ool20006Ool20008Ool20006Ool2000BOol00`00Oomoo`1OOol00`00Oomoo`0YOol00`00
Oomoo`11Ool3000HOol00`00Oomoo`0:Ool01000Oomoogoo0`007goo00<007ooOol01Wooo`000@00
27oo00<007ooOol05Goo00<007ooOol03goo00<007ooOol03Goo00<007ooOol0@goo00<007ooOol0
2goo0P00QGoo00<007ooOol0<goo00<007ooOol0kGoo00<007ooOol01goo000<Ool30004Ool30009
Ool20004Ool2000COol00`00Oomoo`1OOol00`00Oomoo`0XOol00`00Oomoo`15Ool3000EOol00`00
Oomoo`09Ool5000ROol00`00Oomoo`06Oooo00010008Ool00`00Oomoo`0FOol2000?Ool00`00Oomo
o`0=Ool00`00Oomoo`13Ool00`00Oomoo`0:Ool00`00Oomoo`26Ool00`00Oomoo`0aOol00`00Oomo
o`3^Ool00`00Oomoo`07Ool000eoo`P000Yoo`P001=oo`03001oogoo061oo`03001oogoo02Ioo`03
001oogoo04Uoo`@0015oo`03001oogoo00Eoo`@0009oo`03001oogoo025oo`03001oogoo00Moool0
004000Qoo`03001oogoo01Qoo`03001oogoo00]oo`03001oogoo00eoo`03001oogoo04Eoo`03001o
ogoo00Moo`8008Uoo`03001oogoo031oo`03001oogoo0>moo`03001oogoo00Moo`003Woo1@003Woo
10005Goo00<007ooOol0H7oo00<007ooOol09Woo00<007ooOol0CGoo1`002Goo2@001Woo00<007oo
Ool08Goo00<007ooOol01gooo`000@0027oo00<007ooOol06Goo00<007ooOol02Woo00<007ooOol0
3Goo00<007ooOol0AGoo00<007ooOol017oo0`00S7oo00<007ooOol0;goo00<007ooOol0kgoo00<0
07ooOol01goo000jOol00`00Oomoo`1POol00`00Oomoo`0VOol00`00Oomoo`1DOol900000goo001o
o`0<Ool00`00Oomoo`0QOol00`00Oomoo`07Oooo00010008Ool00`00Oomoo`0JOol2000:Ool00`00
Oomoo`0=Ool00`00Oomoo`15Ool01000Oomoogoo0`00T7oo00<007ooOol0;Goo00<007ooOol0l7oo
00<007ooOol01goo000jOol00`00Oomoo`1QOol00`00Oomoo`0TOol00`00Oomoo`1OOol00`00Oomo
o`0;Ool00`00Oomoo`0QOol00`00Oomoo`07Oooo00010009Ool00`00Oomoo`0KOol00`00Oomoo`07
Ool00`00Oomoo`0=Ool00`00Oomoo`16Ool3002DOol00`00Oomoo`0[Ool00`00Oomoo`3aOol00`00
Oomoo`07Ool003Yoo`03001oogoo065oo`03001oogoo02=oo`03001oogoo061oo`03001oogoo00]o
o`03001oogoo021oo`03001oogoo00Qoool0004000Uoo`03001oogoo01aoo`8000Ioo`03001oogoo
00ioo`03001oogoo04=oo`@009Ioo`03001oogoo02Yoo`03001oogoo0?9oo`03001oogoo00Moo`00
>Woo00<007ooOol0HWoo00<007ooOol08Goo00<007ooOol0HGoo00<007ooOol037oo00<007ooOol0
7goo00<007ooOol027ooo`000@002Goo00<007ooOol07Woo0P0017oo00<007ooOol03Woo00<007oo
Ool0@Goo0P000goo00<007ooOol0UGoo00<007ooOol0:7oo00<007ooOol0lgoo00<007ooOol01goo
000jOol00`00Oomoo`1ROol00`00Oomoo`0POol00`00Oomoo`1ROol00`00Oomoo`0<Ool00`00Oomo
o`0OOol00`00Oomoo`08Oooo00010009Ool00`00Oomoo`0POol300000goo001oo`0?Ool00`00Oomo
o`0nOol30006Ool00`00Oomoo`2DOol00`00Oomoo`0WOol00`00Oomoo`3dOol00`00Oomoo`07Ool0
03Yoo`03001oogoo069oo`03001oogoo01moo`03001oogoo06=oo`03001oogoo00aoo`03001oogoo
01ioo`03001oogoo00Uoool0004000Yoo`03001oogoo029oo`80011oo`03001oogoo03]oo`<000Uo
o`03001oogoo09Eoo`03001oogoo02Eoo`03001oogoo0?Eoo`03001oogoo00Moo`00>Woo00<007oo
Ool0Hgoo00<007ooOol07Woo00<007ooOol0Hgoo00<007ooOol037oo00<007ooOol07Woo00<007oo
Ool02Gooo`000@002Woo00<007ooOol08Woo00@007oo000000eoo`03001oogoo03Yoo`8000aoo`03
001oogoo09Ioo`03001oogoo02=oo`03001oogoo0?Ioo`03001oogoo00Moo`00>Woo00<007ooOol0
Hgoo00<007ooOol07Goo00<007ooOol0I7oo00<007ooOol037oo00<007ooOol07Woo00<007ooOol0
IGoo00<007ooOol0A7oo00<007ooOol0I7oo00<007ooOol08Woo00@007ooOomoo`<000Yoo`03001o
ogoo03Moo`<000ioo`03001oogoo09Ioo`03001oogoo029oo`03001oogoo0?Moo`03001oogoo00Mo
o`00>Woo00<007ooOol0I7oo00<007ooOol06goo00<007ooOol0IGoo00<007ooOol03Goo00<007oo
Ool07Goo00<007ooOol0IGoo00<007ooOol0A7oo00<007ooOol0I7oo00<007ooOol08Woo00<007oo
Ool017oo0`001goo00<007ooOol0=7oo0`004Goo00<007ooOol0Ugoo00<007ooOol087oo00<007oo
Ool0n7oo00<007ooOol01goo000jOol00`00Oomoo`1UOol00`00Oomoo`0IOol00`00Oomoo`1WOol0
0`00Oomoo`0<Ool00`00Oomoo`0MOol00`00Oomoo`1UOol00`00Oomoo`14Ool00`00Oomoo`1TOol0
0`00Oomoo`0QOol00`00Oomoo`08Ool50002Ool00`00Oomoo`0_Ool5000EOol00`00Oomoo`2GOol0
0`00Oomoo`0NOol00`00Oomoo`3iOol00`00Oomoo`07Ool003Yoo`03001oogoo06Eoo`03001oogoo
01Qoo`03001oogoo06Qoo`03001oogoo00aoo`03001oogoo01eoo`03001oogoo06Eoo`03001oogoo
04Aoo`03001oogoo06Aoo`03001oogoo025oo`03001oogoo00eoo`@002]oo`D001Yoo`03001oogoo
09Moo`03001oogoo01eoo`03001oogoo0?Yoo`03001oogoo00Moo`00>Woo00<007ooOol0IWoo00<0
07ooOol05Woo00<007ooOol0JGoo00<007ooOol03Goo00<007ooOol06goo00<007ooOol0IWoo00<0
07ooOol0A7oo00<007ooOol0IGoo00<007ooOol07goo00<007ooOol047oo00<007oo00001@0087oo
1@007goo00<007ooOol0Ugoo00<007ooOol077oo00<007ooOol0ngoo00<007ooOol01goo000jOol0
0`00Oomoo`1VOol00`00Oomoo`0EOol00`00Oomoo`1ZOol00`00Oomoo`0=Ool00`00Oomoo`0KOol0
0`00Oomoo`1VOol00`00Oomoo`14Ool00`00Oomoo`1UOol00`00Oomoo`0OOol00`00Oomoo`0@Ool0
0`00Oomoo`05Ool7000BOol7000UOol00`00Oomoo`2GOol00`00Oomoo`0JOol00`00Oomoo`3lOol0
0`00Oomoo`07Ool003Yoo`03001oogoo06Moo`03001oogoo01Aoo`03001oogoo06Yoo`03001oogoo
00eoo`03001oogoo01]oo`03001oogoo06Ioo`03001oogoo04Aoo`03001oogoo06Eoo`03001oogoo
01moo`03001oogoo00moo`03001oogoo00eooa8002aoo`03001oogoo09Qoo`03001oogoo01Moo`80
0?moo`03001oogoo00Moo`00>Woo00<007ooOol0J7oo00<007ooOol04Woo00<007ooOol0Jgoo00<0
07ooOol03Goo00<007ooOol06goo00<007ooOol0IWoo00<007ooOol0A7oo00<007ooOol0IGoo00<0
07ooOol07Woo00<007ooOol047oo00<007ooOol0Bgoo00<007ooOol0V7oo00<007ooOol05Woo00<0
07ooOol0ogoo00<007ooOol01goo000jOol00`00Oomoo`1XOol00`00Oomoo`0AOol00`00Oomoo`1/
Ool00`00Oomoo`0=Ool00`00Oomoo`0KOol00`00Oomoo`1UOol00`00Oomoo`15Ool00`00Oomoo`1U
Ool00`00Oomoo`0NOol00`00Oomoo`0@Ool00`00Oomoo`1;Ool00`00Oomoo`2IOol00`00Oomoo`0D
Ool00`00Oomoo`3oOol1Ool00`00Oomoo`07Ool003Yoo`03001oogoo06Uoo`03001oogoo00moo`03
001oogoo06eoo`03001oogoo00ioo`03001oogoo01Yoo`03001oogoo06Eoo`03001oogoo04Ioo`03
001oogoo06Aoo`03001oogoo01ioo`03001oogoo011oo`03001oogoo04]oo`03001oogoo09Yoo`03
001oogoo019oo`03001oogoo0?moo`9oo`03001oogoo00Moo`00>Woo00<007ooOol0JGoo00<007oo
Ool03Woo00<007ooOol0KWoo00<007ooOol03Woo00<007ooOol06Woo00<007ooOol0IGoo00<007oo
Ool0AWoo00<007ooOol0I7oo00<007ooOol07Goo00<007ooOol04Goo00<007ooOol0C7oo00<007oo
Ool0VGoo00<007ooOol04Goo00<007ooOol0ogoo0goo00<007ooOol01goo000jOol00`00Oomoo`1Z
Ool00`00Oomoo`0<Ool00`00Oomoo`1_Ool00`00Oomoo`0>Ool00`00Oomoo`0JOol00`00Oomoo`1U
Ool00`00Oomoo`16Ool00`00Oomoo`1TOol00`00Oomoo`0MOol00`00Oomoo`0@Ool00`00Oomoo`1=
Ool00`00Oomoo`2IOol00`00Oomoo`0@Ool00`00Oomoo`3oOol4Ool00`00Oomoo`07Ool003Yoo`03
001oogoo06Yoo`03001oogoo00]oo`03001oogoo075oo`03001oogoo00ioo`03001oogoo01Qoo`03
001oogoo06Ioo`03001oogoo04Ioo`03001oogoo06Aoo`03001oogoo01eoo`03001oogoo011oo`03
001oogoo04eoo`03001oogoo09Yoo`03001oogoo00ioo`03001oogoo0?moo`Eoo`03001oogoo00Mo
o`00>Woo00<007ooOol0Jgoo00<007ooOol02Woo00<007ooOol0LGoo00<007ooOol03Woo00<007oo
Ool067oo00<007ooOol0IWoo00<007ooOol0AWoo00<007ooOol0IGoo00<007ooOol06goo00<007oo
Ool04Goo00<007ooOol0CGoo00<007ooOol0Vgoo00<007ooOol037oo00<007ooOol0ogoo1Woo00<0
07ooOol01goo000jOol00`00Oomoo`1/Ool00`00Oomoo`08Ool00`00Oomoo`1bOol00`00Oomoo`0>
Ool00`00Oomoo`0HOol00`00Oomoo`1UOol00`00Oomoo`18Ool00`00Oomoo`1TOol00`00Oomoo`0K
Ool00`00Oomoo`0AOol00`00Oomoo`1=Ool00`00Oomoo`2LOol00`00Oomoo`0:Ool00`00Oomoo`3o
Ool7Ool00`00Oomoo`07Ool003Yoo`03001oogoo06aoo`03001oogoo00Moo`03001oogoo07=oo`03
001oogoo00moo`03001oogoo01Moo`03001oogoo06Eoo`03001oogoo04Qoo`03001oogoo06Aoo`03
001oogoo01]oo`03001oogoo011oo`03001oogoo04moo`03001oogoo09]oo`03001oogoo00Uoo`03
001oogoo0?moo`Qoo`03001oogoo00Moo`00>Woo1@00Jgoo00<007ooOol01Goo00<007ooOol0M7oo
00<007ooOol047oo00<007ooOol05Woo00<007ooOol0IGoo00<007ooOol0B7oo00<007ooOol0I7oo
00<007ooOol06Woo00<007ooOol04Goo00<007ooOol0Cgoo00<007ooOol0Vgoo00<007ooOol027oo
00<007ooOol0ogoo17oo1P002Goo000jOol00`00Oomoo`1]Ool00`00Oomoo`04Ool00`00Oomoo`1e
Ool00`00Oomoo`0@Ool00`00Oomoo`0FOol00`00Oomoo`1TOol00`00Oomoo`1:Ool00`00Oomoo`1S
Ool00`00Oomoo`0JOol00`00Oomoo`0AOol00`00Oomoo`1?Ool00`00Oomoo`2LOol00`00Oomoo`06
Ool00`00Oomoo`3oOol:Ool00`00Oomoo`07Ool003Yoo`03001oogoo06ioo`03001oogoo009oo`03
001oogoo07Ioo`03001oogoo015oo`03001oogoo01Aoo`03001oogoo06Eoo`03001oogoo04Yoo`03
001oogoo06=oo`03001oogoo01Uoo`03001oogoo019oo`03001oogoo051oo`03001oogoo09]oo`03
001oogoo00Aoo`800?moo`eoo`03001oogoo00Moo`00>Woo00<007ooOol0Kgoo00@007ooOol007Uo
o`03001oogoo015oo`8001Eoo`03001oogoo06Eoo`03001oogoo04Yoo`03001oogoo06=oo`03001o
ogoo01Qoo`03001oogoo01=oo`03001oogoo051oo`03001oogoo09aoo`03001oogoo009oo`03001o
ogoo0?moo`eoo`03001oogoo00Moo`00>Woo00<007ooOol0Kgoo00<007oo0000Ngoo00<007ooOol0
47oo0`0057oo00<007ooOol0I7oo00<007ooOol0C7oo00<007ooOol0HWoo00<007ooOol05goo0P00
57oo00<007ooOol0DGoo00<007ooOol0WGoo00@007oo00000?mooa1oo`03001oogoo00Moo`00>Woo
00<007ooOol0L7oo00<007ooOol0NWoo00<007ooOol04Goo0`004Woo00<007ooOol0IGoo00<007oo
Ool0C7oo00<007ooOol0Hgoo00<007ooOol05Goo0`0057oo00<007ooOol0DGoo00<007ooOol0WGoo
0P00ogoo4Woo00<007ooOol01goo000jOol00`00Oomoo`1^Ool200000goo001oo`1jOol00`00Oomo
o`0AOol4000AOol00`00Oomoo`1UOol00`00Oomoo`1<Ool00`00Oomoo`1SOol00`00Oomoo`0DOol3
000EOol00`00Oomoo`1AOol00`00Oomoo`2MOol00`00Oomoo`3oOolAOol00`00Oomoo`07Ool003Yo
o`03001oogoo06eoo`<0009oo`03001oogoo07Qoo`03001oogoo015oo`H000moo`03001oogoo06Ao
o`03001oogoo04ioo`03001oogoo069oo`03001oogoo01=oo`@001Aoo`03001oogoo05=oo`03001o
ogoo09Yoo`800003Ool007oo0?mooa5oo`03001oogoo00Moo`00>Woo00<007ooOol0Jgoo10000goo
00<007ooOol0N7oo00<007ooOol04Woo1P003Goo00<007ooOol0IGoo00<007ooOol0CWoo00<007oo
Ool0HWoo00<007ooOol04Goo1@005Goo00<007ooOol0Dgoo00<007ooOol0VGoo00<007ooOol00Woo
00<007ooOol0ogoo3goo00<007ooOol01goo000jOol00`00Oomoo`1ZOol50004Ool00`00Oomoo`1g
Ool00`00Oomoo`0BOol7000<Ool00`00Oomoo`1UOol00`00Oomoo`1>Ool00`00Oomoo`1ROol00`00
Oomoo`0@Ool6000EOol00`00Oomoo`1COol00`00Oomoo`2GOol20005Ool00`00Oomoo`3oOol?Ool0
0`00Oomoo`07Ool003Yoo`03001oogoo06Uoo`D000Ioo`03001oogoo07Ioo`03001oogoo01=oo`<0
009oo`8000Yoo`03001oogoo06Eoo`03001oogoo051oo`03001oogoo065oo`03001oogoo00moo`H0
01Ioo`03001oogoo05=oo`03001oogoo09Ioo`03001oogoo00Eoo`03001oogoo0?moo`moo`03001o
ogoo00Moo`00>Woo00<007ooOol0Igoo1`001Woo00<007ooOol0Mgoo00<007ooOol04Woo0P0000=o
o`00Ool00Woo00<007ooOol01goo00<007ooOol0IGoo00<007ooOol0D7oo00<007ooOol0HGoo00<0
07ooOol03Woo0P0000=oo`00Ool00P005Woo00<007ooOol0Dgoo00<007ooOol0UGoo00<007ooOol0
1goo00<007ooOol0ogoo3Woo00<007ooOol01goo000jOol00`00Oomoo`1VOol70008Ool00`00Oomo
o`1fOol00`00Oomoo`0COol3000=Ool00`00Oomoo`1TOol00`00Oomoo`1BOol00`00Oomoo`1QOol0
0`00Oomoo`0<Ool01P00Oomoogoo001oo`8001Eoo`03001oogoo05Aoo`03001oogoo09=oo`8000]o
o`03001oogoo0?moo`eoo`03001oogoo00Moo`00>Woo00<007ooOol0IGoo0P000Woo0`002Woo0P00
MWoo00<007ooOol04goo0P0000=oo`00Ool02Woo00<007ooOol0IGoo00<007ooOol0DWoo00<007oo
Ool0HGoo00<007ooOol03goo00@007oo000001Ioo`03001oogoo05Eoo`03001oogoo095oo`03001o
ogoo00]oo`03001oogoo0?moo`eoo`03001oogoo00Moo`00>Woo00<007ooOol0J7oo00@007oo0000
00aoo`03001oogoo07=oo`03001oogoo01=oo`800003Ool007oo00Yoo`03001oogoo06Eoo`03001o
ogoo059oo`03001oogoo065oo`03001oogoo00ioo`03001oogoo008001Ioo`03001oogoo05Eoo`03
001oogoo08moo`8000moo`03001oogoo0?moo`aoo`03001oogoo00Moo`00>Woo00<007ooOol0Igoo
00@007ooOol000ioo`03001oogoo079oo`03001oogoo01Aoo`04001oogoo000:Ool00`00Oomoo`1T
Ool00`00Oomoo`1DOol00`00Oomoo`1QOol00`00Oomoo`0<Ool01@00Oomoogoo00005Woo00<007oo
Ool0EWoo00<007ooOol0SWoo00<007ooOol03goo00<007ooOol0ogoo37oo00<007ooOol01goo000j
Ool00`00Oomoo`1VOol00`00Oomoo`02000?Ool00`00Oomoo`1bOol00`00Oomoo`0GOol00`00Oomo
o`06Ool00`00Oomoo`1TOol00`00Oomoo`1FOol00`00Oomoo`1POol00`00Oomoo`0<Ool00`00Oomo
o`0HOol00`00Oomoo`1FOol00`00Oomoo`2<Ool2000BOol00`00Oomoo`3oOol<Ool00`00Oomoo`07
Ool003Yoo`03001oogoo06Eoo`05001oogooOol0000AOol00`00Oomoo`1aOol00`00Oomoo`0HOol0
0`00Oomoo`05Ool00`00Oomoo`1TOol00`00Oomoo`1GOol00`00Oomoo`1OOol00`00Oomoo`0<Ool0
0`00Oomoo`0HOol00`00Oomoo`1FOol00`00Oomoo`2;Ool00`00Oomoo`0COol00`00Oomoo`3oOol;
Ool00`00Oomoo`07Ool003Yoo`03001oogoo06Aoo`03001oogoo01Eoo`03001oogoo071oo`03001o
ogoo01Uoo`03001oogoo00=oo`03001oogoo06Eoo`03001oogoo05Moo`03001oogoo061oo`03001o
ogoo00Yoo`03001oogoo01Uoo`03001oogoo05Moo`03001oogoo08Qoo`8001Moo`03001oogoo0?mo
o`Yoo`03001oogoo00Moo`00>Woo00<007ooOol0Hgoo00<007ooOol05goo00<007ooOol0Kgoo00<0
07ooOol06Woo00<007ooOol00Woo00<007ooOol0I7oo00<007ooOol0FGoo00<007ooOol0Ggoo00<0
07ooOol027oo0P006goo00<007ooOol0F7oo00<007ooOol0Qgoo00<007ooOol05goo00<007ooOol0
ogoo2Woo00<007ooOol01goo000jOol00`00Oomoo`1ROol00`00Oomoo`0IOol00`00Oomoo`1^Ool0
0`00Oomoo`0KOol01000Oomoo`00IWoo00<007ooOol0FWoo0P00HGoo00<007ooOol01Woo00<007oo
Ool06goo00<007ooOol0F7oo00<007ooOol0QWoo00<007ooOol067oo00<007ooOol0ogoo2Woo00<0
07ooOol01goo000jOol00`00Oomoo`1QOol00`00Oomoo`0KOol00`00Oomoo`1]Ool00`00Oomoo`0L
Ool2001VOol00`00Oomoo`1MOol00`00Oomoo`1NOol00`00Oomoo`05Ool00`00Oomoo`0LOol00`00
Oomoo`1HOol00`00Oomoo`24Ool2000LOol00`00Oomoo`3oOol9Ool00`00Oomoo`07Ool003Yoo`03
001oogoo061oo`03001oogoo01eoo`03001oogoo06eoo`03001oogoo01aoo`03001oogoo06=oo`03
001oogoo05moo`03001oogoo05ioo`03001oogoo009oo`8001ioo`03001oogoo05Uoo`03001oogoo
089oo`8001moo`03001oogoo0?moo`Qoo`03001oogoo00Moo`00>Woo00<007ooOol0Ggoo00<007oo
Ool07goo00<007ooOol0K7oo00<007ooOol06goo00@007oo0000069oo`03001oogoo065oo`03001o
ogoo05eoo`05001oogooOol0000POol00`00Oomoo`1IOol00`00Oomoo`21Ool00`00Oomoo`0OOol0
0`00Oomoo`3oOol8Ool00`00Oomoo`07Ool003Yoo`03001oogoo05ioo`03001oogoo025oo`03001o
ogoo06]oo`03001oogoo01]oo`05001oogooOol0001POol00`00Oomoo`1SOol00`00Oomoo`1MOol0
0`00Ool0000QOol00`00Oomoo`1IOol00`00Oomoo`1oOol2000ROol00`00Oomoo`3oOol8Ool00`00
Oomoo`07Ool003Yoo`03001oogoo05eoo`03001oogoo02=oo`03001oogoo06]oo`03001oogoo01Uo
o`03001oogoo00=oo`03001oogoo05]oo`8006Moo`03001oogoo05aoo`80029oo`03001oogoo05Yo
o`03001oogoo07aoo`8002Eoo`03001oogoo0?moo`Moo`03001oogoo00Moo`00>Woo00<007ooOol0
Fgoo0P009goo0P00Jgoo00<007ooOol067oo00<007ooOol01Goo00<007ooOol0FGoo00<007ooOol0
J7oo00<007ooOol0FWoo0P008Woo00<007ooOol0Fgoo00<007ooOol0NWoo0P009goo00<007ooOol0
ogoo1goo00<007ooOol01goo000jOol00`00Oomoo`1JOol00`00Oomoo`0YOol00`00Oomoo`1XOol0
0`00Oomoo`0HOol00`00Oomoo`06Ool2001HOol00`00Oomoo`1ZOol00`00Oomoo`1HOol01000Oomo
o`008Goo00<007ooOol0Fgoo00<007ooOol0NGoo00<007ooOol0:7oo00<007ooOol0ogoo1Woo00<0
07ooOol01goo000jOol00`00Oomoo`1IOol00`00Oomoo`0[Ool00`00Oomoo`1XOol00`00Oomoo`0F
Ool00`00Oomoo`09Ool2001EOol00`00Oomoo`1/Ool00`00Oomoo`1EOol20003Ool00`00Oomoo`0O
Ool00`00Oomoo`1KOol00`00Oomoo`1gOol2000[Ool00`00Oomoo`3oOol6Ool00`00Oomoo`07Ool0
03Yoo`03001oogoo05Qoo`03001oogoo02eoo`03001oogoo06Moo`03001oogoo01Eoo`03001oogoo
00aoo`03001oogoo055oo`03001oogoo06ioo`03001oogoo05=oo`03001oogoo00Aoo`03001oogoo
01eoo`03001oogoo05aoo`03001oogoo07Eoo`8002eoo`03001oogoo0?moo`Ioo`03001oogoo00Mo
o`00>Woo00<007ooOol0Egoo00<007ooOol0;goo00<007ooOol0IWoo00<007ooOol057oo00<007oo
Ool03Woo0P00D7oo00<007ooOol0L7oo00<007ooOol0Cgoo0`001goo00<007ooOol07Goo00<007oo
Ool0G7oo00<007ooOol0Lgoo0P00<7oo00<007ooOol0ogoo1Goo00<007ooOol01goo000jOol00`00
Oomoo`1FOol00`00Oomoo`0aOol00`00Oomoo`1VOol00`00Oomoo`0BOol00`00Oomoo`0AOol3001<
Ool00`00Oomoo`1bOol00`00Oomoo`1=Ool00`00Oomoo`09Ool00`00Oomoo`0LOol00`00Oomoo`1L
Ool2001cOol00`00Oomoo`0`Ool00`00Oomoo`3oOol5Ool00`00Oomoo`07Ool003Yoo`03001oogoo
05Eoo`03001oogoo03=oo`03001oogoo06Eoo`03001oogoo015oo`03001oogoo01Eoo`8004Uoo`03
001oogoo07Aoo`03001oogoo04Uoo`<000aoo`03001oogoo01]oo`03001oogoo05eoo`80075oo`80
03=oo`03001oogoo0?moo`Eoo`03001oogoo00Moo`00>Woo1@00DWoo00<007ooOol0=Goo0P00IWoo
00<007ooOol03Woo0P006Woo0`00AGoo00<007ooOol0MWoo00<007ooOol0AWoo0P0047oo00<007oo
Ool06Woo00<007ooOol0GGoo0P00Kgoo0P00=Woo00<007ooOol0oWoo1P002Goo000jOol00`00Oomo
o`1COol00`00Oomoo`0hOol2001TOol00`00Oomoo`0=Ool00`00Oomoo`0MOol3000oOol3001jOol3
0012Ool3000BOol00`00Oomoo`0IOol00`00Oomoo`1NOol3001/Ool2000iOol00`00Oomoo`3oOol3
Ool00`00Oomoo`07Ool003Yoo`03001oogoo055oo`8003eoo`03001oogoo065oo`03001oogoo00ao
o`03001oogoo025oo`8003Uoo`@0081oo`<003eoo`8001Ioo`03001oogoo01Qoo`03001oogoo05io
o`<006Yoo`8003]oo`03001oogoo0?moo`=oo`03001oogoo00Moo`00>Woo00<007ooOol0D7oo00<0
07ooOol0?Woo0P00HGoo0P002goo0P009Woo0`00:Goo0P001goo1000Qgoo10002Goo0`00:Woo0`00
6Goo00<007ooOol05goo00<007ooOol0GWoo1000Igoo0P00?Goo0P00ogoo17oo00<007ooOol01goo
000jOol00`00Oomoo`1>Ool20013Ool2001OOol2000:Ool00`00Oomoo`0YOol4000ROol30005Ool4
002?Ool40007Ool4000TOol3000MOol00`00Oomoo`0EOol00`00Oomoo`1NOol5001TOol3000oOol3
003oOol3Ool00`00Oomoo`07Ool003Yoo`03001oogoo04eoo`03001oogoo04Eoo`03001oogoo05ao
o`<000Qoo`03001oogoo02ioo`D001Yoo`@00003Ool0000000@009Moo`D000=oo`H001eoo`@0025o
o`03001oogoo01=oo`80061oo`800003Ool00000069oo`80049oo`<00?moo`=oo`03001oogoo00Mo
o`00>Woo00<007ooOol0C7oo00<007ooOol0Agoo0P00GGoo0P001goo00<007ooOol0=7oo1@004Woo
2000XWoo30005Goo1@009Woo00<007ooOol04Woo0P00H7oo0P0000Aoo`00000005moo`8004Aoo`@0
0?moo`9oo`03001oogoo00Moo`00>Woo00<007ooOol0BWoo0P00C7oo0P00Fgoo0`0017oo0P00?7oo
6`00YWoo7000;7oo00<007ooOol047oo0`00H7oo0P0000Aoo`00Ool005aoo`<004Ioo`D00?moo`5o
o`03001oogoo00Moo`00>Woo00<007ooOol0B7oo0P00D7oo0P00FGoo10000Woo00<007ooOol0DGoo
2000XGoo1`00AGoo00<007ooOol03Woo0`00HGoo00@007ooOol0009oo`03001oogoo05Moo`8004Yo
o`800003Ool000000?moo`03001oogoo00Moo`00>Woo00<007ooOol0Agoo00<007ooOol0DWoo00<0
07ooOol0EWoo1P00FWoo0`00WWoo0`00C7oo00<007ooOol037oo1000HGoo00@007ooOol005Yoo`80
04aoo`80009oo`03001oogoo0?eoo`03001oogoo00Moo`00>Woo00<007ooOol0AWoo00<007ooOol0
E7oo0P00EWoo1@00ogooCGoo00<007ooOol02goo00@007oo000006Aoo`03001oogoo05Ioo`8004io
o`<0009oo`03001oogoo0?aoo`03001oogoo00Moo`00>Woo00<007ooOol0@goo0`00FGoo0P00E7oo
0`000Woo00<007ooOol0ogooBgoo00<007ooOol02Goo00<007oo00000P00I7oo00<007ooOol0E7oo
0P00D7oo00<007oo00000goo00<007ooOol0ngoo00<007ooOol01goo000jOol00`00Oomoo`12Ool0
0`00Oomoo`1LOol3001@Ool300001Goo001oogoo0000ogooCGoo00<007ooOol01goo00<007ooOol0
0`00IGoo00<007ooOol0D7oo0`00DWoo00@007ooOol00?moo`5oo`03001oogoo00Moo`00>Woo00<0
07ooOol0?goo0`00HWoo0`00Bgoo0P000Woo00<007oo0000ogooDGoo00<007ooOol01Goo00D007oo
Ool007oo008006Eoo`03001oogoo04ioo`8005Eoo`04001oogoo003oOol1Ool00`00Oomoo`07Ool0
03Yoo`03001oogoo03ioo`03001oogoo06Ioo`8004Qoo`03001oogoo009oo`03001oo`000?mooe9o
o`03001oogoo00=oo`07001oogooOol007oo0000IWoo00<007ooOol0C7oo0P00Egoo00@007ooOol0
0?moo`5oo`03001oogoo00Moo`00>Woo00<007ooOol0?7oo0P00Jgoo0`00@goo0P0027oo00<007oo
Ool0ogooD7oo00<007ooOol01Woo00<007oo0000IWoo00<007ooOol0BWoo0P00GGoo00<007ooOol0
oGoo00<007ooOol01goo000jOol00`00Oomoo`0iOol3001`Ool3000mOol3000:Ool00`00Oomoo`3o
OomAOol00`00Oomoo`04Ool01000Oomoo`00IWoo00<007ooOol0Agoo0`00Ggoo00<007ooOol0oGoo
00<007ooOol01goo000jOol00`00Oomoo`0fOol3001fOol5000eOol3000=Ool00`00Oomoo`3oOomB
Ool00`00Oomoo`03Ool00`00Oomoo`1WOol00`00Oomoo`13Ool4001ROol00`00Oomoo`3mOol00`00
Oomoo`07Ool003Yoo`03001oogoo039oo`@007ioo`D002]oo`D0015oo`03001oogoo0?mooe9oo`80
00=oo`03001oogoo06Moo`03001oogoo03moo`@006Moo`03001oogoo0?aoo`03001oogoo00Moo`00
>Woo00<007ooOol0;Woo1000Qgoo1@008Goo1@005Woo00<007ooOol0ogooE7oo0`00JWoo00<007oo
Ool0>goo1000Jgoo00<007ooOol0o7oo00<007ooOol01goo000jOol00`00Oomoo`0WOol7002@Ool7
000COol7000LOol00`00Oomoo`3oOomDOol2001[Ool00`00Oomoo`0gOol3001_Ool00`00Oomoo`3l
Ool00`00Oomoo`07Ool003Yoo`03001oogoo0<Eooa<002=oo`03001oogoo0?mooeAoo`04001oo`00
001YOol00`00Oomoo`0dOol3001cOol00`00Oomoo`3kOol00`00Oomoo`07Ool003Yoo`03001oogoo
0?]oo`03001oogoo0?mooeAoo`04001oogooOol2001WOol00`00Oomoo`0aOol3001fOol00`00Oomo
o`3kOol00`00Oomoo`07Ool003Yoo`03001oogoo0?aoo`03001oogoo0?mooe9oo`03001oogoo00Ao
o`8006Eoo`03001oogoo02eoo`@007Uoo`03001oogoo0?]oo`03001oogoo00Moo`00>Woo00<007oo
Ool0o7oo00<007ooOol0ogooDWoo00<007ooOol01Woo00<007ooOol0HWoo00<007ooOol0:Woo0`00
OWoo00<007ooOol0nWoo00<007ooOol01goo000jOol00`00Oomoo`3lOol00`00Oomoo`3oOomAOol0
0`00Oomoo`08Ool2001ROol00`00Oomoo`0VOol40021Ool00`00Oomoo`3jOol00`00Oomoo`07Ool0
03Yoo`03001oogoo0?eoo`03001oogoo0?mooe1oo`03001oogoo00Yoo`80061oo`03001oogoo02=o
o`<008Eoo`03001oogoo0?Yoo`03001oogoo00Moo`00>Woo00<007ooOol0oGoo00<007ooOol0ogoo
D7oo00<007ooOol037oo0`00GGoo00<007ooOol07goo1000RGoo00<007ooOol0nGoo00<007ooOol0
1goo000jOol00`00Oomoo`3mOol00`00Oomoo`3oOom?Ool00`00Oomoo`0@Ool3001KOol00`00Oomo
o`0IOol5002=Ool00`00Oomoo`3iOol00`00Oomoo`07Ool003Yoo`03001oogoo0?ioo`03001oogoo
0?moodioo`03001oogoo01=oo`8005Uoo`03001oogoo01Eoo`@0099oo`03001oogoo0?Uoo`03001o
ogoo00Moo`00>Woo00<007ooOol0oWoo00<007ooOol0ogooCWoo00<007ooOol05Goo0`00EWoo00<0
07ooOol04Goo1000Ugoo00<007ooOol0n7oo00<007ooOol01goo000jOol00`00Oomoo`3nOol00`00
Oomoo`3oOom=Ool00`00Oomoo`0IOol4001BOol00`00Oomoo`0<Ool5002KOol00`00Oomoo`3hOol0
0`00Oomoo`07Ool003Yoo`03001oogoo0?moo`03001oogoo0?mood]oo`03001oogoo01ioo`D004eo
o`03001oogoo00Moo`D00:1oo`03001oogoo0?Qoo`03001oogoo00Moo`00>Woo1@00oGoo00<007oo
Ool0ogooBgoo00<007ooOol08goo1@00Agoo2`00YGoo00<007ooOol0lgoo1P002Goo000jOol00`00
Oomoo`3oOol1Ool00`00Oomoo`3oOom:Ool00`00Oomoo`0XOol4000lOol700000goo001oo`2]Ool0
0`00Oomoo`3hOol00`00Oomoo`07Ool003Yoo`03001oogoo0?moo`5oo`03001oogoo0?moodUoo`03
001oogoo02eoo`L002ioo`L000Qoo`03001oogoo0:eoo`03001oogoo0?Moo`03001oogoo00Moo`00
>Woo00<007ooOol0ogoo0Goo00<007ooOol0ogooBGoo00<007ooOol0=7oo2P006Woo2P003goo00<0
07ooOol0[Goo00<007ooOol0mgoo00<007ooOol01goo000jOol00`00Oomoo`3oOol2Ool00`00Oomo
o`3oOom8Ool00`00Oomoo`0nOolJ000IOol00`00Oomoo`2]Ool00`00Oomoo`3gOol00`00Oomoo`07
Ool003Yoo`03001oogoo0?moo`9oo`03001oogoo0?moodMoo`03001oogoo079oo`03001oogoo0:io
o`03001oogoo0?Ioo`03001oogoo00Moo`00>Woo00<007ooOol0ogoo0Woo00<007ooOol0ogooAWoo
00<007ooOol0Lgoo00<007ooOol0[Woo00<007ooOol0mWoo00<007ooOol01goo000jOol00`00Oomo
o`3oOol3Ool00`00Oomoo`3oOom5Ool00`00Oomoo`1dOol00`00Oomoo`2]Ool00`00Oomoo`3fOol0
0`00Oomoo`07Ool003Yoo`03001oogoo0?moo`=oo`03001oogoo0?moodEoo`03001oogoo07Aoo`03
001oogoo0:eoo`03001oogoo0?Ioo`03001oogoo00Moo`00>Woo00<007ooOol0ogoo0goo00<007oo
Ool0ogooA7oo00<007ooOol0MGoo00<007ooOol0[Goo00<007ooOol0mWoo00<007ooOol01goo000j
Ool00`00Oomoo`3oOol4Ool00`00Oomoo`3oOom3Ool00`00Oomoo`1eOol00`00Oomoo`2^Ool00`00
Oomoo`3eOol00`00Oomoo`07Ool003Yoo`03001oogoo0?moo`Eoo`03001oogoo0?mood5oo`03001o
ogoo07Ioo`03001oogoo0:ioo`03001oogoo0?Eoo`03001oogoo00Moo`00>Woo00<007ooOol0ogoo
1Goo00<007ooOol0ogoo@Goo00<007ooOol0MWoo00<007ooOol0[Woo00<007ooOol0mGoo00<007oo
Ool01goo000jOol00`00Oomoo`3oOol5Ool00`00Oomoo`3oOom1Ool00`00Oomoo`1fOol00`00Oomo
o`2_Ool00`00Oomoo`3dOol00`00Oomoo`07Ool003Yoo`03001oogoo0?moo`Ioo`03001oogoo0?mo
ocmoo`03001oogoo07Moo`03001oogoo0:moo`03001oogoo0?Aoo`03001oogoo00Moo`00>Woo00<0
07ooOol0ogoo1Woo00<007ooOol0ogoo?goo00<007ooOol0Mgoo00<007ooOol0[goo00<007ooOol0
m7oo00<007ooOol01goo000jOol00`00Oomoo`3oOol6Ool00`00Oomoo`3oOoloOol00`00Oomoo`1g
Ool00`00Oomoo`2_Ool00`00Oomoo`3dOol00`00Oomoo`07Ool003Yoo`03001oogoo0?moo`Moo`03
001oogoo0?mooceoo`03001oogoo07Qoo`03001oogoo0:moo`03001oogoo0?Aoo`03001oogoo00Mo
o`00>Woo00<007ooOol0ogoo1goo00<007ooOol0ogoo?Goo00<007ooOol0NGoo00<007ooOol0[goo
00<007ooOol0lgoo00<007ooOol01goo000jOol00`00Oomoo`3oOol7Ool00`00Oomoo`3oOolmOol0
0`00Oomoo`1iOol00`00Oomoo`2_Ool00`00Oomoo`3cOol00`00Oomoo`07Ool003Yoo`03001oogoo
0?moo`Qoo`03001oogoo0?mooc]oo`03001oogoo07Yoo`03001oogoo0:moo`03001oogoo0?=oo`03
001oogoo00Moo`00>Woo00<007ooOol0ogoo27oo00<007ooOol0ogoo>goo00<007ooOol0NWoo00<0
07ooOol0[goo00<007ooOol0lgoo00<007ooOol01goo000jOol00`00Oomoo`3oOol8Ool00`00Oomo
o`3oOolkOol00`00Oomoo`1jOol00`00Oomoo`2_Ool00`00Oomoo`3cOol00`00Oomoo`07Ool003Yo
o`03001oogoo0?moo`Qoo`03001oogoo0?moocYoo`03001oogoo07]oo`03001oogoo0:moo`03001o
ogoo0?=oo`03001oogoo00Moo`00>Woo00<007ooOol0ogoo27oo00<007ooOol0ogoo>Woo00<007oo
Ool0Ngoo00<007ooOol0[goo00<007ooOol0lgoo00<007ooOol01goo000jOol00`00Oomoo`3oOol9
Ool00`00Oomoo`3oOoliOol00`00Oomoo`1kOol00`00Oomoo`2`Ool00`00Oomoo`3bOol00`00Oomo
o`07Ool003Yoo`03001oogoo0?moo`Uoo`03001oogoo0?moocQoo`03001oogoo07aoo`03001oogoo
0;1oo`03001oogoo0?9oo`03001oogoo00Moo`00>Woo00<007ooOol0ogoo2Goo00<007ooOol0ogoo
>7oo00<007ooOol0O7oo00<007ooOol0/7oo00<007ooOol0lWoo00<007ooOol01goo000jOol00`00
Oomoo`3oOol:Ool00`00Oomoo`3oOolgOol00`00Oomoo`1lOol00`00Oomoo`2`Ool00`00Oomoo`3b
Ool00`00Oomoo`07Ool003Yoo`03001oogoo0?moo`Yoo`03001oogoo0?moocIoo`03001oogoo07eo
o`03001oogoo0;1oo`03001oogoo0?9oo`03001oogoo00Moo`00>Woo00<007ooOol0ogoo2Woo00<0
07ooOol0ogoo=Woo00<007ooOol0OGoo00<007ooOol0/Goo00<007ooOol0lGoo00<007ooOol01goo
000jOol00`00Oomoo`3oOol:Ool00`00Oomoo`3oOolfOol00`00Oomoo`1mOol00`00Oomoo`2aOol0
0`00Oomoo`3aOol00`00Oomoo`07Ool003Yoo`03001oogoo0?moo`Yoo`03001oogoo0?moocIoo`03
001oogoo07eoo`03001oogoo0;5oo`03001oogoo0?5oo`03001oogoo00Moo`00>Woo00<007ooOol0
ogoo2goo00<007ooOol0ogoo=Goo00<007ooOol0OGoo00<007ooOol0/Goo00<007ooOol0lGoo00<0
07ooOol01goo000jOol5003oOol9Ool00`00Oomoo`3oOoldOol00`00Oomoo`1nOol00`00Oomoo`2a
Ool00`00Oomoo`3/Ool60009Ool003Yoo`03001oogoo0?moo`]oo`03001oogoo0?moocAoo`03001o
ogoo07ioo`03001oogoo0;5oo`03001oogoo0?5oo`03001oogoo00Moo`00>Woo00<007ooOol0ogoo
37oo00<007ooOol0ogoo<goo00<007ooOol0OWoo00<007ooOol0/Woo00<007ooOol0l7oo00<007oo
Ool01goo000jOol00`00Oomoo`3oOol<Ool00`00Oomoo`3oOolbOol00`00Oomoo`1oOol00`00Oomo
o`2bOol00`00Oomoo`3`Ool00`00Oomoo`07Ool003Yoo`03001oogoo0?moo`aoo`03001oogoo0?mo
oc9oo`03001oogoo081oo`03001oogoo0;5oo`03001oogoo0?1oo`03001oogoo00Moo`00>Woo00<0
07ooOol0ogoo37oo00<007ooOol0ogoo<Woo00<007ooOol0P7oo00<007ooOol0/Goo00<007ooOol0
l7oo00<007ooOol01goo000jOol00`00Oomoo`3oOol<Ool00`00Oomoo`3oOolbOol00`00Oomoo`20
Ool00`00Oomoo`2aOol00`00Oomoo`3`Ool00`00Oomoo`07Ool003Yoo`03001oogoo0?moo`aoo`03
001oogoo0?mooc9oo`03001oogoo081oo`03001oogoo0;5oo`03001oogoo0?1oo`03001oogoo00Mo
o`00>Woo00<007ooOol0ogoo37oo00<007ooOol0ogoo<Goo00<007ooOol0PGoo00<007ooOol0/Goo
00<007ooOol0l7oo00<007ooOol01goo000jOol00`00Oomoo`3oOol=Ool00`00Oomoo`3oOol`Ool0
0`00Oomoo`21Ool00`00Oomoo`2aOol00`00Oomoo`3`Ool00`00Oomoo`07Ool003Yoo`03001oogoo
0?moo`eoo`03001oogoo0?mooc1oo`03001oogoo085oo`03001oogoo0;5oo`03001oogoo0?1oo`03
001oogoo00Moo`00>Woo00<007ooOol0ogoo3Goo00<007ooOol0ogoo<7oo00<007ooOol0PGoo00<0
07ooOol0/Goo00<007ooOol0l7oo00<007ooOol01goo000jOol00`00Oomoo`3oOol=Ool00`00Oomo
o`3oOol`Ool00`00Oomoo`21Ool00`00Oomoo`2bOol00`00Oomoo`3_Ool00`00Oomoo`07Ool003Yo
o`03001oogoo0?moo`eoo`03001oogoo0?moobmoo`03001oogoo089oo`03001oogoo0;9oo`03001o
ogoo0>moo`03001oogoo00Moo`00>Woo00<007ooOol0ogoo3Woo00<007ooOol0ogoo;Woo00<007oo
Ool0PWoo00<007ooOol0/Woo00<007ooOol0kgoo00<007ooOol01goo000jOol00`00Oomoo`3oOol>
Ool00`00Oomoo`3oOol^Ool00`00Oomoo`22Ool00`00Oomoo`2bOol00`00Oomoo`3_Ool00`00Oomo
o`07Ool003Yoo`03001oogoo0?moo`ioo`03001oogoo0?moobioo`03001oogoo089oo`03001oogoo
0;9oo`03001oogoo0>moo`03001oogoo00Moo`00>Woo00<007ooOol0ogoo3Woo00<007ooOol0ogoo
;Woo00<007ooOol0PWoo00<007ooOol0/Woo00<007ooOol0kgoo00<007ooOol01goo000jOol00`00
Oomoo`3oOol>Ool00`00Oomoo`3oOol^Ool00`00Oomoo`22Ool00`00Oomoo`2bOol00`00Oomoo`3_
Ool00`00Oomoo`07Ool003Yoo`03001oogoo0?moo`ioo`03001oogoo0?moobioo`03001oogoo089o
o`03001oogoo0;9oo`03001oogoo0>moo`03001oogoo00Moo`00>Woo00<007ooOol0ogoo3Woo00<0
07ooOol0ogoo;Goo00<007ooOol0Pgoo00<007ooOol0/Woo00<007ooOol0kgoo00<007ooOol01goo
000jOol00`00Oomoo`3oOol>Ool00`00Oomoo`3oOol]Ool00`00Oomoo`23Ool00`00Oomoo`2bOol0
0`00Oomoo`3_Ool00`00Oomoo`07Ool003Yoo`03001oogoo0?moo`moo`03001oogoo0?moobaoo`03
001oogoo08=oo`03001oogoo0;9oo`03001oogoo0>moo`03001oogoo00Moo`00>Woo00<007ooOol0
ogoo3goo00<007ooOol0ogoo;7oo00<007ooOol0Pgoo00<007ooOol0/Woo00<007ooOol0kgoo00<0
07ooOol01goo000jOol00`00Oomoo`3oOol?Ool00`00Oomoo`3oOol/Ool00`00Oomoo`23Ool00`00
Oomoo`2bOol00`00Oomoo`3_Ool00`00Oomoo`07Ool003Yoo`03001oogoo0?moo`moo`03001oogoo
0?moobaoo`03001oogoo08=oo`03001oogoo0;9oo`03001oogoo0>moo`03001oogoo00Moo`0047oo
1`002Woo10005Goo00<007ooOol0ogoo3goo00<007ooOol0ogoo;7oo00<007ooOol0Pgoo00<007oo
Ool0/Woo00<007ooOol0kgoo00<007ooOol01goo000@Ool70008Ool8000COol00`00Oomoo`3oOol?
Ool00`00Oomoo`3oOol/Ool00`00Oomoo`23Ool00`00Oomoo`2bOol00`00Oomoo`3_Ool00`00Oomo
o`07Ool001=oo`8000Yoo`8000Aoo`8001=oo`03001oogoo0?moo`moo`03001oogoo0?moobaoo`03
001oogoo08=oo`03001oogoo0;9oo`03001oogoo0>moo`03001oogoo00Moo`004goo0P002Goo0P00
1Woo0P004Woo00<007ooOol0ogoo3goo00<007ooOol0ogoo;7oo00<007ooOol0Pgoo00<007ooOol0
/Woo00<007ooOol0kgoo00<007ooOol01goo000COol20009Ool20006Ool2000BOol00`00Oomoo`3o
Ool?Ool00`00Oomoo`3oOol/Ool00`00Oomoo`23Ool00`00Oomoo`2cOol00`00Oomoo`3^Ool00`00
Oomoo`07Ool000]oo``000Ioo`8000Qoo`80015oo`03001oogoo0?moo`moo`03001oogoo0?moobao
o`03001oogoo08=oo`03001oogoo0;=oo`03001oogoo0>ioo`03001oogoo00Moo`002goo30001Woo
0P0027oo0P004Goo00<007ooOol0ogoo3goo00<007ooOol0ogoo;7oo00<007ooOol0Pgoo00<007oo
Ool0/goo00<007ooOol0kWoo00<007ooOol01goo000;Ool20006Ool200000goo001oo`05Ool20008
Ool2000AOol8003oOoooOoliOol00`00Oomoo`3oOoooOolUOol80009Ool000aoo`8000Eoo`8000Qo
o`8000Qoo`80015oo`03001oogoo0?mooomooomooomoofeoo`03001oogoo00Moo`0037oo0`0017oo
0P0027oo0P0027oo0P004Goo00<007ooOol0ogooogooogooogooKGoo00<007ooOol01goo000=Ool2
0004Ool20008Ool20008Ool2000AOol00`00Oomoo`3oOoooOoooOoooOom]Ool00`00Oomoo`07Ool0
00ioo`8000=oo`8000Qoo`8000Qoo`80015oo`03001oogoo0?mooomooomooomoofeoo`03001oogoo
00Moo`003Woo0`000Woo0P0027oo0P0027oo0P004Goo00<007ooOol0ogooogooogooogooKGoo00<0
07ooOol01goo000?Ool20002Ool20009Ool20006Ool2000BOol00`00Oomoo`3oOoooOoooOoooOom]
Ool00`00Oomoo`07Ool0011oo`800003Ool0000000Uoo`8000Ioo`80019oo`03001oogoo0?mooomo
oomooomoofeoo`03001oogoo00Moo`004Goo10002Woo0P0017oo0P004goo00<007ooOol0ogooogoo
ogooogooKGoo00<007ooOol01goo000AOol4000:Ool8000COol00`00Oomoo`0HOol00`00Oomoo`3o
Ool<Ool00`00Oomoo`3oOol;Ool00`00Oomoo`3oOol<Ool00`00Oomoo`3oOol;Ool00`00Oomoo`0H
Ool00`00Oomoo`07Ool0019oo`<000aoo`@001Eoo`03001oogoo01Qoo`03001oogoo0?moo`aoo`03
001oogoo0?moo`]oo`03001oogoo0?moo`aoo`03001oogoo0?moo`]oo`03001oogoo01Qoo`03001o
ogoo00Moo`00>Woo00<007ooOol067oo00<007ooOol0ogoo37oo00<007ooOol0ogoo2goo00<007oo
Ool0ogoo37oo00<007ooOol0ogoo2goo00<007ooOol067oo00<007ooOol01goo000jOol00`00Oomo
o`0HOol00`00Oomoo`10Ool00`00Oomoo`11Ool00`00Oomoo`10Ool00`00Oomoo`11Ool00`00Oomo
o`10Ool00`00Oomoo`10Ool00`00Oomoo`11Ool00`00Oomoo`10Ool00`00Oomoo`11Ool00`00Oomo
o`10Ool00`00Oomoo`10Ool00`00Oomoo`11Ool00`00Oomoo`10Ool00`00Oomoo`11Ool00`00Oomo
o`10Ool00`00Oomoo`10Ool00`00Oomoo`0HOol00`00Oomoo`07Ool003Yoo`03001oogoo01Qoo`03
001oogoo041oo`03001oogoo045oo`03001oogoo041oo`03001oogoo045oo`03001oogoo041oo`03
001oogoo041oo`03001oogoo045oo`03001oogoo041oo`03001oogoo045oo`03001oogoo041oo`03
001oogoo041oo`03001oogoo045oo`03001oogoo041oo`03001oogoo045oo`03001oogoo041oo`03
001oogoo041oo`03001oogoo01Qoo`03001oogoo00Moo`00>Woo00<007ooOol067oo00<007ooOol0
@7oo00<007ooOol0@Goo00<007ooOol0@7oo00<007ooOol0@Goo00<007ooOol0@7oo00<007ooOol0
@7oo00<007ooOol0@Goo00<007ooOol0@7oo00<007ooOol0@Goo00<007ooOol0@7oo00<007ooOol0
@7oo00<007ooOol0@Goo00<007ooOol0@7oo00<007ooOol0@Goo00<007ooOol0@7oo00<007ooOol0
@7oo00<007ooOol067oo00<007ooOol01goo000jOol00`00Oomoo`0HOol00`00Oomoo`10Ool00`00
Oomoo`11Ool00`00Oomoo`10Ool00`00Oomoo`11Ool00`00Oomoo`10Ool00`00Oomoo`10Ool00`00
Oomoo`11Ool00`00Oomoo`10Ool00`00Oomoo`11Ool00`00Oomoo`10Ool00`00Oomoo`10Ool00`00
Oomoo`11Ool00`00Oomoo`10Ool00`00Oomoo`11Ool00`00Oomoo`10Ool00`00Oomoo`10Ool00`00
Oomoo`0HOol00`00Oomoo`07Ool003Yoool00?l00?l00?l0074000Uoo`00\
\>"], "Graphics",
  CellLabel->"From In[45]:=",
  Evaluatable->False,
  PageBreakAbove->True,
  ImageSize->{400, 247.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[56]="]
}, Open  ]],

Cell["\<\
The above picture shows the field and the equipotential lines of \
two electrodes, the upper one at zero, the lower at 1. All lines display a \
kink, whenever they enter or leave the dielectric (the greyish bordered \
area).\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["gradient field... ", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The matrix of gradient vectors needs a complicated build: the last \
row has same the y component as the row above, the last column has the same x \
component as the column to its left:
\
\>", "Text"],

Cell[BoxData[{
    \(\(g = 
        Table[{u[\([i, j + 1]\)] - u[\([i, j]\)], 
            u[\([i + 1, j]\)] - u[\([i, j]\)]}, {i, 1, nz - 1}, {j, 1, 
            ns - 1}];\)\), "\n", 
    \(\(lrow = 
        Table[{u[\([nz, j + 1]\)] - u[\([nz, j]\)], 
            u[\([nz, j]\)] - u[\([nz - 1, j]\)]}, {j, 1, 
            ns - 1}];\)\ \), "\[IndentingNewLine]", 
    \(\(g = Append[g, lrow];\)\), "\[IndentingNewLine]", 
    \(\(lcol = 
        Append[Table[{u[\([i, ns]\)] - u[\([i, ns - 1]\)], 
              u[\([i + 1, ns]\)] - u[\([i, ns]\)]}, {i, 1, 
              nz - 1}], {u[\([nz, ns]\)] - u[\([nz, ns - 1]\)], 
            u[\([nz, ns]\)] - 
              u[\([nz - 1, ns]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(g = Transpose[Append[Transpose[g], lcol]];\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["calculate integral over electric field", "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "Use (27) to get ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\)]],
  " in [F/m] from the field:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Epsilon]\_0 = 
        10\^\(-9\)\/\(35.95  \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(cap = \(\[Epsilon]\_0\) 
        Sum[\[Epsilon][\([i, j]\)] g[\([i, j]\)] . g[\([i, j]\)], {i, 1, 
            nz}, {j, 1, ns}]\)}], "Input",
  CellLabel->"In[70]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(6.289035749531222`*^-11\)], "Output",
  CellLabel->"Out[71]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["results for the capacities ", "Subsubsection"],

Cell[TextData[{
  "The following results were obtained in three runs with the parameters vi \
as specified :\n",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_11\)]],
  " = 62.9 [pF/m]      (v1 = 1, v2 = 0)\n",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_22\)]],
  " = 75.7 [pF/m]      (v1 = 0, v2 = 1)\n",
  Cell[BoxData[
      \(TraditionalForm\`CC\&~\)]],
  "  =  66.1 [pF/m]     (v1 = 1, v2 = 1)\n",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_12\)]],
  " = 0.5 (",
  Cell[BoxData[
      \(TraditionalForm\`CC\&~\)]],
  "  - ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_11\)]],
  "- ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_22\)]],
  ") =  - 36.3 [pF/m]\n\nTo understand the negative sign of ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_12\)]],
  " look at (21) with  ",
  Cell[BoxData[
      \(TraditionalForm\`U\_1\)]],
  " = 1 and all other voltages set to zero. From the sign of the field \
produced by the charges on both conductors (see picture of field above) it is \
seen that  for example ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_11\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_12\)]],
  " must be of opposite sign.\n\nWith (24) follow the coefficients of \
capacity:\n\n",
  Cell[BoxData[
      \(TraditionalForm\`C\_10\)]],
  " = 26.6 [pF/m]\n",
  Cell[BoxData[
      \(TraditionalForm\`C\_20\)]],
  " = 39.4 [pF/m]\n",
  Cell[BoxData[
      \(TraditionalForm\`C\_12\)]],
  " = 36.3 [pF/m]\n\nThere is good agreement with the theory. The formula \
from the textbook gives ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\_\(r, eff\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\_0\)]],
  Cell[BoxData[
      \(TraditionalForm\`A\/\(d\ l\)\)]],
  " \[TildeTilde] 36.8 [pF/m] (enter A=19, d=13 and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\_\(r, eff\)\)]],
  "=(8*4+5*1)/(8+5)=2.85 as parameters). It takes into account the mutual \
capacity ",
  Cell[BoxData[
      \(TraditionalForm\`C\_12\)]],
  " of the two conductors and ignores the surrounding ground.\nThe values ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\(i\ j\)\)]],
  " reflect the ",
  StyleBox["geometry",
    FontSlant->"Italic"],
  " of the electrodes and may be combined in various ways to model different \
modes of operating this capacitor :\ndifferential:                 effective  \
C = ",
  Cell[BoxData[
      \(TraditionalForm\`C\_12\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`C\_10\)]],
  "\[VerticalSeparator]\[VerticalSeparator] ",
  Cell[BoxData[
      \(TraditionalForm\`C\_20\)]],
  "  = 52.2 [pF/m] ( \[VerticalSeparator]\[VerticalSeparator] means here: in \
series )\nelectrode 1 grounded (",
  Cell[BoxData[
      \(TraditionalForm\`C\_10\)]],
  "=\[Infinity]) : C = ",
  Cell[BoxData[
      \(TraditionalForm\`C\_12\)]],
  "+      ",
  Cell[BoxData[
      \(TraditionalForm\`C\_20\)]],
  "      = 75.7 [pF/m]\nelectrode 2 grounded (",
  Cell[BoxData[
      \(TraditionalForm\`C\_20\)]],
  "=\[Infinity]) : C = ",
  Cell[BoxData[
      \(TraditionalForm\`C\_12\)]],
  "+      ",
  Cell[BoxData[
      \(TraditionalForm\`C\_10\)]],
  "      = 62.9 [pF/m]\nThe differences are sizeable, because the stray \
capacities are not negligible."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inductances", "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell["Definition of Coefficients of Self- and Mutual Inductance", \
"Subsubsection"],

Cell[TextData[{
  "There is a far reaching ",
  StyleBox["duality",
    FontSlant->"Italic"],
  " between electric and magnetic fields, voltages and currents, or \
capacities and inductances. Because of that, the calculation of the \
inductance of a circuit proceeds on a terrain already paved by the previous \
section.\n\tIn a system of n circuits we have the equations"
}], "Text"],

Cell[TextData[{
  "\[CurlyPhi]",
  Cell[BoxData[
      \(TraditionalForm\`\_1\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`L\_11\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`I\_1\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`L\_12\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`I\_2\)]],
  " + ... + ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(1  n\)\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`I\_n\)]],
  "\n\[CurlyPhi]",
  Cell[BoxData[
      \(TraditionalForm\`\_2\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`L\_21\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`I\_1\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`L\_22\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`I\_2\)]],
  " + ... + ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(2  n\)\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`I\_n\)]],
  "\n      \[VerticalEllipsis]\n",
  "\[CurlyPhi]",
  Cell[BoxData[
      \(TraditionalForm\`\_n\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`L\_n1\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`I\_1\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`L\_n2\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`I\_2\)]],
  " + ... + ",
  Cell[BoxData[
      \(TraditionalForm\`L\_nn\)]],
  "*",
  Cell[BoxData[
      \(TraditionalForm\`I\_n\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "where \[CurlyPhi]",
  Cell[BoxData[
      \(TraditionalForm\`\_i\)]],
  " is the magnetic flux, ",
  Cell[BoxData[
      \(TraditionalForm\`I\_i\)]],
  " the current through circuit i and the ",
  Cell[BoxData[
      \(TraditionalForm\`L\_ij\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`L\_ji\)]],
  " are called 'coefficients of mutual inductance', ",
  Cell[BoxData[
      \(TraditionalForm\`L\_ii\)]],
  " is the self-inductance of circuit i."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Determination of the Coefficients of Inductance in a System of \
Linear Circuits\
\>", "Subsubsection"],

Cell[TextData[{
  "The potential energy of system of linear circuits, carrying certain \
currents ",
  Cell[BoxData[
      \(TraditionalForm\`I\_i\)]],
  ", may then be written as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`W\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(i = 1\)\%n\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(j = 1\)\%n L\_ij\)]],
  Cell[BoxData[
      \(TraditionalForm\`I\_i\)]],
  Cell[BoxData[
      \(TraditionalForm\`I\_j\)]],
  "."
}], "NumberedEquation"],

Cell["\<\
There will be a magnetic field, whose shape is a consequence of the \
given geometry, and whose energy amounts to\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`W\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\[Integral]\_V\%\ \)\ \(\(B\)\(\ \)\)\&\
\[RightVector]\[CenterDot]H\&\[RightVector] \[DifferentialD]V\)]],
  "."
}], "NumberedEquation"],

Cell[TextData[{
  "The energy of a current carrying system of circuits is thus stored in the \
magnetic field between them. So the coefficients of inductance may be found \
through the field. We get the self-inductance per unit length ",
  Cell[BoxData[
      \(TraditionalForm\`L\_ii'\)]],
  " of the linear circuit i out of (34) and (35) after integration over the \
plane perpendicular to the conductor the field, which corresponds to the \
boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`I\_i\)]],
  " = 1 and all other ",
  Cell[BoxData[
      \(TraditionalForm\`I\_k\)]],
  " = 0 :"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`L\_ii'\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_0\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\[Integral]\_A\%\ \)\ \(\(H\)\(\ \)\)\&\
\[RightVector]\_i\[CenterDot]\(\(H\)\(\ \)\)\&\[RightVector]\_i \
\[DifferentialD]x \[DifferentialD]y\)]]
}], "NumberedEquation"],

Cell["\<\
After the self-inductance the coefficients of mutual inductance are \
obtained from\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`L\_ij'\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_0\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\[Integral]\_A\%\ \)\ \(\(H\)\(\ \)\)\&\
\[RightVector]\_ij\[CenterDot]\(\(H\)\(\ \)\)\&\[RightVector]\_ij \
\[DifferentialD]x \[DifferentialD]y\)]],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`L\_ii'\)]],
  "- ",
  Cell[BoxData[
      \(TraditionalForm\`L\_jj'\)]],
  "),"
}], "NumberedEquation"],

Cell[TextData[{
  "where the indices of ",
  Cell[BoxData[
      \(TraditionalForm\`H\&\[RightVector]\)]],
  " point to the two circuits, whose currents were fixed to 1."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The Magnetic Field ",
  Cell[BoxData[
      \(\(H\& \[RightVector] \)\)]]
}], "Subsubsection"],

Cell[TextData[{
  "The magnetic field ",
  Cell[BoxData[
      \(H\&\[RightVector]\)]],
  " can be derived from the vector potential ",
  Cell[BoxData[
      \(A\&\[RightVector]\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(H\&\[RightVector]\)]],
  " = ",
  Cell[BoxData[
      \(\[Del]\&\[RightVector]\)]],
  " \[Times] ",
  Cell[BoxData[
      \(A\&\[RightVector]\)]]
}], "NumberedEquation"],

Cell[TextData[{
  " Ampere's Law ( ",
  Cell[BoxData[
      \(\[Del]\&\[RightVector]\)]],
  " \[Times] ",
  Cell[BoxData[
      \(H\&\[RightVector]\)]],
  " = ",
  Cell[BoxData[
      \(J\&\[RightVector]\)]],
  ") leads with (38) to"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(\[Del]\&\[RightVector]\)]],
  " \[Times] ",
  Cell[BoxData[
      \(\[Del]\&\[RightVector]\)]],
  " \[Times] ",
  Cell[BoxData[
      \(A\&\[RightVector]\)]],
  " = ",
  Cell[BoxData[
      \(\[Del]\&\[RightVector]\)]],
  " ( ",
  Cell[BoxData[
      \(\[Del]\&\[RightVector]\)]],
  " \[CenterDot] ",
  Cell[BoxData[
      \(A\&\[RightVector]\)]],
  " ) - \[CapitalDelta] ",
  Cell[BoxData[
      \(A\&\[RightVector]\)]],
  " = ",
  Cell[BoxData[
      \(\(J\& \[RightVector] \)\)]],
  ","
}], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(J\&\[RightVector]\)]],
  " is the current density. In our case we may orient the coordinate systems \
z axis parallel to the current. As the vector potential is parallel to the \
current (",
  StyleBox["Ref. 7",
    FontWeight->"Bold"],
  ", p.304), it has only a z coordinate ",
  Cell[BoxData[
      \(TraditionalForm\`A\_z\)]],
  ". If  in addition the Coulomb Gauge (",
  Cell[BoxData[
      \(\[Del]\&\[RightVector]\)]],
  " \[CenterDot] ",
  Cell[BoxData[
      \(A\&\[RightVector]\)]],
  " = 0) is applied, equation (39) changes to a Poisson equation"
}], "Text"],

Cell[TextData[{
  "\[CapitalDelta] ",
  Cell[BoxData[
      \(TraditionalForm\`A\_z\)]],
  " =  - ",
  Cell[BoxData[
      \(TraditionalForm\`J\_z\)]],
  "."
}], "NumberedEquation"],

Cell[TextData[{
  "The distribution of the currents is not known, what will the boundary \
condition be like ?  This is similar to our ignorance of the charge \
distribution in the electric case above (currents = moving charges after all \
!). For a way out imagine that currents of magnitude 1 have built up a vector \
potential according to (40). We cut out all current carrying conductors \
1,...,i,...,n of the plane along their outer surfaces and nail down the \
values ",
  Cell[BoxData[
      \(TraditionalForm\`v\_i\)]],
  "of ",
  Cell[BoxData[
      \(TraditionalForm\`A\_z\)]],
  " at the cut i, as if the currents were still there. Now the potential \
satisfies in the current free space a Laplace equation"
}], "Text"],

Cell[TextData[{
  "\[CapitalDelta] ",
  Cell[BoxData[
      \(TraditionalForm\`A\_z\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`0\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "plus certain boundary conditions. At each line of cut the value of ",
  Cell[BoxData[
      \(TraditionalForm\`A\_z\)]],
  " will be constant and can be found by trial and error from the requirement \
"
}], "Text"],

Cell[TextData[{
  "I = \[ContourIntegral]  ",
  Cell[BoxData[
      \(TraditionalForm\`H\&\[RightVector]\)]],
  "\[CenterDot] ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]l\&\[RightVector]\)]],
  " = \[ContourIntegral]  (",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\&\[RightVector]\ \(\(\[Times]\)\(A\&\
\[RightVector]\)\)\)]],
  ") \[CenterDot] ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]l\&\[RightVector]\)]],
  " = \[PlusMinus]1 or 0,"
}], "NumberedEquation"],

Cell[TextData[{
  "if the integration path ",
  StyleBox["l",
    FontSlant->"Italic"],
  " is around the surface cut. The task has now become the same as before, \
namely numerically solving the Laplace equation with (iteratively determined) \
boundary conditions."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Code  (Coaxial Cable)"
}], "Subsection"],

Cell["RAM requirements: Front End 15 MB, Kernel 25 MB", "Text"],

Cell[CellGroupData[{

Cell["set up matrix:", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
This code is very similar to the code example of the previous \
section...\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
nz=130; (* divisible by 2 *)
ns=130; (* divisible by 2 *)
u=.;m=.;
m=Array[u,{nz,ns}];a=Array[u,{nz,ns}];mb=Table[0,{nz},{ns}];
Do[Do[a[[i,j]]=u[[i,j]],{j,1,ns}],{i,1,nz}]
Do[Do[m[[i,j]]:=Evaluate[0.25(a[[i-1,j]]+a[[i+1,j]]+a[[i,j-1]]+a[[i,j+1]])],{\
j,2,ns-1}],{i,2,nz-1}]\
\>", "Input",
  CellLabel->"In[25]:=",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}},
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(Part::"partd" \(\(:\)\(\ \)\) 
      "Part specification \!\(u \[LeftDoubleBracket] \(\(1, 3\)\) \
\[RightDoubleBracket]\) is longer than depth of object."\)], "Message",
  CellLabel->"From In[25]:="],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Part :: \"partd\"\) will be suppressed during \
this calculation."\)], "Message",
  CellLabel->"From In[25]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["boundary conditions:", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[{
    \(Do[m[\([1, j]\)] := 0. , {j, 1, ns}]\), "\[IndentingNewLine]", 
    \(Do[m[\([nz, j]\)] := 0. , {j, 1, ns}]\), "\[IndentingNewLine]", 
    \(Do[m[\([i, 1]\)] := 0. , {i, 1, nz}]\), "\[IndentingNewLine]", 
    \(Do[m[\([i, ns]\)] := 0. , {i, 1, nz}]\)}], "Input",
  CellLabel->"In[31]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  "The value of the vector potential ",
  Cell[BoxData[
      \(TraditionalForm\`A\_z\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`r\_0\)]],
  " -> v1 has to be adjusted according to (42). The vector potential is in \
this case independent of \[CurlyPhi], but changes radially even across the \
metal. A complete expression is given at the end of this section. Usually one \
starts with a guess, here we may use the known value (see (43)) for the coax \
cable (cross section Fig.5) :"
}], "Text",
  PageBreakAbove->True],

Cell[GraphicsData["PICT", "\<\
M_0000000<X0bP0A0_l<0?on0001;0000B`000000003B`=;0000002Q09H02P40
000000000000X02H0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G
0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40000000000000X02H
0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G0:40UP0:0@000000
0000002P09P0X02I0:00U`0N00402P000003B`=;02`02@031TMUKVEfH@000`03
00d0300^00@00?l002/10@4P02T00B0000L0000002<0002P0;h0X@3000eSMG9b
IFidL6mYKW@=002P0;l08P3:0<X0002P0;h0X@300<eSMG9bIFidL6mYKW@P<R1Y
KVAUN21cMF8PIGQSJ20c86U^I6Eh87=eHPdP<S0b821TJGHPIGQSJ20=838`<R0P
I6Uf83<PJFiTIGPP3B0`821cMF8P<b1YKVAUN20=830P87=eHR0d838PLVm/K20e
86U^I6Eh83DPJFiTIGPPM79QKW=/HGAU3FiUIb1cHf5/I@dd838PLVm/K21^IFLP
IGQSJ21^IFLPIGQSJ21dLV5^LfaQM6DP3B0b<38P87=eHR1dLV5^LfaQM6D=002Q
0<01ARDQD5<]@FA_HVD]<bh`84E@DdH]<bh`3BDU@VmeKVAYKVM2KgPj820`830P
<S0b838`<R0=9BEDJGA/ICXP:4=_HGP^@diF:B0=9BE3LVEQM6mb>R13HFifHG<P
:3L^<2hb:B0=9BE3LVEQM6U_KTAQM6Dj82P`<Rlb=2l`<B10834a>S@f851=:B0=
9BE4Kf=eKFE^M51bKf=CIGAc>R14IFiUHV5O@f5^MV5c@gEcM6m]@fm/Kg9c3BDU
:b13ETAYHg@=9BE4Kf=eKFE^M4I_KWAc>R0=9BE4Kf=eKFE^M4iUIFAUI4I_KWAc
>R17IFiUMV4=3BDUA6mSMFeUKWA@LVmSIG=c@fm/Kg9c>R13NF5^84eQIfE^M64P
FFE/K6mg849/HF=[3BDUAFiT@fm]KFE^M7<=9BE2IFMYKU1bKfa_Ib0=0:40`400
9BE2IFMYKU9ULfmeLV=U>R1`LVmSLfEd84=FA6USM0dU9EAYM6aU>R14IFiUHV4P
LgAQKVAQLV@PIg9QL6QYHg<=9BEFIG9cJFm^>R0a;S0b3BDU@g9UHGAYKfi4HGAU
>R0a<2la=2li>@dU9D=_L7UbJFMXM3XP:4<Y834i>C@/834i>CTPA6E^IF9Q85=i
LgAUKG<^845/K21BJFMXM7<PDVEcIG9fIF@=MG=ULVAYHg@P;d=FA6USM20b<30P
I6USM21`MG@=@eI4JF=d869UIfU^3BmYKWIQK6UTHfm/Kg9dHF9/IClPM79eIB1T
IFHP820=;faUMVE/<R0_K65^IgEQIfE/IGIUK21gJ6EbIB1kL6m`86aQKVMeHFMU
K6EfIF`P<R1WIGekIV5/LfEm86UVIFacIB1TIFH=K6EfIF`b86i_M21k82mhLfQ_
Mb1k3C0PHgEbLVE^M71_JFid83DP;C4PLVm/K21kL6m`871_L21]KgIUM6lPI7E`
834PHFAT83<P<B1bKfa/86EhHfPPI7E`83@P<B1bKfa/86EhHfPPIfEd830PLVe_
MVEdKb1SMG9bIFidL6mYKWAm86EhHfPPJg=XKgL=L6m`871_L21`Kg0PL6m`OB1T
IFHPOB1YIPd_JFiYM6UQK6UjI@ek@eI4JF=d3G]TMG0PN6=XIF=[Nf9YKVAmJFHP
L6m`871_L7eVKg9QK6`=HgEbLVE^M7=SLVEUKR0_Gg=`86EhHfPPI6EV82mOLf4P
IGQSJ21TIFHP;emcIR1UN6=X86AUIPd_A6EVHGE/M5=SLVEUKW]OLfHPGg=Q82mO
Lg0PK6mQI7eTIFH=;dAUIV5eK7ACHg9UIFi@LVmSNb0_Gg=`86a_HFAmI6EV3Bmc
IGAcM79_JfEQI6YeLg@PMfQULVEkL6m`87AbMFEmNfIQK7=UOFUVIFacI@ek;g=Q
82mcIGAcM79_JfEQI6YeLg@PK6mQI21TIFH=;faY82m/JFiUM6lPK6mQI21TIFH=
;fed82m]KgIUM6lPK6mQI21TIFH=;f=d82mSMG9fIGA_86a_HF@PI6EV3Bm/J21k
86=eLW9UKWA`KfU^M21UN6=X871_L21/JFiUM6mmHVU^I21TIFH=;faf87/PHgEb
LVE^M71_JFid871_L21UN6=X86aYKVEdKgeRJFiT86AUIWd=NbmcHG]kHgEbLVE^
M6AYHg@PDgAbKf]U@FAZMG=dA6USM21^IG]CM79_JfE1I6YeLgA4JF=d869UIfU^
OFUVOG/PHgEbLVE^M6AYHg@PDgAbKf]U@FAZMG=dA6USM21ULG]UKVAmJFImJFIU
K7=UOB1RJFiT86AUIPeeLfEbI6USM20_DgAbKf]U@FAZMG=dA6USM20a<30PI6US
M21`MG@=DgAbKf]U@FAZMG=dA6USM21RIFMYKPd_GgQ/3G]dLV5^LfI_LVd=;S8e
87=eHR1bKgE^I20^<SDPHFAT86EhHfP=;S8e87=eHR1bKgE^I20^<SDPHFAT86Eh
HfP=JGAbHFicIVmbK@emHVU^I21TIFH=;faYNb1ON6`PK6U^IGA_OF9YKV@PI6EV
3Bm]M7/PGgQ/86e_MVEdKgeRJFiT86AUIPd_HgAk85mhK21SMG9fIGA_OF9YKV@P
I6EV3Bm/J21k86AeL21ON6`PL6m`86=eLW9UKWA`KfU^M21UN6=X871_L21/JFiU
M6mmHVU^I21TIFH=;faf87/PI7E`85mhK21`Kg0PHgEbLVE^M71_JFid871_L21U
N6=X86aYKVEdKgeRJFiT86AUIPd_LW1kGgQ/;f=fGf8PN6AV;f=fGg8PN6AV3Emh
K2mSMUmd87QTIRmSMUm/87QTIPeSMUm/86=fGg@PKFmfIGA_3F=fGg8PHgIOM21/
JFiUM6l=HgIOLR1SMUmR86aYKVEdK`eSMUm/86=fGf8PK6U^IGA_3F=/Kg=UL65d
J0emHVU^I21TIFH=IFiTOFUVIFacIGeTIFH=;gAULVeYKV5dI@ekMG=ULVAYHg@P
;e=dLVm[ID5TJWEcM4AYHg@PJfi_MfhPNf=eLW9UKWATJF=d85=dLVm[ID5TJWEc
M4AYHg@PIG5kIFiTOFUVOFUV3F=eLW9UKWATJF=d84=FA6USM21ULG]UKVAmJFIm
I6EV3Bm]N4eQN20f=21TIFH=;fehDgA[85]]N4eQN21kKF5dLVUhOB1bIG1UHGAM
I6EV3Bm]N4UTN20`86AUIPd_LgA]NfehDgA[86ehBFAh830PK7@PNbm]N4UTN20`
87=dKg9UOFUV86ehBFAh86MUM21SMG9bIFidKF5dLVUh871_L20_KGQ9I7PPKGQ9
I7PP<B1QI6@PLgA_LVEmI6EV3BmbM6ekKGQ9I7PP<B1WIB1k;fehBFAh86ehBFAh
834PLgER87=dKg9U86ehDgA[86ehBFAh86MUM21cIGA]HGAbJGQmJFHPOFAUIPd_
Lf=/87/P=c8PI6Uf86EhHfPP=c8PI6Uf86EhHfPPLf=QK6DPOB1TIFH=;g=SK6TP
Nb0g<R1UN6=X86AYMR1UN6=X83Lb86EhHfPPI6Uf86EhHfPPLf=QK6DPOB1TIFH=
;emSMVedN21]HGAbJGPPI6EV3BmOM7QdKGAh86eQM79YN21TIFH=;emYKVUdKGAh
86eQM79YN21TIFH=;gQTIW]UN6=X86AUIWeTIFH=;feYKW/b86=_L7TPIgAkIGQS
J7eYIR1`Kg1mI6EV3Bm]HGQk<R1SKg1i86adNfEhHfQmJFHPL6m`OFAUIPd_@eIf
IF<P<SDf865bLV5i86AUIPd_E21dLWEU86AUIPd_AR1VHFacIB1TIFH=;emYI20`
86AUIPd_GfE^HfmTJFiTIGPP<21TIFH=;emUKV=_I45bLR0c865bLV5i86AUIPd_
GfIT830PI6EV3BmOM6EhM5=QMVDPKWE/K21TIFH=;em/IGAdIG9CL65SIB0`86AU
IPd_Gg=`HF=UF7AbHB0`86AUIPd_Ge1QIfECHGIU86ieK6`PI6EV3BmOL6E^J20a
;S0PI6EV3BmOL6E^MR0a;S0PI6EV3BmcHGIU<21^MFa/86AUIPd_GgLP<21TIFH=
;emX830PI6EV3BmOI7<P<21TIFH=;fQSM21VHFacIB1TIFH=;g1g830PI6EV3Bmg
I6UV830PI6EV3BmdIFe`830PI6EV3BmSMG9bKg@P<21TIFH=;g=QMVEXHFiTK6Eb
86ieK6`PI6EV3BmYHB0`86AUIPd_JGPP<21TIFH=;fUhKR0a86AUIPd_CGE/M6U`
K6E4HGAQDfmeLV=ULb1VHFacIB1TIFHP3BmTIF9eI`ekI7E`82lTIG1c86EhHfPP
KVmd86AUIW/_Lf5fIFQQKVA/IG8PIG9bKg9TJF=d82mXHFiTK6EULW9_LR1WIG@P
I6EV3FEbLVmbI6USM0d_J65^I6aUIG9bKg9k96EbLVmb869UIfU^3FiUMfEbLVmb
Nbm^IGMULW9_LR1VHFacIB1TIFH=LfQ_Mg1QIfD==c8P=c8PLf=QK6D=;dQUK7IU
M6USHB1VJFiTIVm^M20^<R1cHf5/IFI_KW@PLfEdIVm^M0d^<SDP>Bhf86e_MVEd
K`dXAG9bKg8j82UcJ6mg3FEbLVmbKV5]I@ekI7E`87AiL6D_LgAbJFiWM7U`IB1^
I@ek:6=_KWIULWAUI21ULW9_LR1^HFeU87MYK6`PIFiT87E`86U^87AXJG<PLgAb
JFiW:F=fLgeYIPecJ6mgOFEhIF<=;S8e83T^=21]KgIUM6l=:4mVIVE^I6U^Ib13
Kfe]HFiT>R0YLfQ_M`d_Hfm]KF5^I21/Kf5T3G]TMG0PM7U`IBmcM79YKVMdNG1U
86iU3G/XHfm^MVEbM6ET86=_KFeQKV@PKV5]IB1gJFa/86E^I21eL21YKR1dJ6Uc
87=dLVU^IbUSMW=mJFH=LfQ_MgeUN6ES3Bhb=B0i;S8PKFmfIGA_3BQCM65SJcXP
:G=XKgL=Kg=dHF=[3G/^<SDPHgEbLVE^M71_JFid82hb87=eHR1UN6=X871_L21]
KgIUM6l=I7E`87AiL6D_LgAbJFiWM7U`IB1^IG]TMG0PM7U`IBmYKWAUIfEbM7U`
IB1UL@da86U^I6Eh87AiL6D_LVEQK7AiL6DPIG4PKg8=<B1YKVAUN21dNG1U;fiQ
KFEdNG1U86Ea86mb3Fi_M21kM7U`IGeYIPdXHfm^MVEbM6ET87=dHF=[87MYK6`P
IFiT87E`86U^87AXJG<PLgAbJFiW:F=fLgeYIPecJ6mgOFI_LV5/K0ecJ6mgL65W
I@e3ETAYHg@P;g=QMVEXHFiTK6Eb86MUM21UN6ESOFUV3FE^I7e`MGAmJFImI6EV
3Bm/Hg]cIGA/JFiUHf5`OFAUIPd_K6YkLfEdK6U^IFY_JFimI6EV3Bm/KG]cIGA]
JGAULVaYKFUdOFAUIPd_K6IkLfEdIVaQM7eTIFH=;f=`Nf=/Kg=UL65dJ7eTIFH=
;fi`NfiUMg1QM6QmI6EV3BlTL7=j83<`865bLV5i86AUIPd_971YN20`86AUIPd_
Ig=kIg=QMVDP971cNR1TMG0P971YN21OL6E^J21`MG@P971YN20a865TI21OL6E^
MR1`MG@P;bA`JGPP971YN20b865TI21TIFImI6EV3BmWLW]WLVEcM6mbIBlTL6Uh
82A`JGPP<R1cMF8PI6EV82A`LgXPI7E`82A`JGPPIfEd82mOL6E^J21UN6=X86AU
IR0TL6Uh834PHFAT86MUM20_Gg1UKWHPIGQSJ21TIFImI6EV3Bm/JG]/JFiUM6mm
86AUIPd_K6QkHgEbLVE^M71_JFid86EhHfPPL6m`86aYKVEdKgeTIFH=;fafNf=e
LW9UKWA`KfU^M21`Kg0PIGQSJ21/JFiUM6mmI6EV3Bm]M7]]KgIUM6mm86AUIPd_
Gf=fGfeXNf=eLW9UKWA`KfU^M21UN6=X871_L21]KgIUM6mmI6EV3BmOHgIOKGIk
HgEbLVE^M71_JFid871_L21UN6=X86e_MVEdKgeTIFH=;f=dNf=eLWIUM6mm86AU
IPd_LWAk=20]<R1bKfa/86e_MVEdK`eTMG0P<21UN6=X879/JFiUM6l=IGQSJ20`
879/JFiUM6l=KVEW830PIGQSJ21bK6U^IGA_3F=/Kg=UL65dJ7eTIFH=;emXLPek
3G/_@6EbLR1VHFacIB1TIFHPHgEbLVE^M6I/HG@PI7E`NfMcHGIUNfE_HfaYL7ec
M6m`L6ETNfMbIG=dKg9U838PKGE/86AeL21cIGAVK65d86AeL20b<30PIfEk:2DU
84=QKWIQLcY3K6U`86IQJFaUI5ab:G1bJFid82m0IG9b87AbMFDPI6EV871_L21U
N6UdOFUVOG]WLVEcM6mbIB1cIGAVK65d86EhJGAmJFIUK7=UOFa_Kg0P@6EbLR1^
Kg@PNfE_HfaYL7eYIR1cIGAVK65dO@ek;d1ULW8PIV5/LfDPI6EV86=eLW9UKWAV
K65d86AeL7]WLf5fIG]SK6U`OG=dKg1`IFAkIg9ULgA_LVDP<R1]MF`PI7E`87=U
M6I/HG@PI7E`838`<21WIG/X9BDP@f5^MV5c>T=/JG0PIV5YK6ETG78YL79YKW@P
;d1ULW8PM79eIB1TIFHPL6m`86EhJGAmJFImNfMbIG=dKg9U87=UM6I/HG@PIGQY
M7eYIVE/LfEmK6m_L210IG9b86i_M21kHfaYL7eYIR1cIGAVK65dO@emI6EV3BmO
Hg<PKWE/K21TIFH=;fIWNg=UM6MbHGUmI6EV3BmcIGASKGU[Hfm/Kg8PMfQULVDP
Ng1_L21dLWEUOG]VHFacIGeYIVE/LfD=NbmV=7/PLfEdHfeiJf=_K6mbOFAUIWek
;fHdNc4PLgER83@P<B1bKfa/83=k<b1YKVAUN21QI6@PKVEW86AeL20`86adNg1_
L20`OFUV83<P<B1bKfa/OG9UL6EQM21cIGAbIf9SKfa_LR1`Kg1mI6EVOFUVIFac
I@d_LfEdHfm/Kg9cL65SIB1gJ6EbIB1kL6m`87AbMFEmNfIQK7=UOFUVIFacI@ek
;g=SLg/PI7E`87=UM6=_K6mbLg1QHfDP;emSLb1UN6=X86AUIWeTIFH_IS=k85mS
Lb1cIGASKfa_LW=`HF=U87=UM6=_K6mbOFAUIPemNbmV<g/PLfEdLVMRHfm/Kg9m
I6EV;g=SLg/PL6m`OFAUIWeYIVE/LfD=;bASHb0e865bLV5i86AUIPd_IVU^I6=]
NF]SMG=dKfeSKfa_LR1gJ6EbIB1kL6m`87AbMFEmNfIQK7=UOFUVIFacI@e^Kg@P
NbmVJFiTHfeiJf=eLgA_KF=_K6mbNbASHb1QLgA_LVEmI6EVOFUV3BmcIGASMG=d
KfeSKfa_LR1gJ6EbIB1kL6m`87AbMFEmNfIQK7=UOFUVIFacI@e^KgAk;g=UM6=e
LgA_KF=_K6mbNfEhHfPPHFa_HF@PL6m`871_L20dNc@PJFiTIGPPKGE/83@P<B1b
Kfa/OG9UL6EQM21cIGASKGU[Hfm/Kg8PL6m`OFAUIWeYIPd_IV=k=R0a879_K6`P
IVU^I6=]NF]SMG=dKfeSKfa_LR1UN6=X87=UM6=eLgA_KF=_K6mbOFAUIPd_LfEd
LfE`HG9QM6U_KVMbHGTPMfQULVDPNg1_L21dLWEUOG]VHFacIGeYIVE/LfD=KVmd
NbmcIGAcIG1QLV5dJFm^Ig9QNB1kLgUcM6E]I6USM20_LfEdIg9QNB1WIG@PIGQU
HgdPI6EVOFUV3BmcIg/PLfEdLfE`HG9QM6U_KVMbHGUmI6EV3BmcL7/_Gg1UKWHP
N6AV;em`IFiX87QTIWeTIFH=;g9`3G/_HgIOHR1hI6H_HgIOLR1hI6H=;f=fGg@P
N6AV;f=fGf`PN6AV3F=fGf`PHgIOM21]KgIUM6l=HgIOLR1SMUmd86aYKVEdK`eS
MUmb86=fGf8PK6U^IGA_3F=fGf`PHgIOHR1/JFiUM6l=Hfa_LfE`HGAXOFAUIPd_
LW9k;gUbHFAYMG<PN6AV3BmhLV5TJGEc87QTIPd_HgIOHR1hI6H=;f=fGg8PN6AV
3BmSMUmd87QTIPd_HgIOK21hI6H=HgIOK21hLV5TJGEc865TI21SMUmd86e_MVEd
K`eSMUmb87QbHFAYMG<PLgER86=fGg@PK6U^IGA_3EmSMVedN21SMG9bIFidKF5d
LVUh871_L0eSMG9bIFidL6mYKW@PM79QKW=/HGAU3GQbHFAYMG<PNG9QI6UeLb1c
Hf5/I@da830P<B0a834PHG9SM6lP=7]`Kg1mLVE`IF5d3EmSMVedN21cIGA]HGAb
JGP=HgIOLR1SMUmR87UbHFAYMG<PLgER86aYKVEdK`eOHgI]M7PPHgEbLVE^M6eQ
M79YN21`Kg0=HgEbLVE^M71_JFid87AbHFicK65dI@ehLV5TJGEc87UbHFAYMG<P
Lf=QK6D=<20a82da834P<B1QLV=dKb0dNg1_L7ebIG1UHG@=Gf=fKGAh87=UM6eQ
M79YN0eSMUm/87QbHFAYMG<PHFAT86=fGf8PK6U^IGA_3EmSMVedN21SMG9bIFid
KF5dLVUh871_L0eSMG9bIFidL6mYKW@PM79QKW=/HGAU3GQbHFAYMG<PNG9QI6Ue
Lb1cHf5/I@d]<B0`82da82da834PHG9SM6lP=7]`Kg1mLVE`IF5d3EmSMVedN21c
IGA]HGAbJGP=HgIOK21SMUmd87UbHFAYMG<PHFAT86aYKVEdK`eOHgI]M7PPHgEb
LVE^M6eQM79YN21`Kg0=HgEbLVE^M71_JFid87AbHFicK65dI@ehLV5TJGEc87Ub
HFAYMG<PLf=QK6D=<20]<B0a82da834PHG9SM6lP=7]`Kg1mLVE`IF5d3EmSMVed
N21cIGA]HGAbJGP=Hfa_LfE`HGAXOFAUIPd_IG1kGf=fKGAh86=eLW9UKWA]HGAb
JGPPL6m`3GAbHFicK65dI@ecHf5/I@da830PKFmfIGA_3C0P<20a830P<cH`865b
H`eSK6mcIG1QM6P=Gf=fKGAh87=UM6eQM79YN7eTIFH=;gMTNemSMVedN21SMG9b
IFidKF5dLVUh871_L0edLV5^LfaQM6D=Lf=QK6D=<20`86e_MVEdK`d`830P<B0e
82db879_K6`PHG9SKPeSK6mcIG1QM6P=Gf=fKGAh87=UM6eQM79YN7eTIFH=;f5c
NemSMVedN21SMG9bIFidKF5dLVUh871_L0edLV5^LfaQM6D=Lf=QK6D=<20`834P
=B0]<R1bKfa/865bHfh=Gf=fKGAh87=UM6eQM79YN7eTIFH=;fAc3G]OL6E^MR1O
L6E^J21^IB1TMG1kLgA]85m`IFiX86AeL20`86aUNg1_L20aOFUV85m`IFif86Ae
L20`86aUNg1_L20aOFUV87=SHFaUOG]OL6E^J21cIGA/JFiUMfUTM6QmJFIUK7=U
87=dLVm[IB1kLWA]OFUVOFAUIPd_I6IkIVU/K7eTIFH=;fAUNfE_IVU/K7eTIFH=
;emWLgA[83DPHG9bHGTPI6EV3BmOIg=dJf<P<21TIFH=;emWLgAk83TPI6USM21R
IFMYKR1/IGIUK39k;emSHg<PHgEbLVE^M6=_K6mbLg1QHfDPI6EV82mOHf<PFf=e
LW9UKWASKfa_LUdPI6EVOG/_Gf=S85]SMG9bIFidLVMRHfm/Kg9MI6EVOFUVIFac
IB1kHgEbLVE^M71_JFidOG=dKg1`IF@PNbmOHg0PKWE/K21TIFImNb0b865bLV5i
865cM6mbIB0_Gf=`86EhHfPPI6EVOFUVIFacIB0_Gf=V86=eLW9UKWAVKfid86AU
IPd_Gf=/Mb1SMG9bIFidK6U^IGMYI7AX86AUIR0_Gf=/Hb1SMG9bIFidK6U^IF=Q
L21TIFHP;emSK6XPHgEbLVE^M6aYKVEZKfU^86AUIR0_Gf=]K21SMG9bIFidKFUd
IG9/JFeYM21TIFHPHgEbLVE^M6AYHg@PIFiTOFAUIPd_J7=kKVEgL65dJ21WLf5f
IB1cM6emI6EV3BmXHg/_GfQb86a_HF@PIGQSJ21WIG@PIGQUHb1^IGM`HGAXOFAU
IPd_J6EkGfMcM6/PGfMcM6]S85mWLg@PL7Ed82mOIg=dJf<PGfMcM6]S834PHFAT
87=dKg9U80eWLVEcM6mbIB1bM6dP;emWLgA[Hb1OIg=dJf<P<B1cMF8PLgA_LVDP
GfMcM6/PGfMcM6]S86MUM21/IGIUK39kI7E`82mOHf=c86MUM21cIGASKfa_LW=`
HF=U86AeL20_Gf=S86MUM21QK6mQI21`Kg0PLfEdHfm/Kg9mNfAeL20_Gf=S86MU
M21QK6mQI21`Kg0PLfEdLVMRHfm/Kg9mJFIUK7=U86AeL20_Gf=`86MUM21TMG0P
KWE/K21ULB0=KVmdNf5/Kf5T871_L21]KgIUM6mmNg1_L7eYIVE/LfDPI7E`82mO
HfHPIfEd87=UM6I_KW@=I7E`;emSK7LPIfEd87=UM6aYKVEgJFAdJ21TMG0_Gf=/
Hb1WIG@PLfEdK6U^IF=QL21TMG0_Gf=/JR1WIG@PLfEdK6U^IFY_JFhPI7E`;emS
KF`PIfEd87=UM6eYM6EbK6U]JG@PL6m`OFAUIPd_JFAk82mOJF@PN6AVOFAUIPd_
GfU]HGAbJGQkGgLP<20`85mX85mYI20`86iUNfiUIb0`85mXOG/`831mJFIUK7=U
85mSMVedN21QLgA_LVEmI6EV3BDP@fm`NG9YIfQd82Q3:B0a>CT`;20a>CTa869i
845TKf9U85=iLgAUKG<PBFiSKg9`Kg9QM6ET;PdU845/K21bJFMXM7<PLVEcIG9f
IF@^3FaUMVE/<R1k87=QMVDP;fA_KWA/Kf5TK6EfIF`a87QTIR1mJFH=;g=dHG9d
KVm/Kf5TNg/_KVm/Kf5T87=QMVDPI6EVOB1YIWeTIFH=;fE^I6i_K6mQI7]kKVm/
Kf5T879ULgA_LVEmJFHPOFAUIPd_M6EcM7=iLgAUKFAYHgAkMfQULVEkLgUcM6E]
I6USM21ULG]dLWEUOG]VHFacIGeYIVE/LfEmNfIQK7=UOFUVIFacIGeTIFH=;fiS
Kfa_LW<P<B1TIFH=;f=_K6mbJFeQIfDPMfQULVEkL6m`87AbMFEmNfIQK7=UOFUV
IFacIG/_KV=_K6mbLb0`3G=dHGAeLfAYHg@PHVEWJFhP3Bm`LVmSIG=cHfm/Kg9c
87MXIG9UNg1_L21`Kg0PL79_HfEcLf=_K6mbLgek;fAUMVUSIFU^IVlPMfQULVEk
L6m`86AUMVUSIFU^IVlP;d=_K6mbLb1[KVmgKPekL6m`87]TIGIYHfEYKVI_82m3
Kfa_LW<PIfEdOGeYIWeYIWeYIVE/LfDPIFiT86AUIPe^Hfm/Kg9c830PKVEk;f=_
K6mbJFeQIfDPM6EcM7=iLgAUKFAYHg@=;g=UM6=_K6mbM79QKW=VIG8PM6EcM7=i
LgAUKFAYHg@=;f=eLW9UKWASKfa_LWAbHFicIVEb87AULgAcNG=dIFeTJF=d3BmS
MG9bIFidHfeiJf=_K6mb87AULgAcNG=dIFeTJF=d3F5^I21QKV@PHFiT86i_M7/_
KV=_K6mbLb0`86AUIWeYIWeYIWeYIPe^Hfm/Kg9c86AeL20a86iU86EhHfPPI7E`
83<PKVDPIGQSJ20d86iU865^I21QKV@PNbm^Hfm/Kg9c830PI6EVOFUV3FiSKfa_
LW<P<B1ULB1TMG0PI7E`86i_M21cM65bM6i_K6mQI0ek;fA_HfaeM6U]HFMUNe]k
<SDe86eeK21bKgE^I21SMVTPHWMSK7Ed86EhHfPPIfEd838e=B1TJGIm82mUN6ES
86a_HF@PI7E`86=eLW9UKWAdLV5^LfIULR1UN6=XGB0=HgIh869YKV@PLfEdM79Q
KW=VIG8PGgLPGfPP>21OJFeQM79YN21OI7<PJFeQIfEmI6EVOFUV3Fi_M21UKVA^
Kfa_HF@=KV=_K6mbLb1TMG0P<b1ULB1UN6=X83@PIG4PKg8=I7E`86AeL21^Kg@P
LgAQLWA^Kfa_HF@=Nbm^MFa/L79_Hg]kOGeTIFH_Hfm^Hf5dMGAYK7/_IGQUHb1/
Kf5T3CLP;C4PLVm/K20_IGQUHb1/Kf5TOFAUIPd_I6EVLgERHfaeM0ek<B1QI6@P
IfEdJFidIG9fHF`PI6EVOFAUIPd_Lg1SKfiSHGAdLV5^LfIULR0P80ek;dASK7Ed
86EhHfPPI6EV;d=SK7Ed86EhHfPPI6EV;d9SK7Ed86EhHfPPI6EV;d5SK7Ed86Eh
HfPPI6EV;fiSKfe`MGAU86EhHfPPK6@=HgEbLVE^M6=_K6mbM79QKW=VIG8=Fg]1
HfaeM21^Hfm]L7EdIGeSKfiSHGAeM6U/GB1SMWP=Fg]2HfaeM21^Hfm]L7EdIGeS
KfiSHGAeM6U/GB1SMWP=Fg]3HfaeM21^Hfm]L7EdIGeSKfiSHGAeM6U/GB1SMWP=
Fg]4HfaeM21^Hfm]L7EdIGeSKfiSHGAeM6U/GB1SMWP=LfEdHfm/Kg9dLV5^LfIU
LWeTIFH=;g=UM7E`LVMRHfaeM7<=NbmRJG@cN21bIf9SK7Ed86aUKVMdJ20c87=e
HR1TIFH=;f9YM35h869YM3=h83<PJFAYMR1TIFH_LV=/MG@PLVMRHfaeM21TIFH=
;fMSK7Ed879SK7Ed834PHVUd<gPPI6EVLgERHfaeM2mRHfaeM21bHfaeM20b869Y
M3=h86AUIW=eHV=/MGAmI6EVOFUV86i_M20P3FE^I6i_K6mQI21^Hfm/Kg9c83<P
IG4PI7E`86AeL21^Kg@PLgAQLWA^Kfa_HF@=NblcHfm]L7EdIG]UN6=X869YM3=h
86eeK0ebKgE^I21SMVTPIfEd838e=B1TJGImI6EV3BmTKf=/MGAYKF5WIG/U;g9W
HV=/MG@PN6AV871_L20=LfEdMG1bIf9SK7EdLblcHfm]L7EdIB1bHfaeM21WHfae
M21RHfaeM21TMG0=Lg1SKfiSHGAdLV5^LfIULR1OMb1OJ20h85mYKF5dLVUh3E/_
GfAc86a_HF@P;fEhIF<PK6mQI20_I7E`86a_HF@PI7E`GF=fN0e^MFa/L79_Hb1^
MFa/L79_Hb1dLWEU83<PHfm/Kg9YKF5WIGeTIFImJFHPKVmd86E^I6i_K6mQI21^
Hfm/Kg9c83@PIG4PI7E`86AeL21^Kg@PLgAQLWA^Kfa_HF@=NbmcM7EVIV=/MGAk
HfeiJfU^I6Eh83<P;C4PLVm/K21`MGAmI6EV3BmVM6mYKWAk<B1UN6=X87=eHR0b
=CDPKGE/879_MFiT86=fJGeTIFH=;cASKfe`MGAU87/PIGQSJ21RJG@dN21]MF`P
LVmeKV@PHgIY86MUM20b=CDPI6Uf87dPI6EV3BmSKfe`MGAUHfeiJf=/MGAkLfEd
MG1bIf9SK7EdLbmRJG@dN21bIf9SK7Ed86aUKVMdJ20c86UTJGHP=21]MF`P=21c
MF8PI6EV3BmSKGU[HfaeM21RJG@dN20d865TI21cM79YKVLPI6EV3BmSHfaeM21S
KGU[HfaeM21TIFH=;feSK7Ed86=SK7Ed834PHVUd=7PPI6EVLgERHfaeM0d_NF=/
MG@PHf=/MG@P<R1RJG@dN21TIFIcMF9SK7Ed3Bm[HfaeM21SHfaeM20c869YM3Ah
86AUIW=eHV=/MG@=;f=]NF]YKVAUN20`86AUIPd`834PHVUd<GP=NfAeL20_Hfei
JfU^I6Eh86EhHfPPHVUd<GPPIGQSJ21cMF8P=21]MF`PI6EV3C<PKGE/86AeL21b
HfaeM21UN6=X86MUM20b=CDPI6Uf86EhHfPPI7E`86MSK7Ed86EhHfPPIfEd838e
=B1TJGH=IGQSJ21RHfaeM21UN6=X86MUM20b=CDPI6Uf3G=UM79WHV=_K6mb86=e
LW9UKWASKGU[Hfm/Kg8=IWA_JFid86]SK7Ed87=dMFIVHfaeM0eVM6mYKW@PNF=/
MG@PLgAeIVISK7Ed3FIdKfU^M21]HfaeM21cM7EVIV=/MG@=IWA_JFid86=SK7Ed
87=dMFIVHfaeM0emIVmbOFAUIPd_I6mSK7EdJFeQIfEkJFifHFaYI6=_K6mbM65R
K6DoNf=_KG1eM6ESKGU[HfaeM7eYIPd_=6=_KG1eM6DPHf=/MG@PKF=/MG@PNF=/
MG@PJf=/MG@PLg1SKfiSHGAdLV5^LfIULPeOMb1OJ20h85mYKF5dLVUhFbmOI7<P
K6mQI20_IGQUHb1/Kf5T;fAeL21/Kf5T86AeL21TMG1M86=fN20=KWE/K71bKf<P
KWE/K71bKf<PKWE/K71bKf<PM79eIB0d86=_K6mbJFeQIfEmI6EVOFUV3Fi_M21U
KVA^Kfa_HF@=KV=_K6mbLb0`86Ea3FAeL21TMG0PKVmd87=dHG9dKVm/Kf5T3G/_
Hfm/Kg9UN71QKVAkKGUcM79YKVMUN70P<21bIf9SK7Ed3C<PHfm`N@dg82da879_
K6`=Nc<PKGE/83<PIfEdJFidIG9fHF`PL7EdJFidIG9fHF`PIGQSJ20c865TI21U
N6=X83<PHfm`NGeVKg9QK6`=L6m`871_L21`Kg0PL6m`871_L7eTIFH=;f=bIF5d
IFEhL65^I7=dLW/_KGUcM79YKVMUN70PIGQSJ21cM30PK6E^IgAX86eeK21cM79Y
KVLPI6EVOFAUIPd_I6mSK7EdJFeQIfEk;g9WHV=/MG@PN6AV871_L20c86=bIF5d
IFEhL65^I7=dLR1OMb1OJ20h85mYKF5dLVUh3E/_GfAc86a_HF@P;fEhIF<PK6mQ
I20_Hfm/Kg9UN71QKV@PK6mQI20_IGQUHb1/Kf5TGB1SMWP=IV5/LfDP<b1SKfa_
LVU]HFMUOFAUIWeYIR1^Kg@PIFiTKVm/Kf5T3FaUMVE/<R1k86A_KWA/Kf5TK6Ef
IF`a879ULgA_LVDPOFUV3FaUMVE/<R1^KgAk87=QMVDP;fA_KWA/Kf5TK6EfIF`b
87QTIR1mJFH=;g9WHV=/MG@P<21TIFH=;fA_HfaeM6U]HFMUNbmXJGIQK20b=CDP
I6EV80eK;dU^I6EhIF@P;dAUMVUSIE97@R1XJGIQK21bIf9SK7EdGB1cIGASKfa_
LW=`HF=U3EmYKF5WIFAYHg@PI7E`869UIfU^80d_EfUTM6PPGgLPI6EV80d_B6EY
IfQd85mX86AUIR0P3Bm4IF=_I6DPFc0PJ6UfHFaM86AUIR0P3Bm9KF5WIDeQM79Y
N21OJFeQM79YN21TIFH=;d9YM7=@IG93Kfe`KfiUKW@P>21TIFHP3Bm9KWAULW1_
K65dIB1VHFacIB1TIFH=IFiT86U]HFMUOFAUIPe/IGIUK38PKVmdNb1TKfidK6mQ
I6aUMVE/<R1bIG=dKg9U87eYIPdU9DE^I51bKf=CIG@=;emYKF5WIFAYHg@P<CDP
I6USM21RIFMYKR0_BFeQIfEDNG1U834PI6EV;d9YM7=@IG93Kfe`KfiUKW@P>21T
IFH_BFidIG9`KfaQM6DPIV5/LfDPI6EV86=eLW9UKWATJF=d86E^I21TIFH=;fQQ
Lf=_K6mb87AbMFDPI6EV3Bm/IGIUK38PLgUcM6E]I6USM20_K65^IgEQIfE/IGIU
K21[KVmgKPekK65^IgEQIfE/IGIUK20b86MUOG]VHFacIGeYIVE/LfDPI6EV3BmV
KgEbIG4PNc@PJFiTIGPPIG4P>20a879_K6`==21YKVAUN21ULB0h834PLVm/K0dd
86U^I6Eh86Ea83PP<B1bKfa/3C@PJFiTIGPPIG4P>20a879_K6`=L6m`871_L21`
Kg0PL6m`865^I21QKV@PHFiTOB1TIFH=;g=UM7E`HV5^I7=kIg=QMVD=;emcIGAd
LV5^LfIULR1cNG=dIFeTJF=d82mcIGAdLV5^LfIULR1WIG@PI6EV3BmOHgEbLVE^
M7AbHFicIVEb87=iLgAUKFAYHg@P;f=eLW9UKWAdLV5^LfIULR1WIG@PI6EV3BmO
JFeQIfDPLgUcM6E]I6USM20_JFeQIfDPIfEd86AUIPd_HVaQKV/P<21OHgEbLVE^
M7AbHFicIVEb86EhIF<=<B1OHgEbLVE^M7AbHFicIVEb86EhIF<PIG4PI6EV3Bm^
IFMQM6UfIB1RK65^Jg/`85mSMG9bIFidM79QKW=VIG8PIGQUHb0`;SDPK7Am3G/`
85mSMG9bIFidM79QKW=VIG8PIGQUHb0a85mSMG9bIFidM79QKW=VIG8PIGQUHb1W
M7eYIVE/LfDPI6EV3BmYKWIULWAUI3lPKVEWHGAYMVDPI6EV3BmOHgEbLVE^M6Mb
HGTPLgUcM6E]I6USM20_HgEbLVE^M6MbHGTPIfEd86AUIPeXHG=SKfa_LW/_968P
<21TIFIm87/_968P=B1TIFIm86UVIFacI@d_LfEdHfeiJf=_K6mb87MXIG9UNg1_
L20a830P<20`87=UM6=]NF]SKfa_LR1OHgEbLVE^M6MbHGTP<B1UN6=X87=eHPd`
834P<20`87=UM6=]NF]SKfa_LR1OHgEbLVE^M6MbHGTP<B1UN6=X87=eHPd`830P
<B0`87=UM6=]NF]SKfa_LR1OHgEbLVE^M6MbHGTP<B1UN6=X87=eHPd`830P<20a
87=UM6=]NF]SKfa_LR1OHgEbLVE^M6MbHGTP<B1UN6=X87=eHPdd87/d86=_L7Um
879UL6EQM0da830P<20`86I_MG9ULG/_968P<B1cM6mbIGeYIPd`834P<20`86I_
MG9ULG/_968P<R1cM6mbIGeYIPd`830P<B0`86I_MG9ULG/_968P<b1cM6mbIGeY
IPd`830P<20a86I_MG9ULG/_968P=21cM6mbIGeYIPd`830P<20`86I_MG9ULG/_
968P=R1cM6mbIGeYIWeYIPeRK65^Jg/_968P=R1cM6mbIGeYIPdTHR0`86Ea82AR
83DPIG4PKg9k;bATM20`86AUIWeYIRlTI7@P;C4PI6EV86MbIG=dKg9UOFAUIPd_
I6mYKF5WIG/=K6EfIF`bNfU]HFMUOG]RIFMYKPeGJFAdJ218IFUWJ7@P@VUdLe1U
LT=_KG1_KVE^M219KF5WIDeQM79YN0e4IF=_I6DPK6E^IgAX838PIG4=Nbm4HGAQ
DfmeLV=U86a_HF@PIFiT86U]HFMUOG/=A6ESKfAU86aUKVMdJ20f86Ea3G]=MFad
JG1/IDAQM65CKgEbHfEcNdAQM65CKgEbHfDP<21WIG@PA65dHE=_MG9SIB0a86MU
M214HGAQDfmeLV=U838PIfEdOG/_A65dHE=_MG9SIB1/Kf5TOFUVIFacI@e=MFad
JG1/IDAQM65CKgEbHfEc83<PIFiT84ACBD=_K6mbBFeQIfEmN`e4IF=_I6DPK6E^
IgAX83PPIG5kCGE/M6U`K6E4HGAQDfmeLV=ULg]4HGAQDfmeLV=U830PIfEd84AQ
M65CKgEbHfDP<B1WIG@=A65dHE=_MG9SIB0b86MUM214HGAQDfmeLV=U83<PIfEd
OG/_A65dHE=_MG9SIB1/Kf5TOFUVIFacI@e=MFadJG1/IDAQM65CKgEbHfEc83@P
IFiT84ACBD=_K6mbBFeQIfEmJFImJFIUK7=U3GeYIVE/LfD=OFUVIFacIGeTIFH=
;fAdNbmbIf9SK7Ed87QTIR0_HWMSK7Ed87QTIWeTIFH=;f=/NbAY87=UM6eQM79Y
N21dLV5^LfaQM6DPLf=QK6D=;emg85mYKF5WIFAYHg@P;eMYI7AX86MUM21TIFH=
;emX85mYKF5WIFAYHg@P;dQUJFMXM21WIG@PI6EV3BmOI7<PGfU]HFMUI6USM20_
A65dHE=_MG9SIB1WIG@PI6EV3FA_HfaeM6U]HFMUOB1TIFH=;f=TNbAY87=UM6eQ
M79YN21dLV5^LfaQM6DPLf=QK6D=K6EfIF`bNemYKF5WIFAYHg@P;d=_K6mbDg1Q
HfDPIfEd87=UM6=_K6mbLg1QHfEmJFH=;emg85mYKF5WIFAYHg@P;eMYI7AX86MU
M21TIFH=;emX85mYKF5WIFAYHg@P;dQUJFMXM21WIG@PI6EV3BmOI7<PGfU]HFMU
I6USM20_A65dHE=_MG9SIB1WIG@PI6EV3EmYKF5WIFAYHg@PHVEWJFh=;dU]HFMU
CF5dLVUh85mYKF5dLVUh86AUIPeSMG9bIFidI6USM21UKV@=I6mYKF5WIGdPI6EV
3BmYKG/TJB1cIGA]HGAbJGPPM79QKW=/HGAU87=SHFaU80e/IGIUK39k;dAUMVUS
IDMbHGTPLfEdHfm/Kg9cL65SIB0`87=UM6MbHGUmJFH=;emg85mYKF5WIFAYHg@P
;eMYI7AX86MUM21TIFH=;emX85mYKF5WIFAYHg@P;dQUJFMXM21WIG@PI6EV3BmO
I7<PGfU]HFMUI6USM20_A65dHE=_MG9SIB1WIG@PI6EV3EmYKF5WIFAYHg@PHVEW
JFh=9Bm4IF=_I6DPFc0P<EdPI6EV820=9BmGJFAdJ21OMb1TIFH=9Bm8IFUWJ7@P
GfPPI6EV3Bm9KF5WIDeQM79YN21OJFeQM79YN21TIFH=HgEbLVE^M6AYHg@PIFiT
80eTKfU]HFMU87eTIFH=;f=_K6mbJFeQIfDPMfQULVEkL6m`;dACBD=_K6mbBFeQ
IfDPNf=_K6mbJFeQIfEm86AUIWek;dACBD=_K6mbBFeQIfEk3BlTKV<PN6AV871_
L20_L79_Hc0PN6AV83<PJFiTIGPP<R1YKVAUN21]MF`P=b1QI6@P>21TJGHPHgIY
87=dLVU^Ib0_Lg@a87QTIPdTKV<P<b1ULG]kL79_Hc0PI7E`;g=d<21hI6HP<21U
N6=X83<PIGQSJ21/IFiWM6PP<b1cMF8=NfAeL21cM30PIGQSJ21WIG@P;S<PKGE/
834PJFiTIGPP<B1QI6@PLg@`86EhHfPPIfEd82he>B1]MF`PHFAT834PJFiTIGPP
<R1QI6@PLg@`86EhHfPPIfEd82ha<B1]MF`PHFAT3F=fJB1UN6=X83<PI6Uf86=f
JB1UN6=X87=d<B0c834PLVm/K21`MGAmIVmb87=d<GemNg]`LVmS<21TMG0_Lg@`
87QTIR0`86EhHfPP=21UN6=X86aUKVMdJ20d87=eHW]TMG0=Lg@`86EhHfPPIfEd
82hc86eeK0da86U^I6Eh834PHFAT87=d<21UN6=X86MUM20^=CTPKGE/865TI0da
86U^I6Eh838PHFAT87=d<21UN6=X86MUM20^<C4PKGE/865TI0da86U^I6Eh83<P
HFAT87=d<21UN6=X86MUM21QI6@PI7E`838e=Bh`86MdNg1_L20b=CD^<7eYIPdb
=CD^<21UN6=X87=eHR1SMVT=IGQSJ20d86AYMR1SMVTPIGQSJ0ecM34P<b0a879_
K6`PL7EdOFI_LR1cM35mOFUVIFacI@eYKF5WIGeTIFImJFIUK7=U3Bm?D4UYKF5W
IG]YKF5WIGeTIFH=;bAY86eQM79YN21TIFH=;f9YNg=SHFaU87AbHFicK65dIB0T
JB1SMG9bIFidKF5dLVUh871_L21dLV5^LfaQM6DPLf=QK6DPLfEdMG1RHFiTLgeT
IFH=;fEYNbAY87=UM6eQM79YN7eTIFH=;fU[NbAY87=UM6eQM79YN21dLV5^LfaQ
M6DPLf=QK6DP3BmOMb1OJFeQIfETJF=d82mGJFAdJ21WIG@PI6EV3BmOJ21OJFeQ
IfETJF=d82m8IFUWJ7@PIfEd86AUIPd_GfAc85mYKF5WIFAYHg@P;dAQM65CKgEb
HfDPIfEd86AUIPeOMb1OJ21VHFacIB1OJFeQM79YN20e82da879_K6`PGfAc86U]
HFMUKF5cJgeTIFH=;g9cNc8PHfm`NB1dLV5^LfaQM6D=<b0]<B1bKfa/86iUIb1b
KgAQM6D=KVEW86EhHfPPKVEW86EhHfPPM79QKW=/HGAU3GeTIFH=;f=cNemSMVed
N21QLgA_LVDPHfm^Hf5dOB1TIFH=;fITNbmOIV@PN6AVOFAUIPd_GfI_KWA=HGAb
JGQk<B0`830PGfIT830PKVEk;C4P<20`OG/a830P<7eYIVE/LfDPGf=fKGAh865c
M6mbIGeTIFH=;g9VNbmOIFiSKfAYKVAUN21hI6H=AVm^M4AYLVESM6mbNB1UN6=X
86]^KgM^87/=IVU^I6I_KW@PI7E`86aUKVMdJ20a865TI21TJF=d869UIfU^Nc4P
JFiTIGP_ATU486iUNfAUIWekL6m`871_L7eYIVE/LfEmIVmbHFa/3FAeL20_AVm^
M4iQKFDPIGQSJ21TIFHPAVm^M5AiL6DP<21^IG/_AFiSKfAYKVLPAFiSKfAYKVLP
<SDf865bLV5i86=_L7TPI6EV3EmUKV=_I6U^I6Eh830PIfEk<21OIFiSKfA1LW8P
GfE^HfmTJFiTIGPPIfEdNfAeL21dNG1U;fiQKFEdNG1U86EaNdE^HfmTJFiW838P
JFiTIGPP<R1YKVAUN21`MG@PL6m`834PHFATO@ekIGQSJ21`Kg1mJFIUK7=UOFI_
LV5/K21`Kg1mJFImJFH=HgEbLVE^M6AYHg@PIFiT3FAUIVU^IFI_KW@PL6m`87ek
L6m`871_L7eYIVE/LfEm86AUIPd_HgIcIW/PIVU^I6I_KW@PIWACJGYU830P<21V
M5=YNVDPGfIT830PKVEk;C4PKGE/OFUV830P<21OHgI]M7PPHG=dKg9U80e]HF]U
IVm^M21cIGAVKfidOFAUIPd_KFIk<b0]<B1bKfa/86IYKVAVKfid83<P<B1bKfa/
86EhHfPPIWACJGYU86eeK21UN6=X86IdDfUjIB1]MF`P<21UN6=X830PIGQSJ20=
GfIT830PKVEk;C4PKGE/OFUV830P<21OHgI]M7PPHG=dKg9U86eQJfEVKfid87=U
M6I_KWAmI6EV3BmgLV/a82PP:B1TIFH=;gMTJF=d834f86AYHg@PI6EV3BmGKg9[
=cDP=cDPLgAbJFiW86AUIPd_CVe[NeM_LV/g=B1SMW<PI7E`OFAUIPd_CW1dNg1e
M21SMVimI6EV3BmTJ4mTJ7]>KF/P<R0g>B1>L7AmI6EV3BmTJ49TJ7]>KF/P<R0a
<C4PCW1dOFAUIPd_I6QCI6QkCVe[838P>3<PCW1dOFAUIPd_LfIGJFAdJ7]WLf5f
IB0`830PKFmfIGA_830P<21/JFiUM6lP<20`86aYKVEdKb0`830PK6U^IGA_86=/
Kg=UL65dJ21SK6U`87=dLVU^IgMYI7AX86MbIG=dKg9UOFAUIPd_IWAcNbmVM5=Y
NVDPIGQSJ21TIFImI6EV3Bm]JdIDNfAeL2m6KfidE7U`IB1WIG@P<21ULG]TMG0P
KF5hK6E^IgAX86AYHg@PHVEWJFh=Nc4PJFiTIGP_ATU486iU838PJFiTIGPP;eE^
JG5eIDU486iU865^I7]TIFImNg1_L21`Kg1mJFIUK7=UOFI_LV5/K0eSMG9bIFid
I6USM21UKV@=I7E`;dI4IG1FIF=dKg8P<R1SKg1i86MUM0eKIGQSJ20f86U^I6Eh
86EhHfPP=R1YKVAUN21UN6=XNfe[AU@P<b0a879_K6amIVmbHFa/871_L21`Kg1M
871eM21TMG1mNbmdIFe`AU@P<C8PI6USM21TIFH=M6E]L4ID869UIfU^3Bm6Kfid
CF5dLVUh85/a830P<20a830P<5dPI6EV3Bm6KfidE7U`IB0c86AUIPeTMG0_AFiS
KfAYKVLPIfEd;dE^HfmTJFiW86EhHfPPI6EV3Bm`LVmS<R0b86U^I6Eh86AUIPeT
MG0_IW@a86EhHfPPI6EV3BmVM38P<B1QLW9QNB1TIFH=;dI_KWA2@Vmh85/`830P
<B0aGB1TIFH=;d9eJFaT@fQQLW]3ETAYHg@PHVEWJFh=IGQSJ21TMG0_IWATM21h
I6HPHVEWJFh=MfAYHg@PHVEWJFh=;f=XLR1hI6H_HfQbLg@PMg9[<B1TMG0P<21S
J78PL7Ed86AUIPeVM38P<21WIG@PKWE/K21ULG]VM34PI7E`86aUKVMdJ20b865T
I21TJF=d869UIfU^3G/a86U^I6Eh;dI9A21^IB0b86U^I6Eh82mEKVUaMFE9A21^
IB1QKVAkI6EVOG]`Kg0PL6m`OFUVIFacIGeVKg9QK6`=;e1QJFidE7U`IB0b86AU
IRmCM79_JfEGJFAdJ20^<38d830PAVm^M4eQM79YN21YI7AbHFicIVmbKB1`Kg0P
I6EV3F=eLW9UKWATJF=d86E^I0d_LB1UN6=X86AUIVU^IFI_KW@=IW@b86EhHfPP
<21UN6=X871eM7eYIPeVM6Ad;g1bKf<b86MUM21UN6ES86E^I21UKV@PIFiTOFAU
IR1UKV@PM6E]L4IDOFUVIFacI@dc86U^I6Eh86EhHfP=I6EVJFiUIVm^M21UN6=X
871_L7eTIFH=;feRNfAeL21TJ49TJ216KfidA6UbIF=dKg9i834PJFiTIGPPJfi_
Mfh=NfEhHfPPL6m`OG]TM@0S0000X@30?om`838PJFiTIGP=IVU^I6I_KWAkHVm/
I71bKf=m86EhHfP=KF]6E21`Kg0PL6m`871_L21UN6=X871_L0emJFIUK7=U87eT
IFH=;fe_NfAeL21TJ4mTJ216KfidA6UbIF=dKg9i834PJFiTIGPPJfi_Mfh=NfEh
HfPPL6m`OG]TMG0P<R1YKVAUN0eVJFiTIVm^M7]_MGA`LVmSOB1UN6=X3Fe[AU@P
L6m`871_L21`Kg0PIGQSJ21`Kg0=OFUVIFacIB1mI6EV3Bm]Lg]TMG0PI6QCI6PP
AVm^M4AYLVESM6mbNB0a86U^I6Eh86]^KgM^3G]UN6=X871_L7ekI7E`838PJFiT
IGP=IVU^I6I_KWAkDfQQI4=XHG9m86EhHfP=KF]6E20PL6m`871_L21`Kg0PIGQS
J21`Kg0=OFUVIFacIB1mI6EV3Bm_MGA`LVmSNfId<B1cIGAVKfid3FMcHGIU86=X
LW=d87=VEfUTM6PPIg9ULgA_LVD=LfEdHfQQLWMYI7AX86ARK7=XOFAUIPd_HVm/
I71bKf=kIW@a87=UM6I_KW@=Ig=QMVD=HfQbLg@PLfIGJFAdJ20a86U^I6Eh830P
KVEkIGQSJ20^<3DPHFAT86EhHfQmJFH=Ig9ULgA_LVD=LfEdHfQQLWMYI7AX3FId
<B0_D65YKWADNG1U86MUM20b86iU3G/`830PKFmfIGA_86McHGIU86Id<R0`86MU
M21cIGAVKfid86=XLW=d87=XKgLPIg9ULgA_LVDPHfQbLg@PLfQ_Mgd=Nc0P<21]
KgIUM6lPIg=QMVDPHfQbLg@PLfQ_Mb1WLVEcM6mbIB0^<3DP<21]KgIUM6lPHfQb
Lg@PLfQ_MgeYIVE/LfEmI6EV3BmTHVacJ7]SMG9bIFidHfm/Kg8PHgEbLVE^M6=_
K6mbLg1QHfDP<Bh`87=UM6MbHGT=HfQbLg@P<20`86e_MVEdKb1cJ6mg87=UM6=_
K6mbLg1QHfDPLfEdHfm/Kg8=IW@b830PIfEd87=UM6I_KW@PHfQbLg@P<20`86e_
MVEdKb1cJ6mgOFAUIPd_DfQQI4=XHG9k3FId<B1cIGAVKfid3FMcHGIU3F=XLW=d
87=VEfUTM6PP<B1YKVAUN20`86iUNfEhHfPP;S0e865TI21UN6=XOFUV3FMbIG=d
Kg9U3G=UM6=XHG9gJFAdJ0eSJ79cM20^<3HP<21]KgIUM6lPLfQ_M`d`82h`=B1d
LV5^LfaQM6DPI69/LfQmI6EV3BmdLg]cJ6mgOFAUIPd_M65k;em/IGAdIG9CL65S
IB1hI6H_Gg=`HF=UF7AbHB1hI6ImI6EV3BmdIW/_GgAUN7AGJFAdJ21hI6H=;em^
MFeCL65SIG<PN6AV3BmOLgAbJFiWC6E^IgAX87QTIPeTMG09LgAbJFiWMfUTM6PP
L6m`3Em/IGAdIG9CL65SIB1OLgAbJFiWC6E^IgAX834PLgER86eeK21QI6@=Gg=`
HF=UF7AbHB1OKWE]Dg1QHfEc86eeK21QI6@=GgAUN7AGJFAdJ21UN6=X87=eHR0_
MfAYIR1hI6H=Gg=`HF=UF7AbHB0`83<b3GMTJFHPGg=dLVU^IdaUKVMdJ21TJGH=
GfaUM7AULU=`HF=U865TI0d`83HP;C4PLVm/K21QMfUTM6QcJ6mgOFAUIPd_L69k
;em@HFMUDf5fIB1cHGIU86AUIRmcJ6mgL65WIG]mI6EVOFAUIPd_L6EkGe1QIfEC
HGIU879ULgA_LVEmI6EV3Bm`KG]OL6dPHgEbLVE^M6eQM79YN21`Kg1mI6EV3BmO
L6dPKF5dLVUh86AUIPd_L7=kLfQ_Mg1QIfDPGg1]87=UM6eQM79YN7eTIFH=K6Ef
IF`bNbmUIR1kIg=QMVDP=R1QLW9QNB1QLgA_LVDPHfm^Hf5d86AeL21UN6ESIVmb
KB1WLVEcM6mbIGeTIFIm3G/_IFIkIg=QMVDP=R1QLW9QNB1QLgA_LVDPHfm^Hf5d
86iUMg1QM6PPI7E`869UIfU^84eQM79YN21SKfiSHG@=@T9_N21TMG0PI7E`830P
IfEd86EhHfPP<B1WIG@PKFmfIGA_3FAeL21TMG0P<21WIG@PIGQSJ20c86MUM21/
JFiUM6l=I7E`86AeL20b86MUM21UN6=X83<PIfEd86aYKVEdK`eTMG0P<R1WIG@P
IGQSJ20a86MUM21/JFiUM6lPHfa_LfE`HGAX3F=/JG0PKVEgL65dJ21@HFU^M51b
Kf<PIFiT86MbIG=dKg9UOFAUIWeYIVE/LfD=;f9SNg=QMVDP<C4P<B1bKfa/834`
86AYHg@PHVEWJFhP;d92KgPP=B0a879_K6`P=21QLW9QNB1QLgA_LVDPI6EV3Bm=
HGAbJGPP=b0a879_K6`P=R1QLW9QNB1QLgA_LVDPI6EV82m6Kg9]E7U`IB0a86AU
IRm@HFU^M51bKf=k;g1`86MUM21UN6ESOFAUIWeTIFH=;fESNg1_L21bIG=dKg9U
OFAUIPd_L79YKWAfKG/a87I]LVESK65YKB1fKG=dHGAeLb1`Kg0PIGQSJ21`Kg0P
:20P820P820P820P820P820P820P820P820YHgIc871bJFid82QLKRU`LVU^M21V
K7EcJ7eTIFH=;g=UM6mfIG9`LVU^M21gJ6EbIB1kL6m`OG/_LfEdKgIULW1bJFid
Ng1_L7eTIFImJFIUK7=U3BmcLgAb87/P;bAcLgAbLb1UN6=X86AUIR0_97=cM78P
IGQSJ21TIFHP;bAcLgAbNB1UN6=X86AUIR0_97=cM79h86EhHfPPI6EV82m3KgEb
JFEb86IYKVAVKfid82AcLgAbLb0=Lf=QK6EVKfid87=UM6I_KW@P97=cM79h82Ac
LgAbNB1]M21cM6dP<B0]<B1cHf5/IB0TLg=dLR1cJ6mg879dKB1m86AUIPd_A5=9
@VEWJFi@HFU^M51bKf=k;g1`86eQLV]kHgEbLVE^M6IYK6DPM6m[IFhPKVmdNgeY
IR1TMG0_A5=9AFiTD65YKWA@LVmS3@UULG]`Kg0PHfmeKWAdKfeQLV/PHG9bHGTP
HG=dKg9U86=fN21RJFiT82mUN6ES86a_HFAMHgIh86AUIR14DdU5KVA@HFU^M51b
Kf<PIGQYM7d=2G]SKgE^M7A_KF5bJb0c<30PIgAkHfmeKWAdKfeQLV/PHG9bHGTP
HG=dKg9U86=fN21RJFiT82mUN6ES86a_HFAmJFImJFIUK7=UOFa_Kg1mI6EV3Bm4
DdU5KVA@HFU^M51bKf=kHgEbLVE^M6AYHg@PIFiTOFAUIPd_A5=9@VEWJFi@HFU^
M5=eHU1bKf<PNg=QMVDP<C4P<B1bKfa/834`86AYHg@PI7E`82m`A21UN6=X86AU
IR1RIFMYKR0=2Bm2@Vmh83DP<B1bKfa/83@PHG9bHGTPHG=dKg9U86AUIR0_CF5d
LVUh83LP<B1bKfa/83HPHG9bHGTPHG=dKg9U86AUIR0=2Bm6Kg9]E7U`IB0a86AU
IR0_D65YKWA@LVmS87/P;g1`86MUM21UN6ES87dPI6EV82m`L7dPI6EV3Bm4DdU5
KVA@HFU^M5=eHU1bKf<PNf9YKV@PI6EV86E^I21`A7dPI6EV3BmYHF4PNbmYN21Y
N21YN6hPHFAT86AUIWdPI6EV3BmYHG<b87/_JFMQL21UN6=X86AUIR0_Gg=d<21Y
HB1YN21YIf5`865TI21WIG@PI6EV85mcM31m86AUIPd_JF5c87/_Lg@`86UQ86Uh
86MUM21TIFHPJF5Q87=d<7dPI6EV3BmY>3Ec87/`86UQLc8P;d5C@dU9>3E4IF=_
I6DPIVU/M6Eb87=d<21bIF5TLgAbJFiW871_L21YHF5m86AUIPd_JG9/IG<PNc0P
JF5c<R0_@E=3BDTh=DAUHfmTIB1VJFadIG8P;e9eKTaUKVMdJ4AUHfmTIB1VJFad
IG8PLg@`879UHFAcM79YKVLPL6m`86UQHGdPI6EV3FU^JGAYHFaYNVD=IFiT3BDU
AFiTDVEcKgEbHfD=@eI4JF=d869UIfU^830PJF@P<B1VI0eOIFiSKfA1LW8P<0eK
3C<i;g5eKgAULfU^IfaU83Tf;fMbHGIU3C4b>2mRMFa/IG@_HWE/K6Ed;g5eKgAU
LfU^IfaRHG=U;fI/Kg9YKRmaMFmdIFARK69QLfD_IFa/JG1cJG<_I65WIfEb;fAQ
IfMULVARK2mSJG9SMFeVK6Eh;g1ULWAXKgEcHFiT;e=SHG9_KRmWMFU/LfU^Ifa/
IFId;dm5;f9eK6aUM2mRMFa/IG@_HWE/K6Ed3BmRMFa/IG@_LGE_M6E/IFId;g5e
KgAULVUWJ7@_LGE_M6ETHVa/IFId;g5eKgAUI69/LVUWJ7@_HWE/K6Ed;fE^I65c
J2mUKFAQLfP_M6U/I6D_M79QI6E]HG9[3BmcHf5bKfh=;fMeJFacJFiWK79YIfQd
;fmU;f9eK6aUM2mRMFa/IG@_FFAYIG9ULfUc3BmRMFa/IG@_IGQSK65]I6mgKRmS
IFid;g=dIG9/JFiW;f=eLW9UKV=i;gUUKRmRLVm[IFiRHG8_LfESM6U_KRmTJFEb
IG=YLbmSKg1iLVUWJ7@_Kg9TIVE]JFiYKVD_IgEYK6aUKFmdK6EVM2m/KfMYHf5/
KVmd;fQiL6QUKRmbIFMYLgAULVET;feQHg9_KPd_I6EWLVEU;g1/MG=]JFieLbmd
MfmcMG1ULVU_LRmdJ79UIG=eL6EbJFmb;f5SMGAU;fee;g1QLV5WLV5`J2m`IG9Y
KfASIFidIG9UI2mSIFAYK6aQ;fm^IG=eL6EbJFmb;fmbI6eQLf=eK6U^IBmWMFU/
K6E]KgAbJFMXM2m_KVEaMF5bM6Eb;fm^IFQQK6H_M6QbIFEaMF5bM6EbLbmaMFEc
M6U_KVA_Mfh=;d5WLV5fIBm1HF=eM6D_@F=YLV=eKFI/IGP_@GAYK6AU;d5TJFEb
IG=YL`d_@G9YKVL=;d55;d=SIFAYK6aQ;dEWLV5fIBm5HF=eM6D_AFMbHGIU;dET
JFEbIG=YLbm9Ig9QMVD_BF5SMGAU;dUSJG9SMFeVK6Eh;dUTJFEbIG=YL`d_AGAX
;didJFaTIBm?Ig9QMVD_Cf5SMGAU;dmSJG9SMFeVK6Eh;dmdJFaTIBm?I6UULVEc
JG<_KGE/M6U`K7T_Cg=/HG=X;eEWLV5fIBmEHF=eM6D_EF=YLV=eKFI/IGP_EFAY
IG9ULfUc;eUQHgEdIBmDJ6mbKRmWIG9]HFiTHVac3BmQIg9QMVD_HF5SMGAU;f5S
JG9SMFeVK6Eh;f5dJFaTIBmQI6UULVEcJG<=;f5bJFiW3BmQIBmSHfETJFa/HBmU
Ig9QMVD_IF5SMGAU;fESJG9SMFeVK6Eh;fETJFEbIG=YL`d_JFMbHGIU3BmYHF=e
M6D=;fUSJG9SMFeVK6Eh3BmYI6UULVEcJG<=;fEdJ2m^M6U/I6D_KfMbHGIU;fmQ
HgEdIBm_HfUbHgE]IVaUN2m_M6U/I6D_KfAYIG9ULfUc;fAYMVUTIBm_LfaQLfP_
MFMbHGIU;gEQHgEdIBmeHfUbHgE]IVaUN2meI6UULVEcJG<_NF5SMGAU;gAXKg9^
;gUTJFEbIG=YL`eM871eM0eOIFiSKfA1LW8P<@eK3C<i;g5eKgAULfU^IfaU83Tf
;fMbHGIU3C4b>2m1I6UULVEcJG<_@G9YKVL_@f=UI6U/K64_AF5SMGAU;didJFaT
IBm?I6UULVEcJG<_EFAYIG9ULfUc;f5QHgEdI@d_HFMbHGIU;f5SJG9SMFeVK6Eh
;f5TJFEbIG=YLbmQM6U/I6D_HG9YKVL_Hf=UI6U/K64_IF5SMGAU;fEWLV5fI@d_
IF=YLV=eKFI/IGP_IFAYIG9ULfUc;fUQHgEdIBmYIg9QMVD_JF=YLV=eKFI/IGP_
JFAYIG9ULfUc;fidJFaTIBm_HF=eM6D=;fmWLV5fIBm_HfUbHgE]IVaUN2m_I6UU
LVEcJG<_KgAYK6AU;gEQHgEdIBmeIg9QMVD_MF=YLV=eKFI/IGP_MFAYIG9ULfUc
3BmTHFMWIG8_I6EWLVEU;f=UKW@_LgAULVaYKVL_LfESM6U_KRmRMFa/IG@_L65b
HFMbHG1X;fMULVeQKVARK7<=;g9UIfUcM6EbIF@_Hfm`NG9YIfQd;gAbHFAUKF5b
JbmQHgEdIBmTJFEbIG=YLbm^KgAULGEQK2m1ABm?LfaQLfP=;fU^IVU^JGAi;g1/
MG=]JFieLbm/IG=cIG5eHF`_Ig9UHGAULVEaMF5/;gUUKRm]MBm`HG9dJF5/I6UV
IRmcMFe]HGAYKfh=;g1bKfAeHg@_L6T_JFidIFMbHF`_Kg9TIVE]JFiYKVD_Kg9T
KF5cHgE/JFiU;dm]IFMQ;f5U;fmcK65cJ0d_LGEULgAYKfiTKgM^;fEhHfaQKFA_
Mfh_K6mWJF=QK6i_M2mbHFAYHf5/;fI/Kg9YKRmQL71bKgQULGEQK2m4IFadHBmW
MFU/K6E]KgA/IFId3BmWMFU/K6E]KgAbJFMXM2mUK6aYL7=YLbmRK65^Jbm1Ig9Q
MVD_@GAYK6AU;dmdJFaTIBm?ABm_I@d_IFiTHG=X;fE]I65cJ2maMFmdIFARK6aU
IW@_LGE_M6ETHVabJFMXM2maMFmdIFaUIW@_LGE_M6EbJFMXM2mTJGIYI6D_K6mj
IFiWI@d_NFAYIG9ULfUc;eUTJFEbIG=YLbmVLV5SM6U_KRmSMG9bIFiSNBmWMFU/
LfU^Ifa/IFId;fMeJFacJFiWK79YIfQd;fIY;fI/3BmTHFMWIG9THV`_L6EbJFmT
HfE^M6EbIF@_LGE_M6EcJFiWK69QLfD_LGE_M6ETHVaRHG=U;g1ULWAXKgEcHFiT
;d5SJG9SMFeVK6Eh;dESJG9SMFeVK6Eh;d5QHgEdI@d_AFAYIG9ULfUc;dEWLV5f
IBm9HF=eM6D_BF=YLV=eKFI/IGP_BFAYIG9ULfUc;dUWLV5fIBm?HF=eM6D_Cf=Y
LV=eKFI/IGP=;f5`L6aU;dmWLV5fIBmEHF=eM6D_EF=YLV=eKFI/IGP_EFMbHGIU
;fA_M6aULg=Y;f=YLV=eKFI/IGP_M6U/I6D=;feQHg9_KRmRLVEfIBmTKgAQHf=U
KW@_LVU^IbmSIFAYK6aQ;fQeKVMQLWE]K65eM2m_Ifm^IF/_Hf5bKfh=GB1`MG@=
IFiT3BDUAFiTD79_K6mW80dU9D9UIfU^DfEdMG0P3D=FA6USM21RIFMYKPd=9BE2
IFMYKU9ULfmeLV=U>R1VKfid84MUKVEfH@da=21TJF=d869UIfU^3Bm6KfidCV5]
IB0_AfE^IGIQ86AUIPd_AVm^M4eQM79YN21K<2h`<34P<20`830^<30a830P<5dP
I6EV3Bm6KfidBFiVKb0a<21TJF=d86AeL21RIFMYKPd_AWE/K4iQKFDP:4MUKVEf
HBTPI6EV3Bm6HFeYK7U>HFeU82Q7IFiUMV4Y86AUIPd_EFiTIG9/JFiUD6mcJGAY
KfhP;C4`<21TIFH=;eE^I6EbK6U^IEAXJF=[KVEcLb0e<21TIFH=;e=dLVU[IFme
M51_LfUdJFm^83<`<21TIFH=;e=dLVU[IFmeM5AXJF=[KVEcLb0b=B1TIFH=;eMU
JFMXM20XCFETJGE]:B1TIFH=;dUdHFaYHd5^IfaU830PI6EV3BmYLdIYN6ETD6Ud
HfPPIV5/LfDPI6EV3FE^I21TIFH=;emWK7U`J20XF20P:B1TIFH=;fMh3G/=2C4P
IGQSJ7/=2@UTMG0P<CHP:20P:B1SMW9c85mWK7U`J21UN6=X834PIGQSJ21`MGAY
KWAULWIQK20a86U^I6Eh86EhHfP=2@UOIfaiL6PPHgI^871eM0d92GeVKg8=OFAU
IPd_D65YKWADNG1U830PI6EV3Bm6KfidE7U`IB0a86AUIPd_AFiSKfAYKVLP<SDf
865bLV5i3C0P<B0b=CDPNb0a86U^I6Eh86EhHfPP;bi^KgATIFHPL7Ed87dPIVmb
3C<`838e=B1WN0eTIFH=;dI_KWA2@Vmh85/P<20`830P<21M86AUIPeSMG9bIFid
I6USM21UKV@=I7E`82m@LVUfHGAU83PPI6USM21TMG0PHVEWJFh=;e94Ng=dLVU^
Ib1SMG9bIFidIVU/IB1UN6=X879UHFAXIGQcM79YKVLPL6m`OFAUIPd_CTAkI6EV
OFAUIPd_CU1kL7EdOFAUIPd_@VaeIEIQK7EULe/P;C8e<20`838b<30P<S8`<5dP
I6EV3Bm=JFi6IF5dMG9U87/P<CHP<CIm86AUIPd_L65cLgM_LV@P=CPc>B1TIFH=
;e=eHW9c83@c865bLV5i3Di43C8PJFiTIGPP;d=XHG9CM79YKVMc838e=R1TJF=d
86AeL21RIFMYKPd_;Vi_M6AUIR0P<C0PDT@P<SA5@d94<3DcAD=1A3<e<THe>34P
CT@=;eP`<B0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<38P
834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F30c820a<R1BA20b
=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;eP`=20P<C8PDT@P<SA5@d94<3Dc
AD8i@C0g=DA1=3Q3@dE584i43BmH<3DP834b8594838dAD=2A30e<dE2>D4`=cE4
@C@h@d=5AB1>A0d_F30f820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDP
CT@=;eP`=b0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<3PP
834a8594838dAD=2A30e<dE3@D@c=C96=CPf=C8PCT@=;eP`>B0P<C8PDT@P<SA5
@d94<3DcAD8f=D=4>D8a<CA2<45584i43BmH<44P834b8594838dAD=2A30e<dE2
>D4`=cE4@C@h@d=5AB1>A0d_F312820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d
>4=3ADDPCT@=;eP`@b0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i4
3BmH<4@P834b8594838dAD=2A30e<dE2=SE3A3U2<C4d@S11AB1>A0d_F315820a
<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;eP`AR0P<C8PDT@P<SA5
@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<C0P834b8594838dAD=2A30e<dE2
>D4`=cE4@C@h@d=5AB1>A0d_F34a820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d
>4=3ADDPCT@=;ePa<R0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i4
3BmH<C<P834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F34d820a
<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePa=B0P<C8PDT@P<SA5
@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<CHP834b8594838dAD=2A30e<dE2
>D4`=cE4@C@h@d=5AB1>A0d_F34g820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d
>4=3ADDPCT@=;ePa>20P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i4
3BmH<CTP834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F351820a
<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePa@R0P<C8PDT@P<SA5
@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<D<P834b8594838dAD=2A30e<dE2
>D4`=cE4@C@h@d=5AB1>A0d_F354820a<B1BA20b=4E3@T@`=C=5@d54<cDbASDh
=SDb84i43BmH<DDP834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_
F356820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePb<20P<C8P
DT@P<SA5@d94<3DcAD8f=D=4>D8a<CA2<45584i43BmH<S4P83@a8594838dAD=2
A30e<dE2=SM5<c<f@D4d=c4e<C@dA44e>3=4@S92<DA6<dE1@DDf@d@bA3Lg@CDi
=cQ1=cLa=Pe3<4Hg@D8h<d<i<3Lc@cP`<C8`>CPb84i43BmH<S8P83@e8594838d
AD=2A30e<dE2>D4`=cE4@C@h<c96=c@cASLf>C12ADA4<cPa=C=2>3<i<cA6<DDg
>4@i@CE4<SQ6@Pe3ACI1>3@b<CE2@d95=dHi@C@i=dDg<34h@DDh<D@PCT@=;ePb
<b0P<C4h8594838dAD=2A30e<dE2>3Le<d=1=4@fASQ3ASPaASA2>C8f=c8a<SQ2
@cU5=D=1AD8a<d55<T@`<d=4ADI6A@dh<S=5A38f<D4f=3Tg<TI4=CM6=SLe<S=3
<4=2<CQ2<CE6<T<f=cQ2<SM3<CTaACHe=CE1=SA3=cE6@c8=AS91=SHd>D4d@cI6
=cL`<3Q6@C@g<C0iAC=4@S=2=D4a@C<`=D@b=TD`@cHc<SDdACM5A30f>CU3=cPa
3DI1@S0`>3Q3>CI2<48i@SI6ADHa@SD`@C8eA34i@T<`<TE5@S8d<S4b@TE2ASE4
=c4b>CI6<D=184i43BmH<S@P838g<21BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THg
<4A2<C=5=4Db<3I5@cU2=c4cACHe@c@`<d<c>D8i<T4g<4Di=ST==C4h>453@cPc
<c13=DE1<TDb>D=2<d<b=495>3DiAT@i=DDd<356<38e>3Lc=cHg<C@c>D<c<3=3
@DDd3C0a=3Hd=D@h=TDe<38g<cPi@CH`=DHgAS8c@T4b=3@h=D92ATHd@C4f=CPb
@c0e<3M5<C@d=4A1@SDbA0dd=C=4=T<h=D8c=SLeA4=4ATDb@C15=C8`AT@d>C8b
=4D`<SM4=CDg<351AD=2<C15AD8e@c91A44e<c@=<30c>3I1=C<i=C52A48i<SM5
A38g>3Lb@cTc<CA2=S<g>C8d@dDi=3LeAD8e>D4gACE3=cTg@cE2ACLd3CQ4@c=1
<cHe>CH`>3H`ASLcAD4a<D=2=dE2=S<gA4@i<SI3@cU2@C0i@SLd<C56=C0c<48g
=SA6AD54A@de<4Hf>CI4AT4hA3U2=SQ5>CU2<SM1ACHh@dA5<DE1<3Ti@SU6ATHi
<dI6>4Ha<cE2<SQ1<DHiAS4b<DD==d@d<c93<313=CPc<DI3@cQ5>3=3<SDb@cTb
<4Hh=SLg>3H`@SU6@T=5A34c=D<`AS@g=CPb@d56A3563CU6>454ASP`=S4d<TI5
A44d>3De=d=3=452=cDfAS8aACHd=3<dAS0a=4Hi@DA3=D<i<cA4<c12=C8c>21>
A0d_F38e820b=c4PDT@P<SA5@d94<3DcAD92A3Q4>4E4@T4e=4I1A3Di<c<`<44i
<dA1AS4d@C8a=DI1@CHgADHe=C0aASHh<4Hg3D8c<3DbAD52=c96<C@c=C93=THi
<c4a@THi<48c>48h@CM6<T94=cI5A3A1=38bA4@h=C@h@cHc@cE4=0de@S<aASDa
@S4b@S8d=4Hd=3M4<C=2=CTc<cA3>4Hc<c13<STd<D@e>3E3@SQ6<c12=D8`<c<g
<C14=c4=AS0`=c<dATDiAD@d@cLd<4<`@dDb=d@e=d8b@TDb=454=c8iAS=5@d<`
<SH`=d94<34e<CQ1ATA6@STf3D4a=S@h@SLf=d=3@dH`A30e>4Hb@S0a=SA5A3Hb
=3De=CLg@cQ5=3H`@dDd>DE3AC@d=cLg<SE6A3HaAPda=C0d<D=5AT@f=C<`>4Db
ASI3@S93=cL`>CM2=cM4=SLg<dA2<S8aAS92=d<e<T4g<D8`AT4fA3A6@SL=>DHe
@S=1=cQ6=SI3@c15ACA5<SHc>4=5@SLfA3Hf<496=48g=T@b@C0e>34e=c4h=3<`
>3A3@STh=SE53C8gA30c@SA4=D@eACI1=cQ5@SLdAD@e<T8b@C@f<DI5@d53<D8e
=C8c=d8f=d54>4A1=S8e>4H`<3Lh@Pe6@S54@dHi=3Pf=3A1=TI6ACHe>393<CHb
<d53ADE5@D94<CTe<T8iASQ1=cPiACU4<4He=CDe>3Di>3H=<S@PCT@=;ePb=R0P
<c@h8594838dAD=2A30e<dE2>3<a=C4i<DE6<3@gA34c=d@iACU6@c13>3I3=cE6
=S15<T4e<3=6=3PaAD96<3Q6A@db=c@e=C=3@C4a@SM6@SHbACLaAD<i@dHd@cDg
ATE1=44d@S<a@C0cA4<f=CLe>CDf<C92>CU5@c51<c0=<dDb=CD`@D56<3<f@T=1
>D@g<d<f<T@d<3Le@d=2<34c=S56<cLh<SPe<cDc>C0a<C95=S0i<CPf=dA53CM4
@d<hAT=1@c0`=4=6ASPi>C<d=d=2<THh=SE1>DDf=C@f=SU5=d@a=D4h<4E6AS94
A4Di=cHh>DDh=Pda<cA6<3E2>34hAS<f@C8dAT<e<cPa<34h>311ASDf@SU4=d<e
<395<THf<TE4=T<`<T4iAT4hA3=1=cD=@CM1<D@a<SDd@T55<D8bA3E6@S52<CA4
<DHd<CPaAD8bA3TfA4@`@SHfACM5<C@f=3Q5@SLe=S@e>3H`3C<iAD52<cLa=SHi
>CQ2AS0`@cLi@SPe=SPf<T4f<3U3ASDg<cT`<c8e<dE4A3A2=DHe@CLfAD<bAS4`
<@e5AT8a=CE5=D8eA4E1<cPgA4=6<38e>CHb=4@e@d@i=T8c<3E3=dHi=38a=C4`
<3I3<4He@c<`<4<dATH=<c92A3E4@C<d@C<c@cTaADHbA38f=DA5=c95@DI1ASTb
ATH`=T8`=C0b=dDg=SHe@DE5@d=2@c4hAT<e3CU6AS@e@SHg@CTb<DI4<CHe@TDc
AT@c=T91@S16=dA4=d=4>3I5>DHh=C<c@S93@SQ5=cU1<S91=d=2<0di<SA4=d4d
@T91<S<i=S<e@CDc<CPhAT52>3He@CDe=DHc<S@b<3TaASI2<3Tg<TDe=cE1A3<i
=D91=DH=>C<h<cTcAT<h>C<e<4A4=3<g@SQ1<S<fAS0d<c4i<48i@D8h84i43BmH
<SLP83<`8594838dAD=2A30e<dE2=SM5<c<f@D4d=c4d=SQ2ATDh>4E3AS@g>D4f
=T@g<c0g<CHd=3Q1<c4a=4Hg>C95=B1>A0d_F38h820a<3DPDT@P<SA5@d94<3Dc
AD8i=d91ASA5@CHg@TI1=D8b@SLf>CHd@TDc<3<i<CTc=44cASPh@CU6ASTc=3Ld
=3Db3C8b<CHi<3Li@CLe@cE6=CQ5<TI3=DI6@T51<4@b@C@d=3A6=cHaATA4A4Dc
=DI2ATDi<TA3=SHgA3Ha@Pde=4I4=CHd<d92=cA1ASLc@T8g>4A2<DI2<c=6=T8a
=T53>316=351<CHh=S8`<C4`A355A3=2@CE5>4@==CPh=351=3Hd<S4`>3M5@cA3
ASTc@CDc<D<`@cLf84i43BmH<STP834`=21BA20b=4E3@T@`=C=5@STg@T56=4E1
=S@h<c<b<c@`@dE2=4Hi<cM2<30`ATHg<cDa=THa<CA6<3P`@cQ3A3L=A4@a>315
>44`@d8b=C4`=C4`<CDi=3A1=DHi<T@`=S96>CE2=cLd>396=4A1AC12@SU1@DDd
@DD`@SPi3C4i<cTc@SI2<S8g@T8h@cTd@S16<454<4@d>4@e@d=4>D<`@c0c>30i
<D@aA395=SQ3<DHhA3E5<CQ3<Pdh=cPiA4A1<3M5=d<`<c0b@D8dA44b<cDh=S92
84i43BmH<T4P83La8594838dAD=2A30e<dE2>D8hA4I3AS<f=D=5A3Tf>4E4ACDc
A48d<c56<T4i<d<b<CHa>DDf<CDb<48c>3Da@`e4@S=2<cA3>CI2>3Pc<C<bACA3
>DA6AD@a=3@b@SLe<SM5<C@h@C51AS<dA3<i<C51=C=5=c15<3@h<cD=AT=2<4Ha
=3I3=d@gAS0e=STi@T4g@R1>A0d_F392820d>B1BA20b=4E3@T@`=C=5@SPg=C=3
@CA4=THgADA4@CU4AS13<dHbA3I3=C<h<C13<C53=S8f=cDb<C92@cA4<3<==T<f
<S15<c<a<3Hi=48i@S@b<DHh@S=6>4@a<CPg@T52<44fA3@PCT@=;ePb@b0P=c0P
DT@P<SA5@d94<3DcAD8f=dDc<cI1@C@f=3I2<cQ3<cQ1<cHc=C14@d=6ASM5ASE4
=cU4=THa<C=1@TH`=4<h3C54=d=2A4Hg@cL`@d93AT@h<S96AT<e=SU3=34hAT<d
>392=SL`ACI4=cHg<cLcAD<a<TI4@TH`>CU3<Pde@CU3<c95=dI3=c4e=S4b>48e
@b1>A0d_F394820b=R1BA20b=4E3@T@`=C=5@STb=dE2ASLbA4A2>454@D4i>4<c
<c8c<c4d=4DeA4@fA3<c>4I4=THf84i43BmH<TDP838g8594838dAD=2A30e<dE2
=SM5<c<f@D4d=c4f=c4i=cTg@CM1@S=4A4<eA3E5=CTc@D4g=c91A4E6@R1>A0d_
F396820c<21BA20b=4E3@T@`=C=5@STh=SQ3@C@iADE6<d=5<cTa<4<d<3Lc>391
A491>38f<DHe<SQ1=dI6=44fA4=2>3LPCT@=;ePc<20P<C<e8594838dAD=2A30e
<dE2>3Le<d=1=4@fASP`AT8a>3PbA3Lh=c8b>CPh=c=2=DE6@cPa<TI6@d8g=CDg
<SM3=Pe1<S4h@c0f<48a<cTeADD`>3M3AD4d<C0eAS=4=c@a>44`>3TgA392<C4f
@cI3>3<d=4HeASHe@DDg=c0=AC93@S14<d@b>3U6ASE2AD<a<S4f>C<b=SQ1>C<a
ASE5>4I4>3U4A3TeA44gA44eA4@`<SI1=D=6@S913D94<3I3A3LcACDgACHhASHb
ASPf<CTb<3@a>C12>3Pa@c8b=3I5@dI4@CU3=4<e<3A1=T8b<D=6=3<h<@di@CI2
<C8g=SM3<T8`AC<a<D<e<T<bASU1>D8c<cPPCT@=;ePc<B0P<cDPDT@P<SA5@d94
<3DcAD8h=cDc@d4dA3I6>396>3Di=S@g@cPa=3Pc>48hAC@i<SLe<3HaA4A6AS<g
<SI2=3Li3C55AC<g=T54<S@PCT@=;ePc<R0P<CDh8594838dAD=2A30e<dE2>3Le
<d=1=4@fAD@a>DDi<cHbA3Te>CD`<DE1=cLf@TD`AD52<C@h<CPbAC<a@D=5<0e1
@C8b@SI1<TI5@SL`@CPdAC51AT8a=4@fA3Q6@T@h@SDh=C52A3Ha@dA5<cP`=D<d
<d@b=DA4<3M2<3P==311>38e@CPi@d4fACU5@S<`>C0`<S0h=4Hh@DA2>C@h=4E6
A495=cA2A4I4<c4h=C=1=dI2<c92<CA63C8iACHi<cE1<c8cA34i<d4fAS0eASLf
=C12=C96A3Th@T94=C<f@S4f@SE5<cLc=3Ld>D<`=3HeAC94=`e5<3<i@d<h<dE2
>3LfACPi<cLd@cM2=SDfACLb<354@S16<CHc<SHc<3Le=4E2AT4eATDf=4I3>34h
=S@=<D8h=d8c<T@h>D@e@cTbAB1>A0d_F3<c820b<c4PDT@P<SA5@d94<3DcAD8h
=cDc@d4dA3I6>492>4DbA3Ld@S@`<S11=3PeAD92<T=5=T<g<SPa@dE4<C95ASDc
3DA3<SHgACPd@CLi>CTh<C8i<4@b@C51<dI6<c13<CA3=44h>C8e<CA4>CI4>3@g
<cTf=S<b=c15@THg@Pdg<dH`>3A6>D8`=4<c<3<g=T4gAT96=THeA4D`=TA5@cTc
=3PeACDhA48`A3Lh=TE4>48d<c4`>D=3<4H=<4De<4<`A3Hc<D@`@S54<C15@S@g
ACI1=3E1=TE4ATDdASI4@TDdACHf=34i@dA4<4I1@C0bA4Dg<4<`3CPi=dA4=38f
@cLc<SE4@C=3=C12@SU3=3M1>4<iACU6ADH`ASDe<c=5@DHi>C0g>C<i>4Hh=D4e
=CE5=@de@cLf=D@c=SU3=cLf>44d<SA6@cHc@S96=D=2@cLa>3Lg@DDc@c0a>4E2
>C14A4<d<44i<D8b<3Ta=CL==STh=d=5ATDf=CDg@T54A44`<3@c=c8c@C55@CTd
@S4b<c55=48eATD`=cHb<SHi<dH`=d4cAT=6<cL`3DA2@CTcACDc=S4i<DA3=S94
=T51ACM1@cHg=SHc<d94AC@`A4Hd=C8g<b1>A0d_F3<d820f<21BA20b=4E3@T@`
=C=5@SPg=C=3@CA4=THg>4Hg=dD`AD=6A4Hb@TA3<C4f>CLf@SH`@SQ6=d<b<d8f
=455<d4=A3Pg=S93A3E4ASLa@CLc@d<f<cE1=C@b<C11A311<d<iA4=3<S8c=4=1
=S51AT8`AS16@C94@C12@cDf84i43BmH<cDP834c<R1BA20b=4E3@T@`=C=5@SPg
=C=3@CA4=THh@cI1A4A5=d<i<4=3@cI1AD@fATHb<C=4<CQ6=c<d=DA5>D8i<SD=
=SPh=SHi<TI5<S@d@TDd<SHh=3U6AD53>3I2=d@b@cA6<T4c=44b<S8b=d4hAS0i
<S@b=T@a<CU6<D=13D<b=C16<c51>313A44`AS0aAD93ACM3>4I1ADE3>CDeACE4
=S@i@cTd<CLe>C@d>4He<CQ3@SE1ACHa<@df<c54=cM3=cQ1@C<h<cA1=SPi@S14
=S@h<c=4=4Dg<3Pf@SHh=T8f@cM1<c4b@dI3=3=4=CLf=4I3ADD==c<i>4E3ATI2
@d<h>CPf<C91@SQ2@D@c84i43BmH<cHP838c=R1BA20b=4E3@T@`=C=5@SPg=C=3
@CA4=THh@CHg<48a@D8g<4Ha@c=4<4=4=34i<CQ4>3M1@cLe@T52>316>3@==S0`
<34eAT@h>D<`<cQ1>492<c@`<CHgASPa<D<c=3E2=T54@C0i=TE1<cTcACTcA3A2
AC93<d8h=3I13DE2AS4d<4I2ASA5>C@`<c0g@T<f=353<DE2=T4h>3E6=34i=THa
<CU1A3<h<3E1A3M2@S0i<34i=34eA@e1=cThA48f@cM4<CPb@T4d@dHh=4Hd<S96
=S93=3Da>34e<dA5=DI6<D8hAS<g<SHi<D8`=cA1@S8c=3T=<cLf<3Lf@dE6=C8`
>4I1A494@T4b=3Pd@cM2A4<e<4@d=SLf>352>3@aAS91=c15AC15A3Tc>CU6=4Di
3CL`@c8iASE1AC@i=D@g=CHh>D4`A4Da=dHc=4He@d8d<SDc<S@g>CHf<3=4ADE2
ASU4@C@f=4=4=T@b@`diAS15=cM6=SDgASM4@CA5<D92ACU3AS53AS<a=THe>CPb
<D=5<CM5@d@e<dE4>3Lb@CTdAS0a@cE4=44==DH`@C=4<44f@TE6=cH`<S@cA395
<3I4=30iA34`=CM2@TA1>DI4A3Tf@D53<SQ4<d=3>21>A0d_F3<g820h=R1BA20b
=4E3@T@`=C=5@SPg=C=3@CA4=THh=44dACLfA4D`@d4a@C8d<S@bASTeA3Da<C@d
ASL`=DH`<CLa<T8=@SU2>4Dd@c@`=3E4=DHi=cU5>38hA4I2@C4c>CM5@SI1>DA6
AC<a@CPi=T8gASPb=S4a<d=1>3=4<C533D@d>CTi>CI3AC8dAS4g>493=CTa>3U3
<c4d<dDe@S0e>4A3A4<eA48i@dE6>CH`@cLe<CDPCT@=;ePc>20P<c0e8594838d
AD=2A30e<dE2>3Le<d=1=4@fASLdAC16>3Th@T@a<30h<3A5>CA1ACHc=c8b>D@`
=S=2@TDi>CTeA@db=SDhACTb=CA3=T@i@S0h<CPd@SA2@c0d=c=3>D@e<4<`>4<a
<dI5<3LaA492A3=6@c4a>CHh@C@bAC0=<30cAS16@TI3<DA3=cQ3AC<`>DHeACTc
ASTh@CU5=CE6<S<e@D8b=4A3AS@f<c95=S8i@D<h=D=5AC<`3CE2<c<fA3U2@cTc
<4@g<S<cA48e=4H`@D<f<c52=cT`AC=1AT56@S=6@c@`@dE6<34d<S@cA3U5@C54
A@daAC@a<3<b>3La=THi@D<e@cLb>3Dh<T8i>C@g>3U3@C8f<CLe<DDiAC56>316
<d<`<D55>48f@SLg=SH=@T<g<c<g@cI6@cQ2<C0b@cU2=3Dc=CE4@T<gAS0c=cQ6
=T4g<S4i<cM3<THa@dA2@CLf<SDd=CHf=CU63C8h@c<b@cLb<D51>3E3ASDeASU1
ACQ2@d<d<CHaAT4d>3H`<C53=S=5<3@e>CQ5<SQ3AS<h=38a<34gA@dg@c0g>D54
@C4f<495AS=3>3HbAC=4<D<`AS54<cPh=4A3=SHa=TE2<30h>4=2<S@fAC4f@c4e
>4Dd@ST=ADDa=D54=CE5=3Pc>CDf>3<`AS8i=3M5A4=6AT8i=dH`>CPhASD`=C=4
ACQ2ADA1<c0g<492@CPb@cI53C4`A4A6@dDaA4Db>3<d=D4iA34gA3@i<CPe<T55
@S=4ASI4<cD`ATDfAD@h@CM4=3@g<DE5=CA6<3La>@dd=SLd>D=1@SDd84i43BmH
<cTP838c=R1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THg=S@dA391@SA2@SPi=cM2
AC94=T<hASQ5<3Dd@CU3@cTc@cHi<D@=>CM2<3Ha=SLe@CHh<D@eA314<CE5=c4g
>D=2>3Pe=d=5AT8d=d<f<TE5ACDi=S<i@S@i=c<cA4<h@D<`3CHg@SLh>CLc=CU3
ASTd=S<c>D@iADI1=CQ6=c@`=d4dASA2=c8f=44c=SI6@d=3=cU3A3@iA48e>3Pc
@`de@cDbA3<i<3@d<c16<3E5<cL`@d<e=34gAT=1AC=1@SP`@c4g<C8a>3Ld>351
@C@f<C<f>38i<4E4=S@=<C93A454<3P`=S<h@CU4<cA3=D4aAS94=S0g>3Ta<3<f
@dDf>3E5<dHdAT8f<TI5A4Dd@S16ATI4=CQ63C4f@SA6=cQ4<48e<S=2<T8a<SD`
=391>CU5=SM4=SLfACU4=cQ4<34g<c8a>CM4@CU3AD@e<C96=S4hAPe4=c<`<T<`
@dA6@C<iAC=2=d<h<T<`<44h<S<f=STfA3TgA4A4@S0`>3=4<38h<C8`A3Dc<S<f
=3LbASP=>4<aADI2>D8c<c=6AD8a@cLf=cTb<T@dASLf<S<e=cHb=C8aATHb>44a
=CDa@D53@dA3=21>A0d_F3=1820d<b1BA20b=4E3@T@`=C=5@SHgAC<c=T51=3La
=SLa>CLi=d4g@D8cA4A3=D@eACDi<d51=cLb@DA5<4@a=C@c@c0=AS53<T4`A3Q5
=C@g@SDhAS<a<30`@dE4=cLPCT@=;ePc@R0P>3PPDT@P<SA5@d94<3DcAD8f=dDc
<cI1@C@f=3I2<cQ3<cQ1<cHc=C14@d=6ASM5ASE4=cU4=THa<C=1@TH`=4<h3C54
=d=2A4Hg@cL`@d93AT@h<S96AT<e=SU3=34hAT<d>392=SL`ACI4=cHg<cLcAD<a
<TI4@TH`>CU3<Pde@CU3<c95=dI3=c4e=S4b>491=CE2ASLd>DA5<C8e<CTf=3A2
<CPeASLe<CU6@T@fA4Dd=S<d@B1>A0d_F3=3820d<B1BA20b=4E3@T@`=C=5@SPg
=C=3@CA4=THgADA4=DI2@STa<C4g<C4a>CH`=C0c@SPi<DHe=T54A3LeAS4b>C0=
<c0a@T4f>CI4=CM5AS4`<S95>D<eAR1>A0d_F3=4820d<B1BA20b=4E3@T@`=C=5
@SPg=C=3@CA4=THgADA4=CD`A4Hi>C56=cLc=T@i=S8h<cE5@CTe<S8`=S0f<30`
A3H=<3Pc=d91>D52<cPh<T4i=T=2=C4a@B1>A0d_F3=5820c>21BA20b=4E3@T@`
=C=5@SPg=C=3@CA4=T<g=d@`>34f<3DbACA6>30b>D<e=3L`>DI3@d4g@ST`=4A3
AC<eA3D=@c56=c96<SU1>C8bA34a=R1>A0d_F3=6820a=c<PDT@P<SA5@d94<3Dc
AD8iAC@d<34b=CLiA4=5>DHfACI5A4Dg>44e=TDaAS<c<T<d=T4bA4I2<3A4A4Hg
=T513C54<TI3A493<C@g<38i=DHi<SP`=c4a@DI4<3M1@DD`@CA2ADDfAC4i<cTf
<SU1>C@eAD52<DE5<cLe>@da@D4g<C4c=3Lh=cE3ASDbAD@`ASE1<3M5@TE2=DE4
@cLa@SDe@THe>354AS4dA4HeAS@c@S0h<T4b<SL=ASA3@CI3<CHg@d<i=CM4AC96
<3Ha<3I6>C8b@cA2@S<h@CM2=D<e=dDf<30g=CA5>4@`@C@g=353@THi3C4d<4A6
ASE5<T8b=SI5@T@fA3Q4<c=1@D=5@c92=cU5=d55<d4eA4@`<DI6>CI4@STd<S<i
@C=3@T@f>@e3<c@a<S14@C0d>4DiA4E5<SU2=cQ4@C0cA4@bA3TcASTfA3A3@SPd
=4HfAC0`84i43BmH=30P83<d>B1BA20b=4E3@T@`=C=5@SQ1<D4a@C52>CE6<D8`
=C0i>3I3A44`<C15@cLd=3Dc>D4hAT8d<dHc>D4h<DA1@T4=<SA6ATA3=316@CI4
>3Hc>3Hd=4HbAD@c<SHhASM5@C<b=DE4<c0f<d8i@SI5=30`=CU2<dD`@T<h@c@i
3CHf@CTh<d@iA4A5>44a<SPa<cDc>D4`@SU2<3E2ACPg<TDc=4E6=SQ4>4Dc<S96
AS<eAC92>351<3M2APe6<c@a=4@f@D8f@cLgACQ1<S4h>CA1=d@gA3@a=D93=SE2
=30`ACHb>DDd>CM6<TDd<SI4ACE6=d@h=4D=>4I5=C<hAT4`@c4e=3E6@CDa<38d
=c96@DA2ATDh=cI2>3Lf=CHhATH`<3Pd<d8e<3Te<c92>CM6>DA43DA5<S<c=TDf
AT<i=d<bA3E1=c13<cHc<S4iA3@`<cLe@C4iA4E1>C@e=cE5@S8f=3=1A48`<d8e
A44f<0db@SQ6A3<b<dH`AD93<3U2@D4c=3LeA4=3<cP`>3Hh<cM1=dE5=D<d@SQ2
=4Hc@T4i@S=6<cThA391@ST=>D4f@SHa>D55ADE1<SLb=d<g@D4gAD93@T=6<D=5
=d<i@c8`=dE4@dHg<3Pg>D@e@dHi@D@e<30h=DHd3DI3<cM6@D8d=d<b>3Q2ASQ1
AC55ACTc=d@d@CL`@cH`<3HgA4E3@SM5@SI1<C14AS@h=CTb@d4b@c@`=`e6<SHc
A44a>D8e<3Hf<3I1<44g@C8hAS@bA4@bADI1=D<`AD94<c=4<c0i<453=4Dd@T<h
@SHgAD94@CP=@T<b<3=2>4I1=cI1=cDb=THc=DD`>4He=38d@STg>D4c=c4cADHi
<DE5@STb=d8a>C8dACU1@D@dADE23D94=3D`@C95>3HdAC<h=4<h=3@c=CM6=C=6
A3Df=dDd=cPa@C1384i43BmH=34P83H`8594838dAD=2A30e<dE2>3<a=C4i<DE6
<3Ta<cDeACHc<CU4<dHi<C4`=CHa@dDd@C92ASPfASLgA3La@S51<`d00:40`3oo
>C=6=DDa=4E4=T<g@c=3=d<b<SU1<cM6A4Dc=3Lh@S=3@S93<C0gATHc=c91=D<d
<cHc>38a<S0c=SHe84i43BmH=38P834i<B1BA20b=4E3@T@`=C=5@SPd@CPh<3<h
=3M1ASI1<C4f=SH`ASM1=3Pf=CM5@SPb@S8`=C51ACDa=SM4@C96@C8=<d=6A44h
A4Df=C4i@SI3<D4i>3Te<C53=CM5@d4b=THg>C@gAT8g@c8gAD96=CLg>4Hi<S93
=C15=CPb3D<hA3Pa=cPh=SQ1<C8`@C<iAS4h<d8f<S53>3Hd=4I2=TDi@C51<3Pf
>C55@CTa<T<e<cU6<cE4>CQ2>@d`=D8f=S11=T91<c@c=3Ld@CTi=d92>CM3@d95
=cLcAS<i>3Ph<SHe@DA5>355A3Td=cLf<3Hf@CDa<S0=<D@`AS8b=THf<cQ4@CDg
A3Q3>4I4=C4e>CI3=TE5=d8c<d@d@CLaA351@cA5@c8f<C=5AC0i>4I6=4@i3CT`
AD4i@d=1@d<b<SM5=D<b<3Td<3TiAC=2<D@i=cM3<C12=3A1@cLc<TI1ASM6<SDc
=dHb@TI4@c=3A0db<c8e>CHi>C@e>3A1>4I3AT4a<c<e84i43BmH=3<P834f=21B
A20b=4E3@T@`=C=5@SPd=CL`@C8`>DHfAD8gACPe<3Li=4A2A48h<d92<c8aADA6
A3Ph@c@eAS4`<dE1AD@=<TA1<S12<cDe>38`=SHi>44e=d<e@S<`AD@h@S=3=T4g
>D8`@T4c<cHd@cHcAS4c>3<eACHa>4Db<CPb3CL`ASE4>D8c<4E6=cA5AT@g<cE2
A393AT8f>3<e<T4eA4@f>394<311AT4i=4I5ACA1<CPeASA5>D93<Pe1=DHaA4Ha
>C53<353<D@e=T=4ASM6A3Q1=c8d=dE1<3<c<dHhAD4d=3Dc@CPdAS<`ACHe=CLh
@C8h=TH==T@c=CTh=DHh>3<d@CU2>4I2@TDb>DDi>3@c<CDh@SU3<THc@DDa@S0c
>3I5@SLh=dA2>4@h>DA2=d@b3DE4=c<iA312ASQ3<3Ta>38hAC=4ATI1<c4bASHP
CT@=;ePd=20P<C8`8594838dAD=2A30e<dE2>312@SDe@DI2>3@e>C@eA4@e=cU2
@S4c=4<a<TH`<C95<356=cHaAT51=cTf<SA6@@de@DHd>44h<DE5@c8hAC8`<DHc
<D55ASM2=3LgAD95@cTg<d<c=394=SHf>396<3Q5=C<bASTe@dA2>D8=@SDgACLa
@d@h=cTi@SPeA3=2<CHa>CM5=DA6AT4`<S96<c@a@D8a<cTh>353>D<b<d<bASQ6
@CM4A4Hb3C52ACQ5=S0eAC<iACI2=S8f=c4g<3@g@SPg@SDd<cHg=cLaA3E4ATDa
ADDaA44a=SHhA3<h>391A4E6@R1>A0d_F3@e820d=b1BA20b=4E3@T@`=C=5@SU6
@d51<3La=CA6>D92<314>DDa@SA3<4=4<T@f<34dA4Hd<d@i<d<`AS<a@dHd<S8=
A492<3Pb<C8c@CL`<3Ph=dE6ADDaASHdADHe<T91>D@`@R1>A0d_F3@f820d<B1B
A20b=4E3@T@`=C=5@STi=CTd<SDi=34f@cA1=c16AS@dACA1<S91=DE6<c14@CM2
=T54A48f<STc@S<e<4@=<cH`ASD`>4=5A4Dc=cHb>C54=312=B1>A0d_F3@g820a
=S8PDT@P<SA5@d94<3DcAD8h=T=5<S4g<D51>C=1=CLe<D@a=STb=cHh@SDg@T8b
<4Hc<392<3HhAD@i=c4i<3Te3C=4<C4e<THhAS94>C0i=S4g>3A5@T4b=SHf@CHb
<TDe=3=4=C4gAD4g=c4fA48c@cHb>CHa=S=3<c@e@@diA3Hh@S8fA454>48g<4<h
=4@d=S0hA48eAT95=D8d=DE3@c0h<CPd>CH`<C<g<3Pe@C@f<TH`ASPd>D<=<d53
@D@f<SM1@C4`@SA5@S@h<cDd>C@iASU5@C=4=S8`=c8h@THc@c4g>D@g=38h<cDc
=cP`@SLc=30`3CU3=cQ4>3Hi@SE3>4Hc<dDg@CTcASPa>CA6A30i=3Lb<c4`<SPi
>38f=cI6=3I1A3PhA3@eA4I6=S<i@Pdi>3M4<392>CHi>CQ6@T@i<30i@T<f=T@P
CT@=;ePd>20P=3LPDT@P<SA5@d94<3DcAD8h<DI4=3I2<3Dg=D@h=3LgA3<gA3<e
A3<hA30e=352=CU6AC0g<C96<S95A3Ha>D913C0b<T4c<CLg=3<d<C@a@STa<44d
=cA3ASM2=CI4=cHcAC@PCT@=;ePd>B0P<SDPDT@P<SA5@d94<3DcAD8f<d8c=CU5
AC@d<3<`@STh@CLa<4Ha<3M2@cHh@C<fAC8`AD4e>C8PCT@=;ePd@B0P<C0g8594
838dAD=2A30e<dE2>D4hACI3>4I5AS4f=c=2<T<`=DDe<c<i@S<dA4<b@S4g<c@e
<dA5@CL`=c95>455>@dcAD<d<4A1ADHbAS@c@C@g@cTb<48h=cPhASHc=c0`@T@c
>D@f<cLg=d8i=S<h<30g=SDd=c<e=393=48=>44d<SA3=dDc@D<`=4@c=cQ6<D8b
@dI5=3<h=d94ACT`=dDiATE6<SDe@THd=cM5=DDb<T53>D8i<c<`3CA1@T<`@D<`
>D@d<C94=TDg<S=4ASM3=dDa>4<`>4@b<D@PCT@=;ePd@R0P=C@PDT@P<SA5@d94
<3DcAD8h=c56=CLi@C52<S=1@SE1@C8e<DHh@CPg>D8h<TDfAC8g<C8e@S0i=C@d
ATI1A3<i3CA6=d=1@D@a<4A2<3Pf<SU3@S<d>CA1>496ACL`<C4h<3A2AS4c@SA4
@D94@S92<b1>A0d_F3A3820c<21BA20b=4E3@T@`=C=5@SU6<cHh=T@d=cPf=SDe
=SHg=4@iAC4d=dI3<C54=SDh<4<f>D@eAS0f@CM5<44h<C@PCT@=;ePdA20P=cLP
DT@P<SA5@d94<3DcAD8hAS96<C13<CHg<DI1=c91AC92=4@i@SM3<cTaAC<h=c=4
>44b<3I1A3Pg=34g@CI63C0a@T<fATA6@C@g<d<a=T51AS<h=cTdA3Ld@SHe<dE3
AD<cASA1A4Db<3Hf=DE3=d4g=dDa<SPc@SLe@`daADHc@cHe=D95=c<b>3H`=S4c
@T4g>D8`<30i<C<i<CT`84i43BmH=4DP83Dg8594838dAD=2A30e<dE2>30b=d8a
=C=1<SQ2<D53@T4aACA6@S@cAT4g<D@i=CL`@cQ3@T=5<dDbACHh<S0hA@db=SDa
<D95A3<e@cA6A314=cQ2<S15>44c@S@cASDf@S<gACH`>34g=S@b<c@`=D@dA3Lh
@SDPCT@=;ePdAR0P<C<e8594838dAD=2A30e<dE2>38iAC@d=48`=CU6>CE1<D@d
<DI5@c0eAD4b<T51<CU4<cA2=D4`@S=3=dDb<30a<Pe4<S53=c51>3U2@THb>C8g
>3Q3<cPb=cM6=c91=4HaADHhASD`<34eASLe<C0aADHbASU1>3Q4A30aA3T=AD51
>C55@C92AD8g<4Hb>44f<T@dACPa<C4c>353@CLi=d<f<3HhA3Lh@S0g<d4i=T4d
=DE1=3Dg<C=23D@d@S@`=492@d=5@D8b=S@d>C@e=TDc<c8i@cHa>392ADDd=TDc
@SLcAS@cAC0i@S0e<c51ADDd<d54=`deACLc<3@hAT4b<D8bAS8g<S11<C8h>C@f
>3Hc=S<PCT@=;ePe<20P<C0c8594838dAD=2A30e<dE2>DHc=SPfA3@g@C8c>C15
A316>3E3A3Hg=SQ6<3@b<T=5ADA4>48a@d4iASE3A3Da<`d`<CI2=3Q1>DDe=T<i
ACPg@d55<4I4@C<fAD54@SThASM5<c0i>3Di=d8g=3<h<C8b=c54=3Dh@c4fASP=
<CU1=4A5=CHf=3Db=CA5<30e<3Df=DDf=c4c<48f=S@b=C0g@CU1<3E2>C@c<SQ3
>CPi=c<i=TI4=3563CA3ATDd=D8a@cTg=cE3<SM3<cLa=CPa<45284i43BmH=C4P
834i<B1BA20b=4E3@T@`=C=5@SPb>DDd=3A2<3DiATDd=3E2=T@`@S0g=c=5@CPf
<d<f=4@h=CLh<dE4<THg<SHb<3D=>C<e<D4gAD4c=CLa>C=6<3E2<T8aAC=4>452
=c92A3D`A3=3>CE4=S<g<T8h<S8f=D4i=44c<cA4<c943D<i>3U2=D=3<3Lb@CLh
=d<a>CU4@STh=SLb=3@c>C8h=3Te=38g>D<e=S14<T=1<CE5@dE1=DI4>CLg<`dh
A3PhA48b=S<c<cL`>44h=316<S@`A4@fA4E6AD=3<395>D4e>CPa@D<d=38a@D96
A3A1A4@b>4Hd<d8=@S@`@dDi@dDcAT4e<dDi<T@`@SLa<cE1<c13@c@i<T96<S<d
A4I1AD56@S0g<S4f<3I4A44c>DDh<c963C<e>4A5ADE6=SI4=C0c@d8g<T<eA3Pb
AT<a>3=4@c<e>4@h>CTfA30a=3<c>3Ti>4I4=dHeAT4f<T56A0e3<T53@CI1@D53
=SU6<S<f<S=2=cLf84i43BmH=C8P834f<b1BA20b=4E3@T@`=C=5@SU4@C<`<S4d
<S<b=T@cA4=4@CU1AC<e=CA6<C0f<D@`=T8h<S0aAT4c<3Hd=D=6<cP=<3E6@TA4
=cM5@C54<TI3=T@i@DI5@SE1ASA2AC=3A3Pf<316@CLa@TI3=4H`@THb<DE3<S=6
=C4i@c4a3DA4AT=3>C<h@dDf<C8g<cHa<CLf@d51>D<i@SDb>D54@SI1=493=c4f
>C@a@c4h=c<`<3<c@D4h@T<f<0dh@C8i<SI4@SPi>CTe>DDbAT55>DA1ASPa<3M2
>44b<C=4=S91A3Pf@THa@D51<T8e@TE2<3@d@SHh<3<=<c8g@dHa=C8c<48b<cHf
@CQ2<D56=d4`<C<`AT4a>3Lc<CU2AD=4<3Lb=S91<T<b=CHb<C<gAD56@CU53D=6
<3<bA3Dh<C0g>D94@C0e<THeAD<b<dA584i43BmH=C<P838c=b1BA20b=4E3@T@`
=C=5@SU4@C<`<S4d<S0eAT@a@D=5A4Hg<4A1=4=5=SDh=3Q2<cTf@c<f>D=5<3Di
=353@S@=@d=1<CE6A3<d<4Hf>4HhATHhADHb>C0a<3M5<38i=D93>451@C<f@D=2
ASPf@cTf=SM2>3Tf<c0a=CA13C8aAS8fASTb@c0hAC55>3Tc=cHb<THe<cA1<48b
AD@g=D4`=dDi<48`=cLh@S54=SDeA48f<3M3=S53<Pe5=48i=D8c@T<c=S51<4<c
<S=5@c8b<C51=4@f<c@f<TE3ADI3A38c=3=6=d8`<C=2>311>D94=3L`>3@=<S8c
=3Q3<C53<CHi=3E4=c0g@c12<4A4>CDaAC@b=c8aACDe@CTf<CP`=3P`ACTd=cE2
>D4h=S<i@d@h3D=4A3LaAT<c=SLbACP`<T@i=D<h@dI5=C12A30h<T4c<T91ACLa
<d95>DE2<DHe@SQ3AS8d>44i<cI2@Pdh@cPh@SPeAD4f=451<cLd=T4c<cQ4=SQ1
ATHa=34gAT4b>3=3<34dADI2AT@`@T<b>4E6=c@h@T@`AS0=@D8b=C<a<STb>DA5
@DI4>D92@SE3>38`@SM3>C0i=S11=C@g=SDf=dE1=cI4@CQ2ADDg@SE684i43BmH
=C@P83<f8594838dAD=2A30e<dE2>3A5@S8d=3Db@C0`<S<a>3Dh=C0a<cTc@SD`
=c0bAT@c<c<g=c8h=cI1=dDi<CTd=Pe6>CPd<D53=391=CDPCT@=;ePe=B0P<C4f
8594838dAD=2A30e<dE2>3Le<d=1=4@f@cLi<SDc<S<eADHd<cLbA38a<44aAC=5
<3Pf=T@h@d94>C8`=C16>0dbAS12<DDfA44`=cDfAD<hAS0b@C0h<STd>3Q1A34d
AT8g@CI6@CTg=3@g@cE2<C53@DHd<D8`=c@f<C@=@T8dATDa@T56ASPf=C=1A3@h
<3E2AC11<SI3<DE1<496@c14<CPd@CU4ATE3>3E4A3LiA3M5A38`<3Df3CU2<SE3
@C94=D@b=d=1A4Hf<CLf<4Dc>D@aAC@a@d=4@CTg>C4h@CE2=D55=3Li=CE2AS<P
CT@=;ePe=R0P=3<PDT@P<SA5@d94<3DcAD8h<c4e<CTaADH`=D=2@C<d=4<bA3Tg
<3@b@C0c>C=3<S8i=c@a>311>C0h=cE1=c4h3CPa=CPa<CU4=D94<3Pb@SE4A3M6
@CPg@CI584i43BmH=CLP83Pi8594838dAD=2A30e<dE2@SPb=c56<S<i<CL`=30d
ACM2>CHh@T56@d=4=dI5>CA1<4Ha<SLaACPd<30`=cE3@Pe4=3U2<3@i=48f<TDf
=D<e=4D`<c95<D4d@DH`@d92<4A1ATE6<34f@T=5<cPa=d@b>CQ2=C<h<3Tc@c4=
@DHi<SE3<c4i<TH`>3M1<392AS15=SDc=cHi@SM2=c8b>DI3@c=4AC11<SI2>393
@T4c@S@h<cU3<R1>A0d_F3Dh820f=21BA20b=4E3@T@`=C=5@SU4ACM2<3I1>3Lf
@CDc@d8e>CDa=D94ASA5<SQ3A3Tf@SU5<D8gACPf=S@b@D=3ACL=A3I2<4A3<SU2
>C4b>C@g=CLa@c93=T8g@D8e@STd=4A5=S4d<SQ3<dHg@S@c>D4c<DDfASLa>CE3
@D553C12AC4a>3Tc84i43BmH=CTP83@h8594838dAD=2A30e<dE2>DA5=d8`=T4h
=cHe=D95<4=2@S@a=cTa=4@a<3U4ADA5>3Tf@T4`ATE2@d=3<d8e=0dh>C=2AS4c
@S0hASHh=S12>3Pd>C52@SPg@D<d@CI4=DI4=C8PCT@=;ePe@B0P=3HPDT@P<SA5
@d94<3DcAD8iAT=1@C0g<CDf=4A1<SHbAS4d<C16@dI5>3@b@D55@c<gA3T`AS8d
@c<h<CI2<T8g3D4gA48`<D8i=3Te=cPh>4@a>3<i<4@d<c@`ADE5A4=184i43BmH
=D8P83<h8594838dAD=2A30e<dE2>CM2@DHdAD4f=cA2ATHg<dA2>34c@D=3>CPc
>4<`=C4g=C51ASM1AC55=c=2@d4c<Pda@dHeA4<h@D=5>3La@c<i84i43BmH=D<P
83<a8594838dAD=2A30e<dE2>CPf>4=1=3U5ADHc@cI5>4@g>DI1<CI3>3<i=cLi
<c<dA4A2AD4eAS8b>CDg@T95<`df<B1>A0d_F3E4820c>21BA20b=4E3@T@`=C=5
@STg@T56=4E1=SHa<3Q2@C0`=TDg<c@cAC<aA3ThACHaA3<eA3Ph<c0e@CHh=4Ha
=D@=<3<f<d4`<3@e@dHe=c@iAR1>A0d_F3E5820d<B1BA20b=4E3@T@`=C=5@SPg
=C=3@CA4=THgADA4@C=5=DI6@dDh<4Hb>D8`ADE3@SM3@C4fAT96>DDa=D4`<SP=
@cHd@CM1<cP`ASH`@C8f<S8g@CI1=R1>A0d_F3E6820b=B1BA20b=4E3@T@`=C=5
@SPg=C=3@CA4=T4fAS11>3@h@S<c=THc=SU4<D4c<3Pd>D@f>C8c>21>A0d_F3H`
820c<B1BA20b=4E3@T@`=C=5@SU3@S8i=c93@S0f=SThADI1<SD`AT4f<3<`<cLf
ATE5ASPc>CE4AD56=3=3=STc>C8==cLPCT@=;ePf<B0P<S<a8594838dAD=2A30e
<dE2>CTe>C@b=CTd<d@f>CTb=c8dA3Ti@S@e@d<iA352<cLi=c0h<c@`<c4d<3=5
@SE5=Pdg<cPb<DE6<4HhAD96=D4cASDi>D8b>CE5<CQ3>CPb<3TiA48b<SLh@d8`
@dHh@SPb@CH`=CE5=T<hAC0=<S0g@C8b<D91>3A4>CQ3ASE4<TD`=3Q6>3T`AD54
@CPb@S<e<D8g<C0g=cM1<d52=3I2<c16=cLc@c=13CE1<THf<SDa=T4g=S4c@cPh
@CM3>D8f@c14@C8bA4<a=dI3AC8`<3A4>48i<S4h@SDb>CPh@THb=C55>0dd=3Hd
ACU2=d<e<C54=316<4D`@c@a<C@b>3<b=cDb@TI3>3Th>3U4<T@c=SQ6<SD`<d@c
<C8fATHh>DH=>CT`@T4i=4Hd<D8d@c<h=d8a>355=CPi=SD`<STg@d53A38d=315
ASPi=3U4=THd@TDi=4E6<38bATHe3CA1=S94=TDc=3M3A3=2=C16AS@c<T95=3U2
AC@h<d=6<CDh@D@eAT=6=S<b@CLcAT@c>496@d4`@d=6A0e2<c54@SDa=c8a@TA1
>3U5=cI5@cLe@D=3<SA3AS8e=d=2>CM6=T55@SHPCT@=;ePf<R0P<S0a8594838d
AD=2A30e<dE2>DA5=d8`=T4h=cHhA4<f=TI1@DDd=c=1=D4g<d92=DA4=CPi>3Pc
<DI1<T<a<SPc=@e2<CM6@DDc>34`@TH`<38d=38f=CE1=3A6ACA2<DHa@S0b<cI5
>3=4>38`=391@cA6=d8a@SHeA44bA3<=>CH`=d4a=3A1=THb=C53AS0eACD`@D@c
@dDc=3M4<4Hi<313=d8b<SQ3<D@f<S16ASHf>4=2@D@e@C143C8a=38`<C0i<c0h
>DDd<454<C0fA4Hi@D<d>CLhASLc>38b<d=6=d@b=STe<cDi@T92AS91=30aA3=5
=@e1=C93ASLi=C8f=d<d<3M5@TDb=D95<SDf@CTb@c4`@cTa@c<f=cI5>4H`=c53
>C@c=C0h<S<iASI3=T<=A4I2>C12=C8i<cQ4=C=6=DHiAD4e<d52=D=1>4@c=D91
=T8dA3I6<CD`@CA4>C16=4@a@SI1<SU3=3<f3CL`=D91>CQ6ASU4<394=C0cA3I1
<c93<D53<SI6A30g=dE1=S4f=S<`AR1>A0d_F3Hc820a=CDPDT@P<SA5@d94<3Dc
AD8i>D@`<44a<cHe@dHd=d@f=TDc>DA2<CLi<CU3AD<e>C15@CPe=CT`@C<e<SLe
@STh3C@h=CDb=D53@S=2=3@f<34f<TH`=CHc<3U1@d93@TE4=CQ4=CM6A4Db=S0h
=c15ADE3=S=6@d<aAD8eA@df=c92AD@c=S14@CA4=D@d=c0e<SLeA30`@C4iATI3
>CQ5=dI3<T<g=CTa>4HgA495@T<d<dI6=3=5>34==cL`=CHd=3D`A3LeA4E5@SDi
@CQ1@D<i>CPi@c55>DDc@D@d@CPa>3@f@D4i@C8aACTdA496@C<f=SA63CPcAC4a
@S16@dDc=cE2@cPgA3Hc<3Q5ACLh=c=6>D8g=3Ta@dHeA4<i>C8h@T8`@C=3>C4c
<c@cATE5=0da=cQ5@CHh<cHg84i43BmH=S@P834g<b1BA20b=4E3@T@`=C=5@SU3
=S4a<C55@D8g=3LgATA6AT4d>3<g<C54=D=1=d8a>3Hd=SDaA3@b>3=1>3Dc@C4=
AD<c<S<f<TDiAC4eASTc<4E2>3I1>3Pf<CTaACLi@c0aAT@d@S8iAS8i<dA6>4I6
<3A1<CI4@SA6AD4h3CA2<48iA44h@CE2@dA1<C8a=392=CLa=SI1<cTi<dDi<dDf
@D@d<D<i=SD`<3D`@CLb=C4cA30i=d54A@dgAC<a@S92ASQ2>3U5@D<e>CTi@C@a
A3<b=D@iA4<e=393=C8f=CA6=TDc>C54=C12A4De@S8iAS8`@CP==CA6A311<dDi
AS8`AC15>C@d>CM4>CPc@S8`<T<e>D@f>353<cHe@D8h=T<a<cU4=3Db=T@hATA1
ACPb3C4g=THfACQ1<30`@D4b=SU2@C=2<D4iADE3<3DaASDg=3=4=c0`<C0d<cU4
>3HPCT@=;ePf=B0P<CLb8594838dAD=2A30e<dE2>DI3@D4`=c4e=S@c@d55@SPc
>CPd=3Dd=SA4>3@d@S51<TE5=3DeA4HfA3=5<S@g<`dc=C8f>C=2<SD`<SHiA3Hg
=C8iAC@c@c0`<C8eA3U5=3=2=SA3ADI4<cDcADDh<T8bAC4h>3He=cQ6=d<=A3Lc
@c=5=CDfAT4d@dDb=SD`<DDb@c0e>C@d=D56<4@aA4E5=d4i=C0a>4I5@cQ4ASM3
<d95<3DgASL`3CA3AT@d@c0d<3<e>3E2>CDh<S13AC=5AST`<cTb@C0i>DI6@SI5
A44i>4HgA3I5<C14<T8d=C@`<4@h<@dh=T8aACPh>CDg=S4bAS4h=c@a=c=1<4@h
ACTc<CPd@S=2=T=4=C4iAD55AT<g=c@c=4E5=CTeA3HcAT<==cTa@DDh@CU3<c@b
A4E2<cTc>C0`<D<i>DI2=cA1A4<f=SLgAS@i@D54>D<PCT@=;ePf=R0P>3DPDT@P
<SA5@d94<3DcAD8i<c93>3I4=S95=CI5=dH`ASHd=d54@c11>3Db=4E4=d=5<dHa
@CLb<dDd<3Td@SDb3D=6=c8eAT8c>D52@S0eACU6<C=5@dDg<c52=S8a@cQ4@dDd
=CE3>CI3<D92<496@D4h<c0d=TDe@cHh@Pe4@CLe>393@cLe@SDh>494>4@i=S<b
AC4g=S<eASDf<CM2=3=1@D4f>D91=T4gATDd<B1>A0d_F3Hg820b=30PDT@P<SA5
@d94<3DcAD8iA4Dg@S0f@CPg>CE5=4E6ADDg<C4e=cA2<S<b>3Tg@c8dA3Le@T@h
@SU1=353<3M33CTb>DDc<454<D8c>34bAC8g>3Pd@STc<dE5@C0bACLg@TDi=D92
>CI6>CE6ASI1=c<f=SDd>CTiASPi@@dc@cLh<c4a<CA1@cDa<3<`>C8i>DA3@D<e
<SU1@C8h=c55<d<b>30hAS<aAT52=cHb=D4c<S@d@CDe<30==S94A3U1<dA6<4<f
=3Q3ADHc<C52<CM3>CHa<C56=38a@SHhA3Da<d<d<C8c<D4d@d=4=cI1@S@d@cA5
3D4cA3DhAD<fAS51<cDd=C0f>DH`>D<d>44b@T<f=c8iACU6@DE4@c8`=SHi>3Le
A30c@C0h<DHh<d@dAPdg<D@`@d94<cPaASPg@S=2>D<`ADHa<T93=C<b<C54<3Te
>C4b=C53<D52@cLb=d=2=THf=TA4AS8g@DD=<TDi>3Ha=44cASHc>C0bASHa@S=1
<CM3AD@i=DHb=3@c>CLd>CQ2<dD`<C0c<c0f=S15@CA2@ST`>DHc3D4a>C8d>DI4
<SPi@c=5@T4eADHc<C=3<d95>D4i<T4a=SI1@SHi>C<h<DI4>C8`=THeACM1=cQ6
<SPa=21>A0d_F3Hh820a<S0PDT@P<SA5@d94<3DcAD8iAS<f>3I4=3M1<S<`@c0b
<TE4=SQ4@d4iA3U1@S<fAC11=c92<CLf=3H`ACPiAS0e3CDf>CH`@C0f<c@b@STg
ASDg<3@h=CHf@C14=d94<d@h@C<i<4Da>44`@d@`<CPhA4A5>48i=c13>312A@de
>3TaADHb=c8i@d4aAD<`=dA1<C@gAST`@TDb=dH`=C4g>C0i<T8a<3A3@TDe<T@h
<D96=CE5>C=6@cH=A453<316<CE5=CE1ASA5=cDf<cL`=48h<CPg<SU2A30bA3=1
@D54>353@SLi=S<eADDeA4=6@T=2@cI484i43BmH=STP83<h8594838dAD=2A30e
<dE2=T<b<DDgA3I3=3U2<C0g<CTf@DI5@SPd@c=2<CTc@cTg=c0`@c4eAD4c@C@d
@TA4@`e4@cE1>CE3<cPi=c@i<T=284i43BmH=T4P83Ta8594838dAD=2A30e<dE2
=S4e>CTd=c16@C0d=cHbA3Hc@D8a=C@f=d@f<SU4ADD`=d8a<cU2@SPg<d8i=D@f
<0di=dI1>C0f<CHe=38i@D<b=454@T<e>C11AC4h=SHb@CQ6A4A5<d8cA34bA4Hd
=4DfAS8b<dE5@S@g<3L=ADHb<D4e=3E1@D4d@dDhA3A3<C@a=454AD55=3E2<TI2
<STd=3=4A34dADI4A3@c@d8d@C@iA4@`=d@c3DDd84i43BmH=T8P83Dc8594838d
AD=2A30e<dE2>CPf>4=1=3U5ADH`=C92A3I4<cTdAT53@C0cA48g=S8`>D8i=dI6
=C=4A3Db<cE5@Pe5ADA1=cDa=d<`<C=3ACHh=cI5<S=4@S@f<CTi<S@i>CDgASHc
>454=d@`>CI584i43BmH=T<P838e8594838dAD=2A30e<dE2=T<b<DDgA3I3=T@f
=d4hASDf=THe>3<c@TA3=cTf<CTa<TI1=CE484i43BmH=T@P838a<B1BA20b=4E3
@T@`=C=5@T94=c12ASDb@STa=cThAD<`AD56<cL`AD@i@dHfACQ4<48eA3<a>C52
@dE6<c8eAC0==C8c@dA4=D<`AD96<TA2A456=C94=48a>CPe<c93>C<hAT4i@T@b
@S0c<cHh=DHg=cPg=CT`@TE5<4Da3CHdAC@h@S16>CE1@S56>CHi<3Hi=d@e<TE6
>CD`AD=5>3Pe<D8e@d4e=CPd=dA1ACHe<T95@C11ACLi@@de<T8iACA6=SU3=D<h
=4@a<dHd>4DaA3Tg<c8a@S8`>C95ACI3=3Q3<CDd<S0e=dA2=CPf@D52=dDeA3L=
<SLgAT4eAD@g<C4c=SM6<d<d=C4eACI4<D4c@CTa@T4f<S0h<CPf=cHe<d<bA30c
@T52@dDg@D8`>4@g3C<d<D<`=T4`=355@dHb<c93ADHf<S52@c=5A38a=cU5<cQ5
=c0d<3E4A4A6@SDc@dI2@cHe>CTd=DI6<@e3@SHg=C@`<CH`<4I3=351=T4`A3E3
<S92<d4`=SQ2=3T`<3Tb<T4c<3LdAT8h<C8i@S=2<c0h<3@c=D@=@SHPCT@=;ePf
AB0P<C4i8594838dAD=2A30e<dE2>DHc=SPfA3@g@C8c<4<`<S95A3HiASL`>C8g
>4<h<SLf@C0`=c@c<SQ5=CE4<C54@Pda@CM3<3T`=D8d=d93=CDf@dDb@THd=CQ3
<3A5@SE2<c96<SDiA44i>D<g>CHe<SU4>3Q6=SPbACDb<c@==dA1A4E1>3I1ASA3
@CM1=4Hd<c8b@cLg=3Da<d@b=C52<S4c@CE1<SE2=3PdAS4c<S@g>4HcA3Dh<dE2
3C8d@cDh<D=1ACLd@T@d=3A2@TI6@CM4A4Da>D8iA4@bA4Hc>C@f=SM2<d92=c94
>D@h@CDh=4DfACDPCT@=;ePfAR0P<C<a8594838dAD=2A30e<dE2>DA1<c0b<C@b
<c8i<34h<cTa=cM1ACA2<315<c94>3Q6@C0e<4Hd<DE5@c8`<3PdA0da<D4d=T4b
<T<d<TDa=cTa@c<e>DDg<TI6<SDb>3Th>3E1@dHeA3Lc<STf<cI3>CTh@c13<SDg
@D<d<C0==3Lc=D8a@SLd>DI3@D4h=cTb=3=3>4=6=cPeAT4b=38d@CDb=C0i=S52
<CHa@cU2<TI2<cLaAS4c=T943CU5>3Q5@c=4=38`@DDh=C8a<c8b<d51@c@b<TI1
<C0h<4<e<d52>3@iAT=5AC@`=S<d@c4h>C0cAT8hAPdi>494<c@bASLg>3A3ATE4
>3<dASHg84i43BmH=c0P834g<b1BA20b=4E3@T@`=C=5@SU3=S4a<C55@D8h@dA4
=CPhASPg=c56>DDc>452=CLa<S4e=C0e>D91<D8g=d<`=D<==4<d>D4g=DHe=cHc
@S=5=4DdAS54A4Db=S12=CI3=SPg<dHc@THd>C@eAT<e<C=6=SPeATHhAS0b@SA6
3CP`ASU5=3DeACI6A3M1<4@`@CLc=3He<dHf<3M1@TI5@T<h=DA6<DDg@C@g<cI6
=S8h@dDiA312ACM2=`d`@c<h>D@a@d91=CTf@SPa<d<f=38e=D94>3Le>354>4=6
=T96>3Lb=d52@c@fASQ4>C=2@d54ATDh=C8=@cI5<3Dc>48e<C<e<C0h>D<c=C8i
@S@bACDb=3@a<S@dASI1@CE1AT4d>D96=396=4I2>CLb<dHd<3I63CI6=T8`=TE2
@C4h=T4h@CL`=cQ3=SHfAC=3<3E5@SHh>3@i>3HbAD4d@cI3A3LPCT@=;ePg<B0P
<CLc8594838dAD=2A30e<dE2>D<f<C4a<DE1@SLd=cM5<D<`A3E5<cU6=D<h<351
=d8g>3Df=C<d<3PgAC@i>3I6=Pe1@cA4AC0h<S12<STi>3U2=C4e<T=1<4De@CLa
AS8`@SDc@dE1=3<i<d8b<DE3@THgACTd<4I4@cI2<d4==c8f=3M6=dA2<C<d=3Hb
=d8b@THd>44e<d8bAS4f=DE6=TA2A3P`@CE5<c8c<c53<d4`=c8f=d<d@dI53CHh
>4HiAS92AS8b=3De>C8d=44c<3ThAS8i<dE1>CTi@c@`<3I5=cThAC4iA4@d<CM6
=cM1@CHiATD`@@dh@CTe<C<d<3I2@cTf<DHb@d51=S4`@c55<4A1>4Hf=d=6@cHb
<SPg@cHc@cH`<C0f<c55<cQ5AT4aADH=@CTd<3De=d@e=30`<C=2@c0b<SQ6=cP`
@d=1=D<h<C4e=D4`@cPb>3Q6<d8`<21>A0d_F3Lb820g>21BA20b=4E3@T@`=C=5
@STcACM6@dA2@STd=cPg<3=2A3U3=396ACA6>CM6<STa<CDfAS55=D94@c12=SLh
<T8==S=4@TDiA3E4AD94<TA1<dI1@c4`=c0i<44e@D96<C<c@C0`=CPb>494@SQ3
=S53<D@e=316ATI4=3Le3D55=4@d@S=6@S<f@d@a@cI1ACTi<30d@T4f<SPg@C92
>4=1<B1>A0d_F3Lc820b<CPPDT@P<SA5@d94<3DcAD8i@SU1@c<d>3P`<TDb<CT`
=c4a@SA6<D@c@d=5>396<D<aACE2<c@g=48cA3Q3AS0b3C4g=3La<d@d@C8f=DHg
AS<f>3Ta>DI2=c<b@dI3<T<d=D8f@CA2=44a<d4h>C8e<C<b=314=SHi<3D`=`dc
@C13>4Dg<TD`=T4g<4<d<T51A4Dc>C8b<d8a<4Hf>DHc<D4e=C4fAS0h=C0`=TE4
<c=3AS0f<C4fACT=<S8h<c@g<C=4@S8h=S8fACI5AC<c<CHh>D8e@CLe@DHg<S4a
<C=4<D56A4I1<4E1@C11>DA4>3Lg@cTh3CU3@SI6>CM6=4@i<S@h<44i@cQ3=dHc
AD@gACLe<355@cQ5AD<h>4A5<3Tc>CLgAD=5=396A3Q5=cE6<@df<dI3<c11<44i
=c8h=cI2>C<c@cPb@S8bA392@D<h<D8i<T8e@C0g<353<cDb<3@`ATHe@CPi<cPb
>4H=@c11<SPeAD@hAT8cAST`=c93<38aA4He@T8f<4He>D4e=4Hh<cDa=SLi=DI2
AC56<44`@cA1<dI2AS8c3CA6>CTd=S=4<dDeA3E4@d@PCT@=;ePg=20P<C0b8594
838dAD=2A30e<dE2>CHg>4Hf@d<c>38h>34d@SHg@CPc>3A4@SPf@S51=D@e=3E3
=S0a<T@`=34e=DHd@`e1<d55<C@`<3A3A44bAC8b@CU2=C55@SHa>DDh=cQ2>3Di
<SLa=T8c<4@i<C4`A4Dg=d=5<D51AC0d=dH=A3Ti=d4d=T95@CLb<CLd<cPh<CPf
=4Hd@TI2A3P`@SLg=4<dACM5@T<b<3U5<D8c=c8h<C15@c16@T553CHa=SA4@DDc
<S4a>C4e=3<`=CQ5@TE4=b1>A0d_F3Le820a<3LPDT@P<SA5@d94<3DcAD8iAS<f
>3I4=3M1A4A4<30h<3LaA4E5<3Dg<3<bATDe=CHbATE4<391AD8g<CLi=30a3D@b
AD8b>CTiA3A6=DH`A3Ti=394@d4cA495=C<e<CDe=4@iAS@h@T8fASA4>3Hf<3@i
A351=SE3<DDb@@e4ASLa<d8`AS14@SI3AT94AD96<cQ6=T8c@CLeA3M2=CE6AC93
AC53@cPc<3<b>D@aA3Lh<c=3=T@gAT4=@CPf<c0eA4A3@DI4<cLa@S=3=d8b<c15
=c4g<CI5=cDdAB1>A0d_F3Lf820d<B1BA20b=4E3@T@`=C=5@SU5<355=4Dc>3Lh
=CI4@c96AS0eAS<c=S@g<CI6@d8h=TI1=cI6>3<a=3Tg>CTe=3H=ADDh=dA1>455
<C8g@S0f<cLd@c0`<b1>A0d_F3Lg820h=B1BA20b=4E3@T@`=C=5@SQ6@CM4=D53
=D@bASPi<S<a=CI3=cLg@S8`<T8a<SHh=C0eATE1=D@dAT4g=c12=cL==dI1=D4h
=T55@cE4@cU6A4=6AT@c=d4h>CPe<C<cAD95ACE3=DHd=48h<T@iATD`@cQ4=C<i
@d4i>DDb3CDgAS=1<3Di=cQ2<S4fA452=CLa@cM1=T4f<dA1<4Di=cI1ATDe=TDb
@cU3@dDgASDi84i43BmH=cPP83Hc8594838dAD=2A30e<dE2>CQ5ASTfA4<eA3Ph
=c<`=cHd<48g<S=5>4E5A3E1@CDi<3<gAS0cACLg=dA2>4=6@`e5AS0a<T@a>C96
<d8g<C4g=SI5<cI2A4=1@cDc<DI6@C93<S@a<d8i<C@a>30e=T53>DE2@C=3>C@f
@c8=ATE4>CM484i43BmH=cTP83Ta8594838dAD=2A30e<dE2>DHh=S16@dE1=T<b
>3A1=cTf<S0d=S53>34g<CHf<T56>3Ph>3Hf<cU1=c12@d=5=`e5=44`<cHd>C@f
=D=6ASTa@S0h@CA2>C=3AD8e<D@a>D8e>3Te=STa@d<a@D@`=c<g=c0f=4Db=3=4
@S0=>D4h@d=3ASDg>CDb<C0f>CLc<SA3>3U6<T8h<c@hAD<h=D4b=S4h=TA3A34b
<T=3A4Ha>4Dc<4He>3Q43DI184i43BmH=d4P83@f8594838dAD=2A30e<dE2>CTe
>C@b=CTd<dA3A4Ha@d8i=3=6<cLcA3U1=C55<4Hh=cPh=30f<3E6AC@c>48f<Pe2
>CHbACLh<48h<c0`=3Lb@SLcAD<h@d52@D<e=3Hc>B1>A0d_F3M2820b<S0PDT@P
<SA5@d94<3DcAD8i=dI4<C4bA3E2=30iASDd=c0cATI3@cU1<cE1>3<g=D@d<3=1
=DI2@D8a<3I6=cTc3C0f>38e@DDf@CM1>DDf@SPf=TDg<T4g>3L`=cA1AD<e>CDi
<3Pf>3E1@SE4ACPi<cLe@T@d@C91=S4h@@db@cTb=SL`A3@cAC8c=T<cA3Tc<c<e
ASE3@c13<SI2AS0d=TDe<CA5<dHg<T8g>3HbATHh=SM1>3Q4=S<=A313ADA3ATE5
@S=2>CP`@D55<dDa@D=4AT8h=CDc>CI4@cPb<dDa=S4f=SDg=c=4>4Da<S96<cA4
A3Li3CTiA3@`@c8c=34c<SQ5>4<i=cE6=DE4<C@i>4@b=SU5<DHfATA4>D@f>354
>C8g@T55@CDf@SE6ACP`=0e5=3L`ACU1<d@f=34b=cI5@S12<34`ACPeA38i@SU4
@c4f@d4b<T@iADDd<48`<d94>316>3Le=S4b=d<=@S@c@S8h=38`=38eAS0g<C0g
<dE6=3Pb=T8cAC0g<SE6AS8f<c53<D<i<C@d=SDi@DDb>3<c>30g@SH`3DE1ASHg
=S4i<392>D52>3Q4<TDb84i43BmH=d<P838e8594838dAD=2A30e<dE2=S<gAS<f
@SI6=c0c<SM2@T8dAS0i<TA6A3PgAD96>CM4AT8h=CI584i43BmH=d@P838b<B1B
A20b=4E3@T@`=C=5@STgAT@a<C94=D8b>C=5<CD`>3Hd>3Dg=SU3=S<g<3M1A3Dd
AT8f=CHi=C8e@CTg>4<=<TD`<C54@cPi>CQ6<D<g<DDhA38`=cTfA4HhA34i@S0c
<d<d@CQ6ACDc>3Le<cM4=3E6=T<e>3PdAC913DA5@S94=3E5@S11=S<`<SE4<T8d
AT<g<d=4=CI1<S4f>3<e<S<dA3<h<D<g<dE2=T=4<C<hACTf=TA2@`e3<30d<D=1
>CI5=cM3=SM1ADDi=d<e<CDf@CDh=TDf=D8eASQ1=cM4AS@g<3T`@D@c<cHf<CE1
A44i@D@==cA5<S54ADE3<391<3U5>C92>314<dDgAC=5@SHi=D8f<3M4@c=6<454
<C15@C0i>C0i<DHh=3Tb=cE13CI5A4E1>3Q3AT=5=SI5@S8a>30fAS<d=c0e=cI4
AC<dA30g=3I3AD@c<dHe@SPi=C<bADI6AT8dAC<`<`e6>3@`=cM5=d=4=4A5A38h
<SE4<cI6<SI2@D@`=d=5=cDh@d<h@TDf<d@f=D4e@SPgATD`<c=2@CPc<T<=<DE6
>CLaA3L`>3M6<STb<d=1A3De<B1>A0d_F3M5820a<cTPDT@P<SA5@d94<3DcAD8h
=cDc@d4dA3I3=cU3@S0bACTb>312@c8cAT@`=TH`@THdACPe<315<48bAD<i=D94
3C<f=3@a>3=4<CI1AS54<3M2<d4b<CQ5<D4iAD4d<T<aAS93AS=1>CM2=3M5AS<g
>4Hh<TA4<SM2>C8d<@dhAS<a<DI3@D@i>D<e@c@`=TE3@DI4=492=3U3@c8g@C8f
<S52A395A3Td<3I2@dHi=TA3=C0`<c8a>C<=<313<3A6<d@aAC4fAS53AS0h@T<c
<4Dc<4<e@S@cACPcA4Db@S8c=c<g=T95<dA6=dDa=c52@SDb=38b3C@gAS=5<T56
=C4h<D@e<DH`A3Lh=d=3ACE5=4<d@CHf<c@e@d@`84i43BmH=dHP834b8594838d
AD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F3P`820h=B1BA20b=4E3@T@`=C=5
@SPc<CDa>C55AS0i<C<e=DDf<c4iA3=6>C4a<3Df<D=5=44b@THh=THg=d@g<D8a
@C<=>C=6=DDa=4E4=T<g@c=3=d<b<SU1<cM6A4Dc=3Lh@S=3@S93<C0gATHc=c91
=D<d<cHc>38a<S0c=TI13C=6@S<`=cDa@c0f>DHb<S=2>C=3=STi<S<`<3@i@C8i
=SQ6=S8b=d8i<T<g=4<d=cA584i43BmH>34P834g=b1BA20b=4E3@T@`=C=5@SPc
<CDa>C55AS12=d=2@cHh<S@gA3A5<D@c<CPh>CDi>D=3<3A6<dDi<c=2AC@d=c@=
<c93=D=5=T=5=TI4<C8dASHe=4I6@S0e@d55<3<a>DHe=4I4<316=SI1<d94=3@e
=CU1AS16<3Pi=T943CLiA48c@T8f@DI2>D96<391<48dACPc@d@b=48e>CM1<T8g
=395@dI1<SHdA3LaAC=5=SHh>DHa<3@a=@d`>D56<D<bAT4c@C@d@D4`=cLg<3M4
@D<hATHh@cU5<SQ2>455=cHe<3D`<CM3=S96>3<d<T91<CHh<48=AT4`=c4d=4@c
=DI5AD<`>38a>4@c>4I6@DDa<cPb=355=d<`@cE2<T96<44e<3U5=3A2ACA3>30h
@SHb3CDdA3I1@C0g@STa<S8c<CPh@CM2@TDb=dH`ACHcAD@f<dI6=c8f=S<dAC51
<C@h@CU1=TH`@R1>A0d_F3Pb820b=3HPDT@P<SA5@d94<3DcAD8h=3Dg<44b<3U6
>C12AS=2<D@`=d=2=C@b=c<c<4Hb>3@b@T56=c0`ATDiATA2=c163C0gA455=D4`
ACTh=C11<T8i<S8h<DHd>CDc<CTf@SU1=c91@cM3=SI5=48c@CHc=dE1A3DgATDf
ATDa=@da=3HhA48h<c0h=CE4=c0iAS<f<3Hg=cPg@d=2<C@d@CM1<D<a>3I4A38d
@SE3=SH`<D56<S93=D56<dD=@cT`=4He=C4f<DE5ASD`=cU1<c8aACM1@DE4>3U5
@T@f<DHaAT4c<c8`<c16=CLa@D<i<48e<SHf@SPi3CU4A4@g@dHd<dE5<C15>CTf
>CTa<d52A3La>CPa<TA6>3<fAT<g@T53@SD`<4D`<T8`=CE3@DHb<D@d@Pe5=CPg
<3=2@S@h@TDa<D94=S0b=S8d@TE4@TE3<CA2@SPe<3I6=CDe=4Hf@C4c<C<e>CA4
<D<f<c93=c4==4Hi<3=4A48c@S0e@DA4=SU5>CA5<d8c<S0f=T=4@CPc<SPd=S96
<S<a>3Ld@CLf<3Td@cPb<C8`=C@f3D@f=C@f@SQ5@SQ5>4Hc=S@i>DE4=SE3=d92
A315ADDd@DI3AC52<SThA3M1@S0d=THd=C@`<cD`=CE2<Pe5@CA4=3<f<DH`AD@P
CT@=;ePh<b0P=SLPDT@P<SA5@d94<3DcAD8iAT=1@C0g<CDdASU2@S0`A3U5<D8d
@c13A394=S0a=4A6=3=4>C=3<4Hc<D=6=38b3DA2@S0h<S4b<d4g<30h>3M5ATE5
<DHf=4E6=C92@CU4AS8e@SA6>3Pc@C13@cPa=CE6@DHe<30e@D4g@@e2<44f=SLg
@dA5@C0d<21>A0d_F3Pd820a=SLPDT@P<SA5@d94<3DcAD8h<38g@S4e<d4b>48a
@D=2@C55=4I2=3=6@CLaA3Te=c13>4=2@dDcAC95=SPb<3Q53C8f=C4a@TE4<cE3
=4I4<4@g>48b<4Dh@C=2=3=6=CI2<cM5=S0h<CLf=38c=30eA3A4=cPd@c@a@C0i
>0dhAC<g@cU5=SDc=4=1>CPh@SQ2@SQ5<T<i<THb@S@a<cTc=cLe<T52=353>C91
=3De<T4a@cDf=3M2@ST==C4i=d91@dI1=4HaAD4b@c@bA4<h<DHcAC0a<T8d@cT`
<dHg@c@g>48h>C=4>CE1=TE6ADHi@CPf@C4f3C<hA4@iATA5ASTa<DDc=dE6ACP`
AC16A4=5@DDg<d@aAT4h<D@d=STiA3=6=4<`AS@g@C=6@SDa<dA5A0e1@c91<3Q1
A4He<cPh<CU3<D<f>3Ph>CLe@D@d=dA2A4<f84i43BmH>3DP834f<B1BA20b=4E3
@T@`=C=5@SPb>DDd=3A2<3DiASTe@C54=356AD<`=DE1<S91@C4iA3<d@SE1<48c
@cM5<S0`<C8=A38a@cLa@CPi@T96<STb=cPh@c<h<SLgASLb@CA6<DE6>4He<30a
=DHg=C4`<DE6<THi@CPhA4@`<D@i3DE1@CTaAD4b@TE2=c16<SQ1=S94=4Dh<C4a
<cPa@d4g>CM3=S0f>4@g>48`=c=1>CI1=3E5@C@e=c4c@Pe4=48d<3A2@T=3AD52
<SHd=3Td=CI5<c<b>D<f<CPb@TE5=3I5<d8g<dHd<dD`>D8`=C<a@DE5=3=1A3L=
=DDg<c0d>4I1<S52<THb=c8`@C4b>3Td=SPf<cTf<3LhAT4i<C@h=TDc<3H`=c0`
@SPg<cA4<d@gADI33D<h=CTb>44`=34c<cHd=C0b@T55=cPPCT@=;ePh=R0P<C@a
8594838dAD=2A30e<dE2>3Le<d=1=4@f@cLi<SDc<S<eADHd<cLbA38a<44aAC=5
<3Pf=T@h@d94>C8`=C16>0dbAS12<DDfA44`=cDfAD<hAS0b@C0h<STd>3Q1A34d
AT8g@CI6@CTg=3@g@cE2<C53@DHd<D8`=c@f<C@=@T8dATDa@T56ASPf=C=1A3@h
<3E2AC11<SI3<DE1<496@c14<CPd@CU4ATE3>3E4A3LiA3M5A38`<3Df3CU2<SE3
@C94=D@b=d=1A4Hf<CLf<4Dc>D@aAC@a@d=4@CTg>C4h@CE2=D55=3Li=CE2<456
<CHbATDb>@e4>34hAT8d<T8d<4=4A313ATA6>C0`=dHf<DE1=4Ha>CU6@c8g=cM5
=TDPCT@=;ePh=b0P<SDa002Q0<0oob1BA20b=4E3@T@`=C=5@STi=CTd<SDi=3=4
=STi<SLb=4@i>D8d=D=3>D@a@S<g>CL`>3<d<3<a=30cAD8eACH==c<h<S55AS16
>4E2ASE1<dHe>CU2<STeAC4h@cTh<S0i>DA2<S8g>4=2<4=6>48h<T4f<3DeACI3
>4D`3C8`=d4b<S52@CPdA3Th@dHeA395<3@hASPi<4E1A44h<T8c=C52=c4`=cLg
@C=1@S@f@S<`ASLg<d<c@@de@C96=S8e<CI1=cHa<d<h>44g@cU2=T<`A44b<TA3
<CM6@dDb<30dA3Q2>C8a>48e<STh>496<SDaACP==3@f=4Di@SM3=C4aA3@`AS15
<4<d<C4d<SPc<SLe<T96@cPi>3PiA394<cHhAS8e<3=4<c4b=TI6>3U63CTi<491
>CA6=352=4<c>3M2<CPaACDh>CHe<38i=d=1@d@b=3@`ADHh>C@iA3I6=495>CA5
AS0b<TI6=@dd@CHbA3I5<c@g@d@c@SD`ATHd<c92AC@i@TDd>3=3AS4e>454=DI3
ASHc<T4g<dI4<cQ2AT=1<4=3AT@=@S<aA48e<CLb<D94@CPiACLfAD<g=D53@c8d
@dHb=CM3@STgASI1AC@c=c8`<CPb<TDg@cHe=44f<T8b3CU6A3Pf@S16<S13<S@g
=dE5ASE3@d4PCT@=;ePh>20P<SD`8594838dAD=2A30e<dE2>CTe>C@b=CTd<d@f
>CTb=c8dA3Ti@S@e@d<iA352<cLi=c0h<c@`<c4d<3=5@SE5=Pdg<cPb<DE6<4Hh
AD96=D4cASDi>D8b>CE5<CQ3>CPb<3TiA48b<SLh@d8`@dHh@SPb@CH`=CE5=T<h
AC0=<S0g@C8b<D91>3A4>CQ3ASE4<TD`=3Q6>3T`AD54@CPb@S<e<D8g<C0g=cM1
<d52=3I2<c16=cLc@c=13CE1<THf<SDa=T4g=S4c@cPh@CM3>D8f@c14@C8bA4<a
=dI3AC8`<3A4>48i<S4h@SDb>CPh@THb=C55>0dd=3HdACU2=d<e<C54=316<4D`
@c@a<C@b>3<b=cDb@TI3>3Th>3U4<T@c=SQ6<SD`<d@c<C8fATHh>DH=>CT`@T4i
=4Hd<D8d@c<h=d8a>355=CPi=SD`<STg@d53A38d=315ASPi=3U4=THd@TDi=4E6
<38bATHe3CA1=S94=TDc=3M3A3=2=C16AS@c<T95=3U2AC@h<d=6<CDh@D@eAT=6
=S<b@CLcAT@c>496@d4`@d=6A0e2<c54@SDa=c8a@TA1>3U5=cI5@cLe@D=3<SA3
AS8e=d=2>CM6=T55<cTa@cH`@cD`@T<fA4De<d@iA4<==S4a@dE6@cHhASDb<d4i
<CLi=CPPCT@=;ePh>B0P<SDi8594838dAD=2A30e<dE2>CTe>C@b=CTd<d@f>CTb
=c8dA3Ti@S@e@d<iA352<cLi=c0h<c@`<c4d<3=5@SE5=Pdg<cPb<DE6<4HhAD96
=D4cASDi>D8b>CE5<CQ3>CPb<3TiA48b<SLh@d8`@dHh@SPb@CH`=CE5=T<hAC0=
<S0g@C8b<D91>3A4>CQ3ASE4<TD`=3Q6>3T`AD54@CPb@S<e<D8g<C0g=cM1<d52
=3I2<c16=cLc@c=13CE1<THf<SDa=T4g=S4c@cPh@CM3>D8f@c14@C8bA4<a=dI3
AC8`<3A4>48i<S4h@SDb>CPh@THb=C55>0dd=3HdACU2=d<e<C54=316<4D`@c@a
<C@b>3<b=cDb@TI3>3Th>3U4<T@c=SQ6<SD`<d@c<C8fATHh>DH=>CT`@T4i=4Hd
<D8d@c<h=d8a>355=CPi=SD`<STg@d53A38d=315ASPi=3U4=THd@TDi=4E6<38b
ATHe3CA1=S94=TDc=3M3A3=2=C16AS@c<T95=3U2AC@h<d=6<CDh@D@eAT=6=S<b
@CLcAT@c>496@d4`@d=6A0e2<c54@SDa=c8a@TA1>3U5=cI5@cLe@D=3<SA3AS8e
=d=2>CM6=T55=3=6@STg=38h<cA1>D4a>3Ph=cT=>4I2>CQ5@c@b<cHdAD@d>4@`
<SDc@CDa=c0dAT4e<T=6>D@gASPPCT@=;ePh@B0P<SDg8594838dAD=2A30e<dE2
>CTe>C@b=CTd<d@f>CTb=c8dA3Ti@S@e@d<iA352<cLi=c0h<c@`<c4d<3=5@SE5
=Pdg<cPb<DE6<4HhAD96=D4cASDi>D8b>CE5<CQ3>CPb<3TiA48b<SLh@d8`@dHh
@SPb@CH`=CE5=T<hAC0=<S0g@C8b<D91>3A4>CQ3ASE4<TD`=3Q6>3T`AD54@CPb
@S<e<D8g<C0g=cM1<d52=3I2<c16=cLc@c=13CE1<THf<SDa=T4g=S4c@cPh@CM3
>D8f@c14@C8bA4<a=dI3AC8`<3A4>48i<S4h@SDb>CPh@THb=C55>0dd=3HdACU2
=d<e<C54=316<4D`@c@a<C@b>3<b=cDb@TI3>3Th>3U4<T@c=SQ6<SD`<d@c<C8f
ATHh>DH=>CT`@T4i=4Hd<D8d@c<h=d8a>355=CPi=SD`<STg@d53A38d=315ASPi
=3U4=THd@TDi=4E6<38bATHe3CA1=S94=TDc=3M3A3=2=C16AS@c<T95=3U2AC@h
<d=6<CDh@D@eAT=6=S<b@CLcAT@c>496@d4`@d=6A0e2<c54@SDa=c8a@TA1>3U5
=cI5@cLe@D=3<SA3AS8e=d=2>CM6=T55=3<f=3E2=S8g<CA6>3Da@T56<T4=<3He
@c<h<T96<CLb<S=6@DA5=S@g=4E2=D8c<STi=SLi>21>A0d_F3Q2820c<S0PDT@P
<SA5@d94<3DcAD8i>CDi=38e>C@cA3Hi>C8g<SA4>CU2=3E3@cU4<D8c=cTg<3Pc
=30c<C@`<dE2=DDf3CLc>38aADH`ASQ5@THe@C=6=CTi@S8i=DDa>4<i>38`>CU4
@S8b=cQ3@S13ASQ2>391=S0e=DDf@cQ5<0db<3M1<S8a@T4h=4@i>4=6=D@bAC0d
>4Hh>C15@DA1>392<cDa@SLa<3Lg=d4c@D8d=T8c<4Hg=c=3<d4==D4bASHb=C4f
@CLf<C=3>3Q1=d<i@SI3<4A1<S94@c4gAT=5<S0`=4@h@STb<CQ2=C8i>3Q2AS8e
<DDh3C@d=SA5>D8g@cDa<D@d<4H`AC13=34a=38h<c8g=C92AT<h>CPh>D@bA3<f
>4Hb=C0cA3<a<SI6ASPiAPdi>C12@CTdAS@a@SA3<cPg@S4h<DDe>3Tf=C0b>CM3
@D=4<S@d<4E6>3Td>D@fASA2ACTdADH`<S96ASD==44f<T@fAC<d=d=4<d8e<4I6
=3<b@TDd>D95=3Pc@dHa=CQ1A3E6@dHf<c91=c=6A3<h@TI3@C13@dI43D8c<DA2
=C4g<S52A44h>DDg=TE3=cE1@d<b=4=6<SDg@d8i=dHf@DDd<cTa<354<CE3AC8c
ATE6=cTaAPe1=496<3M2@D8f<3D`@T<c@c56@S56@DHfACE2@dHc<d94ACI6>314
=TI4<S@c<4<b@S4h<CA2@cQ6@CH=@SLd=DA5A493=T52=dDd@S11=S4aAT96@cE1
>316<4@e=STbASLe=T<i<dA4>4Hb=TDhAC0h<SD`>3Df3D=3<4D`@CI2>4=2<D@c
<d4c@S8i<CHiACI2<T4fAC14@SDh>C93=c0PCT@=;ePh@b0P<cDb8594838dAD=2
A30e<dE2>CTe>C@b=CTd<d@f>CTb=c8dA3Ti@S@e@d<iA352<cLi=c0h<c@`<c4d
<3=5@SE5=Pdg<cPb<DE6<4HhAD96=D4cASDi>D8b>CE5<CQ3>CPb<3TiA48b<SLh
@d8`@dHh@SPb@CH`=CE5=T<hAC0=<S0g@C8b<D91>3A4>CQ3ASE4<TD`=3Q6>3T`
AD54@CPb@S<e<D8g<C0g=cM1<d52=3I2<c16=cLc@c=13CE1<THf<SDa=T4g=S4c
@cPh@CM3>D8f@c14@C8bA4<a=dI3AC8`<3A4>48i<S4h@SDb>CPh@THb=C55>0dd
=3HdACU2=d<e<C54=316<4D`@c@a<C@b>3<b=cDb@TI3>3Th>3U4<T@c=SQ6<SD`
<d@c<C8fATHh>DH=>CT`@T4i=4Hd<D8d@c<h=d8a>355=CPi=SD`<STg@d53A38d
=315ASPi=3U4=THd@TDi=4E6<38bATHe3CA1=S94=TDc=3M3A3=2=C16AS@c<T95
=3U2AC@h<d=6<CDh@D@eAT=6=S<b@CLcAT@c>496@d4`@d=6A0e2<c54@SDa=c8a
@TA1>3U5=cI5@cLe@D=3<SA3AS8e=d=2>CM6=T55=3=6<c0c@c<f=3Dc>D4b<c@g
A3P=<TDc@SQ1ACLd@cQ3=3Tg@D4a@C<b<c0cACDi<S4e<cU1@D8iACLf@DDi=T@f
>D8h<TD`=48g@CL`@d<e3C53@cDfAD@a=c@c@CDc>CTa=SM4<dA5=DDh<4A3AC0d
AS52<CTe=44a<38e<cLi<S<hAT56>C16@C8gA@dd=3He>CHe@S8f=d@e=C=2=C54
<4Hc<4@e=dH`<T96>3U1=CP`=c8f>3Lb=SPc@CTc=SM3<D92<c=6<DH=>44a>CU4
<4@e=D<eAS@hADDd@SPg<SLa@cT`=C53<C8bA4HcA3@`ATE6<4HPCT@=;ePhA20P
<S8e8594838dAD=2A30e<dE2>CU4<311<C<f=C<c<3E1@CHb@cHb>451AD8d@CU6
@T8eAT@`A48e<D51<STd=3I5@PdbAT@d<d94<cD`<dA3=SI3=dDa=D4hA3<d>C13
<DA6<d4d<dH`>3Di@CQ1@S8h=S0g>D4f@S8eADD`>CT=AT52@T8g<D8fA3Pe<cE1
=391<S8fA4<`=d<d<CP`<D@f@SHc<3E3@S0hAC8h<CTb>CA1>CE6AD8d>4I43C@d
<4@e>DHf<CM2=4E6=44c<c=2=3<iAS93<4A4>C8f@S8i@cQ5@C@f=D51AT54=D4a
AD<cATA3@D4i@@de<DI1=cA2<T4eACU2>492@cA6<d4i>C0a=SI4ACM1=4<`<c=5
<S11<CE4=cHfAC4d=c91@c16A34h=C<==456=3Da@c@b@S=2>3Pi=TA6>CE2<D51
=3Q6<d@h@SH`<S8`=T8a=312AD@i=c8dAD<g@d<g@DDd<CDg3D4c@cTbAC53@cE5
=d=4=T=1=30aA4DaAS4hADA4@c0i=d<e=C4eASTcA3HbADDe@c@d=4DeA44`=SDc
>@df=SI3@TDf<C51ASQ4=S0c<c8g<44d>D8d=T92<d4PCT@=;ePhAB0P<CTa8594
838dAD=2A30e<dE2>DI3@D4`=c4e=S@c=34a<48`<C@hAC=3<T8gA3@a=30g>C=5
>4<c=cU4<4De=4<bAPe2<C=1=C<g>CTfACDe=TE3<T=3A4I6A3PfASTg=3<b=30e
>CH`<S@f=S@b=C0c@CQ5=D=5@DE5>3T`@S8=@c4f=c=6<DHh>493ACI5=c51<dHe
A3HhATHh=dHc@T53>44d@cI2=STh<3Q6=SE4=3Pd<CTa>D4c>34b3DDe=SHf@d<d
@SI2=C<dADDh>C8h>CPe=TI3>DHa=3Dg=3LfAC8d@SU1@SPh<C4eAT8g=T55<D@e
=S<fA0e5<D92@D@dATDd<4=6<38b>D@cAC8h>3<d@dI1@cM5ACLc>D4b<DHh>316
AD4f=CI4=3Q5<SDb=SHd>DH==3A1>D@f<cA6A3M1=TI4<30c=DA4@TH`<312ASDg
AT4a>34e=d@c@cE6<4I6=SL`<dI1>D94@cI4<3913D94A3Pb<3@b=4A6=d8`=D8`
<CTc=cHPCT@=;ePhAR0P<CTb8594838dAD=2A30e<dE2>DI3@D4`=c4e=S@c=34a
<48`<C@hAC=3<T8gA3@a=30g>C=5>4<c=cU4<4De=4<bAPe2<C=1=C<g>CTfACDe
=TE3<T=3A4I6A3PfASTg=3<b=30e>CH`<S@f=S@b=C0c@CQ5=D=5@DE5>3T`@S8=
@c4f=c=6<DHh>493ACI5=c51<dHeA3HhATHh=dHc@T53>44d@cI2=STh<3Q6=SE4
=3Pd<CTa>D4c>34b3DDe=SHf@d<d@SI2=C<dADDh>C8h>CPe=TI3>DHa=3Dg=3Lf
AC8d@SU1@SPh<C4eAT8g=T55<D@e=S<fA0e5<D92@D@dATDd<4=6<38b>D@cAC8h
>3<d@dI1@cM5ACLc>D4b<DHh>316AD4f=CI4=3Q5<SDb=SHd>DH==3A1>D@f<cA6
A3M1=TI4<30c=DA4@TH`<312ASDgAT4a>34e=d@c@cE6=S8f<353<D<`AC<d=SU2
=S4c3D@d@T<e<C8b@c@d=SA3@C15ATA3=c4d<B1>A0d_F3T`820b<30PDT@P<SA5
@d94<3DcAD8iAT=1@C0g<CDf=3<d<C4`@S0a=3Q5<d<b@SM4=34d<3Li<dDh@c<g
>D@`ACDd@c963D8a<d4e<cLi>CI5=CDfAD<b@d=4ATI4>3I6>CLd<c8d<3Di=S0b
=3Hf=38e<3=1>4De@dE1ADDh>C12<Pe3<CHg<dHaASPh@T=5=TDg<D4cASE4=SQ6
ASPgAS=2@D<h@CA3=T8f>CP`>4Hf=D@d>3@a>C4i@C<h<C8=ACDf=SI3@cA2=T8e
<cA5ACPi<SPi>3DfAT<iAS4d=CLd=cI5<SA2>D52>3Pa<CE6@SLf@DDaA3Df<cI4
3DDa@T91A3A6AC@`@dH`<S8iA3=5<SPh<cA3AT53=dE5=c<i@C8aASPh<4I5@CHe
=T@d>4Db=C8f=S@iAPdd=44iA3Hc=4I4=d4fAT@`<3<eA4A2AS0`<496=CM6@C4h
<CDgA3=3=DHf<T=1>D=4>355<CLh<cI2ACP==cA1=C@f<3Q2=DI4<4Db<4<gADE4
=3Hh@D=5@c<eA48eAT52>4Hc<B1>A0d_F3Ta820a>CLPDT@P<SA5@d94<3DcAD8i
AT=1@C0g<CDf=3<d<C4`@S0a=3Q5<d<b@SM4=34d<3Li<dDh@c<g>D@`ACDd@c96
3D8a<d4e<cLi>CI5=CDfAD<b@d=4ATI4>3I6>CLd<c8d<3Di=S0b=3Hf=38e<3=1
>4De@dE1ADDh>C12<Pe3<CHg<dHaASPh@T=5=TDg<D4cASE4=SQ6ASPgAS=2@D<h
@CA3=T8f>CP`>4Hf=D@d>3@a>C4i@C<h<C8=ACDf=SI3@cA2=T8e<cA5ACPi<SPi
>3DfAT<iAS4d=CLd=cI5<SA2>D52>3Pa<CE6@SLf@DDaA3Df<cI43DDa@T91A3A6
AC@`@dH`<S8iA3=5<SPh<cA3AT53=dE5=c<i@C8aASPh<4I5@CHe=T@d>4Db=C8f
=S@iAPdd=44iA3Hc=4I4=d4fAT@`<3<eA4A2AS0`<496=CM6@C4h<CDgA3=3=DHa
=SDa=3<a<CU4<C<a@cLa=D8=>D4d<S@e<CDb@cQ1@T4cAT<iA48aADA3<S94=3E5
>C4`>B1>A0d_F3Tb820d=21BA20b=4E3@T@`=C=5@SI3<S55=d@f@c@i@S4`=c4i
=T56AD8h=4<c@S4i<d<i=cL`<4<a=C<e>D4f>DA2=TH=@S12<C14=T@cAC12ADA1
>CM6=dDd=34a=4@f=21>A0d_F3Tc820d=B1BA20b=4E3@T@`=C=5@SI3<S55=d@f
@c@i@S4`=c4i=T56AD8h=4<c@S4i<d<i=cL`<4<a=DE1<D=4<DD`<d8=<3Ta=38a
A4Df@d8`=S@b@CI2@C4c=C4b@c4dAT@d84i43BmH>C@P83Dc8594838dAD=2A30e
<dE2=T<b<DDgA3I3=3U2<C0g<CTf@DI5@SPd@c=2<CTc@cTg=c0`@c4e@CDf<cQ2
ADHcA@d`@C91=S0`<cHh>D4a<C53AT8a>4@g<cHc=D8h<TI4=SU1=30aAS<cAC<d
<S=584i43BmH>CDP83D`8594838dAD=2A30e<dE2=T<b<DDgA3I3=3U2<C0g<CTf
@DI5@SPd@c=2<CTc@cTg=c0`@c4e<d<c=dHdA394>0dc=c56<453=395@c<c>3<c
@T8gA4=2=C4g@DHi=dDh=S=2>DDf=D9584i43BmH>CHP838`=b1BA20b=4E3@T@`
=C=5@SU6<cHh=T@d=d4b<c13<38bAD@f>DHg<3Tb=cQ3>38g=T4`<3Ld<c8hACDe
A34aA48=<D4g@c0i<3E2=3M2@cDe=T=5<T96=3Dh@c0dAD8e@S<bAS8e>DA1>CU3
=cTf=C8iA3PhASHh<TDe<S<d3CM4@DA5@CPf@DHd@d4g@CA6=3<b<T<g=c@e<C=4
<SDa@S8a<d4e@C8e@S@h=4Ha<c8d=cQ6<d@e>3=5@Pdb=4<e>353@DDg=494=3@d
@T96AT4gA4A5<CU2>DA4<TA6<cTd=SHg@S=2@SLbA3U4>44e>3A5=S@e=48==SHg
@TE2=c4g>4E2ACDf<S<hA3M2ACA4AD=1<C@i<THc<c0g=c<d=C@f=DDf>D<h<4H`
>CTc=cU6=c123C52<TDh>CTgAS<h<d8cAC<f=4A3>C0h=3Tc>C4iASA1=30c=S=3
<cQ1>D4`>4=3=4Dd<DI6>CI6A3Di<`e1=cLgASM1<DHfA456A3@a=3M6=cHh=S11
ACTa<c4e=S13<3@i=c4a=d<g@c4a>3Db<3ThAC0PCT@=;ePi=b0P<CDa8594838d
AD=2A30e<dE2>DA1<c0b<C@b<c8i<34h<cTa=cM1ACA2<315<c94>3Q6@C0e<4Hd
<DE5@c8`<3PdA0da<D4d=T4b<T<d<TDa=cTa@c<e>DDg<TI6<SDb>3Th>3E1@dHe
A3Lc<STf<cI3>CTh@c13<SDg@D<d<C0==3Lc=D8a@SLd>DI3@D4h=cTb=3=3>4=6
=cPeAT4b=38d@CDb=C0i=S52<CHa@cU2<TI2<cLaAS4c=T943CU5>3Q5@c=4=38`
@DDh=C8a<c8b<d51@c@b<TI1<C0h<4<e<d52>3@iAT=5AC@`=S<d@c4h>C0cAT8h
APdi>494<c@bASLg>3A3ATE4>3<dASTbAD8eASHc=S8g<4Dh<T=6ATA1=STa@SQ6
<S0h=D=2@dA6@c4`>3H==S8PCT@=;ePi>20P<CD`8594838dAD=2A30e<dE2>DA1
<c0b<C@b<c8i<34h<cTa=cM1ACA2<315<c94>3Q6@C0e<4Hd<DE5@c8`<3PdA0da
<D4d=T4b<T<d<TDa=cTa@c<e>DDg<TI6<SDb>3Th>3E1@dHeA3Lc<STf<cI3>CTh
@c13<SDg@D<d<C0==3Lc=D8a@SLd>DI3@D4h=cTb=3=3>4=6=cPeAT4b=38d@CDb
=C0i=S52<CHa@cU2<TI2<cLaAS4c=T943CU5>3Q5@c=4=38`@DDh=C8a<c8b<d51
@c@b<TI1<C0h<4<e<d52>3@iAT=5AC@`=S<d@c4h>C0cAT8hAPdi>494<c@bASLg
>3A3ATE4>3<dASU4<SDfA3=4ATI4@cTe=C4f=4=6>494=391<SHeACM5<DDi=3Dc
A38PCT@=;ePi>B0P<CDg8594838dAD=2A30e<dE2>DA1<c0b<C@b<c8i<34h<cTa
=cM1ACA2<315<c94>3Q6@C0e<4Hd<DE5@c8`<3PdA0da<D4d=T4b<T<d<TDa=cTa
@c<e>DDg<TI6<SDb>3Th>3E1@dHeA3Lc<STf<cI3>CTh@c13<SDg@D<d<C0==3Lc
=D8a@SLd>DI3@D4h=cTb=3=3>4=6=cPeAT4b=38d@CDb=C0i=S52<CHa@cU2<TI2
<cLaAS4c=T943CU5>3Q5@c=4=38`@DDh=C8a<c8b<d51@c@b<TI1<C0h<4<e<d52
>3@iAT=5AC@`=S<d@c4h>C0cAT8hAPdi>494<c@bASLg>3A3ATE4>3<dAST`=dHe
>391>CL`@S4c<dI3>DHi<T8f>3<d@CE3ADI1>CPd@SQ5AS@=AC@i=d8hACA5ASA3
A44PCT@=;ePi@B0P<CDg8594838dAD=2A30e<dE2>DA1<c0b<C@b<c8i<34h<cTa
=cM1ACA2<315<c94>3Q6@C0e<4Hd<DE5@c8`<3PdA0da<D4d=T4b<T<d<TDa=cTa
@c<e>DDg<TI6<SDb>3Th>3E1@dHeA3Lc<STf<cI3>CTh@c13<SDg@D<d<C0==3Lc
=D8a@SLd>DI3@D4h=cTb=3=3>4=6=cPeAT4b=38d@CDb=C0i=S52<CHa@cU2<TI2
<cLaAS4c=T943CU5>3Q5@c=4=38`@DDh=C8a<c8b<d51@c@b<TI1<C0h<4<e<d52
>3@iAT=5AC@`=S<d@c4h>C0cAT8hAPdi>494<c@bASLg>3A3ATE4>3<dASTbA3Da
<STh>DDe=3PiAT4iA353AST`=DDbAS@c<TDg@d56=4DhAD<=A3LdAT4f>D<h@cE6
=CLPCT@=;ePi@R0P<S4i8594838dAD=2A30e<dE2>DA1<c0b<C@b<c8i<34h<cTa
=cM1ACA2<315<c94>3Q6@C0e<4Hd<DE5@c8`<3PdA0da<D4d=T4b<T<d<TDa=cTa
@c<e>DDg<TI6<SDb>3Th>3E1@dHeA3Lc<STf<cI3>CTh@c13<SDg@D<d<C0==3Lc
=D8a@SLd>DI3@D4h=cTb=3=3>4=6=cPeAT4b=38d@CDb=C0i=S52<CHa@cU2<TI2
<cLaAS4c=T943CU5>3Q5@c=4=38`@DDh=C8a<c8b<d51@c@b<TI1<C0h<4<e<d52
>3@iAT=5AC@`=S<d@c4h>C0cAT8hAPdi>494<c@bASLg>3A3ATE4>3<dAS@`<SM5
@C16<T8`@SA4=3Pc>DE1>D=2=CU4AS4g@c@bA4De>3Tb=DD=<S15AC@h=3D`AC8e
@c8dAC11=S0i@T@d@S8gA455AD93ASM2@SM5@S8e<cQ4@cTc>4=2<TDc@c12@SD`
3CLaACLe<TDe=T<a@STc<cI2>C11@CE4AS@e<CU4@SE4<TE4@d<g=cHc=C=6<44g
<CLiA3Te=S0h>3<c<0e4<44b=S@e@CM1ADA1=cT`@CLPCT@=;ePi@b0P<C8f8594
838dAD=2A30e<dE2>DHc=SPfA3@g@DA4A30`>30g<DA5AC0e=c0c<TI5=CDf<TI5
A30b@DE2=c4g>C@`<@e4<TE2<STi>D@dASE6<4@i>C@bA4=1<dA2ACDc=C4e=CA4
>DHd>492=THdA3Pf=S0d>D@a@CHe@c55<T4=A4Hg<C=2<4H`A48f@dI2A4E2AS<h
ASI2<d4g=D@g@SDeATDb@dDa@d<h<c0c<SU4<D@g>3<c@cI4=dI13D4h=S<`=DA4
@d56A3<g<D8c@cM2<S<`ACLa=c4fACLe@T8b<4D`=cHe=cP`@SM4<3Q6<d96<SM2
<SHf<@d`<cE4A44e<493>DDPCT@=;ePiA20P<C8e8594838dAD=2A30e<dE2>DHc
=SPfA3@g@DA4A30`>30g<DA5AC0e=c0c<TI5=CDf<TI5A30b@DE2=c4g>C@`<@e4
<TE2<STi>D@dASE6<4@i>C@bA4=1<dA2ACDc=C4e=CA4>DHd>492=THdA3Pf=S0d
>D@a@CHe@c55<T4=A4Hg<C=2<4H`A48f@dI2A4E2AS<hASI2<d4g=D@g@SDeATDb
@dDa@d<h<c0c<SU4<D@g>3<c@cI4=dI13D4h=S<`=DA4@d56A3<g<D8c@cM2<S<`
ACLa=c4fACLe<S4e<T8i@D<a=S4`=SE1<C53@d=1=4Hi=c@gA0dhACTg<CTcACLd
84i43BmH>DDP834c=B1BA20b=4E3@T@`=C=5@SU6<cHh=T@d=d54A4@`<3P`=c54
ADD`=CL`<c96ACDe=S96AD@`<T55@SLa=cTd<34=A395@S8i>CU4=4HeAS14>CTd
<TA3@C=4@TDe<cDa=CDdA3U6=3Q2@SI6=4@h=SH`=3U4<D4f=D<aAC913DA6=c4c
@S16<4A2=T=6@TA5@THc>4Hf@S=1=cE4=d8e=DI5<T=5<D=3>3<`<c8iA354=cPc
<d<fA3M6@@e1>3Hc<3E4A4=1AT@c=c52<d<g@S8c<4Dg<CLa=TDg=D92@C<a=cHi
AD<`>4<cA3Pd=T4f=3Lh=391>38=<D4e<3Td<cA3=C=2=cM4=4E4@dA4=3Hf@cLf
@CLb84i43BmH>DHP834c<R1BA20b=4E3@T@`=C=5@SU6<cHh=T@d=d54A4@`<3P`
=c54ADD`=CL`<c96ACDe=S96AD@`<T55@SLa=cTd<34=A395@S8i>CU4=4HeAS14
>CTd<TA3@C=4@TDe<cDa=CDdA3U6=3Q2@SI6=4@h=SH`=3U4<D4f=D<aAC913DA6
=c4c@S16<4A2=T=6@TA5@THc>4Hf@S=1=cE4=d8e=DI5<T=5<D=3>3<`<c8iA354
=cPc<d<fA3M6@@e1>3Hc<3E4A4=1AT@c=c52<d<g@S8c<4Dg<CLa=TDg=D92<44e
AS13@cI2<c4e=38a=4<d<SE5<SA5@D8=<d91@C8`AD4a<4Dd=cDc<DHg<CI6<c91
84i43BmH@C0P83Di8594838dAD=2A30e<dE2>3Le<d=1=4@fASL`=S4bASHb@C4f
<T@f=492@C11=3U2@TE5@TDh<494<3@i>4I2>@e2<D=4@d8e<dE4=c95@S95=D<h
=4<fA391@C@d<D96<T91@cQ6<S8h@S<hAC<iA3U2<4<c@C14ATI584i43BmH@C4P
834c<R1BA20b=4E3@T@`=C=5@SHe=3I4A44aAC4h@d8c@S54<cTf<3Da=cPa=T4`
=CQ1@C91A34g<3Pf=cQ5@SHb<C<=@d93=SHh@DA1ASDdA3Df<cLf>4I5<D@e@dE2
>3Q5<c14@CLc@D8dATA1=30e=STd@T@h=cI5=S@`=d513C@c<C94<4@i<d@f@cTa
@dE5=DE1@C<bAD8e=SQ5A3Q1=c56@D4h<CTe@T4gAT8h=SHiA4<iA3P`@cU5@@e2
<3Hg=cLi<SLa<SA2AC<b<4HbAC4a<C<a@T@a=SDd@SPb=dDf@DDa=S@a@c92<CU1
@STh<44`A34f<SD=>44eAT=4=c<i<4A2=CDb<S<e<C0g<T=584i43BmH@C8P834i
<21BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THg<C8h<3Tc>D4g=cLa<D92<SI6@c<e
=C8b@S0eAC91@D4c@d<bAC4=ASU2ACM3<c96@c=6=TI4=d4d=3E1A4I4ASLh>38h
>D8cAD=2<3H`>316<34c=cI5AC8f<cA2<C0`<T8c3C0a<SI4AT<`<4=3=T@`=4He
ASQ1AT<g=C<dASE3<SU5<C<f@S=5=3I2A48b@c8c=TA1=3U6ATDi=T@b@Pdc>4E4
ATH`=dHa=SDg<cTfAC=4@DDe@CDc=SHe@D<a=S8b=D=1>D4d=D4iAC<`<cDe=C51
=D8a<c8g>30=<3I6AD96ASP`=4He<cM4@T<f=T=5@T@gAS@e@C0c@C95A452<3=2
@DDiAC16>3T`=C4`AD=2A3H`>4@d3CHb@c8d=396=SLe@TD`=S0a=cU1=393A4Ha
>D=1@SM5@c0c<3@aADI2A4E2>48b=CDc=T<a<cH`=D@b<0dd<SI5=cHd>CTb<CH`
>453<4@b<R1>A0d_F44c820a=C8PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I4=4H`
@C92=S8e>CA2>34b>3U5AC<g=T8d<cHd@THf>3De=3<g<cLg3C91<4DdA455=4Dh
<STaAS8a@cTiACE4>3Q1A30g=cE6<c8e<c=1=D8c=c@c>CI3@cPa@SA2<c0e=d<a
=@e5@C@e>C<i@cPcA38d=4Dg<C54>C0e<c0e@c0e@CT`<4<i@d4a<C12<3U6<TA1
=dI2@TE3=S@fACLd<C4==S=1<30eASPd<C94=c4i@d4h@d<c@D<h<c8b<T@dAS<f
@d@a<3Db=c=1=CPi=c14=C52=dDe=THd=S4h3CPg@C4e@c8b<CPg@dE5=D=4=cHe
@cQ3>D8aA3<c>4H`=C<g=c4dATI1ADE4=4@d<4=1@d93=D=2@d@g<0e5A4He84i4
3BmH@C@P83<c=B1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THg>DI2ASTh<34hA4A2
=D92=44e<T4i>CDdA4@e<T<e<4Hf@d53@d<=AC8`A3=2=cQ2>3Q1@cE5A3Dg=C<a
@CDi=c54AS0d>4A2=4@g@D55=CU1ASQ4<c13@C@f@D4a=THg=3I63CA3<3Q5=cQ4
AT@e>D@`=SDi<ST`@S8dA4I1ACHc<THfACM4=4DhA3I4<T4b<C8c=455<3Ta@S14
=C0d=@da@CPe=DI3=3=2<395<c52<cTd<S@b<34b@DE2=cU2>3Pd@c52A4I5A395
<4=4>3<c<STaA3I3>D@i=c8==34b=TI6<3P`<CE2=3<gAD8i=4HiASPb=DHgATH`
AT=4<C16@S12<SA5A3@h<SLdA4DfAD4dAT55A3M33D51=TI2<d<`AC92<c<eACP`
AC<e<3@bA3U5@TE2@SHc<TDg=D8f@T56@DE3@CU5@SPc<C@g@CU4=313APdc=SPb
A3Hh=4HcAS54<T8b>3Dc@SA3>4=6<34b<c8g=CLe<48e<D@i<3He>DHc<T=6@CHh
=d8d=DE1>3L=A3Da>4De=D@eASLb<3I6@dA3@c@a=cDe<S@`=38d>D96@D<c=CHf
=T@e@D@a<c4d=30hATH`=3Lh<DHi3C4a@SI1>3<d<SU2A3M2@CTgAD@g<3Q5@S@b
@dE2=T@cA4DdAT8i=SHcA4E5<T<`<3Lg>DI4=cDd<STe>0dh>CD`ASHb>3Te<c53
=THg=S4h=C4h<dA1@dI1@dI2<TDe>3=2@CHb>D@`=3@f=STc@CLd>38e<S@f=d4=
=cI1<3I2@SLg=C91<CI2<dHa>D53@SLg=cTfACTg@CHc@T<e>DI3>DE1<SA5=D54
>3=2<44iASM2<S@f3CTi@DI5<S4b=T<PCT@=;eQ1=B0P<C0a8594838dAD=2A30e
<dE2>3Le<d=1=4@fASQ6AT8cASM1<48`=d52A30cA351=C<`=3U5@d=4<cA3@c4d
@c4d>0diAS4c<DDdACU1@d@b=cA1<d8f=SQ5<DA2=DDg@C53<312=d<b@DDe>3I4
>C0i@cU4@ST`<c93=394>C<=>3=2<d=6=D@e<3I2=3Pa>D<a<C<e>D<d>C=2=3Td
A4<d@DHe>3E6@D@g=THe<d@`=CHc=4@a=DHiACE33CI2<C=2=48d=4E5AT@c@CDd
=C@a=38PCT@=;eQ1=R0P=cLPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=d@g>48a
=3U2<CHdADE4=30d=c53ACI5>4@d@S0e=3Hc<3@e>3Th3D54<C4f=dA2<CPg=353
ATE5<DE2<SM2@T54=S@e@TDf<3Q5ASLc<SHb=d=2<STc@dI1=S=6<SE5<c0f=`dg
>3Td<d4gADDc<dHe@C8f>DE3AT@`<C=5ASDe=D53>39284i43BmH@CLP838d=B1B
A20b=4E3@T@`=C=5@SU3@S8i=c93@S94ASQ2=4A4ASU1<D8cASA3A3Lb<c91>D92
ASI3>D8f@SQ6ADA1<3<=<d4e=T8gA4A6AC@g=C4hACE6=4<e=D94A3T`<38f<4E6
<C@c<3I5<S@e@D8aATI2=dDb@S@f@SA5<S8i3DA4<c=4<STg<T4h@c@a=cE5@TDi
@SE6<d8f>D8dAT4b@SI3=S@g<S@gA3<d<d<eACDb=cI2>D4i@SDe>0db<T@e@SQ4
=cA1@cPfAC14<4=5<cPd=cA2A3=1=SLb=cQ5=c<e@C@e>CPg>492=DI1@c92<T@d
<3Ta<d<=>454@dHi=S<hA3=5<cTi<cA1ACQ5=D4gAC56@T=2A4=6AD<c=D8f=T@b
ASM1<d4e<cTf>3I3AC=5>3Dh3C8eACPbAC<c@T4d@SI3A48b<D52>44eAS@gA3U5
ASM1<dHaA4@b=S8bACU5A4I6@T<a@cM4=S8iA4=3=@dfA4@c=C94ACM4<3Di<c@a
<SHa=C4c<T@iACI6@SLe@TI5<cA6@dI6@DDf=d4h<c8iA492>3=3@d8c<4H=>CI5
A3PbA4Dc=D95=SE6>D8g=C4hATHc@CM2=DD`<SU6>CE6=T@aA4=1=d<e>38d=C91
@CLeACP`@CH`3CQ6ACTb>C4e>4@PCT@=;eQ1>20P<c4d8594838dAD=2A30e<dE2
@T<f=D<`=CU3=dDb<c15>D@i@c0aAC4c@d=4@DE5<C8b=cI1=SE3@S8c@C0`<SA3
@`df<c0i@D54@c54<3De@cI2@T@iACLb=cQ5<3=1<CE1@c4d@dE1@C51@DHh=4@`
@c93=d53<4De@S0h>C4=AT4d=SLfA4Hc>C=1=3HhACE6A34f=SDf<c<gAS8d=C=6
=34a<TD`<SLa>C8b@S<a<CT`=dE4<30gA3I53CU6<c94<DHcA30e<SHe@cTa<454
=D=2=30b<3PhAC8b>492=S4g=c@`<S8h=4He=CDfA4Df=3U6<3Pg<`dd=T4f=d93
<3I4@T4hATA2=CA6<cA4>3Pd=S96=cHg<48h=D@i<C8d<D<i@S0g=3Dd@D@d<TA6
<DI2>CH=@cLa<3=4@STfASDh<cU1@SPf=4E5>3Tb<d<hA34e=d<b@SLhADHb=d<b
>355=cU4AD8c=CLc=4H`=4A63D4`=S8`@d=1@CI1<C=1=3@iA4I2<D<a@c@g=c95
@SHf=3=3=T@`ASU6@DA1>4Dh<3A5AD8a=T<d@d<`<0dh<3Q2AD<`@T@a>CPf=C92
<4Hd=S@h>3M4A44a=DDa<cLh<c@b<THgATI3<3I5<4A5@D<g@c53<SQ5AS<=AS@a
>4=6>C13<4<b@d95@d@a<cQ4>3I4=48aASQ4@c4d=C92<D8b@CTi=4Dh<D96<4<d
ASDhASPh=C<a3CLc>30d@c8a@C0a<TA6>4@a=d<g=cTf>C8b=c<fA4=1@c13AS8c
<cM3AT8a<CA6AD=4A3Hh=d=5<cQ1=Pe3ASHh<SE5@cLb>393<SM6@CHa=S@f=D8e
@cU484i43BmH@CTP838h>B1BA20b=4E3@T@`=C=5@T93=SE3<3Di@cM5@dA6>DI1
>30i=3<`<C<g=3@f=4A6@SDi<3E5=CM2>D=2@STg@DD=<4Hg>3Ph<CPc<cTbASPb
<4Dh>4<iAC<g>C=2=d=4=S<h=D4h@DDf<d@h@cPc=SPd<c@i=DHh=dDeAD8e3CI6
<SQ6@STg<SA1@dHc=S4dA48i@S8g>30g@SA2=TE6@THd>38f<DHe=SLg>C<c@D=3
AS<`<D@f<4<b>0di>316>3Da<CI5<3Df=c<e=DDg=dA2@cE5>D<e<4I4<C@d@CI1
A38b<CDb>3Tb=d@hAD4b=DA2@C@eATH=AS@c>DE6@dI2>4<f<cI2AC96>44a<c@f
@SU4<C0h<TA1<cPaAS=3>D@f>C@iASTi=SU1<c<f=c8b>4Dc3D4h<SHd=D51A3I2
<T4a>C0`@C<b=TDe<d@gACPb>48`@SDi=D8b@cE2=3<iAT8h@S93<SHe>3E3>4@e
>@e5>3Pb@cTi>3Q6@D@e>394>3Hh=CI3A44g=S@b=SI2=T4f>DA4=C@d=4Hf=c@f
@d8aA494<4E2A3Dd=D@=<T<`<4Db<3Hc<CI3=dA3A3M4<C8g@cHfAC<`ACPa=D95
@SM5A3T`=34iA3Td@D4i@cHd=T8e@TDc>34c3CPeAS<b=4<f<D55@CHb=3M3>C0f
@DDa=48b=3A2=cPiAD=4>30e<dA1<C@`=S0i<SDi<cU4<T=2@S<f<@db=DHe=SLd
>C8a=4<f<d4g>3Lg=3Q1=4A4>DE2>3@a=d@i>C@f<b1>A0d_F451820h<21BA20b
=4E3@T@`=C=5@SQ4<3U6=TA1=4<a>494@CTa<3<i=CM1=dE1<TI3=CTa=c4f=SHd
<T4b<3A3A4Dd>4<=@cTc@dHcACU4@TI1<c4f<SThAT<d=3M6=DI4=C4d=CU5=SLa
=cQ5=CE6<cI4@TI3<S=5<dH`@T@a=4<f3CA3=D8d@S13@dDb<CU4AC14<SA5<dE6
>30b@D4e=D51=d8c=D93A3<PCT@=;eQ1@R0P<c4PDT@P<SA5@d94<3DcAD8i@d8b
>CLb@d8`>DI5>CDb=48i>3H`<d4a=3<e>CHc=CDh@D@g=SU2@d@f=CL`A3953C=6
84i43BmH@D<P83<g8594838dAD=2A30e<dE2>D=2<STg<T=2<3U3<THc@c16@CTc
>3Q3@T92<SHe=TI3ACPeA30b=cDf@D53=3M3=PdaAS<b<c95AC@g>CHgAB1>A0d_
F454820g<B1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THgADA4@C8fACDa<4<c=CPa
@cM4@d<g=dI3AS91=c=4=4<c<THhAS0==3Ti=CE3=D<gAT8e>C8`=C15ACM2ASPi
ASPf>4<gA34b<3=5>4A5<S56@SM1=THd@D<e=3Tc>D4i@c133DA4=C0bADE1<3Db
@T<`<496>DH`<DDPCT@=;eQ1AB0P=cPPDT@P<SA5@d94<3DcAD92@S4fAT95<S@i
=SPa=CDgAS4e@CDc=4<h@T=1=313>D<`<SHd@c4e@C8g@S@a>C4c3CQ1>3Df=SQ5
@T<c@d=2AS92>495A4<`@SQ2<cPb<SA1@cM1=48i=S8d=cDg=S<a=T4d>3U3@SDd
ACTb>@di=CLcACTi>3Dd<CTd<3A5=d8h<S=5ASTc=SM2=c55A4@f<C@PCT@=;eQ1
AR0P<S0c8594838dAD=2A30e<dE2>38iAC@d=48`=CHi=D<i>CM2AC92A4E6>CPa
>DHi=S8i>DHe<4=1AD52A4A4AC@e=Pdd@CHd=D<i=cT`<CE3@cU4=C0h<3U5@cM1
A3@e@CLg=cM2@S0a@SM3<SPg@TA6<3Ti<CI4>CTc>C@d=SH==S14@C<`=D@g<4A6
<dHg<SM6>D4`<d8`=C11@dDi<c4`<S14<T52=DDd=30b=CDhA3Pg>C93@CI4=D@`
3CE3@DI2<d8a<3M6ACU2=CDf<3Pa@C@i@C8b@D4b=SM6ASTb<3LeA30f=STi<dDa
<d51>C8g<T@hA4D`@`e2@S54ADHh@C53<3Q5ATHc=353ASM2@SA4AS4i=c4b@D<a
>314@THgA4He>4@iA48i<3@h@SHb=S8c@c<==cE1<d<`<SP`A38f<d8`>CM3ACPa
@S0c@cPe=4Df>D8aAD=1<dE5A4A4<S13>CTeATHi=D52=SDf<CU23D55<C8i<d<f
A3A1<S4a>C0`<cE4=4E2A3U4A496@D8e>D@dADDe=453ASA5@D4PCT@=;eQ2<20P
<S@f8594838dAD=2A30e<dE2>3Le<d=1=4@fASP`AS<b=CQ4<d<e=T96<SDc<C0e
<SI2<D=2<D56@dE6=SLgAD@c<@dg@DA3@C=6=d<gA3@`=C95ATA6<4I5=CTe<S0i
=30`<D8a<DH`A3Ld@SU4<SM4AC8d<cA5@SM1<34e=S0==S@i>D=5=SI5<44h>D93
ACE1AS=3=3@a=cA3<S<h@T8c=3U2AD4g<cI6<4Hi<SPa<d8a=44b=D@iAS0h3D92
>4I6=d53@SI1=3Hc<DI6>CHd@THgACI5ACHg@S0g<CTg<3M6AC91@T8c>CM3<SQ1
<T4i=D<i<DE4=`e3=34f>CDh<cTg<SLb>D<g=C8e@DE4=cU4AT@aATDh>496@S55
=T<fAT8h=S96@C=2AC0b=3LfA3HcAD@=A3A5@CI1=d53<SU6>30g=DI2>D4cAS4i
<d<dAT<h>C51=c@i=c0b<d@g@TD`=312@CTg@C0f=44eADE43C4h>CLe<SA3<3Q2
A38`<d4a@SE3@C0g=T<c=44i<c52AD92<SLg<D@`=dDd<D4e=T@b@DHeAD4c@SD`
@`da@d8h@SP`=C15<C51ADD`<dE1>3M3ACQ2@T4e@TDf=T8c=3Pf@T4c<SA6ACM5
@C@h@c@g<c0`ACI5ACH==C<i<TDc<SDi<39284i43BmH@S4P83Hc8594838dAD=2
A30e<dE2>3Le<d=1=4@fASM5A4@e<T=4=c@c=S@g<3PhA3Lh>38a<30b<cI6>C@i
>D=1AC12@Pdg=3Ta>DDh<CU4A3Pd@CD`>4E1>D=1=491ASM1=3A5>3Dc=SLh<C8a
<dDe=THe@dE1A3Tf>3I1@dHf=4<=<SQ2ACI184i43BmH@S8P83De8594838dAD=2
A30e<dE2>3Le<d=1=4@fASM5A4@d@dA5ASPb=DI1>CDe>C@d<S0e@DHe@C16<3Da
=C<cASHfAPda@D8e<TE6=D8c<CPe=395=34c<c51>D=5ASQ3<S4e>C4fA454<T8f
>3Q3=TE2ASLb=B1>A0d_F48c820e=21BA20b=4E3@T@`=C=5@SPg=C=3@CA4=T<g
>C8i=3Q1<44g=3Ha@D@h>3Q1@d<b=SHh>3@d>4HdACQ2A3PcADH=>C@b@D4h<3=5
<CDh=DI1<4HhASI5<DHi<SP`A4@e<d91<4E1ACL`<c8c@C=1A4Db84i43BmH@S@P
83Pc8594838dAD=2A30e<dE2>3Le<d=1=4@fASL`>C@b=c14@C4c=312=C@aASDe
=3M4>CE2@S52=3@g@T<e<d4i=@deA396@d=4ASPa=c92@SU3=3Pc>CU4=CQ4=CE6
ATHi<CU3ATDi=d<d@C13<CU4<D95<T91A3E5=3Hi<c0=@DI6>DHf<d<e=3HbAS4e
<3<a>4Hf>3Q6>D<a=T94>3@a@C8d>C0h=48g<THc<21>A0d_F48e820a<C8PDT@P
<SA5@d94<3DcAD8i@d8b>CLb@d8c<c=6AS@i@cM1>DH`<T4`@C@`<cI5=c8i=3Q2
<SU1>3Q3=c8iAST`3D4d@S@d=4A3=3M2ASTg=C=5@dE3<4Hf@C0c@T96A4Dh@SE5
<SI6>44fAT53@dA5=cL`@CPiAC8d<D4h<PdbADA2=CDiA4I4@S11=d96<4H`<cTh
>3E1<4A5=C@aASLh=D=2<3Q6@SA3<453=c4b=cTd>38c<30c>3<=<SLa=dA1=d52
@S@c=d=1A4Hb<cT`AS<f@C=2=4Hb=SE6=c92=D54@T@e@S@PCT@=;eQ2=R0P<S0d
8594838dAD=2A30e<dE2>3@e=c11<S0iASHa@cHfACI1@dE5ACQ5ACD`<SA5@C0d
=314=d8bACM5=CLf=cU2A0de=c0a<S12<dA4<SA6<c0i>D@`>396<4D`=3Dg<S12
>4Hb=cLiAC=6>D<fASU6<C@d<cU6AC4h=48d=T<==3A4A4De>4A3=38e<T@a<dH`
=cA4@D8b=dH`@C0f<T@h<30aAS8a<dE3<cDa=4<c<34g=SE1A4=4<T923CHbAT=3
<C0d<C13>DDf<C4dADE5=C@fAC96<CE1@cPd<CHg>C4g=dHd@c95>48bA4Dc=CDa
=391=d8bAPe6=3=1<SPa=4@a>C@f=CU1>DA5=D=1A3@g<D=4=SDf>3Pd=SE1<dE1
@d4gAC=2=4E4A34cASPc@cA5=cD=<494=456>451=T<b@CPcAT<f@T8d=d4d@DDi
<cA5<4Hd<S4c=3Hh>CTh<D@aA4A5=d@i=D92=c0`<DDe3DHi=C8b>C16>4Dh<c8b
A3Lb=D<c=d91@SPh<CLcADHg>DHdA392<S4cAD94>452AB1>A0d_F48g820e=b1B
A20b=4E3@T@`=C=5@SU4@C<`<S4d<S=4ACI1=4<`=TE6AS@d<000X@30?om4>C92
=3M5ASU2ADA3>3A1@CPi<SE2AD933D93AS@e=c51=C8iA3Da<cHd<c0g@DDa@T<i
A393=S@`A4E2<3E1>3Ph>CQ6<SPh@D4`<496=R1>A0d_F48h820d=b1BA20b=4E3
@T@`=C=5@SQ5A4Hi=d=5=CU6<DD`ACI5>CPi@D8gA3E3=ST`<3Ld@cI3>3M6=C@d
@C91@d=6@TD=<cHc<CM2@STa<4A6AS0i=D<a<3M1>3U4=S4`<30g<cD`@b1>A0d_
F48i820h>B1BA20b=4E3@T@`=C=5@SPaAT@d=T8`=CLe>D@d=STfA3A1A3@hATA4
@c8f@SM1ACQ6>DHc@c=6@C8`=4<g@CL=@TDb>4@a=S4g<T8h>CU1@SDc<D@d<314
@CTc=30h>4=5<315@T<hAS4h>DHg@D8a=C92<TI2@C@iATHg3D<`@CTdADI3A3Hi
<cI3@S16<dDb=S@`@CP`@SE2<d4i<S16<d@f<S92>4E4=D<cA3M1>3M3<S0d>DHP
CT@=;eQ2@B0P<S4f8594838dAD=2A30e<dE2>D8g<3Ti<34dASDg@cLb@DA1<4Df
>3A6=4I4>4@g<38d<c4h<T@gAD<f<3M2<D8`=0e2<3M3=cH`AS<hAT8h<C96=492
=C54@DHe=C0gA3<i<3Pf<cE6=D92=4<dAT4d>3T`<c<`>C@e<3=3=3@=>CPd@c@d
@c=4=T4a<3Q5<30i>3Tb=d54=d91@cQ6=3Lf<DDh>4<e=C11@TDiACHg=C8a<CM3
<DI6=SU33C@a@cE4ADA1<30`=3=4<CHf=CPg@dA3<c0f@C=2@T94=c0b@dDgASQ1
A3A3<DDgA455@T53>C<i<C<h=@deASM5AS@e@SI1A352@CM4@d=5<cE3=3Th=3Lb
<c<cAC51ADHf@T<`ACQ2<3I2ADE5@T94@dHb@TE5=T@==T91A34e=4=1>DA3AC0c
<391<48i=c8g<TI6=SLg@T8c=c0a@C4e<c93=S0d<3Q5@cDd@STg=SLdADI23D93
@c<f<CM4A3=1>C8d@T8b>CLc<SPd@d8a@d4h<3E6AS8e<SI2=STe<C0b@S4`<4I1
@SDf@CLc<c92=0da>CLb<3<b<D<a<SHPCT@=;eQ2@R0P<S4a8594838dAD=2A30e
<dE2=SE3A3U2<C4d=4Da<cP`AC=1<CLe<cI4=S8aAT@g=T8`<cE1@c8c>3Tc@S4f
>C8e=@dg=S=2<C51=c<f<3E3<CLf=SQ6<dHe=d4hA3Hc@SA2>DHb=T@eAS=4A3Da
=CM5A3Pd@CE4<CPd@d8h>C4=@c<`AT@`@c54@c4i<d4f>CDb>48e<C4gAT=6=d@a
=SU2@CE2<cPi>4A2AC0i<cTcAC=1=3Lf>3U6<cLi3C@d@cQ5A494@S@iAS0`@STe
<dDc=S0`=d@g<d@c@c<g<T8`=S55<S@h<cLaA44d=D96@dDd>4Di<SLh=`df@CM1
=SA4<C0b<cTb<c8bAS14@TDaAT4f=C@d>CM5=cI2>3I2=38`AT<a>3I4=SQ3<48h
>493=cA5<48=<dHf>CU6<C0a=3Q6>CA4AS4d>48f>4D`@S@i=cI6ASPc>C0i=48e
<4I6>C<i=3E3=3=1=CQ1=D@d=SPd3CTd=cHh=CI6<dHg>3M1<C4e>3=4@c8b@cE3
<S8cA4@hA3He<dDb<S11<CE6<D<f<CTh@D8d=3Lg>3Df>0e4=b1>A0d_F493820a
<c8PDT@P<SA5@d94<3DcAD8i<THe=cLc=d4c=DA3@d<g@DI4@c<dA3@iA4A6@SQ3
>CHg=SM2AD@aAT4e=dI3<dHa3C0a<34a=TDb=4<aA3Q4A30`<d4h<4<d>CLd>392
=T@bATE4>44d@dDc<d@eA495AT4`<SLh@STi>D<f=0e6<dE6=SPa>3I5@THa<4I5
@D=6=c=3@c8f>44i@T92AS=3<4H`<TDc=3=2>3E3<c95<c4b<S0`@c95AS8=>C93
=SP`=d8dAC4iAS4c<CLf@DDhADA5<T4dAT8e<S@`<4=2=STaAC91@SQ1>CDa<dHc
<c0gAC@d@cI43D=2>C8aAS<e@SLg=C4d=48i@D8f@D8f<B1>A0d_F494820a=cDP
DT@P<SA5@d94<3DcAD8hADA6>CM3ACDiAT54=C93<DI5<D4i=dDfAT4i=CA6<3Df
>4@b@cDc>4@i@T=6AS4g3D94@c<h=4Hi@CU4<cDd=c4a=T95<T<f=30b=dHc@C<i
@CTi<D8a>C<g=T@h<c4a@cI2<C16A3U4@d<d@Pe6=SL`AC4d>3HaAC<d<T=6=S<f
@T<b=d53<dHa@STbAT8a@S@fAD=2A356=3<`<S@a@T8`<dI2<C8i>3D=@dE2<SDc
ACM4A3M1=3E3=cLc<dA3=354ATD`<4E4@SDf@T8b=S0b@SA3>48fAS=1=cDh=S=1
=S4g@D8c3D8i=D4`<T8g<SDa<3H`<STd@D8f@S91>3Pe<dI5>D=3<DA4ATDh<d52
=c<a=c@f=4Da<SE3<CE2=dD`@PdaA3PaACLh<CT`@C16AC@a>CTh=c@e<CE6>C@a
<CTb>DA3=395<C56A30e>C<`=3@b<B1>A0d_F495820c=S8PDT@P<SA5@d94<3Dc
AD92AS56<3E6>3Dd@c0h<cDgAS51@cI6AT51=d@c@S=1>D@`=CLh=3U6>D@e@DHb
<D<c3D8i>D8e=cHeAS0iAT4g<CLh@CLd>C0hAT4h@dHi=cM3@SI5@d4b=c93A4@b
A3I4>3I3@CI6@T4h<495A@e3=SDa<D@i<3M1>3@c@SDd>311@cL`=3Pi<cU5=4A2
=D4c>CTi>3M5@DDaA4<f=D55<c8a>491@D4a<44=<SA1A4A3=C@fA3Q3<3Tc<3<e
=c13=3A1AS8g<dHc=THbATDdAD54@D91>C4a=cU6<SLc@dDc=c4a@c<c3CTb=S4h
@SDc=4=2=S8c@cQ2=d94=THd>C=3=d8f>352<D<bACDeA4Dd=CDe@CA3A48c=D<d
@cM4=4Hf@@deADHe=cDi<c4h<cL`>C4`=D@h>3M4<314>3Ti=SHi@T8cAC4cADD`
@S8`@C@c=d<b=C0cAD4e@DD`<TD==S55@SThADE5>30a<3Db<SU2=S4h=d=3A3E2
@C<e@dH`<T56=d94>C56>CTe=4Hd@S4h<cE3<T52AT<`3D8c=c8i=S96=CA4AD<b
@S<c=TI5>38aA3M6<3Lb=cLf>CT`ACI4@c<iACL`<3Hd>D<g<DE3AS@`@cU4@Pd`
>C0dATE6ACQ4<dA2=dE1A4D`<3Pd@cLc=S53=3He=cA5=38i>48g=S52ACPiAD91
AC<dA3DeAT@g<dH==CDg@T@h<3Lf<cPe<D4i<S92<3@h=SL`A492@cI6=cM4<3I2
=d8aAD55<S<dA3TcAC=6@c@d>4<d>CQ43C53@TA4<3Dc=cLd<3Df=SPbA3Hc>3<c
@c8`<34c=T54@C@dAD4h>D56<CE4>C8aAC@i<C<f<4@f=d4b@`db=C=6=S95A4De
=4Hb<C51<S95=C=2>491ACI2<CLf=SL`<3U5@SQ3<TA6<SHa=C56=34g<396<T56
=S8=A3Q2<21>A0d_F496820a=cTPDT@P<SA5@d94<3DcAD8iA44c<38a=38c<SA2
@T=4ADA1=DDhACDc<THf<SPa=D8f>48g@dDd=SA2<CP`=DA63D4h=THa<D<g<SDc
=dHc=d<`=CDi@cI2@C@c=c8e=D4e<4D`=C<`=C0d@S@i>CPh@CHg@c14<c=2ACDd
@Pdb@T<aAC=1<3Di>CU5<C4i<CE1AT4gA3Dg=cDiAD@h=T<g=T@eAC<e@D53=CTf
@c8b@D96=T95<c91<D@==DH`AT94<S=2<T@i@T4d>C8h=3M2<44cAD=5>3Lg=3Hc
AS56>3Pb=T=1=S=4>3Hg@C4a<C=6=d54<T8i3DDe<3@i<3Dc<SI1>C4g<CQ2=S@`
<CE5<d<d<454<4@d<S@h@DE5=DE4=dDc>48b=CI1<3=5=T8f<3Ti@`e1=CQ5=D8g
=34e<3Q6@T<c@c=1>48d@S93=D8c=C=2ASU4>3U3<3I1<D<g@D<h<dDc=CLd=3Th
@T8h84i43BmH@c0P834g<b1BA20b=4E3@T@`=C=5@SU5=3@`<C8e=cU4A3LeA3Pd
>DDeAD93A4<c=S<g<30`<S8i=d54<T55A353<4<b<cT=>44d=C<b=TH`@CM2>4He
@C4e<cL`=S=3<C8`=STh@SLiASLb<493@C=5@D8bA4Dd@SLh@dI6=3M4<SA63C12
=c8d<d8dAT8iA3Hf<CLa>316AD4c=3Lb@T@b>3Db<S@c=DDe@c8c<dA1>CE1=D@f
@S@c=38d@cL`=0da<3Hi>CM2A3Tg=SQ4=TA5@T96<SL`>D8`>3E5>CTh>C=2ASQ4
<3U5ADHf=3@dAC0d<C=6=391>4Hc@ST=<cPf<DA1=C11=3Di<314=S8`<c4d=cP`
<3H`@d8i<3A3=D4a=3H`>D@d>3Q3=C14=d56A3Pf<3M4@cU13DA5A4<eA456=c@h
AC@h<T4c=CDb<DA6<454=D=2@T4i@cPc<C0f<TI1<S0g=48PCT@=;eQ3<B0P=38P
DT@P<SA5@d94<3DcAD8f=dDc<cI1@C@g<S8b@S8i=CPh=d@b=TDa<S8d<3=5>C=6
=D4a>30d<d@cA4@f@S=33D<c>48`=CU6=4Hc<d<f=C96=C94@d8a<b1>A0d_F4<b
820c<b1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THgADA4@CU4AS0`=c8b<3Q1@SHe
>CH`@CTg<T53AT8b<T8`<D@g@d8=@c@c<SPc84i43BmH@c<P83D`8594838dAD=2
A30e<dE2@T@c@c4eA3Tf@dE3=DI3=dA5@cHhASI1AS0a<SPg=cA2=T@fACE4ASHg
A3T`<cT`<@db<d@iA3=5<T=2A3Q4@cLh=3Th>C11=4=2AC0b<d8aA453ASTh<T4g
84i43BmH@c@P83Ta8594838dAD=2A30e<dE2>3Le<d=1=4@fASPi@SDb<cTe<S<f
ASDd<354ACPi=CTe@D@g=455A4=1=3@h=c=4=`e3=cDf<C53=C=5A494<dHiA3E6
=D@c@c0b<d56<4I4<CE3=SDa=D@f@T<d<cLf=DI4=T@cACTh=30hA44==cA5=392
<SDa<TDg@D51<dE6>456@SPg=SLb>D55@cTd>3@a=TA1@DDeAS8h<S<e=S4h=d4f
ACDi>48f3CM484i43BmH@cDP838f=B1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=T<g
>D4e>CA2=c8a<cT`AT4`>C93<4Dd<T@c<TDe=SU3>D@`ASU5=T8=@T<h=CL`<CLi
>4Hg@SU5<c0b<CM6>3PcA4<i=C13<4E6<c0e>DI4=TDf@DE6=T4b=dA1ATHb<d4a
<D@`3D8`<d<a=3Hf=c4i<dE1@S<d@CH`<C8g<3Di=CU1<C@gA4@e=C4dASDa>DE6
ASHdAS51=cHd<d@h=D@d>@e1<c@hA3DfACLc<3M1AT8e<391@D<e=391>38h<C4g
@c4h>C4f=S16=3Tf>4E2<S16<S@d=T4e<d=5AS<=>34b=d8c<T96@CHd=CE1<DHe
AT<h<D8gAC11<T96<SP`<S92=CHd@S=5<CLd>491>C4`>C4c=C4`=STh3CTi=TDe
<CDh<4A4<394@TA2<d94A3@i@D<b<C=3<D@g<4<g=3@cAC8`<cHh@cE2@S@b@C53
AC<g=48f@@e4@SE4@S<f@cPbASE6AT=1>D8e=CU5@D@d@T<a=T8f=495=SH`=D8e
=3U4@CA1>CDgAS=6AC@eAT@h>CL=<3He<C8`@DA1@dA1@dE6A3<e@TA2@c92A30d
@c0h=3La=S13AC11ASE1<CPi<3=6A352ASA6>D<d@d523CPh>456=CI1=4A4<d<`
=S8b<4H`<491@S8e<SLh<T4g=3A3@STg=SPhAC@eAS<`A3U384i43BmH@cHP83D`
8594838dAD=2A30e<dE2>4@`>DHfA44d>DHeAD8a=D@a=S4e@CTf<DDc>DDe<D4a
ASHiAS@g<cQ5=d@h=CHg=@e1=CDd<c93@S=1=THa=3Hg<cP`AC4d@DA2<4<e<TE3
@d@`@SA4=d@`84i43BmH@cLP83Lc8594838dAD=2A30e<dE2>CPb=44`=S@i=STg
ACT`=d=1=4=3=3Pe>4=3=C<b@d92ASHc<TI3=4@b=TE5@CTg=@e6AD<e>30d@S8i
=314@D51@S11>3Tb=C56A494<D94A44h<d4cAC4b>C@d<S@g=d56>C0a<S<a<d4`
@D8==4E6<CI5ADE2A3@i@d91@d@g<D55ASE2@dDPCT@=;eQ3>20P=c<PDT@P<SA5
@d94<3DcAD8i>38d@C0f=3Tf>D<a>CTb@cTe@TE4>4E3@S4i@C0dA3Q5=d8h@c@d
>3E5<4<a<c523C<f>CP`A4@d=394AD4`AS52<cDa=S0g=SHd<d94AT55<3E6AC4a
=CQ3@cPa>CDeAS<g>4<f=T@aATE6@Pdi<SA5AC55<SQ4=D4b=C8b=c94AD<e<SI1
=b1>A0d_F4<i820e>B1BA20b=4E3@T@`=C=5@T8eASA5@DI4=STd<SP`=T4g=4=4
A4I4<cQ1@d53@S8`>CP`=3Q4@dDe=D<h=cHb<D<=AC94<3I1>CTa=SM3@cPa=CTa
@DDf>C<`=SH`=CU2AD95>3M6=T@d=CDd=dHf@CA2@c16=CM3<CQ3<b1>A0d_F4=1
820a<R1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=S0f@cDPCT@=;eQ3@R0P>30PDT@P
<SA5@d94<3DcAD8h<c4e<CTaADH`>C4c=CE5=S<a>D@cASTa<C0e=S53ACA1<T96
>3I6=cM4=c52<D4c3CTcASE5<CA5A3I3=d<c@cM3<S8i@C<gATA5<c@g>48c@d8b
@c4`=dI6<cLb@CE3=3<f<cPb<C8`<cHi<`e2>CA1=C53>D96>C51>D92>D<a@S0h
<T8h@T=4=d8f@T92@cDg<cL`84i43BmH@d<P834f>B1BA20b=4E3@T@`=C=5@SPc
<CDa>C55AS0i<C<e=DDf<c4iA3=6>C4a<3Df<D=5=44b@THh=THg=d@g<D8a@C<=
>C=6=DDa=4E4=T<g@c=3=d<b<SU1<cM6A4Dc=3Lh@S=3@S93<C0gATHc=c91=D<d
<cHc>38a<S0c=SPa3D=4<cHbAC94=dE4AT<g@C<`=cH`=cHc>3A3<S4a<3Dh@c0`
=SLh<DHe@c12>3D`<SP`=3T`<cQ2=3Q3=0deATA1@S4e@CQ5>355>DDb<c=2<TI1
@cLd@T@e=cQ3<dE6=S=6=38g>DI4<c@g=TA5<S8`AC4d<C4a=c@=@CA6=cM1@CPa
<T=5<3@h>CQ2ASHg>CDh@SPaAD4c<d@`=3@d@d4i<S0g@CLc<4A5<c@aACPg@cDe
<c0g3CL`A3L`<S8g>D<hASE2=4E5=S<d<S95@D=2ACI2@D8hA3<a<C1684i43BmH
@d@P838d=21BA20b=4E3@T@`=C=5@SPb>DDd=3A2<3DiASTe@C54=356AD<`=DE1
<S91@C4iA3<d@SE1<48c@cM5<S0`<C8=A38a@cLa@CPi@T96<STb=cPh@c<h<SLg
ASLb@CA6<DE6>4He<30a=DHg=C4`<DE6<THi@CPhA4@`<D@i3DE1@CTaAD4b@TE2
=c16<SQ1=S94=4Dh<C4a<cPa@d4g>CM3=S0f>4@g>48`=c=1>CI1=3E5@C@e=c4c
@Pe4=48d<3A2@T=3AD52<SHd=3Td=CI5<c<b>D<f<CPb@TE5=3I5<d8g<dHd<dD`
>D8`=C<a@DE5=3=1A3L==DDg<c0d>4I1<S52<THb=c8`@C4b>3Td=SPf<c<`<CP`
AC4hAC8a<C96=3Hg@C4a=D4i<4De@c0f=4Df3C<b<cH`=3=1<3A2=dA1@CA4=dHi
=C8i=S8f<S8eAD=1@cA1>3<e<THf>3H`=CTe>DHe<C=6=C55ACDa@@e6=c<eA3@c
=44`=TDb<3Li=T4h=TDhAD8i>34c@c@d<c53<D54<C4`>44cASLf=STd<cE6>CHb
A44i<TH=<C8hA4=6=c4i@dHc>313ASP`>C<`ACDd=3Pi=THh=T=3A394@S8c@D8d
<4<e=c4f@SPg>495@dHhACLc3C@c=3Lc@S1384i43BmH@dDP834f>21BA20b=4E3
@T@`=C=5@T8a<S8aAC8fAT=3A3Q5@STgA48c=S0a=d=5@CA2=3Ha=TI6<DI3=d<g
=S<d=SI3=3H=>CLe@S0f=3Hi<38dAC13@SE2@CP`@CTe=S@eAC0h=4Df=c4bADH`
<cQ1=CDf=4A5>391@C15=SE3@S513CTe=d51=cLi>4=2<dDa<TA4<D<c@D=5AS94
=34b@D94<DDc@C@c>3U1=SI4@C8i<THc=CA3>C14@CHb<Pda<C8h<D=5=4@e>3Db
ATHf@SPi=3Hd<T<b<D4c>CA5@cPd@cM5<38h=CU5=c51=c4h<CP`=dHgASA6A4@=
=TDf=c@eACTa<D@a>CTdACDi>CI3=SU5@CA1>3E1<S15ACHi@D4eAC=6ATA3A3Ha
>C12<cDh<dA6<TDc3D56<cI2=38d@CDi<TH`=TI6>3E1<S@`<C<f=cDb=SI1<T<f
<B1>A0d_F4=6820b>3<PDT@P<SA5@d94<3DcAD92@T@`<S0e<3U4=c4`<3E3=T<f
=4<e=D<aAT@b=S0fA3Tc<D@`<cLe>CA3@CDc>D@g3CI2<SU3AT=2<CLeA4<dA38a
ACM1=3U1@C@h=D4e>4Dh=S8c=c@a=CE2=STb>3@b<CQ3@C8b@S@`>3E6>0dbAD@e
=dE2>3A5<CHg>DDh=S4h<4=3@C@d=SM4<356@S96<CE5<c@`@C94>CDa=48e=d4e
A3I1=4=4>3D=AC12>C0c@d8f>3Da<4He<D<g<CQ1<48`=S8`<4E3<c4`@cI2@C@e
<D4hACDc<c@gASTf<T8hA4=6AT4`3C0c=3I6=3U4AD55<cLh=CDa<3U5ASHh=THg
A3U1A4DcASDe=S@f>CM4=C=1<4I3<D93<CQ6=cE3AS@h@`dh=c<h<D<h<c<e<dE1
A3A5ASDfACLf@d=2<48g>3Ld<C<e>3P`@C95<c0h<C=4<4@`=48i>44i<cHe<d4=
@d<c=c@`<C8i<SE4AT8b<CLf@DDg@CQ1ASM2=SI1@C<eATA4<SM3=dE5<CE2AC4i
>DA3ADI2@SL`>3Q33CPhAC4e=cTf@D8bAT4f=DDi@CI6=T54@CA3<S14>4Hg>C16
=3M4<D<g@SHa=cT`<T<c=S=3@dA6>3I6=0e3AD8fA3Dg=c<f=S4c<3Pd=DI2=T4e
>4D`<d@c<CI5@S=1@C@cA354@cDb=4I3<T53=S@h@SPcASM2@S8=<492=S4i@CQ3
@T=1<44d=38a@TA1AS8c=SPPCT@=;eQ4<20P<SHPDT@P<SA5@d94<3DcAD8i@THg
@CPgA3Ti@DDgA3U3<T<a=C8cAS<b=SPi@T56ASM3ADE4@T=3AR1>A0d_F4@a820b
=R1BA20b=4E3@T@`=C=5@T8eASA5@DI4=T=1@c<`>3D`<S4e@d<g>CA4=c93=48b
A4D`<C@d<SA284i43BmHA38P834b>B1BA20b=4E3@T@`=C=5@SU1>4Df@cQ6ACTg
A3M3@dHc@DI3<d53<38h@D<h=34h>3HbADE2AD<a@D4f=c=4=3L=<CA4>34c<c<h
@SI5<TDiASL`>D4a=3Q2=cU4>D@d<C8dATDdAT8h<THbAD=5=3LaACTf>C4f>CDg
=4Dg3CHeA354A3I2@CP`@CPdAC0iACDh@SU6<d8g=3DdA456=S91@D@f>D92ACDe
=3=5=dI2<d8a>CM2@THd>@dg>44`=c8f>CE2=4HbAD=1<cDbADHh@CHf>48e=T@d
>44a<cM3AD54=C8`<d<i@dDf@DDb=CE3>38d>C8==4<i>DI6<TDb<d<c@c<`<3Q4
84i43BmHA3<P834b>21BA20b=4E3@T@`=C=5@SU1>4Df@cQ6ACQ4<CE3ACP`AT4`
@SQ6AD<g>CTh<48g>C<g=D=5<48d@T4a=C14=S4=@d=4<C8i>D<h>CU6@d51=cHi
<C54@S4i@c<i=SPbAT=5=T95=C4`A4=1<D56>3I1AS91=C4d>C91ASPb3C8c<3E1
=SE6@TI3@d<g@SA1<C=4<SPg<T8g>3Q5=SPd<3<gA3Q4=T=4<34c=STi=dE6AD@i
@c@a@TI2<`dc<CA1>4HbATE2>3=4@SLd@S4g=dDc<C8cATDb=c=5<C0e>C8c@SLf
=cDeASA4<D4`>C0`ACPi<T4i=4H==c=6>CPg<34e<cU1@c96=B1>A0d_F4@d820g
<B1BA20b=4E3@T@`=C=5@SHgAC<c=T51=3La=SM6=S0`<dH`=S8b@dH`=cPi<SA2
>C52A3@d<S@a@D<`>C=5=4@=<30hAC16<3E4AC<h<cLgAT8b<c@d=454=d4e<4Df
<CU5ATI1ACPi@cH`<C96=T<`ASLf=T8g>4DiA3Pb3CHb<D=3>38i<D@b<44i>3D`
=DA4>3LPCT@=;eQ4=B0P=c0PDT@P<SA5@d94<3DcAD8f=dDc<cI1@C@f=3Hh>3M1
ACQ2>C@f@d53=C0hACDaASTc>DDbAC4h@C=6@c8`ASE23C4i<cLc=SQ4<SDc=d@d
>C=4=T4g=c<g<C52@T<c@CM4=T=3>C4i<CHa@CE4@dDe@C4c=d51=34aA38`=`d`
=DDb@D=4=D56@d@c=S=2@CPc@b1>A0d_F4@f820e<b1BA20b=4E3@T@`=C=5@SPg
=C=3@CA4=THgADA4@CU4AS13<dHbA34`=c0c@S94>CU2@S0a@C8a@CHi=48`=DH=
<D8g=d<h<493<d@a<cPh=cI2<D@e=S<dASM1<3Li=3HdAD<i<D53ADA1A38`A21>
A0d_F4@g820f<21BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THgADA4=C@a@CA6@cI3
<C@i>C4`<CU5>D@aAT8c<34c@SHa=4E3=DH=ASDg@CE2@dHi<cPd<S4i=dI4=c0c
=SQ5A3<iADDc>3Pb=d@g=DI1<3<hASPe=dI2AD@`=DE2=SI3=T5284i43BmHA3PP
834a=R1BA20b=4E3@T@`=C=5@SU6>3H`AT=5@CI3<SPd@CLi=S8`=3Ha@cPa=c4f
=S91ASPh>3Pf=S<i@CL`@T=3ACL=ACA1<3<f=3Td=SE3ATHi<D8`>44d@STc@dE2
=C54<CU2=CPi=CHi<D=3<D54<3Lc=cL`=SA5<S@cA48`3CU1>4=3@dHe=cTe<S4`
=STg<c8d@cPiAS92>3<d>4E3>3E1<SHa>3I4@d@a<S93@dA6<CQ5<c16=CPhA0e4
=S92=D@i=C53>CI4<S4a<CTh<4A2>4E3AT96=cQ3ASDi<cDa<CI5@C@c=38c=dI1
A4@i84i43BmHA3TP83Ld8594838dAD=2A30e<dE2>DA5=d8`=T4h=cHe=D95<4=2
@S@a=cTa=4@a<3U4ADA5>3Tf@T4`ATE2@d=3<d8e=0dh>C=2AS4c@S0hASHh=S12
>3Pd>C52@SPg@D<d@CI4=DI4@CL`@c96AC=3<DDc@TDgA4Hg@C4f<CI5@c@=<dE6
<C4i<C8i<DDb=C16@C13=3Hg<S0aAD@g<R1>A0d_F4A1820b>B1BA20b=4E3@T@`
=C=5@S15@S16<d54ACU2@C<a@S=2=3Lc>44a=cPf<D51AC<f=4@i<4E2<C4b=d4c
ACTc84i43BmHA48P834c>B1BA20b=4E3@T@`=C=5@SPb=SLc=STh>3T`@dE4<SE6
A4Df>D=6<STh>D92=CU2@THh<S52A3Hh@D4i<TA3<4@=<dE2<cM5=S11<DA2<T51
AC11=d<b>3Te<3<`=c@`>34b<4@b=S0`@D4i>44d<DDa<CTfAD4i<C13<T8d3D8d
A3=5<44`<48g=392<38g<D<cA3A1>CU6>3La=D93<3DeAC56=3Lc=SM6@d8dAT@b
=SA4A4@f<3=5=Pde@S94ASLf=CM2<SI2AC4h<CDa<D4aA38c@cLb@cDd<S=5=SDh
ATI4<d<dADD`<cLc@S8f<SH`>3Ta<TD==C<f@d8`@T8iAT@bAT4g@T56>CTfAS0e
A4Hf>34hA4Dg<C54=C@PCT@=;eQ4@b0P=3<PDT@P<SA5@d94<3DcAD8f=T95<C<a
<cPa<c0c>C93>CA5=496<3I4>CLg@d93A3TdAT@f>30c@D@a=dA2=CQ23C96>38g
@d4a@SLg@c0`=SHcACI5=TDg@DI284i43BmHA4@P83@c8594838dAD=2A30e<dE2
=SI2AC4c<C<h<C<d>4I5@SPc<S<h<3Hg@S0g=48e@CM5AS0fASM6@SDf>C<a=S96
<Pe2ATI1ACTg<d=4=48dAT=5=T8g<34bAST`=21>A0d_F4A5820i<B1BA20b=4E3
@T@`=C=5@SU3<d93<SDiA456<CA5<D92ACU1>CI4=C54<C53AS<c=C4b=CDb=CPd
>C=2@T<g<T@=ASLi<SDbAD4`A3<hACTe<3He=48h=3Pd>352@C0hAT<d>3@a@d@b
@SPb@SE4=392<T<`A44gADE6<3E53D=5@DHa@C13=3Da<4I6<D4d<S4f=C4a<c4f
=38eAC94<cA3=48f<4I3@CE6>392<30h=CDd<C0b<456@`di=R1>A0d_F4A6820a
<30PDT@P<SA5@d94<3DcAD8i@c=2@c8e>DA1ASLc=SU1<3@eA4Dc=d=1@S8g>C51
A3A2@c53>392>3<fASHh=D4b3CLd@CM1>CDgA44c>CLg@S52@T4c<dDd@DI6>D<d
A30h<311>D<d@S@cADHdA392A34dAT8i<3PbAT4f<0e1=C53=D@e=C<bAS11AT=6
@CTd<4=3ACA3@cLcA4Dd@T54<cI3=4I3<D@g=T4h>4I5=SQ5AD4iA492@c@=>4H`
@dDi>D93=T@g<d92=3HgAC4PCT@=;eQ5<20P>3LPDT@P<SA5@d94<3DcAD8h=cDc
@d4dA3I6=c0f<C96=S91<CHbAC<f<c91>DDc=44hASI5<C91A3@gAC8h@CDh3C0f
<S@d<3E6A3<`AT8d=3Df>4He<S8h<cE2=CPf@d@e>3U3A34e>C4bA3@c<3E5=CM1
=d@a=4E3>CTe@`de=SLb@cPa@c8h<cHb<38f<3Hh>C53=c4iAC8dAT@a=3U4<DDe
<dD`=D4f@CLg<c@`=C4cAC8PCT@=;eQ5<B0P<STPDT@P<SA5@d94<3DcAD8h=cDc
@d4dA3I6>3A6>CLb=4Dd<d93>C@iACLa@cPg>48i=3Hh@S=2=CI4<dDdA21>A0d_
F4Db820g<21BA20b=4E3@T@`=C=5@SHgAC<c=T51=3Hd=T8c>4<c>44c=S<e<4A3
@dI6=dE6=D@g>D@fAS4a<d52AS0d@cP=<D@g@d94ASM3=c13@T=6A3Pb<TI6@cDf
>D<d<CQ6@c@h<T8f=c15=T@g=SLc=c=5@c4bATA2AS0i>D<b3CE1>D<c<TDgAT<g
<CDf<C8h@SE384i43BmHAC<P834b>21BA20b=4E3@T@`=C=5@SU1>4Df@cQ6ACQ4
<CI3=cU5@SM6<d8a<S@e>3U6AT56=3Tg<c=3<S8hAS8d=3He<T4=AS11<SA4=TH`
>CPd>D@eA34dACLhATE4ADHg=DE3@SLeASLi>30b=dA6=3Q3<C8e<C@h<C92=4He
@CTh3CU6>C0d<dI6AT54>3@g>4A4<c<f@c8iA3Dh<d51ATHc=S@g=cPa>34e=3Q4
AD4g=C55AS<`>3Pd=48g=`d`=3D`<S@h@cI4@D8`=4Hi@dE4ADDa<c@dAT8i=d<b
@SHiATA2@S8c<4Dc=SHb>3<`@c@d<SM2=cHgAC0=@S<`=S0a@CDb=D@i<cPbAR1>
A0d_F4Dd820c>C<PDT@P<SA5@d94<3DcAD95<c0b@c4cA3A1ACE1ASDcA48g=C16
>4A1=D52=cE5=D<d@c8bAS<b=CE1A3M1<d=23C8f>3U5@dI4=dHh=3@d=C4g@C0e
=d@f<TI6<cLd=T4h<d<h<TA4=4Di<d=1ACA2@D<h=D@h<C@b=495@`e2<S54@THd
=CM6A4<f>4Db=D@b<3Le=d<b=c4gA3Hb>3T`>D@e<d<g<TE2=S0c=dI1@C@e>CU6
A3@e@DD=@C14>D<`ASDfA34a=d8a=CQ6=S4`A3Pa@c<a<T<c@CU4ASPd=DHd@THa
@C4d<STi=ST`<CPh>CHa=SDg3CPb@CHcAS15=d8fA452ASE1@D96A4Ha@dD`A44a
<d=5=D4aA3Pd@C0`A4Ha=cI4<T@c<SLi=SDgASA2A0e6@c<g=c55<D<g@S93<4@b
@c8hAS4i<38`<cM3=C@i<dI1>4<i<SHa=TDb<3@c@STc@D4gATA2=D4e>3@=AS4i
=cI4>3Lb<D95<c4b@c8h=cI2<dA1<C<d<4@a=496<T=1>3Q5@CHe>CTd<cI3<491
=SPf=3U5@TDc3D4aASQ2>CA2@d=4>3A4@dA1<D=2=T4e=3Lh>4Hb=S16<cE1>395
ACI6=SQ4=cDf=30a@STeAT8e<SM4<`e4ADE4=S8c<3U1<d4b<SE4AD55AS4d@cHd
AC4g<c91=3A2>4A4AC8h=d4a@T=1A4DhAC4f>DA4<DHc@C8==d4c>3Ta=CA1@T<`
@SA5A3Df@cQ4=c=3<S8c>4@f>314=495=C0iA4Dd<D8fAC@g<c@c@SU5<cLg@DA2
3C<c=3I3<4@f=cM6=315@SHcAS0d@DA1=SI6ACDgASI6<cHhA4E2>4<a@STe=D91
A4@f>44g=S0c>3M2<`de<dDi<dDf<dA1A3T`>D=1@DDg@d8e<DI4=DA3>4I4=SA6
>30e<CI1=38d=SHe>492@T8c>D56@SE5=S<=@CTc@C@aA38c=T@fA396=d8fAS@d
ACI2<SQ5ATI1<D<bA3Q5=C4a<c=1@S<h>C4f=D56=S8b>C=1@SHf3DDe=S52=b1>
A0d_F4De820h=R1BA20b=4E3@T@`=C=5@SPc<CDa>C55AS0i<C<e=DDf<c4iA3=6
>C4a<3Df<D=5=44b@THh=THg=d@g<D8a@C<=>C=6=DDa=4E4=T<g@c=3=d<b<SU1
<cM6A4Dc=3Lh@S=3@S93<C0gATHc=c91=D<d<cHc>38a<S0c=SU33CTa<SLh=SI4
@CQ5<TE3=c55=C8c<4Hd>3=4@SHh=S<hASQ2AT54<c4`ATI6<D=1@S@a=S0PCT@=
;eQ5=R0P=c<PDT@P<SA5@d94<3DcAD8iAT=1@C0g<CDdASU2@S0`A3U5<D8d@c13
A394=S0a=4A6=3=4>C=3<4Hc<D=6=38b3DA2@S0h<S4b<d4g<30h>3M5ATE5<DHf
=4E6=C92@CU4AS94@DDg=d8i=DA5@C91AD4g>D@`@SDi>CM3@Pe1<DE3@dHh=S<i
@cQ3<3<iATDeA3De@CLc<R1>A0d_F4Dg820h<21BA20b=4E3@T@`=C=5@SPc<CDa
>C55AS0i<C<e=DDf<c4iA3=6>C4a<3Df<D=5=44b@THh=THg=d@g<D8a@C<=>C=6
=DDa=4E4=T<g@c=3=d<b<SU1<cM6A4Dc=3Lh@S=3@S93<C0gATHc=c91=D<d<cHc
>38a<S0c=SU33DI4<4@d=cQ3@CQ3ASU4=DHg<cLh>DI2@CHh<4Hd=3H`=STd@d<f
>C<PCT@=;eQ5>20P=c8PDT@P<SA5@d94<3DcAD8iAT=1@C0g<CDdASU2@S0`A3U5
<D8d@c13A394=S0a=4A6=3=4>C=3<4Hc<D=6=38b3DA2@S0h<S4b<d4g<30h>3M5
ATE5<DHf=4E6=C92@CU4A3U3=D<f=CTb@cTh=cE2>D8`@d=3ASPd@D=6=0da@d8`
<3Hi=4=4=STf<C4hACQ6<3M5<cPPCT@=;eQ5>B0P=SLPDT@P<SA5@d94<3DcAD8i
AT=1@C0g<CDdASU2@S0`A3U5<D8d@c13A394=S0a=4A6=3=4>C=3<4Hc<D=6=38b
3DA2@S0h<S4b<d4g<30h>3M5ATE5<DHf=4E6=C92@CU4AT@a<SPbA3@g=4Hf>D4f
=cU6AC@d<S0`@T<g=0da>C14<S4e=c8d<d96AB1>A0d_F4E1820d=21BA20b=4E3
@T@`=C=5@SHc@S<e>DE5=3@`<c12>CQ1=c4`AS4`=d93=SQ1<cI5<S15@CE2@c0b
=d@f@c8a=cD=ASPh<c@g<DDd=SHb<c=4A312=TH`>3Pf@DI2<R1>A0d_F4E2820e
<21BA20b=4E3@T@`=C=5@SHc@S<e>DE5=3@`<c12>CQ1=c4`AS4`=d93=SQ1<cI5
<S15@CDcA3I1<CTf=S0h=3T=<STb<DHg=3I5@c@f<C52>3A6=S11@D@g>396=S4g
<cHf@d@e=c0bAR1>A0d_F4E3820e<B1BA20b=4E3@T@`=C=5@SHc@S<e>DE5=3@`
<c12>CQ1=c4`AS4`=d93=SQ1<cI5<S15@CDf=c8i<cM2>4D`>DH=@T@`=4E5=CHd
=3Tb=T<a<cA2=3Q2ASQ5>DHd@D8h<TI5<c@d<cI3@d<c84i43BmHAD@P83@e8594
838dAD=2A30e<dE2=S=2<cDiADDd=30c<48i>44g<C16<C0g@T<f>44c=TDb<4E1
=CI2ACQ3<SM6<3Pb@@de<3TfAS12<S8c=c@e<D4f>4@iAC=5@S52A48hASPPCT@=
;eQ5AB0P<CDd8594838dAD=2A30e<dE2>38iAC@d=48`=CU6>CE1<D@d<DI5@c0e
AD4b<T51<CU4<cA2=D4`@S=3=dDb<30a<Pe4<S53=c51>3U2@THb>C8g>3Q3<cPb
=cM6=c91=4HaADHhASD`<34eASLe<C0aADHbASU1>3Q4A30aA3T=AD51>C55@C92
AD8g<4Hb>44f<T@dACPa<C4c>353@CLi=d<f<3HhA3Lh@S0g<d4i=T4d=DE1=3Dg
<C=23D@d@S@`=492@d=5@D8b=S@d>C@e=TDc<c8i@cHa>392ADDd=TDc@SLcAS@c
AC0i@S0e<c51ADDd<d54=`deACLc<3@hAT4b<D8bAS8g<S11<C8h>C@f>3Hc<dH`
<4H`=48b>3He<d4h@cTiADE2=3Q2@c@e<D8`@S4==DE5ADE1<38PCT@=;eQ5AR0P
<CH`8594838dAD=2A30e<dE2>38iAC@d=48`=CU6>CE1<D@d<DI5@c0eAD4b<T51
<CU4<cA2=D4`@S=3=dDb<30a<Pe4<S53=c51>3U2@THb>C8g>3Q3<cPb=cM6=c91
=4HaADHhASD`<34eASLe<C0aADHbASU1>3Q4A30aA3T=AD51>C55@C92AD8g<4Hb
>44f<T@dACPa<C4c>353@CLi=d<f<3HhA3Lh@S0g<d4i=T4d=DE1=3Dg<C=23D@d
@S@`=492@d=5@D8b=S@d>C@e=TDc<c8i@cHa>392ADDd=TDc@SLcAS@cAC0i@S0e
<c51ADDd<d54=`deACLc<3@hAT4b<D8bAS8g<S11<C8h>C@f>3Hc@TDi>3@d=T<i
=SQ6<391ACDg<c8g<C4a<SDa<S@h=SH=A4=6AD8a<D<eA3<c<4E4AS91=T4PCT@=
;eQ6<20P<S4i8594838dAD=2A30e<dE2>4H`=T@f>DH`AD<eACA5=T<bASH`=38i
<dHe@T<g=S91=S4d>CDb<DI4@cLa<3I1=Pe6=d4c<D@i>C8iASPf@C<a=dD`AT@c
=cE4=D8h=D@d<311=3Df<4@a@c@`=TD`>CTc@cLa=C0g=C<f=4H=AD<dACDi@cTd
<c4hAT=1AD<e=SHc>CQ2<3Hh<DE6<4I1=C91@cU5=T8b@cTe>D<a=3Tb=34hADI5
@C@a3DH`@SQ1<cD`@S14A4<c<d@c=d<`<D8h@D8b=44e>4D`@CTd>CLf=cH`=dHf
=3Ph>4I2>4<a@T51>3M4@Pe4<d@e>CPh>DDcA3Li@c@c<d@e<4I5<DDb@CHbACDh
<dA1=3M6@THh>DHgATA4<3Lh<3Db<S<d@TDe@D4==3PdAS0d<CM6<T@c@d=4>DHg
<T@c>C8gAD@d<3Tf@CD`<cDiADE4AT4bACA3=c4i<SM5AD@d>4Ha@CHh3D56<3La
ADE6@c91=dE4<dE1<CT`@C8h<3Lb=d=5AT@e<48g@CQ2<CE3ATDa>D52=c0f=dA4
=cI3<3I3A@dd=SHc=cLi>312<CM4@C0g@CPPCT@=;eQ6<B0P<CDe8594838dAD=2
A30e<dE2>38iAC@d=48`=CU6>CE1<D@d<DI5@c0eAD4b<T51<CU4<cA2=D4`@S=3
=dDb<30a<Pe4<S53=c51>3U2@THb>C8g>3Q3<cPb=cM6=c91=4HaADHhASD`<34e
ASLe<C0aADHbASU1>3Q4A30aA3T=AD51>C55@C92AD8g<4Hb>44f<T@dACPa<C4c
>353@CLi=d<f<3HhA3Lh@S0g<d4i=T4d=DE1=3Dg<C=23D@d@S@`=492@d=5@D8b
=S@d>C@e=TDc<c8i@cHa>392ADDd=TDc@SLcAS@cAC0i@S0e<c51ADDd<d54=`de
ACLc<3@hAT4b<D8bAS8g<S11<C8h>C@f>3Hc>D4b>D8cA3Db@TI1>D8cAC16@cM2
>3Li>CT`<C@d@S4==dA6@C4h<DHa<b1>A0d_F4Hb820a<cDPDT@P<SA5@d94<3Dc
AD8h=cDc@d4dA3I3=cTb=C<b<cE5AS@c=c94<S4`@C55<dD`>3HfA3Q3@T@i<S0e
<4Hh3C96<48aACI4@C0g=CI5@cQ6<391<3Pb>C@h>454<CA6@SM1=TI1>CLd=3M3
=D8a<D=1AS@a@S0g=3Ha=0e2@SA6AC52@DI6>3He<d54=3P`=D95<44b=T<aAD4`
@TI3<4@a>3A1>DA6AD<h=DA4=cU4=dE4<S0`=CH=>D8b=D=1<T@eA38g@d54ASHa
=cH`AC<iA355=353@dA1>CLi<CQ1=D8e@DDd=cTe=D8`@D8b<c4g@cQ13DDe=S0f
=SLf<D=4>395<4H`@d4b>C8b@D8dA391AB1>A0d_F4Hc820a=38PDT@P<SA5@d94
<3DcAD8h=cDc@d4dA3I3=cTb=C<b<cE5AS@c=c94<S4`@C55<dD`>3HfA3Q3@T@i
<S0e<4Hh3C96<48aACI4@C0g=CI5@cQ6<391<3Pb>C@h>454<CA6@SM1=TI1>CLd
=3M3=D8a<D=1AS@a@S0g=3Ha=0e2@SA6AC52@DI6>3He<d54=3P`=D95<44b=T<a
AD4`@TI3<4@a>3A1>DA6AD<h=DA4=cU4=dE4<S0`=CH=>D8b=D=1<T@eA38g@d54
ASHa=cH`AC<iA355=353@dA1>CLi<CQ1=D8e@DDd=cTe=D8`@C15=3Hf>DDg3D4b
<STe=3Hc=4=5ACI2<dHeA48i@cTi@TA6AD8b=S0a>356>312=THhATA284i43BmH
AS@P834c=B1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=T<g>C8e<c8c=DE6=3<g<T@b
<C11<DDcAC0h=SI4>4=2A3Tb<3D`ASP=<TH`@S55=TA1<3Le=TE3>4H`<T4`>38i
=3Ph@D@a=4I2=d4fAT4i=c@d=d<e@S4a@d56=352<3Ld=S4d3D92=4I5<D91ATHh
=SDc@D@d>30e@TD`@C8f@c55@C12AT<`A34h=44iA4I5@cPeA4@g>D@gAD@b<30e
=Pdi@S8e@d4bA3E4<SM3@DA6=S4g=S15<cU4<DDd<D=3A44i=cTa>44e@SE1AC@g
>CDe@S0e=DHb<3Ha@SH=A4E6ASQ3<T8c=TA1@THb@T<`>C8gACL`>DI5=C<a84i4
3BmHASDP838f8594838dAD=2A30e<dE2=T<b<DDgA3I3=3U2<C0g<CTf@DI5@SPd
@c=2<CTc@cTg=c0`@c4e<C<PCT@=;eQ6=R0P<cTPDT@P<SA5@d94<3DcAD8i@d8b
>CLb@d8`>CE4=S0`ADA3@DDc=S<eACP`<SDh@SQ5@C8`@S=6>C15@CDb=C953DH`
@c92=TDh=c12=S@a>3Q6=B1>A0d_F4Hg820a<30PDT@P<SA5@d94<3DcAD8i@d8b
>CLb@d8`>D96=SHdACDeASLd>3D`<D55=T8hAS<`AS<a>3TiA4A6=D4c<3@c3CDe
@TI6<D4dACDdAD@h>C52A352A3<g<30d=3Ta=3E6<393<3De<D<b<DHc<T8i<CPg
@S53>4=5@S4eAPdc@d=2ASHf=S8b=d8dASQ2<4@i=c16@SDfAD4`>D8dA3M4@CLi
=3M2A4Hc<3Q4<S4c<SE2AS@iA3U5A3H=A3DiAS8b=T=6>D=3AS@h>3=6<T8PCT@=
;eQ6>20P<SLPDT@P<SA5@d94<3DcAD8i@d8b>CLb@d8`>D@e@CDe<30`>3Pg@S@d
<dA2>CHa<d93@c4d>CA3=D9484i43BmHASTP83Ta8594838dAD=2A30e<dE2>D=2
<STg<T=2<3Th@cPfAT4c<S12A4Hd@dA1@D91<T=5A494>3I2@DE2<cM6<dH`>0d`
=T92<TDh<C53<CD`A3I3AS<g=34a@cLa@TA4ASDcATE2@SDh<c4i<3<c<SDeACPi
=S@f<SPi<dHf<T4==44b>DA5=D8g<c0b@T8hAT<b>CLgAD@h@CQ6>30i<D@d@S0d
@dA4AC55>DDh<C<b<CM1<4E6<c4i>CM13D8i84i43BmHAT4P838e8594838dAD=2
A30e<dE2>D=2<STg<T=2<3Tf>3Pa>D4b=DHb@SE1A3I6=3E4<THh<4Hi=3Ld84i4
3BmHAT8P834c<R1BA20b=4E3@T@`=C=5@SU3@S8i=c93@S0i=D@f<3Hc=351@C12
<DHd@SHd>48b@S0h>CLd=C<h<C<g<S4d<C0=AD<gAS4dA3Pe=3Dh>3U6>CDa<D<g
<S4bA4@b=4E2ATA2@C<d@DDg@CI3=SHaAS55AT91@SD`=cQ4>CTh3C0c<d@h=S0d
<S@i@CQ4<d<b@c=2>3La=DHh=dDb=c0b>3Tf=cDg=c<f=38a@C14@SPf<STa>D8c
<3M6>0da<S14<DI6<d<i<3Hc=3I2=3U2@cHh=38d<3=6<4@f<4Hc>D@a<3M4=d<i
A453ASU6A3Q5<c91AD54=44=<STc=3TfASTc>CTe=cDc<cE6@STg=d@a84i43BmH
AT<P83Ph8594838dAD=2A30e<dE2>D=2<STg<T=2<3Tc>4@b>CLg=C93>C<dASHi
>4Hc<THa=CPfA454A3Ha@c14A3TaA0dc<38g=d@`<C93@TD`@d<h=CHi=TE2A34`
=c0e<S@cA30e@SM2ACLc>D93>394>4A3=3Hd=SDd=C<i>CT=@DDa>D8aATA2@S8e
<4<iA3@i=SA3@THbACP`<D8f@C0f@d=6>D8b=SDfADDi=48c<dHe@cTd=4HPCT@=
;eQ6A20P=3DPDT@P<SA5@d94<3DcAD8i@d8b>CLb@d8`>CLg=STd@cLe<CTdA4I6
A4I4>44i<CI2A4Dg@DI3@C<d=392ACM63C=5>3PhAD96@c96>CT`=3Pb<CI6=DDc
>CHg<SDc@B1>A0d_F4I5820h<R1BA20b=4E3@T@`=C=5@SU3@S8i=c93@S0f=cDc
<SI3=cM1=d=1@SLg=DI1=S56ASTg=SM5@CDd=3LeATA1@D@=<C<f<SE5@cHa=cM6
A3He>CPd@d51<ST00:40`03kACHc<TDaAC8`@c8`<T4hA3Pa<CQ1AC<`@S0iAS=2
>3PcAS<eAPd`AD4dAC4h<c8e=DI4<3Pg<SU6>DHa>3Pi=cE1<cLi<C8cA391<cHi
<34i@b1>A0d_F4I6820c>B1BA20b=4E3@T@`=C=5@SU3@S8i=c93@S0i=D@f<30c
ATDgACU3<C<`<CI4@TDi@dA3<c8d=S8c<3Ld>456=3<=<CPc=d8e=c=6<CTf=dI4
>34g84i43FE^I0eUKV@=L7Ed3G1eM0eTMG0P;dI_KWA>HFeU86MUM21UN6=X86AU
IVU^IFI_KW@PL6m`3BDUAFiTDVEcKgEbHfDP3@d00:40`07P;emOGdI><B0_AfE^
IGIQ82m7IFiUMV4PI7E`86IYKVAVKfid86AeL20_@fQQLU=dLVU^Ig<PJfi_MfhP
Nf9UIfU^84=XHG9CM79YKVMc82m1I6UULVEcJG<PJfi_MfhPNbda87ek;C5m86UV
IFacIB1UKVAm87]`Kg0P;C5m86UVIFacIB1bIPd`86UT3C4PIV@=<20b<38PM79Q
KW=/HGAU3C<`<20]<c0`87=SK6T=9BE5KVACIGAeL20=9BE2IFMYKU1QIfECIGAe
L20=L6d=9BE5KVA@HFMUDfEdMG0=;dAUMVUSIE97@R1cHg<=<20`830PIS<=<2ha
<SD`830^<C8e<21cL0dP<21/H`dP<R1/JPeD87=Q3BE`HFMU879UHg@j834i<R0g
>20c>C<P<SLh80ecM6d=<2hf=SPP<2hf=SPP<2hf=SPPIS<=KW0=<CLc=2ha<CPh
834g<c@^<C4h>20a=c@b;SPa<3LP<CLd<Rhh<C0g86E`3FAU3C0P<20`86Hc3C4g
;S<f<C0P<CL^<cHa<21cL0da<Bhe86a]3B0`86aZ3Fi`3C4g<c@^<C4h>20a=c<d
;S4a>3PP<CLd<Rhh<C0g834g=38^>34`=b1UL0eTL`ebM6d=0:40`01mLgA]3C4^
834^834^86Hc3Fi`3C4a=cT^=S4e834a>3L^=cDb=B0a=c@b;SPa<3PP<CLd<Rhh
<C0g86E`3FAU3C0P<20`86Hc3Fi`3C4a=cT^=S4e834a>3L^=cDb=B0a=c@b;SPa
<3PP<CLd<Rhh<C0g86E`3FAc3G9dK@d00:40`027LgA]3C0^=cPe<R0`;SLh=C8P
<2hg>3Db86Hc3Fi`3C@f<2h`=3Th83@f<bhb<S<d834g=38^>34`=b0a=c@b;SPa
<3LPIG0=I6D=<20`830PIS<=KW0==3H`;S0d>CPP=3Hc;S8b<c@P<CLd<Rhh<C0g
834g=38^>34`=b1UL0eTL`ebM6d=002Q0<00M7=dK@d`830P<21V<`e^L0db<Bhg
<34c838a;SL`<C<P<CLd<Rhh<C0h834g=38^>34`>21UL0eTI@d`830P<21V<`e^
L0db<Bhg<34c838a;SL`<C<P<CLd<Rhh<C0h834g=38^>34`>21UL0eTL`ebM6d=
0:40`011LgA]3C0P<20`86Hc3Fi`3C4g=38^=cT`=20a=c<i;ST`=CPPKG@=<S4c
=Bhe>3<f834e>34^=3Pf=B1/J@eTL`d00:40`003Ig<=002Q0<00_S0P<20`86Hc
3Fi`3C4i=CP^>3<d=20a=CLi;SLc>C8PKG@=<CTe>2hh<c@d834e=cT^=c<i<R0a
>CDe;S4i=34P<CHe<bhi<c@d838`<C0^<S@i>B0a=c0e;S8d<cPPHg@=<S0d<Rhf
=C4c834f=cP^=CPd>20b<CHc;SPf<CDP<CDf>2hi=SHc838a=S<^>3Ha=B0a=CHh
;STf=S<PHg@=<CTe>2hh<c@d834e=cT^=c<i<R1/J@eSL0eTI@d0X@3000=WLPd0
0:40`004LWA]3@2Q0<00?g=dK@d`830P<21V<`e^L0da=c@b;SLi<3@P<CLc>Bhi
<3Dh86ed3C8d=S4^<C0b>20h=3<^=S@c86aY3FAc3@00X@3000=WL`d00:40`02f
<20`830PIS<=KW0=<S<`=Rha=3Ta83Tb>2hf=S0d86ed3C8c<3H^<C@i<B0i<SP^
=SH`=20b<c<i;S<a<c@P>CTe;S4c<3TP<S@a<Rhd=3<e834`<C8^>C0a86=d3C8d
<SL^=S<f<b0i=c<^=cPi<R0b=3Li;SHb=c4P>34h;SPe<c8P<S@g>Bhf<SLa83Pa
>2hh=C<b86=d3C8c<3H^<C@i<B0i<SP^=SH`=21/J@eSL0eTI@d0X@3000=WLPd0
0:40`004LWA]3@2Q0<00?g=dK@d`830P<21V<`e^L0da=c@b;SLi<3@P<CLc>Bhi
<3Dh86ed3C4f>C8^>3Lg=B0c=Rhc=CDe86aY3FAc3@00X@3000=WL`d00:40`02^
<20`830PIS<=KW0=<CHb>Bhh>C8P<S0a;SDd<C8PKG@=<CHb>Bhh>C8P<S0a;SDd
<C8P<CHi>2hb<S8h838c<2hf>30d834g=SD^=3<h834i=Rhh<STe86=d3C4g=C4^
=SHf>20a=CL^<CTd>20a=ST`;SPg<c@P=Bhd>CHi834f>C0^>3Lc=20e;S@i=STP
Hg@=<CHb>Bhh>C8P<S0a;SDd<C8PK6T=Hg0=I6D=0:40`003Ig8=002Q0<00179d
K@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d0
0:40`01FLgA]3C8`>2hc<c8c86IdL`d_GemOATha86=fLfH=<20`830PIS<=AR1c
H@da>3Pb;SHg>3HP<CPc<Bh`=C4b86ed3BQb:B0PLfQ_M`eD87=Q3G9dK@d0X@30
00AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830P
IS<=002Q0<00EW=dK@da=CH^<S@i<R1VM7<=;emOGdI><B1SMW=V3C0P<20`86Hc
3DHPLf4=<CTd<bhd=38b834i<cD^<S4g=21]M0dX<2TP87=XKgL=E21cH@ebM6d=
0:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P
<20`86Hc3@00X@3003acM6d=<20`830PIS<=AR1cH@db<CT`;SPc=SPP<C0c=Rhg
>3@d86ed3BPa:B0PLfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=0:40`00WLgA]3C0P
<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00EG=dK@db<3P^
<c<b<b1VM7<=;emOGdI><B1SMW=V3C0P<20`86Hc3DHPLf4=<S4c>2hg=C<g83Td
<Bhb>CPh86ed3BQb:B0PLfQ_M`eD87=Q3G9dK@d00:40`004LWA]3@2Q0<009g=d
K@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@3005EcM6d=
<CDf;S8d>C8PIWAc3BmOGem6CS4PHgIcIPd`830P<21V<`e687=Q3C4d>3L^=c4e
<b0b>CP^>C@`>B1]M0dX<RTP87=XKgL=E21cH@ebM6d=002Q0<00179dK@d0X@30
02McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`01E
LgA]3C8`>2hc<c8c86IdL`d_GemOATha86=fLfH=<20`830PIS<=AR1cH@da=3<e
;SHc<S<P<S4b;S4c=CPPKG@=:78Y821cJ6mg3E@PLf4=LWA]3@00X@3000AbM6d=
0:40`00:M6EbKFU^HGAU3@2P0;l0X02n09X0003oSB`000000d/3B`0000@00000
04P000180000400P00<02000000000001HfON0000003B`=;000000=;0d/0000X
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnPo`0XPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnPo`0XPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnPo`0XPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOnPo`0bPOn1oh7ofol0087oPOn1oh7oPOn1okOo
0021oh7oPOn1oh7oPOngo`00POn1oh7ogOl0<X7oPOn1oo3oeP21oh7oPOn1oh7o
POoQomH0POn1oh7oPOn1oh7ohOoF087oPOn1oo;o02Z1oh7oQOn/087oPOn1oh7o
POn;oj`0POn1oh7oPOn1oh_o[021oh7oQol0:X7oPOn;oj00POn1oh7oPOn1oiOo
X021oh7oPOn1oh7oUonP087oPOn=o`0ZPOn1oi7oU021oh7oPOn1oh7oXonD087o
POn1oh7oPOnSoi@0POn1oi?o04:1oh7oUooI0?ZZoP3QZ]X0POn1oh7oPOn1ojoo
f@3jZ_h0hJ[J087oPOn1oh7oPOn_omT0nZ[n0>6ZfP21oh7oVOl0@X7oPOnLonX0
iJ[m0<fZj021oh7oPOn1oh7o^_oZ0>FZo@3=Z^P0POn1oh7oPOn1ok[ojP3UZ_d0
cJ[X087oPOnOo`12POn1oj;ojP3OZ_d0aj[Y087oPOn1oh7oPOo5onX0gj[m0<NZ
j@21oh7oPOn1oh7oaOoZ0=nZo@37Z^T0POn1ojCo04:1oh7oZ?oZ0=VZo032Z^T0
POn1oh7oPOn1om7ojP3IZ_`0`Z[Y087oPOn1oh7oPOoAonX0fJ[l0<:Zj@21oh7o
Z_l0@X7oPOn_onT0dj[l0;bZj@21oh7oPOn1oh7og_oY0=>Zo02lZ^T0POn1oh7o
POn1omkoj@3CZ_`0_:[Y087oPOn`o`12POn1ok?ojP3?Z_/0]Z[[087oPOn1oh7o
POoVonX0cj[k0;JZj`21oh7oPOn1oh7oi_oZ0<nZn`2fZ^/0POn1okCo04:1oh7o
]oo/0<VZnP2aZ^d0POn1oh7oPOn1onkok039Z_X0/J[]087oPOn1oh7oPOo^on`0
bJ[j0;6Zk@21oh7o^?l0@X7oPOnkonh0`j[j0:^Zk`21oh7oPOn1oh7om_o^0<>Z
nP2[Z^l0POn1oh7oPOn1ooKokP33Z_X0Zj[_087oPOnlo`12POn1okook`2oZ_P0
Yj[`087oPOn1oh7oPOononl0_j[h0:NZl021oh7oPOn1oh7oo_o_0;nZn02WZ_00
POn1ol3o03j1oh7o`_o`0;^Zn02SZ_00POn1oh7oPOn5oo00^j[h0:>Zl021oh7o
POn1ohGol02kZ_P0Xj[`087oPOo4o`0nPOn1olKol02gZ_L0X:[`087oPOn1oh7o
SOo`0;NZm`2PZ_00POn1oh7oPOn=oo00]j[g0:2Zl021oh7ob?l0?X7oPOo:oo00
]:[f09bZl021oh7oPOn1oiGol02dZ_H0W:[`087oPOn1oh7oUOo`0;BZmP2LZ_00
POn1olco03j1oh7oc_o`0;2ZmP2HZ_00POn1oh7oPOnMoo00/:[f09RZl021oh7o
POn1oigol02`Z_H0V:[`087oPOo@o`0nPOn1om;ol02/Z_D0UJ[`087oPOn1oh7o
YOo`0:bZm@2EZ_00POn1oh7oPOnUoo00[:[e09FZl021oh7oe?l0?X7oPOoFoo00
ZJ[d096Zl021oh7oPOn1ojgol02YZ_@0TJ[`087oPOn1oh7o[Oo`0:VZm02AZ_00
POn1omSo03j1oh7ofOoa0:FZl`2>Z_40POn1oh7oPOncoo40YJ[c08jZl@21oh7o
POn1ok?ol@2UZ_<0SZ[a087oPOoKo`0nPOn1omcolP2QZ_<0RZ[b087oPOn1oh7o
^Oob0:6Zl`2:Z_80POn1oh7oPOnioo80XJ[c08ZZlP21oh7og_l0BX7oPOoNoo@0
aj[l0=fZlP26Z_@0POn1oh7oPOnmoo@0aj[l0=fZlP26Z_@0POn1oh7oPOnmoo@0
aj[l0=fZlP26Z_@0POn1on3o05J1oh7ohOoe0<fZo03nZ_X0gJ[a08>Zm@21oh7o
POn1ol?om@3=Z_`0oZ[j0=fZl@23Z_D0POn1oh7oPOo3ooD0cJ[l0?jZnP3MZ_40
Pj[e087oPOoSo`1OPOn1onCom@3:Z_`00JZZn@3MZ_40PJX0Z_D0POn1oh7oPOo9
ooD0bZ[l006ZZ_T0gJ[a086Z0:[e087oPOn1oh7obOoe0<ZZo001ZZ[i0=fZl@21
ZP2Zm@21oh7oi_l0Gh7oPOoWoo@0b:[l002Zn03MZ_00PJX1ZZ[d087oPOn1oh7o
cood0<RZo000Z_P0gJ[`086Z0JZZm021oh7oPOn1oloom038Z_`00:[h0=fZl021
ZP6ZZ_@0POn1onWo05b1oh7ojOoe0<FZm`3mZP00gZ[_086Zo:[d087oPOn1oh7o
e?oe0<FZm`3mZP00gZ[_086Zo:[d087oPOn1oh7oe?oe0<FZm`3mZP00gZ[_086Z
o:[d087oPOo/o`1@POn1oncom@32Z_T0ej[_086ZnJ[e087oPOn1oh7ofOoe0<:Z
n@3GZ^l0PJ[iZ_D0POn1oh7oPOoIooD0`Z[i0=NZk`21Z_VZm@21oh7ok_l0D87o
POo_ooD0_j[j0=JZkP21Z_NZm@21oh7oPOn1omoom@2oZ_X0eZ[^086Zmj[e087o
POn1oh7ogooe0;nZnP3FZ^h0PJ[gZ_D0POn1oo7o0521oh7ol_od0;fZn`3FZ^d0
PJ[eZ_@0POn1oh7oPOoUoo@0_J[k0=JZk@21Z_FZm021oh7oPOn1onGom02mZ_/0
eZ[]086ZmJ[d087oPOodo`1@POn1ooGom02jZ_/0eZ[/086Zlj[d087oPOn1oh7o
jood0;ZZn`3FZ^`0PJ[cZ_@0POn1oh7oPOo[oo@0^Z[k0=JZk021Z_>Zm021oh7o
mol0D87oPOogooD0]j[k0=JZk021Z_2Zm@21oh7oPOn1onoom@2gZ_/0eZ[/086Z
l:[e087oPOn1oh7okooe0;NZn`3FZ^`0PJ[`Z_D0POn1ooWo0521oh7on_od0;FZ
o03FZ^/0PJ[^Z_@0POn1oh7oPOoeoo@0]J[l0=JZj`21Z^jZm021oh7oPOn1ooGo
m02eZ_`0eZ[[086ZkZ[d087oPOolo`1APOn1oogom02bZ_`0eZ[Z086Zk:[d087o
POn1oh7onood0;:Zo03FZ^X0PJ[/Z_@0POn1oh7oPOokoo@0/Z[l0=JZjP21Z^bZ
m021oh7o0Ooo0561oh7o0Ooom@2_Z_`0eZ[Z086ZjJ[e087oPOn1oh7o0Ooom@2_
Z_`0eZ[Z086ZjJ[e087oPOn1oh7o0Ooom@2_Z_`0eZ[Z086ZjJ[e087oPOl0B87o
POof0:bZo03GZ^P0PJ[WZ_H0POn1oh7oPoof0:bZo03GZ^P0PJ[WZ_H0POn1oh7o
Poof0:bZo03GZ^P0PJ[WZ_H0POn3o`18POn3ooH0ZZ[l0=NZj021Z^FZmP21oh7o
POn7ooH0ZZ[l0=NZj021Z^FZmP21oh7oPOn7ooH0ZZ[l0=NZj021Z^FZmP21ohGo
04R1ohGom`2WZ_`0ej[X086ZhZ[g087oPOn1oh_om`2WZ_`0ej[X086ZhZ[g087o
POn1oh_om`2WZ_`0ej[X086ZhZ[g087oQol0B87oQoog0:FZo03HZ^H0PJ[QZ_L0
POn1oh7oSoog0:FZo03HZ^H0PJ[QZ_L0POn1oh7oSoog0:FZo03HZ^H0PJ[QZ_L0
POn9o`18POn9ooL0Xj[l0=RZiP21Z]nZm`21oh7oPOnCooL0Xj[l0=RZiP21Z]nZ
m`21oh7oPOnCooL0Xj[l0=RZiP21Z]nZm`21oh_o04R1oh_om`2QZ_`0f:[V086Z
gJ[g087oPOn1oiOom`2QZ_`0f:[V086ZgJ[g087oPOn1oiOom`2QZ_`0f:[V086Z
gJ[g087oSOl0B87oSOog09nZo03HZ^D0PJ[LZ_L0POn1oh7oVoog09nZo03HZ^D0
PJ[LZ_L0POn1oh7oVoog09nZo03HZ^D0PJ[LZ_L0POn?o`18POn?ooL0WJ[l0=VZ
i021Z]ZZm`21oh7oPOnOooL0WJ[l0=VZi021Z]ZZm`21oh7oPOnOooL0WJ[l0=VZ
i021Z]ZZm`21oi7o05B1oi7om`2KZ_`0mJ[i0>fZi021Z]RZm`21oh7oPOnSooL0
Vj[l0?FZn@3]Z^@0PJ[HZ_L0POn1oh7oXoog09^Zo03eZ_T0kJ[T086Zf:[g087o
Tol0E87oToog09VZo03gZ_D0kj[S086Zej[g087oPOn1ojOom`2IZ_`0mj[e0>nZ
h`21Z]NZm`21oh7oPOnWooL0VJ[l0?NZm@3_Z^<0PJ[GZ_L0POnEo`1DPOnEooL0
Uj[l0?RZl`3aZ^80PJ[EZ_L0POn1oh7oZoog09NZo03hZ_<0lJ[R086ZeJ[g087o
POn1oj_om`2GZ_`0n:[c0?6ZhP21Z]FZm`21oiOo0621oiOom`2EZ_`0nJ[m0?ZZ
o03bZ^40PJ[DZ_L0POn1oh7o[oog09FZo03iZ_d0nZ[l0?:Zh@21Z]BZm`21oh7o
POn_ooL0UJ[l0?VZo@3jZ_`0lZ[Q086Ze:[g087oVOl0H87oVOog09>Zo03jZ_d0
mj[m0?>Zh@21Z]:Zm`21oh7oPOncooL0Tj[l0?ZZo@3gZ_d0lj[Q086ZdZ[g087o
POn1ok?om`2CZ_`0nZ[m0?NZo@3cZ^40PJ[BZ_L0POnKo`1PPOnKooL0TJ[l0?ZZ
oP3eZ_h0m:[R086ZcZ[g087oPOn1okOom`2AZ_`0nZ[n0?FZoP3dZ^80PJ[>Z_L0
POn1oh7o]oog096Zo03jZ_h0mJ[n0?BZhP21Z/jZm`21oigo05B1oigom`2?Z_`0
jj[n0?>Zi@21Z/ZZm`21oh7oPOnkooL0Sj[l0>^ZoP3cZ^D0PJ[:Z_L0POn1oh7o
^oog08nZo03[Z_h0lj[U086ZbZ[g087oWol0E87oWoog08fZo03[Z_h0kZ[/086Z
aZ[g087oPOn1okoom`2=Z_`0jj[n0>jZk021Z/JZm`21oh7oPOnoooL0SJ[l0>^Z
oP3^Z^`0PJ[6Z_L0POnQo`1>POnQooL0PJ[`Z_h0iZ[l086Z_:[g087oPOn1ol?o
m`21Z_2ZoP3VZ_`0PJZlZ_L0POn1oh7o`oog086Zl:[n0>JZo021Z[bZm`21oj?o
04j1oj?om`21Z^nZoP3UZ_`0PJZjZ_L0POn1oh7oaoog086Zkj[n0>FZo021Z[ZZ
m`21oh7oPOo7ooL0PJ[_Z_h0iJ[l086Z^Z[g087oYOl0CX7oY?oh086ZkJ[n0>FZ
o021Z[RZn021oh7oPOo9ooP0PJ[]Z_h0iJ[l086Z^:[h087oPOn1olWon021Z^fZ
oP3UZ_`0PJZhZ_P0POnVo`1>POnVooP0PJ[/Z_h0i:[l086Z]Z[h087oPOn1olgo
n021Z^bZoP3TZ_`0PJZfZ_P0POn1oh7ocOoh086Zk:[n0>BZo021Z[JZn021ojSo
04j1ojSon021Z^bZo@3SZ_`0PJZdZ_P0POn1oh7odOoh086Zk:[m0>>Zo021Z[BZ
n021oh7oPOoAooP0PJ[/Z_d0hj[l086Z]:[h087oZ_l0CX7oZOoi086Zjj[m0>:Z
o021Z[:Zn@21oh7oPOoCooT0PJ[[Z_d0hZ[l086Z/Z[i087oPOn1om?on@21Z^^Z
o@3RZ_`0PJZbZ_T0POn[o`1>POn[ooP0PJ[[Z_d0hJ[l086Z/J[h087oPOn1omOo
n021Z^^Zo@3QZ_`0PJZaZ_P0POn1oh7oeooh086Zjj[m0>6Zo021Z[6Zn021ojgo
04j1ojgon021Z^^Zo03PZ_`0PJZ_Z_P0POn1oh7ofooh086Zjj[l0>2Zo021ZZnZ
n021oh7oPOoKooP0PJ[[Z_`0h:[l086Z[j[h087o[ol0CX7o[_oh086Zjj[m0=jZ
o021ZZfZn@21oh7oPOoMooP0PJ[[Z_d0gZ[l086Z[J[i087oPOn1omgon021Z^^Z
o@3NZ_`0PJZ]Z_T0POn`o`1>POn`ooP0PJ[ZZ_d0gJ[l086Z[:[h087oPOn1on7o
n021Z^ZZo@3MZ_`0PJZ/Z_P0POn1oh7ohOoh086ZjZ[m0=fZo021ZZbZn021ok;o
04j1ok;on021Z^VZoP3JZ_`0PJZ[Z_P0POn1oh7oiOoh086ZjJ[n0=ZZo021ZZ^Z
n021oh7oPOoUooP0PJ[YZ_h0fZ[l086ZZj[h087o]?l0CX7o/ooh086ZjJ[n0=VZ
o021ZZZZn021oh7oPOoWooP0PJ[YZ_h0fJ[l086ZZZ[h087oPOn1onOon021Z^VZ
oP3IZ_`0PJZZZ_P0POneo`1>POneooP0PJ[XZ_h0f:[l086ZZ:[h087oPOn1on_o
n021Z^RZoP3HZ_`0PJZXZ_P0POn1oh7ojooh086Zj:[n0=RZo021ZZRZn021okOo
04j1okOon021Z^NZoP3GZ_`0PJZVZ_P0POn1oh7okooh086Zij[n0=NZo021ZZJZ
n021oh7oPOo_ooP0PJ[WZ_h0ej[l086ZYZ[h087o^Ol0CX7o^?oh086ZiZ[n0=NZ
o021ZZFZn021oh7oPOoaooP0PJ[VZ_h0ej[l086ZYJ[h087oPOn1oo7on021Z^JZ
oP3GZ_`0PJZUZ_P0POnjo`1>POnjooP0PJ[UZ_h0eZ[l086ZXj[h087oPOn1ooGo
n021Z^FZoP3FZ_`0PJZSZ_P0POn1oh7omOoh086ZiJ[n0=JZo021ZZ>Zn021okco
04j1okcom`21Z^BZoP3FZ_`0PJZRZ_L0POn1oh7onOog086Zi:[n0=JZo021ZZ:Z
m`21oh7oPOoiooL0PJ[TZ_h0eZ[l086ZXZ[g087o__l0CX7o_Ooh086ZhZ[n0=JZ
o021ZZ2Zn021oh7oPOokooP0PJ[RZ_h0eZ[l086ZX:[h087oPOn1oo_on021Z^:Z
oP3FZ_`0PJZPZ_P0POnoo`1@POnoooP0PJ[PZ^h0iZ[l086ZWZ[h087oPOn1o`7o
ooP0PJ[PZ^h0iZ[l086ZWZ[h087oPOn1o`7oooP0PJ[PZ^h0iZ[l086ZWZ[h087o
`Ol0BX7o`Oog086Zgj[^0>JZo021ZYfZm`21oh7oPoog086Zgj[^0>JZo021ZYfZ
m`21oh7oPoog086Zgj[^0>JZo021ZYfZm`21ol?o04Z1ol;on021Z]fZkP3VZ_`0
PJZKZ_P0POn1ohGon021Z]fZkP3VZ_`0PJZKZ_P0POn1ohGon021Z]fZkP3VZ_`0
PJZKZ_P0POo4o`0nPOo4ooP0PJZ]Z_`0PJZIZ_P0POn1ohWon021ZZfZo021ZYVZ
n021oh7oROoh086Z[J[l086ZVJ[h087oa_l0?X7oaOoh086Z[:[l086ZV:[h087o
POn;ooP0PJZ/Z_`0PJZHZ_P0POn1oh_on021ZZbZo021ZYRZn021olOo03j1olOo
n021ZZZZo021ZYJZn021oh7oSooh086ZZZ[l086ZUZ[h087oPOn?ooP0PJZZZ_`0
PJZFZ_P0POo9o`0nPOo8ooP0PJZYZ_`0PJZEZ_P0POn1oi7on021ZZVZo021ZYFZ
n021oh7oTOoh086ZZJ[l086ZUJ[h087ob_l0?X7obOoj086ZYZ[l086ZTZ[j087o
POnCooX0PJZVZ_`0PJZBZ_X0POn1oi?onP21ZZJZo021ZY:ZnP21ol_o03j1ol_o
nP21ZZBZo021ZY2ZnP21oh7oUooj086ZY:[l086ZT:[j087oPOnGooX0PJZTZ_`0
PJZ@Z_X0POo=o`0nPOo<ooX0PJZSZ_`0PJZ?Z_X0POn1oiWonP21ZZ>Zo021ZXnZ
nP21oh7oVOoj086ZXj[l086ZSj[j087oc_l0?X7ocOoj086ZXZ[l086ZSZ[j087o
POnKooX0PJZRZ_`0PJZ>Z_X0POn1oi_onP21ZZ:Zo021ZXjZnP21oloo03j1oloo
nP21ZZ2Zo021ZXbZnP21oh7oWooj086ZX:[l086ZS:[j087oPOnOooX0PJZPZ_`0
PJZ<Z_X0POoAo`0nPOo@ooX0PJZOZ_`0PJZ;Z_X0POn1oj7onP21ZYnZo021ZX^Z
nP21oh7oXOoj086ZWj[l086ZRj[j087od_l0?X7odOoj086ZWZ[l086ZRZ[j087o
POnSooX0PJZNZ_`0PJZ:Z_X0POn1oj?onP21ZYjZo021ZXZZnP21om?o03j1om?o
nP21ZYbZo021ZXRZnP21oh7oYooj086ZW:[l086ZR:[j087oPOnWooX0PJZLZ_`0
PJZ8Z_X0POoEo`0nPOoDooX0PJZKZ_`0PJZ7Z_X0POn1ojWonP21ZY^Zo021ZXNZ
nP21oh7oZOoj086ZVj[l086ZQj[j087oe_l0?X7oeOoj086ZVZ[l086ZQZ[j087o
POn[ooX0PJZJZ_`0PJZ6Z_X0POn1oj_onP21ZYZZo021ZXJZnP21omOo03j1omOo
nP21ZYRZo021ZXBZnP21oh7o[ooj086ZV:[l086ZQ:[j087oPOn_ooX0PJZHZ_`0
PJZ4Z_X0POoIo`0nPOoHooX0PJZGZ_`0PJZ3Z_X0POn1ok7onP21ZYNZo021ZX>Z
nP21oh7o/Ooj086ZUj[l086ZPj[j087of_l0?X7ofOoj086ZUZ[l086ZPZ[j087o
POncooX0PJZFZ_`0PJZ2Z_X0POn1ok?onP21ZYJZo021ZX:ZnP21om_o04B1om_o
nP21ZYBZo021ZX6Z0:[j087oPOngooX0PJZDZ_`0PJZ1ZP2ZnP21oh7o]ooj086Z
U:[l086ZPJX0Z_X0POoMo`17POoLooX0PJZCZ_`0PJZ1ZP6ZZ_X0POn1okWonP21
ZY>Zo021ZX6Z0JZZnP21oh7o^Ooj086ZTj[l086ZPJX1ZZ[j087og_l0A87ogOoj
086ZTZ[l086ZPJ[nZ_X0POn1ok_onP21ZY:Zo021ZX6ZoZ[j087oPOnkooX0PJZB
Z_`0PJZ1Z_jZnP21omoo04B1omoonP21ZY2Zo021ZX6Zo:[j087oPOnoooX0PJZ@
Z_`0PJZ1Z_bZnP21oh7o_ooj086ZT:[l086ZPJ[lZ_X0POoQo`14POoPooX0PJZ?
Z_`0PJZ1Z_^ZnP21oh7o`Ooj086ZSj[l086ZPJ[kZ_X0POn1ol7onP21ZXnZo021
ZX6Znj[j087oh_l0A87ohOoj086ZSZ[l086ZPJ[jZ_X0POn1ol?onP21ZXjZo021
ZX6ZnZ[j087oPOo3ooX0PJZ>Z_`0PJZ1Z_ZZnP21on?o04B1on?onP21ZX^Zo021
ZX6ZnJ[j087oPOo7ooX0PJZ;Z_`0PJZ1Z_VZnP21oh7oaooj086ZRj[l086ZPJ[i
Z_X0POoUo`14POoTooX0PJZ:Z_`0PJZ1Z_RZnP21oh7obOoj086ZRZ[l086ZPJ[h
Z_X0POn1olWonP21ZXZZo021ZX6Zn:[j087oi_l0A87oiOoj086ZRJ[l086ZPJ[g
Z_X0POn1ol_onP21ZXVZo021ZX6Zmj[j087oPOo;ooX0PJZ9Z_`0PJZ1Z_NZnP21
onOo04B1onKon`21ZXNZo021ZX6ZmJ[k087oPOo=oo/0PJZ7Z_`0PJZ1Z_FZn`21
oh7ocOok086ZQj[l086ZPJ[eZ_/0POoXo`14POoWoo/0PJZ6Z_`0PJZ1Z_BZn`21
oh7ocook086ZQZ[l086ZPJ[dZ_/0POn1oloon`21ZXJZo021ZX6Zm:[k087ojOl0
A87oj?ok086ZQJ[l086ZPJ[cZ_/0POn1om7on`21ZXFZo021ZX6Zlj[k087oPOoA
oo/0PJZ5Z_`0PJZ1Z_>Zn`21on[o04B1on[onP21ZXBZo021ZX6ZlZ[j087oPOoE
ooX0PJZ4Z_`0PJZ1Z_:ZnP21oh7oeOoj086ZQ:[l086ZPJ[bZ_X0POo/o`14POo[
ooX0PJZ3Z_`0PJZ1Z_6ZnP21oh7oeooj086ZPj[l086ZPJ[aZ_X0POn1omOonP21
ZX>Zo021ZX6ZlJ[j087okOl0A87ok?oj086ZPZ[l086ZPJ[`Z_X0POn1omWonP21
ZX:Zo021ZX6Zl:[j087oPOoIooX0PJZ2Z_`0PJZ1Z_2ZnP21onko04Z1ongon`21
ZX6Z0:[l086ZPJ[^Z_/0POn1om_on`21ZX6Z0:[l086ZPJ[^Z_/0POn1om_on`21
ZX6Z0:[l086ZPJ[^Z_/0POo_o`1=POo^oo/0PJZ1ZP6ZZ_`0PJZ1Z^fZn`21oh7o
gOok086ZPJX1ZZ[l086ZPJ[]Z_/0POn1omgon`21ZX6Z0JZZo021ZX6ZkJ[k087o
l?l0BX7okook086ZPJ[nZ_`0PJZ1Z^bZn`21oh7ogook086ZPJ[nZ_`0PJZ1Z^bZ
n`21oh7ogook086ZPJ[nZ_`0PJZ1Z^bZn`21oo7o04Z1oo3on`21ZX6ZoJ[l086Z
PJ[[Z_/0POn1on7on`21ZX6ZoJ[l086ZPJ[[Z_/0POn1on7on`21ZX6ZoJ[l086Z
PJ[[Z_/0POobo`1:POoaoo/0PJZ1Z_bZo021ZX6ZjZ[k087oPOoSoo/0PJZ1Z_bZ
o021ZX6ZjZ[k087oPOoSoo/0PJZ1Z_bZo021ZX6ZjZ[k087olol0BX7ol_ok086Z
PJ[kZ_`0PJZ1Z^VZn`21oh7oiOok086ZPJ[kZ_`0PJZ1Z^VZn`21oh7oiOok086Z
PJ[kZ_`0PJZ1Z^VZn`21ooCo04Z1ooConP21ZX6ZnZ[l086ZPJ[XZ_X0POn1onWo
nP21ZX6ZnZ[l086ZPJ[XZ_X0POn1onWonP21ZX6ZnZ[l086ZPJ[XZ_X0POofo`1:
POoeooX0PJZ1Z_VZo021ZX6Zij[j087oPOo[ooX0PJZ1Z_VZo021ZX6Zij[j087o
POo[ooX0PJZ1Z_VZo021ZX6Zij[j087omol0BX7om_oj086ZPJ[hZ_`0PJZ1Z^JZ
nP21oh7okOoj086ZPJ[hZ_`0PJZ1Z^JZnP21oh7okOoj086ZPJ[hZ_`0PJZ1Z^JZ
nP21ooSo04Z1ooOon`21ZX6ZmZ[l086ZPJ[TZ_/0POn1onoon`21ZX6ZmZ[l086Z
PJ[TZ_/0POn1onoon`21ZX6ZmZ[l086ZPJ[TZ_/0POoio`1:POohoo/0PJZ1Z_FZ
o021ZX6Zhj[k087oPOoaoo/0PJZ1Z_FZo021ZX6Zhj[k087oPOoaoo/0PJZ1Z_FZ
o021ZX6Zhj[k087on_l0BX7onOok086ZPJ[dZ_`0PJZ1Z^:Zn`21oh7olook086Z
PJ[dZ_`0PJZ1Z^:Zn`21oh7olook086ZPJ[dZ_`0PJZ1Z^:Zn`21oo_o04Z1oo[o
n`21ZX6Zlj[l086ZPJ[QZ_/0POn1ooGon`21ZX6Zlj[l086ZPJ[QZ_/0POn1ooGo
n`21ZX6Zlj[l086ZPJ[QZ_/0POolo`1:POokoo/0PJZ1Z_:Zo021ZX6Zh:[k087o
POogoo/0PJZ1Z_:Zo021ZX6Zh:[k087oPOogoo/0PJZ1Z_:Zo021ZX6Zh:[k087o
oOl0BX7oo?ok086ZPJ[aZ_`0PJZ1Z]nZn`21oh7onOok086ZPJ[aZ_`0PJZ1Z]nZ
n`21oh7onOok086ZPJ[aZ_`0PJZ1Z]nZn`21ooko04Z1ookonP21ZX6Zl:[l086Z
PJ[NZ_X0POn1oogonP21ZX6Zl:[l086ZPJ[NZ_X0POn1oogonP21ZX6Zl:[l086Z
PJ[NZ_X0POl0o`1;POl1oooj086ZPJ[_Z_`0PJZ1Z]fZnP21oh7o0OoonP21ZX6Z
kj[l086ZPJ[MZ_X0POn1o`7oooX0PJZ1Z^nZo021ZX6ZgJ[j087o04B1o`3onP21
ZX6ZkZ[l086ZPJ[LZ_X0POn1ooX0PJZ1Z^jZo021ZX6Zg:[j087oPOoj086ZPJ[^
Z_`0PJZ1Z]bZnP22o`12POok086ZPJ[/Z_`0PJZ1Z]ZZn`21oh?on`21ZX6Zk:[l
086ZPJ[JZ_/0POn3oo/0PJZ1Z^bZo021ZX6ZfZ[k08?o04:2oo/0PJZ1Z^^Zo021
ZX6ZfJ[k087oQOok086ZPJ[[Z_`0PJZ1Z]VZn`21ohGon`21ZX6Zjj[l086ZPJ[I
Z_/0Q?l0@X?on`21ZX6ZjZ[l086ZPJ[HZ_/0POn7oo/0PJZ1Z^ZZo021ZX6Zf:[k
087oQook086ZPJ[ZZ_`0PJZ1Z]RZn`25o`12Q?ok086ZPJ[YZ_`0PJZ1Z]NZn`21
ohWon`21ZX6ZjJ[l086ZPJ[GZ_/0POn9oo/0PJZ1Z^VZo021ZX6Zej[k08Ko04:5
oo/0PJZ1Z^RZo021ZX6ZeZ[k087oRook086ZPJ[XZ_`0PJZ1Z]JZn`21oh_on`21
ZX6Zj:[l086ZPJ[FZ_/0Qol0@XKon`21ZX6Zij[l086ZPJ[EZ_/0POn=oo/0PJZ1
Z^NZo021ZX6ZeJ[k087oSOok086ZPJ[WZ_`0PJZ1Z]FZn`28o`12Q_ol086ZPJ[V
Z_`0PJZ1Z]BZn`21ohkoo021ZX6ZiZ[l086ZPJ[DZ_/0POn>oo`0PJZ1Z^JZo021
ZX6Ze:[k08Wo04:7oo`0PJZ1Z^BZo021ZX6Ze:[l087oSool086ZPJ[TZ_`0PJZ1
Z]BZo021ohooo021ZX6Zi:[l086ZPJ[DZ_`0ROl0@XSoo021ZX6Zhj[l086ZPJ[C
Z_`0POnAoo`0PJZ1Z^>Zo021ZX6Zdj[l087oTOol086ZPJ[SZ_`0PJZ1Z]>Zo02:
o`1>ROok086ZPJ[SZ_`0o:X0086ZPJ[HZ_`0POnCoo/0PJZ1Z^>Zo03lZP00PJZ1
Z]RZo021oi?on`21ZX6Zhj[l0?bZ0021ZX6Zf:[l08_o04::oo/0PJZ1Z^JZi021
ZX6ZiZ[k087oUOok086ZPJ[VZ^@0PJZ1Z^JZn`21oiGon`21ZX6ZiZ[T086ZPJ[V
Z_/0S?l0@X_on`21ZX6Zm:[6086ZPJ[dZ_/0POnGoo/0PJZ1Z_BZaP21ZX6Zm:[k
087oUook086ZPJ[dZ/H0PJZ1Z_BZn`2=o`12S?ok086ZPJ[jZ[P0PJZ1Z_ZZn`21
oiWon`21ZX6ZnZZh086ZPJ[jZ_/0POnIoo/0PJZ1Z_ZZ^021ZX6ZnZ[k08ko04:=
oo/0PJZ1ZP2ZZP21ZX6Z0:[k087oVook086ZPJX0ZZX0PJZ1ZP2Zn`21oi_on`21
ZX6Z0:ZZ086ZPJX0Z_/0Sol0CXkon`21ZXJZg03noo`0kOoM086ZQZ[k087oWOok
086ZQZ[L0?koo03]omd0PJZ6Z_/0POnMoo/0PJZ6Z]`0o_ol0>gog@21ZXJZn`2@
o`1>Sook086ZS:[T0>ooo03Oon@0PJZ<Z_/0POnOoo/0PJZ<Z^@0kool0=ooi021
ZXbZn`21oioon`21ZXbZi03_oo`0gooT086ZS:[k097o04j?oo`0PJZ?Z^L0j?ol
0=Soi`21ZXnZn`21oj3oo021ZXnZi`3Xoo`0f?oW086ZSj[k087oX?ol086ZSj[W
0>Soo03HonL0PJZ?Z_/0T_l0CY3oo021ZY:ZjP3Qoo`0dOoZ086ZTZ[l087oXOol
086ZTZ[Z0>7oo03AonX0PJZBZ_`0POnQoo`0PJZBZ^X0hOol0=7ojP21ZY:Zo02B
o`1>TOol086ZUJ[]0=[oo03:ond0PJZEZ_`0POnSoo`0PJZEZ^d0f_ol0<[ok@21
ZYFZo021oj?oo021ZYFZk@3Joo`0b_o]086ZUJ[l09?o04jBoo/0PJZHZ_40dool
0<?ol021ZYRZo021ojGon`21ZYRZl@3Coo`0`oo`086ZV:[l087oYOok086ZV:[a
0=?oo033oo00PJZHZ_`0U?l0CY?on`21ZY^Zl@3?oo`0_ooa086ZVj[k087oYook
086ZVj[a0<ooo02ooo40PJZKZ_/0POnWoo/0PJZKZ_40cool0;ool@21ZY^Zn`2E
o`1>U?ok086ZWZ[a0<_oo02koo40PJZNZ_/0POnYoo/0PJZNZ_40bool0;_ol@21
ZYjZn`21ojWon`21ZYjZl@3;oo`0^ooa086ZWZ[k09Ko04jEoo/0PJZQZ_40aool
0;Ool@21ZZ6Zn`21oj_on`21ZZ6Zl@37oo`0]ooa086ZXJ[k087oZook086ZXJ[a
0<Ooo02goo40PJZQZ_/0Uol0CYKon`21ZZ>Zl@34oo`0/oob086ZXj[k087o[Ook
086ZXj[a0<Coo02coo80PJZSZ_/0POn]oo/0PJZSZ_40a?ol0;?olP21ZZ>Zn`2H
o`1>Uook086ZY:[c0<3oo02`oo<0PJZTZ_/0POn_oo/0PJZTZ_<0`?ol0;3ol`21
ZZBZn`21ojoon`21ZZBZl`30oo`0/?oc086ZY:[k09Wo04jHoo/0PJZVZ_@0_?ol
0:com021ZZJZn`21ok7on`21ZZJZm02loo`0[?od086ZYZ[k087o/Ook086ZYZ[d
0;coo02/oo@0PJZVZ_/0V_l0CYSoo021ZZNZmP2hoo`0Z?of086ZYj[k087o/_ol
086ZYj[f0;Soo02XooH0PJZWZ_/0POnboo`0PJZWZ_H0^?ol0:SomP21ZZNZn`2K
o`1>VOol086ZZJ[f0;Goo02UooH0PJZYZ_`0POncoo`0PJZYZ_H0]Ool0:GomP21
ZZVZo021ok?oo021ZZVZmP2eoo`0YOof086ZZJ[l09_o04jJoo`0PJZ[Z_D0/ool
0:?om@21ZZ^Zo021okGoo021ZZ^Zm@2coo`0Xooe086ZZj[l087o]Ool086ZZj[e
0;?oo02SooD0PJZ[Z_`0W?l0CY_on`21ZZfZmP2`oo`0X?of086Z[:[l087o]ook
086Z[J[f0;3oo02PooH0PJZ/Z_`0POngoo/0PJZ]Z_H0/?ol0:3omP21ZZbZo02M
o`1>W?ok086Z[j[e0:koo02NooD0PJZ_Z_/0POnioo/0PJZ_Z_D0[_ol09kom@21
ZZnZn`21okWon`21ZZnZm@2^oo`0W_oe086Z[j[k09ko04jMoo/0PJZ`Z_H0Zool
09_omP21Z[2Zn`21ok_on`21Z[2ZmP2[oo`0Voof086Z/:[k087o^ook086Z/:[f
0:_oo02KooH0PJZ`Z_/0Wol0CYkon`21Z[:ZmP2Xoo`0VOoe086Z/Z[k087o_Ook
086Z/Z[f0:Soo02IooD0PJZbZ_/0POnmoo/0PJZbZ_H0Z?ol09Wom@21Z[:Zn`2P
o`1>W_ol086Z/j[f0:Koo02FooH0PJZcZ_/0POnnoo`0PJZcZ_H0Y_ol09KomP21
Z[>Zn`21okkoo021Z[>ZmP2Voo`0U_of086Z/j[k0:7o04jOoo`0PJZdZ_L0Xool
09ComP21Z[FZn`21okooo021Z[BZm`2Soo`0U?of086Z]J[k087o_ool086Z]:[g
0:?oo02DooH0PJZeZ_/0XOl0CZ3oo021Z[FZm`2Qoo`0TOog086Z]Z[k087o`Ool
086Z]J[g0:7oo02AooL0PJZfZ_/0POo1oo`0PJZeZ_L0XOol097om`21Z[JZn`2R
o`1>XOok086Z]j[g09ooo02?ooL0PJZgZ_/0POo3oo/0PJZgZ_L0Wool08oom`21
Z[NZn`21ol?on`21Z[NZm`2Ooo`0Soog086Z]j[k0:?o04jQoo`0PJZhZ_L0WOol
08gom`21Z[VZnP21olCoo021Z[RZm`2Moo`0SOog086Z^J[j087oa?ol086Z^:[g
09goo02=ooL0PJZiZ_X0Y?l0CZ;oo021Z[VZm`2Koo`0Roof086Z^j[k087oaOol
086Z^J[g09_oo02;ooH0PJZkZ_/0POo5oo`0PJZiZ_L0Vool08_omP21Z[^Zn`2T
o`1>Xool086Z^j[f09Woo029ooH0PJZlZ_/0POo7oo`0PJZkZ_H0VOol08WomP21
Z[bZn`21olOoo021Z[^ZmP2Ioo`0ROof086Z_:[k0:Go04jToo/0PJZmZ_H0Uool
08OomP21Z[fZn`21olWon`21Z[fZmP2Goo`0Qoof086Z_J[k087obOok086Z_J[f
09Ooo027ooH0PJZmZ_/0Y_l0CZCoo021Z[jZmP2Doo`0Q_of086Z_j[j087ob_ol
086Z_Z[f09Coo026ooH0PJZoZ_X0POo:oo`0PJZnZ_H0U?ol08KomP21Z[nZnP2W
o`1>YOol086Z_j[f09;oo023ooL0PJ[0Z_/0POo;oo`0PJZoZ_H0T_ol08?om`21
Z/2Zn`21ol_oo021Z[nZmP2Boo`0Poog086Z`:[k0:Oo04jVoo`0PJ[0Z_L0Sool
087om`21Z/6Zn`21olgoo021Z/2Zm`2?oo`0POog086Z`J[k087ocOol086Z`:[g
08ooo021ooL0PJ[1Z_/0Z?l0EjOon`21Z/:Zm`2=oo`0POl1ooog086Z`Z[k087o
cook086Z`Z[g08goo021o`7oooL0PJ[2Z_/0POo?oo/0PJ[2Z_L0SOol087o0Ooo
m`21Z/:Zn`2Yo`1DYool086Z`j[g08_oo021oogom`21Z/BZnP21om3oo021Z/>Z
m`2;oo`0POomooL0PJ[4Z_X0POo@oo`0PJ[3Z_L0Rool087ooOog086Za:[j0:[o
05BXoo`0PJ[3Z_P0ROol087onooh086Za:[k087odOol086Z`j[h08Woo021oo_o
n021Z/BZn`21om7oo021Z/>Zn029oo`0POokooP0PJ[4Z_/0Z_l0E:Woo021Z/BZ
n027oo`0POoiooP0PJ[5Z_/0POoCoo`0PJ[4Z_P0Qool087onOoh086ZaJ[k087o
dool086Za:[h08Ooo021ooWon021Z/FZn`2[o`1DZ_ok086ZaJ[i08Goo021ooOo
n@21Z/FZn`21omGon`21Z/FZn@25oo`0POogooT0PJ[5Z_/0POoEoo/0PJ[5Z_T0
QOol087omooi086ZaJ[k0:co05BZoo`0PJ[6Z_T0Pool087omOoi086Zaj[j087o
e_ol086ZaZ[i08?oo021ooGon@21Z/NZnP21omKoo021Z/JZn@23oo`0POoeooT0
PJ[7Z_X0[Ol0E:_oo021Z/JZn@22oo`0POodooT0PJ[7Z_/0POoGoo`0PJ[6Z_T0
P_ol087om?oi086Zaj[k087oeool086ZaZ[i08;oo021ooCon@21Z/NZn`2]o`1J
[?ol086Zaj[i087o0?ol087ol_oi086Zb:[k087ofOol086Zaj[i087o0?ol087o
l_oi086Zb:[k087ofOol086Zaj[i087o0?ol087ol_oi086Zb:[k0:ko05Z]oo/0
PJ[8Z_X0POonoo`0POo`ooX0PJ[8Z_/0POoKoo/0PJ[8Z_X0POonoo`0POo`ooX0
PJ[8Z_/0POoKoo/0PJ[8Z_X0POonoo`0POo`ooX0PJ[8Z_/0[ol0FZgoo021Z/VZ
n@21oogoo021onoon@21Z/ZZnP21omcoo021Z/VZn@21oogoo021onoon@21Z/ZZ
nP21omcoo021Z/VZn@21oogoo021onoon@21Z/ZZnP2`o`1J[_ol086ZbJ[j087o
nool087okOoj086ZbZ[k087ogOol086ZbJ[j087onool087okOoj086ZbZ[k087o
gOol086ZbJ[j087onool087okOoj086ZbZ[k0;3o05Z_oo`0PJ[:Z_T0POojoo`0
POo[ooX0PJ[;Z_/0POoOoo`0PJ[:Z_T0POojoo`0POo[ooX0PJ[;Z_/0POoOoo`0
PJ[:Z_T0POojoo`0POo[ooX0PJ[;Z_/0/Ol0F[3on`21Z/^ZnP21ooSoo021on[o
nP21Z/^Zn`21on7on`21Z/^ZnP21ooSoo021on[onP21Z/^Zn`21on7on`21Z/^Z
nP21ooSoo021on[onP21Z/^Zn`2bo`1J/?ol086Zc:[j087om_ol087oj?oj086Z
cJ[j087oh_ol086Zc:[j087om_ol087oj?oj086ZcJ[j087oh_ol086Zc:[j087o
m_ol087oj?oj086ZcJ[j0;?o05Zaoo`0PJ[<Z_X0POoeoo`0POoWooT0PJ[>Z_/0
POoSoo`0PJ[<Z_X0POoeoo`0POoWooT0PJ[>Z_/0POoSoo`0PJ[<Z_X0POoeoo`0
POoWooT0PJ[>Z_/0/ol0F[;oo021Z/jZn@21oo?oo021onGon@21Z/nZn`21onGo
o021Z/jZn@21oo?oo021onGon@21Z/nZn`21onGoo021Z/jZn@21oo?oo021onGo
n@21Z/nZn`2do`1J/ook086Zcj[j087olOol087ohooj086Zcj[k087oiook086Z
cj[j087olOol087ohooj086Zcj[k087oiook086Zcj[j087olOol087ohooj086Z
cj[k0;Go05Zcoo`0PJ[@Z_T0POo`oo`0POoRooT0PJ[AZ_X0POoXoo`0PJ[@Z_T0
POo`oo`0POoRooT0PJ[AZ_X0POoXoo`0PJ[@Z_T0POo`oo`0POoRooT0PJ[AZ_X0
]_l0F[Coo021Z]2ZnP21onkoo021on3onP21Z]6Zn`21onWoo021Z]2ZnP21onko
o021on3onP21Z]6Zn`21onWoo021Z]2ZnP21onkoo021on3onP21Z]6Zn`2fo`1J
]Ool086Zd:[j087okOol087ogooj086ZdJ[k087ojool086Zd:[j087okOol087o
gooj086ZdJ[k087ojool086Zd:[j087okOol087ogooj086ZdJ[k0;Oo05Zfoo/0
PJ[BZ_X0POo[oo`0POoMooX0PJ[BZ_/0POo]oo/0PJ[BZ_X0POo[oo`0POoMooX0
PJ[BZ_/0POo]oo/0PJ[BZ_X0POo[oo`0POoMooX0PJ[BZ_/0^?l0F[Koo021Z]:Z
nP21on[oo021omconP21Z]>Zn`21ongoo021Z]:ZnP21on[oo021omconP21Z]>Z
n`21ongoo021Z]:ZnP21on[oo021omconP21Z]>Zn`2ho`1J]ook086Zdj[j087o
jOol087of_ok086Zdj[k087okook086Zdj[j087ojOol087of_ok086Zdj[k087o
kook086Zdj[j087ojOol087of_ok086Zdj[k0;Wo05Zgoo`0PJ[CZ_/0POoWoo`0
POoIooX0PJ[DZ_`0POo_oo`0PJ[CZ_/0POoWoo`0POoIooX0PJ[DZ_`0POo_oo`0
PJ[CZ_/0POoWoo`0POoIooX0PJ[DZ_`0^Ol0F[Son`21Z]FZnP21onKoo021omSo
nP21Z]FZn`21oo7on`21Z]FZnP21onKoo021omSonP21Z]FZn`21oo7on`21Z]FZ
nP21onKoo021omSonP21Z]FZn`2jo`1J^Ook086ZeJ[k087oi?ol087oe_ok086Z
eJ[k087olook086ZeJ[k087oi?ol087oe_ok086ZeJ[k087olook086ZeJ[k087o
i?ol087oe_ok086ZeJ[k0;_o05Zioo/0PJ[FZ_/0POoSoo`0POoEoo/0PJ[FZ_/0
POocoo/0PJ[FZ_/0POoSoo`0POoEoo/0PJ[FZ_/0POocoo/0PJ[FZ_/0POoSoo`0
POoEoo/0PJ[FZ_/0^ol0F[[on`21Z]NZnP21on;oo021omConP21Z]NZn`21ooGo
n`21Z]NZnP21on;oo021omConP21Z]NZn`21ooGon`21Z]NZnP21on;oo021omCo
nP21Z]NZn`2lo`1J^_ol086Zej[k087oh?ol087od_ok086Zej[l087omOol086Z
ej[k087oh?ol087od_ok086Zej[l087omOol086Zej[k087oh?ol087od_ok086Z
ej[l0;co05Zkoo/0PJ[HZ_/0POoOoo`0POoAoo/0PJ[HZ_/0POogoo/0PJ[HZ_/0
POoOoo`0POoAoo/0PJ[HZ_/0POogoo/0PJ[HZ_/0POoOoo`0POoAoo/0PJ[HZ_/0
_Ol0F[con`21Z]VZnP21omkoo021oloon`21Z]VZn`21ooWon`21Z]VZnP21omko
o021oloon`21Z]VZn`21ooWon`21Z]VZnP21omkoo021oloon`21Z]VZn`2no`1P
_?ol086ZfZ[j087ofool097oo034oo/0PJ[IZ_`0POoioo`0PJ[JZ_X0POoKoo`0
TOol0<Con`21Z]VZo021ooWoo021Z]ZZnP21om_oo02Aoo`0a?ok086ZfJ[l0;ko
06bmoo/0PJ[KZ_X0POoJoo`0Vool0?konP34ooX0PJ[JZ_/0POokoo/0PJ[KZ_X0
POoJoo`0Vool0?konP34ooX0PJ[JZ_/0POokoo/0PJ[KZ_X0POoJoo`0Vool0?ko
nP34ooX0PJ[JZ_/0_ol0Nkgoo021Z]^Zn`21omSoo02Koo`00Ooon@35ooh00?ol
086ZfZ[l087onool086Zfj[k087of?ol09_oo001oooi0<GooP00oo`0PJ[JZ_`0
POokoo`0PJ[KZ_/0POoHoo`0Vool007oooT0aOon003oo021Z]ZZo02oo`1h__ok
086Zg:[k087oeool09_oo000ooP0aoom0?koo021Z]^Zn`21oogon`21Z]bZn`21
omOoo02Koo`00?oh0<Ooo@3noo`0PJ[KZ_/0POomoo/0PJ[LZ_/0POoGoo`0Vool
003on037ood0o_ol086Zfj[k0<3o07Zooo/0PJ[LZ_/0POoFoo`0Voog0?go0038
oo`0oOol086Zfj[k087o0Ooon`21Z]bZn`21omKoo02KooL0oOl00<Soo03moo`0
PJ[KZ_/0POl1oook086Zg:[k087oe_ol09_om`3mo`00b?ol0?goo021Z]^Zn`31
o`1^_ool086Zg:[k087oeOol09_on@33oo/0nook086Zg:[l087o0Oooo021Z]bZ
n`21omGoo02KooT0`ook0?_on`21Z]bZo021o`7ooo`0PJ[LZ_/0POoEoo`0Vooi
0<?on`3koo/0PJ[LZ_`0`Ol0J<3on`21Z]fZn`21omCoo02KooX0`ooj0?[on`21
Z]fZn`21oo/0PJ[MZ_/0POoDoo`0Vooj0<?onP3joo/0PJ[MZ_/0POok086ZgJ[k
087oe?ol09_onP33ooX0n_ok086ZgJ[k0<;o06S0oo`0PJ[MZ_/0POoCoo`0Vook
0<Con03ioo/0PJ[MZ_`0POol086ZgJ[k087odool09_on`34ooP0nOok086ZgJ[l
087oo021Z]fZn`21om?oo02Koo/0a?oh0?Won`21Z]fZo032o`1X`Ook086ZgZ[k
087od_ol09_on`36ooL0mook086ZgJ[l08?on`21Z]jZn`21om;oo02Koo/0a_og
0?Oon`21Z]fZo023oo/0PJ[NZ_/0POoBoo`0Vook0<Kom`3goo/0PJ[MZ_`0`ol0
J<;on`21Z]jZn`21om7oo02Koo/0aoof0?Kon`21Z]jZn`25oo/0PJ[NZ_/0POoA
oo`0Vook0<OomP3foo/0PJ[NZ_/0QOok086ZgZ[k087odOol09_on`37ooH0m_ok
086ZgZ[k0<Co06S2oo`0PJ[OZ_X0POo@oo`0Vool0<Som03eoo/0PJ[NZ_`0QOol
086Zgj[j087od?ol09_oo038oo@0mOok086ZgZ[l08Goo021Z]nZnP21om3oo02K
oo`0b?od0?Gon`21Z]jZo034o`1X`ook086Zh:[j087ocool09_oo039oo@0look
086Zgj[k08Oon`21Z^2ZnP21olooo02Koo`0bOod0??on`21Z]nZn`27oo/0PJ[P
Z_X0POo?oo`0Vool0<Wom03coo/0PJ[OZ_/0aOl0J<?oo021Z^2ZnP21olkoo02K
oo`0boob0?7oo021Z]nZo027oo`0PJ[PZ_X0POo>oo`0Vool0<_olP3aoo`0PJ[O
Z_`0Qool086Zh:[j087oc_ol09_oo03;oo80lOol086Zgj[l0<Go06S4oo`0PJ[P
Z_/0POo<oo`0Vool0<col@3`oo`0PJ[OZ_`0ROol086Zh:[k087oc?ol09_oo03<
oo40l?ol086Zgj[l08Woo021Z^2Zn`21olcoo02Koo`0c?oa0?3oo021Z]nZo036
o`1XaOok086ZhJ[k087obool09_oo03>oo00k_ok086ZhJ[k08_on`21Z^6Zn`21
ol_oo02Koo`0c_o`0>kon`21Z^6Zn`2;oo/0PJ[QZ_/0POo;oo`0Vool0<kol03^
oo/0PJ[QZ_/0aol0J<Goo021Z^6Zn`21ol[oo02Koo`0d?o^0>gon`21Z^6Zo02;
oo`0PJ[QZ_/0POo:oo`0Vool0=3okP3]oo/0PJ[QZ_`0Rool086ZhJ[k087ob_ol
09_oo03@onh0kOok086ZhJ[l0<Oo06S6oo/0PJ[RZ_/0POo9oo`0Vool0=7ok@3/
oo/0PJ[RZ_/0SOok086ZhZ[k087obOol09_oo03Aond0k?ok086ZhZ[k08gon`21
Z^:Zn`21olWoo02Koo`0dOo]0>con`21Z^:Zn`38o`1Xa_ol086ZhZ[k087ob?ol
09_oo03Con/0jook086ZhZ[l08goo021Z^:Zn`21olSoo02Koo`0doo[0>_on`21
Z^:Zo02=oo`0PJ[RZ_/0POo8oo`0Vool0=?oj`3[oo/0PJ[RZ_`0b?l0J<Ooo021
Z^:Zn`21olOoo02Koo`0e?o[0>Won`21Z^:Zo02?oo`0PJ[RZ_/0POo7oo`0Vool
0=Coj`3Yoo/0PJ[RZ_`0Sool086ZhZ[k087oaool09_oo03Don/0jOok086ZhZ[l
0<Wo06S8oo/0PJ[SZ_/0POo6oo`0Vool0=Koj@3Xoo/0PJ[SZ_/0TOok086Zhj[k
087oa_ol09_oo03FonT0j?ok086Zhj[k097on`21Z^>Zn`21olKoo02Koo`0e_oY
0>Son`21Z^>Zn`3:o`1Xb?ol086Zhj[k087oaOol09_oo03HonL0iook086Zhj[l
097oo021Z^>Zn`21olGoo02Koo`0f?oW0>Oon`21Z^>Zo02Aoo`0PJ[SZ_/0POo5
oo`0Vool0=Soi`3Woo/0PJ[SZ_`0b_l0J<Woo021Z^>Zn`21olCoo02Koo`0fOoW
0>Gon`21Z^>Zo02Coo`0PJ[SZ_/0POo4oo`0Vool0=Woi`3Uoo/0PJ[SZ_`0Tool
086Zhj[k087oa?ol09_oo03IonL0iOok086Zhj[l0<_o06S9oo`0PJ[TZ_/0POo3
oo`0Vool0=_oi@3Too/0PJ[TZ_`0Tool086Zi:[k087o`ool09_oo03KonD0i?ok
086Zi:[l09?oo021Z^BZn`21ol?oo02Koo`0fooU0>Con`21Z^BZo03;o`1Xb_ol
086Zi:[k087o`_ol09_oo03Lon@0hook086Zi:[l09Goo021Z^BZn`21ol;oo02K
oo`0g?oT0>?on`21Z^BZo02Eoo`0PJ[TZ_/0POo2oo`0Vool0=coi03Soo/0PJ[T
Z_`0c?l0M<[oo021Z^BZo021ol7oo02Koo`0loom0?3oh`3Qoo/0PJ[UZ_/0U_ol
086Zi:[l087o`Ool09_oo03cood0l?oS0>7on`21Z^FZn`2Foo`0PJ[TZ_`0POo1
oo`0Vool0??oo@3`on<0hOok086ZiJ[k0<go07C;oo`0PJ[TZ_`0POo0oo`0Vool
0?Gon`3aon80h?ol086Zi:[l09Ooo021Z^BZo021ol3oo02Koo`0mOok0?7ohP3P
oo`0PJ[TZ_`0Uool086Zi:[l087o`?ol09_oo03eoo/0lOoR0>3oo021Z^BZo03=
o`1dbool086ZiJ[l087o_ool09_oo03gooT0looQ0=koo021Z^BZo02Hoo`0PJ[U
Z_`0POnooo`0Vool0?Oon@3con40g_ol086Zi:[l09Soo021Z^FZo021okooo02K
oo`0mooi0??oh@3Noo`0PJ[TZ_`0c_l0M<coo021Z^FZn`21okooo02Koo`0n?oh
0??oh@3Moo`0PJ[UZ_`0VOol086ZiJ[k087o_ool09_oo03hooP0looQ0=goo021
Z^FZo02Ioo`0PJ[UZ_/0POnooo`0Vool0?Son03con40gOol086ZiJ[l0<ko08?<
oo`0PJ[VZ_/0POnnoo`0Vool0?Soo@01ooon0?;ohP3Moo/0PJ[UZ_`0V_ol086Z
iZ[k087o__ol09_oo03hood00OoooP3bon80gOok086ZiJ[l09[oo021Z^JZn`21
okkoo02Koo`0n?om007oooh0l_oR0=gon`21Z^FZo03?o`1gcOol086ZiZ[k087o
_Ool08go0@00oOon0?;oh`3Koo/0PJ[VZ_`0Vool086ZiZ[k087o_Ool08go0@00
oOon0?;oh`3Koo/0PJ[VZ_`0Vool086ZiZ[k087o_Ool08go0@00oOon0?;oh`3K
oo/0PJ[VZ_`0col0J<goo021Z^NZn`21okcoo027ooh0lOoT0=[on`21Z^JZo02L
oo`0PJ[WZ_/0POnloo`0Qoon0?7oi03Joo/0PJ[VZ_`0W?ol086Zij[k087o_?ol
08OooP3aon@0f_ok086ZiZ[l0=3o06S>oo`0PJ[WZ_/0POnkoo`0Qoon0?3oi@3I
oo/0PJ[WZ_`0WOol086Zij[k087o^ool08OooP3`onD0fOok086Zij[l09goo021
Z^NZn`21ok_oo027ooh0l?oU0=Won`21Z^NZo03@o`1Xc_ol086Zj:[k087o^_ol
08OooP3_onL0eook086Zij[l09koo021Z^RZn`21ok[oo027ooh0kooW0=Oon`21
Z^NZo02Noo`0PJ[XZ_/0POnjoo`0Qoon0>ooi`3Goo/0PJ[WZ_`0dOl0J<ooo021
Z^RZn`21okWoo027ooh0k_oX0=Kon`21Z^RZo02Ooo`0PJ[XZ_/0POnioo`0Qoon
0>koj03Foo/0PJ[XZ_`0Wool086Zj:[k087o^Ool08OooP3^onP0e_ok086Zj:[l
0=7o06S?oo`0PJ[XZ_`0POngoo`0R?on0>koj@3Doo/0PJ[XZ_`0X?ol086Zj:[l
087o]ool08SooP3^onT0e?ok086Zj:[l0:3oo021Z^RZo021okOoo028ooh0k_oY
0=Con`21Z^RZo03Bo`1Xd?ol086Zj:[l087o]_ol08SooP3]onX0dool086Zj:[l
0:7oo021Z^RZo021okKoo028ooh0kOoZ0=?oo021Z^RZo02Qoo`0PJ[XZ_`0POnf
oo`0R?on0>gojP3Coo`0PJ[XZ_`0d_l0J=3oo021Z^VZo021okGoo028ooh0k?o[
0=;oo021Z^RZo02Roo`0PJ[YZ_`0POneoo`0R?on0>coj`3Boo`0PJ[XZ_`0X_ol
086ZjJ[l087o]Ool08SooP3/on/0d_ol086Zj:[l0=?o06SAoo`0PJ[YZ_/0POne
oo`0R?on0>_ok@3@oo`0PJ[YZ_`0Xool086ZjJ[k087o]Ool08SooP3[ond0d?ol
086ZjJ[l0:?oo021Z^VZn`21okGoo028ooh0joo]0=3oo021Z^VZo03Co`1XdOol
086ZjZ[k087o]?ol08SooP3[ond0d?ok086ZjJ[l0:Coo021Z^ZZn`21okCoo028
ooh0joo]0=3on`21Z^VZo02Too`0PJ[ZZ_/0POndoo`0R?on0>_ok@3@oo/0PJ[Y
Z_`0e?l0J=;oo021Z^ZZn`21ok?oo028ooh0k?o/0<oon`21Z^ZZo02Uoo`0PJ[Z
Z_/0POncoo`0R?on0>cok03?oo/0PJ[ZZ_`0YOol086ZjZ[k087o/ool08SooP3/
on`0cook086ZjZ[l0=Co07CBoo`0PJ[[Z_/0POnboo`0R?on0>gon`00oo80c_ok
086ZjZ[l0:Koo021Z^^Zn`21ok;oo028ooh0kOok003olP3>oo/0PJ[ZZ_`0Y_ol
086Zjj[k087o/_ol08SooP3]oo/00?ob0<kon`21Z^ZZo03Eo`1ddool086Zjj[k
087o/Ool08SooP3^oo/0o_od0<con`21Z^^Zo02Woo`0PJ[[Z_/0POnaoo`0R?on
0>kon`3noo@0c?ok086Zjj[l0:Ooo021Z^^Zn`21ok7oo028ooh0k_ok0?kom03<
oo/0PJ[[Z_`0eOl0M=?oo021Z^^Zo021ok3oo028ooh0k_ol0?_omP3;oo`0PJ[Z
Z_`0Z?ol086Zjj[l087o/?ol08SooP3^oo`0noof0<_oo021Z^ZZo02Xoo`0PJ[[
Z_`0POn`oo`0R?on0>koo03kooH0bool086ZjZ[l0=Ko07CDoo`0PJ[[Z_`0POn_
oo`0R?on0>ooo03hooP0b_ol086Zjj[l0:Woo021Z^^Zo021ojooo028ooh0kool
0?Son03:oo`0PJ[[Z_`0ZOol086Zjj[l087o[ool08SooP3_oo`0n?oh0<[oo021
Z^^Zo03Fo`1de?ol086Zk:[k087o[ool08SooP3`oo`0m_oj0<Won`21Z^^Zo02Z
oo`0PJ[/Z_/0POn_oo`0R?on0?3oo03fooX0bOok086Zjj[l0:[oo021Z^bZn`21
ojooo028ooh0l?ol0?KonP39oo/0PJ[[Z_`0eol0M=Goo021Z^bZn`21ojkoo028
ooh0lOok0??oo@38oo/0PJ[/Z_`0Zool086Zk:[k087o[_ol08SooP3aoo/0loom
0<Son`21Z^bZo02[oo`0PJ[/Z_/0POn^oo`0R?on0?7on`3cood0b?ok086Zk:[l
0=Oo06SEoo`0PJ[/Z_`0POn]oo`0R?on0?;on`2doo`0PJ[[Z_`0[?ol086Zk:[l
087o[Ool08SooP3boo/0]?ol086Zjj[l0:coo021Z^bZo021ojgoo028ooh0l_ok
0;Coo021Z^^Zo03Ho`1Xe_ol086Zk:[l087o[?ol08SooP3boo`0/_ol086Zk:[l
0:goo021Z^bZo021ojcoo028ooh0l_ol0;;oo021Z^bZo02]oo`0PJ[/Z_`0POn/
oo`0R?on0?;oo02boo`0PJ[/Z_`0f?l0J=Koo021Z^fZn`21ojcoo028ooh0lool
0;7on`21Z^bZo02^oo`0PJ[]Z_/0POn/oo`0R?on0??oo02aoo/0PJ[/Z_`0[_ol
086ZkJ[k087o[?ol08SooP3coo`0/Ook086Zk:[l0=Wo06SGoo`0PJ[]Z_/0POn[
oo`0R?on0?Coo02_oo/0PJ[]Z_`0[ool086ZkJ[k087oZool08SooP3doo`0[ook
086ZkJ[l0:ooo021Z^fZn`21oj_oo028ooh0m?ol0:oon`21Z^fZo03Io`1Xeool
086ZkJ[l087oZ_ol08SooP3eoo/0[_ok086ZkJ[l0;3oo021Z^fZo021oj[oo028
ooh0mOok0:kon`21Z^fZo02`oo`0PJ[]Z_`0POnZoo`0R?on0?Gon`2^oo/0PJ[]
Z_`0f_l0J=Soo021Z^fZo021ojWoo028ooh0m_ok0:coo021Z^fZo02aoo`0PJ[]
Z_`0POnYoo`0R?on0?Kon`2/oo`0PJ[]Z_`0/Ool086ZkJ[l087oZOol08SooP3f
oo/0[?ol086ZkJ[l0=[o06;Hoo`0PJ[^Z_/0POnYoo`0POojoo`0Zook086ZkJ[l
0;;oo021Z^jZn`21ojWoo021oo[oo02[oo/0PJ[]Z_`0/_ol086ZkZ[k087oZOol
087on_ol0:_on`21Z^fZo03Ko`1RfOol086ZkZ[k087oZ?ol087onool0:Won`21
Z^jZo02coo`0PJ[^Z_/0POnXoo`0POokoo`0ZOok086ZkZ[l0;?oo021Z^jZn`21
ojSoo021oo_oo02Yoo/0PJ[^Z_`0fol0H]Woo021Z^nZn`21ojOoo021oocoo02W
oo/0PJ[^Z_`0]?ol086Zkj[k087oYool087oo?ol0:Oon`21Z^jZo02doo`0PJ[_
Z_/0POnWoo`0POoloo`0Yook086ZkZ[l0=co06;Joo`0PJ[^Z_/0POnWoo`0POom
oo/0Yook086ZkZ[l0;Goo021Z^jZn`21ojOoo021oogon`2Woo/0PJ[^Z_`0]Ool
086ZkZ[k087oYool087ooOok0:Oon`21Z^jZo03Lo`1Rf_ol086Zkj[k087oY_ol
087oo_ok0:Gon`21Z^jZo02foo`0PJ[_Z_/0POnVoo`0POonoo/0YOok086ZkZ[l
0;Koo021Z^nZn`21ojKoo021ookon`2Uoo/0PJ[^Z_`0gOl0H]_oo021Z^nZn`21
ojGoo021ookoo02Soo/0PJ[_Z_`0]ool086Zkj[k087oYOol087oo_ol0:?on`21
Z^nZo02goo`0PJ[_Z_/0POnUoo`0POonoo`0Xook086Zkj[l0=go06GKoo`0PJ[`
Z_/0POnToo`0POl1oool0:7on`21Z^nZo02hoo`0PJ[`Z_/0POnToo`0POl1oool
0:7on`21Z^nZo02hoo`0PJ[`Z_/0POnToo`0POl1oool0:7on`21Z^nZo03No`1R
g?ol086Zkj[k087oY?ol087o0?ol0:3on`21Z^nZo02ioo`0PJ[_Z_/0POnToo`0
POl0oo`0X?ok086Zkj[l0;Woo021Z^nZn`21ojCoo021o`3oo02Poo/0PJ[_Z_`0
g_l0G=coo021Z_2Zn`21oj?oo021oo/0Wook086Zkj[m0;Woo021Z_2Zn`21oj?o
o021oo/0Wook086Zkj[m0;Woo021Z_2Zn`21oj?oo021oo/0Wook086Zkj[m0=ko
05cMoo`0PJ[`Z_/0POnRoo`0P_ok09gon`21Z_2Zo02koo`0PJ[`Z_/0POnRoo`0
P_ok09gon`21Z_2Zo02koo`0PJ[`Z_/0POnRoo`0P_ok09gon`21Z_2Zo03Oo`1L
gOol086ZlJ[k087oXOol08;oo02Koo/0PJ[aZ_`0^ool086ZlJ[k087oXOol08;o
o02Koo/0PJ[aZ_`0^ool086ZlJ[k087oXOol08;oo02Koo/0PJ[aZ_`0gol0G=go
o@21Z_2Zn`21oj7oo023oo`0V_ok086Zl:[m0;_oo@21Z_2Zn`21oj7oo023oo`0
V_ok086Zl:[m0;_oo@21Z_2Zn`21oj7oo023oo`0V_ok086Zl:[m0=oo05cNoo`0
PJ[aZ_/0POnPoo`0Q?ol09Son`21Z_6Zo02moo`0PJ[aZ_/0POnPoo`0Q?ol09So
n`21Z_6Zo02moo`0PJ[aZ_/0POnPoo`0Q?ol09Son`21Z_6Zo03Po`1Lg_ol086Z
lJ[l087oWool08Gon`2Goo`0PJ[aZ_`0_Ool086ZlJ[l087oWool08Gon`2Goo`0
PJ[aZ_`0_Ool086ZlJ[l087oWool08Gon`2Goo`0PJ[aZ_`0h?l0G=ooo021Z_6Z
n`21oiooo026oo/0U_ok086ZlJ[l0;ooo021Z_6Zn`21oiooo026oo/0U_ok086Z
lJ[l0;ooo021Z_6Zn`21oiooo026oo/0U_ok086ZlJ[l0>7o05cOoo`0PJ[aZ_`0
POnNoo`0Q_ol09Con`21Z_:Zo02ooo`0PJ[aZ_`0POnNoo`0Q_ol09Con`21Z_:Z
o02ooo`0PJ[aZ_`0POnNoo`0Q_ol09Con`21Z_:Zo03Qo`1Lgoom086ZlJ[l087o
W?ol08Soo02Coo/0PJ[aZ_d0_oom086ZlJ[l087oW?ol08Soo02Coo/0PJ[aZ_d0
_oom086ZlJ[l087oW?ol08Soo02Coo/0PJ[aZ_d0hOl0G>3oo021Z_:Zn`21oico
o029oo`0TOok086ZlZ[l0<7oo021Z_:Zn`21oicoo029oo`0TOok086ZlZ[l0<7o
o021Z_:Zn`21oicoo029oo`0TOok086ZlZ[l0>;o05cPoo`0PJ[bZ_`0POnKoo`0
R_ok093oo021Z_:Zo031oo`0PJ[bZ_`0POnKoo`0R_ok093oo021Z_:Zo031oo`0
PJ[bZ_`0POnKoo`0R_ok093oo021Z_:Zo03Ro`1Lh?om086ZlZ[l087oV_ol08_o
n`2?oo/0PJ[bZ_d0`Oom086ZlZ[l087oV_ol08_on`2?oo/0PJ[bZ_d0`Oom086Z
lZ[l087oV_ol08_on`2?oo/0PJ[bZ_d0h_l0G>7oo021Z_:Zo021oi[oo02;oo`0
SOol086ZlZ[l0<?oo021Z_:Zo021oi[oo02;oo`0SOol086ZlZ[l0<?oo021Z_:Z
o021oi[oo02;oo`0SOol086ZlZ[l0>?o05cQoo`0PJ[cZ_`0POnIoo`0S?ol08_o
o021Z_>Zo033oo`0PJ[cZ_`0POnIoo`0S?ol08_oo021Z_>Zo033oo`0PJ[cZ_`0
POnIoo`0S?ol08_oo021Z_>Zo03So`1LhOom086Zlj[l087oV?ol08goo02:oo/0
PJ[cZ_d0`oom086Zlj[l087oV?ol08goo02:oo/0PJ[cZ_d0`oom086Zlj[l087o
V?ol08goo02:oo/0PJ[cZ_d0hol0G>;oo021Z_>Zo021oiSoo02>oo/0ROol086Z
lj[l0<Goo021Z_>Zo021oiSoo02>oo/0ROol086Zlj[l0<Goo021Z_>Zo021oiSo
o02>oo/0ROol086Zlj[l0>Co05cRood0PJ[cZ_`0POnGoo`0Sook08Son`21Z_>Z
o@35ood0PJ[cZ_`0POnGoo`0Sook08Son`21Z_>Zo@35ood0PJ[cZ_`0POnGoo`0
Sook08Son`21Z_>Zo@3To`1Lh_om086Zlj[l087oUool08ooo026oo`0PJ[cZ_d0
aOom086Zlj[l087oUool08ooo026oo`0PJ[cZ_d0aOom086Zlj[l087oUool08oo
o026oo`0PJ[cZ_d0i?l0G>?oo021Z_BZo021oiKoo02@oo`0Q?ol086Zm:[l0<Oo
o021Z_BZo021oiKoo02@oo`0Q?ol086Zm:[l0<Ooo021Z_BZo021oiKoo02@oo`0
Q?ol086Zm:[l0>Go05cSood0PJ[cZ_d0POnEoo`0TOol08?on`21Z_BZo@37ood0
PJ[cZ_d0POnEoo`0TOol08?on`21Z_BZo@37ood0PJ[cZ_d0POnEoo`0TOol08?o
n`21Z_BZo@3Uo`1Li?ol086Zm:[l087oUOol09;on`22oo`0PJ[dZ_`0bOol086Z
m:[l087oUOol09;on`22oo`0PJ[dZ_`0bOol086Zm:[l087oUOol09;on`22oo`0
PJ[dZ_`0i_l0G>Coo021Z_FZo021oiCoo02Coo/0POok086ZmJ[l0<Woo021Z_FZ
o021oiCoo02Coo/0POok086ZmJ[l0<Woo021Z_FZo021oiCoo02Coo/0POok086Z
mJ[l0>Ko06GTood0PJ[dZ_d0POnCoo`0Tool087o0Oooo021Z_BZo@39ood0PJ[d
Z_d0POnCoo`0Tool087o0Oooo021Z_BZo@39ood0PJ[dZ_d0POnCoo`0Tool087o
0Oooo021Z_BZo@3Vo`1RiOol086ZmJ[l087oTool09Coo021oogoo021Z_FZo03;
oo`0PJ[eZ_`0POnCoo`0U?ol087ooOol086ZmJ[l0<_oo021Z_FZo021oi?oo02D
oo`0POomoo`0PJ[eZ_`0iol0H^Goo021Z_FZo@21oi;oo02Eoo`0POoloo`0PJ[e
Z_`0bool086ZmJ[m087oT_ol09Goo021oocoo021Z_FZo03;oo`0PJ[eZ_d0POnB
oo`0UOol087oo?ol086ZmJ[l0>Oo06;Uood0PJ[eZ_d0POnAoo`0U_ok087onool
086ZmJ[m0<_oo@21Z_FZo@21oi7oo02Foo/0POokoo`0PJ[eZ_d0boom086ZmJ[m
087oTOol09Kon`21oo_oo021Z_FZo@3Wo`1Ri_ol086ZmJ[m087oTOol09Oon`21
oo[on`21Z_JZo03=oo`0PJ[eZ_d0POnAoo`0Uook087on_ok086ZmZ[l0<goo021
Z_FZo@21oi7oo02Goo/0POojoo/0PJ[fZ_`0j?l0H^Koo@21Z_FZo021oi7oo02G
oo`0POohoo`0PJ[eZ_d0cOom086ZmJ[l087oTOol09Ooo021ooSoo021Z_FZo@3=
ood0PJ[eZ_`0POnAoo`0Uool087on?ol086ZmJ[m0>So06;Vood0PJ[eZ_`0POnA
oo`0V?ol087om_om086ZmJ[m0<goo@21Z_FZo021oi7oo02Hoo`0POofood0PJ[e
Z_d0cOom086ZmJ[l087oTOol09Soo021ooKoo@21Z_FZo@3Xo`1Riool086ZmZ[l
087oT?ol09Woo021ooGoo021Z_JZo03?oo`0PJ[fZ_`0POn@oo`0VOol087omOol
086ZmZ[l0<ooo021Z_JZo021oi3oo02Ioo`0POoeoo`0PJ[fZ_`0jOl0H^Ooo@21
Z_FZo021oi3oo02Joo/0POoeoo`0PJ[eZ_d0coom086ZmJ[l087oT?ol09[on`21
ooGoo021Z_FZo@3?ood0PJ[eZ_`0POn@oo`0V_ok087omOol086ZmJ[m0>Wo06;W
ood0PJ[fZ_`0POn?oo`0Vook087olool086ZmZ[l0=3oo@21Z_JZo021ohooo02K
oo/0POocoo`0PJ[fZ_`0d?om086ZmZ[l087oSool09_on`21oo?oo021Z_JZo03Z
o`1Rj?ol086ZmZ[l087oSool09_oo021oo;oo021Z_JZo03Aoo`0PJ[fZ_`0POn?
oo`0Vool087ol_ol086ZmZ[l0=7oo021Z_JZo021ohooo02Koo`0POoboo`0PJ[f
Z_`0j_l0H^Soo@21Z_JZo021ohkoo02Loo`0POo`oo`0PJ[fZ_d0dOom086ZmZ[l
087oS_ol09coo021oo3oo021Z_JZo@3Aood0PJ[fZ_`0POn>oo`0W?ol087ol?ol
086ZmZ[m0>[o06;Yoo`0PJ[fZ_`0POn>oo`0WOol087okool086ZmZ[l0=?oo021
Z_JZo021ohkoo02Moo`0POo_oo`0PJ[fZ_`0dool086ZmZ[l087oS_ol09goo021
onooo021Z_JZo03[o`1RjOom086ZmZ[l087oSOol09kon`21onkoo021Z_JZo@3C
ood0PJ[fZ_`0POn=oo`0W_ok087ok_ol086ZmZ[m0=?oo@21Z_JZo021ohgoo02N
oo/0POo^oo`0PJ[fZ_d0jol0H^Woo@21Z_JZo021ohgoo02Ooo/0POo]oo`0PJ[f
Z_d0doom086ZmZ[l087oSOol09oon`21ongoo021Z_JZo@3Cood0PJ[fZ_`0POn=
oo`0Wook087okOol086ZmZ[m0>_o06;Zoo`0PJ[gZ_`0POn<oo`0Wool087ojool
086Zmj[l0=Goo021Z_NZo021ohcoo02Ooo`0POo[oo`0PJ[gZ_`0eOol086Zmj[l
087oS?ol09ooo021on_oo021Z_NZo03/o`1Rj_om086ZmZ[l087oS?ol0:3oo021
on[oo021Z_JZo@3Eood0PJ[fZ_`0POn<oo`0X?ol087oj_ol086ZmZ[m0=Goo@21
Z_JZo021ohcoo02Poo`0POoZoo`0PJ[fZ_d0k?l0H^[oo@21Z_NZo021oh_oo02Q
oo`0POoXoo`0PJ[gZ_d0eOom086Zmj[l087oRool0:7oo021onSoo021Z_NZo@3E
ood0PJ[gZ_`0POn;oo`0XOol087oj?ol086Zmj[m0>co06;[oo`0PJ[gZ_`0POn;
oo`0X_ok087oj?ol086Zmj[l0=Ooo021Z_NZo021oh_oo02Roo/0POoXoo`0PJ[g
Z_`0eool086Zmj[l087oRool0:;on`21onSoo021Z_NZo03]o`1Rjool086Zn:[l
087oR_ol0:?on`21onKoo021Z_NZo@3Goo`0PJ[hZ_`0POn:oo`0Xook087oi_ol
086Zmj[m0=Ooo021Z_RZo021oh[oo02Soo/0POoVoo`0PJ[gZ_d0kOl0H^_oo@21
Z_NZo021ohWoo02Too`0POoUoo`0PJ[gZ_d0eoom086Zmj[l087oROol0:Coo021
onGoo021Z_NZo@3Good0PJ[gZ_`0POn9oo`0Y?ol087oiOol086Zmj[m0>go06;[
ood0PJ[hZ_`0POn8oo`0YOol087ohool086Zn:[m0=Ooo@21Z_RZo021ohSoo02U
oo`0POoSoo`0PJ[hZ_d0eoom086Zn:[l087oR?ol0:Goo021on?oo021Z_RZo@3]
o`1Rk?ol086Zn:[l087oR?ol0:Koo021on;oo021Z_RZo03Ioo`0PJ[hZ_`0POn8
oo`0Y_ol087oh_ol086Zn:[l0=Woo021Z_RZo021ohSoo02Voo`0POoRoo`0PJ[h
Z_`0k_l0H^coo021Z_VZo021ohOoo02Woo/0POoQoo`0PJ[hZ_d0fOol086ZnJ[l
087oQool0:Oon`21on7oo021Z_RZo@3Ioo`0PJ[iZ_`0POn7oo`0Yook087ohOol
086Zn:[m0>ko06;/ood0PJ[hZ_`0POn7oo`0Z?ok087oh?ol086Zn:[m0=Woo@21
Z_RZo021ohOoo02Xoo/0POoPoo`0PJ[hZ_d0fOom086Zn:[l087oQool0:Son`21
on3oo021Z_RZo@3^o`1Rk?om086ZnJ[l087oQ_ol0:Soo021omkoo021Z_VZo@3I
ood0PJ[iZ_`0POn6oo`0Z?ol087og_ol086ZnJ[m0=Woo@21Z_VZo021ohKoo02X
oo`0POoNoo`0PJ[iZ_d0k_l0H^goo021Z_VZo021ohKon`2Zoo`0POoMoo`0PJ[i
Z_`0fool086ZnJ[l087oQ_ok0:[oo021omgoo021Z_VZo03Koo`0PJ[iZ_`0POn6
oo/0Z_ol087ogOol086ZnJ[l0>oo06;]oo`0PJ[jZ_`0POn;onX0]_ol087ofool
086ZnJ[m0=_oo021Z_ZZo021oh_ojP2foo`0POoKoo`0PJ[iZ_d0fool086ZnZ[l
087oRooZ0;Koo021om_oo021Z_VZo@3_o`1RkOom086ZnJ[l087oU_oD0<;on`21
om_oo021Z_VZo@3Kood0PJ[iZ_`0POnFom@0`_ok087ofool086ZnJ[m0=_oo@21
Z_VZo021oiKoe032oo/0POoKoo`0PJ[iZ_d0kol0H^goo@21Z_VZo@21oiGoe033
oo/0POoIood0PJ[iZ_d0foom086ZnJ[m087oUOoD0<?on`21omWoo@21Z_VZo@3K
ood0PJ[iZ_d0POnEom@0`ook087ofOom086ZnJ[m0>oo06;^oo`0PJ[jZ_`0POnH
old0aool087of?ol086ZnZ[l0=goo021Z_ZZo021oiSoc@37oo`0POoHoo`0PJ[j
Z_`0gOol086ZnZ[l087oV?o=0<Ooo021omSoo021Z_ZZo03`o`1jk_ol086ZnZ[l
087oW?oZ0038o03ib>/0bool087oeool086ZnJ[m0=goo021Z_ZZo021oicojP00
b?`0nLS[0<_oo021omOoo021Z_VZo@3Moo`0PJ[jZ_`0POnLonX00<Sl0?W8j`3;
oo`0POoGoo`0PJ[iZ_d0l?l0N^koo@21Z_ZZo021oikok`3hb?`0l/S^0=3oo021
omGoo021Z_ZZo@3Mood0PJ[jZ_`0POnNonl0n<Sl0?;8kP3@oo`0POoEoo`0PJ[j
Z_d0gOom086ZnZ[l087oW_o_0?S8o03bb>h0d?ol087oeOol086ZnZ[m0?3o07[^
ood0PJ[jZ_`0POnRoo80lLSl0>_8lP3Doo/0POoEoo`0PJ[jZ_d0gOom086ZnZ[l
087oX_ob0?78o03[b?80e?ok087oeOol086ZnZ[m0=goo@21Z_ZZo021oj;olP3a
b?`0jlSb0=Con`21omGoo021Z_ZZo@3`o`1jkool086ZnZ[m087oY?ob0>k8o03W
b?80fOok087odoom086ZnZ[l0=ooo021Z_ZZo@21ojColP3^b?`0ilSb0=Won`21
om?oo@21Z_ZZo03Ooo`0PJ[jZ_d0POnToo80k/Sl0>O8lP3Ioo/0POoCood0PJ[j
Z_`0lOl0N^ooo021Z_^Zo021ojSolP3Zb?`0i<Sb0=coo021om;oo021Z_ZZo@3O
oo`0PJ[kZ_`0POnXoo80j/Sl0>C8lP3Loo`0POoBoo`0PJ[jZ_d0gool086Znj[l
087oZ?ob0>[8o03Tb?80g?ol087od_ol086ZnZ[m0?7o07[_ood0PJ[jZ_`0POnZ
oo<0ilSl0>38m03Ooo`0POoAoo`0PJ[jZ_d0goom086ZnZ[l087oZ_oc0>O8o03P
b?@0gool087odOol086ZnZ[m0=ooo@21Z_ZZo021oj[ol`3Wb?`0h<Sd0=ooo021
om7oo021Z_ZZo@3ao`1jkoom086ZnZ[m087oZ_of0>?8o03Mb?D0h_ol087ocoom
086ZnZ[m0=ooo@21Z_ZZo@21oj[omP3Sb?`0gLSe0>;oo021olooo@21Z_ZZo@3O
ood0PJ[jZ_d0POnZooH0hlSl0=g8m@3Roo`0POo?ood0PJ[jZ_d0lOl0N_3oo021
Z_^Zo021ojcom`3Pb?`0fLSh0>Con`21olooo021Z_^Zo03Qoo`0PJ[kZ_`0POn/
ooL0h<Sl0=W8n03Too/0POo?oo`0PJ[kZ_`0hOol086Znj[l087o[?og0>38o03I
b?P0i?ok087ocool086Znj[l0?;o07[`oo`0PJ[kZ_`0POn^ooP0gLSl0=O8n03W
oo/0POo>oo`0PJ[jZ_d0hOol086Znj[l087o[_oh0=g8o03Gb?P0iook087oc_ol
086ZnZ[m0>7oo021Z_^Zo021ojkon03Mb?`0elSh0>Oon`21olkoo021Z_ZZo@3b
o`1jl?om086Znj[l087o[ooh0=_8o03Eb?P0jOol087oc?ol086Znj[m0>7oo@21
Z_^Zo021ojoon03Kb?`0eLSh0>Woo021olcoo021Z_^Zo@3Qood0PJ[kZ_`0POn_
ooP0flSl0=G8n03Yoo`0POo<oo`0PJ[kZ_d0l_l0N_3oo@21Z_^Zo021ok3on@3I
b?`0dlSi0>_oo021ol_oo021Z_^Zo@3Qood0PJ[kZ_`0POn`ooT0fLSl0=?8n@3[
oo`0POo;oo`0PJ[kZ_d0hOom086Znj[l087o/?oi0=W8o03Cb?T0jool087obool
086Znj[m0?;o07[aoo`0PJ[kZ_d0POnaooT0elSl0=78n@3^oo`0POo9ood0PJ[k
Z_`0hool086Znj[m087o/Ooi0=O8o03Ab?T0k_ol087obOom086Znj[l0>?oo021
Z_^Zo@21ok7on@3Gb?`0dLSi0>koo021olWoo@21Z_^Zo03co`1jlOol086Zo:[l
087o/ooi0=G8o03?b?T0lOok087obOol086Znj[m0>?oo021Z_bZo021ok?on@3E
b?`0clSi0?7on`21olWoo021Z_^Zo@3Soo`0PJ[lZ_`0POncooT0eLSl0<o8n@3a
oo/0POo9oo`0PJ[kZ_d0lol0N_7oo@21Z_^Zo021okGon03Db?`0cLSi0?Con`21
olSoo021Z_^Zo@3Sood0PJ[kZ_`0POneooP0e<Sl0<g8n@3doo/0POo8oo`0PJ[k
Z_d0hoom086Znj[l087o]Ooh0=C8o03=b?T0m?ok087ob?ol086Znj[m0??o07[a
ood0PJ[lZ_`0POneooT0d/Sl0<c8n@3eoo`0POo6oo`0PJ[lZ_d0hoom086Zo:[l
087o]Ooi0=;8o03<b?T0mOol087oa_ol086Zo:[m0>?oo@21Z_bZo021okGon@3B
b?`0c<Si0?Goo021olKoo021Z_bZo@3co`1jl_ol086Zo:[l087o]ooi0=38o03:
b?T0n?ol087oaOol086Zo:[l0>Goo021Z_bZo021okOon@3@b?`0b/Si0?Soo021
olGoo021Z_bZo03Uoo`0PJ[lZ_`0POngooT0d<Sl0<[8n@3hoo`0POo5oo`0PJ[l
Z_`0m?l0N_;oo021Z_bZo@21okOonP3>b?`0b<Sj0?[oo021ol?oo@21Z_^Zo@3U
oo`0PJ[lZ_d0POngooX0c/Sl0<S8nP3joo`0POo3ood0PJ[kZ_d0iOol086Zo:[m
087o]ooj0<k8o038b?X0n_ol087o`oom086Znj[m0?Co07[bood0PJ[lZ_`0POni
ooX0c<Sl0<K8nP3moo/0POo3oo`0PJ[lZ_d0iOom086Zo:[l087o^Ooj0<c8o036
b?X0oOok087o`ool086Zo:[m0>Goo@21Z_bZo021okWonP3<b?`0a/Sj0?gon`21
ol?oo021Z_bZo@3do`1ml_om086Zo:[l087o^_ok0<[8o034b?/00Ooon`21ol;o
o021Z_bZo@3Uood0PJ[lZ_`0POnjoo/0b/Sl0<C8n`01oook087o`_ol086Zo:[m
0>Goo@21Z_bZo021ok[on`3:b?`0a<Sk007ooo/0POo2oo`0PJ[lZ_d0m?l0N_?o
o021Z_bZo@21ok[on`39b?`0`lSk003oo021ol3oo@21Z_bZo03Woo`0PJ[lZ_d0
POnjoo/0bLSl0<?8n`00oo`0POo0ood0PJ[lZ_`0iool086Zo:[m087o^_ok0<W8
o033b?/00?ol087o`?om086Zo:[l0?Go06kcoo`0PJ[mZ_`0POnlooX0b<Sl0<;8
m`21okooo021Z_bZo@3Woo`0PJ[mZ_`0POnlooX0b<Sl0<;8m`21okooo021Z_bZ
o@3Woo`0PJ[mZ_`0POnlooX0b<Sl0<;8m`21okooo021Z_bZo@3eo`1^loom086Z
o:[l087o_Ooj0<O8o031b?T0POnnoo`0PJ[lZ_d0ioom086Zo:[l087o_Ooj0<O8
o031b?T0POnnoo`0PJ[lZ_d0ioom086Zo:[l087o_Ooj0<O8o031b?T0POnnoo`0
PJ[lZ_d0mOl0K_?oo@21Z_fZo021okgon`35b?`0_lSk087o_Ool086ZoJ[l0>So
o@21Z_fZo021okgon`35b?`0_lSk087o_Ool086ZoJ[l0>Soo@21Z_fZo021okgo
n`35b?`0_lSk087o_Ool086ZoJ[l0?Ko06kdoo`0PJ[mZ_`0POnnoo/0`lSl0<78
n021okooo021Z_fZo03Yoo`0PJ[mZ_`0POnnoo/0`lSl0<78n021okooo021Z_fZ
o03Yoo`0PJ[mZ_`0POnnoo/0`lSl0<78n021okooo021Z_fZo03fo`1^m?ol086Z
oJ[m087o_ooj0<;8o031b?L0POnoood0PJ[lZ_d0jOol086ZoJ[m087o_ooj0<;8
o031b?L0POnoood0PJ[lZ_d0jOol086ZoJ[m087o_ooj0<;8o031b?L0POnoood0
PJ[lZ_d0m_l0K_Coo@21Z_bZo@21ol3onP31b?`0`/Se087o`?om086Zo:[m0>Wo
o@21Z_bZo@21ol3onP31b?`0`/Se087o`?om086Zo:[m0>Woo@21Z_bZo@21ol3o
nP31b?`0`/Se087o`?om086Zo:[m0?Ko07gdood0PJ[mZ_`0POo1ooX0`<Sl0<?8
o001b<Sj087o`Ool086ZoJ[m0>Woo@21Z_fZo021ol7onP30b?`0`lSl0078b?X0
POo1oo`0PJ[mZ_d0jOom086ZoJ[l087o`Ooj0<38o033b?`00LS8nP21ol7oo021
Z_fZo@3fo`1jm?om086ZoJ[m087o`_oi0;o8o034b?/0o/Si087o`_om086ZoJ[m
0>Woo@21Z_fZo@21ol;on@2ob?`0a<Sk0?k8n@21ol;oo@21Z_fZo@3Yood0PJ[m
Z_d0POo2ooT0_lSl0<C8n`3nb?T0POo2ood0PJ[mZ_d0m_l0N_Goo@21Z_bZo@21
ol?on@2nb?`0aLSk0?c8n@21ol?oo@21Z_fZo03[ood0PJ[lZ_d0POo3ooT0_/Sl
0<G8n`3lb?T0POo3ood0PJ[mZ_`0joom086Zo:[m087o`ooi0;k8o035b?/0o<Si
087o`oom086ZoJ[l0?Oo07[eood0PJ[lZ_d0POo3oo/0_<Sl0<G8o03ib?/0POo3
ood0PJ[lZ_d0joom086Zo:[m087o`ook0;c8o035b?`0nLSk087o`oom086Zo:[m
0>_oo@21Z_bZo@21ol?on`2lb?`0aLSl0?W8n`21ol?oo@21Z_bZo@3go`1jmOom
086ZoJ[l087oa?ok0;_8o036b?`0mlSk087oa?ol086ZoJ[m0>_oo@21Z_fZo021
olCon`2kb?`0a/Sl0?O8n`21olCoo021Z_fZo@3[ood0PJ[mZ_`0POo4oo/0^lSl
0<K8o03gb?/0POo4oo`0PJ[mZ_d0mol0N_Goo@21Z_fZo@21olCon`2jb?`0alSl
0?G8n`21olCoo@21Z_fZo@3[ood0PJ[mZ_d0POo4oo/0^/Sl0<O8o03eb?/0POo4
ood0PJ[mZ_d0joom086ZoJ[m087oa?ok0;[8o037b?`0mLSk087oa?om086ZoJ[m
0?Oo07[eood0PJ[mZ_d0POo5oo`0^<Sl0<S8n`3cb?d0POo4ood0PJ[mZ_d0joom
086ZoJ[m087oaOol0;S8o038b?/0llSm087oa?om086ZoJ[m0>_oo@21Z_fZo@21
olGoo02hb?`0b<Sk0??8o@21olCoo@21Z_fZo@3go`1jmOom086ZoJ[m087oaOom
0;O8o039b?/0lLSm087oaOom086ZoJ[m0>_oo@21Z_fZo@21olGoo@2gb?`0bLSk
0?78o@21olGoo@21Z_fZo@3[ood0PJ[mZ_d0POo5ood0]lSl0<W8n`3ab?d0POo5
ood0PJ[mZ_d0mol0N_Koo@21Z_fZo021olKoo02gb?`0bLSl0?38o021olKoo021
Z_jZo03]ood0PJ[mZ_`0POo6oo`0]lSl0<W8o03`b?`0POo6oo`0PJ[nZ_`0kOom
086ZoJ[l087oa_ol0;O8o039b?`0l<Sl087oa_ol086ZoZ[l0?So07[food0PJ[m
Z_d0POo6oo`0]/Sl0<[8o03^b?`0POo6ood0PJ[nZ_`0kOom086ZoJ[m087oa_ol
0;K8o03:b?`0k/Sl087oa_om086ZoZ[l0>goo@21Z_fZo@21olKoo02fb?`0b/Sl
0>k8o021olKoo@21Z_jZo03ho`1jm_om086ZoJ[m087oaool0;G8o03;b?`0k<Sl
087oaoom086ZoJ[m0>goo@21Z_fZo@21olOoo02eb?`0blSl0>c8o021olOoo@21
Z_fZo@3]ood0PJ[mZ_d0POo7oo`0]LSl0<_8o03/b?`0POo7ood0PJ[mZ_d0n?l0
N_Koo@21Z_fZo@21olSoo02db?`0c<Sk0>_8o021olSoo@21Z_fZo@3]ood0PJ[m
Z_d0POo8oo`0]<Sl0<c8n`3[b?`0POo8ood0PJ[mZ_d0kOom086ZoJ[m087ob?ol
0;C8o03<b?/0jlSl087ob?om086ZoJ[m0?So07[food0PJ[nZ_`0POo9oo/0]<Sl
0<g8n`3Zb?`0POo8oo`0PJ[nZ_d0kOom086ZoZ[l087obOok0;C8o03=b?/0j/Sl
087ob?ol086ZoZ[m0>goo@21Z_jZo021olWon`2db?`0cLSk0>[8o021olSoo021
Z_jZo@3ho`1jm_om086ZoZ[m087obOok0;?8o03=b?`0j<Sl087ob?om086ZoZ[m
0>goo@21Z_jZo@21olWon`2cb?`0cLSl0>S8o021olSoo@21Z_jZo@3]ood0PJ[n
Z_d0POo9oo/0/lSl0<g8o03Xb?`0POo8ood0PJ[nZ_d0n?l0N_Ooo@21Z_fZo@21
ol[on`2bb?`0c/Sl0>K8o021olWoo@21Z_jZo03_ood0PJ[mZ_d0POo:oo/0//Sl
0<k8o03Vb?`0POo9ood0PJ[nZ_`0koom086ZoJ[m087ob_ok0;;8o03>b?`0i/Sl
087obOom086ZoZ[l0?Wo07[good0PJ[mZ_d0POo:oo`0/LSl0<o8o03Tb?`0POo:
ood0PJ[nZ_`0koom086ZoJ[m087ob_ol0;78o03?b?`0i<Sl087ob_om086ZoZ[l
0>ooo@21Z_fZo@21ol[oo02ab?`0clSl0>C8o021ol[oo@21Z_jZo03io`1jmoom
086ZoZ[l087obook0;78o03@b?/0i<Sk087obool086ZoZ[m0>ooo@21Z_jZo021
ol_on`2ab?`0d<Sk0>C8n`21ol_oo021Z_jZo@3_ood0PJ[nZ_`0POo;oo/0/LSl
0=38n`3Tb?/0POo;oo`0PJ[nZ_d0nOl0N_Ooo@21Z_jZo@21ol_on`2`b?`0dLSk
0>;8o021ol[oo@21Z_jZo@3_ood0PJ[nZ_d0POo;oo/0/<Sl0=78n`3Rb?`0POo:
ood0PJ[nZ_d0koom086ZoZ[m087obook0;38o03Ab?/0h/Sl087ob_om086ZoZ[m
0?Wo07[good0PJ[nZ_d0POo<oo/0[lSl0=78o03Pb?`0POo;ood0PJ[nZ_d0koom
086ZoZ[m087oc?ok0:o8o03Ab?`0h<Sl087oboom086ZoZ[m0>ooo@21Z_jZo@21
olcon`2_b?`0dLSl0>38o021ol_oo@21Z_jZo@3io`1jmoom086ZoZ[m087ocOok
0:k8o03Bb?`0g/Sk087ocOom086ZoZ[m0>ooo@21Z_jZo@21olgon`2^b?`0d/Sl
0=k8n`21olgoo@21Z_jZo@3_ood0PJ[nZ_d0POo=oo/0[/Sl0=;8o03Nb?/0POo=
ood0PJ[nZ_d0nOl0OOSoo@21Z_jZo021olkonP2^b?`0dlSl0=c8n`21olkoo021
ZP6ZZ_`0lOom086ZoZ[l087oc_oj0:k8o03Cb?`0g<Sk087oc_ol086Z0JZZo03a
ood0PJ[nZ_`0POo>ooX0[/Sl0=?8o03Lb?/0POo>oo`0PJX1ZZ[l0?[o07ghood0
PJ[nZ_d0POo=oo/0[LSl0=C8n`3Lb?/0POo=ood0PJX1ZZ[l0?7oo@21Z_jZo@21
olgon`2]b?`0e<Sk0=c8n`21olgoo@21ZP6ZZ_`0lOom086ZoZ[m087ocOok0:g8
o03Db?/0g<Sk087ocOom086Z0JZZo03jo`1mn?om086ZoZ[m087oc_ol0:_8o03E
b?/0fLSl087oc_om086Z0JZZo03aood0PJ[nZ_d0POo>oo`0ZlSl0=G8n`3Ib?`0
POo>ood0PJX1ZZ[l0?7oo@21Z_jZo@21olkoo02[b?`0eLSk0=W8o021olkoo@21
ZP6ZZ_`0n_l0OOSoo@21Z_jZo@21olkoo02[b?`0eLSl0=S8o021olkoo021ZP6Z
Z_d0lOom086ZoZ[m087oc_ol0:_8o03Eb?`0f<Sl087oc_ol086Z0JZZo@3aood0
PJ[nZ_d0POo>oo`0ZlSl0=G8o03Hb?`0POo>oo`0PJX1ZZ[m0?[o083hood0PJX1
ZZ[l087ocool0:[8o03Fb?`0e/Sl087oc_om086Z0JZZo@3aood0PJX1ZZ[l087o
cool0:[8o03Fb?`0e/Sl087oc_om086Z0JZZo@3aood0PJX1ZZ[l087ocool0:[8
o03Fb?`0e/Sl087oc_om086Z0JZZo@3jo`20n?om086Z0JZZo@21olkoo02Zb?`0
elSl0=G8o021olkoo@21ZP6ZZ_d0lOom086Z0JZZo@21olkoo02Zb?`0elSl0=G8
o021olkoo@21ZP6ZZ_d0lOom086Z0JZZo@21olkoo02Zb?`0elSl0=G8o021olko
o@21ZP6ZZ_d0n_l0OOWoo@21Z_jZo@21olooo02Yb?`0f<Sk0=C8o021olooo@21
ZP6ZZ_`0loom086ZoZ[m087ocool0:W8o03Hb?/0e<Sl087ocoom086Z0JZZo03c
ood0PJ[nZ_d0POo?oo`0ZLSl0=S8n`3Db?`0POo?ood0PJX1ZZ[l0?_o07giood0
PJ[nZ_d0POo?oo`0ZLSl0=W8n`3Cb?`0POo?ood0PJX1ZZ[l0??oo@21Z_jZo@21
olooo02Yb?`0fLSk0=?8o021olooo@21ZP6ZZ_`0loom086ZoZ[m087ocool0:W8
o03Ib?/0dlSl087ocoom086Z0JZZo03ko`1mnOom086ZoZ[m087od?ol0:S8o03I
b?`0dLSl087od?om086Z0JZZo03cood0PJ[nZ_d0POo@oo`0Z<Sl0=W8o03Ab?`0
POo@ood0PJX1ZZ[l0??oo@21Z_jZo@21om3oo02Xb?`0fLSl0=78o021om3oo@21
ZP6ZZ_`0nol0OOWoo@21ZP6ZZ_`0POo@oo`0Z<Sl0=[8o03@b?`0POo@oo`0PJX0
Z_`0loom086Z0JZZo021om3oo02Xb?`0f/Sl0=38o021om3oo021ZP2Zo03cood0
PJX1ZZ[l087od?ol0:S8o03Jb?`0d<Sl087od?ol086Z0:[l0?_o083iood0PJX1
ZZ[m087od?ol0:O8o03Kb?`0c/Sl087od?om086Z0JZZo@3cood0PJX1ZZ[m087o
d?ol0:O8o03Kb?`0c/Sl087od?om086Z0JZZo@3cood0PJX1ZZ[m087od?ol0:O8
o03Kb?`0c/Sl087od?om086Z0JZZo@3ko`20nOom086Z0JZZo@21om3oo02Vb?`0
gLSk0<k8o021om3oo@21ZP6ZZ_d0loom086Z0JZZo@21om3oo02Vb?`0gLSk0<k8
o021om3oo@21ZP6ZZ_d0loom086Z0JZZo@21om3oo02Vb?`0gLSk0<k8o021om3o
o@21ZP6ZZ_d0nol0OO[oo@21Z_jZo@21om7oo02Ub?`0g/Sk0<c8o021om7oo@21
ZP6ZZ_`0mOom086ZoZ[m087odOol0:G8o03Nb?/0c<Sl087odOom086Z0JZZo03e
ood0PJ[nZ_d0POoAoo`0YLSl0=k8n`3<b?`0POoAood0PJX1ZZ[l0?co07gjood0
PJ[nZ_d0POoAoo`0YLSl0=k8o03;b?`0POoAood0PJX1ZZ[l0?Goo@21Z_jZo@21
om7oo02Ub?`0g/Sl0<_8o021om7oo@21ZP6ZZ_`0mOom086ZoZ[m087odOol0:G8
o03Nb?`0blSl087odOom086Z0JZZo03lo`1mn_om086ZoZ[m087od_ol0:C8o03O
b?`0bLSl087od_om086Z0JZZo03eood0PJ[nZ_d0POoBoo`0Y<Sl0=o8o039b?`0
POoBood0PJX1ZZ[l0?Goo@21Z_jZo@21om;oo02Tb?`0glSl0<W8o021om;oo@21
ZP6ZZ_`0o?l0OO[oo@21Z_jZo@21om;oo02Tb?`0h<Sl0<S8o021om;oo@21ZP6Z
Z_`0mOom086ZoZ[m087od_ol0:C8o03Pb?`0b<Sl087od_om086Z0JZZo03eood0
PJ[nZ_d0POoBoo`0Y<Sl0>38o038b?`0POoBood0PJX1ZZ[l0?co07gjood0PJX1
ZZ[l087odool0:?8o03Qb?/0alSl087odool086Z0:[l0?Goo@21ZP6ZZ_`0POoC
oo`0XlSl0>78n`37b?`0POoCoo`0PJX0Z_`0mOom086Z0JZZo021om?oo02Sb?`0
hLSk0<O8o021om?oo021ZP2Zo03lo`20n_om086Z0JZZo@21om;oo02Sb?`0h/Sk
0<K8n`21om?oo@21ZP6ZZ_`0m_om086Z0JZZo@21om;oo02Sb?`0h/Sk0<K8n`21
om?oo@21ZP6ZZ_`0m_om086Z0JZZo@21om;oo02Sb?`0h/Sk0<K8n`21om?oo@21
ZP6ZZ_`0oOl0OO_oo@21Z_jZo@21om?oo02Rb?`0h/Sl0<C8o021om?oo@21ZP6Z
Z_`0moom086ZoZ[m087odool0:;8o03Rb?`0a<Sl087odoom086Z0JZZo03good0
PJ[nZ_d0POoCoo`0X/Sl0>;8o034b?`0POoCood0PJX1ZZ[l0?go07gkood0PJ[n
Z_d0POoCoo`0X/Sl0>?8o032b?d0POoCood0PJX1ZZ[l0?Ooo@21Z_jZo@21om?o
o02Rb?`0hlSl0<;8o@21om?oo@21ZP6ZZ_`0moom086ZoZ[m087odool0:;8o03S
b?`0`/Sm087odoom086Z0JZZo03mo`1mnoom086ZoZ[m087odoom0:78o03Tb?`0
`LSm087odoom086Z0JZZo03good0PJ[nZ_d0POoCood0XLSl0>C8o031b?d0POoC
ood0PJX1ZZ[l0?Ooo@21Z_jZo@21om?oo@2Qb?`0i<Sl0<78o@21om?oo@21ZP6Z
Z_`0oOl0OO_oo@21Z_jZo@21omCoo02Qb?`0iLSk0<78o021omCoo@21ZP6ZZ_`0
moom086ZoZ[m087oe?ol0:78o03Ub?/0`LSl087oe?om086Z0JZZo03good0PJ[n
Z_d0POoDoo`0XLSl0>G8n`31b?`0POoDood0PJX1ZZ[l0?go08Wkood0PJ[nZ_d0
POoDood0X<Sl0>K8n`3Gb>X00<Sm087oe?om086Z0JZZo03good0PJ[nZ_d0POoD
ood0X<Sl0>K8n`3Gb>X00<Sm087oe?om086Z0JZZo03good0PJ[nZ_d0POoDood0
X<Sl0>K8n`3Gb>X00<Sm087oe?om086Z0JZZo03mo`2<noom086Z0JZZo021omCo
o@2Pb?`0i/Sl0>o8dP01b<Sm087oe?ol086Z0:[l0?Ooo@21ZP6ZZ_`0POoDood0
X<Sl0>K8o03_b=800LS8o@21omCoo021ZP2Zo03good0PJX1ZZ[l087oe?om0:38
o03Vb?`0klSB0078b?d0POoDoo`0PJX0Z_`0oOl0RO_oo@21ZP6ZZ_d0POoDoo`0
X<Sl0>O8o03^b=<0o/Sl087oe?om086Z0:[l0?Ooo@21ZP6ZZ_d0POoDoo`0X<Sl
0>O8o03^b=<0o/Sl087oe?om086Z0:[l0?Ooo@21ZP6ZZ_d0POoDoo`0X<Sl0>O8
o03^b=<0o/Sl087oe?om086Z0:[l0?go08Wkood0PJX1ZZ[m087oe?om09o8o03X
b?`0kLSD0?c8o@21omCoo@21ZP2Zo03good0PJX1ZZ[m087oe?om09o8o03Xb?`0
kLSD0?c8o@21omCoo@21ZP2Zo03good0PJX1ZZ[m087oe?om09o8o03Xb?`0kLSD
0?c8o@21omCoo@21ZP2Zo03mo`29noom086Z0JZZo@21omCoo@2Ob?`0jLSk0>g8
e@3kb?d0POoDood0PJX0Z_`0moom086Z0JZZo@21omCoo@2Ob?`0jLSk0>g8e@3k
b?d0POoDood0PJX0Z_`0moom086Z0JZZo@21omCoo@2Ob?`0jLSk0>g8e@3kb?d0
POoDood0PJX0Z_`0oOl0S?_oo@21ZP6ZZ_d0POoEoo`0WlSl0>[8n`3/b=H0n/Sl
087oeOom086Z0JZZo@3good0PJX1ZZ[m087oeOol09o8o03Zb?/0k<SF0?[8o021
omGoo@21ZP6ZZ_d0moom086Z0JZZo@21omGoo02Ob?`0j/Sk0>c8eP3jb?`0POoE
ood0PJX1ZZ[m0?go08ckood0PJX1ZZ[m087oeOom09k8o03Zb?`0j/SI0?O8o@21
omGoo@21ZP6ZZ_d0moom086Z0JZZo@21omGoo@2Nb?`0j/Sl0>[8f@3gb?d0POoE
ood0PJX1ZZ[m0?Ooo@21ZP6ZZ_d0POoEood0W/Sl0>[8o03Zb=T0mlSm087oeOom
086Z0JZZo@3mo`2<noom086Z0JZZo@21omGoo@2Nb?`0jlSl0>W8fP3fb?d0POoE
ood0PJX1ZZ[m0?Ooo@21ZP6ZZ_d0POoEood0W/Sl0>_8o03Yb=X0m/Sm087oeOom
086Z0JZZo@3good0PJX1ZZ[m087oeOom09k8o03[b?`0jLSJ0?K8o@21omGoo@21
ZP6ZZ_d0oOl0Q__oo@21ZP2Zo021omKoo02Nb?`0k<Sl0>S8f`3eb?`0POoFoo`0
PJX0Z_d0moom086Z0:[l087oe_ol09k8o03/b?`0j<SK0?G8o021omKoo021ZP2Z
o@3good0PJX0Z_`0POoFoo`0W/Sl0>c8o03Xb=/0mLSl087oe_ol086Z0:[m0?go
08Wlood0PJX1ZZ[m087oeOom09g8o03]b?/0j<SL0??8o@21omGoo@21ZP2Zo03i
ood0PJX1ZZ[m087oeOom09g8o03]b?/0j<SL0??8o@21omGoo@21ZP2Zo03iood0
PJX1ZZ[m087oeOom09g8o03]b?/0j<SL0??8o@21omGoo@21ZP2Zo03no`29o?om
086Z0JZZo@21omGoo@2Mb?`0k/Sk0>K8gP3bb?d0POoEood0PJX0Z_`0nOom086Z
0JZZo@21omGoo@2Mb?`0k/Sk0>K8gP3bb?d0POoEood0PJX0Z_`0nOom086Z0JZZ
o@21omGoo@2Mb?`0k/Sk0>K8gP3bb?d0POoEood0PJX0Z_`0o_l0ROcoo@21ZP6Z
Z_d0POoFoo`0WLSl0>k8o03Ub=l0lLSl087oe_om086Z0:[l0?Woo@21ZP6ZZ_d0
POoFoo`0WLSl0>k8o03Ub=l0lLSl087oe_om086Z0:[l0?Woo@21ZP6ZZ_d0POoF
oo`0WLSl0>k8o03Ub=l0lLSl087oe_om086Z0:[l0?ko08Wlood0PJX1ZZ[m087o
e_om09c8o03_b?`0i<SP0>o8o@21omKoo@21ZP2Zo03iood0PJX1ZZ[m087oe_om
09c8o03_b?`0i<SP0>o8o@21omKoo@21ZP2Zo03iood0PJX1ZZ[m087oe_om09c8
o03_b?`0i<SP0>o8o@21omKoo@21ZP2Zo03no`29o?om086Z0JZZo@21omKoo@2L
b?`0l<Sl0>?8h@3^b?d0POoFood0PJX0Z_`0nOom086Z0JZZo@21omKoo@2Lb?`0
l<Sl0>?8h@3^b?d0POoFood0PJX0Z_`0nOom086Z0JZZo@21omKoo@2Lb?`0l<Sl
0>?8h@3^b?d0POoFood0PJX0Z_`0o_l0ROcoo@21ZP6ZZ_d0POoGoo`0W<Sl0?78
n`3Rb><0kLSl087oeoom086Z0:[l0?Woo@21ZP6ZZ_d0POoGoo`0W<Sl0?78n`3R
b><0kLSl087oeoom086Z0:[l0?Woo@21ZP6ZZ_d0POoGoo`0W<Sl0?78n`3Rb><0
kLSl087oeoom086Z0:[l0?ko08Wlood0PJX1ZZ[m087oeoom09_8o03bb?/0hLST
0>_8o@21omOoo@21ZP2Zo03iood0PJX1ZZ[m087oeoom09_8o03bb?/0hLST0>_8
o@21omOoo@21ZP2Zo03iood0PJX1ZZ[m087oeoom09_8o03bb?/0hLST0>_8o@21
omOoo@21ZP2Zo03no`29o?om086Z0JZZo@21omOoo@2Kb?`0l/Sl0>78i@3Yb?d0
POoGood0PJX0Z_`0nOom086Z0JZZo@21omOoo@2Kb?`0l/Sl0>78i@3Yb?d0POoG
ood0PJX0Z_`0nOom086Z0JZZo@21omOoo@2Kb?`0l/Sl0>78i@3Yb?d0POoGood0
PJX0Z_`0o_l0ROcoo@21ZP6ZZ_d0POoHoo`0VlSl0??8o03Rb>@0j<Sl087of?om
086Z0:[l0?Woo@21ZP6ZZ_d0POoHoo`0VlSl0??8o03Rb>@0j<Sl087of?om086Z
0:[l0?Woo@21ZP6ZZ_d0POoHoo`0VlSl0??8o03Rb>@0j<Sl087of?om086Z0:[l
0?ko08?lood0PJX1ZZ[m087of?om09[8o03db?`0i<SR0>K8o@21omSoo021Z_`0
nOom086Z0JZZo@21omSoo@2Jb?`0m<Sl0>C8hP3Vb?d0POoHoo`0PJ[l0?Woo@21
ZP6ZZ_d0POoHood0V/Sl0?C8o03Tb>80i/Sm087of?ol086Zo03no`20o?om086Z
0:[l087of?om09[8o03eb?/0i/SQ0>G8o@21omSoo021Z_`0nOom086Z0:[l087o
f?om09[8o03eb?/0i/SQ0>G8o@21omSoo021Z_`0nOom086Z0:[l087of?om09[8
o03eb?/0i/SQ0>G8o@21omSoo021Z_`0o_l0T_coo@21ZP2Zo@21omOoo@2Jb?`0
m/Sk0>O8m`00b>/0i<Sm087of?ol086Z0:[m0?Woo@21ZP2Zo@21omOoo@2Jb?`0
m/Sk0>O8m`00b>/0i<Sm087of?ol086Z0:[m0?Woo@21ZP2Zo@21omOoo@2Jb?`0
m/Sk0>O8m`00b>/0i<Sm087of?ol086Z0:[m0?ko09;lood0PJX0Z_d0POoGood0
V/Sl0?K8o03Yb?H0oLS]0>?8o@21omSoo021ZP2Zo@3iood0PJX0Z_d0POoGood0
V/Sl0?K8o03Yb?H0oLS]0>?8o@21omSoo021ZP2Zo@3iood0PJX0Z_d0POoGood0
V/Sl0?K8o03Yb?H0oLS]0>?8o@21omSoo021ZP2Zo@3no`2Bo?om086Z0:[m087o
eoom09[8o03gb?`0j/Sg0?[8kP3Rb?d0POoHoo`0PJX0Z_d0nOom086Z0:[m087o
eoom09[8o03gb?`0j/Sg0?[8kP3Rb?d0POoHoo`0PJX0Z_d0nOom086Z0:[m087o
eoom09[8o03gb?`0j/Sg0?[8kP3Rb?d0POoHoo`0PJX0Z_d0o_l0T_coo@21ZP2Z
o@21omOoo@2Ib?`0nLSl0>c8mP3gb?00hLSm087of?ol086Z0:[m0?Woo@21ZP2Z
o@21omOoo@2Ib?`0nLSl0>c8mP3gb?00hLSm087of?ol086Z0:[m0?Woo@21ZP2Z
o@21omOoo@2Ib?`0nLSl0>c8mP3gb?00hLSm087of?ol086Z0:[m0?ko09;lood0
PJX0Z_d0POoHood0V<Sl0?[8n`3^b?H0mLSa0=o8o@21omWoo021ZP2Zo@3iood0
PJX0Z_d0POoHood0V<Sl0?[8n`3^b?H0mLSa0=o8o@21omWoo021ZP2Zo@3iood0
PJX0Z_d0POoHood0V<Sl0?[8n`3^b?H0mLSa0=o8o@21omWoo021ZP2Zo@3no`2B
o?om086Z0:[m087of?om09S8o03kb?/0l<Sf0?78l`3Nb?d0POoIoo`0PJX0Z_d0
nOom086Z0:[m087of?om09S8o03kb?/0l<Sf0?78l`3Nb?d0POoIoo`0PJX0Z_d0
nOom086Z0:[m087of?om09S8o03kb?/0l<Sf0?78l`3Nb?d0POoIoo`0PJX0Z_d0
o_l0T_coo@21ZP2Zo@21omSoo@2Hb?`0nlSl0?78mP3^b?H0g<Sm087of?om086Z
0:[m0?Woo@21ZP2Zo@21omSoo@2Hb?`0nlSl0?78mP3^b?H0g<Sm087of?om086Z
0:[m0?Woo@21ZP2Zo@21omSoo@2Hb?`0nlSl0?78mP3^b?H0g<Sm087of?om086Z
0:[m0?ko09;lood0PJX0Z_d0POoHood0V<Sl0?c8o03cb?H0jlSg0=_8o@21omSo
o@21ZP2Zo@3iood0PJX0Z_d0POoHood0V<Sl0?c8o03cb?H0jlSg0=_8o@21omSo
o@21ZP2Zo@3iood0PJX0Z_d0POoHood0V<Sl0?c8o03cb?H0jlSg0=_8o@21omSo
o@21ZP2Zo@3no`2Bo?om086Z0:[m087of?om09S8o03mb?`0m<Sf0>S8nP3Ib?d0
POoHood0PJX0Z_d0nOom086Z0:[m087of?om09S8o03mb?`0m<Sf0>S8nP3Ib?d0
POoHood0PJX0Z_d0nOom086Z0:[m087of?om09S8o03mb?`0m<Sf0>S8nP3Ib?d0
POoHood0PJX0Z_d0o_l0T_coo@21ZP2Zo@21omSoo@2Hb?`0o/Sk0?O8mP3Sb?d0
f<Sm087of?om086Z0:[m0?Woo@21ZP2Zo@21omSoo@2Hb?`0o/Sk0?O8mP3Sb?d0
f<Sm087of?om086Z0:[m0?Woo@21ZP2Zo@21omSoo@2Hb?`0o/Sk0?O8mP3Sb?d0
f<Sm087of?om086Z0:[m0?ko09Wmoo`0PJX0Z_d0POoHood0V<Sl0078b?/0n<Sf
0>380@00elSm087of?om086Z0:[l0?_oo021ZP2Zo@21omSoo@2Hb?`00LS8n`3h
b?H0h<P1003Gb?d0POoHood0PJX0Z_`0nool086Z0:[m087of?om09S8o001b<Sk
0?S8mP3Pb0400=O8o@21omSoo@21ZP2Zo001ool0SOgoo@21ZP6ZZ_d0POoHood0
V<Sl0078b?`0n/Sf0;78o@21omSoo@21ZP2Zo03kood0PJX1ZZ[m087of?om09S8
o001b<Sl0?[8mP2ab?d0POoHood0PJX0Z_`0noom086Z0JZZo@21omSoo@2Hb?`0
0LS8o03jb?H0/LSm087of?om086Z0:[l007oo`2:oOom086Z0JZZo@21omSoo@2H
b?`00<Sl0?_8mP2_b?d0POoHood0PJX0Z_`0noom086Z0JZZo@21omSoo@2Hb?`0
0<Sl0?_8mP2_b?d0POoHood0PJX0Z_`0noom086Z0JZZo@21omSoo@2Hb?`00<Sl
0?_8mP2_b?d0POoHood0PJX0Z_`00Ooo087mood0PJX0Z_`0POoHood0V<Sg0?g8
mP3Xb?`0b/Sm087of?ol086Zo03kood0PJX0Z_`0POoHood0V<Sg0?g8mP3Xb?`0
b/Sm087of?ol086Zo03kood0PJX0Z_`0POoHood0V<Sg0?g8mP3Xb?`0b/Sm087o
f?ol086Zo001ool0U_goo@21ZP2Zo@21omOoo@2Hb?L00LS8mP3`b?`0o/Sj0<[8
o@21omSoo021ZP2Zo@3kood0PJX0Z_d0POoGood0V<Sg0078b?H0l<Sl0?k8nP3:
b?d0POoHoo`0PJX0Z_d0noom086Z0:[m087oeoom09S8m`01b<Sf0?38o03nb?X0
b/Sm087of?ol086Z0:[m007oo`2:oOom086Z0:[m087of?ol09_8jP3]b?`00LS8
n@39b?d0POoIoo`0PJX0Z_d0noom086Z0:[m087of?ol09_8jP3]b?`00LS8n@39
b?d0POoIoo`0PJX0Z_d0noom086Z0:[m087of?ol09_8jP3]b?`00LS8n@39b?d0
POoIoo`0PJX0Z_d00Ooo08Omood0PJX0Z_d0POoHood0V/S/0>_8o000b?P0bLSm
087ofOol086Z0:[m0?_oo@21ZP2Zo@21omSoo@2Jb>`0jlSl0038n039b?d0POoI
oo`0PJX0Z_d0noom086Z0:[m087of?om09[8k03[b?`00<Sh0<W8o@21omWoo021
ZP2Zo@01ool0Qogoo@21ZP2Zo@21omSoo@2Jb>l0j<Sg0?g80039b?d0POoIoo`0
PJX0Z_d0noom086Z0:[m087of?om09[8k`3Xb?L0oLP00<W8o@21omWoo021ZP2Z
o@3kood0PJX0Z_d0POoHood0V/S_0>S8m`3mb000bLSm087ofOol086Z0:[m007o
o`1koOom086Z0:[m087of?om09_8l03Vb?T0`/Sm087ofOol086Z0:[m0?_oo@21
ZP2Zo@21omSoo@2Kb?00i/Si0<;8o@21omWoo021ZP2Zo@3kood0PJX0Z_d0POoH
ood0VlS`0>K8n@32b?d0POoIoo`0PJX0Z_d00Ooo07_mood0PJX0Z_d0POoHood0
VlSc0>?8nP31b?d0POoIoo`0PJX0Z_d0noom086Z0:[m087of?om09_8l`3Sb?X0
`LSm087ofOol086Z0:[m0?_oo@21ZP2Zo@21omSoo@2Kb?<0hlSj0<78o@21omWo
o021ZP2Zo@01ool0Nogoo@21ZP2Zo@21omSoo@2Lb?80hlSk0<38o@21omWoo021
ZP2Zo@3kood0PJX0Z_d0POoHood0W<Sb0>?8n`30b?d0POoIoo`0PJX0Z_d0noom
086Z0:[m087of?om09c8lP3Sb?/0`<Sm087ofOol086Z0:[m007oo`1koOom086Z
0:[m087of?om09c8lP3Sb?/0`<Sm087ofOol086Z0:[m0?_oo@21ZP2Zo@21omSo
o@2Lb?80hlSk0<38o@21omWoo021ZP2Zo@3kood0PJX0Z_d0POoHood0W<Sb0>?8
n`30b?d0POoIoo`0PJX0Z_d00Ooo07_mood0PJX0Z_d0POoHood0VlSc0>?8n`30
b?d0POoIoo`0PJX0Z_d0noom086Z0:[m087of?om09_8l`3Sb?/0`<Sm087ofOol
086Z0:[m0?_oo@21ZP2Zo@21omSoo@2Kb?<0hlSk0<38o@21omWoo021ZP2Zo@01
ool0Nogoo@21ZP2Zo@21omSoo@2Kb?@0h/Sl0;o8o@21omWoo021ZP2Zo@3kood0
PJX0Z_d0POoHood0VlSd0>;8o02ob?d0POoIoo`0PJX0Z_d0noom086Z0:[m087o
f?om09_8m03Rb?`0_lSm087ofOol086Z0:[m007oo`1koOom086Z0:[m087of?om
09[8m@3Rb?`0_lSm087ofOol086Z0:[m0?_oo@21ZP2Zo@21omSoo@2Jb?D0h/Sl
0;o8o@21omWoo021ZP2Zo@3kood0PJX0Z_d0POoHood0V/Se0>;8o02ob?d0POoI
oo`0PJX0Z_d00Ooo07_mood0PJX0Z_d0POoHood0V/Sf0>78o02ob?d0POoIoo`0
PJX0Z_d0noom086Z0:[m087of?om09[8mP3Qb?`0_lSm087ofOol086Z0:[m0?_o
o@21ZP2Zo@21omSoo@2Jb?H0hLSl0;o8o@21omWoo021ZP2Zo@01ool0Nogoo@21
ZP2Zo@21omSoo02Jb?P0h<Sl0<38o021omWoo021ZP2Zo@3kood0PJX0Z_d0POoH
oo`0V/Sh0>38o030b?`0POoIoo`0PJX0Z_d0noom086Z0:[m087of?ol09[8n03P
b?`0`<Sl087ofOol086Z0:[m007oo`1koOom086Z0:[l087of?om09S8o03Nb?`0
`<Sm087of?ol086Z0:[m0?_oo@21ZP2Zo021omSoo@2Hb?`0g/Sl0<38o@21omSo
o021ZP2Zo@3kood0PJX0Z_`0POoHood0V<Sl0=k8o030b?d0POoHoo`0PJX0Z_d0
0Ooo07;mood0PJX1ZZ[m087of?om0878l<Sl0<38o@21omSoo021Z_`0noom086Z
0JZZo@21omSoo@21b?38o030b?d0POoHoo`0PJ[l0?_oo@21ZP6ZZ_d0POoHood0
PLS`b?`0`<Sm087of?ol086Zo001ool0N?goo@21ZP6ZZ_d0POoHood0PLS`b?`0
`<Sm087of?om086Z0:[l0?_oo@21ZP6ZZ_d0POoHood0PLS`b?`0`<Sm087of?om
086Z0:[l0?_oo@21ZP6ZZ_d0POoHood0PLS`b?`0`<Sm087of?om086Z0:[l007o
o`1hoOom086Z0JZZo@21omSoo@21b?38o030b?d0POoHood0PJX0Z_`0noom086Z
0JZZo@21omSoo@21b?38o030b?d0POoHood0PJX0Z_`0noom086Z0JZZo@21omSo
o@21b?38o030b?d0POoHood0PJX0Z_`00Ooo07Gmoo`0PJX0Z_d0POoHood0PLS`
b?`0`<Sm087of?om086Z0:[l0?_oo021ZP2Zo@21omSoo@21b?38o030b?d0POoH
ood0PJX0Z_`0nool086Z0:[m087of?om0878l<Sl0<38o@21omSoo@21ZP2Zo001
ool0M?coo@21ZP2Zo@21omSoo@21b?38o030b?d0POoHood0PJX0Z_d0nOom086Z
0:[m087of?om0878l<Sl0<38o@21omSoo@21ZP2Zo@3iood0PJX0Z_d0POoHood0
PLS`b?`0`<Sm087of?om086Z0:[m0?ko07Clood0PJX0Z_d0POoHood0PLS`b?`0
`<Sm087of?om086Z0:[m0?Woo@21ZP2Zo@21omSoo@21b?38o030b?d0POoHood0
PJX0Z_d0nOom086Z0:[m087of?om0878l<Sl0<38o@21omSoo@21ZP2Zo@3no`1d
o?om086Z0:[m087of?om0878l<Sl0<38o@21omSoo@21ZP2Zo@3iood0PJX0Z_d0
POoHood0PLS`b?`0`<Sm087of?om086Z0:[m0?Woo@21ZP2Zo@21omSoo@21b?38
o030b?d0POoHood0PJX0Z_d0o_l0M?coo@21ZP2Zo@21omSoo@21b?38o030b?d0
POoIoo`0PJX0Z_d0nOom086Z0:[m087of?om0878l<Sl0<38o@21omWoo021ZP2Z
o@3iood0PJX0Z_d0POoHood0PLS`b?`0`<Sm087ofOol086Z0:[m0?ko07Clood0
PJX0Z_d0POoHood0PLS`b?`0`<Sm087ofOol086Z0:[m0?Woo@21ZP2Zo@21omSo
o@21b?38o030b?d0POoIoo`0PJX0Z_d0nOom086Z0:[m087of?om0878l<Sl0<38
o@21omWoo021ZP2Zo@3no`1do?om086Z0:[m087of?ol0878lLSl0<38o@21omWo
o021ZP2Zo@3iood0PJX0Z_d0POoHoo`0PLSab?`0`<Sm087ofOol086Z0:[m0?Wo
o@21ZP2Zo@21omSoo021b?78o030b?d0POoIoo`0PJX0Z_d0o_l0P?coo@21ZP2Z
o@21omOoo@21b?78o03cb?/0eLSm087of?ol086Z0:[m0?Woo@21ZP2Zo@21omOo
o@21b?78o03cb?/0eLSm087of?ol086Z0:[m0?Woo@21ZP2Zo@21omOoo@21b?78
o03cb?/0eLSm087of?ol086Z0:[m0?ko083lood0PJX0Z_d0POoGood0PLSab?`0
mLSg0=O8o@21omSoo021ZP2Zo@3iood0PJX0Z_d0POoGood0PLSab?`0mLSg0=O8
o@21omSoo021ZP2Zo@3iood0PJX0Z_d0POoGood0PLSab?`0mLSg0=O8o@21omSo
o021ZP2Zo@3no`20o?om086Z0:[m087oeoom0878lLSl0?K8m@3Hb?d0POoHoo`0
PJX0Z_d0nOom086Z0:[m087oeoom0878lLSl0?K8m@3Hb?d0POoHoo`0PJX0Z_d0
nOom086Z0:[m087oeoom0878lLSl0?K8m@3Hb?d0POoHoo`0PJX0Z_d0o_l0S?co
o@21ZP2Zo@21omOoo@21b?78o03gb?`0oLSl0=W8o@21omSoo021ZP2Zo@3iood0
PJX0Z_d0POoGood0PLSab?`0mlSl0?g8o03Ib?d0POoHoo`0PJX0Z_d0nOom086Z
0:[m087oeoom0878lLSl0?O8o03mb?`0fLSm087of?ol086Z0:[m0?ko07[lood0
PJX0Z_`0POoHood0PLSSb?d0nLSm0=[8o@21omSoo021Z_`0nOom086Z0:[l087o
f?om0878hlSm0?W8o@3Jb?d0POoHoo`0PJ[l0?Woo@21ZP2Zo021omSoo@21b>?8
o@3ib?d0f/Sm087of?ol086Zo03no`23o?om086Z0JZZo@21omSoo@21b>?8oP3g
b?h0f/Sm087of?om086Z0:[l0?Woo@21ZP6ZZ_d0POoHood0PLSSb?h0mlSn0=[8
o@21omSoo@21ZP2Zo03iood0PJX1ZZ[m087of?om0878hlSn0?O8oP3Jb?d0POoH
ood0PJX0Z_`0o_l0Pocoo@21ZP6ZZ_d0POoHoo`0PLSUb?d0mlSm0=c8o021omSo
o@21ZP2Zo03iood0PJX1ZZ[m087of?ol0878iLSm0?O8o@3Lb?`0POoHood0PJX0
Z_`0nOom086Z0JZZo@21omSoo021b>G8o@3gb?d0g<Sl087of?om086Z0:[l0?ko
08?lood0PJX1ZZ[m087oeoom0878iLSn0?G8oP3Lb?d0POoGood0PJX0Z_`0nOom
086Z0JZZo@21omOoo@21b>G8oP3eb?h0g<Sm087oeoom086Z0:[l0?Woo@21ZP6Z
Z_d0POoGood0PLSUb?h0mLSn0=c8o@21omOoo@21ZP2Zo03no`23o?om086Z0JZZ
o@21omOoo@21b>G8oP3eb?h0g<Sm087oeoom086Z0:[l0?Woo@21ZP6ZZ_d0POoG
ood0PLSUb?h0mLSn0=c8o@21omOoo@21ZP2Zo03iood0PJX1ZZ[m087oeoom0878
iLSn0?G8oP3Lb?d0POoGood0PJX0Z_`0o_l0Pocoo@21ZP6ZZ_d0POoGoo`0PLSV
b?h0mLSn0=g8o021omOoo@21ZP2Zo03iood0PJX1ZZ[m087oeool0878i/Sn0?G8
oP3Mb?`0POoGood0PJX0Z_`0nOom086Z0JZZo@21omOoo021b>K8oP3eb?h0gLSl
087oeoom086Z0:[l0?ko08?lood0PJX1ZZ[m087oe_om0878ilSn0??8oP3Nb?d0
POoFood0PJX0Z_`0nOom086Z0JZZo@21omKoo@21b>O8oP3cb?h0g/Sm087oe_om
086Z0:[l0?Woo@21ZP6ZZ_d0POoFood0PLSWb?h0llSn0=k8o@21omKoo@21ZP2Z
o03no`23o?om086Z0JZZo@21omKoo@21b>O8oP3cb?h0g/Sm087oe_om086Z0:[l
0?Woo@21ZP6ZZ_d0POoFood0PLSWb?h0llSn0=k8o@21omKoo@21ZP2Zo03iood0
PJX1ZZ[m087oe_om0878ilSn0??8oP3Nb?d0POoFood0PJX0Z_`0o_l0Pocoo@21
ZP6ZZ_d0POoFoo`0PLSXb?h0llSn0=o8o021omKoo@21ZP2Zo03iood0PJX1ZZ[m
087oe_ol0878j<Sn0??8oP3Ob?`0POoFood0PJX0Z_`0nOom086Z0JZZo@21omKo
o021b>S8oP3cb?h0glSl087oe_om086Z0:[l0?ko08?lood0PJX1ZZ[m087oeOom
0878j<Sn0??8oP3Ob?d0POoEood0PJX0Z_`0nOom086Z0JZZo@21omGoo@21b>S8
oP3cb?h0glSm087oeOom086Z0:[l0?Woo@21ZP6ZZ_d0POoEood0PLSXb?h0llSn
0=o8o@21omGoo@21ZP2Zo03no`20o?ol086Z0:[m087oeOom0878j<Sn0??8oP3O
b?d0POoEood0PJX0Z_`0nOol086Z0:[m087oeOom0878j<Sn0??8oP3Ob?d0POoE
ood0PJX0Z_`0nOol086Z0:[m087oeOom0878j<Sn0??8oP3Ob?d0POoEood0PJX0
Z_`0o_l0P?_oo@21ZP2Zo021omKoo021b>W8oP3cb?h0h<Sl087oe_ol086Z0:[m
0?Ooo@21ZP2Zo021omKoo021b>W8oP3cb?h0h<Sl087oe_ol086Z0:[m0?Ooo@21
ZP2Zo021omKoo021b>W8oP3cb?h0h<Sl087oe_ol086Z0:[m0?go08Kkood0PJX1
ZZ[m087oeOom0878jLSn0??8oP3Pb?d0POoEood0PJX1ZZ[m0?Ooo@21ZP6ZZ_d0
POoEood0PLSYb?h0llSn0>38o@21omGoo@21ZP6ZZ_d0moom086Z0JZZo@21omGo
o@21b>W8oP3cb?h0h<Sm087oeOom086Z0JZZo@3mo`26noom086Z0JZZo@21omGo
o@21b>W8oP3cb?h0h<Sm087oeOom086Z0JZZo@3good0PJX1ZZ[m087oeOom0878
jLSn0??8oP3Pb?d0POoEood0PJX1ZZ[m0?Ooo@21ZP6ZZ_d0POoEood0PLSYb?h0
llSn0>38o@21omGoo@21ZP6ZZ_d0oOl0Po_oo@21ZP6ZZ_d0POoEoo`0PLSZb?h0
llSn0>78o021omGoo@21ZP2Zo03good0PJX1ZZ[m087oeOol0878j/Sn0??8oP3Q
b?`0POoEood0PJX0Z_`0moom086Z0JZZo@21omGoo021b>[8oP3cb?h0hLSl087o
eOom086Z0:[l0?go08?kood0PJX1ZZ[m087oe?om0878j/Sn0??8oP3Qb?d0POoD
ood0PJX0Z_`0moom086Z0JZZo@21omCoo@21b>[8oP3cb?h0hLSm087oe?om086Z
0:[l0?Ooo@21ZP6ZZ_d0POoDood0PLSZb?h0llSn0>78o@21omCoo@21ZP2Zo03m
o`23noom086Z0JZZo@21omCoo@21b>W8oP3eb?h0h<Sm087oe?om086Z0:[l0?Oo
o@21ZP6ZZ_d0POoDood0PLSYb?h0mLSn0>38o@21omCoo@21ZP2Zo03good0PJX1
ZZ[m087oe?om0878jLSn0?G8oP3Pb?d0POoDood0PJX0Z_`0oOl0Po_oo@21ZP6Z
Z_d0POoDoo`0PLSZb?h0mLSn0>78o021omCoo@21ZP2Zo03good0PJX1ZZ[m087o
e?ol0878j/Sn0?G8oP3Qb?`0POoDood0PJX0Z_`0moom086Z0JZZo@21omCoo021
b>[8oP3eb?h0hLSl087oe?om086Z0:[l0?go08?kood0PJX1ZZ[l087oe?om0878
j/Sn0?G8oP3Qb?d0POoDoo`0PJX0Z_`0moom086Z0JZZo021omCoo@21b>[8oP3e
b?h0hLSm087oe?ol086Z0:[l0?Ooo@21ZP6ZZ_`0POoDood0PLSZb?h0mLSn0>78
o@21omCoo021ZP2Zo03mo`23noom086ZoZ[m087oe?om0878j/Sm0?O8o@3Qb?d0
POoDood0PJX1ZZ[l0?Ooo@21Z_jZo@21omCoo@21b>[8o@3gb?d0hLSm087oe?om
086Z0JZZo03good0PJ[nZ_d0POoDood0PLSZb?d0mlSm0>78o@21omCoo@21ZP6Z
Z_`0oOl0Po_oo@21Z_jZo@21omCoo021b>[8oP3gb?h0hLSl087oe?om086Z0JZZ
o03good0PJ[nZ_d0POoDoo`0PLSZb?h0mlSn0>78o021omCoo@21ZP6ZZ_`0moom
086ZoZ[m087oe?ol0878j/Sn0?O8oP3Qb?`0POoDood0PJX1ZZ[l0?go08?kood0
PJ[nZ_d0POoCood0PLSZb?d0nLSm0>78o@21om?oo@21ZP6ZZ_`0moom086ZoZ[m
087odoom0878j/Sm0?W8o@3Qb?d0POoCood0PJX1ZZ[l0?Ooo@21Z_jZo@21om?o
o@21b>[8o@3ib?d0hLSm087odoom086Z0JZZo03mo`23noom086ZoZ[m087odool
0878j/Sl0?g8o03Qb?`0POoCood0PJX1ZZ[l0?Ooo@21Z_jZo@21om?oo021b>[8
o03mb?`0hLSl087odoom086Z0JZZo03good0PJ[nZ_d0POoCoo`0PLSZb?`0oLSl
0>78o021om?oo@21ZP6ZZ_`0oOl0N__oo021ZP6ZZ_d0POoCoo`0PLSYb?D0h<Sl
087odoom086Z0JZZo03goo`0PJX1ZZ[m087odool0878jLSe0>38o021om?oo@21
ZP6ZZ_`0mool086Z0JZZo@21om?oo021b>W8m@3Pb?`0POoCood0PJX1ZZ[l0?go
07Ojood0PJX1ZZ[m087od_ol0878jLSg0>38o021om;oo@21ZP2Zo03eood0PJX1
ZZ[m087od_ol0878jLSg0>38o021om;oo@21ZP2Zo03eood0PJX1ZZ[m087od_ol
0878jLSg0>38o021om;oo@21ZP2Zo03lo`1gn_om086Z0JZZo021om?oo021b>O8
n`3Nb?`0POoCoo`0PJX0Z_`0mOom086Z0JZZo021om?oo021b>O8n`3Nb?`0POoC
oo`0PJX0Z_`0mOom086Z0JZZo021om?oo021b>O8n`3Nb?`0POoCoo`0PJX0Z_`0
o?l0Jo[oo@21Z_jZo@21om;oo021b<38o021om;oo@21ZP6ZZ_`0mOom086ZoZ[m
087od_ol0878`<Sl087od_om086Z0JZZo03eood0PJ[nZ_d0POoBoo`0PLS0b?`0
POoBood0PJX1ZZ[l0?co06_jood0PJ[nZ_d0POoBoo`0PLS0b?`0POoBood0PJX1
ZZ[l0?Goo@21Z_jZo@21om;oo021b<38o021om;oo@21ZP6ZZ_`0mOom086ZoZ[m
087od_ol0878`<Sl087od_om086Z0JZZo03lo`1[n_om086ZoZ[m087odOol0878
`/Sl087odOom086Z0JZZo03eood0PJ[nZ_d0POoAoo`0PLS2b?`0POoAood0PJX1
ZZ[l0?Goo@21Z_jZo@21om7oo021b<;8o021om7oo@21ZP6ZZ_`0o?l0K_[oo021
ZP6ZZ_d0POoAoo`0PLS2b?`0POoAood0PJX1ZZ[l0?Goo021ZP6ZZ_d0POoAoo`0
PLS2b?`0POoAood0PJX1ZZ[l0?Goo021ZP6ZZ_d0POoAoo`0PLS2b?`0POoAood0
PJX1ZZ[l0?co06kiood0PJX1ZZ[m087od?ol0878a<Sl087od?om086Z0JZZo@3c
ood0PJX1ZZ[m087od?ol0878a<Sl087od?om086Z0JZZo@3cood0PJX1ZZ[m087o
d?ol0878a<Sl087od?om086Z0JZZo@3ko`1[nOom086Z0JZZo@21om3on`21b<K8
n`21om3oo@21ZP2Zo03cood0PJX1ZZ[m087od?ok0878a/Sk087od?om086Z0:[l
0??oo@21ZP6ZZ_d0POo@oo/0PLS6b?/0POo@ood0PJX0Z_`0nol0JoWoo@21ZP6Z
Z_`0POo@oo`0PLS6b?`0POo@oo`0PJX0Z_`0loom086Z0JZZo021om3oo021b<K8
o021om3oo021ZP2Zo03cood0PJX1ZZ[l087od?ol0878a/Sl087od?ol086Z0:[l
0?_o06_iood0PJ[nZ_d0POo?oo`0PLS8b?`0POo?ood0PJX1ZZ[l0??oo@21Z_jZ
o@21olooo021b<S8o021olooo@21ZP6ZZ_`0loom086ZoZ[m087ocool0878b<Sl
087ocoom086Z0JZZo03ko`1[nOom086ZoZ[m087ocool0878b<Sl087ocoom086Z
0JZZo03cood0PJ[nZ_d0POo?oo`0PLS8b?`0POo?ood0PJX1ZZ[l0??oo@21Z_jZ
o@21olooo021b<S8o021olooo@21ZP6ZZ_`0nol0K_Woo021ZP6ZZ_d0POo>oo`0
PLS:b?`0POo>ood0PJX1ZZ[l0??oo021ZP6ZZ_d0POo>oo`0PLS:b?`0POo>ood0
PJX1ZZ[l0??oo021ZP6ZZ_d0POo>oo`0PLS:b?`0POo>ood0PJX1ZZ[l0?_o06kh
ood0PJX1ZZ[m087oc_ol0878b/Sl087oc_om086Z0JZZo@3aood0PJX1ZZ[m087o
c_ol0878b/Sl087oc_om086Z0JZZo@3aood0PJX1ZZ[m087oc_ol0878b/Sl087o
c_om086Z0JZZo@3jo`1^n?om086Z0JZZo021olkoo021b<c8o021olkoo021ZP6Z
Z_d0lOom086Z0JZZo021olkoo021b<c8o021olkoo021ZP6ZZ_d0lOom086Z0JZZ
o021olkoo021b<c8o021olkoo021ZP6ZZ_d0n_l0JoSoo@21Z_jZo@21olkoo021
b<c8o021olkoo@21ZP6ZZ_`0lOom086ZoZ[m087oc_ol0878c<Sl087oc_om086Z
0JZZo03aood0PJ[nZ_d0POo>oo`0PLS<b?`0POo>ood0PJX1ZZ[l0?[o06_hood0
PJ[nZ_d0POo=oo`0PLS>b?`0POo=ood0PJX1ZZ[l0?7oo@21Z_jZo@21olgoo021
b<k8o021olgoo@21ZP6ZZ_`0lOom086ZoZ[m087ocOol0878c/Sl087ocOom086Z
0JZZo03jo`1[n?om086ZoZ[m087ocOok0878d<Sk087ocOom086Z0JZZo03aood0
PJ[nZ_d0POo=oo/0PLS@b?/0POo=ood0PJX1ZZ[l0?7oo@21Z_jZo@21olgon`21
b=38n`21olgoo@21ZP6ZZ_`0n_l0K_Soo021ZP6ZZ_`0POo=oo/0PLSBb?/0POo=
oo`0PJX1ZZ[l0?7oo021ZP6ZZ_`0POo=oo/0PLSBb?/0POo=oo`0PJX1ZZ[l0?7o
o021ZP6ZZ_`0POo=oo/0PLSBb?/0POo=oo`0PJX1ZZ[l0?[o06Sgood0PJ[nZ_d0
POo=oo/0PLSBb?`0POo<ood0PJ[nZ_d0koom086ZoZ[m087ocOok0878d/Sl087o
c?om086ZoZ[m0>ooo@21Z_jZo@21olgon`21b=;8o021olcoo@21Z_jZo@3io`1X
moom086ZoZ[m087oc?ok0878e<Sl087oboom086ZoZ[m0>ooo@21Z_jZo@21olco
n`21b=C8o021ol_oo@21Z_jZo@3_ood0PJ[nZ_d0POo<oo/0PLSDb?`0POo;ood0
PJ[nZ_d0nOl0J?Ooo@21Z_jZo@21ol_on`21b=K8o021ol[oo@21Z_jZo@3_ood0
PJ[nZ_d0POo;oo/0PLSFb?`0POo:ood0PJ[nZ_d0koom086ZoZ[m087obook0878
e/Sl087ob_om086ZoZ[m0?Wo06_good0PJ[nZ_`0POo;oo/0PLSHb?/0POo;oo`0
PJX1ZZ[l0>ooo@21Z_jZo021ol_on`21b=S8n`21ol_oo021ZP6ZZ_`0koom086Z
oZ[l087obook0878f<Sk087obool086Z0JZZo03io`1Xmoom086ZoJ[m087ob_ol
0878f<Sl087ob_om086ZoZ[l0>ooo@21Z_fZo@21ol[oo021b=S8o021ol[oo@21
Z_jZo03_ood0PJ[mZ_d0POo:oo`0PLSHb?`0POo:ood0PJ[nZ_`0nOl0J?Ooo021
Z_jZo@21ol[on`21b=[8o021olWoo@21Z_jZo03_oo`0PJ[nZ_d0POo:oo/0PLSJ
b?`0POo9ood0PJ[nZ_`0kool086ZoZ[m087ob_ok0878f/Sl087obOom086ZoZ[l
0?Wo06Sfood0PJ[nZ_d0POo9oo/0PLSLb?`0POo8ood0PJ[nZ_d0kOom086ZoZ[m
087obOok0878g<Sl087ob?om086ZoZ[m0>goo@21Z_jZo@21olWon`21b=c8o021
olSoo@21Z_jZo@3ho`1Xm_om086ZoZ[l087obOok0878g/Sl087ob?ol086ZoZ[m
0>goo@21Z_jZo021olWon`21b=k8o021olSoo021Z_jZo@3]ood0PJ[nZ_`0POo9
oo/0PLSNb?`0POo8oo`0PJ[nZ_d0n?l0J?Koo@21Z_fZo@21olSoo021b=k8o021
olSoo@21Z_fZo@3]ood0PJ[mZ_d0POo8oo`0PLSNb?`0POo8ood0PJ[mZ_d0kOom
086ZoJ[m087ob?ol0878g/Sl087ob?om086ZoJ[m0?So06Sfood0PJ[mZ_d0POo7
oo`0PLSPb?`0POo7ood0PJ[mZ_d0kOom086ZoJ[m087oaool0878h<Sl087oaoom
086ZoJ[m0>goo@21Z_fZo@21olOoo021b>38o021olOoo@21Z_fZo@3ho`1Xm_om
086ZoJ[m087oa_ol0878h/Sl087oa_om086ZoZ[l0>goo@21Z_fZo@21olKoo021
b>;8o021olKoo@21Z_jZo03]ood0PJ[mZ_d0POo6oo`0PLSRb?`0POo6ood0PJ[n
Z_`0n?l0J?Koo021Z_jZo021olKoo021b>C8o021olKoo021Z_jZo03]oo`0PJ[n
Z_`0POo6oo`0PLSTb?`0POo6oo`0PJ[nZ_`0kOol086ZoZ[l087oa_ol0878i<Sl
087oa_ol086ZoZ[l0?So06Seood0PJ[mZ_d0POo5oo`0PLSUb?d0POo5ood0PJ[m
Z_d0joom086ZoJ[m087oaOol0878iLSm087oaOom086ZoJ[m0>_oo@21Z_fZo@21
olGoo021b>G8o@21olGoo@21Z_fZo@3go`1XmOom086ZoJ[m087oaOol0878i/Sm
087oa?om086ZoJ[m0>_oo@21Z_fZo@21olGoo021b>K8o@21olCoo@21Z_fZo@3[
ood0PJ[mZ_d0POo5oo`0PLSVb?d0POo4ood0PJ[mZ_d0mol0J?Goo@21Z_fZo@21
olCon`21b>[8n`21olCoo@21Z_fZo@3[ood0PJ[mZ_d0POo4oo/0PLSZb?/0POo4
ood0PJ[mZ_d0joom086ZoJ[m087oa?ok0878j/Sk087oa?om086ZoJ[m0?Oo06Se
ood0PJ[mZ_`0POo4oo/0PLS/b?/0POo4oo`0PJ[mZ_d0joom086ZoJ[l087oa?ok
0878k<Sk087oa?ol086ZoJ[m0>_oo@21Z_fZo021olCon`21b>c8n`21olCoo021
Z_fZo@3go`1XmOom086Zo:[m087o`ook0878k/Sk087o`oom086Zo:[m0>_oo@21
Z_bZo@21ol?on`21b>k8n`21ol?oo@21Z_bZo@3[ood0PJ[lZ_d0POo3oo/0PLS^
b?/0POo3ood0PJ[lZ_d0mol0J?Coo@21Z_fZo@21ol;onP21b?;8nP21ol;oo@21
Z_fZo03Zood0PJ[mZ_d0POo2ooX0PLSbb?X0POo2ood0PJ[mZ_`0j_om086ZoJ[m
087o`_oj0878l/Sj087o`_om086ZoJ[l0?Oo06Sdood0PJ[mZ_`0POo2ooX0PLSd
b?X0POo1ood0PJ[mZ_d0jOom086ZoJ[l087o`_oj0878m<Sj087o`Oom086ZoJ[m
0>Woo@21Z_fZo021ol;onP21b?C8nP21ol7oo@21Z_fZo@3fo`1Xm?om086Zo:[m
087o`?ok0878m/Sk087o`?ol086ZoJ[m0>Woo@21Z_bZo@21ol3on`21b?K8n`21
ol3oo021Z_fZo@3Yood0PJ[lZ_d0POo0oo/0PLSfb?/0POo0oo`0PJ[mZ_d0m_l0
J?Coo@21Z_bZo@21okoon`21b?S8n`21okooo@21Z_bZo@3Yood0PJ[lZ_d0POno
oo/0PLShb?/0POnoood0PJ[lZ_d0jOom086Zo:[m087o_ook0878n<Sk087o_oom
086Zo:[m0?Ko06Sdoo`0PJ[mZ_d0POnnoo/0PLSjb?/0POnnood0PJ[lZ_d0jOol
086ZoJ[m087o__ok0878n/Sk087o__om086Zo:[m0>Woo021Z_fZo@21okkon`21
b?[8n`21okkoo@21Z_bZo@3fo`1Xloom086ZoJ[l087o__ok0878o<Sk087o__ol
086ZoJ[l0>Soo@21Z_fZo021okkon`21b?c8n`21okkoo021Z_fZo03Xood0PJ[m
Z_`0POnnoo/0PLSlb?/0POnnoo`0PJ[mZ_`0m_l0J??oo@21Z_fZo021okcoo021
b?k8n`21okgoo021Z_fZo@3Wood0PJ[mZ_`0POnloo`0PLSnb?/0POnmoo`0PJ[m
Z_d0ioom086ZoJ[l087o_?ol0878o/Sk087o_Ool086ZoJ[m0?Go06;cood0PJ[l
Z_`0POnloo/0P/Sk087o_?ol086Zo:[m0>Ooo@21Z_bZo021okcon`22b?/0POnl
oo`0PJ[lZ_d0ioom086Zo:[l087o_?ok08;8n`21okcoo021Z_bZo@3eo`1Rlool
086ZoJ[l087o^ook08C8n`21ok_oo021Z_bZo@3Woo`0PJ[mZ_`0POnkoo/0Q<Sk
087o^ool086Zo:[m0>Ooo021Z_fZo021ok_on`24b?/0POnkoo`0PJ[lZ_d0mOl0
H_;oo@21Z_bZo@21ok[on`26b?/0POnjood0PJ[lZ_`0i_om086Zo:[m087o^_ok
08K8n`21ok[oo@21Z_bZo03Vood0PJ[lZ_d0POnjoo/0Q/Sk087o^_om086Zo:[l
0?Go06;bood0PJ[lZ_`0POnjoo/0R<Sk087o^_ol086Zo:[m0>Goo@21Z_bZo021
ok[on`28b?/0POnjoo`0PJ[lZ_d0iOom086Zo:[l087o^_ok08S8n`21ok[oo021
Z_bZo@3do`1Rl_om086Zo:[l087o^?ok08c8n`21okSoo021Z_bZo@3Uood0PJ[l
Z_`0POnhoo/0S<Sk087o^?ol086Zo:[m0>Goo@21Z_bZo021okSon`2<b?/0POnh
oo`0PJ[lZ_d0m?l0H_;oo021Z_bZo@21okOonP2@b?X0POngood0PJ[kZ_d0iOol
086Zo:[m087o]ooj0938nP21okOoo@21Z_^Zo@3Uoo`0PJ[lZ_d0POngooX0T<Sj
087o]oom086Znj[m0?Co06;aood0PJ[lZ_`0POngooT0U<Si087o]ool086Zo:[l
0>Coo@21Z_bZo021okOon@2Db?T0POngoo`0PJ[lZ_`0i?om086Zo:[l087o]ooi
09C8n@21okOoo021Z_bZo03do`1RlOom086Zo:[l087o]Ooi09S8n@21okGoo021
Z_bZo@3Sood0PJ[lZ_`0POneooT0V<Si087o]Ool086Zo:[m0>?oo@21Z_bZo021
okGon@2Hb?T0POneoo`0PJ[lZ_d0lol0H_7oo@21Z_^Zo021okCon@2Kb?T0POne
oo`0PJ[kZ_d0hoom086Znj[l087o]?oi09_8n@21okGoo021Z_^Zo@3Sood0PJ[k
Z_`0POndooT0VlSi087o]Ool086Znj[m0??o06;aoo`0PJ[lZ_`0POncooT0W/Si
087o/ool086Znj[m0>?oo021Z_bZo021ok?on@2Nb?T0POncoo`0PJ[kZ_d0hool
086Zo:[l087o/ooi09k8n@21ok?oo021Z_^Zo@3co`1Rl?om086Znj[m087o/Ooi
0:;8n@21ok7oo@21Z_^Zo03Rood0PJ[kZ_d0POnaooT0X/Si087o/Oom086Znj[l
0>;oo@21Z_^Zo@21ok7on@2Rb?T0POnaood0PJ[kZ_`0lol0H_3oo@21Z_^Zo021
ok3on@2Vb?T0POn`oo`0PJ[kZ_d0hOom086Znj[l087o/?oi0:K8n@21ok3oo021
Z_^Zo@3Qood0PJ[kZ_`0POn`ooT0Y/Si087o/?ol086Znj[m0?;o06;`ood0PJ[k
Z_`0POn_ooP0Z/Sh087o[ool086Znj[m0>7oo@21Z_^Zo021ojoon02Zb?P0POn_
oo`0PJ[kZ_d0hOom086Znj[l087o[ooh0:[8n021ojooo021Z_^Zo@3bo`1Rl?ol
086Znj[l087o[_oh0:k8n021ojkoo021Z_ZZo@3Qoo`0PJ[kZ_`0POn^ooP0[/Sh
087o[_ol086ZnZ[m0>7oo021Z_^Zo021ojkon02^b?P0POn^oo`0PJ[jZ_d0l_l0
H^ooo@21Z_^Zo021ojcom`2cb?P0POn/oo`0PJ[kZ_`0h?om086Znj[l087o[?og
0;?8n021ojcoo021Z_^Zo03Pood0PJ[kZ_`0POn/ooL0/lSh087o[?ol086Znj[l
0?;o06;_ood0PJ[jZ_d0POnZooH0^/Sf087oZ_om086ZnZ[m0=ooo@21Z_ZZo@21
oj[omP2jb?H0POnZood0PJ[jZ_d0goom086ZnZ[m087oZ_of0;[8mP21oj[oo@21
Z_ZZo@3ao`1Rkoom086ZnZ[l087oZ_oc0<78m021oj[oo021Z_ZZo@3Oood0PJ[j
Z_`0POnZoo<0`LSd087oZ_ol086ZnZ[m0=ooo@21Z_ZZo021oj[ol`31b?@0POnZ
oo`0PJ[jZ_d0lOl0H^ooo021Z_^Zo021ojSolP38b?80POnXoo`0PJ[jZ_d0gool
086Znj[l087oZ?ob0<S8lP21ojSoo021Z_ZZo@3Ooo`0PJ[kZ_`0POnXoo80b<Sb
087oZ?ol086ZnZ[m0?7o06;^ood0PJ[jZ_d0POnToo80clSb087oYOom086ZnZ[l
0=koo@21Z_ZZo@21ojColP3?b?80POnUood0PJ[jZ_`0g_om086ZnZ[m087oY?ob
0<o8lP21ojGoo@21Z_ZZo03ao`1Rk_om086ZnZ[l087oX_ob0=K8lP21oj;oo021
Z_ZZo@3Mood0PJ[jZ_`0POnRoo80e/Sb087oX_ol086ZnZ[m0=goo@21Z_ZZo021
oj;olP3Fb?80POnRoo`0PJ[jZ_d0l?l0H^koo@21Z_ZZo021oikokP3Ub>h0POnO
oo`0PJ[jZ_d0gOom086ZnZ[l087oW_o^0>G8kP21oiooo021Z_ZZo@3Mood0PJ[j
Z_`0POnNonh0iLS^087oWool086ZnZ[m0?3o06;^oo`0PJ[jZ_`0POnLonX0m<SZ
087oW?ol086ZnJ[m0=goo021Z_ZZo021oicojP3db>X0POnLoo`0PJ[iZ_d0gOol
086ZnZ[l087oW?oZ0?C8jP21oicoo021Z_VZo@3`o`1FkOom086ZnZ[l087oV?o=
087oVOol086ZnZ[l0=coo@21Z_ZZo021oiSoc@21oiWoo021Z_ZZo03Lood0PJ[j
Z_`0POnHold0POnIoo`0PJ[jZ_`0l?l0E^goo@21Z_VZo021oiKoe021oiGoo@21
Z_VZo@3Kood0PJ[iZ_`0POnFom@0POnEood0PJ[iZ_d0foom086ZnJ[l087oU_oD
087oUOom086ZnJ[m0>oo05K]ood0PJ[iZ_`0POn>on<0POn?oo`0PJ[iZ_d0foom
086ZnJ[l087oS_oS087oSool086ZnJ[m0=_oo@21Z_VZo021ohkoh`21ohooo021
Z_VZo@3_o`1FkOol086ZnJ[m087oQoob087oQool086ZnJ[m0=_oo021Z_VZo@21
ohOolP21ohOoo021Z_VZo@3Koo`0PJ[iZ_d0POn7oo80POn7oo`0PJ[iZ_d0kol0
E^coo@21Z_VZo021oh7oPOn1o`3oo021Z_VZo03Jood0PJ[iZ_`0POn1oh7oPOl0
oo`0PJ[iZ_`0f_om086ZnJ[l087oPOn1oh7o0?ol086ZnJ[l0>oo05K/ood0PJ[i
Z_`0POn1oh7oPOl0oo`0PJ[iZ_d0fOom086ZnJ[l087oPOn1oh7o0?ol086ZnJ[m
0=Woo@21Z_VZo021oh7oPOn1o`3oo021Z_VZo@3^o`1@k?om086Zn:[l087oPOn1
oh;oo021Z_RZo@3Iood0PJ[hZ_`0POn1oh7oP_ol086Zn:[m0=Woo@21Z_RZo021
oh7oPOn2oo`0PJ[hZ_d0k_l0D>coo021Z_VZo021oh7oPOn2oo`0PJ[hZ_d0fOol
086ZnJ[l087oPOn1oh;oo021Z_RZo@3Ioo`0PJ[iZ_`0POn1oh7oP_ol086Zn:[m
0>ko053[ood0PJ[hZ_`0POn1oh7oQ?ol086Zn:[l0=Soo@21Z_RZo021oh7oPOn4
oo`0PJ[hZ_`0f?om086Zn:[l087oPOn1ohCoo021Z_RZo03^o`1@joom086Zn:[l
087oPOn1ohCoo021Z_RZo@3Good0PJ[hZ_`0POn1oh7oQ?ol086Zn:[m0=Ooo@21
Z_RZo021oh7oPOn4oo`0PJ[hZ_d0kOl0D>_oo@21Z_NZo021oh7oPOn6oo`0PJ[g
Z_d0eoom086Zmj[l087oPOn1ohKoo021Z_NZo@3Good0PJ[gZ_`0POn1oh7oQ_ol
086Zmj[m0>go053[oo`0PJ[hZ_`0POn1oh7oQ_ol086Zmj[m0=Ooo021Z_RZo021
oh7oPOn6oo`0PJ[gZ_d0eool086Zn:[l087oPOn1ohKoo021Z_NZo@3]o`1@j_om
086Zmj[l087oPOn1ohSoo021Z_NZo03Food0PJ[gZ_`0POn1oh7oR?ol086Zmj[l
0=Koo@21Z_NZo021oh7oPOn8oo`0PJ[gZ_`0kOl0D>[oo@21Z_NZo021oh7oPOn8
oo`0PJ[gZ_d0eOom086Zmj[l087oPOn1ohSoo021Z_NZo@3Eood0PJ[gZ_`0POn1
oh7oR?ol086Zmj[m0>co053Zood0PJ[fZ_`0POn1oh7oR_ol086ZmZ[m0=Goo@21
Z_JZo021oh7oPOn:oo`0PJ[fZ_d0eOom086ZmZ[l087oPOn1oh[oo021Z_JZo@3/
o`1@j_ol086Zmj[l087oPOn1oh[oo021Z_NZo03Eoo`0PJ[gZ_`0POn1oh7oR_ol
086Zmj[l0=Goo021Z_NZo021oh7oPOn:oo`0PJ[gZ_`0k?l0D>Woo@21Z_JZo021
oh7oPOn<oo`0PJ[fZ_d0doom086ZmZ[l087oPOn1ohcoo021Z_JZo@3Cood0PJ[f
Z_`0POn1oh7oS?ol086ZmZ[m0>_o053Yood0PJ[fZ_`0POn1oh7oS?ol086ZmZ[m
0=?oo@21Z_JZo021oh7oPOn<oo`0PJ[fZ_d0doom086ZmZ[l087oPOn1ohcoo021
Z_JZo@3[o`1@jOol086ZmZ[l087oPOn1ohkoo021Z_JZo03Coo`0PJ[fZ_`0POn1
oh7oS_ol086ZmZ[l0=?oo021Z_JZo021oh7oPOn>oo`0PJ[fZ_`0jol0D>Soo@21
Z_JZo021oh7oPOn>oo`0PJ[fZ_d0dOom086ZmZ[l087oPOn1ohkoo021Z_JZo@3A
ood0PJ[fZ_`0POn1oh7oS_ol086ZmZ[m0>[o053Xoo`0PJ[fZ_`0POn1oh7oT?ol
086ZmZ[l0=7oo021Z_JZo021oh7oPOn@oo`0PJ[fZ_`0dOol086ZmZ[l087oPOn1
oi3oo021Z_JZo03Zo`1@ioom086ZmZ[l087oPOn1oi3oo021Z_JZo@3?ood0PJ[f
Z_`0POn1oh7oT?ol086ZmZ[m0<ooo@21Z_JZo021oh7oPOn@oo`0PJ[fZ_d0jOl0
D>Ooo@21Z_FZo021oh7oPOnBoo`0PJ[eZ_d0coom086ZmJ[l087oPOn1oi;oo021
Z_FZo@3?ood0PJ[eZ_`0POn1oh7oT_ol086ZmJ[m0>Wo053Woo`0PJ[fZ_`0POn1
oh7oT_ol086ZmZ[l0<ooo021Z_JZo021oh7oPOnBoo`0PJ[fZ_`0cool086ZmZ[l
087oPOn1oi;oo021Z_JZo03Yo`1@i_om086ZmJ[l087oPOn1oiCoo021Z_FZo@3=
ood0PJ[eZ_`0POn1oh7oU?ol086ZmJ[m0<goo@21Z_FZo021oh7oPOnDoo`0PJ[e
Z_d0j?l0D>Koo@21Z_FZo021oh7oPOnDoo`0PJ[eZ_d0cOom086ZmJ[l087oPOn1
oiCoo021Z_FZo@3=ood0PJ[eZ_`0POn1oh7oU?ol086ZmJ[m0>So053Voo`0PJ[e
Z_d0POn1oh7oUOol086ZmJ[l0<goo021Z_FZo@21oh7oPOnEoo`0PJ[eZ_`0cOol
086ZmJ[m087oPOn1oiGoo021Z_FZo03Xo`1@iOom086ZmJ[m087oPOn1oiGoo021
Z_FZo@3;ood0PJ[eZ_d0POn1oh7oUOol086ZmJ[m0<_oo@21Z_FZo@21oh7oPOnE
oo`0PJ[eZ_d0iol0D>Goo021Z_FZo@21oh7oPOnGoo`0PJ[eZ_`0bool086ZmJ[m
087oPOn1oiOoo021Z_FZo03;oo`0PJ[eZ_d0POn1oh7oUool086ZmJ[l0>Oo053U
oo`0PJ[eZ_`0POn1oh7oV?ol086ZmJ[l0<_oo021Z_FZo021oh7oPOnHoo`0PJ[e
Z_`0bool086ZmJ[l087oPOn1oiSoo021Z_FZo03Wo`1@i?om086Zm:[m087oPOn1
oiWoo021Z_BZo@39ood0PJ[dZ_d0POn1oh7oVOol086Zm:[m0<Woo@21Z_BZo@21
oh7oPOnIoo`0PJ[dZ_d0i_l0D>Coo021Z_FZo021oh7oPOnKoo/0PJ[eZ_`0bOol
086ZmJ[l087oPOn1oi_on`21Z_FZo039oo`0PJ[eZ_`0POn1oh7oVook086ZmJ[l
0>Ko053Too`0PJ[dZ_`0POn1oh7oW?ol086Zm:[l0<Woo021Z_BZo021oh7oPOnL
oo`0PJ[dZ_`0bOol086Zm:[l087oPOn1oicoo021Z_BZo03Vo`1@hoom086Zlj[m
087oPOn1oigoo021Z_>Zo@37ood0PJ[cZ_d0POn1oh7oWOol086Zlj[m0<Ooo@21
Z_>Zo@21oh7oPOnMoo`0PJ[cZ_d0iOl0D>?oo021Z_BZo021oh7oPOnNoo`0PJ[d
Z_`0aool086Zm:[l087oPOn1oikoo021Z_BZo037oo`0PJ[dZ_`0POn1oh7oW_ol
086Zm:[l0>Go053Rood0PJ[cZ_`0POn1oh7oX?ol086Zlj[m0<Goo@21Z_>Zo021
oh7oPOnPoo`0PJ[cZ_d0aOom086Zlj[l087oPOn1oj3oo021Z_>Zo@3To`1@h_om
086ZlZ[m087oPOn1oj7on`21Z_>Zo@35ood0PJ[bZ_d0POn1oh7oXOok086Zlj[m
0<Goo@21Z_:Zo@21oh7oPOnQoo/0PJ[cZ_d0i?l0D>;oo021Z_>Zo021oh7oPOnR
oo`0PJ[cZ_`0aOol086Zlj[l087oPOn1oj;oo021Z_>Zo035oo`0PJ[cZ_`0POn1
oh7oX_ol086Zlj[l0>Co053Qood0PJ[bZ_`0POn1oh7oY?ol086ZlZ[m0<?oo@21
Z_:Zo021oh7oPOnToo`0PJ[bZ_d0`oom086ZlZ[l087oPOn1ojCoo021Z_:Zo@3S
o`1@hOol086Zlj[l087oPOn1ojGon`21Z_>Zo033oo`0PJ[cZ_`0POn1oh7oYOok
086Zlj[l0<?oo021Z_>Zo021oh7oPOnUoo/0PJ[cZ_`0hol0D>7oo021Z_:Zo021
oh7oPOnVoo`0PJ[bZ_`0`ool086ZlZ[l087oPOn1ojKoo021Z_:Zo033oo`0PJ[b
Z_`0POn1oh7oY_ol086ZlZ[l0>?o053Pood0PJ[aZ_d0POn1oh7oYool086ZlJ[m
0<7oo@21Z_6Zo@21oh7oPOnWoo`0PJ[aZ_d0`Oom086ZlJ[m087oPOn1ojOoo021
Z_6Zo@3Ro`1@h?ol086ZlZ[l087oPOn1ojSoo021Z_:Zo031oo`0PJ[bZ_`0POn1
oh7oZ?ol086ZlZ[l0<7oo021Z_:Zo021oh7oPOnXoo`0PJ[bZ_`0h_l0D>3oo021
Z_6Zo021oh7oPOnZoo`0PJ[aZ_`0`Ool086ZlJ[l087oPOn1oj[oo021Z_6Zo031
oo`0PJ[aZ_`0POn1oh7oZ_ol086ZlJ[l0>;o053Oood0PJ[aZ_`0POn1oh7oZook
086ZlJ[m0;ooo@21Z_6Zo021oh7oPOn[oo/0PJ[aZ_d0_oom086ZlJ[l087oPOn1
oj_on`21Z_6Zo@3Qo`1@gool086ZlJ[l087oPOn1ojcoo021Z_6Zo02ooo`0PJ[a
Z_`0POn1oh7o[?ol086ZlJ[l0;ooo021Z_6Zo021oh7oPOn/oo`0PJ[aZ_`0hOl0
D=koo@21Z_2Zo021oh7oPOn^oo`0PJ[`Z_`0__om086Zl:[l087oPOn1ojkoo021
Z_2Zo02nood0PJ[`Z_`0POn1oh7o[_ol086Zl:[l0>7o053Noo`0PJ[aZ_`0POn1
oh7o[_ol086ZlJ[l0;goo021Z_6Zo021oh7oPOn^oo`0PJ[aZ_`0_Ool086ZlJ[l
087oPOn1ojkoo021Z_6Zo03Po`1@g_ol086Zl:[l087oPOn1ok3oo021Z_2Zo02m
oo`0PJ[`Z_`0POn1oh7o/?ol086Zl:[l0;goo021Z_2Zo021oh7oPOn`oo`0PJ[`
Z_`0h?l0D=goo@21Z_2Zn`21oh7oPOnboo/0PJ[`Z_d0^oom086Zl:[k087oPOn1
ok;on`21Z_2Zo@2kood0PJ[`Z_/0POn1oh7o/_ok086Zl:[m0=oo053Moo`0PJ[`
Z_`0POn1oh7o/_ol086Zl:[l0;_oo021Z_2Zo021oh7oPOnboo`0PJ[`Z_`0^ool
086Zl:[l087oPOn1ok;oo021Z_2Zo03Oo`1@gOol086Zl:[k087oPOn1okCon`21
Z_2Zo02koo`0PJ[`Z_/0POn1oh7o]?ok086Zl:[l0;_oo021Z_2Zn`21oh7oPOnd
oo/0PJ[`Z_`0gol0D=coo021Z_2Zn`21oh7oPOnfoo/0PJ[_Z_d0^Ool086Zl:[k
087oPOn1okKon`21Z^nZo@2ioo`0PJ[`Z_/0POn1oh7o]_ok086Zkj[m0=ko053L
oo`0PJ[_Z_/0POn1oh7o^?ok086Zkj[l0;Woo021Z^nZn`21oh7oPOnhoo/0PJ[_
Z_`0^Ool086Zkj[k087oPOn1okSon`21Z^nZo03No`1@fool086Zl:[k087oPOn1
okSon`21Z^nZo02hoo`0PJ[`Z_/0POn1oh7o^?ok086Zkj[l0;Soo021Z_2Zn`21
oh7oPOnhoo/0PJ[_Z_`0g_l0D=_oo021Z^nZn`21oh7oPOnjoo/0PJ[_Z_`0]ool
086Zkj[k087oPOn1ok[on`21Z^nZo02goo`0PJ[_Z_/0POn1oh7o^_ok086Zkj[l
0=go053Joo`0PJ[_Z_/0POn1oh7o_?ok086ZkZ[l0;Koo021Z^nZn`21oh7oPOnl
oo/0PJ[^Z_`0]_ol086Zkj[k087oPOn1okcon`21Z^jZo03Mo`1@f_ol086ZkZ[k
087oPOn1okkon`21Z^jZo02eoo`0PJ[^Z_/0POn1oh7o__ok086ZkZ[l0;Goo021
Z^jZn`21oh7oPOnnoo/0PJ[^Z_`0g?l0D=Woo021Z^nZn`21oh7oPOnnoo/0PJ[^
Z_`0]?ol086Zkj[k087oPOn1okkon`21Z^jZo02doo`0PJ[_Z_/0POn1oh7o__ok
086ZkZ[l0=co053Ioo`0PJ[^Z_/0POn1oh7o`?ok086ZkZ[l0;?oo021Z^jZn`21
oh7oPOo0oo/0PJ[^Z_`0/ool086ZkZ[k087oPOn1ol3on`21Z^jZo03Ko`1@f?ol
086ZkZ[k087oPOn1ol;on`21Z^fZo02boo`0PJ[^Z_/0POn1oh7o`_ok086ZkJ[l
0;;oo021Z^jZn`21oh7oPOo2oo/0PJ[]Z_`0fol0D=Soo021Z^fZo021oh7oPOo2
oo`0PJ[]Z_`0/Ool086ZkJ[l087oPOn1ol;oo021Z^fZo02aoo`0PJ[]Z_`0POn1
oh7o`_ol086ZkJ[l0=[o053Goo`0PJ[]Z_`0POn1oh7oa?ok086ZkJ[l0;3oo021
Z^fZo021oh7oPOo4oo/0PJ[]Z_`0/?ol086ZkJ[l087oPOn1olCon`21Z^fZo03J
o`1@eool086ZkJ[k087oPOn1olKon`21Z^fZo02_oo`0PJ[]Z_/0POn1oh7oa_ok
086ZkJ[l0:ooo021Z^fZn`21oh7oPOo6oo/0PJ[]Z_`0fOl0D=Koo021Z^fZn`21
oh7oPOo8oo/0PJ[/Z_`0[_ol086ZkJ[k087oPOn1olSon`21Z^bZo02^oo`0PJ[]
Z_/0POn1oh7ob?ok086Zk:[l0=Wo053Foo`0PJ[/Z_`0POn1oh7ob?ol086Zk:[l
0:goo021Z^bZo021oh7oPOo8oo`0PJ[/Z_`0[Ool086Zk:[l087oPOn1olSoo021
Z^bZo03Ho`1@eOol086Zk:[l087oPOn1ol[oo021Z^^Zo02/oo`0PJ[/Z_`0POn1
oh7ob_ol086Zjj[l0:coo021Z^bZo021oh7oPOo:oo`0PJ[[Z_`0f?l0D=Goo021
Z^bZn`21oh7oPOo<oo/0PJ[/Z_`0Zool086Zk:[k087oPOn1olcon`21Z^bZo02[
oo`0PJ[/Z_/0POn1oh7oc?ok086Zk:[l0=Oo053Doo`0PJ[/Z_/0POn1oh7oc_ok
086Zjj[l0:[oo021Z^bZn`21oh7oPOo>oo/0PJ[[Z_`0Z_ol086Zk:[k087oPOn1
olkon`21Z^^Zo03Go`1@e?ol086Zjj[l087oPOn1olkoo021Z^^Zo02Yoo`0PJ[[
Z_`0POn1oh7oc_ol086Zjj[l0:Woo021Z^^Zo021oh7oPOo>oo`0PJ[[Z_`0e_l0
D=?oo021Z^^Zo021oh7oPOo@oo`0PJ[ZZ_`0Z?ol086Zjj[l087oPOn1om3oo021
Z^ZZo02Xoo`0PJ[[Z_`0POn1oh7od?ol086ZjZ[l0=Ko053Coo`0PJ[[Z_/0POn1
oh7od_ok086Zjj[l0:Ooo021Z^^Zn`21oh7oPOoBoo/0PJ[[Z_`0Yool086Zjj[k
087oPOn1om;on`21Z^^Zo03Eo`1@d_ol086Zjj[k087oPOn1omCon`21Z^ZZo02V
oo`0PJ[[Z_/0POn1oh7oe?ok086ZjZ[l0:Koo021Z^^Zn`21oh7oPOoDoo/0PJ[Z
Z_`0eOl0D=;oo021Z^ZZn`21oh7oPOoFoo/0PJ[ZZ_`0YOol086ZjZ[k087oPOn1
omKon`21Z^ZZo02Uoo`0PJ[ZZ_/0POn1oh7oe_ok086ZjZ[l0=Co053Aoo`0PJ[Z
Z_/0POn1oh7of?ok086ZjJ[l0:Coo021Z^ZZn`21oh7oPOoHoo/0PJ[YZ_`0Y?ol
086ZjZ[k087oPOn1omSon`21Z^VZo03Do`1@dOol086ZjJ[k087oPOn1omWoo021
Z^VZo02Soo`0PJ[YZ_/0POn1oh7ofOol086ZjJ[l0:?oo021Z^VZn`21oh7oPOoI
oo`0PJ[YZ_`0dol0D=3oo021Z^VZo021oh7oPOoJoo`0PJ[XZ_`0X_ol086ZjJ[l
087oPOn1om[oo021Z^RZo02Roo`0PJ[YZ_`0POn1oh7of_ol086Zj:[l0=?o053@
oo`0PJ[XZ_`0POn1oh7og?ol086Zj:[l0:7oo021Z^RZo021oh7oPOoLoo`0PJ[X
Z_`0XOol086Zj:[l087oPOn1omcoo021Z^RZo03Bo`1@cool086Zj:[l087oPOn1
omkon`21Z^RZo02Poo`0PJ[XZ_`0POn1oh7og_ok086Zj:[l0:3oo021Z^RZo021
oh7oPOoNoo/0PJ[XZ_`0d_l0D<ooo021Z^RZn`21oh7oPOoPoo/0PJ[XZ_`0Wool
086Zj:[k087oPOn1on3on`21Z^RZo02Ooo`0PJ[XZ_/0POn1oh7oh?ok086Zj:[l
0=7o053>oo`0PJ[XZ_/0POn1oh7oh_ok086Zij[l09koo021Z^RZn`21oh7oPOoR
oo/0PJ[WZ_`0W_ol086Zj:[k087oPOn1on;on`21Z^NZo03Ao`1@c_ol086Zij[k
087oPOn1onCon`21Z^NZo02Moo`0PJ[WZ_/0POn1oh7oi?ok086Zij[l09goo021
Z^NZn`21oh7oPOoToo/0PJ[WZ_`0d?l0D<goo021Z^NZn`21oh7oPOoVoo/0PJ[V
Z_`0W?ol086Zij[k087oPOn1onKon`21Z^JZo02Loo`0PJ[WZ_/0POn1oh7oi_ok
086ZiZ[l0=3o053=oo`0PJ[VZ_/0POn1oh7oj?ok086ZiZ[l09_oo021Z^JZn`21
oh7oPOoXoo/0PJ[VZ_`0Vool086ZiZ[k087oPOn1onSon`21Z^JZo03?o`1@c?ol
086ZiZ[k087oPOn1on[on`21Z^FZo02Joo`0PJ[VZ_/0POn1oh7oj_ok086ZiJ[l
09[oo021Z^JZn`21oh7oPOoZoo/0PJ[UZ_`0col0D<coo021Z^FZn`21oh7oPOo[
oo`0PJ[UZ_`0VOol086ZiJ[k087oPOn1on_oo021Z^FZo02Ioo`0PJ[UZ_/0POn1
oh7ojool086ZiJ[l0<ko053;oo`0PJ[UZ_`0POn1oh7ok?ol086Zi:[l09Soo021
Z^FZo021oh7oPOo/oo`0PJ[TZ_`0V?ol086ZiJ[l087oPOn1oncoo021Z^BZo03>
o`1@bool086Zi:[l087oPOn1onkoo021Z^BZo02Goo`0PJ[TZ_`0POn1oh7ok_ol
086Zi:[l09Ooo021Z^BZo021oh7oPOo^oo`0PJ[TZ_`0cOl0D<[oo021Z^BZo021
oh7oPOo`oo/0PJ[UZ_/0U_ol086Zi:[l087oPOn1oo3on`21Z^FZn`2Foo`0PJ[T
Z_`0POn1oh7ol?ok086ZiJ[k0<go053:oo`0PJ[TZ_/0POn1oh7ol_ok086Zi:[l
09Goo021Z^BZn`21oh7oPOoboo/0PJ[TZ_`0UOol086Zi:[k087oPOn1oo;on`21
Z^BZo03<o`1@bOol086Zi:[k087oPOn1ooCon`21Z^BZo02Coo`0PJ[TZ_/0POn1
oh7om?ok086Zi:[l09?oo021Z^BZn`21oh7oPOodoo/0PJ[TZ_`0bol0D<Woo021
Z^>Zn`21oh7oPOofoo/0PJ[SZ_`0Tool086Zhj[k087oPOn1ooKon`21Z^>Zo02C
oo`0PJ[SZ_/0POn1oh7om_ok086Zhj[l0<_o0538oo`0PJ[SZ_/0POn1oh7on?ok
086Zhj[l097oo021Z^>Zn`21oh7oPOohoo/0PJ[SZ_`0TOol086Zhj[k087oPOn1
ooSon`21Z^>Zo03:o`1@b?ok086Zhj[k087oPOn1oo[on`21Z^>Zn`2Aoo/0PJ[S
Z_/0POn1oh7on_ok086Zhj[k097on`21Z^>Zn`21oh7oPOojoo/0PJ[SZ_/0b_l0
D<Ooo021Z^:Zn`21oh7oPOoloo/0PJ[RZ_`0Sool086ZhZ[k087oPOn1oocon`21
Z^:Zo02?oo`0PJ[RZ_/0POn1oh7oo?ok086ZhZ[l0<Wo0536oo`0PJ[RZ_/0POn1
oh7oo_ok086ZhZ[l08goo021Z^:Zn`21oh7oPOonoo/0PJ[RZ_`0SOol086ZhZ[k
087oPOn1ookon`21Z^:Zo038o`1@a_ok086ZhZ[k087oPOn1o`3on`21Z^:Zn`2=
oo/0PJ[RZ_/0POn1oh7o0?ok086ZhZ[k08gon`21Z^:Zn`21oh7oPOl0oo/0PJ[R
Z_/0b?l0B/Goo021Z^6Zn`21oh7oP_ok086ZhJ[l08_oo021Z^6Zn`21oh7oP_ok
086ZhJ[l08_oo021Z^6Zn`21oh7oP_ok086ZhJ[l0<Oo04[5oo/0PJ[QZ_/0POn1
ohCoo021Z^2Zn`2;oo/0PJ[QZ_/0POn1ohCoo021Z^2Zn`2;oo/0PJ[QZ_/0POn1
ohCoo021Z^2Zn`37o`1:a?ol086Zh:[j087oPOn7oo`0PJ[OZ_`0ROol086Zh:[j
087oPOn7oo`0PJ[OZ_`0ROol086Zh:[j087oPOn7oo`0PJ[OZ_`0a_l0B/?oo021
Z^2ZnP21oh7oR_ok086Zgj[l08Ooo021Z^2ZnP21oh7oR_ok086Zgj[l08Ooo021
Z^2ZnP21oh7oR_ok086Zgj[l0<Go04[3oo/0PJ[PZ_X0POn1ohcon`21Z]nZn`27
oo/0PJ[PZ_X0POn1ohcon`21Z]nZn`27oo/0PJ[PZ_X0POn1ohcon`21Z]nZn`35
o`1:`_ol086ZgZ[k087oPOn>oo/0PJ[NZ_`0QOol086ZgZ[k087oPOn>oo/0PJ[N
Z_`0QOol086ZgZ[k087oPOn>oo/0PJ[NZ_`0a?l0B/;on`21Z]jZn`21oh7oT?ok
086ZgZ[k08Gon`21Z]jZn`21oh7oT?ok086ZgZ[k08Gon`21Z]jZn`21oh7oT?ok
086ZgZ[k0<Co04[1oo/0PJ[NZ_/0POn1oi;on`21Z]fZo023oo/0PJ[NZ_/0POn1
oi;on`21Z]fZo023oo/0PJ[NZ_/0POn1oi;on`21Z]fZo033o`1:`?ol086ZgJ[k
087oPOnDoo/0PJ[MZ_`0POol086ZgJ[k087oPOnDoo/0PJ[MZ_`0POol086ZgJ[k
087oPOnDoo/0PJ[MZ_`0`_l0B/3on`21Z]fZn`21oh7oU_ok086ZgJ[k087on`21
Z]fZn`21oh7oU_ok086ZgJ[k087on`21Z]fZn`21oh7oU_ok086ZgJ[k0<;o052o
oo`0PJ[LZ_/0POn1oiSon`21Z]bZo021o`7ooo`0PJ[LZ_/0POn1oiSon`21Z]bZ
o021o`7ooo`0PJ[LZ_/0POn1oiSon`21Z]bZo031o`1@_ook086Zg:[k087oPOnJ
oo`0PJ[KZ_/0POl1oook086Zg:[k087oPOnJoo`0PJ[KZ_/0POl1oook086Zg:[k
087oPOnJoo`0PJ[KZ_/0`Ol0C[kon`21Z]bZnP21oh7oW_ok086Zfj[k087ooOok
086Zg:[j087oPOnNoo/0PJ[KZ_/0POomoo/0PJ[LZ_X0POn1oikon`21Z]^Zn`30
o`1>_Ool086Zfj[i087oPOnRooX0PJ[JZ_`0POokoo`0PJ[KZ_T0POn1oj;onP21
Z]ZZo021oo_oo021Z]^Zn@21oh7oX_oj086ZfZ[l0;oo04jmoo/0PJ[KZ_T0POn1
ojConP21Z]ZZn`21oo_on`21Z]^Zn@21oh7oY?oj086ZfZ[k087onook086Zfj[i
087oPOnTooX0PJ[JZ_/0_ol0C[coo021Z]VZnP21oh7oY_oj086ZfJ[l087onOol
086ZfJ[j087oPOnVooX0PJ[IZ_`0POoioo`0PJ[IZ_X0POn1ojKonP21Z]VZo02n
o`1>_?ok086ZfJ[i087oPOnYooX0PJ[IZ_/0POoioo/0PJ[IZ_T0POn1ojWonP21
Z]VZn`21ooWon`21Z]VZn@21oh7oZOoj086ZfJ[k0;ko04jkoo/0PJ[HZ_X0POn1
ojconP21Z]RZn`21ooOon`21Z]RZnP21oh7o[?oj086Zf:[k087omook086Zf:[j
087oPOn/ooX0PJ[HZ_/0_Ol0C[[oo021Z]NZnP21oh7o[_oj086Zej[l087omOol
086Zej[j087oPOn^ooX0PJ[GZ_`0POoeoo`0PJ[GZ_X0POn1ojkonP21Z]NZo02l
o`1>^_ok086Zej[j087oPOn`ooX0PJ[GZ_/0POoeoo/0PJ[GZ_X0POn1ok3onP21
Z]NZn`21ooGon`21Z]NZnP21oh7o/?oj086Zej[k0;co04jioo/0PJ[FZ_X0POn1
okConP21Z]JZn`21oo?on`21Z]JZnP21oh7o]?oj086ZeZ[k087olook086ZeZ[j
087oPOndooX0PJ[FZ_/0^ol0C[Won`21Z]FZnP21oh7o]_oj086ZeJ[k087olook
086ZeJ[j087oPOnfooX0PJ[EZ_/0POocoo/0PJ[EZ_X0POn1okKonP21Z]FZn`2k
o`1>^?ok086ZeJ[j087oPOnhooX0PJ[EZ_/0POoaoo/0PJ[EZ_X0POn1okSonP21
Z]FZn`21oo7on`21Z]FZnP21oh7o^?oj086ZeJ[k0;[o04jgoo`0PJ[CZ_X0POn1
okcon@21Z]BZo021onooo021Z]>ZnP21oh7o_?oi086Ze:[l087okool086Zdj[j
087oPOnlooT0PJ[DZ_`0^Ol0C[Oon`21Z]>ZnP21oh7o__oj086Zdj[k087okook
086Zdj[j087oPOnnooX0PJ[CZ_/0POo_oo/0PJ[CZ_X0POn1okkonP21Z]>Zn`2i
o`1>]_ol086ZdZ[j087oPOo0ooX0PJ[CZ_/0POo]oo`0PJ[BZ_X0POn1ol3onP21
Z]>Zn`21ongoo021Z]:ZnP21oh7o`?oj086Zdj[k0;So04jfoo/0PJ[BZ_X0POn1
ol;onP21Z]:Zn`21ongon`21Z]:ZnP21oh7o`_oj086ZdZ[k087okOok086ZdZ[j
087oPOo2ooX0PJ[BZ_/0^?l0C[Goo021Z]2ZnP21oh7oa_oj086ZdJ[k087ojool
086Zd:[j087oPOo6ooX0PJ[AZ_/0POo[oo`0PJ[@Z_X0POn1olKonP21Z]6Zn`2g
o`1>]?ol086Zd:[j087oPOo8ooX0PJ[AZ_/0POoYoo`0PJ[@Z_X0POn1olSonP21
Z]6Zn`21onWoo021Z]2ZnP21oh7ob?oj086ZdJ[k0;Ko04jcoo`0PJ[@Z_T0POn1
olcon@21Z]6ZnP21onSoo021Z]2Zn@21oh7oc?oi086ZdJ[j087oj?ol086Zd:[i
087oPOo<ooT0PJ[AZ_X0]_l0C[?on`21Z/nZnP21oh7oc_oj086Zcj[k087oiook
086Zcj[j087oPOo>ooX0PJ[?Z_/0POoWoo/0PJ[?Z_X0POn1olkonP21Z/nZn`2e
o`1>/_ol086ZcJ[j087oPOoBooX0PJ[>Z_/0POoUoo`0PJ[=Z_X0POn1om;onP21
Z/jZn`21onGoo021Z/fZnP21oh7od_oj086ZcZ[k0;Co04jaoo`0PJ[<Z_X0POn1
omKonP21Z/fZn`21on?oo021Z/bZnP21oh7oe_oj086ZcJ[k087ohool086Zc:[j
087oPOoFooX0PJ[=Z_/0/ol0C[3oo021Z/bZnP21oh7of?oj086ZcJ[j087oh_ol
086Zc:[j087oPOoHooX0PJ[=Z_X0POoRoo`0PJ[<Z_X0POn1omSonP21Z/fZnP2c
o`1>/?ok086Zbj[j087oPOoLooX0PJ[;Z_/0POoQoo/0PJ[;Z_X0POn1omconP21
Z/^Zn`21on7on`21Z/^ZnP21oh7og?oj086Zbj[k0;;o04j_oo`0PJ[:Z_T0POn1
omoonP21Z/^Zn`21omooo021Z/ZZn@21oh7ogooj086Zbj[k087ogool086ZbZ[i
087oPOoOooX0PJ[;Z_/0/Ol0CZkoo021Z/VZnP21oh7oh_oj086ZbZ[k087ogOol
086ZbJ[j087oPOoRooX0PJ[:Z_/0POoMoo`0PJ[9Z_X0POn1on;onP21Z/ZZn`2`
o`1>[Ool086ZbJ[i087oPOoVooT0PJ[:Z_X0POoLoo`0PJ[9Z_T0POn1onKon@21
Z/ZZnP21omcoo021Z/VZn@21oh7oi_oi086ZbZ[j0;3o04j]oo/0PJ[8Z_X0POn1
onSonP21Z/RZn`21om_on`21Z/RZnP21oh7oj?oj086Zb:[k087ofook086Zb:[j
087oPOoXooX0PJ[8Z_/0[ol0CZcoo021Z/NZn@21oh7ok?oi086Zb:[k087ofOol
086Zaj[i087oPOo/ooT0PJ[8Z_/0POoIoo`0PJ[7Z_T0POn1oncon@21Z/RZn`2^
o`1>Zool086ZaZ[i087oPOo`ooT0PJ[7Z_/0POoGoo`0PJ[6Z_T0POn1oo3on@21
Z/NZn`21omOoo021Z/JZn@21oh7ol?oi086Zaj[k0:go04jZoo`0PJ[6Z_T0POn1
oo;on@21Z/NZnP21omKoo021Z/JZn@21oh7ol_oi086Zaj[j087oe_ol086ZaZ[i
087oPOobooT0PJ[7Z_X0[Ol0CZ[on`21Z/FZn@21oh7om_oi086ZaJ[k087oeOok
086ZaJ[i087oPOofooT0PJ[5Z_/0POoEoo/0PJ[5Z_T0POn1ooKon@21Z/FZn`2/
o`1>ZOol086Za:[h087oPOojooP0PJ[5Z_/0POoCoo`0PJ[4Z_P0POn1oo[on021
Z/FZn`21om?oo021Z/BZn021oh7on_oh086ZaJ[k0:_o04jXoo`0PJ[3Z_P0POn1
ookon021Z/BZn`21om7oo021Z/>Zn021oh7oo_oh086Za:[k087odOol086Z`j[h
087oPOonooP0PJ[4Z_/0Z_l0B:Ooo021Z/:Zn021oh;om`21Z/BZnP21om3oo021
Z/:Zn021oh;om`21Z/BZnP21om3oo021Z/:Zn021oh;om`21Z/BZnP2Zo`18Yook
086Z`Z[g087oQ_og086Z`Z[k087ocook086Z`Z[g087oQ_og086Z`Z[k087ocook
086Z`Z[g087oQ_og086Z`Z[k0:Wo04RVoo`0PJ[0Z_L0POn:ooL0PJ[1Z_/0POo=
oo`0PJ[0Z_L0POn:ooL0PJ[1Z_/0POo=oo`0PJ[0Z_L0POn:ooL0PJ[1Z_/0Z?l0
B:Goo021Z[nZmP21ohoom`21Z/2Zn`21ol_oo021Z[nZmP21ohoom`21Z/2Zn`21
ol_oo021Z[nZmP21ohoom`21Z/2Zn`2Wo`18Y?ol086Z_Z[f087oU?of086Z_j[j
087ob_ol086Z_Z[f087oU?of086Z_j[j087ob_ol086Z_Z[f087oU?of086Z_j[j
0:Oo04RToo/0PJZmZ_H0POnHooH0PJZmZ_/0POo9oo/0PJZmZ_H0POnHooH0PJZm
Z_/0POo9oo/0PJZmZ_H0POnHooH0PJZmZ_/0Y_l0B:?oo021Z[^ZmP21oicomP21
Z[bZn`21olOoo021Z[^ZmP21oicomP21Z[bZn`21olOoo021Z[^ZmP21oicomP21
Z[bZn`2Uo`18X_ol086Z^J[g087oX?of086Z^j[k087oaOol086Z^J[g087oX?of
086Z^j[k087oaOol086Z^J[g087oX?of086Z^j[k0:Co04RQoo`0PJZhZ_L0POnT
ooL0PJZiZ_X0POo4oo`0PJZhZ_L0POnTooL0PJZiZ_X0POo4oo`0PJZhZ_L0POnT
ooL0PJZiZ_X0Y?l0B:7on`21Z[NZm`21ojSom`21Z[NZn`21ol?on`21Z[NZm`21
ojSom`21Z[NZn`21ol?on`21Z[NZm`21ojSom`21Z[NZn`2So`18X?ol086Z]J[g
087o[?og086Z]Z[k087o`Ool086Z]J[g087o[?og086Z]Z[k087o`Ool086Z]J[g
087o[?og086Z]Z[k0:;o04ROoo`0PJZdZ_L0POnaooH0PJZeZ_/0POnooo`0PJZd
Z_L0POnaooH0PJZeZ_/0POnooo`0PJZdZ_L0POnaooH0PJZeZ_/0XOl0B9koo021
Z[>ZmP21okKomP21Z[>Zn`21okkoo021Z[>ZmP21okKomP21Z[>Zn`21okkoo021
Z[>ZmP21okKomP21Z[>Zn`2Qo`18W_ok086Z/Z[f087o^ooe086Z/Z[k087o_Ook
086Z/Z[f087o^ooe086Z/Z[k087o_Ook086Z/Z[f087o^ooe086Z/Z[k0:3o04RM
oo/0PJZ`Z_H0POo0ooH0PJZ`Z_/0POnkoo/0PJZ`Z_H0POo0ooH0PJZ`Z_/0POnk
oo/0PJZ`Z_H0POo0ooH0PJZ`Z_/0Wol0B9con`21ZZnZm@21olKom@21ZZnZn`21
okWon`21ZZnZm@21olKom@21ZZnZn`21okWon`21ZZnZm@21olKom@21ZZnZn`2N
o`18Vook086Z[J[f087ob_of086Z[:[l087o]ook086Z[J[f087ob_of086Z[:[l
087o]ook086Z[J[f087ob_of086Z[:[l09go04RJoo`0PJZ[Z_D0POo@ooD0PJZ[
Z_`0POneoo`0PJZ[Z_D0POo@ooD0PJZ[Z_`0POneoo`0PJZ[Z_D0POo@ooD0PJZ[
Z_`0W?l0B9Woo021ZZVZmP21omComP21ZZVZo021ok?oo021ZZVZmP21omComP21
ZZVZo021ok?oo021ZZVZmP21omComP21ZZVZo02Ko`18V?ol086ZYj[f087of_of
086ZYj[k087o/_ol086ZYj[f087of_of086ZYj[k087o/_ol086ZYj[f087of_of
086ZYj[k09_o04RHoo/0PJZVZ_@0POoRoo@0PJZVZ_/0POnaoo/0PJZVZ_@0POoR
oo@0PJZVZ_/0POnaoo/0PJZVZ_@0POoRoo@0PJZVZ_/0V_l0B9Oon`21ZZBZl`21
on[ol`21ZZBZn`21ojoon`21ZZBZl`21on[ol`21ZZBZn`21ojoon`21ZZBZl`21
on[ol`21ZZBZn`2Io`18U_ok086ZXj[a087ol_oa086ZXj[k087o[Ook086ZXj[a
087ol_oa086ZXj[k087o[Ook086ZXj[a087ol_oa086ZXj[k09So04REoo/0PJZQ
Z_00POoioo40PJZQZ_/0POn[oo/0PJZQZ_00POoioo40PJZQZ_/0POn[oo/0PJZQ
Z_00POoioo40PJZQZ_/0Uol0B9Con`21ZYjZl@21o`3ol@21ZYjZn`21ojWon`21
ZYjZl@21o`3ol@21ZYjZn`21ojWon`21ZYjZl@21o`3ol@21ZYjZn`2Fo`12Took
086ZVj[a08Sol@21ZY^Zn`21ojOon`21ZY^Zl@28oo40PJZKZ_/0POnWoo/0PJZK
Z_40R?oa086ZVj[k09Go04:Boo/0PJZHZ_40T?oa086ZUj[l087oYOok086ZV:[a
093ol@21ZYNZo021ojGon`21ZYRZl@2@oo40PJZGZ_`0U?l0@Y7oo021ZYBZkP2N
ond0PJZEZ_`0POnSoo`0PJZDZ^h0W_o]086ZUJ[l087oXool086ZU:[^09kok@21
ZYFZo02Co`12T?ol086ZTZ[Z0:cojP21ZY:Zo021oj7oo021ZY:ZjP2/onX0PJZB
Z_`0POnQoo`0PJZBZ^X0[?oZ086ZTZ[l09;o04:?oo`0PJZ?Z^L0^_oW086ZSj[k
087oX?ol086ZSj[W0;[oi`21ZXnZn`21oj3oo021ZXnZi`2jonL0PJZ?Z_/0T_l0
@Xoon`21ZXbZi038on@0PJZ<Z_/0POnOoo/0PJZ<Z^@0b?oT086ZS:[k087oWook
086ZS:[T0<Soi021ZXbZn`2Ao`0fS_ok086ZQZZL086ZQZ[k087oWOok086ZQZZL
086ZQZ[k087oWOok086ZQZZL086ZQZ[k093o04:=oo/0PJZ1ZP2ZZP21ZX6Z0:[k
087oVook086ZPJX0ZZX0PJZ1ZP2Zn`21oi_on`21ZX6Z0:ZZ086ZPJX0Z_/0Sol0
@Xcon`21ZX6ZnZZh086ZPJ[jZ_/0POnIoo/0PJZ1Z_ZZ^021ZX6ZnZ[k087oVOok
086ZPJ[jZ[P0PJZ1Z_ZZn`2>o`12Rook086ZPJ[cZ/P0PJZ1Z_>Zn`21oiOon`21
ZX6Zlj[8086ZPJ[cZ_/0POnGoo/0PJZ1Z_>Zb021ZX6Zlj[k08go04::oo/0PJZ1
Z^JZi021ZX6ZiZ[k087oUOok086ZPJ[VZ^@0PJZ1Z^JZn`21oiGon`21ZX6ZiZ[T
086ZPJ[VZ_/0S?l0=XWon`21ZX6ZPJZ1ZZnZo021oi?on`21ZX6ZPJZ1ZZnZo021
oi?on`21ZX6ZPJZ1ZZnZo02;o`0fR?ol086ZPJZ1ZX6Z/:[l087oTOol086ZPJZ1
ZX6Z/:[l087oTOol086ZPJZ1ZX6Z/:[l08[o03J7oo`0PJZ1ZX6ZPJZbZ_`0POn?
oo`0PJZ1ZX6ZPJZbZ_`0POn?oo`0PJZ1ZX6ZPJZbZ_`0ROl0=XKoo021ZX6ZPJZ1
Z[BZn`21ohkoo021ZX6ZPJZ1Z[BZn`21ohkoo021ZX6ZPJZ1Z[BZn`29o`0fQ_ok
086ZPJZ1ZX6Z]Z[k087oSOok086ZPJZ1ZX6Z]Z[k087oSOok086ZPJZ1ZX6Z]Z[k
08So03J5oo/0PJZ1ZX6ZPJZhZ_/0POn;oo/0PJZ1ZX6ZPJZhZ_/0POn;oo/0PJZ1
ZX6ZPJZhZ_/0Qol0=XCon`21ZX6ZPJZ1Z[ZZn`21ohWon`21ZX6ZPJZ1Z[ZZn`21
ohWon`21ZX6ZPJZ1Z[ZZn`26o`0fPook086ZPJZ1ZX6Z_:[k087oQook086ZPJZ1
ZX6Z_:[k087oQook086ZPJZ1ZX6Z_:[k08Go03J2oo/0PJZ1ZX6ZPJZnZ_/0POn5
oo/0PJZ1ZX6ZPJZnZ_/0POn5oo/0PJZ1ZX6ZPJZnZ_/0Q?l0=X7on`21ZX6ZPJZ1
Z/2Zn`21oh?on`21ZX6ZPJZ1Z/2Zn`21oh?on`21ZX6ZPJZ1Z/2Zn`23o`0hPOl0
ooX0PJZ1ZX6ZPJ[4Z_X0POn1ooX0PJZ1ZX6ZPJ[4Z_X0POn1ooX0PJZ1ZX6ZPJ[4
Z_X0P_l0?h7o0OoonP21ZX6ZPJZ1Z/JZnP21oh7o0OoonP21ZX6ZPJZ1Z/JZnP21
oh7o0OoonP21ZX6ZPJZ1Z/JZnP21o`0nPOonooX0PJZ1ZX6ZPJ[8Z_X0POn1oogo
nP21ZX6ZPJZ1Z/RZnP21oh7ooOoj086ZPJZ1ZX6Zb:[j087o0?l0?X7oo?ok086Z
PJZ1ZX6ZbZ[k087oPOoioo/0PJZ1ZX6ZPJ[:Z_/0POn1ooWon`21ZX6ZPJZ1Z/ZZ
n`21ooko03j1oo_on`21ZX6ZPJZ1Z/bZn`21oh7omook086ZPJZ1ZX6Zc:[k087o
POogoo/0PJZ1ZX6ZPJ[<Z_/0POomo`0nPOojoo/0PJZ1ZX6ZPJ[>Z_/0POn1ooGo
n`21ZX6ZPJZ1Z/jZn`21oh7omOok086ZPJZ1ZX6ZcZ[k087oo?l0?X7onOok086Z
PJZ1ZX6Zd:[k087oPOocoo/0PJZ1ZX6ZPJ[@Z_/0POn1oo?on`21ZX6ZPJZ1Z]2Z
n`21oo_o03j1ooSon`21ZX6ZPJZ1Z]:Zn`21oh7olOok086ZPJZ1ZX6ZdZ[k087o
POoaoo/0PJZ1ZX6ZPJ[BZ_/0POojo`0nPOogoo/0PJZ1ZX6ZPJ[DZ_/0POn1onoo
n`21ZX6ZPJZ1Z]BZn`21oh7okook086ZPJZ1ZX6Ze:[k087onOl0?X7om_oj086Z
PJZ1ZX6Zf:[j087oPOo]ooX0PJZ1ZX6ZPJ[HZ_X0POn1ongonP21ZX6ZPJZ1Z]RZ
nP21ooSo03j1ooGonP21ZX6ZPJZ1Z]ZZnP21oh7ojooj086ZPJZ1ZX6ZfZ[j087o
POo[ooX0PJZ1ZX6ZPJ[JZ_X0POogo`0nPOodooX0PJZ1ZX6ZPJ[LZ_X0POn1onWo
nP21ZX6ZPJZ1Z]bZnP21oh7ojOoj086ZPJZ1ZX6Zg:[j087om_l0?X7ol_ok086Z
PJZ1ZX6ZgZ[k087oPOoUoo/0PJZ1ZX6ZPJ[NZ_/0POn1onGon`21ZX6ZPJZ1Z]jZ
n`21ooCo03j1oo7on`21ZX6ZPJZ1Z^2Zn`21oh7ohook086ZPJZ1ZX6Zh:[k087o
POoSoo/0PJZ1ZX6ZPJ[PZ_/0POoco`0nPOo`oo/0PJZ1ZX6ZPJ[RZ_/0POn1on7o
n`21ZX6ZPJZ1Z^:Zn`21oh7ohOok086ZPJZ1ZX6ZhZ[k087ol_l0?X7okook086Z
PJZ1ZX6Zi:[k087oPOoOoo/0PJZ1ZX6ZPJ[TZ_/0POn1omoon`21ZX6ZPJZ1Z^BZ
n`21oo7o03j1onkon`21ZX6ZPJZ1Z^JZn`21oh7ogOok086ZPJZ1ZX6ZiZ[k087o
POoMoo/0PJZ1ZX6ZPJ[VZ_/0POo`o`0nPOo]oo/0PJZ1ZX6ZPJ[XZ_/0POn1om_o
n`21ZX6ZPJZ1Z^RZn`21oh7ofook086ZPJZ1ZX6Zj:[k087okol0?X7ok?oj086Z
PJZ1ZX6Zk:[j087oPOoIooX0PJZ1ZX6ZPJ[/Z_X0POn1omWonP21ZX6ZPJZ1Z^bZ
nP21onko03j1on_onP21ZX6ZPJZ1Z^jZnP21oh7oeooj086ZPJZ1ZX6ZkZ[j087o
POoGooX0PJZ1ZX6ZPJ[^Z_X0POo]o`0nPOoZooX0PJZ1ZX6ZPJ[`Z_X0POn1omGo
nP21ZX6ZPJZ1Z_2ZnP21oh7oeOoj086ZPJZ1ZX6Zl:[j087ok?l0?X7oj?ok086Z
PJZ1ZX6ZlZ[k087oPOoAoo/0PJZ1ZX6ZPJ[bZ_/0POn1om7on`21ZX6ZPJZ1Z_:Z
n`21on[o03j1onOonP21ZX6ZPJZ1Z_JZnP21oh7ocooj086ZPJZ1ZX6ZmZ[j087o
POo?ooX0PJZ1ZX6ZPJ[fZ_X0POoYo`0nPOoVooT0PJZ1ZX6ZPJ[jZ_T0POn1olgo
n@21ZX6ZPJZ1Z_ZZn@21oh7ocOoi086ZPJZ1ZX6ZnZ[i087oj?l0?X7oiOoi086Z
PJZ1ZX6Zo:[i087oPOo;ooT0PJZ1ZX6ZPJ[lZ_T0POn1ol_on@21ZX6ZPJZ1Z_bZ
n@21onOo03j1onCon@21ZX6ZPJZ1Z_jZn@21oh7obOoi086ZPJZ1ZX6ZoZ[i087o
POo9ooT0PJZ1ZX6ZPJ[nZ_T0POoVo`0hPOoSooP0PJZ1ZX6ZPZ[h087oPOo7ooP0
PJZ1ZX6ZPZ[h087oPOo7ooP0PJZ1ZX6ZPZ[h087oiOl0>87ohOoi086ZPJZ1ZXBZ
n@21oh7o`ooi086ZPJZ1ZXBZn@21oh7o`ooi086ZPJZ1ZXBZn@21on?o03R1on3o
n@21ZX6ZPJZ6Z_T0POn1ol7on@21ZX6ZPJZ6Z_T0POn1ol7on@21ZX6ZPJZ6Z_T0
POoRo`0hPOoOooP0PJZ1ZX6ZRZ[h087oPOnoooP0PJZ1ZX6ZRZ[h087oPOnoooP0
PJZ1ZX6ZRZ[h087ohOl0>87ogOoi086ZPJZ1ZXbZn@21oh7o^ooi086ZPJZ1ZXbZ
n@21oh7o^ooi086ZPJZ1ZXbZn@21omoo03R1omcon@21ZX6ZPJZ>Z_T0POn1okWo
n@21ZX6ZPJZ>Z_T0POn1okWon@21ZX6ZPJZ>Z_T0POoNo`0hPOoKooP0PJZ1ZX6Z
TZ[h087oPOngooP0PJZ1ZX6ZTZ[h087oPOngooP0PJZ1ZX6ZTZ[h087ogOl0>87o
fOoi086ZPJZ1ZYBZn@21oh7o/ooi086ZPJZ1ZYBZn@21oh7o/ooi086ZPJZ1ZYBZ
n@21om_o03R1omSon@21ZX6ZPJZFZ_T0POn1ok7on@21ZX6ZPJZFZ_T0POn1ok7o
n@21ZX6ZPJZFZ_T0POoJo`0hPOoGooP0PJZ1ZX6ZVZ[h087oPOn_ooP0PJZ1ZX6Z
VZ[h087oPOn_ooP0PJZ1ZX6ZVZ[h087ofOl0>87oeOoi086ZPJZ1ZYbZn@21oh7o
Zooi086ZPJZ1ZYbZn@21oh7oZooi086ZPJZ1ZYbZn@21omOo03R1omCon@21ZX6Z
PJZNZ_T0POn1ojWon@21ZX6ZPJZNZ_T0POn1ojWon@21ZX6ZPJZNZ_T0POoFo`0h
POoCooP0PJZ1ZX6ZXZ[h087oPOnWooP0PJZ1ZX6ZXZ[h087oPOnWooP0PJZ1ZX6Z
XZ[h087oeOl0>87odOoi086ZPJZ1ZZBZn@21oh7oXooi086ZPJZ1ZZBZn@21oh7o
Xooi086ZPJZ1ZZBZn@21om?o03R1om3on@21ZX6ZPJZVZ_T0POn1oj7on@21ZX6Z
PJZVZ_T0POn1oj7on@21ZX6ZPJZVZ_T0POoBo`0hPOo?ooP0PJZ1ZX6ZZZ[h087o
POnOooP0PJZ1ZX6ZZZ[h087oPOnOooP0PJZ1ZX6ZZZ[h087odOl0>87ocOoi086Z
PJZ1ZZbZn@21oh7oVooi086ZPJZ1ZZbZn@21oh7oVooi086ZPJZ1ZZbZn@21oloo
03R1olcon@21ZX6ZPJZ^Z_T0POn1oiWon@21ZX6ZPJZ^Z_T0POn1oiWon@21ZX6Z
PJZ^Z_T0POo>o`0hPOo;ooP0PJZ1ZX6Z/Z[h087oPOnGooP0PJZ1ZX6Z/Z[h087o
POnGooP0PJZ1ZX6Z/Z[h087ocOl0>87obOoi086ZPJZ1Z[BZn@21oh7oTooi086Z
PJZ1Z[BZn@21oh7oTooi086ZPJZ1Z[BZn@21ol_o03R1olSon021ZX6ZPJZhZ_P0
POn1oi7on021ZX6ZPJZhZ_P0POn1oi7on021ZX6ZPJZhZ_P0POo:o`0hPOo7ooP0
PJZ1ZX6Z^Z[h087oPOn?ooP0PJZ1ZX6Z^Z[h087oPOn?ooP0PJZ1ZX6Z^Z[h087o
bOl0>87oaOoh086ZPJZ1Z[jZn021oh7oRooh086ZPJZ1Z[jZn021oh7oRooh086Z
PJZ1Z[jZn021olOo03R1olCom`21ZX6ZPJ[1Z_P0POn1ohWom`21ZX6ZPJ[1Z_P0
POn1ohWom`21ZX6ZPJ[1Z_P0POo6o`0hPOo2ooP0PJZ1ZX6Za:[h087oPOn5ooP0
PJZ1ZX6Za:[h087oPOn5ooP0PJZ1ZX6Za:[h087oa?l0>87o`Oog086ZPJZ1Z/RZ
m`21oh7oPoog086ZPJZ1Z/RZm`21oh7oPoog086ZPJZ1Z/RZm`21ol?o03j1okoo
n021ZX6ZPJ[:Z_P0POn1oh7o0Ooon021ZX6ZPJ[:Z_P0POn1oh7o0Ooon021ZX6Z
PJ[:Z_P0POo1o`0lPOnmooP0PJZ1ZX6ZcZ[h087oPOn1oo_on021ZX6ZPJ[>Z_P0
POn1oh7onooh086ZPJZ1Z/jZn021okoo03b1okcom`21ZX6ZPJ[BZ_L0POn1oh7o
nOog086ZPJZ1Z]:Zm`21oh7oPOoiooL0PJZ1ZX6ZdZ[g087o__l0?87o^_oh086Z
PJZ1Z]BZn021oh7oPOoeooP0PJZ1ZX6Ze:[h087oPOn1ooGon021ZX6ZPJ[DZ_P0
POnlo`0lPOnhooP0PJZ1ZX6Zf:[h087oPOn1oo7on021ZX6ZPJ[HZ_P0POn1oh7o
lOoh086ZPJZ1Z]RZn021ok[o03b1okOon021ZX6ZPJ[JZ_P0POn1oh7okooh086Z
PJZ1Z]ZZn021oh7oPOo_ooP0PJZ1ZX6ZfZ[h087o^Ol0?87o]Ooh086ZPJZ1Z]jZ
n021oh7oPOo[ooP0PJZ1ZX6ZgZ[h087oPOn1on_on021ZX6ZPJ[NZ_P0POngo`0l
POncooP0PJZ1ZX6ZhZ[h087oPOn1onOon021ZX6ZPJ[RZ_P0POn1oh7oiooh086Z
PJZ1Z^:Zn021okGo03b1ok;on021ZX6ZPJ[TZ_P0POn1oh7oiOoh086ZPJZ1Z^BZ
n021oh7oPOoUooP0PJZ1ZX6Zi:[h087o]?l0?87o/?oh086ZPJZ1Z^RZn021oh7o
POoQooP0PJZ1ZX6Zj:[h087oPOn1on7on021ZX6ZPJ[XZ_P0POnbo`0lPOn^ooP0
PJZ1ZX6Zk:[h087oPOn1omgon021ZX6ZPJ[/Z_P0POn1oh7ogOoh086ZPJZ1Z^bZ
n021ok3o03b1ojgon021ZX6ZPJ[^Z_P0POn1oh7ofooh086ZPJZ1Z^jZn021oh7o
POoKooP0PJZ1ZX6ZkZ[h087o[ol0?87oZooh086ZPJZ1Z_:Zn021oh7oPOoGooP0
PJZ1ZX6ZlZ[h087oPOn1omOon021ZX6ZPJ[bZ_P0POn]o`0lPOnYooT0PJZ1ZX6Z
m:[i087oPOn1om?on@21ZX6ZPJ[dZ_T0POn1oh7odooi086ZPJZ1Z_BZn@21oj_o
03b1ojSon021ZX6ZPJ[hZ_P0POn1oh7odOoh086ZPJZ1Z_RZn021oh7oPOoAooP0
PJZ1ZX6Zn:[h087oZ_l0?87oY_oh086ZPJZ1Z_bZn021oh7oPOo=ooP0PJZ1ZX6Z
o:[h087oPOn1olgon021ZX6ZPJ[lZ_P0POnXo`0lPOnTooP0PJZ1ZX6Z0:[h087o
POn1olWon021ZX6ZPJX0Z_P0POn1oh7obOoh086ZPJZ1ZP2Zn021ojKo03J1oj?o
m`21ZX6ZQ:[g087oPOn1olOom`21ZX6ZQ:[g087oPOn1olOom`21ZX6ZQ:[g087o
YOl0=X7oXOog086ZPJZ8Z_L0POn1oh7o`oog086ZPJZ8Z_L0POn1oh7o`oog086Z
PJZ8Z_L0POnSo`0fPOnOooL0PJZ1ZXbZm`21oh7oPOnoooL0PJZ1ZXbZm`21oh7o
POnoooL0PJZ1ZXbZm`21oj7o03J1oigom`21ZX6ZT:[g087oPOn1ok_om`21ZX6Z
T:[g087oPOn1ok_om`21ZX6ZT:[g087oWol0=X7oVoog086ZPJZDZ_L0POn1oh7o
]oog086ZPJZDZ_L0POn1oh7o]oog086ZPJZDZ_L0POnMo`0fPOnIooL0PJZ1ZYRZ
m`21oh7oPOncooL0PJZ1ZYRZm`21oh7oPOncooL0PJZ1ZYRZm`21oi_o03J1oiOo
m`21ZX6ZW:[g087oPOn1ojoom`21ZX6ZW:[g087oPOn1ojoom`21ZX6ZW:[g087o
VOl0=X7oUOog086ZPJZPZ_L0POn1oh7oZoog086ZPJZPZ_L0POn1oh7oZoog086Z
PJZPZ_L0POnGo`0fPOnCooL0PJZ1ZZBZm`21oh7oPOnWooL0PJZ1ZZBZm`21oh7o
POnWooL0PJZ1ZZBZm`21oiGo03J1oi7om`21ZX6ZZ:[g087oPOn1oj?om`21ZX6Z
Z:[g087oPOn1oj?om`21ZX6ZZ:[g087oTol0=X7oSoog086ZPJZ/Z_L0POn1oh7o
Woog086ZPJZ/Z_L0POn1oh7oWoog086ZPJZ/Z_L0POnAo`0fPOn=ooL0PJZ1Z[2Z
m`21oh7oPOnKooL0PJZ1Z[2Zm`21oh7oPOnKooL0PJZ1Z[2Zm`21ohoo03J1oh_o
m`21ZX6Z]:[g087oPOn1oiOom`21ZX6Z]:[g087oPOn1oiOom`21ZX6Z]:[g087o
SOl0=X7oROog086ZPJZhZ_L0POn1oh7oToog086ZPJZhZ_L0POn1oh7oToog086Z
PJZhZ_L0POn;o`0fPOn7ooL0PJZ1Z[bZm`21oh7oPOn?ooL0PJZ1Z[bZm`21oh7o
POn?ooL0PJZ1Z[bZm`21ohWo03J1ohGom`21ZX6Z`:[g087oPOn1oh_om`21ZX6Z
`:[g087oPOn1oh_om`21ZX6Z`:[g087oQol0=X7oPoof086ZPJ[6Z_H0POn1oh7o
Qoof086ZPJ[6Z_H0POn1oh7oQoof086ZPJ[6Z_H0POn5o`0fPOn1ooH0PJZ1Z/ZZ
mP21oh7oPOn3ooH0PJZ1Z/ZZmP21oh7oPOn3ooH0PJZ1Z/ZZmP21oh?o03n1oh7o
0Ooom@21ZX6Zd:[e087oPOn1oh7o0Ooom@21ZX6Zd:[e087oPOn1oh7o0Ooom@21
ZX6Zd:[e087oPOl0?h7oPOomoo@0PJZ1Z]JZm021oh7oPOn1oo_om021ZX6ZeZ[d
087oPOn1oh7onood086ZPJ[FZ_@0POn1o`7oo`0nPOn1oo[om021ZX6Zg:[d087o
POn1oh7omOod086ZPJ[LZ_@0POn1oh7oPOoeoo@0PJZ1Z]bZm021oh7oo?l0?X7o
POogooD0PJZ1Z^2Zm@21oh7oPOn1onoom@21ZX6Zh:[e087oPOn1oh7okooe086Z
PJ[PZ_D0POn1ooWo03j1oh7omOod086ZPJ[VZ_@0POn1oh7oPOo[oo@0PJZ1Z^JZ
m021oh7oPOn1on_om021ZX6ZiZ[d087oPOogo`0nPOn1oo;om021ZX6Zk:[d087o
POn1oh7oiOod086ZPJ[/Z_@0POn1oh7oPOoUoo@0PJZ1Z^bZm021oh7om?l0?X7o
POo_ooD0PJZ1Z_2Zm@21oh7oPOn1omoom@21ZX6Zl:[e087oPOn1oh7ogooe086Z
PJ[`Z_D0POn1oo7o03j1oh7ok?oe086ZPJ[fZ_D0POn1oh7oPOoIooD0PJZ1Z_JZ
m@21oh7oPOn1omWom@21ZX6ZmZ[e087oPOo^o`0nPOn1onWom@21ZX6Zo:[d087o
POn1oh7oe?oe086ZPJ[lZ_@0POn1oh7oPOoDooD0PJZ1Z_bZm021oh7ok?l0>87o
POoWoo@0PJZ2Z_@0POn1oh7oPOo?oo@0PJZ2Z_@0POn1oh7oPOo?oo@0PJZ2Z_@0
POn1onWo03R1oh7oi?oe086ZQZ[e087oPOn1oh7obOoe086ZQZ[e087oPOn1oh7o
bOoe086ZQZ[e087oPOoVo`0hPOn1on7om@21ZXbZm@21oh7oPOn1ol?om@21ZXbZ
m@21oh7oPOn1ol?om@21ZXbZm@21oh7ohol0>87oPOoNoo@0PJZDZ_@0POn1oh7o
POnmoo@0PJZDZ_@0POn1oh7oPOnmoo@0PJZDZ_@0POn1on3o03R1oh7og?ob086Z
W:[b087oPOn1oh7o^Oob086ZW:[b087oPOn1oh7o^Oob086ZW:[b087oPOoNo`0h
POn1omWol@21ZZBZl@21oh7oPOn1ok?ol@21ZZBZl@21oh7oPOn1ok?ol@21ZZBZ
l@21oh7ofol0>87oPOoFoo00PJZ/Z_00POn1oh7oPOn]oo00PJZ/Z_00POn1oh7o
POn]oo00PJZ/Z_00POn1omSo03R1oh7od_o`086Z]:[`087oPOn1oh7oYOo`086Z
]:[`087oPOn1oh7oYOo`086Z]:[`087oPOoDo`0hPOn1olkol021Z[bZl021oh7o
POn1oigol021Z[bZl021oh7oPOn1oigol021Z[bZl021oh7od?l0>87oPOo:oo00
PJ[4Z_00POn1oh7oPOnEoo00PJ[4Z_00POn1oh7oPOnEoo00PJ[4Z_00POn1olco
03R1oh7oa_o`086Zc:[`087oPOn1oh7oSOo`086Zc:[`087oPOn1oh7oSOo`086Z
c:[`087oPOo8o`0hPOn1ol;ol021Z]BZl021oh7oPOn1ohGol021Z]BZl021oh7o
POn1ohGol021Z]BZl021oh7oa?l0?87oPOnoonl0PJ[LZ_00POn1oh7oPOn1ooko
k`21Z]bZl021oh7oPOn1oh7oo_o_086Zg:[`087oPOo0o`0lPOn1ok_ok@21Z^RZ
kP21oh7oPOn1oh7om_o]086Zj:[^087oPOn1oh7oPOofond0PJ[XZ^h0POn1okco
03b1oh7o]ooZ086ZmZ[[087oPOn1oh7oPOo^onX0PJ[fZ^/0POn1oh7oPOn1onko
jP21Z_JZj`21oh7o^?l0=X7oPOnconL0Q:[X087oPOn1oh7oPOoVonL0Q:[X087o
POn1oh7oPOoVonL0Q:[X087oPOndo`0fPOn1ojkoiP2AZ^D0POn1oh7oPOn1omgo
iP2AZ^D0POn1oh7oPOn1omgoiP2AZ^D0POn1ok3o03J1oh7oZ?oU09nZi021oh7o
POn1oh7odOoU09nZi021oh7oPOn1oh7odOoU09nZi021oh7oZ_l0=X7oPOnRon@0
[J[S087oPOn1oh7oPOo5on@0[J[S087oPOn1oh7oPOo5on@0[J[S087oPOnTo`0f
POn1oicof`39Z]`0POn1oh7oPOn1okWof`39Z]`0POn1oh7oPOn1okWof`39Z]`0
POn1oiko03J1oh7oU_oC0>JZdP21oh7oPOn1oh7o[_oC0>JZdP21oh7oPOn1oh7o
[_oC0>JZdP21oh7oVOl0:X7oPOnAoi@0POn1oh7oPOn1oj?oU021oh7oPOn1oh7o
XonD087oPOnCo`0ZPOn1oh_oX021oh7oPOn1oh7oUonP087oPOn1oh7oPOnGoj00
POn1ohgo02Z1oh7oQOn/087oPOn1oh7oPOn;oj`0POn1oh7oPOn1oh_o[021oh7o
Qol0<X7oPOn1oo3oeP21oh7oPOn1oh7oPOoQomH0POn1oh7oPOn1oh7ohOoF087o
POn1oo;o02R1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oj3o
02R1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oj3o0:00_`3o\>"], "NumberedFigure",
  ImageSize->{202, 202},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Figure 5.  Inner wire and shield of a coax cable with their \
corresponding radii.\
\>", "Caption"],

Cell[TextData[{
  "Because of the complete shielding of the coax the addition of a constant \
doesn't change the shape of the vector potential between ",
  Cell[BoxData[
      \(TraditionalForm\`r\_0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`r\_1\)]],
  ". Therefore the vector potential at ",
  Cell[BoxData[
      \(TraditionalForm\`r\_1\)]],
  " can be put to zero:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(A\_z\)(r)\)]],
  "= ",
  Cell[BoxData[
      \(\(1\/\(4  \[Pi]\)\) Log[r1\^2\/r\^2]\)]],
  "."
}], "NumberedEquation"],

Cell["\<\
v1=0.11248766;
v2=0;\
\>", "Input",
  CellLabel->"In[35]:=",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}},
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  "Set two circular boundaries at ",
  Cell[BoxData[
      \(TraditionalForm\`r\_0\)]],
  " (inner wire) and ",
  Cell[BoxData[
      \(TraditionalForm\`r\_1\)]],
  " (shield):"
}], "Text"],

Cell[BoxData[{
    \(\({xr, yr, r0, r1, r2} = {65, 65, 30. , 60. , 63};\)\), "\n", 
    \(Do[Do[{b = \@\(\((j - xr)\)\^2 + \((i - yr)\)\^2\); \
\[IndentingNewLine]If[
            b \[GreaterEqual] 0\  && \ 
              b \[LessEqual] r0 + 0.0, {m[\([i, j]\)] := v1; 
              mb[\([i, j]\)] = 1;}]; \[IndentingNewLine]If[
            b \[GreaterEqual] r1 - 0.0\ , {m[\([i, j]\)] := v2; 
              mb[\([i, j]\)] = 1;}]}, \[IndentingNewLine]{i, nz}], {j, 
        ns}]\)}], "Input",
  CellLabel->"In[37]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell["\<\
If the boundaries are curved, they can only be mapped approximately \
to a square grid. In all tests the best way to find the sets of grid line \
intersection points that belong to the boundary areas and are to be kept \
fixed during the relaxation process, was just to include or exclude the \
points according to the radius of curvature of the corresponding boundary \
(see cell above). The general agreement between theory and numerical \
calculation ( about 2%)  could \[Dash] in the case of coaxial geometry \
\[Dash] be somewhat improved (-> 0.5%) by using a radius of curvature that \
extends the fixed areas by 0.3 units. But this turned out not to be true for \
other configurations like for instance a pair of circular wires.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["calculate potential", "Subsubsection",
  PageBreakAbove->True],

Cell["\<\
Calculate rough guess u1 on coarse grid as input for main \
calculation:\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
nz1=nz/2;ns1=ns/2; u1=.;m1=.;
m1=Array[u1,{nz1,ns1}];a1=Array[u1,{nz1,ns1}];
Do[Do[a1[[i,j]]=u1[[i,j]],{j,1,ns1}],{i,1,nz1}]
Do[Do[
m1[[i,j]]:=Evaluate[0.25(a1[[i-1,j]]+a1[[i+1,j]]+a1[[i,j-1]]+a1[[i,j+1]])],
{j,2,ns1-1}],{i,2,nz1-1}];
Do[m1[[1,j]]:=0.,{j,1,ns1}];
Do[m1[[nz1,j]]:=0.,{j,1,ns1}];
Do[m1[[i,1]]:=0.,{i,1,nz1}];
Do[m1[[i,ns1]]:=0.,{i,1,nz1}];
(* guess for coordinates:old/2 *)
Do[Do[If[mb[[2i,2j]]==1,m1[[i,j]]=m[[2i,2j]]],{i,nz1}],
{j,ns1}]\
\>", "Input",
  CellLabel->"In[39]:=",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}},
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(Part::"partd" \(\(:\)\(\ \)\) 
      "Part specification \!\(u1 \[LeftDoubleBracket] \(\(1, 3\)\) \
\[RightDoubleBracket]\) is longer than depth of object."\)], "Message",
  CellLabel->"From In[39]:="],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Part :: \"partd\"\) will be suppressed during \
this calculation."\)], "Message",
  CellLabel->"From In[39]:="]
}, Open  ]],

Cell["Laplace at work...", "Text"],

Cell[CellGroupData[{

Cell["\<\
u1=Table[0.,{i,1,nz1},{j,1,ns1}];
Timing[Do[{u1=m1;
If[Mod[i,500]==0,
err=Max[Flatten[Abs[u1-m1]]];
Print[i,\" residual error: \",err];
If[err<10^-6,Break[]]]},{i,1,4000}]]\
\>", "Input",
  CellLabel->"In[49]:=",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}},
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    InterpretationBox[\(500\[InvisibleSpace]" residual error: "\
\[InvisibleSpace]4.219638350587418`*^-6\),
      SequenceForm[ 500, " residual error: ", 4.219638350587418*^-06],
      Editable->False]], "Print",
  CellLabel->"From In[49]:="],

Cell[BoxData[
    InterpretationBox[\(1000\[InvisibleSpace]" residual error: "\
\[InvisibleSpace]2.796935170967796`*^-8\),
      SequenceForm[ 1000, " residual error: ", 2.7969351709677959*^-08],
      Editable->False]], "Print",
  CellLabel->"From In[49]:="],

Cell[BoxData[
    \({280.86666666666656`\ Second, Null}\)], "Output",
  CellLabel->"Out[50]="]
}, Open  ]],

Cell["Copy coarse to fine grid:", "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p = ListInterpolation[u1];\)\), "\n", 
    \(\(u = Table[p[i/2, j/2], {i, 1, nz}, {j, 1, ns}];\)\), "\n", 
    \(\(ListPlot3D[u, PlotRange -> All];\)\)}], "Input",
  CellLabel->"In[51]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P0002_1000`40O003h00OogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooKgoo0P00lGoo003oOoooOom/Ool300000goo001oo`3`Ool00?mooomo
ofYoo`8000Aoo`800?1oo`00ogooogooIgoo0`001Woo00<007oo0000kgoo003oOoooOomTOol30009
Ool00`00Ool0003_Ool00?mooomoof9oo`8000aoo`04001oogoo003^Ool00?mooomooemoo`<000io
o`05001oogooOol0003]Ool00?mooomooeeoo`80011oo`8000=oo`03001oogoo0>]oo`00ogooogoo
FWoo0`0047oo0P0000=Fo@00Ool00goo00<007ooOol0jWoo003oOoooOomHOol2000@Ool30003E_d2
0004Ool00`00Oomoo`3YOol00?mooomooeEoo`<000ioo`@0009Fo@03001FoEKm009Fo@8000=oo`03
001oogoo0>Uoo`00ogooogooDgoo0P003goo0P0000=Fo@00E_d015Km00<005Km00000`0017oo00<0
07ooOol0j7oo003oOoooOom@Ool3000?Ool20004E_d00`00E_eFo@02E_d20002E_d00`00E_d00004
Ool00`00Oomoo`3WOol00?mooomoodeoo`<000moo`<00003E_d005Km00=Fo@03001Fo@0000800006
E_d005KmE_d005Km0P000goo00<007ooOol0igoo003oOoooOom;Ool2000@Ool20005E_d00`00E_eF
o@030005E_d01P00E_d00000E_d000Aoo`03001oogoo0>Ioo`00ogooogooB7oo0`0047oo0P000UKm
00<005KmE_d00UKm0`000UKm00<005KmE_d00eKm0`000eKm00D007ooOomoo`000>Qoo`00ogooogoo
AWoo0P0047oo0`001EKm00H005Km000005Km0004E_d00`00E_d0000200000eKm00000003E_d00`00
Oomoo`02Ool00`00Oomoo`3UOol00?mooomood=oo`<000moo`<0009Fo@03001FoEKm00=Fo@8000AF
o@04001FoEKmE_d20005E_d00`00E_eFo@030004Ool00`00Oomoo`3TOol00?mooomood5oo`80009o
o`03001oogoo00Yoo`<00003E_d005Km00=Fo@03001Fo@0000800003E_d005Km00=Fo@04001Fo@00
0002E_d00`00E_eFo@02E_d30002E_d00`00Oomoo`02Ool00`00Oomoo`3TOol00?mooomoocioo`<0
00Eoo`03001oogoo00Moo`8000EFo@03001FoEKm00<000EFo@03001FoEKm00<000EFo@03001Fo@00
00<000AFo@03001oogoo009oo`03001oogoo0>=oo`00ogoo_Goo2P002goo10003Woo1000Dgoo0P00
47oo0P0000=Fo@00E_d015Km0`000UKm00<005KmE_d00eKm0`000UKm00<005KmE_d00eKm0P000UKm
00<005Km00000UKm0`0017oo00<007ooOol0hWoo003oOonmOol:0009Ool8000:Ool8001>Ool3000?
Ool30004E_d00`00E_d0000200000eKm001Fo@03E_d00`00E_d0000200000eKm001Fo@03E_d00`00
E_d0000200001UKm001FoEKm001Fo@<0009Fo@03001oogoo009oo`03001oogoo0>9oo`00ogoo`Goo
0P003Goo0P0017oo0P002Woo0P0017oo0P00Bgoo0`003goo0`000UKm00<005KmE_d00UKm0P001EKm
00@005KmE_eFo@8000EFo@03001FoEKm00<000EFo@06001Fo@00001Fo@0015Km00<007ooOol00Woo
00<007ooOol0hGoo003oOoo1Ool2000<Ool20006Ool20008Ool20006Ool20018Ool2000?Ool30000
0eKm001Fo@03E_d01000E_d000000UKm00<005KmE_d00UKm00H005Km000005Km0005E_d30002E_d0
0`00E_eFo@03E_d30003E_d01000E_eFoEKm0P0017oo00<007ooOol0h7oo003oOoo1Ool2000<Ool2
0006Ool20008Ool20006Ool20015Ool3000?Ool20005E_d01000E_eFoEKm0P001EKm00<005KmE_d0
0`0015Km00<005Km00000P0000=Fo@00E_d00eKm00<005Km00000P0000=Fo@0000000eKm00@005Km
0000009Fo@05001oogooOol0003ROol00?mool5oo`8000]oo`8000Qoo`8000Ioo`8000Qoo`80049o
o`80011oo`800003E_d005Km00AFo@06001Fo@00001Fo@001EKm0`000UKm00<005KmE_d00UKm0P00
1EKm00<005KmE_d00`001EKm00<005KmE_d00`001EKm00D007ooOomoo`000>5oo`00ogoo`Goo0P00
2goo0P0027oo0P001Woo0P0027oo0P00?goo0`0047oo0P0015Km00@005KmE_eFo@<000AFo@03001F
o@0000800003E_d005Km00=Fo@06001Fo@00001Fo@001EKm0`000UKm00<005KmE_d00eKm0`000UKm
00<005KmE_d00eKm0P000goo00<007ooOol0gWoo003oOoo1Ool2000;Ool20008Ool20006Ool20008
Ool2000mOol2000AOol200000eKm001Fo@03E_d40002E_d00`00E_eFo@02E_d20005E_d00`00E_eF
o@030004E_d00`00E_d0000200000eKm001Fo@03E_d00`00E_d0000200000eKm001Fo@03E_d00`00
E_d0000200000eKm001oo`02Ool00`00Oomoo`3NOol00?mool5oo`8000]oo`8000Qoo`8000Ioo`80
00Qoo`8003Yoo`<0011oo`<000AFo@04001Fo@000002E_d00`00E_eFo@02E_d01P00E_d00000E_d0
00EFo@<0009Fo@03001FoEKm009Fo@8000EFo@04001FoEKmE_d20004E_d20002E_d30005E_d00`00
Oomoo`02003OOol00?mool5oo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8003Qoo`8000moo`@0009F
o@03001FoEKm009Fo@8000EFo@03001FoEKm00<000AFo@03001Fo@0000800003E_d005Km00=Fo@04
001Fo@000002E_d00`00E_eFo@02E_d01P00E_d00000E_d000AFo@@0009Fo@03001FoEKm00=Fo@<0
009oo`03001oogoo0=aoo`00ogoo`Goo0P002goo0P0027oo0P001Woo0P0027oo0P00=Goo0`003goo
0P0000=Fo@00E_d015Km00H005Km000005Km0005E_d30002E_d00`00E_eFo@02E_d20005E_d01000
E_eFoEKm0P001EKm00<005KmE_d00`0015Km00<005Km00000P0000=Fo@00E_d00eKm00<005Km0000
0P0000=Fo@00Ool00Woo00<007ooOol0g7oo003oOoo1Ool2000;Ool20008Ool20006Ool20008Ool2
000bOol3000@Ool20004E_d01000E_eFoEKm0`0015Km00<005Km00000P0000=Fo@00E_d00eKm00H0
05Km000005Km0005E_d01P00E_d00000E_d000EFo@<0009Fo@03001FoEKm009Fo@80009Fo@04001F
oEKm0002E_d30005E_d01@00Oomoogoo0000gGoo003oOoo1Ool2000;Ool20008Ool20006Ool20008
Ool2000`Ool2000AOol200000eKm001Fo@03E_d40002E_d00`00E_eFo@02E_d20005E_d00`00E_eF
o@030004E_d01000E_eFoEKm0`0015Km00<005Km00000P0000=Fo@00E_d00eKm00H005Km000005Km
0002E_d00`00E_eFo@030002E_d00`00E_eFo@03E_d20003Ool00`00Oomoo`3JOol00?mool5oo`80
00aoo`8000Ioo`8000Qoo`8000Ioo`8002ioo`<0011oo`<000AFo@04001Fo@000002E_d00`00E_eF
o@02E_d01P00E_d00000E_d000EFo@<0009Fo@03001FoEKm009Fo@@0009Fo@03001FoEKm009Fo@80
00EFo@03001FoEKm00<000AFo@03001Fo@0000800003E_d005Km00=Fo@03001Fo@0000800003E_d0
07oo009oo`03001oogoo0=Yoo`00ogoo`Goo0P0037oo0P001Woo0P0027oo0P001Woo0P00;7oo0P00
3goo10000UKm00<005KmE_d00UKm0P001EKm00<005KmE_d00`0015Km00<005Km00000P0000=Fo@00
E_d00eKm00@005Km0000009Fo@03001FoEKm009Fo@06001Fo@00001Fo@001EKm0`000UKm00<005Km
E_d00UKm0`0015Km00@005KmE_eFo@8000EFo@05001oogooOol0003KOol00?mookeoo`<00003Ool0
000000eoo`8000Aoo`8000Yoo`8000Aoo`8002Yoo`<0009oo`03001oogoo00Yoo`80009Fo@03001F
oEKm009Fo@06001Fo@00001Fo@001EKm0`000UKm00<005KmE_d00UKm0P001EKm00@005KmE_eFo@80
00EFo@03001FoEKm00<000AFo@03001Fo@0000800003E_d005Km00=Fo@05001Fo@00001Fo@020004
E_d01P00E_d00000E_d000EFo@8000=oo`03001oogoo0=Qoo`00ogoo_Goo1P003Goo20002Woo2000
:7oo0P001Woo00<007ooOol01goo0P001EKm00<005KmE_d00`0015Km00<005Km00000P0000=Fo@00
E_d00eKm00H005Km000005Km0005E_d01P00E_d00000E_d000EFo@<0009Fo@03001FoEKm009Fo@80
00EFo@03001FoEKm00<000AFo@04001FoEKmE_d30004E_d00`00E_d0000200000eKm001oo`02Ool0
0`00Oomoo`3HOol00?mool1oo`<000moo`@000ioo`@002Moo`<0011oo`800003E_d005Km00AFo@<0
009Fo@03001FoEKm009Fo@8000EFo@03001FoEKm00<000AFo@04001FoEKmE_d30004E_d00`00E_d0
000200000eKm001Fo@03E_d01P00E_d00000E_d000EFo@<0009Fo@03001FoEKm009Fo@@0009Fo@03
001FoEKm009Fo@8000EFo@05001oogooOol0003IOol00?mooomoo`ioo`80011oo`<000AFo@03001F
o@0000800003E_d005Km00=Fo@06001Fo@00001Fo@001EKm0`000UKm00<005KmE_d00UKm10000UKm
00<005KmE_d00UKm0P001EKm00<005KmE_d00`0015Km00<005Km00000P0000=Fo@00E_d00eKm00<0
05Km00000P0000=Fo@00E_d00eKm00H005Km000005Km0005E_d20003Ool00`00Oomoo`3FOol00?mo
oomoo`]oo`<000ioo`@0009Fo@03001FoEKm009Fo@8000EFo@03001FoEKm00<000AFo@03001Fo@00
00800003E_d005Km00=Fo@04001Fo@000002E_d00`00E_eFo@02E_d01P00E_d00000E_d000EFo@<0
009Fo@03001FoEKm009Fo@8000EFo@04001FoEKmE_d20002E_d01000E_eFo@000UKm0`0015Km00<0
05Km00000P0000=Fo@00Ool00Woo00<007ooOol0eWoo003oOoooOol8Ool3000?Ool20002E_d00`00
E_eFo@02E_d01P00E_d00000E_d000EFo@<0009Fo@03001FoEKm009Fo@8000EFo@04001FoEKmE_d2
0005E_d00`00E_eFo@030004E_d00`00E_d0000200000eKm001Fo@03E_d01P00E_d00000E_d000EF
o@06001Fo@00001Fo@000UKm00<005KmE_d00`000UKm00<005KmE_d00UKm0P001EKm00D007ooOomo
o`000=Moo`00ogooogoo1Woo0P0047oo0P001EKm00<005KmE_d00`0015Km00<005Km00000P0000=F
o@00E_d00eKm00@005Km0000009Fo@03001FoEKm009Fo@06001Fo@00001Fo@001EKm0`000UKm00<0
05KmE_d00UKm0P001EKm00<005KmE_d00`0015Km00@005KmE_eFo@<000AFo@03001Fo@0000800003
E_d005Km00=Fo@06001Fo@00001Fo@001EKm0P000Woo00<007ooOol0eGoo003oOoooOol3Ool3000@
Ool200000eKm001Fo@04E_d30002E_d00`00E_eFo@02E_d20005E_d00`00E_eFo@030005E_d00`00
E_eFo@030004E_d00`00E_d0000200000eKm001Fo@03E_d01P00E_d00000E_d000EFo@<0009Fo@03
001FoEKm009Fo@@0009Fo@03001FoEKm009Fo@<000AFo@03001FoEKm00<000AFo@03001Fo@000080
0003E_d007oo009oo`03001oogoo0=Aoo`00ogooogoo0Goo0P0047oo0`0015Km00<005Km00000P00
00=Fo@00E_d00eKm00@005Km0000009Fo@03001FoEKm009Fo@<0009Fo@03001FoEKm00=Fo@<0009F
o@03001FoEKm009Fo@8000EFo@03001FoEKm00<000AFo@03001Fo@0000800003E_d005Km00=Fo@04
001Fo@000002E_d00`00E_eFo@02E_d01@00E_d00000E_d00P0015Km0`000UKm00<005KmE_d00UKm
0P001EKm00D007ooOomoo`000=Eoo`00ogoooGoo0`003goo0`000UKm00<005KmE_d00UKm0P001EKm
00<005KmE_d00`001EKm00H005Km000005Km0004E_d00`00E_d0000200000eKm001Fo@03E_d01P00
E_d00000E_d000EFo@<0009Fo@03001FoEKm009Fo@8000EFo@04001FoEKmE_d20005E_d00`00E_eF
o@030004E_d500000eKm001Fo@03E_d01P00E_d00000E_d000EFo@80009oo`03001oogoo0==oo`00
ogoongoo0P003goo0`0000=Fo@00E_d00eKm00@005Km0000009Fo@03001FoEKm009Fo@<0009Fo@03
001FoEKm00=Fo@8000AFo@04001FoEKmE_d20005E_d00`00E_eFo@030004E_d00`00E_d000020000
0eKm001Fo@03E_d01P00E_d00000E_d000EFo@06001Fo@00001Fo@001EKm0`000UKm00<005KmE_d0
0UKm0P001EKm00<005KmE_d00`0015Km00<005Km00000P0000=Fo@00Ool00Woo00<007ooOol0dWoo
003oOoohOol3000?Ool20005E_d00`00E_eFo@030005E_d01P00E_d00000E_d000AFo@03001Fo@00
00800003E_d005Km00=Fo@06001Fo@00001Fo@001EKm0`000UKm00<005KmE_d00UKm0P001EKm00<0
05KmE_d00`0015Km00@005KmE_eFo@<000AFo@03001Fo@0000800003E_d005Km00=Fo@06001Fo@00
001Fo@001EKm0`000UKm00<005KmE_d00UKm0P001EKm00D007ooOomoo`000==oo`00ogoomGoo0`00
47oo0P000UKm00<005KmE_d00UKm0`000UKm00<005KmE_d00eKm0P0015Km00<005KmE_d00`001EKm
00<005KmE_d00`0015Km00<005Km00000P0000=Fo@00E_d00eKm00@005Km0000009Fo@03001FoEKm
009Fo@<0009Fo@03001FoEKm009Fo@@0009Fo@03001FoEKm009Fo@8000EFo@03001FoEKm00<000=F
o@800006E_d00000001Fo@0015Km00H005Km000005Km0005E_d01@00Oomoogoo0000dgoo003oOooc
Ool2000@Ool30005E_d01P00E_d00000E_d000AFo@03001Fo@0000800003E_d005Km00=Fo@<0009F
o@03001FoEKm00=Fo@<0009Fo@03001FoEKm009Fo@8000EFo@03001FoEKm00<000EFo@06001Fo@00
001Fo@0015Km00@005Km0000009Fo@03001FoEKm009Fo@06001Fo@00001Fo@001EKm0`000UKm00@0
05KmE_eFo@<000EFo@03001FoEKm00<000AFo@04001FoEKmE_d30003Ool00`00Oomoo`3@Ool00?mo
oo1oo`<000moo`<0009Fo@03001FoEKm00=Fo@8000AFo@03001FoEKm00<000EFo@06001Fo@00001F
o@0015Km00<005Km00000P0000=Fo@00E_d00eKm00@005Km0000009Fo@03001FoEKm009Fo@<0009F
o@03001FoEKm00=Fo@8000AFo@03001FoEKm00<000EFo@03001FoEKm00<000AFo@03001Fo@000080
0003E_d005Km00=Fo@06001Fo@00001Fo@001EKm0`000UKm00<005KmE_d00UKm10000UKm00<007oo
Ool00Woo00<007ooOol0cgoo003oOoo^Ool2000@Ool200000eKm001Fo@03E_d00`00E_d000020000
0eKm001Fo@03E_d30003E_d00`00E_eFo@02E_d20004E_d00`00E_eFo@030005E_d00`00E_eFo@03
0005E_d01P00E_d00000E_d000AFo@03001Fo@0000800003E_d005Km00=Fo@<0009Fo@03001FoEKm
00=Fo@<0009Fo@03001FoEKm009Fo@8000EFo@03001FoEKm00<00006E_d005KmE_d005Km0`0000=F
o@00E_d00eKm00H005Km000005Km0005E_d01@00Oomoogoo0000dGoo003oOoo[Ool4000>Ool30004
E_d00`00E_eFo@030005E_d01P00E_d00000E_d000EFo@06001Fo@00001Fo@0015Km0`000eKm00<0
05KmE_d00UKm0`000UKm00<005KmE_d00eKm0P0015Km00<005KmE_d00`001EKm00H005Km000005Km
0004E_d00`00E_d0000200000eKm001Fo@03E_d01P00E_d00000E_d000EFo@<0009Fo@03001Fo@00
009Fo@8000EFo@03001FoEKm00<000AFo@04001FoEKmE_d30003Ool00`00Oomoo`3>Ool00?moonUo
o`8000Aoo`03001oogoo00Qoo`<0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm009Fo@8000AF
o@04001FoEKmE_d30004E_d01P00E_d00000E_d000EFo@06001Fo@00001Fo@0015Km00<005Km0000
0P0000=Fo@00E_d00eKm0`000UKm00<005KmE_d00eKm0P0015Km00<005KmE_d00`001EKm00<005Km
E_d00`0015Km00<005Km00000P0000=Fo@00E_d00eKm100000=Fo@00E_d015Km0`000UKm00<005Km
E_d00UKm10000UKm00<007ooOol00Woo00<007ooOol0cGoo003oOooVOol30007Ool00`00Oomoo`04
Ool300000eKm001Fo@03E_d01000E_d000000UKm00<005KmE_d00UKm00H005Km000005Km0004E_d4
0002E_d00`00E_eFo@02E_d20004E_d01000E_eFoEKm0`0015Km00<005KmE_d00`001EKm00H005Km
000005Km0004E_d00`00E_d0000200000eKm001Fo@03E_d30002E_d00`00E_eFo@03E_d30002E_d0
0`00E_eFo@02E_d20005E_d00`00E_eFo@030004E_d00`00E_d0000200000eKm001Fo@03E_d01P00
E_d00000E_d000EFo@05001oogooOol0003?Ool00?moonAoo`8000]oo`04001oogooOol20005E_d0
0`00E_eFo@030005E_d00`00E_eFo@030004E_d01000E_d000000UKm00<005KmE_d00UKm00H005Km
000005Km0004E_d40002E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@03E_d20004E_d00`00E_eF
o@030005E_d01P00E_d00000E_d000AFo@03001Fo@0000800003E_d005Km00=Fo@06001Fo@00001F
o@001EKm0`000UKm00<005KmE_d00UKm0P001EKm00<005KmE_d00`0015Km00@005KmE_eFo@<000=o
o`03001oogoo0<aoo`00ogoohGoo0`003goo0P000UKm00<005KmE_d00UKm0`000UKm00<005KmE_d0
0eKm0`000UKm00<005KmE_d00UKm0P001EKm00<005KmE_d00`0015Km00@005Km0000009Fo@03001F
oEKm009Fo@06001Fo@00001Fo@0015Km00<005Km00000P0000=Fo@00E_d00eKm0`000UKm00<005Km
E_d00eKm0P0015Km00<005KmE_d00`001EKm00<005KmE_d00`0015Km00<005Km00000P0000=Fo@00
E_d00UKm0P0000EFo@00001Fo@0000EFo@<0009Fo@03001FoEKm009Fo@@0009Fo@03001oogoo009o
o`03001oogoo0<]oo`00ogoogWoo0`003goo0`001EKm00H005Km000005Km0004E_d00`00E_d00002
00000eKm001Fo@03E_d01P00E_d00000E_d000EFo@<0009Fo@03001FoEKm009Fo@8000EFo@03001F
oEKm00<000AFo@03001FoEKm00<000EFo@06001Fo@00001Fo@0015Km00<005Km00000P0000=Fo@00
E_d00eKm0`000UKm00<005KmE_d00eKm0`000UKm00<005KmE_d00UKm0P001EKm00<005KmE_d00`00
15Km00<005Km00000P0000=Fo@00E_d00eKm00H005Km000005Km0005E_d01@00Oomoogoo0000cGoo
003oOooLOol2000?Ool30003E_d00`00E_eFo@02E_d20004E_d00`00E_eFo@030005E_d00`00E_eF
o@030004E_d00`00E_d0000200000eKm001Fo@03E_d01P00E_d00000E_d000EFo@<0009Fo@03001F
oEKm009Fo@<000=Fo@03001FoEKm009Fo@8000AFo@03001FoEKm00<000EFo@06001Fo@00001Fo@00
15Km00<005Km00000P0000=Fo@00E_d00eKm00H005Km000005Km0005E_d400000eKm001Fo@03E_d2
0005E_d00`00E_eFo@030004E_d01000E_eFoEKm0`000goo00<007ooOol0bWoo003oOooIOol3000?
Ool200000eKm001Fo@04E_d01P00E_d00000E_d000AFo@<000=Fo@03001FoEKm009Fo@<0009Fo@03
001FoEKm009Fo@8000EFo@03001FoEKm00<000AFo@03001Fo@0000800003E_d005Km00=Fo@06001F
o@00001Fo@001EKm00H005Km000005Km0004E_d30003E_d00`00E_eFo@02E_d20004E_d00`00E_eF
o@030005E_d00`00E_eFo@030004E_d00`00E_d00002000015Km001Fo@000UKm00H005Km000005Km
0005E_d30002E_d00`00E_eFo@02E_d40002E_d01000Oomoogoo0P00bgoo003oOooGOol2000@Ool2
0004E_d01000E_eFoEKm0`0015Km00H005Km000005Km0005E_d01P00E_d00000E_d000AFo@04001F
o@000002E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d20005E_d00`00E_eFo@030004E_d0
1000E_eFoEKm0`0015Km00H005Km000005Km0005E_d01P00E_d00000E_d000AFo@<0009Fo@03001F
oEKm00=Fo@<0009Fo@03001FoEKm009Fo@8000EFo@800004E_d000000004E_d00`00E_d000020000
0eKm001Fo@03E_d01P00E_d00000E_d000EFo@05001oo`00Ool0003;Ool00?moomAoo`<0011oo`80
0003E_d005Km00=Fo@@0009Fo@03001FoEKm009Fo@8000AFo@04001FoEKmE_d30004E_d00`00E_eF
o@030005E_d01P00E_d00000E_d000AFo@06001Fo@00001Fo@001EKm0`000UKm00<005KmE_d00UKm
10000UKm00<005KmE_d00UKm0P0015Km00@005KmE_eFo@<000AFo@06001Fo@00001Fo@0015Km00<0
05Km00000P0000=Fo@00E_d00eKm00H005Km000005Km0005E_d30002E_d00`00E_eFo@02E_d20005
E_d00`00E_eFo@030004E_d01000E_eFoEKm0`000goo00<007ooOol0b7oo003oOooBOol2000@Ool3
0004E_d01000E_d000000UKm00<005KmE_d00UKm00H005Km000005Km0004E_d40002E_d00`00E_eF
o@02E_d30002E_d00`00E_eFo@03E_d20004E_d00`00E_eFo@030004E_d00`00E_d0000200000eKm
001Fo@03E_d01P00E_d00000E_d000EFo@06001Fo@00001Fo@0015Km10000UKm00<005KmE_d00UKm
0P0015Km00<005KmE_d00`001EKm00<005KmE_d00`0015Km00<005Km00000P0000=Fo@0000000eKm
00H005Km000005Km0005E_d30002E_d00`00E_eFo@02E_d40002E_d00`00Oomoo`02Ool00`00Oomo
o`37Ool00?moolmoo`<000moo`<0009Fo@03001FoEKm009Fo@8000EFo@03001FoEKm00<000AFo@04
001Fo@000002E_d00`00E_eFo@02E_d01P00E_d00000E_d000AFo@03001Fo@0000800003E_d005Km
00=Fo@<0009Fo@03001FoEKm009Fo@8000EFo@03001FoEKm00<000AFo@04001FoEKmE_d30004E_d0
1P00E_d00000E_d000EFo@06001Fo@00001Fo@0015Km0`000eKm00<005KmE_d00UKm0`000UKm00<0
05KmE_d00UKm0P001EKm00<005KmE_d00`0015Km00<005Km00000P0000=Fo@00E_d00eKm00H005Km
000005Km0005E_d01@00Oomoogoo0000bGoo003oOoo=Ool2000?Ool300000eKm001Fo@03E_d01P00
E_d00000E_d000EFo@<0009Fo@03001FoEKm009Fo@8000EFo@03001FoEKm00<000AFo@03001FoEKm
00<000EFo@06001Fo@00001Fo@0015Km00@005Km0000009Fo@03001FoEKm009Fo@<0009Fo@03001F
oEKm009Fo@@0009Fo@03001FoEKm009Fo@8000AFo@04001FoEKmE_d30004E_d01P00E_d00000E_d0
00EFo@06001Fo@00001Fo@0015Km00H005Km000005Km0005E_d30002E_d00`00E_eFo@02E_d20005
E_d00`00E_eFo@030004E_d01000E_eFoEKm0`000goo00<007ooOol0aWoo003oOoo:Ool3000>Ool3
0005E_d00`00E_eFo@030004E_d00`00E_d0000200000eKm001Fo@03E_d01P00E_d00000E_d000EF
o@<0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm009Fo@8000AFo@03001FoEKm00<000EFo@06
001Fo@00001Fo@0015Km00@005Km0000009Fo@03001FoEKm009Fo@06001Fo@00001Fo@0015Km1000
0UKm00<005KmE_d00UKm0P0015Km00@005KmE_eFo@<000AFo@03001FoEKm00<000AFo@03001Fo@00
00@000AFo@06001Fo@00001Fo@001EKm0`000UKm00<005KmE_d00UKm10000UKm00<007ooOol00Woo
00<007ooOol0aGoo003oOoo7Ool3000>Ool30003E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@02
E_d20005E_d00`00E_eFo@030004E_d00`00E_d0000200000eKm001Fo@03E_d01P00E_d00000E_d0
00EFo@06001Fo@00001Fo@0015Km0`000UKm00<005KmE_d00eKm0P0015Km00<005KmE_d00`001EKm
00<005KmE_d00`0015Km00H005Km000005Km0005E_d01P00E_d00000E_d000AFo@@0009Fo@03001F
oEKm009Fo@<0009Fo@03001FoEKm009Fo@8000=Fo@03001Fo@00009Fo@<000AFo@03001Fo@000080
0003E_d005Km00=Fo@06001Fo@00001Fo@001EKm00D007ooOomoo`000<Moo`00ogooaGoo0P003goo
0P000UKm00<005KmE_d00UKm00H005Km000005Km0004E_d01000E_d000000UKm00<005KmE_d00UKm
0`000UKm00<005KmE_d00UKm0P001EKm00<005KmE_d00`0015Km00@005KmE_eFo@<000AFo@06001F
o@00001Fo@0015Km00<005Km00000P0000=Fo@00E_d00eKm0`000UKm00<005KmE_d00eKm0`000UKm
00<005KmE_d00UKm0P0015Km00@005KmE_eFo@<000AFo@06001Fo@00001Fo@001EKm00H005Km0000
05Km0004E_d01P00E_d00000E_d000=Fo@03001Fo@000080009Fo@03001FoEKm009Fo@8000EFo@03
001FoEKm00<000AFo@03001FoEKm00<000Aoo`03001oogoo0<Aoo`00ogoo`Woo10003Woo0P001EKm
00<005KmE_d00`0015Km00<005KmE_d00`001EKm00H005Km000005Km0004E_d01000E_d000000UKm
00<005KmE_d00UKm0`000UKm00<005KmE_d00UKm10000UKm00<005KmE_d00UKm0P0015Km00<005Km
E_d00`001EKm00H005Km000005Km0004E_d00`00E_d0000200000eKm001Fo@03E_d01P00E_d00000
E_d000AFo@@0009Fo@03001FoEKm009Fo@8000AFo@04001FoEKmE_d30004E_d00`00E_eFo@030004
E_d00`00E_d0000200000eKm001Fo@03E_d01P00E_d00000E_d000EFo@<0009Fo@03001FoEKm009F
o@<0009Fo@03001oogoo009oo`03001oogoo0<Aoo`00ogoo`7oo0P0017oo00<007ooOol02Goo0P00
00=Fo@00E_d015Km0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00UKm0P0015Km00<005Km
E_d00`001EKm00H005Km000005Km0004E_d01000E_d000000UKm00<005KmE_d00UKm00H005Km0000
05Km0004E_d30003E_d00`00E_eFo@02E_d20004E_d00`00E_eFo@030005E_d00`00E_eFo@030004
E_d01000E_d000000UKm00<005KmE_d00UKm00H005Km000005Km0004E_d40002E_d00`00E_eFo@02
E_d30002E_d00`00E_eFo@02E_d200000eKm001Fo@02E_d00`00E_eFo@030004E_d00`00E_d00002
00000eKm001Fo@03E_d01P00E_d00000E_d000AFo@03001oogoo009oo`03001oogoo0<=oo`00ogoo
_Goo0`001goo00<007ooOol01Goo0`0015Km00<005Km00000P0000=Fo@00E_d00eKm00H005Km0000
05Km0005E_d01P00E_d00000E_d000AFo@<0009Fo@03001FoEKm00=Fo@8000AFo@03001FoEKm00<0
00EFo@03001FoEKm00<000AFo@06001Fo@00001Fo@001EKm00H005Km000005Km0004E_d30002E_d0
0`00E_eFo@03E_d30002E_d00`00E_eFo@02E_d20005E_d00`00E_eFo@030004E_d01P00E_d00000
E_d000EFo@06001Fo@00001Fo@0015Km00P005Km000005Km001Fo@000eKm0`000UKm00<005KmE_d0
0UKm0P001EKm00<005KmE_d00`0015Km00<005KmE_d00`0017oo00<007ooOol0`Woo003oOonkOol2
000?Ool30002E_d00`00E_eFo@02E_d20005E_d00`00E_eFo@030004E_d01000E_eFoEKm0`0015Km
00H005Km000005Km0004E_d00`00E_d0000200000eKm001Fo@03E_d30002E_d00`00E_eFo@03E_d3
0003E_d00`00E_eFo@030004E_d01000E_eFoEKm0`0015Km00H005Km000005Km0004E_d00`00E_d0
000200000eKm001Fo@03E_d01P00E_d00000E_d000EFo@<0009Fo@03001FoEKm009Fo@8000AFo@04
001FoEKmE_d30004E_d00`00E_eFo@030004E_d500000eKm001Fo@03E_d01P00E_d00000E_d000EF
o@<0009Fo@03001FoEKm009Fo@<000=Fo@05001oogooOol00034Ool00?mookQoo`<000moo`800003
E_d005Km00=Fo@04001Fo@000002E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d40003E_d0
0`00E_eFo@030004E_d00`00E_eFo@030005E_d01P00E_d00000E_d000AFo@03001Fo@0000800003
E_d005Km00=Fo@<0009Fo@03001FoEKm009Fo@@0009Fo@03001FoEKm009Fo@8000AFo@03001FoEKm
00<000EFo@03001FoEKm00<000AFo@03001Fo@0000800003E_d005Km00=Fo@06001Fo@00001Fo@00
15Km10000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`001EKm00<005KmE_d00`0015Km00<0
05Km00000P0000=Fo@00E_d00eKm00H005Km000005Km0004E_d20003Ool00`00Oomoo`31Ool00?mo
okIoo`8000moo`<000AFo@03001FoEKm00<000EFo@06001Fo@00001Fo@0015Km00@005Km0000009F
o@03001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm009Fo@8000AFo@03001F
oEKm00<000EFo@06001Fo@00001Fo@0015Km00@005Km0000009Fo@03001FoEKm009Fo@06001Fo@00
001Fo@0015Km0`000eKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`001EKm00<005KmE_d00`00
15Km00H005Km000005Km0005E_d01P00E_d00000E_d000AFo@<0009Fo@03001FoEKm00=Fo@<0009F
o@03001FoEKm009Fo@8000EFo@03001FoEKm00<000AFo@06001Fo@00001Fo@0017oo00<007ooOol0
`7oo003oOoncOol3000>Ool30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@02E_d20004E_d0
0`00E_eFo@030005E_d01P00E_d00000E_d000AFo@04001Fo@000002E_d00`00E_eFo@02E_d01P00
E_d00000E_d000AFo@<000=Fo@03001FoEKm009Fo@8000AFo@03001FoEKm00<000EFo@03001FoEKm
00<000AFo@06001Fo@00001Fo@001EKm00H005Km000005Km0004E_d30002E_d00`00E_eFo@03E_d3
0002E_d00`00E_eFo@02E_d20004E_d01000E_eFoEKm0`0015Km00H005Km000005Km0003E_d20000
1UKm00000000E_d000AFo@06001Fo@00001Fo@001EKm0`000UKm00<005KmE_d00UKm0P0015Km00D0
07ooOomoo`000<9oo`00ogoo/7oo0`003goo0P0000=Fo@00E_d00eKm00@005Km0000009Fo@03001F
oEKm009Fo@06001Fo@00001Fo@0015Km0`000eKm00<005KmE_d00UKm0P0015Km00<005KmE_d00`00
1EKm00<005KmE_d00`0015Km00H005Km000005Km0005E_d01P00E_d00000E_d000AFo@<0009Fo@03
001FoEKm00=Fo@<0009Fo@03001FoEKm009Fo@8000AFo@04001FoEKmE_d30004E_d01P00E_d00000
E_d000AFo@03001Fo@0000800003E_d005Km00=Fo@06001Fo@00001Fo@0015Km10000UKm00<005Km
E_d00UKm0P0015Km00<005KmE_d00`001EKm00<005KmE_d00`0015Km00<005Km00000P0000=Fo@00
E_d00eKm00H005Km000005Km0004E_d20003Ool00`00Oomoo`2oOol00?moojioo`80011oo`8000AF
o@03001FoEKm00<000EFo@03001FoEKm00<000AFo@06001Fo@00001Fo@001EKm00H005Km000005Km
0004E_d30002E_d00`00E_eFo@03E_d30002E_d00`00E_eFo@02E_d20004E_d01000E_eFoEKm0`00
15Km00H005Km000005Km0004E_d00`00E_d0000200000eKm001Fo@03E_d01P00E_d00000E_d000AF
o@@0009Fo@03001FoEKm009Fo@8000AFo@03001FoEKm00<000EFo@03001FoEKm00<000AFo@06001F
o@00001Fo@001EKm00H005Km000005Km0004E_d400000eKm001Fo@04E_d30002E_d00`00E_eFo@02
E_d20005E_d00`00E_eFo@030004E_d01P00E_d00000E_d000Aoo`03001oogoo0;ioo`00ogooZgoo
0`0047oo0P0000=Fo@00E_d00eKm0`000UKm00<005KmE_d00eKm0`000UKm00<005KmE_d00UKm0P00
15Km00@005KmE_eFo@<000AFo@06001Fo@00001Fo@0015Km00<005Km00000P0000=Fo@00E_d00eKm
00H005Km000005Km0004E_d40002E_d00`00E_eFo@02E_d20004E_d00`00E_eFo@030005E_d00`00
E_eFo@030004E_d01P00E_d00000E_d000EFo@06001Fo@00001Fo@0015Km0`000UKm00<005KmE_d0
0eKm0`000UKm00<005KmE_d00UKm0P0015Km00@005KmE_eFo@<000AFo@08001Fo@00001Fo@00E_d0
009Fo@03001Fo@0000800003E_d005Km00=Fo@06001Fo@00001Fo@001EKm0`000UKm00<005KmE_d0
0UKm0P0015Km00D007ooOomoo`000<1oo`00ogooZGoo0P0047oo0`0015Km00H005Km000005Km0004
E_d00`00E_d0000200000eKm001Fo@03E_d01P00E_d00000E_d000AFo@@0009Fo@03001FoEKm009F
o@8000AFo@03001FoEKm00<000EFo@03001FoEKm00<000AFo@04001Fo@000002E_d00`00E_eFo@02
E_d01P00E_d00000E_d000AFo@<000=Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00<000AFo@04
001FoEKmE_d30004E_d01P00E_d00000E_d000AFo@03001Fo@0000800003E_d005Km00=Fo@06001F
o@00001Fo@0015Km10000UKm00<005KmE_d00UKm0P0015Km0P0000AFo@00000000EFo@03001FoEKm
00<000AFo@03001Fo@0000800003E_d005Km00=Fo@06001Fo@00001Fo@0015Km0P000goo00<007oo
Ool0_Goo003oOonVOol3000>Ool40002E_d00`00E_eFo@02E_d20004E_d00`00E_eFo@030005E_d0
0`00E_eFo@030004E_d01000E_d000000UKm00<005KmE_d00UKm00H005Km000005Km0004E_d30003
E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@030005E_d00`00E_eFo@030004E_d01P00E_d00000
E_d000EFo@06001Fo@00001Fo@0015Km0`000UKm00<005KmE_d00UKm10000UKm00<005KmE_d00UKm
0P0015Km00<005KmE_d00`001EKm00<005KmE_d00`0015Km00H005Km000005Km0005E_d01P00E_d0
0000E_d000AFo@<0009Fo@03001FoEKm00=Fo@<000=Fo@03001FoEKm00<000EFo@03001FoEKm00<0
00AFo@06001Fo@00001Fo@0017oo00<007ooOol0_7oo003oOonTOol2000?Ool20002E_d00`00E_eF
o@02E_d01P00E_d00000E_d000AFo@<000=Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00<000EF
o@03001FoEKm00<000AFo@06001Fo@00001Fo@001EKm00H005Km000005Km0004E_d30002E_d00`00
E_eFo@03E_d30002E_d00`00E_eFo@02E_d20004E_d01000E_eFoEKm0`0015Km00H005Km000005Km
0004E_d01000E_d000000UKm00<005KmE_d00UKm00H005Km000005Km0004E_d30003E_d00`00E_eF
o@02E_d30003E_d00`00E_eFo@030004E_d01000E_eFoEKm0`0015Km00D005Km000005Km008000=F
o@03001Fo@0000800003E_d005Km00=Fo@<0009Fo@03001FoEKm009Fo@@0009Fo@03001FoEKm009F
o@8000AFo@05001oogooOol0002nOol00?mooj5oo`<000ioo`<000EFo@03001FoEKm00<000AFo@04
001Fo@000002E_d00`00E_eFo@02E_d01P00E_d00000E_d000AFo@<000=Fo@03001FoEKm009Fo@<0
009Fo@03001FoEKm009Fo@8000AFo@04001FoEKmE_d30004E_d01P00E_d00000E_d000AFo@03001F
o@0000800003E_d005Km00=Fo@06001Fo@00001Fo@0015Km10000UKm00<005KmE_d00UKm0P0015Km
00<005KmE_d00`001EKm00<005KmE_d00`0015Km00H005Km000005Km0005E_d01P00E_d00000E_d0
00AFo@<0009Fo@03001FoEKm009Fo@@0009Fo@03001FoEKm009Fo@8000AFo@03001FoEKm00<000EF
o@06001Fo@00001Fo@0015Km00H005Km000005Km0005E_d01P00E_d00000E_d000AFo@8000=oo`03
001oogoo0;]oo`00ogooWWoo0`003Woo0`000eLM00<005KmE_d00UKm0`000UKm00<005KmE_d00UKm
0P001EKm00<005KmE_d00`0015Km00H005Km000005Km0005E_d01P00E_d00000E_d000AFo@06001F
o@00001Fo@0015Km10000UKm00<005KmE_d00UKm0P0015Km00<005KmE_d00`001EKm00<005KmE_d0
0`0015Km00H005Km000005Km0005E_d01P00E_d00000E_d000AFo@<0009Fo@03001FoEKm00=Fo@<0
009Fo@03001FoEKm009Fo@8000AFo@04001FoEKmE_d30004E_d01P00E_d00000E_d000AFo@04001F
o@000002E_d00`00E_eFo@02E_d01P00E_d00000E_d000AFo@<0009Fo@03001FoEKm00=Fo@8000AF
o@03001FoEKm00<000AFo@04001FoEKmE_d30004E_d01P00E_d00000E_d000Aoo`03001oogoo0;Yo
o`00ogooW7oo0P003goo0P000U;m00<005LMEad00ULM00H005Km000005Km0004E_d01000E_d00000
0UKm00<005KmE_d00UKm0`000UKm00<005KmE_d00UKm0P0015Km00@005KmE_eFo@<000AFo@03001F
oEKm00<000AFo@04001Fo@000002E_d00`00E_eFo@02E_d01P00E_d00000E_d000AFo@<000=Fo@03
001FoEKm009Fo@<000=Fo@03001FoEKm00<000AFo@04001FoEKmE_d30004E_d01P00E_d00000E_d0
00AFo@03001Fo@0000800003E_d005Km00=Fo@06001Fo@00001Fo@0015Km10000UKm00<005KmE_d0
0UKm0P0015Km00<005KmE_d00`001EKm00<005KmE_d00`0015Km00<005Km00000`0015Km00<005Km
00000P0000=Fo@00E_d00eKm0`000UKm00<005KmE_d00UKm10000eKm00<005KmE_d00`0015Km00D0
07ooOomoo`000;aoo`00ogooVGoo10003Goo0`001E;m00<005LMEad00`0015Km00<005KmE_d01000
15Km00H005Km000005Km0004E_d01P00E_d00000E_d000AFo@@0009Fo@03001FoEKm009Fo@<000=F
o@03001FoEKm00<000EFo@03001FoEKm00<000AFo@06001Fo@00001Fo@001EKm00H005Km000005Km
0004E_d30002E_d00`00E_eFo@02E_d40002E_d00`00E_eFo@02E_d20004E_d00`00E_eFo@030005
E_d00`00E_eFo@030004E_d01P00E_d00000E_d000EFo@06001Fo@00001Fo@0015Km0`000UKm00<0
05KmE_d00eKm0`000eKm00<005KmE_d00`000UKm00<005Km00000UKm0`001EKm00H005Km000005Km
0004E_d01P00E_d00000E_d000EFo@<0009Fo@03001FoEKm009Fo@8000=oo`03001oogoo0;Uoo`00
ogooUgoo0P0017oo00<007ooOol01Woo10000dZl00<005;mD_d00U;m0`000UKm00<005KmE_d00UKm
0`0015Km00<005KmE_d00`0015Km00<005KmE_d00`0015Km00@005Km0000009Fo@03001FoEKm009F
o@06001Fo@00001Fo@0015Km0`000eKm00<005KmE_d00UKm0`000UKm00<005KmE_d00UKm0P0015Km
00@005KmE_eFo@<000AFo@06001Fo@00001Fo@0015Km00@005Km0000009Fo@03001FoEKm009Fo@06
001Fo@00001Fo@0015Km0`000UKm00<005KmE_d00eKm0`000eKm00<005KmE_d00`0015Km00@005Km
E_eFo@<000AFo@06001Fo@00001Fo@0015Km00<005Km00000P0000=Fo@00E_d00eKm0`000UKm00D0
05KmE_d005Km00<0009Fo@03001FoEKm00=Fo@8000AFo@03001FoEKm00<000AFo@03001Fo@000080
0003E_d005Km00=Fo@06001Fo@00001Fo@0017oo00<007ooOol0^7oo003oOonDOol30007Ool01000
Oomoogoo10000dYk00<004ZlB[`00TZl00H005;m000005Km0004E_d01P00E_d00000E_d000EFo@<0
009Fo@03001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@8000EFo@03001FoEKm00<000AFo@06001F
o@00001Fo@001EKm00H005Km000005Km0004E_d01P00E_d00000E_d000AFo@@0009Fo@03001FoEKm
009Fo@8000AFo@03001FoEKm00<000EFo@03001FoEKm00<000AFo@06001Fo@00001Fo@0015Km00<0
05Km00000P0000=Fo@00E_d00eKm0`000UKm00<005KmE_d00UKm10000UKm00<005KmE_d00UKm0P00
15Km00<005KmE_d00`001EKm00H005Km000005Km0004E_d01P00E_d00000E_d000AFo@03001Fo@00
00800003E_d005Km00=Fo@<0009Fo@03001FoEKm009Fo@8000EFo@03001FoEKm00<000AFo@05001o
ogooOol0002jOol00?mooi9oo`8000Yoo`@0009>NP03001:NdYk00=:N`03001:_4Zl00<000AFo@03
001FoEKm00<000AFo@03001Fo@0000800003E_d005Km00=Fo@06001Fo@00001Fo@0015Km00@005Km
0000009Fo@03001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@8000AFo@04001FoEKmE_d30004E_d0
0`00E_eFo@030004E_d01000E_d000000UKm00<005KmE_d00UKm00H005Km000005Km0004E_d30002
E_d00`00E_eFo@03E_d30003E_d00`00E_eFo@030004E_d00`00E_eFo@030005E_d01P00E_d00000
E_d000AFo@06001Fo@00001Fo@001EKm00H005Km000005Km0004E_d30002E_d00`00E_eFo@03E_d2
0004E_d00`00E_eFo@040003E_d00`00E_eFo@030005E_d01P00E_d00000E_d000AFo@06001Fo@00
001Fo@001EKm0`000UKm00<005KmE_d00UKm0P000goo00<007ooOol0]goo003oOon?Ool30009Ool3
0002CWT00`00CWY>NP02CWX00`00BW]:N`02BW/30002E_`00`00E_eFo@02E_d30002E_d00`00E_eF
o@02E_d20005E_d00`00E_eFo@030004E_d00`00E_eFo@040004E_d01P00E_d00000E_d000AFo@06
001Fo@00001Fo@0015Km10000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`001EKm00<005Km
E_d00`0015Km00H005Km000005Km0004E_d00`00E_d0000200000eKm001Fo@03E_d30002E_d00`00
E_eFo@02E_d30003E_d00`00E_eFo@02E_d20004E_d00`00E_eFo@030004E_d01000E_eFoEKm0`00
15Km00H005Km000005Km0004E_d00`00E_d0000200000eKm001Fo@03E_d30002E_d20003E_d30003
E_d01000E_eFoEKm0`0015Km00<005KmE_d00`0015Km00<005Km00000P0000=Fo@00E_d00eKm00H0
05Km000005Km0004Ool00`00Oomoo`2fOol00?mooheoo`8000Yoo`800003CUT004ii00=>N@03001>
NTij009>NP06001:N`00001Fg00015Kl00H005Km000005Km0004E_d01000E_d000000UKm00<005Km
E_d00UKm0`000UKm00<005KmE_d00UKm0`0015Km00<005KmE_d00`0015Km00<005KmE_d00`0015Km
00@005Km0000009Fo@03001FoEKm009Fo@06001Fo@00001G7@0015Km0`000eKm00<005KmE_d00UKm
0`000UKm00<005KmE_d00UKm0P0015Km00<005KmE_d00`001EKm00H005Km000005Km0004E_d01P00
E_d00000E_d000EFo@06001Fo@00001Fo@0015Km0`000UKm00<005KmE_d00UKm10000eKm00<005Km
E_d00`0015Km00<005KmE_d00`001EKm00H005Km000005Km0004E_d01P00E_d00000E_d000AFo@@0
009Fo@03001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@8000EFo@03001FoEKm00<000AFo@03001o
ogoo00800;Qoo`00ogooRWoo0`002Goo0`0014iI00<004iiCWT00Tii00@004ijCWY>NP8000AFg003
001Fo5Kl00<000AFo@03001FoEKm00@000AFo@06001Fo@00001Fo@0015Km00H005Km000005LM0005
E_d30002E_d00`00E_eFo@02E_d30003Ead00`00E_eFo@030005E_d00`00E_eFo@030004Ead01P00
E_d00000E_d000EFo@06001Fo@00001Fo@0015Km00H005Km000005Km0004E_d30003E_d00`00E_eF
o@02E_d20004E_d00`00E_eFo@030004E_d01000E_eFoEKm0`0015Km00H005Km000005Km0004E_d0
1P00E_d00000E_d000EFo@<0009Fo@03001FoEKm009Fo@<000=Fo@04001FoEKmE_d30004E_d00`00
E_eFo@030004E_d01P00E_d00000E_d000EFo@06001Fo@00001Fo@0015Km00H005Km000005Km0004
E_d40002E_d00`00E_eFo@02E_d30002Ool00`00Oomoo`2eOol00?moohMoo`<000Qoo`@0009>F@03
001>FDiI00=>F@06001>NDiiCWT004ij0P0000=Fg000E]`00eKL0`000ULM00<005KmE_d00UKm0`00
15Km00<005KmE_d00`0015Km00<005KmE_d00`0015LM00<005Km00000P0000=Fo@00E_d00eKm00H0
05Km000005LM0004Ead30003E_d00`00E_eFo@02E_d30003Ead00`00EaeG7@030004E_d01000E_eF
oEKm0`0015Km00<005KmE_d00`0015Km00H005Km000005LM0005E_d01P00E_d00000E_d000AFo@<0
009Fo@03001FoEKm009Fo@@000=Fo@03001FoEKm00<000AFo@03001FoEKm00<000AFo@03001Fo@00
00800003E_d005Km00=Fo@06001Fo@00001Fo@0015Km10000UKm00<005KmE_d00UKm0`0000=Fo@00
000015Km0P0015Km00@005KmE_eFo@<000AFo@03001FoEKm00<000AFo@06001Fo@00001Fo@001EKm
00H005Km000005Km0003Ool00`00Oomoo`2eOol00?moohEoo`8000Qoo`<0009:>003001>FDiI009>
F@03001>FDiI009>F@03001>NDii00<000AFg006001Fg000001G7@0015LM00@005Km0000009Fo@03
001FoEKm009Fo@<0009Fo@03001FoEKm009Fo@<000=G7@03001G7ELM00<000EFo@03001FoEKm00<0
00AG7@04001G7@000002D_`00`00E_eFo@02E_d01P00E_d00000Ech000AG7@<0009Bo003001FoEKm
009Fo@@0009G7@03001FoEKm009Fo@<000=Fo@03001FoEKm00<000AG7@04001FoEKmE_d30004E_d0
1P00E_d00000E_d000AFo@04001Fo@000002E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d3
0002E_d00`00E_eFo@02E_d20005E_d00`00E_eFo@030004E_d01P00E_d00000E_d000EFo@06001F
o@00001Fo@000UKm00@005Km001Fo@800003E_d005Km00=Fo@@0009Fo@03001FoEKm009Fo@<000=F
o@03001FoEKm00<000AFo@04001FoEKmE_d30004E_d01@00Oomoogoo0000]Woo003oOon2Ool30008
Ool200000e9H001:>003BSP00`00CUU>F@02CUT01000CUU>FDiI0`000UKL00<005KLE]`00UKL0P00
15LM00<005LMEad00`001EKm00H005Km000005Km0004E_d01P00E_d00000Ead000AG7@<000=Bo003
001FoEKm009Fo@<000=G?P03001G7ELM00<000EBo003001FoEKm00<000AG?P06001G7@00001Bg000
15;l00@005Km0000009G7@03001G7ELM009G7@06001Fo@00001Fo@0015Km0`000ULM00<005LMEad0
0ULM10000eKm00<005KmE_d00`0015Km00<005KmE_d00`001EKm00H005Km000005Km0004E_d01P00
E_d00000E_d000AFo@04001Fo@000002E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d20004
E_d01000E_eFoEKm0`0015Km00<005Km00000`0015Km00H005Km000005Km0005E_d01P00E_d00000
E_d000AFo@<0009Fo@03001FoEKm009Fo@@000=Fo@03001FoEKm00<000=oo`03001oogoo0;=oo`00
ogooP7oo0P002Woo00<0059HDUP00U9H00<004XhBSP00TXh00H004iICUU>F@00CUT200000eKL001F
g003E]`01P00E]`00000Ead000AG7@<000=G7@03001FoEKm009Fo@8000AFo@03001FoEKm00<000AG
7@04001G7@000002D]`00`00D_aBo002D_`01P00E_d00000Ech000AG?P<0009Bg003001Bo5;l00=B
o0<000=G?P03001G?ULn00<000ABg003001Bo5;l00<000EG7@03001G7ELM00<000AFo@06001Fo@00
001G?P0015LM00@005LM0000009Bo003001FoEKm009Fo@<0009G7@03001FoEKm009Fo@<0009Fo@03
001FoEKm00=Fo@8000AFo@03001FoEKm00<000AFo@03001FoEKm00<000EFo@06001Fo@00001Fo@00
15Km00H005Km000005Km0004E_d40002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@030004E_d0
1000E_eFoEKm0`0015Km00H005Km000005Km0004E_d01P00E_d00000E_d000EFo@<0009Fo@05001o
ogooOol0002eOol00?moogeoo`<000]oo`8000ABF003001:>4Xh009:>003001>FDiI00<000AFg003
001Fg5KL00<000AG7@04001G7@000002Ead00`00EaeG7@02Ead01P00E_d00000E_d000AFo@<000=G
7@03001G7ELM00<000EBg003001Bo5;l00<000AG?P06001G?P00001Bg00015;L00<005;l00000P00
00=Ff`00Ech00eLn0`000U;L00<005;LD]`00U;L0`000eKK00@005LMEaeG7@@0009Bo@03001FoEKm
009Fo@8000AG?P03001G7ELM00<000EBo006001Fo@00001G7@0015LM00H005Km000005Km0004E_d0
0`00E_d0000200000eKm001Fo@03E_d30002E_d00`00E_eFo@02E_d30003E_d01000E_eFoEKm0`00
15Km00<005KmE_d00`0015Km00H005Km000005Km0005E_d01@00E_d00000E_d00P000eKm0`000UKm
00<005KmE_d00UKm10000UKm00<005KmE_d00UKm0P0015Km00<005KmE_d00`0015Km00<005Km0000
0P0000=Fo@00E_d00eKm00D007ooOomoo`000;Aoo`00ogooNgoo0P003Goo00@006KiI_T000ABF004
001:>4XhBSP30002E]`00`00E]aFg002E]`30003Ead00`00EaeG7@040004Ead00`00EaeG7@030004
E_d01P00E_d00000Ech000AG7@<000=Bg003001Bg5;L009Bg0<000=Ff`03001G?ULn00<000ABg003
001Bg5;L00<000EFf`06001G?P00001Fg00015;L00H005;L0000059i0004E]/40002E]`00`00D_eB
o@02D_d01000E_d000000ULn00<005LnEch010000U;L00<005;lD_`00e;l0P0015LM00<005LMEad0
0`0015Km00<005KmE_d00`001EKm00H005Km000005Km0004E_d01P00E_d00000E_d000AFo@@0009F
o@03001FoEKm009Fo@<000=Fo@03001FoEKm00<000AFo@04001FoEKmE_d30004E_d01P00E_d00000
E_d000AFo@06001Fo@00001Fo@001EKm100000=Fo@00E_d00eKm0`000UKm00<005KmE_d00UKm0P00
1EKm00<005KmE_d00`000goo00<007ooOol0/Goo003oOomhOol3000>Ool00`00I_UVn@02I_T01P00
DUQBF59H001:>0800003E]/005KL00=Fg006001Fg000001G?@0015LM0`0015LM00<005LMEad01000
0e;l00<005KmE_d00`0015Ln00@005LM0000009Bg003001Bg5;L009Bg006001Bg000001BN@0015KK
0`000UKL00<005;LD]`00U;L0`000e9i00<005KKE]/00UKK0P0015KL00<005;LD]`00`00159i00H0
05KKE]/005Zi0005E]`00`00D_eBo@030004Ech30002D]`00`00D]aBg002D]`00`00D_`000020000
0eKK001G7@03Ead30002D_d00`00E_eFo@02E_d30003Ead01000E_eFoEKm0`0015Km00<005KmE_d0
0`0015Km00H005Km000005Km0005E_d01P00E_d00000E_d000AFo@<0009Fo@03001FoEKm009Fo@@0
009Fo@03001FoEKm009Fo@8000AFo@03001FoEKm00<000AFo@03001FoEKm00<000EFo@06001Fo@00
001Fo@0015Km00H005Km000005Km0004E_d40002E_d01@00Oomoogoo0000/goo003oOomfOol2000@
Ool00`00I_UVn@03I_T00`00DUQBF0030004E]/01000E]aFg5KL0P0015Lm00@005LM0000009G7@03
001G7ELM009G7@<0009Bg003001Bo5;l009Bo0<000=G?P03001G?ULn00<000EBg003001Bg5;L00<0
00ABN@06001FfeKK001J^@0015KL00H005;L000004hh0005DWT01P00E]/00000F[T000AFg0<0009>
>003001BNE9i009BN@03001Ff`0000=J^@03001Fg5KL009Fg0<000=B^`06001G?P00001Fg00015;L
00<005;LD]`00`001EKK00H005LM000005KL0004D_d01P00E_d00000Ead000AG7@@0009Fo@03001F
oEKm009Fo@<0009Fo@03001FoEKm009Fo@8000AFo@04001FoEKmE_d30004E_d01P00E_d00000E_d0
00AFo@06001Fo@00001Fo@001EKm100000=Fo@00E_d00eKm0`000UKm00<005KmE_d00UKm0`000eKm
00@005KmE_eFo@<000AFo@03001FoEKm00<000AFo@06001Fo@00001Fo@001EKm00D007ooOomoo`00
0;9oo`00ogoo0goo1P003Woo1000F7oo0`004Goo00<007?K000016Ki0`000UKK00<005KKE]/00UKK
00@005KL0000009G?@03001G?ELm00@000AG7@06001G7@00001Bg00015;L00H005;l000005KK0004
Ech30003D]`00`00D]aBg002D]`30002DUT00`00DWUBN@02DWT00`00E]/00003F[T01000E]aFg5KL
0P0014hh00<0059iDWT00U9i0P0015Zi00H005KL0000058g0004CSP01000DWUBNE9i0P001EZi00H0
05KL0000059h0004D[/20004E]`00`00D]aBg0040003DWT00`00E]]Ff`02E]/20004E]`00`00D_eB
o@030004Ead01000Ead000000U;m00<005KmE_d00UKm00H005Km000005LM0004E_d01P00E_d00000
E_d000AFo@@0009Fo@03001FoEKm009Fo@8000AFo@03001FoEKm00<000AFo@03001FoEKm00<000AF
o@800005E_d00000E_d00004E_d01P00E_d00000E_d000AFo@@0009Fo@03001FoEKm009Fo@<000=F
o@03001FoEKm00<000AFo@04001FoEKmE_d30003Ool00`00Oomoo`2_Ool00?moo`5oo`X000Yoo`P0
05=oo`<000=oo`03001oogoo00eoo`06001cfg?KLm/006Ki0P0000=Fo@00E]/00eKK00<005KKE]/0
0`0015Lm0`0015Lm00<005LMEad00`0015;L00@005;LD]aBg08000AFf`04001G?P000002E]/00`00
D]aBg002D]`01P00D]`00000DUP000ABF@04001BNE9iDWT20004F[T01P00E]`00000DSL000E>>006
001BNE9i001JM`001EZi00<0058gDSL00U8g00D004hhCSQ>>000009BN@03001JN00000EJ^@8000AB
N006001B^e:k001JV@0015KL0`000Thh00<0059iDWT00e9i00H005KK000005Zi0004E]`30003D[/0
0`00EaeG7@030005D_d00`00E_eFo@030004Ead00`00E_eFo@030004E_d01P00E_d00000E_d000EF
o@06001Fo@00001Fo@0015Km0`000UKm00<005KmE_d00UKm0`000eKm00@005KmE_eFo@<000AFo@03
001FoEKm00<000AFo@06001Fo@00001Fo@001EKm00H005Km000005Km0004E_d30002E_d00`00E_eF
o@02E_d40002E_d01@00Oomoogoo0000/Goo003oOol1Ool30005Ool30009Ool20004Ool2001AOol2
0007Ool00`00Oomoo`0;Ool01000Lm]cfg?K0`0015Km00@005KKE]]Ff`<000=G?P04001G?@000002
Ech00`00EceG?@02Ecd30002D]`00`00D]aBg002D]`01P00D]`00000DWT000AFf`8000EFf`03001B
g5;L00<000ABF005001BFE9IDUT00002DWT00`00FWP00004F[T20004DSL00`00CSQ>>002CSP00`00
DWT00003FWL01000F[UJ^EZi0P00158g00L004hhCSQ>>000DWT00003FWP01`00F[UJ^EZi001NM`00
00ABN003001B^`0000=JV@06001Fg000001B=`0014hh00<0059iDWT00U9i0P0015Zi00H005KL0000
059i0004D[/30002E]`00`00D_eBo@03D_d30003Ead00`00EaeG7@040003E_d00`00E_eFo@030004
E_d01000E_eFoEKm0`0015Km00H005Km000005Km0004E_d01P00E_d00000E_d000AFo@D00003E_d0
05Km00=Fo@<000=Fo@03001FoEKm00<000AFo@04001FoEKmE_d30004E_d01P00E_d00000E_d000AF
o@06001Fo@00001Fo@001EKm00D007ooOomoo`000;1oo`00ogoo2Woo0P0027oo0P001Woo0P00CGoo
0`005Goo1P000ULn00<005KmE_d00UKm00H005KK000005Ln0004Ech30004Ech01P00Ecd00000D]`0
00ABg003001Bg5;L00<000ABN@04001Ff`000002F[T00`00E]]Ff`02E]/30002CSL00`00DUQBF002
DUP01`00DUUBFE9I001BN@0000=JN006001J^EZi001JM`001E8g00@004hhCSQ>>08000AJM`04001J
^EZi0002GWL01@00DSMB=e8g00000dhh0P001EYh00<005Zi00000eig00@0059hDWQBN08000EJV@03
001B=e8g009B=`03001>>4hh009>>006001BNE9i001JN00015Zi0P00159i00H005:kD[/005ZI0004
E]`00`00D_d0000200000e:K001G7@03Ead30002D_d00`00E_eFo@02E_d30002Ead00`00E_eFo@02
E_d40003E_d00`00E_eFo@030004E_d00`00E_eFo@030004E_d01P00E_d00000E_d0009Fo@05001F
oEKm001Fo@0200000eKm001Fo@03E_d30002E_d00`00E_eFo@02E_d40002E_d00`00E_eFo@02E_d2
0004E_d00`00E_eFo@030004E_d00`00E_eFo@030004Ool00`00Oomoo`2]Ool00?moo`]oo`8000Mo
o`8000Ioo`8004]oo`8001Ioo`800005Do/00000Eeh00004Ech00`00E_eFo@030004Ech01000Ech0
00000eLn00<005LnEch00`0015;L00@005;LD]aBg0<0009BF@03001BNE9i009BN@8000EJ^@06001F
f`00001B=`0014hg00D0059HDUQBF00000=BF@8000AJN003001J^@0000=JM`03001B=e8g009B=`06
001>>000001B=`0015Yg00<005Zi00000eig00<0058gDSL00U8g0`0000=B=`00FWP015Yh0P0015ig
00H0059hDWP005Yg0004FYT20004DSL00`00CSQ>>002CSP00`00DWT00003FWP01P00F[UJ^@00GYL0
00ABN@03001B^`0000=JV@03001Fg5KL00<000EBV`06001G7@00001Fg00015;m00H005Km000005LM
0004Ead01P00E_d00000E_d000EFo@<0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00<000AF
o@04001Fo@00E_d30004E_d01P00E_d00000E_d000AFo@06001Fo@00001Fo@001EKm100000=Fo@00
E_d00eKm0`000UKm00<005KmE_d00UKm0`000eKm00D007ooOomoo`000:moo`00ogoo2goo0P001Woo
0P0027oo0P00Agoo0`005Woo1@0015MN00<005LnEch010000dkM00<005LnEch0100015Ln0`000U;L
00<005;LD]`00U;L00H005;L0000059H0004DUT01P00DWUBN@00FWP000EJ^@8000=B=`03001>=dhg
009>=`03001BF59H009BF0<00003DUL005Yh00AJN003001JMeYg009JM`03001B=e8g009B=`8000AB
=`03001JMeYg009JM`03001NMeig009NM`04001B=e8gDSL20004DSL01`00FWQJN5Yh001NU`0000AN
M`03001BN00000=JM`06001JVEZI001NMP00158g00<004hhCSP00Thh0P0015Yh00<005Zi00000ejG
00@0059iDWUBN@8000EJV@80009BN003001BVe:K00=BV`8000AFg003001BoE;m00<000AG7@03001G
7ELM00<000AFo@03001Fo@0000800003Ead005Km00=Fo@06001Fo@00001Fo@0015Km0`000UKm00<0
05KmE_d00UKm10000UKm00<005KmE_d00UKm0P0015Km00<005KmE_d00`0015Km00<005KmE_d00`00
1EKm00H005Km000005Km0004E_d01P00E_d00000E_d000AFo@8000=oo`03001oogoo0:aoo`00ogoo
2goo0P001Woo0P0027oo0P00AGoo0P0067oo00@003Mg0000009GG`03001GGUMN00@0009:_003001>
gDkM009>g@<000AG?P06001G?P00001Bg00015;L00<005;LD]`00`00159H00L0059IDUUBF@00DWT0
0003FWP01`00F[UJ^EZi001JEP0000AB=`05001>=dhgCSL00003DUP20004DUL01000FWQJN5Yh0P00
15Yg00<0058gDSL00P0000=B=P00DSL00e8g00@005YgFWMJM`8000ENM`<00003DSH0058g00=B=`04
001JN5Yh0003GYL00`00GWMNM`02GWL00`00FWMJM`02FWL00`00FYT00003GWH00`00DSMB=`02DSL4
00000e8g001JN004FWP00`00GYMNU`02GYL01P00DWUBN@00FWL000AJV@8000ABN003001BV`000080
0003FYT005KL00=Fg0<000=BV`03001G7ELM00@000=Bo@03001FoEKm00<000EG7@03001FoEKm00<0
00AFo@06001Fo@00001Fo@0015Km00D005Km000005Km008000AFo@06001Fo@00001Fo@0015Km0`00
0UKm00<005KmE_d00UKm0`000eKm00@005KmE_eFo@<000AFo@03001FoEKm00<000AFo@06001Fo@00
001Fo@0017oo00<007ooOol0Zgoo003oOol;Ool20006Ool20008Ool20012Ool3000IOol40002Eel4
0002D[/00`00B[a:_002B[`01000C]d000000eKL00<005LnEch00`0015;L00@005;LD]aBg0<0009>
>003001BF59H009BF004001BFE9IDUT20004FWP01000F[UJ^@000UYF00<0058gDSL00U8g00<004hg
CSL00Thg0`0000=B=`00DUL00e9G00@005YhFWP0009NM`03001JMeYg009JM`8000=B=P03001B=e8g
009B=`04001JMeYg0002GWL00`00GWMNM`02GWL00`00DSIB=P02DSH01`00DSMB=e8g001JN00000AN
U`04001NMeigGWL20005FWL00`00GWINMP02GWH01000DSMB=e8g0P001E8g00@005YhFWQJN08000AN
U`03001BN@0000=JM`04001JVEZI0002GYL00`00DWQBN002DWP00`00FYUJV@03FYT01P00E]`00000
DWP000ABV`<0009Fg003001BoE;m009Bo@<000=G7@04001G7ELMEad40002E_d00`00E_eFo@02E_d2
0004E_d00`00E_eFo@030004E_d01000E_eFoEKm0`0015Km00H005Km000005Km0004E_d01P00E_d0
0000E_d000AFo@@0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00<000AFo@05001oogooOol0
002]Ool00?moo`]oo`8000Ioo`8000Qoo`80041oo`8001Uoo`@0009CO`<0009BV`03001B^e:k009B
^`03001:_4Zl00<000EFg0<0009Ff`03001Bg5;L009Bg006001Bg000001>=`0014hh00H0059HDUQB
F000DUT200000e9G001JN003FWP00`00F[T00004FUH01@00DSMB=e8g00000dhg0P00158g00L0059G
DUMBE`00FWP00003GWL01000FWMJMeYg0P001E8f00<0058gDSL00U8g0P000eig00@005igGWMNM`80
00AB=P04001B=e8gDSL20005GYL01000GWMNM`000Uig00<005YgFWL00UYg00<005ifGWH00Uif00H0
058gDSL005Hf0005DSL01000FWQJN0000UjG00<005jGGYL00UjG00<005YgFWL00UYg00<005ZI0000
0ejG00@0059hDWQBN08000IJV@03001BN59h009BN006001BVe:K001JV@0015KL00H005;m000005:K
0004Ead40002D_d00`00E_eFo@02E_d01P00E_d00000Ead000AFo@<0009Fo@03001FoEKm009Fo@@0
00=Fo@03001FoEKm00<000AFo@03001FoEKm00<000AFo@06001Fo@00001Fo@001EKm00H005Km0000
05Km0004E_d30002E_d00`00E_eFo@02E_d20003Ool00`00Oomoo`2ZOol00?moo`Yoo`8000Moo`80
00Qoo`8003eoo`<001Uoo`<00003Dgl005=o00800003DYX005:K00=BV`04001B^e:kD[/30003DWX0
1`00E]aFg5KL001J^@0000AFf`03001Bg5;L00<000A>=`05001>>4hhCSP00003DUP20004DUL00`00
FWQJN002FWP00`00FUIJEP03FUH00`00DSMB=`02DSL300000dhF001B=`03DSL01000DUMBEe9G0P00
15ig00H005YgFWL005YF0005DSH01000DSMB=e8g0P0015ig00H005igGWL005YF0004DSH01P00DSMB
=`00FWL000INU`8000=NM`04001JMeYgFWL20005GWH20003ESH00`00DSMB=`02DSL00`00FWP00003
GYL01000GYMNUejG0P001EYg00<005jGGYL00UjG00@0059hDWP0009JM`03001JVEZI009JV@8000AB
N003001BV`0000=JV@04001Fg5KLE]`20004DY/01P00Ead00000E_`000EBo@03001FoEKm00<000AG
7@06001Fo@00001Fo@0015Km00<005Km00000`001EKm0`000UKm00<005KmE_d00UKm0`000eKm00<0
05KmE_d00`0015Km00@005KmE_eFo@<000AFo@06001Fo@00001Fo@0015Km00H005Km000005Km0004
Ool00`00Oomoo`2YOol00?moo`9oo`8000Eoo`<000Moo`8000Qoo`8003Yoo`<001Uoo`@0009CO`<0
00ABVP06001BVe:KDY/005:k0P0000=BF@00DWX0159j00<005KL00000eZi00@005KKE]]Ff`<0009>
5`03001>=dhg009>=`06001>>4hhCSP0059H0P0000=B=`00DUL00e9G00@005YhFWQJN08000EJEP04
001B=e8gDSL20004CQH01@00DSMB=e8g00000U9G00<005IG00001Eig0P000eYF00<0058fDSH00U8f
00H0058gDSL005YG0005GWL20003FUH00`00DSIB=P02DSH20003FWL00`00GYMNU`03GYL00`00GWMN
M`02GWL01000FWMJM`000V9f00<005ifGWH00Uif00<005HfESH00UHf00<0058gDSL00U8g0P0015jG
00@005jGGYL0009NM`03001JMeYg009JM`03001NUejG00=NU`8000AJM`04001JVEZI0002GYL01000
DWQBN59h0P0015ZI00H005KL000005Ii0004DY/20004E_`01000D_eBoE;m10000eKm00<005LMEad0
0`0015Km00<005KmE_d00`000UKm00@005Km001Fo@<00003E_d005Km00=Fo@06001Fo@00001Fo@00
15Km0`000UKm00<005KmE_d00UKm10000UKm00@005KmE_eFo@<000AFo@03001FoEKm00<000AFo@05
001oogooOol0002[Ool00?moo`9oo`T000Qoo`8000Qoo`8003Qoo`8001Uoo`@0009CO`<0009BVP03
001BVU:J00=BVP03001BVe:K008000ABF@03001BNU9j009BNP8000AJ^@06001Ff`00001B5`0014hG
00D004hgCSM>=`0000=>>08000AB=`05001BEe9GDUL00002FWP01000GWMNM`001EYF0`0000=B5P00
CQH00dhF00<0058gDSL00U8g0P000eIG00<005igGWL00Uig00<005YFFUH00UYF00<0058fDSH00e8f
0P000eYG00<005igGWL00Uig00<005YFFUH00UYF00@0058fDSIB=P8000AJM`03001NUejG009NU`80
00ENM`8000=RMP04001NMUifGWH20005ESH01P00DSMB=`00FWL000ENU`8000=NM`07001JMeYgFWL0
06:G000015jG00<005YgFWL00eYg00<005ZI00000ejG00H0059hDWP005Yg0004FYT20004EWT01P00
DY/00000FYT000AFo0@0009BV`03001FoEKm009Fo@<0009Bo@03001FoEKm009Fo@<000=Fo@03001F
o@0000<000EFo@03001FoEKm00<000AFo@06001Fo@00001Fo@0015Km00H005Km000005Km0004E_d4
0002E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d20003Ool00`00Oomoo`2XOol00?moo`9o
o`800003Ool0000000<000Uoo`8000Qoo`8003Eoo`<001Uoo`<00003Dgl005=o00800003DYX005:J
00=BVP03001BVU:J009BVP<00003DUP0059I00ABF@06001BNU9j001JN00015Zi0P000e8G00<004hG
CQL00ThG00<004hgCSL00Thg0`0000=B=`00DSL00e8g00<0059GDUL00U9G0P000eig00<005YFFUH0
0UYF0P000e8F00<004hFCQH00ThF00@0058gDSMB=`8000AFE`04001NMeigGWL20005FUH01000DSIB
=U8f0P0015YG00@005igGWMNM`8000AJEP06001B=U8f001JE`001EYg00@005jGGYL0009NM`03001N
Meig009NM`03001RMV9f009RMP04001NMUif0002GUH00`00ESIF=P02ESH00`00DSL00003FWL00`00
GYMNU`02GYL00`00GWMNM`02GWL01000FWMJM`000V:G00@005jGGYMNU`8000IJM`03001NUejG009N
U`03001BN00000=JM`06001JVEZI001NU`001EIi00<005ZIFYT00UZI00H005Kl000005Ii0005DY/0
1P00E_d00000E_`000ABo@06001Fo@00001Fo@0015Km0`000UKm00<005KmE_d00UKm10000eKm00<0
05KmE_d00`0015Km00<005KmE_d00`0015Km00H005Km000005Km0005E_d400000eKm001Fo@03E_d0
1P00E_d00000E_d000Aoo`03001oogoo0:Moo`00ogoo0Woo0P0047oo0P001Woo0P00=7oo0P006Goo
10000U=o0`0015:J00<005:JDYX00U:J00H005:J0000059H0003DUP00`00DUUBF@02DUT00`00DWX0
0003FWP01P00F[UJ^@00FUH000AB5`05001>5dhGCQL00003CSL20003DSL00`00DSMB=`02DSL01000
DUMBEe9G0P001Eig00H005YFFUH005YF0004DQH00`00CQI>5P02CQH300000eIG001FE`03EUL01000
GWMNM`000UYg00<005YFFUH00UYF00H0058fDSH005IG0004FUL01P00GWMNM`00GWH000EJEP8000=J
E`03001JMeYg009JM`03001NU`0000=NM`04001NMeigGWL20005HWH20003GUH00`00ESIF=P03ESH0
0`00FWMJM`02FWL01000GYMNUejG0P001Eig0P000f:G00@005jGGYL0009NM`03001JMeYg009JM`80
00ENU`03001JMeYg009JM`03001JV@0000=NU`04001FNEIiEWT20005FYT00`00EWUFN@02EWT00`00
DY]BV`02DY/20004E_`00`00D_eBo@030004E_d01@00E_d00000E_d00P000eKm00H005Km000005Km
0005E_d30002E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d20004E_d00`00E_eFo@030005
E_d00`00E_eFo@030004E_d01@00Oomoogoo0000ZGoo003oOol2Ool2000@Ool20006Ool2000aOol3
000HOol5000015=o000000000U:J00<005:JDYX00e:J00<005:JDYX00`00159H00D0059HDUQBF000
00=BF@8000AJN003001J^@00009JEP03001B5e8G009B5`03001>5dhG009>5`<00003CQH0058g00=B
=`03001B=e8g009B=`<00003EUL005ig00ANM`03001JEP00009JEP03001B5U8F009B5P04001>5ThF
CQH20004EUL00`00EUMFE`02EUL20003FWL00`00FUIJEP02FUH00`00DSH00003EUL00`00FUMJE`02
FUL20003GWH00`00FUIJEP02FUH00`00FUMJE`02FUL00`00FWMJM`02FWL20004GWL01000GWMNM`00
0Uig00<0069fHWH00V9f00<005iFGUH00eiF00@005HfESIF=P8000AJM`04001NUejG0002GYL01000
GWMNMeig0P001F:G0P0015ig00@005YgFWL0009RU`04001NUejGGYL20005FWL00`00GYMNU`02GYL0
1000EWUFN@000UYg00@005ZIFYUJV@8000AFN@03001BV`0000800003F[X005Kl00=Fo0<000=C7@03
001FoEKm00<000AFo@03001FoEKm00<000AFo@03001Fo@0000800003E_d005Km00=Fo@06001Fo@00
001Fo@0015Km00H005Km000005Km0004E_d30002E_d00`00E_eFo@03E_d30003E_d00`00E_eFo@03
0003Ool00`00Oomoo`2VOol00?moo`9oo`80015oo`8000Aoo`80031oo`8001Uoo`H00004Dgl005:J
0004DYX00`00DYYBVP02DYX30002CSP00`00DUQBF002DUP01P00DUQBF59H001BF@800003DUL005Yh
00AJN003001JEUYF009JEP05001B5e8GDQL00003CQL20003CQH00`00DSMB=`02DSL01000DSMB=e8g
0P0015IG00<005igGWL00eig00<005YFFUH00UYF00D0058FDQIB5P00009>5P03001F=`0000AFE`04
001FEeIGEUL20005FWL01000FUIJEUYF0P0015IG00@005YGFUMJE`8000ANMP04001JEUYFFUH20005
FUL01P00FWMJM`00FWL000ENM`8000=NM`04001RMV9fHWH20005GUH01000ESIF=P000UYG00<005Yg
FWL00UYg0P000ejG00H005igGWL005jG0005HYL00`00GWMNM`03GWL00`00FWL00003HYL01000GYMN
U`000Uig00<005YgFWL00UYg00<005jGGYL00UjG00<005Ii00000eYg00@005ZIFYT0009NU`04001F
NEIiEWT20005F[X01000E_`000000U/m00<005<MDad010000UKm00<005KmE_d00UKm0`000UKm00<0
05KmE_d00UKm0P001EKm00<005KmE_d00`0015Km00<005KmE_d00`0015Km00H005Km000005Km0004
E_d00`00E_d0000200000eKm001Fo@03E_d30002E_d00`00Oomoo`02Ool00`00Oomoo`2UOol00?mo
o`9oo`X000Uoo`P002eoo`<0009oo`03001oogoo01=oo`D0009CO`<000=BVP03001BVU:J009BVP06
001BVP00001>>00014hh00D0059HDUQBF00000=BF08000ABE`04001JN5YhFWP20004FUH00`00DQMB
5`02DQL300000dhF001>5P03CQH01@00DSMB=e8g00000U8g00<005IG000015IG00<005igGWL00Uig
0P0015YF00<0058FDQH00U8F0P000UHg00<005IGEUL00UIG00H005IGEUL005YG0005FWL01P00FUIJ
EP00FUL000AFE`06001JEeYG001JE`0015if00@005YFFUH0009JE`03001JEeYG009JE`03001JM`00
00=JM`03001NMeig009NM`03001NMeig009NM`04001RMV9f0002GWH00`00GUINEP02GUH00`00ESH0
0003FUL01000FWMJMeYg0P0015jG00<005ig00000ejG00@006:GHYMRU`8000INM`03001RUf:G009R
U`03001NU`0000=NM`07001JMeYgFWL006:G000015jG00<005YgFWL00UYg00<005ZI00000ejG00H0
05IiEWT005Yh0005F[X20004Fcd30002C]d00`00E_eFo@02E_d01P00E_d00000Ead000AFo@06001F
o@00001Fo@001EKm0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`0015Km00<005KmE_d0
0`001EKm100000=Fo@00E_d00eKm00D007ooOomoo`000:Moo`00ogoo0Woo2P002goo1000;Goo0P00
1Woo00<007ooOol03goo1@000U=o0`000U:J00<005:JDYX00U:J00<005:JDYX00`0014hh00D004hh
CSQ>>00000ABF0<00003DSL0059G00=BE`06001JN5Yh001NM`0015YF00@0058GDQMB5`8000=>5P03
001>5ThF009>5P03001B=e8g009B=`8000=FE`03001FEeIG009FE`06001NMeig001JEP0015YF00@0
058FDQIB5P8000AF=`03001FEeIG009FE`8000=JE`03001JMeYg009JM`03001JEP0000=JE`03001F
EeIG009FE`8000=JE`03001NMUif009NMP8000=JE`03001JEeYG00=JE`03001JMeYg009JM`04001N
MeigGWL20005GWL20003GWH00`00GUINEP02GUH20004FUL01P00FWMJM`00GWL000ENU`03001NUejG
009NU`04001RUf:G0002HYL00`00GWMNM`02GWL20005HYL00`00GWMNM`02GWL01000FWMJM`000V:G
00@005jGGYMNU`8000EJM`03001NUejG009NU`03001FN@0000=JN005001J^UZjF[X00002H_X01P00
Fcd00000E_`000A>g@03001FoEKm00<000=G7@80009Fo@<000AFo@03001Fo@0000800003E_d005Km
00=Fo@06001Fo@00001Fo@0015Km0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`001EKm
00<005KmE_d00`000goo00<007ooOol0Y7oo003oOom5Ool3000HOol600001E=o000005:J000015:J
00@005:JDYYBVP<0009>>003001>>4hh009>>005001>>4hhCSP00002DUP30004DSL01`00DUMBEe9G
001JN00000=NM`03001JEUYF009JEP<00003CQH004hF00=>5P05001>5ThFCQH00003DSL20004EUL0
0`00EUMFE`02EUL00`00GWL00003FUH00`00FUIJEP02FUH300000eHg001F=`03ESL01000EUMFEeIG
0P0015YG00<005YgFWL00UYg0P0015YG00@005IGEUMFE`8000AJE`04001NMUifGWH20005FUL01000
FUMJEeYG0P0015Yg00@005igGWL0009NM`03001NMeig009NM`03001NMUif009NMP03001NEUiF0080
0003GWL005YG00AJE`8000=NM`04001NUejGGYL20004GYL00`00HYL00004HYL01000GWMNM`000UjG
00<006:GHYL00V:G00<005igGWL00eig0P000f:G00@005jGGYL0009NU`04001JMeYgFWL20005GYL0
0`00FWQJN003FWP00`00F[X00004H_X00`00E_aFo002E_`00`00C]e>g@040003Ead00`00EaeG7@04
0003E_d00`00E_eFo@030005E_d00`00E_eFo@030004E_d01P00E_d00000E_d000AFo@06001Fo@00
001Fo@0015Km0`000UKm00<005KmE_d00UKm10000eKm00<007ooOol00P00YGoo003oOom2Ool3000H
Ool6000015=o0000000015:J00H005:JDYYBVP00DYX200000dhh001>>003CSP01@00CSQ>>4hh0000
0dhh0`000U8g00<0058gDSL00U8g00@0059GDUMBE`8000ANM`04001JEUYFFUH20003CQH00`00CQI>
5P02CQH00`00CQI>5P02CQH300000e8g001FE`04EUL01000EUMFEeIG0P0015YF00@005YFFUIJEP80
00=F=`03001F=eHg009F=`06001FEeIG001FE`001EYG00H005YgFWL005YG0004FUL01P00EUMFE`00
FUL000AJE`06001NMUif001JM`001EYG00@005YGFUL0009JE`03001JMeYg009JM`8000=NM`04001N
MeigGWL20005GWH20004GWL00`00FUMJE`02FUL00`00GWMNM`02GWL01000GYMNU`000Uig00<005jG
GYL00UjG00<006:GHYL00f:G00<005ig00000ejG00L006:GHYMRU`00HYL00004GWL00`00HYMRU`03
HYL20003GYL01000FWMJM`000V:G00@005jGGYMNU`8000IJN003001RnV;j009RnP8000AFo0<0009>
V`03001G7ELM009G7@@00003D_d005Km00=Fo@<0009G7@03001FoEKm009Fo@@000=Fo@03001FoEKm
00<000AFo@03001FoEKm00<000AFo@06001Fo@00001Fo@0015Km00H005Km000005Km0005E_d30000
0goo001oo`2TOol00?mood1oo`8001Qoo`H00004Dgl000000002DYX00`00DYYBVP02DYX00`00DYYB
VP030004CSP01@00CSQ>>4hh000014hh0`0000=>=`00DSL00e8g00D0058gDSMB=`00009BE`03001F
E`0000ANM`06001JEUYF001F=P0014hF00D004hFCQI>5P0000=>5P8000AB=`03001FEeIG009FE`06
001FEeIG001FE`0015YF00H005YFFUH005IG0004ESL00`00ESMF=`02ESL20003EUL00`00FUMJE`02
FUL00`00FWL00002FUL00`00FUMJE`03FUL20003FUL00`00FUMJE`02FUL20003FWL00`00FUMJE`02
FUL00`00FUL00003FUL01000FWMJMeYg0P0015ig00@005igGWL0009NM`03001NMUif009NMP03001N
Meig00=NM`04001JEeYGFUL20004GWL00`00GYL00003GWL01000GYMNUejG0P001V:G00<005jGGYL0
0UjG00@006:GHYL0009RU`04001NMeigGWL20005HYL00`00GYMNU`02GYL00`00FWL00003HYL01000
GYMNU`000V:G00<005YhFWP00UYh0P000f;j00D006KhI_P005Kl00800003EWP004jK00=>V`08001G
7@00001Fo000D_d0009Bo@06001Fo@00001Fo@0015LM00H005Km000005Km0005E_d30002E_d00`00
E_eFo@02E_d30003E_d00`00E_eFo@030004E_d00`00E_eFo@030004E_d00`00E_d0000200000eKm
001oo`02Ool00`00Oomoo`2ROol00?mooceoo`<001Uoo`D00005Dgl00000DYX00004DYX01000DYYB
VU:J0`000Thh00<004hhCSP00Thh00D004hhCSQ>>00000=>>08000=>=`03001B=e8g009B=`03001B
=e8g009B=`8000=FE`03001NMeig009NM`80009F=P03001>5ThF009>5P03001>5ThF009>5P<00003
DSL0058g00=B=`03001FEeIG009FE`03001FE`0000=FE`03001JEUYF009JEP80009FE`03001F=eHg
009F=`04001F=eHgESL20004EUL00`00FUMJE`02FUL20004FUL00`00FUMJE`02FUL00`00FUMJE`02
FUL01000FUMJEeYG0P0015Yg00<005YGFUL00UYG0P0015YG00H005YgFWL005Yg0005GWL20003GWL0
1000GWINMUif0P001Eig00@005YGFUL0009JM`03001NMeig009NM`03001NMeig009NM`04001NUejG
0002GYL00`00HYMRU`02HYL20005GYL20003HYL01000GWMNM`000V:G00@006:GHYMRU`8000ENU`03
001RUf:G009RU`03001NU`0000ARU`04001JN5Yh0002H[P00`00H_X00004I_P00`00EWQFN002EWP0
1000CY]>VdjK0P0015Kl0P0000ABo@00000000AFo@03001G7ELM00<000AFo@03001Fo@0000800003
E_d005Km00=Fo@06001Fo@00001Fo@0015Km0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d0
0`001EKm00@007ooOol00:Aoo`00ogoo>goo0P006Goo1@0000ACO`00000000ABVP06001BVU:JDYX0
05:J0P0000=>>000CSP00dhh00D004hhCSQ>>00000A>>0<00003CQL004hg00=>=`05001B=e8gDSL0
0003DSL20004EUL01000GWMNMeig0P0015Hf00D004hFCQI>5P0000=>5P8000AB=`03001B=e8g009B
=`04001FEeIGEUL20004EUL01000FUIJEUYF0P0015IG00D005HgESMF=`00009F=`03001FE`0000AF
E`03001JEeYG00800003FUL005YG00=JE`04001JEeYGFUL20004FUL01P00FUMJE`00FUL000AJM`03
001JEeYG00800003FUL005YG00AJE`8000=JM`03001NMeig009NM`03001NMeig009NM`04001NMUif
0002GWL00`00GWMNM`03GWL20003FWL01000GWMNMeig0P001Eig0P000ejG00D006:GHYMRU`00009N
U`03001NUejG009NU`03001RUf:G00=RU`8000=RU`04001RUf:G0002HYL01000GYMNUejG0P001F:G
00<006:GHYL00f:G00<005Yh000016:h00<006KhI_P00fKh00<005IhEWP00UIh00H004jK000005ZI
0004E_`30002CY/00`00E_eFo@02E_d30003D_d00`00E_eFo@030005E_d00`00E_eFo@030004E_d0
1P00E_d00000E_d000AFo@06001Fo@00001Fo@0015Km0`000UKm00<005KmE_d00UKm0P000goo00<0
07ooOol0XGoo003oOolhOol3000HOol5000015=o000000000U:J00<005:JDYX00U:J00<005:JDYX0
0`0014hh00D004hhCSQ>>00000A>>003001>>000008000=>5`03001>=dhg009>=`03001B=e8g009B
=`<00003DUL005IG00=FE`06001NMeig001JEP0015Hf00<004hFCQH00ThF0`0000=B=`00DSL00e8g
00<0058gDSL00U8g00H005IG000005Hg0004EUL01P00FUIJEP00EUL000AFE`03001F=eHg009F=`80
00=FE`03001FEeIG009FE`8000=JE`03001JEeYG009JE`06001JEeYG001JE`001EYG0P000eYG00<0
05YgFWL00UYg0P0015YG00<005YGFUL00UYG00<005YgFWL00UYg00@005igGWMNM`8000ENM`8000=N
M`03001NMeig00=NM`03001JMeYg009JM`04001NMeig0002GWL00`00GWMNM`02GWL00`00GYMNU`02
GYL01000HYMRU`000ejG00@005jGGYMNU`8000ERU`03001RUf:G009RU`03001RU`0000=RU`04001N
UejG0002HYL01000HYMRUf:G0P001V:G00<006:hH[P00f:h00<006KhI_P00VKh00<006JG000015Ih
00<005ZIFYT00UZI00H005Kl000005Ii0004CY/01P00E_d00000E_`000ABo@<0009Fo@03001FoEKm
009Fo@@0009Fo@04001FoEKmE_d30004E_d00`00E_eFo@030004E_d01P00E_d00000E_d000AFo@06
001Fo@00001Fo@0017oo00<007ooOol0X7oo003oOolfOol2000IOol500001E=o000005:J000015:J
00@005:JDYYBVP<0009>>003001>>4hh009>>005001>>4hhCSP00003CSP30002CQL00`00CQM>5`02
CQL01@00CSM>=dhg00000e8g0P00159G00<005IGEUL00UIG0P000UYF00<005HfESH00UHf00@004hF
CQI>5P8000AB=`03001B=e8g009B=`04001B=e8gDSL20004ESL00`00EUMFE`02EUL20002EUL00`00
EUMFE`02EUL01000ESMF=eHg0P0015IG00@005IGEUMFE`8000EJE`03001JEeYG009JE`8000=JE`03
001JEeYG009JE`03001JEeYG009JE`04001JMeYgFWL20005FUL01000FUMJEeYG0P0015Yg00@005ig
GWL0009NM`03001NMeig009NM`03001NMeig00=NM`04001NMeigGWL20005FWL20003GWL01000GWMN
Meig0P001EjG0P0015jG00@005jGGYL0009RU`04001RUf:GHYL20005HYL00`00HYMRU`02HYL00`00
GYL00003HYL01000HYMRU`000V:g00<006:GHYL00V:G0P0016:h00<006KG00000VKh00@006JGIYL0
00=FN08000EJV@04001FNEIiEWT20003CY/20004E_`01P00D_d00000Dad000AFo@06001Fo@00001F
o@0015Km10000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`0015Km00<005KmE_d00`0015Km
00D007ooOomoo`000:9oo`00ogoo<goo0`0067oo1@0000ACO`00000000ABVP06001BVU:JDYX005:J
0P0000=>>000CSP00dhh00D004hhCSQ>>00000A>>0<00003CQL004hG00=>5`05001>5dhGCQL00004
CSL300000e8g001BE`03DUL01000EUMFEeIG0P0015YF00<005HfESH00UHf0`0000=B=`00DSL00e8g
00<0058gDSL00U8g00H0058gDSL005Hg0004ESL01000EUMFEeIG0P0015IG00<005IGEUL00UIG0`00
00=FE`00EUL00eIG00H005IGEUL005IG0005FUL01000FUMJEeYG0P0015YG00@005YGFUMJE`8000AJ
E`06001JMeYg001JE`001EYG00@005YGFUL0009JM`03001JMeYg009JM`8000=NM`04001NMeigGWL2
0005GWL01000GWMNM`000Uig00<005YgFWL00UYg00<005igGWL00Uig00@005igGWL0009NM`03001N
UejG009NU`03001NUejG00ANU`8000=RU`04001RUf:G0002HYL00`00HYMRU`02HYL00`00HYMRU`03
HYL00`00HYMRU`02HYL00`00HYL00004H[L01000HYMRU`000V:g00@006:hH[P0009Ve`03001Vn000
00=VU`04001FN5Ih0002FWL01000FYUJVEZI0P000eIi0P0000=>V`0000000UZj00<005KlE_`00`00
15<M00<005KmE_d00`0015Km00H005Km000005Km0005E_d01P00E_d00000E_d000AFo@<0009Fo@03
001FoEKm009Fo@<000=Fo@03001FoEKm00<000=oo`03001oogoo09moo`00ogoo<7oo0`0067oo1@00
00ACO`000000009BVP03001BVU:J009BVP03001BVU:J00<000A>>005001>>4hhCSP00004CSP00`00
CSP000020003CQL00`00CQM>5`02CQL01@00CQM>5dhG00000dhg0P00158g00D0059GDUMBE`00009F
E`03001FE`0000AJEP04001F=UHfESH20004DSL00`00DSMB=`02DSL01`00DSMB=e8g001B=`00009F
=`03001F=eHg009F=`06001FEeIG001FE`0015IG00@005IGEUMFE`8000AFE`03001FEeIG009FE`80
00=FE`03001JEeYG009JE`06001JEeYG001JE`0015YG00H005YGFUL005YG0005FUL20003FUL00`00
FUMJE`03FUL20003FWL01000FWMJMeYg0P0015ig00@005igGWL0009NM`03001NMeig009NM`03001N
M`0000=NM`04001JMeYgFWL20005GWL20003GWL01000GYMNUejG0P001UjG00<006:GHYL00V:G00<0
06:G00000f:G00L006:GHYMRU`00HYL00004HYL00`00HYMRU`03HYL00`00H[MR]`03H[L00`00HYL0
0003H[L01000H[QR^0000fKG00<006JGIYL00fJG0P000eYg00@005ZIFYT0009RU`03001FNEIi00<0
00EJ^P8000=K7@03001C7E<M00@000=Fo@03001FoEKm00<000AFo@04001FoEKmE_d30004E_d01P00
E_d00000E_d000AFo@06001Fo@00001Fo@0015Km0`000UKm00<007ooOol00Woo00<007ooOol0WWoo
003oOol^Ool2000IOol6000015=o001BVP0015:J00@005:JDYYBVP<0009>>003001>>4hh009>>005
001>>4hhCSP00003CSP30002CQL00`00CQM>5`02CQL01@00CQM>5dhG000014hG0`0000=B=`00DSL0
0e8g00<0059GDUL00U9G0P000UIG00<005YFFUH00UYF00H005HfESH005Hg0004DSL00`00DSMB=`02
DSL01000DSMB=e8g0P0015Hg00<005HgESL00UHg0P000UIG00<005IGEUL00UIG00H005IGEUL005IG
0004EUL01000EUMFEeIG0P0015IG00<005YGFUL00eYG0P000eYG00<005YGFUL00UYG0P000eYG00<0
05YGFUL00UYG00<005YGFUL00UYG00<005YGFUL00UYG0P0015Yg00H005YgFWL005ig0005GWL20003
GWL00`00GWMNM`02GWL20004GWL01000FWMJM`000Uig00<005igGWL00Uig00<005igGWL00Uig00@0
05jGGYL0009NU`03001NUejG009NU`8000ERU`03001RUf:G009RU`04001RUf:G0002HYL01`00HYMR
Uf:G001RU`0000ARU`03001R]f:g00AR]`03001R]f:g009R]`03001R^00000AVe`03001VUfJG00=V
U`03001JMeYg009JM`03001JV@0000=RU`06001FNEIi001JN00015Zj0P0015/M0`000TkM00<005Km
E_d00UKm0`000ULM00<005KmE_d00UKm10000UKm00@005KmE_eFo@<000AFo@03001FoEKm00<000AF
o@06001Fo@00001Fo@0015Km00D007ooOomoo`000:1oo`00ogoo:goo0`0027oo100037oo1@000UMO
0`000e:J00<005:JDYX00U:J00D005:J001>>00000A>>005001>>4hhCSP00004CSP300000dhG001>
5`02CQL00`00CQM>5`02CQL00`00CQM>5`02CQL00`00CQL000020004DSL01@00DSMB=e8g00000e9G
0P0015IG00<005YFFUH00UYF0P000eHg00<0058gDSL00U8g00H0058gDSMB=`00DSL200000e8g001F
=`03ESL01000ESMF=eHg0P0015IG00<005IGEUL00UIG0P000UIG00<005IGEUL00UIG00H005IGEUL0
05IG0005EUL01000FUMJEeYG0P0015YG00@005YGFUMJE`8000AJE`04001JEeYGFUL20005FUL01P00
FUMJE`00FUL000EJM`8000=NM`03001NMeig009NM`03001NMeig00=NM`06001NMeig001NM`001Eig
0P000eig00@005igGWMNM`8000ENM`8000ANU`04001NUejG0002GYL00`00HYMRU`02HYL00`00HYMR
U`03HYL20003HYL01000HYMRU`000V:G00L006:GHYMRU`00HYL00005H[L00`00H[MR]`03H[L00`00
I]MVe`02I]L00`00J[H00004IYL00`00FWMJM`03FWL00`00HYMRU`02HYL01000EWT000000UYh00@0
05ZjF[X0009RnP06001K7@00001Fo00014kM00H005Km000005Km0004Ead01P00E_d00000E_d000AF
o@@0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00<000AFo@03001FoEKm00<000=oo`03001o
ogoo09eoo`00ogoo:Goo0P002Goo0P0000A>>000=MTef@<000Ioo`@000=GGP<0009F^P03001BVU:J
009BVP03001BVU:J00<000=>>005001>>4hhCSP00004CSP00`00CSP000020003CQL00`00CQM>5`02
CQL01@00CQM>5dhG00000dhG0`000U8g00<0058gDSL00U8g00<0058gDSL00U8g0`0000=B=`00EUL0
0eIG00@005YFFUIJEP8000AF=`03001B=e8g009B=`04001B=e8gDSL20004DSL01@00ESMF=eHg0000
0UHg00<005Hg000015IG00@005IGEUMFE`8000AFE`03001FEeIG009FE`8000=FE`03001FEeIG009F
E`06001JEeYG001JE`0015YG00H005YGFUL005YG0004FUL01000FUMJE`000UYG00<005YGFUL00UYG
00<005YG00000eYG00<005YgFWL00UYg00<005igGWL00Uig00@005igGWMNM`8000ENM`03001NM`00
00=NM`03001NMeig009NM`03001NMeig009NM`04001NMeig0002GWL00`00GWMNM`02GWL00`00GYMN
U`03GYL00`00GYL00003GYL01`00HYMRUf:G001RU`0000ARU`03001RUf:G00=RU`8000=RU`04001R
Uf:G0002HYL00`00H[MR]`02H[L00`00H[L00003H[L20003I]L01000J[IZ]P000fJG00<006:F0000
0eYg0P001F:G00<005Yh00000UYh00<005Zj000016;j00<005KlE_`00UKl00<004kMC]d00`0015Km
00<005LMEad00`0015Km00H005Km000005Km0005E_d400000eKm001Fo@03E_d30002E_d00`00E_eF
o@02E_d30002E_d00`00Oomoo`02Ool00`00Oomoo`2LOol00?moobIoo`<000Uoo`8000A>>005000e
fCGI000Mo0070002Ech01P00Eeh00000E[/000AF^P04001BVU:JDYX30002CSP01@00CSQ>>4hh0000
14hh00<004hhCSP00`000ThG00<004hGCQL00ThG00D004hGCQM>5`0000A>5`<00003CSL0058g00=B
=`05001B=e8gDSL00003DSL20004DSL01@00EUMFEeIG00000UYF00<005IG00001EHg00H0058gDSMB
=`00DSL200000e8g001B=`03DSL00`00ESMF=`02ESL20002ESL00`00EUMFE`02EUL01P00EUMFE`00
EUL000AFE`04001FEeIGEUL20004EUL00`00EUMFE`02EUL00`00FUL00003FUL00`00FUMJE`02FUL2
0003FUL00`00FUMJE`02FUL20003FUL00`00FUMJE`03FUL00`00FUMJE`02FUL01000FWMJMeYg0P00
15ig00@005igGWL0009NM`03001NMeig00=NM`03001NMeig009NM`04001NMeigGWL20005GWL20003
GWL01000GWMNMeig0P001UjG00<005jGGYL00UjG00@006:GHYL0009RU`04001RUf:GHYL20005HYL0
0`00HYMRU`03HYL20004HYL01000H[MR]`000V:g00@006:gH[L0009V]`04001VefKG0002J[H01000
IYMVU`000V:F00@005YgFWL0009RU`04001RUf:GHYL200000eYh001JN002FWP00`00H_YRnP02H_X2
0004E_`30002CY/00`00E_eFo@02E_d30003D_d00`00E_eFo@030004E_d00`00E_eFo@030005E_d4
00000eKm001Fo@03E_d01P00E_d00000E_d000AFo@05001oogooOol0000HOol6000>Ool4001^Ool0
0?moobAoo`80009oo`03001oogoo00Eoo`800003EWP004hh00=>>005000efCGI=MT000027O`30004
Ech20004E[/01P00E[YF^UJj001BVP800003DUP004hh00=>>005001>>4hhCSP00003CSP01@00CSP0
04hG000014hG00D004hGCQM>5`0000=>5`04001>5dhGCQL20003CSL00`00DSMB=`02DSL00`00DSMB
=`02DSL300000e8g001B=`03DSL00`00EUMFE`02EUL20003EUL00`00ESMF=`02ESL01000DSMB=e8g
0P000e8g00<0058gDSL00U8g00@005HgESMF=`8000AF=`03001FEeIG009FE`80009FE`03001FEeIG
009FE`06001FEeIG001FE`001EIG00@005IGEUMFE`8000AJE`04001JEeYGFUL20004FUL01000FUMJ
EeYG0P001EYG00@005YGFUMJE`8000AJE`06001JMeYg001JM`001Eig0P000eig00<005igGWL00Uig
0P0015ig00@005igGWL0009NM`03001NMeig009NM`03001NMeig009NM`04001NMeig0002GWL00`00
GYMNU`02GYL20005GYL20003HYL01000HYMRU`000V:G00@006:GHYMRU`8000ERU`03001RUf:G00=R
U`03001R]`0000=R]`03001R]`0000=V]`03001Ve`0000AZ]P8000=RUP03001JM`0000=RU`04001R
Uf:G0002HYL20002FWP20003H_X01@00I_QVn000E_`00P0000=FN@00CY/00djK00H005Km000005Kl
0004D_d30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@030005E_d00`00E_eFo@030004E_d0
0`00E_eFo@030003Ool00`00Oomoo`0COol:000:Ool8001/Ool00?moob5oo`<000Eoo`04001oogoo
Ool30004EWP01@00CSQ>>4hh00000cGI0`000eKm00H005Ln000005KK0004E[/00`00E[YF^P030004
DUP01@00CSQ>>4hh00000dhh00<004hhCSP00`000dhG00D004hGCQM>5`0000=>5`03001>5dhG009>
5`<00003CSL004hg00=>=`05001B=e8gDSL00003DSL20004DSL01@00DSMB=e8g00000eIG0P0015IG
00<005HgESL00UHg00H0058g0000058g0004DSL00`00DSMB=`02DSL300000eHg001F=`03ESL01000
EUMFEeIG0P0015IG00<005IGEUL00UIG0P000eIG00<005IGEUL00UIG00H005IGEUL005IG0004FUL0
1P00FUMJE`00FUL000AJE`06001JEeYG001JE`001EYG00H005YGFUL005YG0005FUL20003FWL00`00
GWMNM`02GWL00`00GWMNM`03GWL01000GWMNM`000Uig00<005igGWL00Uig0P000eig00@005igGWMN
M`8000ENM`8000ANM`04001NUejG0002GYL00`00GYMNU`02GYL00`00HYMRU`03HYL20003HYL01000
HYMRU`000V:G00@006:GHYMRU`8000IRU`03001R]f:g00=R]`03001V]fJg00=V]`03001Z]VZf00=Z
]P03001RUV:F00=RUP03001RUf:G009RU`03001RU`0000=RU`800007FWP006;HH]P006;j000016Kh
00<005IiEWT00UIi00@004jKCY]>V`8000AFo006001Bo@00001C7@0015Km00H005Km000005Km0004
E_d30002E_d00`00E_eFo@02E_d40002E_d01000E_eFoEKm10000eKm00D007ooOomoo`0001Aoo`<0
00Eoo`<000Uoo`8000Aoo`8006aoo`00ogoo7goo0P002Goo0`000U9i00<005IhEWP00UIh00<004hh
CSP00Thh0`0000=Ff`00E_d00eKm0P0015KK00@005JkE[]F^`<0009BF003001BF59H009BF005001>
>4hhCSP00003CSP30002CQL01@00CQM>5dhG000014hG00H004hGCQM>5`00CQL30004CSL01@00CSM>
=dhg0000158g0`0000=B=`00DSL00e8g00<0058gDSL00U8g0`0000=F=`00EUL015IG00@005HgESMF
=`8000=B=`03001B=e8g009B=`04001B=e8gDSL20004ESL01@00ESMF=eHg00000UIG00<005Hg0000
15IG00@005IGEUMFE`8000AFE`03001FEeIG009FE`03001FE`0000=FE`03001JEeYG009JE`8000=J
E`03001JEeYG009JE`8000=JE`03001JEeYG009JE`03001JE`0000=JE`03001JEeYG009JE`03001J
MeYg009JM`04001NMeigGWL20005GWL00`00GWL00003GWL01000GWMNMeig0P0015ig00@005igGWL0
009NM`03001NMeig009NM`03001NMeig00=NM`03001NU`0000=NU`04001NUejGGYL20005HYL00`00
HYMRU`02HYL00`00HYL00003HYL01000HYMRU`000V:G00<006:GHYL00V:G0P001F:g00<006JgI[L0
0fJg00<006ZfJ[H00fZf00<006:FHYH00f:F00<006:GHYL00f:G00<006:GHYL00V:G00<005Yh0000
16;H00<006KhI_P00fKh00<005IiEWT00UIi00@004jK0000009J^P03001Fo5Kl00<000AC7@03001F
oEKm00<000AFo@06001Fo@00001Fo@0015Km00H005Km000005Km0004E_d40002E_d00`00E_eFo@02
E_d20002Ool00`00Oomoo`0KOol20008Ool20006Ool2001[Ool00?mooaaoo`<000Uoo`800003DWT0
059i00=BN@05001FN5IhEWP00002CSP30004E]/01P00E_d00000Ga`000AFf`06001F^`00001BF@00
159H00D0059HDUQBF00000A>>0<00003CQL004hG009>5`03001>5dhG009>5`05001>5dhGCQL00002
CQL30002CSL00`00CSM>=`02CSL01@00CSM>=dhg00000e8g0P00158g00D0058gDSMB=`0000=B=`80
00AF=`03001FEeIG009FE`06001F=eHg001F=`00158g00D0058gDSMB=`00009B=`03001F=`0000AF
=`03001F=eHg009F=`80009F=`03001FEeIG009FE`06001FEeIG001FE`001EIG00@005IGEUMFE`80
00AFE`04001JEeYGFUL20004FUL01000FUMJEeYG0P0015YG00<005YGFUL00UYG0P0015YG00@005YG
FUMJE`8000AJM`04001NMeig0002GWL00`00GWMNM`02GWL20004GWL01P00GWMNM`00GWL000ENM`80
00=NM`04001NMeigGWL20006GWL00`00GYMNU`02GYL01000GYMNU`000V:G00@006:GHYMRU`8000ER
U`03001RUf:G009RU`03001RU`0000ARU`04001RUf:G0002HYL01`00H[MR]f:g001R]`0000=V]`03
001V]`0000=Z]P03001V]P0000=RUP03001R]`0000ARU`03001RUf:G00=RU`8000ARf003001Vn6Kh
009Vn003001V]`0000=FN@8000EJ^P8000=K7@03001C7E<M00@000=Fo@03001FoEKm00<000AFo@03
001FoEKm00<000AFo@06001Fo@00001Fo@001EKm100000=Fo@00Ool00Woo00<007ooOol06goo0P00
1goo0P001Woo0P00Jgoo003oOolIOol3000:Ool20004DWT01@00DWUBNE9i00000eIh0`000UKK00<0
05KKE]/00UKK0P0015lL00<005KKE]/00`00159I00D0059HDUQBF00000ABF003001>>000008000=>
5`03001>5dhG009>5`05001>5dhGCQL00003CQL01@00CQL004hg000014hg00D004hgCSM>=`0000A>
=`<00003DSL0058g00=B=`03001B=e8g009B=`<00003DSL005Hg00=F=`03001FEeIG009FE`03001F
=`00009F=`03001B=e8g009B=`03001B=e8g009B=`80009F=`03001F=eHg009F=`04001F=eHgESL2
0004ESL00`00EUMFE`02EUL20003EUL00`00EUMFE`02EUL01P00EUMFE`00EUL000AFE`06001JEeYG
001JE`0015YG00H005YGFUL005YG0005FUL01P00FUMJE`00FUL000AJE`04001JEeYG0002FUL00`00
FWMJM`02FWL20003GWL01`00GWMNMeig001NM`0000ENM`8000=NM`03001NMeig009NM`03001NMeig
009NM`04001NMeig0002GWL00`00GWMNM`02GWL20005GYL20003HYL01000HYMRU`000V:G00@006:G
HYMRU`8000ERU`03001RUf:G00=RU`03001RU`0000=RU`04001R]f:g0002H[L01000I[MV]`000VJg
00@006ZfJ[H0009V]P04001RUV:F0002H[L01`00HYMRUf:G001V]`0000=RU`<000=Rf003001Ze`00
009Vn004001V]fJg0002EWT00`00FWP00004F[X20004Fad30002C]d00`00E_eFo@02E_d30002Ead0
0`00E_eFo@02E_d30003E_d00`00E_eFo@030004E_d00`00E_eFo@030005E_d01@00Oomoogoo0000
77oo0P001Woo0P0027oo0P00JWoo003oOolGOol2000<Ool00`00EWT00004DWT01P00DWUBNE9i001F
N0800003E]`005KK00=Ff`04001Ff`000002Gcd01000GaaO75lL0`000U9j00<0059IDUT00U9I00D0
059HDUQBF000009BF0@0009>5`03001>5dhG009>5`05001>5dhGCQL00003CQL00`00CQM>5`030003
CSL01@00CSM>=dhg000014hg00<004hg00000P00158g00D0058gDSMB=`0000=B=`8000AB=`03001F
=eHg009F=`04001FEeIGEUL20004ESL01@00DSMB=e8g00000e8g0P0015Hg00<005HgESL00UHg0`00
00=F=`00ESL00eHg00@005IGEUMFE`8000AFE`03001FEeIG009FE`03001FE`0000=FE`03001FEeIG
009FE`80009JE`03001JEeYG00=JE`80009JE`03001JEeYG00=JE`03001JE`0000=JE`03001JEeYG
009JE`8000=JE`04001JMeYgFWL20004GWL01000GWMNM`000eig00<005igGWL00Uig00<005igGWL0
0Uig00@005igGWMNM`8000ENM`8000ANM`04001NMeig0002GWL00`00GYMNU`02GYL00`00HYMRU`02
HYL00`00HYL00003HYL01000HYMRU`000V:G00@006:GHYMRU`8000ERU`8000ARU`03001R]`0000=R
]`03001V]`0000=V]`03001Z]P0000=V]P03001RUP0000=R]`04001RUf:G0002I[L01000HYMRU`00
0V:g00@006;HH]P0009Ze`03001Vn00000=V]`03001FN@0000=JN004001J^UZj0002I_X01P00Fad0
0000E_`000A>g@06001Fo@00001Fo@0015LM00H005Km000005Km0004E_d30002E_d00`00E_eFo@02
E_d30003E_d00`00E_eFo@030003Ool00`00Oomoo`0JOol20006Ool20008Ool2001ZOol00?mooaAo
o`<000]oo`<000=FN@05001BNE9iDWT00002DWT30004E]`01000E]]FfeKK0`0015lm00D005lL001F
g00000ABNP05001BFE9IDUT00003DUP30002CQL00`00CQM>5`02CQL01@00CQM>5dhG00000dhG00@0
04hGCQM>5`<0009>=`05001>=dhgCSL00003CSL01000CSM>=dhg0`000U8g00<0058gDSL00U8g00<0
058gDSL00U8g0`0000=B=`00DSL00e8g00<005HgESL00UHg00H005IG000005Hg0004ESL00`00DSMB
=`02DSL300000e8g001F=`03ESL01000ESMF=eHg0P0015Hg00D005HgESMF=`00009FE`03001FE`00
00EFE`04001FEeIGEUL20004EUL01000EUMFEeIG0P0015YG00<005YGFUL00UYG00<005YGFUL00UYG
00<005YGFUL00UYG0P0015YG00@005YGFUMJE`8000AJE`06001JMeYg001JM`001Eig0P0015ig00@0
05igGWMNM`8000ANM`04001NMeig0002GWL00`00GWMNM`02GWL00`00GWMNM`03GWL00`00GWL00003
GWL01000GYMNUejG0P001F:G00<006:GHYL00V:G00<006:G00000f:G00@006:GHYL0009RU`07001R
Uf:GHYL006:G00001F:G00<006:gH[L00f:g00<006JgI[L00fJg00<006JfI[H00fJf00<006:gH[L0
0f:g0P000fJg00<006:G00000f:g00<006;H000016[G00<006JgI[L00fJg00<005YhFWP00UYh00<0
05Zj000016Kj00<005KlE_`00UKl00<004kMC]d00`0015Km00<005LMEad00`0015Km00H005Km0000
05Km0004E_d01P00E_d00000E_d000AFo@<0009Fo@03001oogoo009oo`03001oogoo01Uoo`8000Io
o`8000Qoo`8006Yoo`00ogoo4Woo0P002goo0`000UJJ00<005IiEWT00UIi00<0059iDWT00`000eKL
00H005KLE]aFg000E]/20003Ech00`00GceO?@030003E]`00`00DWYBNP02DWX01000DUUBFE9I0`00
00=>=`00CQL00ThG00<004hGCQL00ThG00D004hGCQM>5`0000A>5`<00003CSL004hg00=>=`05001>
=dhgCSL00003CSL300000dhg001B=`03DSL01@00DSMB=e8g00000e8g0P00158g00<0058gDSL00U8g
00@005HgESMF=`8000=F=`03001F=eHg009F=`04001B=e8gDSL20004DSL01@00ESMF=eHg00000UHg
00<005Hg000015Hg00<005HgESL00UHg0P000eIG00<005IGEUL00UIG00H005IGEUL005IG0004EUL0
1P00EUMFE`00EUL000AJE`04001JEeYGFUL20004FUL01`00FUMJEeYG001JE`0000AJE`06001JEeYG
001JE`001EYG0P000eYg00<005igGWL00Uig00<005igGWL00eig00H005igGWL005ig0005GWL20003
GWL01000GWMNMeig0P001Uig00<005igGWL00Uig00@005jGGYL0009NU`04001RUf:GHYL20005HYL0
0`00HYMRU`02HYL00`00HYL00003HYL01000HYMRU`000f:G00@006:GHYMRU`8000ER]`03001V]fJg
00=V]`03001V]VJf00=V]P03001R]f:g00=R]`03001V]fJg00=V]`03001R]f:g009R]`8000EZe`03
001V]fJg00=V]`03001JN5Yh00=JN003001VnVKj009VnP8000AFo0<0009>V`03001FoEKm009Fo@<0
00=Bo@03001FoEKm00<000AFo@03001FoEKm00<000AFo@06001Fo@00001Fo@0015Km00<007ooOol0
0Woo00<007ooOol067oo0P001Woo0P0027oo0P00JWoo003oOol?Ool3000<Ool00`00F]/00004EYX0
1`00EWUFNEIi001BN@00009Fg003001Fg5KL009Fg003001Fg5KL00<000AG?P<0009G?P03001Fg5KL
009Fg005001BNU9jDWX00002DUT20003CSL00`00CQM>5`02CQL01@00CQM>5dhG000014hG00<004hG
00000P000dhg00<004hgCSL00Thg00D004hgCSM>=`00009>=`8000A>=`05001B=e8gDSL00004DSL3
00000e8g001B=`03DSL00`00DSMB=`02DSL01P00ESMF=`00DSL000AF=`03001F=eHg009F=`<00003
DSL0058g00=B=`03001F=eHg009F=`80009F=`03001F=eHg009F=`04001F=eHgESL20004EUL00`00
EUMFE`02EUL00`00EUL00003EUL00`00EUMFE`02EUL20002EUL00`00FUMJE`02FUL01P00FUMJE`00
FUL000AJE`04001JEeYG0002FUL00`00FUMJE`03FUL20003FUL00`00FUMJE`02FUL00`00FWMJM`02
FWL01000GWMNMeig0P001Uig0P000eig00<005igGWL00Uig00<005igGWL00Uig00@005igGWL0009N
M`03001NMeig00=NM`03001NMeig00=NM`8000=NU`04001RUf:G0002HYL00`00HYMRU`02HYL00`00
HYMRU`03HYL00`00HYMRU`02HYL00`00HYL00004HYL01000HYMRU`000V:g00L006:gH[MR]`00H[L0
0003I[L00`00I[L00003I[H00`00I[L00003H[L20005I[L00`00H[MR]`02H[L20004J]L00`00J]L0
0003I[L00`00I[L00003FWP20003I_X01@00J_QZn000E_`00P0000=FN@00CY/00djK00H005Km0000
05Kl0004D_d30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@030004E_d00`00E_eFo@030003
Ool00`00Oomoo`0GOol20007Ool20008Ool2001ZOol00?moo`eoo`8000ioo`05001Jfe[KF]/00003
EYX00`00EWUFN@030004E]`00`00E]aFg0040003Dah01000Ech000000ULn00D005LnEciG?P0000=F
g003001BNU9j00@00003CSP004hg00=>=`05001>5dhGCQL00004CQL00`00CQL000030002CSL00`00
CSM>=`02CSL01@00CSM>=dhg00000dhg00D004hg001>=`0000A>=`03001B=e8g009B=`03001B=e8g
008000AB=`03001B=e8g009B=`07001B=e8gDSL005Hg00000U8g00<005HgESL00UHg00@005HgESMF
=`8000=B=`03001B=e8g009B=`04001F=eHgESL20004ESL00`00ESMF=`02ESL300000eHg001FE`03
EUL00`00EUMFE`02EUL20004EUL01000EUMFEeIG0P0015IG00<005YGFUL00UYG0P000eYG00<005YG
FUL00UYG0P0015YG00<005YGFUL00UYG00<005YGFUL00UYG00@005YGFUMJE`8000AJM`04001NMeig
0002GWL00`00GWMNM`03GWL00`00GWMNM`02GWL01000GWMNMeig0P001Eig0P000eig00<005igGWL0
0Uig00<005ig000015ig00<005jGGYL00UjG00<006:G00000f:G00L006:GHYMRU`00HYL00004HYL0
0`00HYMRU`03HYL00`00HYMRU`03HYL00`00HYL00003H[L01000H[MR]`000V:g00@006JgI[L0009V
]`04001V]VJf0002I[L01000H[MR]`000VJg00L006JgI[MV]`00I[L00003H[L00`00I[L00002J]L0
1000J]MZe`000VJg00@006JgI[L0009JN006001Vf6KH001VnP0016[h00<005IiEWT00UIi00@004jK
CY]>V`8000AFo006001Bo@00001Bo@0015Km00H005Km000005Km0004E_d30002E_d00`00E_eFo@02
E_d30003E_d01@00Oomoogoo000047oo0P001Goo0`001goo0P0027oo0P00JWoo003oOol:Ool3000>
Ool20004F]/01000EYYFVUJJ0`000UKL00<005KLE]`00UKL0`000eLN00<005<NDah00`0015Ln2`00
0TXi00D004hhCSQ>>00000=>=`05001>5dhGCQL00003CQL30002CSL00`00CSM>=`02CSL01@00CSM>
=dhg000014hg00<004hg00000P000dhg00<004hgCSL00Thg00T0058gDSMB=`00DSL0058g0000158g
00<0058gDSL00U8g00@0058gDSMB=`8000AB=`05001F=eHgESL00002ESL00`00ESL00004DSL00`00
DSMB=`02DSL300000eHg001F=`03ESL01000ESMF=eHg0P0015Hg00<005IGEUL00UIG100000=FE`00
EUL00eIG00H005IGEUL005IG0004EUL01000FUMJEeYG0P0015YG00@005YGFUMJE`8000EJE`04001J
EeYGFUL20004FUL01P00FUMJE`00FUL000EJM`8000=NM`03001NMeig009NM`8000ANM`04001NMeig
0002GWL00`00GWMNM`02GWL00`00GWMNM`03GWL01000GWMNM`000Uig00@005igGWMNM`8000ENU`03
001RUf:G009RU`04001RUf:G0002HYL01`00HYMRUf:G001RU`0000ARU`03001RUf:G00ARU`03001R
]f:g009R]`03001R]`0000=R]`03001V]`0000=V]`03001V]P0000=V]`03001R]`0000=V]`04001V
]fJg0002I[L00`00H[MR]`02000016Jg001Ze`000f[G00<006Jg00000fJg00<005Yh000016KH00<0
06[hJ_P00f[h00<005IiEWT00UIi00@004jK0000009J^P03001Fo5Kl00<000ABo@03001FoEKm00<0
00AFo@06001Fo@00001Fo@0015Km00H005Km000005Km0004E_d20003Ool00`00Oomoo`0=Ool90008
Ool20008Ool2001ZOol00?moo`Qoo`8000moo`800003Ga`005[K00=Jf`06001FVP00001Fg00015KL
00H005KL000005LM0004Eah30003Ech01P00Ech00000D]`000=6W0050012Fd9K@U/00004BST01000
CSQ>>0000dhg00<004hGCQL00ThG0`0000=>=`00CSL00dhg00D004hgCSM>=`0000=>=`04001>=dhg
CSL30002CSL01@00CSM>=dhg000014hg00@0058gDSMB=`8000=B=`03001B=e8g009B=`06001B=e8g
DSL0058g0P0000=B=`00DSL00e8g00<005HgESL00UHg0P000UHg00<0058gDSL00U8g00@0058gDSMB
=`8000=F=`03001F=eHg009F=`06001F=eHg001F=`0015Hg00@005IGEUMFE`8000EFE`03001FEeIG
009FE`80009FE`03001FEeIG009FE`06001JEeYG001JE`0015YG00H005YGFUL005YG0005FUL01000
FUMJE`000UYG00<005YGFUL00UYG0P000eYG00<005YgFWL00UYg00<005igGWL00eig00H005igGWL0
05ig0005GWL20003GWL01000GWMNMeig0P001Eig00<005ig00000eig00@005igGWL0009NM`03001N
UejG009NU`03001RUf:G00=RU`8000=RU`04001RUf:G0002HYL01`00HYMRUf:G001RU`0000ERU`03
001R]f:g00=R]`03001R]f:g00=R]`03001V]fJg00=V]`03001V]fJg00=V]`03001V]fJg009V]`03
001V]`0000=V]`05001R]`00I[L00002I[L00`00J]MZe`03J]L00`00I[MV]`03I[L00`00I]QVf003
I]P00`00J_QZn002J_P00`00I[L00003EWT20005F[X20002Fa`01000D_eBoE;m10000eKm00<005Km
E_d00`0015Km00<005KmE_d00`0015Km00H005Km000005Km0003Ool00`00Oomoo`0=Ool200000goo
000000030009Ool20008Ool2001ZOol00?moo`Eoo`<000ioo`<000AO7003001Jfe[K00<000AFg003
001Fg5KL00@000=G7@04001G7P000003Ecd00`00EciG?P020004D]`01@00AYa6W4JL00000d9K00D0
04XiBSU:>@0000=>>006001>=dhgCSL004hG0`000dhg00<004hgCSL00Thg00D004hgCSM>=`0000A>
=`<00003CQL004hg00=>=`05001>=dhgCSL00003CSL01P00DSL00000DSL000=B=`03001B=e8g009B
=`04001B=e8gDSL20004DSL01@00DSMB=e8g00000eHg0P0015Hg00D0058gDSMB=`00009B=`03001F
=`0000AF=`03001F=eHg009F=`80009F=`03001F=eHg009F=`06001FEeIG001F=`001EIG00@005IG
EUMFE`8000AFE`03001FEeIG009FE`8000=JE`03001JEeYG009JE`8000=JE`03001JEeYG00=JE`80
00=JE`04001JEeYGFUL20004FUL01000FWMJMeYg0P001Eig00<005ig00000eig00<005igGWL00Uig
00<005igGWL00Uig00@005igGWL0009NM`03001NMeig009NM`8000ENM`8000=NM`07001NUejGGYL0
06:G000016:G00<006:GHYL00f:G0P000f:G00@006:GHYL0009RU`03001RUf:G009RU`03001RU`00
00=R]`8000ER]`03001V]fJg00=V]`03001V]fJg00=V]`03001V]fJg00=V]`03001V]fJg00=V]`04
001V]fJg0002I[L00`00J]MZe`03J]L00`00I[MV]`03I[L00`00I]QVf002I]P00`00J]L00002J_P0
1000I[MV]`000UIi00<005ZH000015Zj0P000e/L10000U;m00<005KmE_d00UKm0`000UKm00<005Km
E_d00UKm0`000eKm00<005KmE_d00`0015Km00D007ooOomoo`0000ioo`80011oo`8000Ioo`8006]o
o`00ogoo0Woo0`003Woo0`000eLM00@005lLGaaO70<000=Fo004001Fg5KLE]`30004Ead00`00EaeG
7@030004Ecd30002E]/00`00D]aBg002D]`01000AYa6W0000d9K00D004XiBSU:>@0000=>>003001>
=dhg00<0009>=`03001>=dhg009>=`05001>=dhgCSL00004CSL00`00CSL000020003CQL00`00CSM>
=`02CSL01@00CSM>=dhg00000dhg0P000e8g00<0058gDSL00U8g00H0058gDSMB=`00DSL200000e8g
001B=`03DSL00`00DSMB=`02DSL300000e8g001F=`03ESL00`00DSMB=`02DSL20002ESL00`00ESMF
=`02ESL01000ESMF=eHg0P0015Hg00<005HgESL00UHg0P000eHg00<005IGEUL00UIG00H005IGEUL0
05IG0004EUL01000EUMFEeIG0P0015YG00@005YGFUMJE`8000AJE`03001JEeYG009JE`8000AJE`06
001JEeYG001JEP0015YG00@005YgFWL0009JMP03001NMeig00=NM`03001NMeig009NM`04001NMeig
GWL20005GWL20003GWL01`00GWMNMeig001NM`0000ENM`03001NMeig009NM`04001NUejG0002HYL0
1000HYMRUf:G0P001F:G00<006:GHYL00f:G0P0016:G00@006:GHYL0009RU`04001R]f:g0002H[L0
1`00H[MR]f:g001V]`0000=V]`03001V]`0000=V]`03001V]`0000=V]`8000AV]`80009V]`05001V
]`00I[L00003J]L00`00J]L00003I[L00`00I]L00002I]P01P00J]MZe`00J_P000=V]`03001FN@00
00=JV004001J^UZj0002H_X300000e/L001Bo@04D_d400000eKm001Fo@03E_d01P00E_d00000E_d0
00AFo@<0009Fo@03001FoEKm009Fo@80009oo`03001oogoo00aoo`80011oo`8000Ioo`8006]oo`00
ogoo0`003goo00@005;mD_d000AG7@03001O7000009Fo@03001Fo5Kl009Fo003001Fg000009C7@03
001G7ELM009G7@<000=G7@06001G?@00001Fg00015KK00<005;LD]`02@0014Xi00<004hh00000`00
00=:6000CSL00dhg00D004hgCSM>=`0000A>=`03001>=`0000<0009>5`03001>5dhG009>5`05001>
=dhgCSL00003CSL01P00CSL00000CSL000AB=`05001B=e8gDSL00003DSL20003DSL00`00DSMB=`02
DSL01000DSMB=e8g0P00158g00D005HgESMF=`0000=B=`8000AF=`05001F=eHgESL00002ESL00`00
ESL00004ESL01000ESMF=eHg0P0015Hg00<005IGEUL00eIG0P000UIG00<005IGEUL00UIG00H005IG
EUL005YF0004FUL01P00FUMJE`00FUH000EJE`06001JEeYG001JEP001EYG0P000eYF00<005YGFUL0
0UYG0P000eYf00<005igGWL00Uig0P0015ig00@005igGWL0009NM`03001NMeig009NM`03001NMeig
009NM`04001NMeig0003GWL01000GWMNMeig0P001Eig0P000f:G00@006:GHYL0009RU`04001RUf:G
HYL20005HYL00`00HYMRU`03HYL00`00HYL00003HYL00`00H[L00003H[L01000H[MR]`000VJg00@0
06JgI[L0009V]`04001V]fJg0002I[L01000I[MV]`000VJg00@006JgI[L0009V]`04001V]`000002
I[L01000J]MZe`000V[G00@006JgI[L0009Ve`03001Vf00000AZe`03001V]fJg00=V]`03001JV5ZH
009JV003001J^P0000=RnP03001K75/L009K7003001BoE;m00<000EFo@03001FoEKm00<000AFo@06
001Fo@00001Fo@0015Km00H005Km000005Km0002Ool2000=Ool2000AOol20004Ool2001/Ool00?ao
o`<000=oo`03001oogoo00Uoo`<000ABo@03001G7ELM00<000AFo@03001Fo5Kl00<000AC7@04001G
7@000002Ead00`00EaeG7@030004E]`01000E]]FfeKK0`000ThG00@003Vg>KL0008i]`L0009:6005
001:64XHBQP00003CSL01@00CSM>=dhg00000dhg0`000ThG00<004hGCQL00ThG00D004hGCQM>5`00
00A>=`03001>=`00008000=>=`03001B=e8g009B=`06001B=e8gDSL0058g0P0000=B=`00DSL00e8g
00<0058gDSL00U8g0`0000=B=`00DSL00e8g00<005HgESL00UHg0`0000=B=`00ESL00eHg00<005Hg
ESL00UHg0P000UHg00<005HgESL00UHg00H005HgESL005Hg0005ESL01000EUMFEeIG0P0015IG00<0
05IGEUL00UIG0P000eYF00<005YGFUL00UYG0P000eYF00<005YGFUL00UYG00<005YG00000eYF00<0
05YGFUL00UYG00<005YFFUH00UYF00@005YGFUMJE`8000EJMP04001NMeig0002GWH00`00GWMNM`02
GWL20003GWL01000GWMNMeig0P001Eig0P0015ig00@005igGWL0009NM`03001NMeig009NM`03001R
Uf:G00=RU`8000=RU`04001RUf:G0002HYL01000HYMRUf:G0P001V:G00<006:GHYL00f:G00<006:g
H[L00V:g00<006:g00000fJg00<006Jg00000fJg00<006Jg00000fJg00<006Jg00000fJg00<006Jg
00000fJg00<006Jg00000fJg00<006[G00000f[G00<006Jg000016KG00<006[GJ]L00f[G00<006Jg
I[L00VJg0P001EZH00@006;jH_YRnP8000AK70<0009>o@03001FoEKm009Fo@@0009Fo@04001FoEKm
E_d30004E_d00`00E_eFo@030004E_d20002Ool00`00Oomoo`0:Ool:0009Ool8001/Ool00?Yoo`80
00Moo`03001oogoo00Eoo`<000=Fo@03001BoE;m00@000=Fo@03001FoEKm00@000=Bo@03001C7E<M
00<000AG7@<0009Fg003001Fg5KL009Fg006001Ff`00001B=`0014hG00@003Vg>KL0008i]`050016
64HHAQP00004BQP01000BQQ:60000dhg00<004hgCSL00Thg0`0000=>5`00CQL00dhG00D004hGCQM>
5`0000=>5`04001>=dhgCSL30002CSL00`00CSM>=`02CSL01@00DSMB=e8g00000e8g0P000e8g00<0
058gDSL00U8g00@0058gDSMB=`8000=B=`03001B=e8g009B=`04001F=eHgESL20003DSL00`00ESMF
=`02ESL01000ESMF=eHg0P0015Hg00<005HgESL00UHg0P000eHg00<005HgESL00UHg00H005IGEUL0
05IF0004EUL01000EUMFEeIG0P0015YF00@005YGFUMJE`8000AJEP03001JEeYG009JE`8000AJEP04
001JEeYGFUL20004FUH01P00FUMJE`00FUH000EJMP03001NM`0000=NMP04001NMeigGWL20004GWL0
1000GWMNM`000Uig00<005igGWL00Uig00<005igGWL00eig00<005ig00000eig00@005igGWMNM`80
00ERU`03001RUf:G009RU`03001RU`0000=RU`04001RUf:G0002HYL00`00HYMRU`02HYL20005HYL0
0`00H[MR]`03H[L00`00I[MV]`03I[L00`00I[MV]`03I[L00`00I[MV]`03I[L00`00I[MV]`03I[L0
0`00I[MV]`03I[L20004I[L00`00J]MZe`03J]L00`00I]MVe`03I]L00`00J]MZe`02J]L00`00J]L0
0002I[L01000I[MV]`000eZH0P000V;j00D006LIIaT005/L0080009K?@06001>oDkmC_d005Km0P00
00=Fo@00E_d00eKm10000UKm00@005KmE_eFo@@0009Fo@04001FoEKmE_d30002Ool00`00Oomoo`0:
Ool:000;Ool4001^Ool00?Moo`<000moo`800003E_d005Km00=Fo@<0009Fo@03001FoEKm009Fo@<0
00=Bo@03001BoE;m00@000=G7@04001G7@000002E]`01@00E]aFg5KL00000UKL0`00158g00D004hG
CQM>5`00008i]`05000i]cVg>KL00003AQP01@00BQQ:64XH00000dXH00H004hgCSM>=`00CSL30003
CQL00`00CQM>5`02CQL01@00CQM>5dhG000014hG0`0000=>5`00CSL00dhg00D004hgCSM>=`0000AB
=`<00003DSL0058g00=B=`05001B=e8gDSL00002DSL00`00DSL00004DSL00`00DSMB=`02DSL30000
0e8g001B=`03DSL00`00ESMF=`02ESL300000eHg001F=`03ESL01000ESMF=eHg0P0015Hg00<005Hg
ESL00UHg00<005IG00000UIF00<005IGEUL00UIG00H005IGEUL005IF0004FUH01P00FUMJE`00FUH0
00EJEP06001JEeYG001JEP0015YF00H005YGFUL005YF0005FUH20003FUH00`00FWIJMP03FWH00`00
GWINMP02GWH01P00GWMNM`00GWH000ENM`8000=NM`04001NMeigGWL20006GWL00`00GWMNM`02GWL0
1000GWMNM`000Uig00@006:GHYMRU`8000ERU`03001RUf:G009RU`03001RU`0000ARU`04001RUf:G
0002HYL01`00HYMRUf:G001RU`0000=R]`8000EV]`03001V]fJg00=V]`03001V]fJg00=V]`03001V
]fJg00=V]`03001V]fJg00=V]`8000AV]`03001Zef[G00=Ze`03001VefKG009Ve`03001Ve`00009Z
e`06001Zef[G001V]`000fJg00@005ZHFYP0009Vf08000AW6@03001K?E/m009K?@H000AFo@06001F
o@00001G7@001EKm0`0000=Fo@00E_d00eKm10000UKm00D007ooOomoo`00099oo`00mGoo0P003goo
10000eKm00@005Km0000009Fo@06001FoEKmE_d005Km0P000UKm00@005;mD_eBo@<000AG7@03001G
7ELM008000EFg003001Fg5KL00<0009>>003001B=e8g009B=`05001>5dhGCQL00003>KL01000>KLi
]`000dHH00D004XHBQQ:600000=:6003001>=dhg00<0009>5`03001>5dhG009>5`05001>5dhGCQL0
0004CQL00`00CQL000020003CQL00`00CSM>=`02CSL01@00CSM>=dhg00000e8g0P000e8g00<0058g
DSL00U8g00<0058gDSL00U8g0P000U8g00<0058gDSL00U8g00@0058gDSMB=`8000=B=`03001B=e8g
009B=`04001F=eHgESL20004ESL01@00ESMF=eHg00000UHg00<005Hf00001EHg00@005HgESMF=`80
00AFEP03001FEeIG009FE`80009FEP03001JEUYF00=JEP8000=JEP03001JEUYF009JEP03001JE`00
009JEP03001JEUYF00=JEP8000=JEP03001JEUYF009JEP03001JEUYF009JEP03001JMUYf009JMP80
00ENMP8000=NMP03001NMeig009NM`03001NMeig009NM`04001NMeig0002GWL00`00GWMNM`03GWL0
0`00GWMNM`03GWL20003GWL01000HYMRU`000V:G00<006:GHYL00V:G00<006:GHYL00f:G00<006:G
HYL00f:G00<006:G00000f:G00@006:GHYL0009RU`04001R]f:g0002H[L01`00I[MV]fJg001V]`00
00=V]`03001V]`0000=V]`03001V]`0000=V]`03001V]`0000=V]`03001V]`0000=V]`03001V]`00
00=Ze`03001Ve`00009Ve`06001VefKG001Ze`0016[G00<006JgI[L00VJg00<005ZH00000fKH00<0
06LIIaT00VLI00@006/I001K?@800003F_`004kM00=>g@03001FoEKm00<000AG7@03001FoEKm00<0
00AFo@06001Fo@00001Fo@001EKm00D007ooOomoo`00095oo`00lWoo0`003Woo0`0015Km00<005Km
E_d00P001EKm00<005KmE_d00`0015Km00<005;m00000UKm00<005LMEad00ULM0`000UKl00<005KL
E]`00UKL0`0000=BF000CSP00dhh00D0058gDSMB=`0000A>5`04000i]cVg0002>KL01@00AQQ664HH
000014XH00<004XH00000`0000=>5`00CQL00dhG00D004hGCQM>5`0000A>5`03001>5`0000<0009>
5`03001>5dhG009>5`05001>=dhgCSL00004CSL300000e8g001B=`03DSL01@00DSMB=e8g00000e8g
0P00158g00D0058gDSMB=`00009B=`03001B=`0000AB=`05001B=e8gDSL00002ESL00`00ESL00004
ESL00`00ESMF=`02ESL20003ESH00`00ESMF=`02ESL01P00ESMF=`00ESH000AFEP04001FEeIGEUL2
0004EUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJ
EP02FUH00`00FUIJEP02FUH01000FUIJEUYF0P001EYF00@005YfFWH0009NMP03001NMUif009NMP03
001NMUif009NMP04001NMeigGWL20005GWL20003GWL00`00GWMNM`02GWL00`00GWL00004GWL00`00
GWMNM`02GWL00`00HYL00003HYL01`00HYMRUf:G001RU`0000ARU`03001RUf:G00ARU`03001RUf:G
009RU`03001RU`0000=RU`03001R]`0000=R]`04001V]fJg0002I[L01000I[MV]`000VJg00@006Jg
I[L0009V]`04001V]fJg0002I[L01000I[MV]`000VJg0P0000EV]`00I[MV]`00009Ze`06001VefKG
001Ve`0016KG00<006[GJ]L00f[G00<006JgI[L00fJg00<006KHI]P00VKH00D006LIIaUW6@0000=[
6@03001Jo5[l009Jo003001>gDkM00@000=Fo@03001G7ELM00@000=Fo@03001FoEKm00<000AFo@03
001FoEKm00<000=oo`03001oogoo08moo`00l7oo0P0047oo00@005KmE_d000AFo@<0009Fo@03001F
oEKm009Fo@<000=Fo@03001FoEKm00<000AFo@06001G7@00001Fo00015Kl00H005KL0000059I0003
DUP01@00CSQ>>4hh0000158g00<004hG00001@000cVg00H004HHAQQ66000BQP40002BQL01@00CQM>
5dhG00000dhG00D004hGCQM>5`0000=>5`<0009>5`03001>5dhG009>5`05001>5dhGCQL00004CSL0
0`00CSL000020004DSL01@00DSMB=e8g0000158g0`0000=B=`00DSL00e8g00<0058gDSL00U8g0P00
0U8g00<0058gDSL00U8g00<0058gDSL00U8g0P000UHg00<005HgESL00UHg00@005HgESMF=`8000AF
=P03001F=eHg009F=`03001F=`00009F=P03001FEUIF009FEP06001FEeIG001FEP0015IF00@005YF
FUIJEP8000EJEP04001JEUYFFUH20004FUH01000FUIJEUYF0P0015YF00H005YFFUH005YF0005FUH0
0`00FWH00003GWH01000GWINMUif0P0015if00@005igGWL0009NMP03001NMeig009NM`03001NMeig
00=NM`04001NMeig0002GWL01000GWMNMeig0P001Eig00<006:GHYL00V:G00@006:GHYL0009RU`07
001RUf:GHYL006:G00001F:G00<006:GHYL00f:G00<006:GHYL00f:G00<006:gH[L00V:g00<006Jg
00000fJg00<006Jg00000fJg00<006Jg00000fJg00<006Jg00000fJg00<006Jg00000fJg0`000fJg
00<006[G000016KG00<006KGI]L00fKG00<006[GJ]L00V[G00<006[G00000fJg0P000fKH00D006[h
001W6@0000A[6@03001Jo5[l009Jo0<0009>V`03001FoEKm009Fo@<0009Bo@03001FoEKm009Fo@<0
00=Fo@03001FoEKm00@000=Fo@05001oogooOol0002@Ool00>eoo`<000moo`<000AFo@06001Fo@00
001Fo@0015Km00H005Km000005Km0004E_d30002E_d00`00E_eFo@02E_d20004E_`00`00E_aFo003
0004DUT01000DUQBF0000dhh00@0058gDSMB=`<00099mP030011]T6f00X0009:5`03001:5dXG009:
5`04001>5dhG0003CQL00`00CQM>5`02CQL300000dhG001>5`02CQL00`00CQM>5`02CQL01@00CQM>
5dhG00000dhg0`000Thg00<0058gDSL00U8g00D0058gDSMB=`0000=B=`8000AB=`05001B=e8gDSL0
0003DSL20004DSL01@00DSMB=e8g00000e8g0P0015Hg00<005HgESL00UHg0`0000=F=P00ESH015Hf
00@005HgESMF=`8000AF=P03001FEUIF009FEP80009FEP03001FEUIF009FEP04001JEUYF0002FUH0
0`00FUIJEP02FUH01P00FUIJEP00FUH000AJEP06001JEUYF001JEP001EYF0P000eYF00<005YFFUH0
0UYF0P0015if00H005ifGWH005if0005GWH20003GWH01000GWMNMeig0P001Eig00<005ig00000eig
00@005igGWL0009NM`03001NMeig009NM`03001RUf:G00=RU`8000=RU`04001RUf:G0002HYL00`00
HYMRU`02HYL00`00HYL00003HYL20005HYL00`00H[MR]`03H[L00`00I[MV]`03I[L00`00I[MV]`03
I[L00`00I[MV]`03I[L00`00I[MV]`03I[L00`00I[MV]`03I[L00`00I[MV]`03I[L00`00I]MVe`03
I]L00`00I]MVe`02I]L00`00I]L00002J]L01000J]MZe`000VJg00H006KHI]P006KH0003J_P00`00
JaU[6@02JaT01000KaP005[l0P0000=FN@00CY/00djK00H005Km000005Kl0004D_d01P00E_d00000
E_d000AFo@<0009Fo@03001FoEKm009Fo@8000=oo`03001oogoo08eoo`00jWoo0`003Woo10000eKm
00<005KmE_d00`0015Km00<005KmE_d00`0015Km00H005Km000005Km0004E_d01P00E_d00000E_`0
00AFo0<0009BN@03001BFE9I009BF@05001BF59HDUP00003CSP300000dhG0019mP02BOH01@00@KI1
]T6f00000Sfg00D004GgAOM5m`0000A:5`05001:5dXGBQL00003CQL01P00CQM>5dhG001>5`<000=>
5`03001>5dhG009>5`05001>5dhGCQL00004CQL300000dhG001>=`03CSL01@00DSMB=e8g0000158g
0`0000=B=`00DSL00e8g00<0058gDSL00U8g0`0000=B=`00DSL00e8g00<0058gDSL00U8g0`0000=B
=`00ESL00eHg00@005HgESMF=`8000AF=P03001F=UHf009F=P06001F=eHg001F=P0015Hf00@005IF
EUIFEP8000AFEP03001FEUIF009FEP8000=JEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF
009JEP8000=JEP03001JEUYF009JEP03001JEUYF009JEP07001JEUYFFUH005YF00001Eif0P000eif
00<005ifGWH00Uif00<005ifGWH00Uif00@005igGWL0009NMP03001NMeig00=NM`03001NMeig00=N
M`8000=NM`07001NMeigGWL006:G000016:G00<006:GHYL00f:G0P0016:G00@006:GHYL0009RU`04
001RUf:G0002HYL01`00HYMRUf:G001RU`0000=R]`8000EV]`03001V]fJg00=V]`03001V]fJg00=V
]`03001V]fJg00=V]`03001V]fJg00=V]`03001V]fJg009V]`8000AVe`03001Ve`00009Ve`04001V
efKG0002J]L01P00J]MZe`00I[L000=Vf003001Vf00000=Zn005001[6F/IJaT00003KaP00`00EWUF
N@02EWT01000CY]>VdjK0P0015Kl00<005;mD_d00`0015Km00H005Km000005Km0004E_d01P00E_d0
0000E_d000=oo`03001oogoo08eoo`00j7oo0P003Woo0`000UKm00<005KmE_d00UKm0`000eKm00<0
05KmE_d010000eKm00<005KmE_d010000eKm00<005KmE_d010000eKl00H005Kl000005KK0004DWT0
1@00DUUBFE9I00000e9H00<004hhCSP00P000dhG00<004WfBOH00TWf00@0046f@KH000<m]`050015
mdGgAOL00003BQL01@00BQM:5dXG00000dhG00<004hGCQL00`000ThG00<004hGCQL00ThG00D004hG
CQM>5`0000A>5`03001>5`00008000=>5`03001>=dhg009>=`03001B=e8g009B=`03001B=`000080
00AB=`05001B=e8gDSL00003DSL20003DSL00`00DSMB=`02DSL01000DSMB=e8g0P00158g00D005Hg
ESMF=`00009F=`03001F=P0000AF=P03001F=UHf009F=P03001F=`00009F=P03001F=UHf009F=P06
001FEUIF001FEP0015IF00@005IFEUIFEP8000EJEP04001JEUYFFUH20004FUH01000FUIJEUYF0P00
15YF00@005YFFUIJEP8000AJEP04001JEUYF0003FUH00`00GWINMP02GWH00`00GWINMP02GWH01000
GWINMUif0P001Eif0P000eif00<005igGWL00Uig0P001Eig00<005igGWL00Uig00@005igGWL0009R
U`04001RUf:GHYL20005HYL00`00HYMRU`03HYL00`00HYL00003HYL00`00HYL00003HYL01000HYMR
U`000V:G00@006:gH[L0009V]`07001V]fJgI[L006Jg00000fJg00<006Jg00000fJg00<006Jg0000
0fJg00<006Jg00000fJg0`000VJg00@006JgI[L0009Ve`06001VefKG001Ve`000fKG00<006[G0000
16[G00<006KHI]P00fKH00T006[hJ_QZn000K_L006/I000016lH00<005IiEWT00UIi00H004jK0000
05Zj0004E_`30003D_d00`00E_eFo@030004E_d00`00E_eFo@030004E_d01@00Oomoogoo0000SWoo
003UOol3000>Ool20002E_d01P00E_eFoEKm001Fo@80009Fo@04001FoEKmE_d30003E_d01000E_eF
oEKm0`0015Km00<005KmE_d00`0015Km00<005KlE_`00P0015KK00D0059iDWUBN@0000ABF@03001B
F00000<00003CQL004hG00=>5`050019mTWfBOH00003@KH01000?KLm]`000dGg00D004XGBQM:5`00
00A:5`03001>5`0000<00003CQL004hG00=>5`05001>5dhGCQL00003CQL01000CQM>5dhG0`000ThG
00<004hGCQL00ThG00D004hgCSM>=`0000=B=`<0009B=`03001B=e8g009B=`03001B=e8g009B=`<0
0003DSL0058g00=B=`03001B=e8g009B=`<00003DSL0058g00=B=`03001F=eHg009F=`8000=F=P03
001F=UHf009F=P04001F=UHfESH20004ESH00`00ESIF=P02ESH20002EUH00`00EUIFEP02EUH01P00
EUIFEP00EUH000EJEP06001JEUYF001JEP0015YF00H005YFFUH005YF0004FUH01000FUIJEP000UYF
00<005YFFUH00UYF0P0015YF00@005ifGWINMP8000ANMP04001NMUif0002GWH00`00GWINMP02GWH0
0`00GWINMP03GWH01000GWMNM`000Uig00<005igGWL00Uig00<005igGWL00eig0P000f:G00@006:G
HYL0009RU`04001RUf:GHYL20006HYL00`00HYMRU`03HYL00`00HYMRU`02HYL00`00HYL00003HYL0
0`00H[L00003I[L01000I[MV]`000VJg00@006JgI[L0009V]`04001V]fJg0002I[L01000I[MV]`00
0VJg00D006JgI[L006Jg00800003I[L006Jg009V]`03001Ve`0000AVe`03001VefKG00=Ve`03001Z
ef[G00=Ze`03001Vf6KH009Vf080009Zn005001^mfkgK_L00004KaP00`00J]L00003EWT20004F[X0
1000E_`000000U/L00<005;mD_d010000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`000goo
00<007ooOol0Rgoo003SOol2000?Ool20005E_d00`00E_eFo@030004E_d00`00E_d00002E_d00`00
E_eFo@02E_d00`00E_d00002E_d00`00E_eFo@02E_d30002E_d00`00E_eFo@02E_d30002Ech01@00
E]]FfeKK00000e9i00<0059IDUT010000ThG00@004hGCQL000A>5`050019mTWfBOH00003@KH01000
?KLm]`000dGg00<004XGBQL00TXG00<004XG00000`000TXG00D004hGCQM>5`0000=>5`05001>5dhG
CQL00004CQL300000dhG001>5`03CQL01@00CQM>5dhG000014hg0`0000=B=`00DSL00e8g00D0058g
DSMB=`0000=B=`8000=B=`03001B=e8g009B=`04001B=e8gDSL20003DSL00`00DSMB=`02DSL01000
ESMF=eHg0P0015Hf00<005HfESH00UHf00H005HfESH005Hf0004ESH01000ESIF=UHf0P0015IF00<0
05IFEUH00UIF0P000eIF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH00UYF0P000eYF00<0
05YFFUH00UYF0P000eYF00@005YFFUIJEP8000EJEP06001NMUif001NMP001Eif0P000eif00@005if
GWINMP8000ENMP03001NM`0000=NM`07001NMeigGWL005ig000015ig00<006:GHYL00f:G0P000f:G
00@006:GHYL0009RU`03001RUf:G009RU`8000ERU`03001RUf:G00=RU`03001RUf:G00=RU`03001V
]fJg009V]`03001V]`0000=V]`03001V]`0000=V]`03001V]`0000=V]`03001V]`0000=V]`03001V
]`00009V]`03001V]`0000EV]`03001VefKG00=Ve`03001VefKG00=Ve`03001Zef[G009Ze`03001Z
e`00009Vf003001Zf6[H008000A^m`05001_66lHKaP00002J]L01P00EWUFN@00FYP000AJ^P8000AK
70<0009Bo@03001FoEKm009Fo@06001Fo@00001Fo@0015Km0`000UKm00D007ooOomoo`0008eoo`00
h7oo0`003Woo0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`0015Km00<005KmE_d00`00
15Km00H005Km000005Km0004E_d01000E_d000000ULn00D005LnEciG?P00009Ff`03001BNE9i00@0
009>>003001>5dhG009>5`04001>5dhG0003CQL01@00BOI9mTWf00000d6f00D003fg?KLm]`0000=5
m`03001:5`0000<0009:5`05001:5dXGBQL00003CQL01@00CQM>5dhG000014hG00<004hG00000P00
0dhG00<004hGCQL00ThG00D004hGCQM>5`0000=>=`8000=B=`03001B=e8g009B=`03001B=e8g009B
=`<00003DSL0058g00=B=`05001B=e8gDSL00002DSL00`00DSL00004DSL00`00DSMB=`02DSL30000
0eHf001F=P04ESH01`00ESIF=UHf001F=P00009F=P03001F=UHf009F=P06001F=UHf001F=P0015IF
00@005IFEUIFEP8000AFEP03001JEUYF009JEP8000AJEP04001JEUYFFUH20004FUH01000FUIJEUYF
0P0015YF00H005YFFUH005YF0006FUH20003GWH00`00GWINMP02GWH00`00GWINMP02GWH01000GWIN
MP000Uif00<005ifGWH00eif00<005igGWL00Uig00@005igGWL0009NM`04001NMeigGWL20005HYL0
0`00HYMRU`02HYL00`00HYL00004HYL01000HYMRU`000V:G00L006:GHYMRU`00HYL00004HYL00`00
HYMRU`03HYL00`00I[MV]`03I[L00`00I[MV]`03I[L00`00I[MV]`03I[L00`00I[MV]`03I[L00`00
I[MV]`03I[L01`00I[MV]fJg001V]`0000EV]`03001VefKG009Ve`03001Ve`0000=Ve`03001Ze`00
009Ze`06001Zef[G001Vf0000f[H00<006kgK_L00Vkg00D006kg001_600000=Ze`03001FN@0000=J
V004001J^UZj0002H_X01P00Fa`00000Fa`000ABo@03001FoEKm00<000AFo@06001Fo@00001Fo@00
15Km00D007ooOomoo`0008aoo`00gWoo0P003goo0P0000=Fo@00E_d00eKm00H005Km000005Km0004
E_d30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@030004E_d00`00E_eFo@030004Ech:0002
BSP00`00CSQ>>002CSP01@00CQM>5dhG00000ThG00D004hGCQM>5`0000A9mP060011]T6f@KH003fg
1`000TXG00D004XGBQM:5`0000A:5`05001>5dhGCQL00003CQL00`00CQL000030002CQL00`00CQM>
5`02CQL01@00CQM>5dhG000014hG0`0000=>5`00DSL00e8g00D0058gDSMB=`0000=B=`8000=B=`03
001B=e8g009B=`03001B=e8g009B=`80009B=`03001B=e8g009B=`04001B=e8gDSL20004ESH00`00
ESIF=P02ESH01000ESIF=UHf0P0015Hf00<005HfESH00UHf0P000UHf00<005IFEUH00UIF00H005IF
EUH005IF0004EUH00`00FUIJEP0200000eYF001JEP03FUH01P00FUIJEP00FUH000AJEP06001JEUYF
001JEP001EYF0P000eYF00<005YFFUH00eYF00<005ifGWH00Uif00@005ifGWINMP8000ENMP8000=N
MP03001NMUif009NMP8000ENM`8000=NM`04001NMeig0002GWL00`00HYMRU`02HYL00`00HYMRU`03
HYL00`00HYMRU`03HYL00`00HYL00003HYL01000HYMRU`000V:G00L006:GHYMRU`00HYL00003HYL0
0`00HYL00004I[L00`00I[MV]`03I[L00`00I[MV]`03I[L00`00I[MV]`03I[L00`00I[MV]`03I[L0
1000I[MV]fJg0P0000=V]`00I[L00VJg00<006KG00000VKG00@006KGI]L0009Ve`06001Zef[G001Z
e`0016[G00<006[HJ]P00V[H00D006kgK_M^m`0000=^m`03001Zef[G00=Ze`03001JV5ZH009JV003
001J^P0000ARnP03001K75/L009K7003001BoE;m00@0009Fo@04001FoEKmE_d30004E_d00`00E_eF
o@030003Ool00`00Oomoo`29Ool00=]oo`<000ioo`@000=Fo@03001FoEKm00@000=Fo@06001Fo@00
001Fo@0015Km00H005Km000005Km0004E_d30002E_d00`00E_eFo@02E_d30003Ead01P00Ech00000
D]`000=2W@040012Fd9K0004BSP01@00CSQ>>4hh00000dhG00@004hGCQL000A>5`030019mP0000L0
0003AOL004Gg0095m`05001:5dXGBQL00004BQL01@00BQM:5dXG00000dhG00<004hGCQL00`000ThG
00<004hGCQL00ThG00D004hGCQM>5`0000A>5`03001>5`00008000=>5`03001B=e8g009B=`03001B
=e8g009B=`<00003DSL0058g00=B=`05001B=e8gDSL00003DSL20004DSL01@00DSMB=e8g00000U8g
00<0058f000015Hf00<005HfESH00UHf00H005Hf000005Hf0004ESH01000ESIF=UHf0P0015Hf00<0
05IFEUH00UIF0P000eIF00<005IFEUH00UIF0P000eYF00<005YFFUH00eYF0P000UYF00<005YFFUH0
0eYF0P000eYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH00UYF0P0015if00@005ifGWH0
009NMP03001NMUif009NMP03001NMUif00=NMP04001NMUif0002GWH00`00GWMNM`02GWL00`00GWMN
M`03GWL20003GWL01`00HYMRUf:G001RU`0000ARU`03001RUf:G00ARU`03001RUf:G009RU`03001R
U`0000=RU`04001RUf:G0002HYL01000HYMRU`000V:G00L006JgI[MV]`00I[L00003I[L00`00I[L0
0003I[L00`00I[L00003I[L00`00I[L00003I[L00`00I[L00002I[L01000I[MV]`000VJg00H006KG
I]L006KG0003I]L00`00I]L00004J]L00`00J]MZe`03J]L01`00J]QZf6[H001Zn000009^m`05001^
mfkgK_L00005J]L00`00FYQJV003FYP00`00H_YRnP02H_X20003Fa`40002C_d01000E_eFoEKm1000
0UKm00<005KmE_d01@000UKm00D007ooOomoo`0008]oo`00f7oo0`000goo00<007ooOol027oo0`00
15Km00<005KmE_d00`0015Km00<005KmE_d00`000eKm00<005KmE_d010000eKm00@005Km0000009F
o@06001FoEKmE_d005Km0P000eLM00<005LMEad00P0015;L00D004:M@Ye2W@000092F`05001:>4Xh
BSP00003CSP00`00CQM>5`02CQL01@00CQM>5`00CQL010000TWg00D004GgAOM5m`0000=5m`050015
mdGgAOL00003BQL01@00BQM:5dXG00000dXG00T004hGCQM>5`00CQL004hG00000dhG00<004hGCQL0
0ThG00D004hGCQM>5`0000=>5`<0009>5`03001>5dhG009>5`05001B=e8gDSL00003DSL20003DSL0
0`00DSMB=`02DSL00`00DSMB=`02DSL300000e8g001B=`03DSL00`00DSMB=`02DSL20003DSH00`00
ESIF=P02ESH01000ESIF=UHf0P0015Hf00D005HfESIF=P00009F=P03001F=P0000AF=P04001FEUIF
EUH20004EUH01000EUIFEUIF0P001EYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH00UYF
00<005YFFUH00UYF00@005YFFUIJEP8000EJEP06001JEUYF001NEP001Eif0P000eif00@005ifGWIN
MP8000ENMP03001NMP0000=NMP04001NMeigGWL20005GWL00`00GWMNM`02GWL01000HYMRU`000V:G
00L006:GHYMRU`00HYL00005HYL00`00HYMRU`03HYL00`00HYMRU`03HYL20003HYL00`00HYL00003
HYL01000I[MV]`000VJg00@006JgI[L0009V]`04001V]fJg0002I[L01000I[MV]`000VJg00@006Jg
I[L0009V]`04001V]`000002I[L00`00I[L00004I]L00`00I]MVe`03I]L00`00J]MZe`03J]L00`00
J]MZe`02J]L01@00J]L006[H00000V[h00<006kg00000fkg00<006kf00000f[G00<006Jg00000eZH
0P000f;j00<006/IJaT00`0000=K7000C_d014km0`0000=Fo@00E_d00eKm0`000UKm00<005KmE_d0
0UKm0P000goo00<007ooOol0R7oo003FOol20007Ool00`00Oomoo`06Ool01000E_eFo@0015Km0`00
0UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`0015Km00<005KmE_d00`0015Km00<005KmE_d0
0`0015LM0`000UKK00D005;LD]aBg00000=2W@050012Fd9K@U/00002BSP00`00CSQ>>002CSP00`00
CQL000060002BQL01@00BOM9mdWg000014Gg00@004GgAOL000=5m`05001:5dXGBQL00003BQL00`00
BQM:5`02BQL00`00CQL000020003CQL01@00CQM>5dhG00000dhG00<004hGCQL00ThG0`0000=>5`00
CQL00ThG00<004hGCQL00ThG00<0058gDSL00U8g0`0000=B=`00DSL00e8g00D0058gDSMB=`0000=B
=`8000=B=`03001B=e8g009B=`04001B=e8gDSL20004DSH00`00ESIF=P02ESH01P00ESIF=P00ESH0
00AF=P03001F=UHf009F=P80009F=P03001F=UHf009F=P06001FEUIF001F=P0015IF00H005IFEUH0
05YF0005FUH01000FUIJEUYF0P0015YF00@005YFFUIJEP8000AJEP04001JEUYF0002FUH00`00FUIJ
EP02FUH00`00FUH00003GUH00`00GWINMP02GWH00`00GWINMP02GWH01000GWINMP000Uif00<005if
GWH00eif00<005ifGWH00Uif00@005igGWL0009NMP03001NMeig009NM`03001NMeig00=NM`8000=R
U`04001RUf:G0002HYL00`00HYMRU`02HYL00`00HYL00004HYL00`00HYMRU`03HYL00`00HYMRU`03
HYL00`00HYMRU`03HYL20003I[L00`00I[L00003I[L00`00I[L00003I[L00`00I[L00003I[L00`00
I[L00004I[L00`00I[L00003I[L00`00I]MVe`03I]L00`00I]MVe`03I]L00`00J]MZe`02J]L00`00
J]L00002J]L01P00J]MZe`00J]P000=Zn003001^mfkg009^m`03001^mP00009Ze`04001V]fJg0002
FYP01P00I]QVf000H_X000=[6@03001K75/L009K7003001>oDkm00<000AFo@06001Fo@00001Fo@00
15Km00H005Km000005Km0004Ool00`00Oomoo`27Ool00==oo`<000moo`<000AFo@06001Fo@00001F
o@0015Km00H005Km000005Km0004E_d30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@040003
Ead01P00Ead00000E]`000AFf`03001Bg5;L00T000=:>003001>>00000<0009:5`04001:5dXG0003
BQL00`00BOM9m`02BOL01@00AOM5mdGg00000dGg00@004GgAOL000=:5`03001:5dXG009:5`03001:
5`0000<0009:5`05001>5dhGCQL00003CQL00`00CQM>5`02CQL00`00CQL000020003CQL00`00CQM>
5`02CQL01@00CQM>5dhG00000e8g0P000e8g00<0058gDSL00U8g00<0058gDSL00U8g0`0000=B=`00
DSL00e8g00<0058gDSL00U8g0`0000=B=P00DSH0158f00L005HfESIF=P00ESH00002ESH00`00ESIF
=P02ESH01000ESIF=UHf0P0015Hf00<005HfESH00UHf0P000UHf00<005IFEUH00eIF0P000eYF00<0
05YFFUH00UYF00H005YFFUH005YF0004FUH01P00FUIJEP00FUH000EJEP8000=JEP03001JEUYF00=J
EP03001NEUiF009NEP04001NMUifGWH20005GWH20003GWH00`00GWINMP02GWH20005GWH20003GWH0
1`00GWMNMeig001NMP0000ANM`03001RUf:G00=RU`8000ARU`04001RUf:G0002HYL01`00HYMRUf:G
001RU`0000ARU`03001RUf:G00=RU`03001RUf:G00=RU`03001V]fJg00=V]`03001V]fJg00=V]`03
001V]fJg00=V]`03001V]fJg00=V]`03001V]fJg00=V]`03001V]`0000=V]`03001VefKG009Ve`03
001Ve`0000=Ve`03001Ve`00009Ze`06001Zef[G001Ze`0016[G00<006[hJ_P00V[h00D006kgK_M^
m`00009^mP03001Ze`0000=V]`03001JV00000AVf004001[6F/IJaT20004Fa`30003C_d00`00E_eF
o@030004E_d00`00E_eFo@030004E_d01@00Oomoogoo0000RGoo003AOol2000?Ool30003E_d00`00
E_eFo@030004E_d00`00E_eFo@030004E_d01P00E_d00000E_d000AFo@06001Fo@00001Fo@0015Km
0`000eLM00<005LMEad00`0015KL00<005KKE]/0100000=>=`00>KL00SVg00<003Fh=KP01P000TXH
00D004XGBQM:5`0000=:5`05001:5dXGBQL00003BOL01@00AOM5mdGg00000dGg00D004GgAOM5m`00
00=:5`03001:5`0000<0009:5`03001:5dXG009:5`05001>5dhGCQL00002CQL01000CQM>5dhG0`00
0ThG00<004hGCQL00ThG00D004hGCQM>5`0000A>5`<00003DQL0058g00=B=`05001B=e8gDSL00003
DSL20003DSL00`00DSMB=`02DSL01000DSMB=e8g0P00158f00<0058fDSH00U8f00@005HfESIF=P80
00AF=P03001F=UHf009F=P<00003ESH005Hf00=F=P04001F=UHfESH20004ESH00`00EUIFEP02EUH0
0`00FUIJEP02FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP02FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P0015iF00@005ifGWH0009NMP03001NMUif009NMP03001NMUif
00=NMP04001NMUif0002GWH00`00GWINMP02GWH00`00GWINMP02GWH01000GWMNM`000Uif00@005ig
GWMNM`8000ERU`03001RUf:G00=RU`03001RU`0000=RU`04001RUf:G0002HYL01`00HYMRUf:G001R
U`0000=RU`03001RU`0000=RU`8000EV]`03001V]fJg00=V]`03001V]fJg00=V]`03001V]fJg00=V
]`03001V]fJg009V]`04001V]`000002I[L00`00I[L00002I]L01000I]MVe`000VKG00H006KGI]L0
06[G0004J]L00`00J]MZe`03J]L02@00J_QZn6[h001Zm`00K_L00004K_H00`00I[MV]`03I[L00`00
I]QVf003I]P01000JaU[6@000V/I00@005/L0000009K7003001>oDkm00@0009Fo@03001FoEKm009F
o@<000=Fo@03001FoEKm00<000=oo`03001oogoo08Ioo`00cWoo0`003goo0P000UKm00@005KmE_eF
o@<0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00<000AFo@06001F
o@00001Fo@0015LM0`000UKl00<005KLE]`00UKL0`000U9H00D004hgCSM>=`0000<i]`04000e^3Fh
0002AOP00`00BQQ:6002BQP01@00BQM:5dXG00000TXG00D004XGBQM:5`0000=9m`030015mdGg0095
m`040015mdGg0002AOL70002BQL00`00BQM:5`02BQL01@00BQM:5dXG00000dhG00@004hGCQM>5`<0
0003CQL004hG009>5`03001>5dhG009>5`05001>5dhGCQL00003CQL20003DQL00`00DSMB=`02DSL0
0`00DSMB=`02DSL300000e8g001B=`03DSL01@00DSMB=e8g00000U8g00<0058f0000158f00<0058f
DSH00U8f00H005Hf000005Hf0004ESH01000ESIF=UHf0P000eHf00<005HfESH00UHf00H005HfESH0
05Hf0004ESH01000EUIFEUIF0P001EYF00@005YFFUIJEP8000AJEP04001JEUYFFUH20004FUH01000
FUIJEUYF0P001EYF00H005YFFUH005YF0005GUH20003GWH01000GWINMUif0P001Eif00<005if0000
0eif00@005ifGWINMP8000ENMP8000=NMP04001NMeig0002HWH01000HYMRUf:G0P001V:G00<006:G
HYL00f:G0P000f:G00@006:GHYL0009RU`04001RUf:G0002HYL01000HYMRU`000VJg00L006JgI[MV
]`00I[L00003I[L00`00I[L00003I[L00`00I[L00003I[L00`00I[L00002I[L00`00I[MV]`020000
1fJg001V]fJg001Ve`0000=Ve`03001Ve`0000AVe`03001Zef[G00=Ze`03001Zef[G009Ze`05001Z
e`00J_P00002J_L00`00K_L00004K_H00`00I[MV]`03I[L00`00I]QVf002I]P01000J_P0000016/I
00<005/LFa`00U/L0`000Tkm00<005KmE_d00UKm00H005Km000005Km0004E_d30002E_`00`00Oomo
o`02Ool00`00Oomoo`25Ool00<aoo`80011oo`<000AFo@03001Fo@00009Fo@06001FoEKmE_d005Km
0P000UKm00@005KmE_eFo@<000AFo@03001FoEKm00<000=Fo@03001FoEKm00@000=Fo@04001G7@00
0002E_`01P00E_aFo5Kl001Fg0800003DUT0059H00=BF004001>=dhg0003>KL01@00=KPe^3Fh0000
0TGh00D004XHBQQ:600000=:5`05001:5dXGBQL00002BQL00`00BOM9m`02BOL00`00AOL000070000
0dWg001:5`02BQL00`00BQM:5`02BQL01@00BQM:5dXG00000dXG00D004hGCQM>5`00009>5`8000A>
5`05001>5dhGCQL00003CQL00`00CQM>5`02CQL300000dhG001B5`03DQL01@00DSMB=e8g00000e8g
0P000e8g00<0058gDSL00U8g00<0058gDSL00U8g0P000e8f00<0058fDSH00U8f00@0058fDSIB=P80
00=F=P03001F=UHf009F=P06001F=UHf001F=P0015Hf00<005HfESH00UHf0P000UHf00<005HfESH0
0UHf00@005IFEUH0009FEP03001JEUYF009JEP06001JEUYF001JEP0015YF00H005YFFUH005YF0004
FUH01000FUIJEP000UYF00<005YFFUH00UYF00<005YF00000eYF00<005iFGUH00UiF00<005ifGWH0
0Uif00@005ifGWH0009NMP03001NMUif009NMP8000ANMP04001NMUif0002GWH00`00GWINMP02GWH0
0`00GWINMP03GWH20003HWH01000HYMRU`000V:G00<006:GHYL00f:G00<006:GHYL00f:G00<006:G
HYL00f:G0P000f:G00<006:G00000f:G00<006:G00000fJg00@006JgI[L0009V]`04001V]fJg0002
I[L01000I[MV]`000VJg00@006JgI[L0009V]`03001V]`0000=V]`<000AV]`03001VefKG00=Ve`03
001VefKG00=Ve`03001Zef[G009Ze`03001Ze`00009Ze`06001Zef[G001Zn0000f[g00<006kfK_H0
0Vkf00<006[G00000fJg00<006[H00000VKH00@006[hJ_P000A[6@04001_6@00Fa`200000e/m001>
o@03C_d00`00E_eFo@030004E_d01P00E_d00000E_d000AFo005001oogooOol00027Ool00<Uoo`<0
00ioo`@000=Fo@03001FoEKm00<000AFo@03001FoEKm00<000AFo@03001Fo@00009Fo@03001FoEKm
009Fo@<0009Fo@04001FoEKmE_d30004E_d00`00E_eFo@020005E_`00`00E_aFo0020004DUT01@00
DUQBF59H00000dhg00@003Vg>KL000<e^0040015n4Gh0003BQP01@00BQM:5dXG00000dXG00H004XG
BQM:5`00BOL40002AOL01@00AOM5mdGg00000TWg00<004XGBQL00TXG00D004XGBQM:5`0000=:5`03
001:5dXG009:5`03001>5`0000<00003CQL004hG00=>5`05001>5dhGCQL00004CQL00`00CQL00002
0003CQL00`00DQMB5`02DQL00`00DSMB=`02DSL300000e8g001B=`03DSL01@00DSMB=e8g00000e8g
0P00158f00<0058fDSH00U8f00H0058fDSH0058f0004ESH00`00ESIF=P02ESH20002ESH00`00ESIF
=P02ESH01000ESIF=UHf0P0015Hf00<005HfESH00UHf0P000eIF00<005YFFUH00UYF00<005YF0000
0UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF00<005YFFUH0
0UYF00@005iFGUINEP8000ENMP8000=NMP07001NMUifGWH005if00001Eif0P000eif00@005ifGWIN
MP8000ENMP03001RMV9f009RMP03001RU`0000=RU`03001RUf:G009RU`03001RU`0000ARU`03001R
Uf:G00=RU`03001RUf:G00=RU`03001RUf:G00=RU`03001V]fJg009V]`03001V]`0000=V]`03001V
]`0000=V]`03001V]`0000=V]`03001V]`0000AV]`03001V]fJg00=V]`03001V]fJg00=V]`03001V
efKG00=Ve`03001VefKG009Ve`03001Ze`00009Ze`06001Zef[G001Ze`0016[G00<006[gJ_L00V[g
00D006kfK_I^mP00009Ze`04001V]fJg0002J]P00`00I]P00003J_P01@00JaU[6F/I00000flI00<0
05/mFcd00U/m00<004kmC_d010000eKm00<005KmE_d00`0015Km00<005KlE_`00`000goo00<007oo
Ool0Q7oo0037Ool2000>Ool30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@040003E_d00`00
E_eFo@030004E_d01P00E_d00000E_d000AFo@03001Fo@00009Fo@03001FoEKm009Fo@<0009Fo003
001Fo5Kl009Fo0<00003DWT0059I00=BF@05001BF59HDUP00003CSL01@00>KLi]cVg00000SFh00@0
04GhAOP000A:6006001:5dXGBQL004XG1`000TWg00D004GgAOM5m`0000A5m`040019mdWg0003BQL0
1@00BQM:5dXG000014XG00<004XG00000`000ThG00D004hGCQM>5`0000A>5`04001>5dhG0003CQL3
0002CQL00`00CQM>5`02CQL01@00DQMB5e8G00000e8g0P000e8g00<0058gDSL00U8g00<0058gDSL0
0U8g0`0000=B=P00DSH0158f00L0058fDSIB=P00DSH00002DSH00`00ESIF=P02ESH01000ESIF=UHf
0P0015Hf00D005HfESIF=P00009F=P03001F=P0000AF=P04001F=UHfESH20005EUH01000FUIJEUYF
0P0015YF00<005YFFUH00UYF00<005YFFUH00UYF00@005YFFUIJEP8000EJEP04001JEUYFFUH20004
FUH01000GUINEP000UiF00<005ifGWH00Uif00<005ifGWH00Uif00@005ifGWH000=NMP03001NMUif
009NMP03001NMUif009NMP04001NMUif0002GWH01000GWINMUif0P001F9f00<006:GHYL00f:G00@0
06:GHYL0009RU`07001RUf:GHYL006:G00000f:G0P001F:G00<006:GHYL00f:G00<006JgI[L00fJg
00<006JgI[L00fJg00<006JgI[L00fJg00<006JgI[L00fJg00<006JgI[L00fJg00<006JgI[L00fJg
0P000fJg00<006KG00000fKG00<006KG00000VKG00H006[GJ]L006[G0004J]L00`00J]MZe`03J]L0
1`00J_MZmf[g001Zm`00009^mP06001Zef[G001V]`0016[H00T006[hJ_QZn000KaP006/I000016lI
00<005/mFcd00U/m0`000T[M00<005KmE_d00UKm0`000eLM00<005KmE_d010000UKl00<007ooOol0
0Woo00<007ooOol0Pgoo0034Ool3000>Ool20002E_d01P00E_eFoEKm001Fo@800003E_d005Km00=F
o@<0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00<000AFo@03001FoEKm00<000AFo@06001F
o@00001Fo@0015Kl00H005Kl000005KK0003DWT01@00DUUBFE9I0000159H00<004hg00001`0000He
^000AOQ5n000BQP80002BQL01000BOM9m`000dWg00<004GgAOL00TGg00D004GgAOM5m`000099m`05
001:5dXGBQL00004BQL00`00BQL000030002BQL01@00CQM>5dhG00000dhG00<004hGCQL00ThG00@0
04hGCQM>5`<00003CQL004hG00=>5`05001>5dhGCQL00004DQL300000e8G001B=`03DSL01@00DSMB
=e8g00000e8g0P00158f00<0058fDSH00U8f00@0058fDSIB=P8000AB=P05001F=UHfESH00002ESH0
0`00ESH00004ESH00`00ESIF=P02ESH20002ESH00`00ESIF=P02ESH01P00ESIF=P00ESH000EFEP06
001JEUYF001JEP0015YF00@005YFFUIJEP8000AJEP06001JEUYF001JEP001EYF00@005YFFUH0009J
EP03001JEUYF009JEP8000=NEP04001NMUifGWH20005GWH20004GWH01000GWINMUif0P001Eif0P00
0eif00@005ifGWH0009NMP03001RMV9f009RMP03001RUf:G00=RU`03001RU`0000=RU`04001RUf:G
0002HYL01000HYMRU`000V:G00L006:GHYMRU`00HYL00003HYL00`00HYL00004I[L00`00I[MV]`03
I[L00`00I[MV]`03I[L00`00I[MV]`03I[L00`00I[MV]`02I[L00`00I[L00003I[L00`00I[L00002
I[L01000I]MVe`000VKG00H006KGI]L006KG0004J]L00`00J]MZe`03J]L00`00J]MZe`02J]L20002
J_L01P00J_MZm`00K_H000AZe`03001Zf6[H00=Zf004001Zn6[h0003KaP00`00KaU_6@02KaT01000
KcP005/m0P0000=Jo000B]d00d[M00H005Km000005Km0004Ead30002D_d01000E_aFo5Kl0P000goo
00<007ooOol0Pgoo0031Ool3000?Ool30004E_d00`00E_eFo@030003E_d01000E_d000000UKm00H0
05KmE_eFo@00E_d20002E_d01000E_eFoEKm0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d0
0`0015Km00<005KlE_`00`0015KK00D0059iDWUBN@0000=BF@03001BF00000<00099m`04000m]Sff
0002?KL60002AOP01@00AQM65dHG00000dXG00D004WgBOM9m`0000=9m`050015mdGgAOL00003AOL0
1000BOM9m`0014XG00<004XG00000`000TXG00D004XGBQM:5`0000A>5`05001>5dhGCQL00003CQL0
0`00CQM>5`020003CQL00`00CQM>5`02CQL01@00CQM>5dhG00000e8G0P000e8G00<0058gDSL00U8g
00<0058gDSL00U8g0`0000=B=`00DSH00e8f00<0058fDSH00U8f00H0058f0000058f0004DSH00`00
ESIF=P02ESH20002ESH00`00ESIF=P02ESH01000ESIF=UHf0P0015Hf00<005HfESH00UHf0P000eHf
00<005IFEUH00UIF00<005YF00000UYF00<005YFFUH00UYF00H005YFFUH005YF0005FUH20003FUH0
0`00FUIJEP02FUH00`00FUH00003FUH01000FUIJEUYF0P0015iF00@005ifGWH0009NMP03001NMUif
009NMP03001NMUif00=NMP04001NMUif0002GWH00`00GWINMP02GWH00`00GWINMP02GWH00`00GWH0
0003GWH01`00HWIRMV9f001RUP0000ERU`03001RUf:G00=RU`8000=RU`03001RU`0000=RU`04001R
Uf:G0002HYL01000HYMRU`000V:G00L006JgI[MV]`00I[L00003I[L00`00I[L00003I[L00`00I[L0
0003I[L00`00I[L00002I[L01000I[MV]`000VJg00@006JgI[L0009V]`06001VefKG001Ve`0016KG
00<006[GJ]L00f[G00<006[GJ]L00V[G00<006[G00000V[G00<006[gJ_L00P0016[g00<006[GJ]L0
0f[G00<006[HJ]P00V[H00D006[h001Zn00000=_6005001_6FlIKaT00003KcP01000F_aJo5[l1`00
15Km100000=Bo@00D_d00e;m0`0000=Jo000Ool00goo00<007ooOol0PWoo002oOol2000?Ool30003
E_d00`00E_eFo@040003E_d00`00E_eFo@030004E_d00`00E_eFo@030004E_d00`00E_d00002E_d0
1P00E_eFoEKm001Fo@80009Fo@04001FoEKmE_d30002E_d00`00E_eFo@02E_d30002Ech00`00E]]F
f`02E]/01@00DWUBNE9i00000U9I0`000ThG00D004WgBOM9m`00008m]P05000m]cfg?KL00002@OL0
1@00AOQ5n4Gh000014HG00D004XGBQM:5`000099m`050019mdWgBOL00003AOL00`00AOM5m`02AOL0
1@00BOM9m`00BQL010000TXG00D004XGBQM:5`0000A:5`05001>5dhGCQL00003CQL00`00CQM>5`04
00000dhG001>5`03CQL01@00CQM>5dhG000014hG0`0000=B5`00DQL00e8G00D0058gDSMB=`0000=B
=`8000AB=`03001B=U8f009B=P04001B=U8fDSH20003DSH00`00DSIB=P02DSH01000ESIF=UHf0P00
15Hf00<005HfESH00UHf0`0000=F=P00ESH00eHf00@005HfESIF=P8000AF=P03001FEUIF00=FEP03
001JEUYF009JEP03001JEUYF009JEP8000=JEP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF
009JEP8000AJEP06001JEUYF001JEP001EiF0P000eif00@005ifGWINMP8000INMP8000=NMP04001N
MUifGWH20005GWH00`00GWINMP02GWH01000HWIRMP000V:F00<006:GHYL00V:G0P001F:G00<006:G
HYL00f:G00<006:GHYL00V:G00<006:G00000f:G00<006:G00000f:G00@006JgI[L0009V]`04001V
]fJg0002I[L01000I[MV]`000VJg00@006JgI[L0009V]`03001V]`0000=V]`03001V]`0000=V]`03
001V]`0000AVe`03001VefKG00=Ve`03001Zef[G009Ze`03001Ze`00009Ze`06001Zef[G001Ze`00
0f[g00<006[gJ_L00f[g00<006[GJ]L00V[G00<006[g00000V[H00D006[hJ_QZn00000=_6005001_
5`00KaT00004KcP01P00F_`00000EWT000A>V`03001FoEKm00<000EBo@03001Bo@00008000AJo005
001oogooOol00024Ool00;aoo`<000moo`800003E_d005Km00=Fo@<0009Fo@03001FoEKm009Fo@<0
00=Fo@03001FoEKm00@000=Fo@03001FoEKm00<000AFo@03001FoEKm00<000AFo@03001Fo@00009F
o@06001FoEKmE_d005Km0P000eLn00@005LnEch000=Ff`03001BNE9i00@00003BSP004hG009>5`03
0019mdWg0099m`04000m]Sff0003?KL01000@OM1m`000dGh00D004HGAQM65`0000=:5`040019mdWg
0003BOL00`00AOM5m`02AOL00`00AOL000060002BQL01@00BQM:5dXG000014XG00D004XGBQM:5`00
00=>5`04001>5dhGCQL30002CQL01@00CQM>5dhG00000dhG00<004hGCQL00ThG00<004hG00000P00
0e8G00<0058GDQL00U8G00<0058gDSL00U8g0`0000=B=`00DSL00e8g00<0058fDSH00U8f00H0058f
DSH0058f0004DSH00`00DSIB=P02DSH300000eHf001F=P03ESH01000ESIF=UHf0P000eHf00<005Hf
ESH00UHf00H005HfESH005Hf0005ESH01000EUIFEUIF0P0015YF00@005YFFUIJEP8000AJEP04001J
EUYFFUH20005FUH01P00FUIJEP00FUH000EJEP8000=JEP03001NEUiF009NEP03001NMUif009NMP04
001NMUif0002GWH00`00GWINMP03GWH00`00GWINMP02GWH01000GWINMP000Uif00<005ifGWH00Uif
00<005ifGWH00eif0P0016:F00@006:GHYL0009RUP04001RUf:GHYL20005HYL00`00HYMRU`03HYL0
0`00HYMRU`03HYL00`00HYMRU`03HYL20003I[L00`00I[L00003I[L00`00I[L00003I[L00`00I[L0
0004I[L00`00I[MV]`03I[L00`00I[MV]`02I[L20005I]L00`00I]MVe`02I]L00`00J]L00002J]L0
1P00J]MZe`00J]L000AZe`03001Zmf[g009Zm`03001Zmf[g009Zm`03001Zm`00009Ze`06001Zmf[g
001Zf00016[h00@006lHKaP000=_5`03001_>6lh009_>003001_600000AFN@04001>VdjKCY/30003
E_`00`00D_eBo@040002D_d00`00F_aJo002F_`20003Ool00`00Oomoo`21Ool00;Yoo`8000moo`@0
00=Fo@04001Fo@000002E_d01P00E_eFoEKm001Fo@800003E_d005Km00=Fo@<0009Fo@03001FoEKm
009Fo@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00<000AFo@03001FoEKm00<000AG?PX0009:
>@05001:>4XhBSP00003CQL01@00BOM9mdWg00000Sff00D003fg?KLm]`000091m`050015n4GhAOP0
0003AQL01@00BQM:5dXG00000dWg00H004WgBOM9m`00AOL40002AOL01000BOM9m`000dXG00<004XG
BQL00TXG00D004XGBQM:5`0000=:5`03001>5dhG009>5`<00003CQL004hG009>5`05001>5dhGCQL0
0003CQL01000CQM>5dhG0`000ThG00<0058GDQL00U8G00D0058GDQMB5`0000=B=`8000AB=`03001B
=e8g009B=`07001B=U8fDSH0058f00000U8f00<0058fDSH00U8f00@0058fDSIB=P8000=F=P03001F
=UHf009F=P06001F=UHf001F=P0015Hf00<005HfESH00UHf0P000UHf00<005HfESH00eHf00H005IF
EUH005IF0004FUH01P00FUIJEP00FUH000AJEP06001JEUYF001JEP001EYF00<005YF00000eYF00<0
05YFFUH00UYF00<005YFFUH00UYF00@005iFGUINEP8000ENMP8000=NMP03001NMUif00=NMP03001N
MUif00=NMP8000=NMP07001NMUifGWH005if000015if00<006:FHYH00f:F00<006:G00000f:F00@0
06:GHYL0009RUP07001RUf:GHYL006:G000016:G00<006:GHYL00f:G00<006:GHYL00f:G00<006Jg
I[L00fJg00<006JgI[L00fJg00<006JgI[L00fJg00<006JgI[L00fJg00<006JgI[L00fJg00<006Jg
I[L00VJg0P0016KG00<006KG00000VKG00H006[GJ]L006[G0004J]L00`00J]MZe`03J]L01`00J_MZ
mf[g001Ze`00009Zm`06001Zmf[g001Ze`0016[g00<006[hJ_P00V[h0P000VlH00D006lGKaM_5`00
00=_>004001_66lH0004EWT01P00CY/00000F[X000AFo0<0009Bo@03001BoE;m009Bo@04001Jo000
0002Fa`00`00Oomoo`020022Ool00;Moo`<000ioo`<000AFo@03001FoEKm00<000AFo@03001FoEKm
00<000=Fo@04001Fo@000002E_d01P00E_eFoEKm001Fo@800003E_d005Km00=Fo@<0009Fo@03001F
oEKm009Fo@<000=Fo@03001FoEKm00@000=G7@06001G?P00001Bg0000TJM00D0049K@U]2F`0000A:
>@04001:>4Xh0003CQL01@00BOM9mdWg00000Sff00D003fg?KLm]`0000=1m`040015n4Gh0004AQL0
1P00BQM:5dXG0019m`L00095m`050015mdGgAOL00003BOL01@00BQM:5dXG00000dXG00D004XGBQM:
5`0000A:5`03001>5`00008000=>5`03001>5dhG009>5`05001>5dhGCQL00003CQL300000dhG001>
5`03CQL01@00DQMB5e8G0000158G0`0000=B=`00DSL00e8g00<0058gDSL00U8g00@0058fDSIB=P80
00AB=P05001B=U8fDSH00002DSH00`00ESH00004ESH00`00ESIF=P02ESH20002ESH00`00ESIF=P02
ESH01000ESIF=UHf0P0015Hf00<005HfESH00UHf00<005IF00000eIF00<005YFFUH00UYF0P000eYF
00<005YFFUH00UYF0P000eYF00<005YFFUH00UYF0P0015YF00@005YFFUIJEP8000AJEP04001NEUiF
0002GUH00`00GWINMP02GWH00`00GWINMP03GWH01000GWINMUif0P001Eif00<005ifGWH00Uif00@0
05ifGWH0009NMP04001NMUifGWH20006HYH00`00HYIRUP02HYH00`00HYL00003HYH01000HYMRU`00
0V:G00L006:GHYMRU`00HYL00003HYL00`00HYL00004HYL00`00I[MV]`03I[L00`00I[MV]`03I[L0
0`00I[MV]`03I[L00`00I[MV]`02I[L00`00I[L00003I[L00`00I[L00003I[L00`00I[L00002I]L0
1P00I]MVe`00I]L000AZe`03001Zef[G00=Ze`03001Zef[G009Ze`05001Ze`00J_L00002J]L00`00
J_L00004J_L00`00J_MZm`03J_L01@00J_QZn6[h00000V[h0P000flG00D006lG001_>000009_6003
001Ze`0000=FN@8000AJ^P06001Fo000001K700015;m00<005;mD_d00`0015/L0`0000=oo`00Ool0
PGoo002eOol20003Ool00`00Oomoo`08Ool30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@04
0003E_d00`00E_eFo@030004E_d00`00E_eFo@030003E_d01000E_d000000UKm00H005KmE_eFo@00
E_d200000eKm001Fo@03E_d30003Ead00`00EaeG7@030004D]`01000AYe6W@000d9K00D004XiBSU:
>@00009:>005001>5dhGCQL00004BOL01000?KHm]P000cfg00@0047g@OL000=5n00300165`0000L0
0003AOL004Gg0095m`050015mdGgAOL00004AOL01000BOM9m`000dXG00D004XGBQM:5`0000A:5`03
001:5`0000<0009>5`03001>5dhG009>5`05001>5dhGCQL00003CQL00`00CQM>5`020004CQL01@00
CQM>5dhG00000e8G00@0058GDQMB5`8000AB=`03001B=e8g009B=`06001B=e8gDSL0058f0P0000=B
=P00DSH00e8f00<0058fDSH00U8f0P000UHf00<005HfESH00UHf00@005HfESIF=P8000AF=P05001F
=UHfESH00002ESH00`00ESH00004ESH00`00ESIF=P02ESH20004EUH01000FUIJEUYF0P0015YF00@0
05YFFUIJEP8000AJEP07001JEUYFFUH005YF000015YF00H005YFFUH005YF0005FUH20003GUH01000
GWINMUif0P001Eif00@005ifGWH0009NMP03001NMUif009NMP03001NMUif00=NMP8000=NMP04001N
MUif0002HWH00`00HYIRUP03HYH00`00HYIRUP03HYH00`00HYIRUP02HYH00`00HYL00003HYL01000
HYMRU`000V:G00@006:GHYL0009RU`07001RUf:GHYL006JG00000fJg00<006Jg00000fJg00<006Jg
00000fJg00<006Jg00000VJg00@006JgI[L0009V]`04001V]fJg0002I[L2000016Jg001Ve`0016KG
00<006[GJ]L00f[G00<006[GJ]L00V[G00<006[G00000V[G00H006[GJ]L006[g0003J]L00`00J_MZ
m`03J_L00`00J_MZm`02J_L01@00J_P006[h00000f[h00D006lGKaM_5`0000=_5`07001_66lHKaP0
06[G00000UIi00<005jH000015Zj0P0015/L00<005;mD_d010000e;m00H005/L000005/L0003Ool0
0`00Oomoo`1oOol00;9oo`<000Ioo`03001oogoo00Eoo`800003E_d005Km00=Fo@06001Fo@00001F
o@0015Km0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d010000eKm00<005KmE_d00`0015Km
00<005KmE_d00`000eKm00@005Km0000009Fo@04001G7ELMEad30003E_`00`00D]aBg0060002@U/0
1@00BSU:>DXi00000dXh00H004hGCQM>5`00BOLB0002AOL01@00AOM5mdGg00000dGg00D004GgAOM5
m`0000=5m`050015mdGgAOL00003BOL01000BQM:5`0014XG00<004XG00000`000TXG00<004hGCQL0
0ThG00D004hGCQM>5`0000=>5`09001>5dhGCQL004hG001>5`0000A>5`03001>5dhG009>5`04001B
5e8GDQL300000e8G001B=`03DSL00`00DSMB=`02DSL01000DSMB=e8g0P000e8f00<0058fDSH00U8f
00@0058fDSIB=P8000AF=P05001F=UHfESH00002ESH00`00ESH00004ESH00`00ESIF=P02ESH20002
ESH00`00ESIF=P02ESH00`00ESIF=P0200000eHf001FEP03EUH01P00FUIJEP00FUH000AJEP06001J
EUYF001JEP0015YF00@005YFFUH0009JEP03001JEUYF00=JEP8000=JEP03001JEUYF009JEP03001N
EUiF009NEP04001NMUif0002GWH00`00GWINMP02GWH00`00GWH00003GWH01`00GWINMUif001NMP00
00ANMP03001NMUif00=NMP8000=RMP03001RUV:F009RUP03001RUP0000ARUP03001RUV:F00=RUP03
001RUf:G00=RU`8000=RU`03001RU`0000=RU`04001RUf:G0002IYL01000I[MV]`000VJg00@006Jg
I[L0009V]`04001V]fJg0002I[L01000I[MV]`000VJg00<006Jg00000fJg00D006Jg001V]`00009V
]`03001VefKG00=Ve`03001Zef[G009Ze`03001Ze`00009Ze`04001Zef[G0002J]L01@00J]MZef[G
000016[G00<006[gJ_L00V[g00<006[g00000V[g00D006[hJ_QZn00000AZn005001_5flGKaL00003
KaL01000KaQ_60000V[G00<005Ii00000ejH00@005ZjF[X0009RnP03001K75/L00@000=Bo@03001B
oE;m00<000AK7005001oogooOol00020Ool00;1oo`8000moo`<000=Fo@03001FoEKm00@000=Fo@06
001Fo@00001Fo@0015Km00H005Km000005Km0004E_d30002E_d00`00E_eFo@02E_d30003E_d00`00
E_eFo@040003E_d00`00E_eFo@030004E_d00`00Ead00002E_`01000E_aFo5Kl0`000Thh00<003WH
>MP0100014Xi00<004Xh00001P000TGg00@0047g@OL000=1m`050015mdGgAOL00002AOL01@00AOM5
mdGg000014Gg00@004GgAOL000=5m`050015mdGgAOL00003AOL01@00BOM9mdWg00000dXG00<004XG
00000`000TXG00D004XGBQM:5`0000A>5`05001>5dhGCQL00004CQL00`00CQL000020003CQL00`00
CQM>5`02CQL01@00CQM>5dhG00000U8G0P00158G00<0058gDSL00U8g00H0058gDSMB=`00DSL20000
0e8f001B=P03DSH00`00DSIB=P02DSH300000e8f001F=P03ESH00`00ESIF=P02ESH20002ESH00`00
ESIF=P02ESH01000ESIF=UHf0P0015Hf00<005HfESH00UHf0P0015Hf00<005IFEUH00UIF0P000UYF
00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF0P0015YF00<005YFFUH00UYF00<005YFFUH00UYF
00@005YFFUIJEP8000ENEP8000=NMP03001NMUif00=NMP03001NMUif009NMP04001NMUif0002GWH0
1000GWINMUif0P001Eif00<0069fHWH00f9f00@006:FHYH0009RUP07001RUV:FHYH006:F000016:F
00<006:GHYL00f:G00<006:GHYL00f:G00<006:GHYL00f:G0P000fJG00<006Jg00000fJg00<006Jg
00000fJg00<006Jg00000fJg00<006Jg000016Jg00<006JgI[L00fJg00@006JgI[L0009V]`03001V
efKG009Ve`03001Ze`00009Ze`04001Zef[G0002J]L01P00J]MZe`00J]L000AZe`07001Zef[GJ]L0
06[g00000V[g00H006[gJ_L006[g0004J_P02@00J_QZn6[h001^n000KaL00003KaL01@00LaL006lH
00000f[G00<005jHGYP00UjH00<005Zj000016;j0P000e/L00<005;mD_d010000Tkm00<005/LFa`0
0U/L0P000Woo00<007ooOol0OWoo002]Ool3000>Ool30003E_d00`00E_eFo@030004E_d00`00E_eF
o@030003E_d00`00E_eFo@040003E_d01P00E_d00000E_d000AFo@06001Fo@00001Fo@0015Km0`00
0UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`0015Kl00D005Kl001FN@0000A>>004000if3WH
0002=KP600000dHH00166002AQP01@00AOM5mdGg00000T7g00D0047g@OM1m`0000A5m`040015mdGg
0003AOL01@00AOM5mdGg00000dGg00@004GgAOL000=5m`030015mdGg0095m`030019m`0000H0009:
5`05001:5dXGBQL00004BQL01@00CQM>5dhG000014hG00<004hG00000`000ThG00D004hGCQM>5`00
00A>5`09001>5dhGCQL0058G001B5`0000AB5`03001B=e8g009B=`04001B=e8gDSL20003DSH00`00
DSIB=P02DSH01000DSIB=U8f0P000e8f00<005HfESH00UHf00@005HfESIF=P8000AF=P03001F=UHf
009F=P<00003ESH005Hf00=F=P04001F=UHfESH20005ESH01000EUIFEUIF0P0015YF00<005YFFUH0
0UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP06001J
EUYF001NEP001EiF00<005ifGWH00eif00@005ifGWINMP8000ENMP8000=NMP04001NMUif0002GWH0
0`00GWINMP02GWH00`00HWIRMP03HWH00`00HYH00003HYH01000HYIRUP000V:F00L006:FHYIRUP00
HYH00004HYL00`00HYMRU`03HYL00`00HYMRU`03HYL00`00IYMVU`03IYL00`00I[MV]`03I[L00`00
I[MV]`03I[L00`00I[MV]`03I[L00`00I[MV]`03I[L00`00I[MV]`03I[L02000I[MV]`00I[L006KG
0002I]L01000J]MZe`000V[G00H006[GJ]L006[G0004J]L00`00J]MZe`02J]L01@00J]L006[G0000
0V[g00<006[g000016[g00<006[hJ_P00V[h00D006[h001Zn00000=^n005001_5flGKaL00003LaL0
0`00J]MZe`02J]L00`00GYQNV003GYP00`00H_YRnP02H_X20004Fa`30002C_d00`00C_e>o@02C_d0
1P00Fa`00000Fa`000=oo`03001oogoo07eoo`00ZWoo0`003goo0P0000=Fo@00E_d00eKm0`000UKm
00<005KmE_d00UKm0`000eKm00<005KmE_d00`0015Km00<005KmE_d00`000eKm00<005KmE_d01000
0eKm00H005Km000005Km0004E_d01P00E_d00000E_d000AFo@<0009Fo003001Fo5Kl009Fo08000=F
N@05001>>4hhCSP00003>MP00`00=KP00003@QP01@00AQQ664HH00000dHH00D004GgAOM5m`000091
m`050011md7g@OL00003AOL01000AOM5m`000dGg00D004GgAOM5m`0000=5m`050015mdGgAOL00003
AOL00`00AOL000030002BOL01000BOM9m`000dXG00<004XGBQL00TXG00D004XGBQM:5`0000A>5`03
001>5`0000<0009>5`03001>5dhG009>5`05001>5dhGCQL00003CQL00`00CQM>5`030003DQL00`00
DQMB5`02DQL01P00DSMB=e8g001B=`800003DSH0058f00=B=P05001B=U8fDSH00002DSH00`00DSH0
0004DSH00`00ESIF=P02ESH300000eHf001F=P03ESH01000ESIF=UHf0P000eHf00<005HfESH00UHf
00H005HfESH005Hf0005ESH01P00EUIFEP00FUH000AJEP04001JEUYFFUH20004FUH01000FUIJEUYF
0P001EYF00H005YFFUH005YF0005FUH20003GUH00`00GUINEP02GUH00`00GWINMP03GWH01000GWIN
MP000Uif00<005ifGWH00Uif00<005ifGWH00eif0P000eif00L005ifGWINMP00GWH00005HWH00`00
HYIRUP03HYH20003HYH01000HYIRUP000V:F00L006:GHYMRU`00HYH00003HYL00`00HYL00004HYL0
0`00IYMVU`03IYL00`00I[MV]`03I[L00`00I[MV]`03I[L00`00I[MV]`03I[L00`00I[MV]`02I[L0
0`00I[L00003I[L01000I[L006Jg0P000VKG00<006KG00000f[G00<006[G000016[G00<006[GJ]L0
0f[G00D006[GJ]MZe`00009Ze`03001Ze`0000=Zm`03001Zmf[g00=Zm`05001Zn6[hJ_P00002J_P0
0`00J_P00003K_P01@00KaM_5flG00000g<G00L006[GJ]MZe`00I[L00003GYP20003H_X01@00IaYW
6P00Fa`00P0000=K7000C_d00dkm00<004kmC_d00`0015/L00D007ooOomoo`0007ioo`00Z7oo0P00
3goo10000eKm00H005Km000005Km0004E_d01P00E_d00000E_d000AFo@<0009Fo@03001FoEKm009F
o@<000=Fo@03001FoEKm00<000AFo@03001FoEKm00<000=Fo@03001FoEKm00@000=Fo@06001Fo@00
001Fo@0015Kl00H005Kl000005KK0003EWT01@00CSQ>>4hh00000cWH00@003Fh=KP000=260040016
64HH0003AQP01@00AOM5mdGg00000T7g00D0047g@OM1m`0000=5m`040015mdGg0003AOL00`00AOM5
m`02AOL01000AOM5m`000TGg1`000TGg00D004WgBOM9m`0000=9m`05001:5dXGBQL00003BQL01@00
BQM:5dXG00000dhG0`000ThG00D004hGCQM>5`0000A>5`05001>5dhGCQL00003CQL30002CQL01@00
DQMB5e8G0000158G00@0058gDSMB=`8000=B=P03001B=U8f009B=P03001B=U8f009B=P80009B=P03
001B=U8f009B=P04001F=UHfESH20003ESH00`00ESIF=P02ESH01P00ESIF=P00ESH000AF=P03001F
=UHf009F=P8000=F=P03001F=UHf00=F=P80009JEP03001JEUYF009JEP06001JEUYF001JEP0015YF
00@005YFFUH0009JEP03001JEUYF00=JEP8000=JEP03001JEUYF009JEP03001NEUiF009NEP07001N
EUiFGUH005if000015if00<005if00000eif00@005ifGWINMP8000ENMP03001NMUif009NMP04001N
MUif0002GWH00`00HWIRMP02HWH20005HYH00`00HYIRUP03HYH20003HYH01000HYMRU`000V:F00@0
06:GHYL0009RU`07001RUf:GHYL006JG00000fJG00<006Jg00000fJg00<006Jg00000fJg00<006Jg
00000fJg00<006Jg00000VJg00@006JgI[L0009V]`06001V]fJg001V]`0016KG00<006[GJ]L00f[G
00<006[GJ]L00f[G00<006[GJ]L00V[G00<006[G00000V[G00D006[GJ]MZe`0000AZm`03001Zmf[g
009Zm`05001Zm`00J_P00004J_P02@00K_Q^n6kh001^n000KaL00003LaL01@00K_H006[G00000VJg
00@005jHGYP0009Vn003001RnP0000AW6P03001K75/L009K7003001>o@0000@0009>o@03001K75/L
00<000=oo`03001oogoo07aoo`00YGoo0`003Woo0`0015Km00<005KmE_d00`000eKm00<005KmE_d0
10000eKm00H005Km000005Km0004E_d01P00E_d00000E_d000AFo@<0009Fo@03001FoEKm009Fo@<0
00=Fo@03001FoEKm00<000AFo@03001FoEKm00<000=Fo@03001Fo5Kl00<000AFf`05001FNEIiEWT0
0003CSP01000>MPif0000SFh00D0048H@QQ2600000966005001664HHAQP00003AOL01000@OM1m`00
0d7g00<004GgAOL00TGg00@004GgAOL000=5m`030015m`0000L00003AOL004Gg0095m`050015mdGg
AOL00004BOL01000BOM9m`000dXG00D004XGBQM:5`0000A:5`<00003CQL004hG009>5`03001>5dhG
009>5`05001>5dhGCQL00003CQL01P00CQL00000CQL000=>5`03001B5e8G009B5`06001B5e8GDQL0
058g0P0000=B5P00DSH00e8f00D0058fDSIB=P0000=B=P8000AB=P05001B=U8fDSH00002ESH00`00
ESH00004ESH00`00ESIF=P02ESH20002ESH00`00ESIF=P02ESH01000ESIF=UHf0P0015Hf00<005Hf
ESH00eHf00<005YFFUH00UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00UYF0P000eYF00<005YF
FUH00eYF00<005YFFUH00UYF00@005YFFUIJEP8000ANEP04001NEUiF0002GWH00`00GWINMP03GWH0
0`00GWINMP02GWH01000GWINMP000Uif00<005ifGWH00Uif00<005ifGWH00eif0P0015if00@0069f
HWH0009RMP03001RUV:F009RUP03001RUV:F00=RUP03001RUV:F00=RUP8000=RUP03001RU`0000=R
U`04001RUf:G0002IYL01000IYMVU`000VJg00@006JgI[L0009V]`04001V]fJg0002I[L01000I[MV
]`000VJg00<006Jg00000fJg00<006Jg000016Jg0P0016KG00<006[GJ]L00f[G00<006[GJ]L00V[G
00<006[G00000V[G00H006[GJ]L006[G0004J]L01`00J_MZmf[g001Zm`00009Zm`05001Zmf[gJ_L0
0005J_P01000K_Q^n0000fkh00D007<GLaMc5`00009^mP03001Ze`00009V]`03001NV00000AVn003
001W6VLJ009W6P8000=K70<000=>o@03001>oDkm00@000=K7005001oogooOol0001mOol00:=oo`80
00ioo`<0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00<000AFo@03001FoEKm00<000=Fo@03
001FoEKm00@000=Fo@06001Fo@00001Fo@0015Km00H005Km000005Km0004E_d30002E_d00`00E_eF
o@02E_d30003E_d00`00E_eFo@030002Ech00`00E]]Ff`02E]/01@00EWUFNEIi00000Thh100000@i
f000=KP000=26005001664HHAQP00003AQP01@00AOM5mdGg00000T7g00H0047g@OM1m`00AOL;0002
AOL01@00AOM5mdGg00000TGg00<004GgAOL00TGg00D004GgAOM5m`0000=9m`050019mdWgBOL00002
BQL00`00BQM:5`02BQL00`00BQL000020003CQL00`00CQM>5`02CQL01@00CQM>5dhG000014hG00<0
04hG00000P000dhG00<004hGCQL00ThG00D0058GDQMB5`0000=B5`8000=B5P03001B=U8f009B=P03
001B=U8f009B=P<00003DSH0058f00=B=P03001B=U8f009B=P80009F=P03001F=UHf009F=P04001F
=UHfESH20004ESH01@00ESIF=UHf00000UHf00<005Hf00001EHf00@005HfESIF=P8000AJEP04001J
EUYFFUH20004FUH01000FUIJEUYF0P001EYF00@005YFFUIJEP8000AJEP06001JEUYF001JEP001EiF
0P0015if00@005ifGWINMP8000ENMP8000=NMP04001NMUifGWH20005GWH00`00GWINMP03GWH00`00
HWH00003HWH01`00HYIRUV:F001RUP0000ARUP03001RUV:F00=RUP03001RUV:F00=RUP03001RUf:G
00=RU`8000=VU`03001VU`0000=V]`03001V]`0000=V]`03001V]`0000=V]`03001V]`0000AV]`03
001V]fJg00=V]`03001V]fJg00=V]`8000=Ve`03001Ze`0000=Ze`03001Ze`00009Ze`06001Zef[G
001Ze`0016[G00<006[GJ]L00V[G00D006[g001Zm`00009Zm`03001Zm`0000AZm`03001Zn6[h009Z
n005001^n000K_P00003K_P01@00LaMc5g<G00000fkf00<006JgI[L00VJg00<006KhI_P00fKh00D0
06LJIaYW6P00009[6@<0009K7003001>oDkm00@0009>o@03001K75/L009K708000=oo`03001oogoo
07Yoo`00X7oo0`003Woo0P0000=Fo@00E_d00eKm00H005Km000005Km0004E_d30002E_d00`00E_eF
o@02E_d30003E_d00`00E_eFo@030004E_d00`00E_eFo@030003E_d00`00E_eFo@040003E_d01P00
E_d00000E_d000AFo@06001Fo@00001Fo@0015Km0`000eLn00@005LnEch000=Ff`03001FNEIi00@0
0004BQL003fg?KL50003@QP00`00AQP0000A0002AOL01000AOM5m`000dGg00D004GgAOM5m`0000=5
m`050015mdGgAOL00003AOL01@00AOM5mdGg00000dWg00D004WgBOM9m`0000=:5`03001:5`0000<0
009:5`03001>5dhG009>5`05001>5dhGCQL00003CQL01000CQM>5dhG0`000ThG00<004hGCQL00ThG
00D004hGCQM>5`0000=B5`06001B5`00001B5P00158F00D0058fDSIB=P0000=B=P8000=B=P03001B
=U8f009B=P04001B=U8fDSH20004ESH01@00ESIF=UHf00000UHf00<005Hf000015Hf00<005HfESH0
0UHf0P000eHf00<005HfESH00UHf00H005HfESH005Hf0004FUH01P00FUIJEP00FUH000AJEP06001J
EUYF001JEP001EYF00H005YFFUH005YF0005FUH20003FUH00`00GUINEP02GUH00`00GWINMP03GWH0
1000GWINMP000Uif00<005ifGWH00Uif00<005ifGWH00Uif00@005ifGWH0009NMP03001NMUif009N
MP03001NMUif00ANMP03001RMV9f009RMP04001RUV:F0002HYH01`00HYIRUV:F001RUP0000ARUP03
001RUV:F00=RUP03001RUf:G00=RU`03001VUfJG00=VU`03001V]fJg00=V]`03001V]fJg00=V]`03
001V]fJg00=V]`03001V]fJg00=V]`03001V]fJg00=V]`03001V]fJg009V]`03001Ve`00009Ve`04
001Zef[G0002J]L01P00J]MZe`00J]L000AZe`03001Zef[G00=Ze`05001Zef[GJ]L00002J_L00`00
J_L00003J_L00`00J_MZm`02J_L00`00J_L00002J_P01@00K_Q^n6kh00000fkh00D006kg001c5`00
00A^mP03001V]fJg009V]`03001Vn6Kh009Vn005001[6000IaX00003JaT00`00FaaK7002Fa`30002
C_d00`00C_e>o@02C_d01P00Fa`00000Fa`000=oo`03001oogoo07Yoo`00WWoo0P003goo0`000eKm
00<005KmE_d010000eKm00H005Km000005Km0004E_d01P00E_d00000E_d000AFo@<0009Fo@03001F
oEKm009Fo@<000=Fo@03001FoEKm00<000AFo@03001FoEKm00<000=Fo@03001FoEKm00<000AFo@04
001Fo@000002Ead00`00EciG?P0;0002BSP01000BQM:5`000cfg00<003Vg>KL01P0000=5n000AOP0
0TGh00D004GgAOM5m`000091m`050011md7g@OL00003AOL01@00AOM5mdGg00000dGg00D004GgAOM5
m`0000=5m`040015mdGg0003AOL01@00AOM5mdGg000014Wg00<004Wg00001P000TXG00<004XGBQL0
0TXG00D004hGCQM>5`0000=>5`03001>5dhG009>5`<00003CQL004hG009>5`03001>5dhG009>5`05
001>5dhGCQL00003DQL20003DQH00`00DQIB5P02DQH00`00DSIB=P02DSH300000e8f001B=P03DSH0
0`00DSIB=P02DSH300000e8f001F=P03ESH00`00ESIF=P02ESH20002ESH00`00ESIF=P02ESH01000
ESIF=UHf0P0015Hf00<005HfESH00UHf00<005Hf00000eHf00<005YFFUH00UYF0P000UYF00<005YF
FUH00eYF0P000eYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH00UYF00<005YFFUH00UYF
00@005iFGUINEP8000ENMP03001NMP0000=NMP04001NMUifGWH20005GWH20003GWH01`00GWINMUif
001NMP0000ANMP8000ERMP8000=RUP04001RUV:F0002HYH01`00HYIRUV:F001RUP0000=RUP03001R
UP0000ARU`03001VUfJG00=VU`03001V]fJg00=V]`03001V]fJg00=V]`03001V]fJg00=V]`03001V
]fJg009V]`03001V]`0000=V]`03001V]`00009V]`04001VefKG0002I]L01P00J]MZe`00J]L000AZ
e`03001Zef[G00=Ze`03001Zef[G009Ze`03001Ze`00009Ze`05001Zmf[gJ_L00004J_L01@00J_MZ
mf[g00000V[g00<006[h000016kh00@006khK_P000=^m`03001^mVkf009^mP03001^m`00009V]`03
001Zn000009Vn005001[66/HJaP00003JaT01000JcT005/L0P0000=K7000C_d00dkm00<004kmC_d0
0`0015/L00D007ooOomoo`0007]oo`00Vgoo0`003Woo0`000eKm00<005KmE_d00`0015Km00<005Km
E_d00`000eKm00<005KmE_d010000eKm00H005Km000005Km0004E_d01P00E_d00000E_d000AFo@<0
009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00<000=Fo@03001FoEKm00@000=G7@<0009Bo004
0012WD:M0003@U/00`00BSQ:>002BSP01000BQM:5`000cfg00<003Vg00000d7h00D004GhAOQ5n000
00=5n0050015mdGgAOL00002@OL01@00@OM1md7g00000dGg00@004GgAOL000=5m`050015mdGgAOL0
0003AOL01000AOM5m`0014Gg00H004GgAOM5m`00BOL40002BOL01000BOM9m`000dXG00<004XGBQL0
0TXG00D004hGCQM>5`0000A>5`03001>5`00008000=>5`03001>5dhG009>5`05001>5dhGCQL00004
CQL300000dhG001B5P03DQH01@00DQIB5U8F00000e8f0P000e8f00<0058fDSH00U8f00@0058fDSIB
=P8000=B=P03001F=UHf009F=P04001F=UHfESH20004ESH01@00ESIF=UHf00000UHf00<005Hf0000
1EHf00@005HfESIF=P8000AF=P04001JEUYFFUH20004FUH00`00FUIJEP02FUH00`00FUIJEP02FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUH01000FUIJEUYF0P0015YF00@005iFGUH0009NEP03001NMUif
009NMP8000ANMP04001NMUif0002GWH00`00GWINMP02GWH00`00GWINMP02GWH01000GWINMP000Uif
00D005ifGWINMP00009RMP03001RMV9f009RMP03001RUV:F00=RUP8000=RUP04001RUV:F0002HYH0
1000HYIRUP000V:F00L006:GHYMRU`00HYH00003IYL00`00IYL00003I[L00`00I[L00003I[L00`00
I[L00003I[L00`00I[L00003I[L01P00I[MV]`00I[L0009V]`03001V]`0000=Ve`<000AZe`03001Z
ef[G00=Ze`03001Zef[G009Ze`03001Ze`00009Ze`06001Zef[G001Ze`0016[g00T006[gJ_MZm`00
J_L006[g000016[g00<006khK_P00Vkh00@006kg000000A^m`05001^mVkfK_H00002K_L00`00I[L0
0002J_P00`00I_P00004JaP01000JaU[6@000f/i00<005/LFa`00U/L00<004kmC_d010000Tkm00<0
05/LFa`00U/L0P000goo00<007ooOol0N7oo002IOol2000?Ool200000eKm001Fo@03E_d30002E_d0
0`00E_eFo@02E_d30003E_d00`00E_eFo@030004E_d00`00E_eFo@030003E_d00`00E_eFo@040003
E_d01P00E_d00000E_d000AFo@06001Fo@00001Fo@0015Km0`000eKm00<005KmE_d00`0015LM00<0
05LM00000UKl00D005;lD_aBo0000092W@050012Fd9K@U/00003BSP01000BQM:5`000cfg00@003Vg
>KL000=1n0040015n4Gh0003AOP01@00AOM5mdGg00000T7g00D0047g@OM1m`0000=5m`050015mdGg
AOL00002AOL01@00AOM5mdGg00000dGg00H004GgAOM5m`00AOL80002BOL01@00BOM9mdWg00000dWg
00D004XGBQM:5`0000=:5`03001>5dhG009>5`03001>5`0000<0009>5`03001>5dhG009>5`05001>
5dhGCQL00004CQL00`00CQL000020003CQL00`00DQIB5P02DQH00`00DQIB5P02DQH300000e8F001B
=P03DSH01@00DSIB=U8f00000U8f00<0058f0000158f00D005HfESIF=P00009F=P03001F=P0000AF
=P03001F=UHf009F=P8000=F=P03001F=UHf009F=P06001F=UHf001F=P0015Hf00H005YFFUH005YF
0004FUH01000FUIJEUYF0P001EYF00@005YFFUIJEP8000AJEP06001JEUYF001JEP001EYF0P000eiF
00L005ifGWINMP00GWH00005GWH20003GWH01000GWINMUif0P001Eif0P000eif00@005ifGWH000=R
MP04001RMV9fHWH20005HYH00`00HYIRUP03HYH20003HYH00`00HYH00003HYH01000HYMRU`000V:F
00@006JGIYL0009VU`04001V]fJg0003I[L00`00I[L00003I[L00`00I[L00003I[L00`00I[L00003
I[L00`00I[L00003I[L00`00I]MVe`03I]L00`00J]MZe`03J]L00`00J]MZe`02J]L00`00J]L00002
J]L01P00J]MZe`00J]L000AZe`03001Zmf[g009Zm`80009Zm`05001Zmf[gJ_L00005J_L01@00K_Q^
n6kh00000Vkg00<006kgK_L00Vkg00<006kg00000Vkf00H006kgK_L006Jg0003J_P00`00JaQ[6002
JaP01000KaP000000f/i0P0015/L0`000dkm00H004kmC_e>o@00Fa`200000e/L001oo`02Ool00`00
Oomoo`1hOol009Ioo`<000moo`<000=Fo@04001Fo@000002E_d01P00E_eFoEKm001Fo@800003E_d0
05Km00=Fo@<0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00<000AFo@03001FoEKm00<000=F
o@03001FoEKm00<000AFo@06001Fo@00001Fo@0015Km0`000UKm00<005LMEad00ULM0P0015Kl00<0
05;lD_`01@000T9K00D004XhBSQ:>000009:5`05000m]cfg?KL00002>KL01@00@OQ1n47h00000dGh
00@004GhAOP000=5m`050011md7g@OL00002@OL01@00AOM5mdGg00000dGg00D004GgAOM5m`0000=5
m`060015mdGgAOL004Gg0`000TGg00D004GgAOM5m`0000=9m`030019mdWg0099m`040019mdWg0003
BQL00`00BQM:5`02BQL00`00CQL000030002CQL01@00CQM>5dhG000014hG00D004hGCQM>5`0000=>
5`<0009>5`03001>5dhG009>5`05001B5U8FDQH00003DQH20003DQH00`00DSIB=P02DSH00`00DSIB
=P02DSH20002DSH00`00DSIB=P02DSH00`00ESIF=P02ESH20002ESH00`00ESIF=P02ESH01000ESIF
=UHf0P0015Hf00<005HfESH00UHf00<005Hf00000UHf00<005HfESH00eHf0P000UYF00<005YFFUH0
0UYF00@005YFFUH0009JEP03001JEUYF009JEP06001JEUYF001JEP001EYF0P000eYF00<005YFFUH0
0UYF00<005iFGUH00UiF00@005ifGWH000=NMP03001NMUif009NMP03001NMUif009NMP04001NMUif
0002GWH00`00GWINMP02GWH00`00GWINMP03GWH20004HWH01000HWIRMP000V9f00<006:FHYH00V:F
00<006:FHYH00f:F00<006:FHYH00f:F00<006:FHYH00f:F0P000f:F00<006JG00000fJG00<006Jg
000016Jg00<006Jg00000fJg00<006Jg00000fJg00<006Jg000016Jg00<006JgI[L00VJg00<006KG
I]L00fKG00<006[GJ]L00V[G00<006[G00000V[G00H006[GJ]L006[G0004J]L00`00J]MZe`03J]L0
1@00J_MZmf[g00000V[g0P0016[g00<006[gJ_L00V[g00D006kg001^n00000=^m`05001^mfkgK_L0
0002K_L00`00K_H00004K_L01000J_QZn6[h0P000f/H00@006lHKaP000=[>@05001_>Fli001K7002
00000e/L001>o@02C_d70003Fa`20003Ool00`00Oomoo`1gOol009=oo`<000ioo`@000=Fo@03001F
oEKm00<000AFo@03001FoEKm00<000=Fo@06001Fo@00001Fo@0015Km00H005Km000005Km0004E_d3
0002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@030003E_d00`00E_eFo@040003E_d01P00E_d0
0000E_d000AFo@06001G7@00001Fo00015Kl0`0000A>>000>MPif0@000A:>004001:5dXG0003?KL0
0`00>KL00003@OP01@00AOQ5n4Gh00000dGh00D004GgAOM5m`000091m`050011md7g@OL00003AOL0
1000AOM5m`000TGg2`0000=5m`00AOL00TGg00D004GgAOM5m`0000A9m`050019mdWgBOL00003BOL0
1000BQM:5`000dXG0`000TXG00D004hGCQM>5`0000A>5`05001>5dhGCQL00004CQL300000dhG001>
5`02CQL00`00CQM>5`02CQL00`00DQIB5P02DQH300000e8F001B5P03DQH01@00DSIB=U8f00000e8f
0P00158f00D0058fDSIB=P0000=F=P8000AF=P03001F=UHf009F=P<00003ESH005Hf00AF=P04001F
=UHfESH20004ESH00`00ESIF=P02ESH00`00FUIJEP02FUH00`00FUIJEP02FUH20003FUH00`00FUIJ
EP02FUH00`00FUH00003FUH00`00FUIJEP02FUH00`00FUIJEP02FUH01000FUIJEUYF0P001EiF0P00
15if00@005ifGWINMP8000ENMP8000=NMP04001NMUifGWH20005GWH00`00HWIRMP04HWH20003HWH0
1`00HYIRUV:F001RUP0000=RUP8000ERUP03001RUV:F00=RUP03001RUV:F00=RUP03001VUfJG00=V
U`03001V]fJg00AV]`03001V]fJg00=V]`03001V]fJg00=V]`03001V]fJg00=V]`07001V]fJgI[L0
06Jg00000fKG0`000V[G00H006[GJ]L006[G0004J]L00`00J]MZe`03J]L00`00J]MZe`02J]L01@00
J]L006[g00000f[g00<006[gJ_L00V[g00<006[g00000V[g00D006kgK_M^m`0000=^m`03001^m`00
009^m`05001^mfkgK_L00005K_L01000J_QZn0000V[h00<006/H00000flH0P0000=[>@00KcT00fli
00@005/LFaaK70@0009>o@06001>oDkmC_d005/L0P0000=K7000Ool00goo00<007ooOol0MWoo002A
Ool20003Ool00`00Oomoo`08Ool30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@040003E_d0
0`00E_eFo@030003E_d00`00E_eFo@040003E_d01P00E_d00000E_d000AFo@06001Fo@00001Fo@00
15Km0`000eKm00<005KmE_d00`0015Km00<005KmE_d00`000eKm00<005KmE_d00`0015Kl00H005Kl
000005Ii0003CSP01000>MPif0000S6h3`000d7h00@004GhAOP00095n1H00003AOL004Gg0095m`05
0015mdGgAOL00003AOL01@00AOM5mdGg00000dGg00D004WgBOM9m`0000=9m`050019mdWgBOL00003
BQL300000dXG001:5`02BQL00`00CQM>5`02CQL01@00CQM>5dhG000014hG00<004hG00000P000dhG
00<004hGCQL00ThG00D004hGCQM>5`0000=B5P8000=B5P03001B5U8F009B5P03001B=U8f009B=P<0
0003DSH0058f00=B=P03001B=U8f009B=P<00003ESH005Hf00=F=P04001F=UHfESH20004ESH00`00
ESIF=P02ESH01P00ESIF=P00ESH000AF=P04001F=UHfESH20004FUH01000FUIJEUYF0P001EYF00@0
05YFFUIJEP8000AJEP04001JEUYFFUH20004FUH01000FUIJEP000UiF00<005iFGUH00UiF00<005if
GWH00eif00H005ifGWH005if0005GWH00`00GWINMP02GWH01000GWINMP000Uif00<005ifGWH00Uif
00<0069fHWH0169f00<0069fHWH00V9f00@006:FHYH0009RUP04001RUV:F0002HYH01`00HYIRUV:F
001RUP0000ARUP03001RUV:F00=RUP03001VUfJG00=VU`03001V]fJg00AV]`03001V]fJg00=V]`03
001V]fJg00=V]`03001V]fJg009V]`03001V]`00009V]`07001V]fJg001Ve`00J]L00P0000=Ze`00
J]L00f[G00<006[GJ]L00f[G00<006[GJ]L00V[G00<006[G00000V[G00D006[GJ]MZe`0000AZm`05
001Zmf[gJ_L00002J_L00`00J_L00004K_L02@00K_M^mfkg001^m`00K_L00004K_L00`00K_M^m`02
K_L01000J_P0000016[h00D006lHKaQ_6000009_6003001_>Fli009_>@800005Fa`00000Fa`00005
C_d00`00C_d000020004Fa`01@00Oomoogoo0000N7oo002>Ool30006Ool00`00Oomoo`05Ool20002
E_d01P00E_eFoEKm001Fo@800003E_d005Km00=Fo@<0009Fo@03001FoEKm009Fo@<000=Fo@03001F
oEKm00<000AFo@03001FoEKm00<000=Fo@03001FoEKm00<000AFo@06001Fo@00001Fo@0015Km0`00
0UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`000eKl00<005KlE_`00`0015Ii00@004hhCSP0
00<if003000a^00000=1n0040011n47h0003?MP00`00?MPmf00:00000d7h0011m`02@OL01@00@OM1
md7g00000T7g00D004GgAOM5m`0000=5m`040015mdGg0003AOL00`00AOM5m`02AOL01000AOM5m`00
0dGg00D004GgAOM5m`0000=9m`030019mdWg0099m`030019m`0000D000=:5`03001:5dXG009:5`05
001>5dhGCQL00003CQL01000CQM>5dhG0`000ThG00<004hGCQL00ThG00D004hGCQM>5`0000A>5`<0
0003DQH0058F00=B5P05001B5U8FDQH00003DSH20003DSH00`00DSIB=P02DSH01000DSIB=U8f0P00
0eHf00<005HfESH00UHf00H005HfESH005Hf0004ESH00`00ESIF=P02ESH00`00ESH00002ESH00`00
ESIF=P02ESH01P00ESIF=P00ESH000AJEP06001JEUYF001JEP001EYF00H005YFFUH005YF0004FUH0
1P00FUIJEP00FUH000EJEP8000=NEP04001NEUiFGUH20006GWH20003GWH00`00GWINMP02GWH00`00
GWINMP03GWH20003GWH01`00GWINMUif001NMP0000ERMP03001RMV9f00=RMP8000=RUP03001RUP00
00=RUP04001RUV:F0002HYH01`00HYIRUV:F001RUP0000=RUP03001VUP0000=VU`03001V]P0000AV
]`03001V]`0000=V]`03001V]`0000=V]`03001V]`00009V]`06001V]fJg001V]`000fJg00L006KG
001Ze`00J]L00005J]L00`00J]MZe`02J]L00`00J]L00002J]L01P00J]MZe`00J]L000AZe`07001Z
mf[gJ_L006[g00000V[g00D006[gJ_MZm`0000A^m`05001^m`00K_L00003K_L00`00K_M^m`02K_L0
0`00K_L00002K_L01000J_QZn00016[h0P000VlH00D006lHKaQ_600000=_>@04001_>Fli0004Fa`0
0`00C_e>o@040002C_d00`00FaaK7002Fa`20003Ool00`00Oomoo`1eOol008aoo`8000moo`<000AF
o@03001FoEKm00<000=Fo@04001Fo@000002E_d01P00E_eFoEKm001Fo@800003E_d005Km00=Fo@<0
00=Fo@03001FoEKm00@000=Fo@03001FoEKm00<000=Fo@03001FoEKm00@000=Fo@06001Fo@00001F
o@0015Km00H005Km000005Km0004E_d30002E_d01000E_aFo5Kl0`000UKK00<005IiEWT00UIi00D0
04hhCSQ>>000008if004000a^36h0003@OP01000@OQ1n0000cgH00<003gH00000d7h00D0047h@OQ1
n0000091n0050011md7g@OL00003@OL01000@OM1m`0014Gg00D004GgAOM5m`000095m`050015mdGg
AOL00003AOL01@00AOM5mdGg00000TGg00D004GgAOM5m`0000A9m`030019m`0000<00099m`04001:
5dXG0004BQL01@00BQM:5dXG00000dhG00<004hGCQL00ThG0`0000=>5`00CQL00ThG00<004hGCQL0
0ThG00D004hGCQM>5`0000=>5`8000=B5P03001B5U8F009B5P03001B5U8F009B5P<00003DQH0058f
00=B=P05001B=U8fDSH00002DSH00`00DSH00004ESH00`00ESIF=P02ESH20003ESH00`00ESIF=P02
ESH01000ESIF=UHf0P0015Hf00<005HfESH00UHf0P000eHf00<005YFFUH00UYF0P000UYF00<005YF
FUH00eYF00<005YF00000eYF00<005YFFUH00UYF0P000eYF00<005YFFUH00UYF00<005iFGUH00UiF
00@005iFGUH0009NEP03001NMUif00=NMP03001NMUif009NMP04001NMUifGWH20005GWH00`00GWIN
MP02GWH01000GWINMP000Uif00<0069fHWH00V9f00<0069f0000169f00<006:FHYH00f:F00<006:F
HYH00V:F00<006:F00000f:F00@006:FHYH0009RUP04001RUV:F0002IYH01000IYMVU`000fJf00@0
06JgI[L0009V]`04001V]fJg0002I[L01000I[MV]`000VJg00<006Jg00000fJg00<006Jg000016Jg
00H006[GJ]L006[G0004J]L00`00J]L00002J]L01P00J]MZe`00J]L000AZe`03001Zef[G009Ze`05
001Zm`00J_L00002J_L00`00J_L00004J_L01@00K_M^mfkg00000Vkg00<006kg00000fkg00D006kg
K_M^m`00009^m`03001^m`0000=Zn005001Zn6[hJ_P00002KaP00`00KaP00002KaP01@00KcP006li
00000fli00<005/LFa`00U/L0`000Tkm00<004kmC_d00Tkm00@005/L0000009K7005001oogooOol0
001fOol008Uoo`<000ioo`<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00<000AFo@03001FoEKm
00<000=Fo@06001Fo@00001Fo@0015Km0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`00
15Km00<005KmE_d00`000eKm00<005KmE_d00`0015Km00H005Km000005Km0004E_d00`00E_`00002
Ead01@00E]]FfeKK00000eIi00D004hhCSQ>>000008if004000a^36h0003@OP01000@OQ1n0000cgH
00@003gH?MP000=1n0050011n47h@OP00002@OP01@00@OM1md7g00000d7g00@0047g@OL000=5m`05
0015mdGgAOL00002AOL01@00AOM5mdGg00000dGg00D004GgAOM5m`0000=5m`060015mdGgAOL004Wg
10000TWg00D004WgBOM9m`0000=:5`05001:5dXGBQL00003BQL00`00CQM>5`02CQL00`00CQL00002
0003CQL00`00CQM>5`02CQL01@00CQM>5dhG000014hG0`0000=>5P00DQH00e8F00D0058FDQIB5P00
00=B5P8000=B5P03001B=U8f009B=P03001B=U8f009B=P80009B=P03001F=UHf009F=P04001F=UHf
ESH20004ESH00`00ESIF=P02ESH01P00ESIF=P00ESH000AF=P04001F=UHfESH20004ESH00`00FUIJ
EP02FUH00`00FUIJEP02FUH00`00FUIJEP02FUH20004FUH01000FUIJEUYF0P0015YF00@005YFFUIJ
EP8000ENEP8000=NEP03001NMUif00=NMP03001NMUif009NMP04001NMUif0002GWH00`00GWINMP02
GWH00`00GWINMP03GWH20004GWH01000HWIRMP000V9f00@0069fHWIRMP8000ERUP03001RUV:F00=R
UP03001RUV:F00=RUP8000=RUP03001RUP0000=VUP03001VU`0000AV]P03001V]`0000=V]`03001V
]`0000=V]`03001V]`0000AV]`03001V]fJg00=V]`03001V]fJg00=V]`03001Zef[G00800005J]L0
06[GJ]L00002J]L00`00J]L00004J]L00`00J]MZe`03J]L01@00J]MZef[G00000V[g00<006[g0000
0f[g00<006[gJ_L00V[g00<006kg00000Vkg00D006kgK_M^m`0000=^m`05001^m`00K_L00004K_L0
2@00J_QZn6[h001_6000J_P00004KaP01@00KaQ_66lH00000Vlh00P006liKcU_>@00KcT005/L0P00
00=K7000C_d00dkm00<004kmC_d00`0015/L0P000Woo00<007ooOol0M7oo0027Ool2000?Ool20002
E_d01000E_eFoEKm0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d010000eKm00<005KmE_d0
0`000eKm00@005Km0000009Fo@06001FoEKmE_d005Km0P0000=Fo@00E_d00eKm0`000UKm00<005Km
E_d00UKm0`000eKm00<005KmE_d00`000eKm00<005KmE_d010000eKm00<005KmE_d00`0015LM00@0
05KKE]/0009FN@X00003<KP0047h0091n0040011n47h0003?MP01000?MPmf0000d7h00D0047h@OQ1
n0000091n0050011md7g@OL00003@OL01000@OM1m`000dGg00D004GgAOM5m`000095m`050015mdGg
AOL00004AOL01000AOM5m`000TGg1`000TWg00D004WgBOM9m`0000A9m`04001:5dXG0003BQL00`00
BQM:5`02BQL00`00CQL000030002CQL00`00CQM>5`02CQL01@00CQM>5dhG000014hG00<004hG0000
0P000dhF00<0058FDQH00U8F00<0058FDQH00U8F0`0000=B5P00DQH00e8F00D0058fDSIB=P0000=B
=P8000AB=P05001F=UHfESH00002ESH00`00ESH00004ESH00`00ESIF=P02ESH00`00ESH00002ESH0
0`00ESIF=P02ESH01P00ESIF=P00ESH000AF=P04001JEUYFFUH20004FUH01`00FUIJEUYF001JEP00
00AJEP06001JEUYF001JEP0015YF00@005YFFUH0009JEP03001NEUiF009NEP03001NEUiF00=NEP04
001NMUifGWH20005GWH20003GWH01`00GWINMUif001NMP0000ANMP03001NMUif00=NMP03001RMP00
00=RMP04001RMV9f0002HYH01`00HYIRUV:F001RUP0000ARUP03001RUV:F00=RUP03001RUV:F00=R
UP03001VUVJF00=VUP03001V]VJf00AV]P03001V]fJg00=V]`03001V]fJg00=V]`03001V]fJg00=V
]`03001V]fJg00=V]`03001V]fJg009V]`03001Ze`0000<00005J]L006[GJ]L00003J]L00`00J]MZ
e`03J]L00`00J]MZe`02J]L00`00J]L00002J]L01@00J_MZmf[g000016[g00D006[gJ_MZm`00009^
m`03001^m`0000A^m`04001^mfkg0003K_L00`00K_M^m`03K_L01000J_QZn0000flH00<006lHKaP0
0flH00@006lHKaP000=_>004001_>Fli0003KcT00`00FaaK7002Fa`00`00C_e>o@040003C_d01P00
Fa`00000Fa`000=oo`03001oogoo07=oo`00Q7oo0`003goo0`0015Km00<005Km00000UKm00H005Km
E_eFo@00E_d200000eKm001Fo@03E_d30003E_d00`00E_eFo@040003E_d00`00E_eFo@030004E_d0
0`00E_eFo@030003E_d01P00E_d00000E_d000AFo@06001Fo@00001Fo@0015Km0`000UKm00@005Km
E_eFo@<000AFo@03001FoEKm00<000=G7@03001G7ELM00L0009:>@05001664HHAQP00002>KL40003
@OP01000@OQ1n0000cgH00@003gH?MP00091n0050011n47h@OP00002@OP01@00@OM1md7g00000d7g
00@0047g@OL000A5m`050015mdGgAOL00002AOL01P00AOM5mdGg0015m`P00003AOL004Gg0095m`05
0019mdWgBOL00004BOL01@00BOM9mdWg00000dXG00H004XGBQM:5`00BQL40002CQL01@00CQM>5dhG
000014hG00D004hGCQM>5`0000=>5`<0009>5P03001>5ThF009>5P05001B5U8FDQH00003DQH20003
DQH00`00DQIB5P02DQH00`00DSIB=P02DSH300000e8f001B=P03DSH00`00ESIF=P02ESH20002ESH0
0`00ESIF=P03ESH01000ESIF=UHf0P0015Hf00<005HfESH00UHf0P000UHf00<005HfESH00UHf00H0
05YFFUH005Xf0004FUH01000FUIJEP000UYF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF0P00
0eYF00@005iFGUINEP8000ENEP04001NMUif0002GWH00`00GWINMP02GWH00`00GWINMP02GWH01000
GWINMP000Uif00@005ifGWINMP8000INMP03001RMV9f00=RMP8000=RUP04001RUV:F0002HYH01`00
HYIRUV:F001RUP0000ARUP03001RUV:F00=RUP03001VUVJF00=VUP03001V]VJf00AV]P03001V]fJg
00=V]`03001V]fJg00=V]`03001V]fJg009V]`03001V]`0000=V]`03001V]`00009V]`@00007J]L0
06[GJ]L006[G000016[G00<006[GJ]L00V[G00<006[G00000V[G00H006[GJ]L006[G0004J_L02@00
J_MZmf[g001Zm`00J_L00004K_L00`00K_M^m`02K_L01@00K_L006kg00000fkg00<006kgK_L00Vkg
00D006kh001Zn00000=_6003001_66lH009_6005001_6000KaP00002KcP01@00LcP006li00000Vli
00<006li00000U/L10000dkm00<004kmC_d00`0015/L00D007ooOomoo`0007Aoo`00PWoo0P003Woo
10000eKm00<005KmE_d00`0015Km00<005KmE_d00`000eKm00@005Km0000009Fo@04001FoEKmE_d3
0002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@040003E_d00`00E_eFo@030003E_d00`00E_eF
o@040003E_d01P00E_d00000E_d000AFo@03001Fo@00009Fo@03001FoEKm009Fo@<000=Fo@03001G
7ELM00<00096_@040012Fd9K0004BST01000AQQ660000SVg00<003Fg=KL03`000d7h00D0047h@OQ1
n0000091n0050011md7g@OL00003@OL01@00@OM1m`00AOL03`000TGg00D004GgAOM5m`0000=5m`04
0015mdGg0004BOL01@00BOM9mdWg00000dWg00D004XGBQM:5`00009:5`<0009:5`05001>5dhGCQL0
0004CQL01@00CQM>5dhG000014hG0`0000=>5P00CQH00ThF00<004hFCQH00ThF00<0058FDQH00U8F
0`0000=B5P00DQH00e8F00D0058FDQIB5P0000=B=P8000=B=P03001B=U8f009B=P04001F=UHfESH2
0004ESH00`00ESIF=P02ESH01P00ESIF=P00ESH000AF=P04001F=UHfESH20004ESH00`00ESIF=P02
ESH20003FSH00`00FUIJEP02FUH20004FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJEP02
FUH00`00FUIJEP02FUH01000GUINEP000UiF00<005iFGUH00UiF00<005if00000eif00@005ifGWIN
MP8000ENMP8000=NMP04001NMUif0002GWH00`00GWINMP03GWH00`00HWIRMP03HWH00`00HYIRUP02
HYH00`00HYH00003HYH01000HYIRUP000V:F00L006:FHYIRUP00HYH00003HYH00`00IYH00003IYH0
0`00IYH00004I[H00`00I[H00003I[L00`00I[L00003I[L00`00I[L00002I[L01000I[MV]`000VJg
00<006JgI[L010000V[G00@006[G0000009Ze`03001Zef[G009Ze`03001Ze`00009Ze`06001Zef[G
001Ze`0016[G00<006[gJ_L00V[g00D006[g001Zm`0000=Zm`03001^mfkg00=^m`05001^mfkgK_L0
0003K_L01`00K_M^mfkg001^m`00009^m`05001^n6khK_P00003KaP00`00KaP00002KaP01@00KaQ_
66lH00000Vlh00D007<hLcQc>000009_>@04001_>FliKcT20003Fa`00`00C_e>o@040002C_d01000
FaaK75/L0P000goo00<007ooOol0LWoo001oOol3000=Ool30004E_d00`00E_eFo@030003E_d00`00
E_eFo@040003E_d00`00E_eFo@030004E_d00`00E_d00002E_d01P00E_eFoEKm001Fo@800003E_d0
05Km00=Fo@<0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00<000AFo@03001FoEKm00<000=F
o@03001FoEKm00<000AFo@06001Fo@00001Fo@0015Km0`000UKl00D004JmA[e6_@000092F`05001:
>DXiBST00003AQP01P00>KLi]`00=KL000<mn0040011n47h0003?OP00`00@OQ1n00H0002AOL01@00
AOM5mdGg00000TGg00D004GgAOM5m`0000=5m`050015mdGgAOL00003AOL01@00AOM5mdGg00000dWg
00D004WgBOM9m`0000A9m`03001:5`0000<00003BQL004XG009:5`03001>5dhG009>5`05001>5dhG
CQL00003CQL01000CQM>5dhG0P000dhF00<004hFCQH00ThF00D004hFCQI>5P0000=B5P8000=B5P03
001B5U8F009B5P03001B5U8F009B5P<00003DQH0058f00=B=P03001B=U8f009B=P<00003ESH005Hf
00=F=P03001F=UHf009F=P03001F=P00009F=P03001F=UHf009F=P06001F=UHf001F=P0015Hf00@0
05HfESIF=P8000AJ=P04001JEUYFFUH20005FUH01000FUIJEUYF0P0015YF00@005YFFUIJEP8000EJ
EP8000=NEP03001NEUiF00=NEP03001NMUif009NMP04001NMUif0002GWH00`00GWINMP02GWH00`00
GWINMP03GWH20003GWH00`00GWINMP02GWH00`00HWH00004HWH00`00HYIRUP03HYH00`00HYIRUP03
HYH20003HYH01000HYIRUP000V:F00@006:FHYH000=VUP03001VUP00009VUP05001V]VJfI[H00002
I[H01000I[MV]`000VJg00@006JgI[L0009V]`04001V]fJg0002I[L01000I[L006Jg10001F[G00H0
06[GJ]L006[G0003J]L01000J]MZe`000V[G00D006[GJ]MZe`0000EZe`05001Zmf[gJ_L00002J_L0
0`00J_L00003J_L00`00K_M^m`02K_L01@00K_L006kg000016kg00@006kgK_L0009^m`03001^m`00
00A^n004001_66lH0002KaP00`00KaP00003KaP200000flh001c>003LcP00`00KcT00004KcT00`00
FaaK7002Fa`30002C_d00`00C_e>o@02C_d30002Fa`01@00Oomoogoo0000Lgoo001lOol3000?Ool0
1000E_eFo@0015Km0`000UKm00@005KmE_eFo@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00<0
00AFo@03001FoEKm00<000=Fo@04001Fo@000002E_d01P00E_eFoEKm001Fo@800003E_d005Km00=F
o@<0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00<000=Fo@03001FoEKm00<000AFo@06001F
o@00001Jo00015Kl00@004JmA[d000=2F`04001:>DXi0003AQP01000>KLi]`000SFg00D003gh?OPm
n0000091n004000mn3gh0003@OP01000@OQ1n0000d7h00@0047g@OL000=1m`050011md7g@OL00002
@OL01@00AOM5mdGg00000dGg00D004GgAOM5m`0000=5m`050015mdGgAOL00003AOL01@00AOM5mdGg
00000TGg00D004WgBOM9m`0000A9m`030019m`0000<00099m`05001:5dXGBQL00003BQL01@00CQM>
5dhG00000dhG00<004hGCQL00ThG0`0000=>5P00CQH00dhF00D004hFCQI>5P0000A>5P<00003DQH0
058F00=B5P05001B5U8FDQH00003DQH20003DQH00`00DSIB=P02DSH01000DSIB=U8f0P000eHf00<0
05HfESH00UHf00<005HfESH00UHf0P0015Hf00<005HfESH00UHf0P000UHf00<005HfESH00UHf00H0
05HfESH005Hf0004FSH01P00FUIJEP00FUH000EJEP06001JEUYF001JEP0015YF00@005YFFUH0009J
EP03001JEUYF009JEP03001NEUiF00=NEP04001NEUiFGUH20005GWH20003GWH01000GWINMUif0P00
1Eif00<005ifGWH00eif00@005ifGWH0009RMP07001RMV9fHWH0069f000016:F00<006:FHYH00f:F
00<006:FHYH00f:F0P000f:F00<006:F000016JF00<006JF00000fJF00@006JfI[H0009V]P03001V
]`0000=V]`03001V]`0000=V]`03001V]`0000AV]`<000=V]`03001Zef[G00=Ze`07001Zef[GJ]L0
06[G00000V[G00H006[GJ]L006[G0004J]L00`00J]MZe`02J]L00`00J_L00002J_L01@00J_MZmf[g
00000f[g00<006kg00000Vkg00D006kgK_M^m`0000A^m`80009^m`05001^mfkgK_L00004K_P01000
KaP0000016lH00D006lHKaQ_6000009_6003001c>7<h009c>003001c>00000A_>@04001_>@00Fa`2
00000e/L001>o@03C_d00`00C_d000020004Fa`20002Ool00`00Oomoo`1aOol007Yoo`8000moo`@0
00=Fo@06001Fo@00001Fo@0015Km00<005Km00000UKm00@005KmE_eFo@<000=Fo@04001FoEKmE_d3
0003E_d00`00E_eFo@040003E_d00`00E_eFo@030004E_d00`00E_eFo@030003E_d01P00E_d00000
E_d000AFo@06001Fo@00001Fo@0015Km0`000eKm00<005KmE_d00`000eKm00<005KmE_d010000e[l
00<005KlE_`02@000dXi00@004HHAQP0008i]`04000e]cFg0003?OP01000@OQ1n0000cgh00D0047h
@OQ1n0000091n0050011n47h@OP00002@OL01@00@OM1md7g00000d7g00@0047g@OL000=5m`050015
mdGgAOL00002AOL01@00AOM5mdGg00000dGg00D004GgAOM5m`0000=5m`040015mdGg0004BOL00`00
BOL000030002BOL01@00BOM9mdWg00000dXG00D004XGBQM:5`0000=>5`03001>5dhG009>5`03001>
5`00008000=>5P03001>5ThF009>5P05001>5ThFCQH00003CQH20003DQH00`00DQIB5P02DQH01@00
DQIB5U8F00000U8F00<0058F0000158F00D0058fDSIB=P00009B=P03001B=P0000AF=P03001F=UHf
009F=P@00003ESH005Hf00=F=P04001F=UHfESH20004ESH00`00ESIF=P02ESH20002ESH00`00FSIJ
=P03FSH20003FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP02FUH20003FUH01000FUIJEUYF0P00
1EiF00@005iFGUH0009NEP03001NMUif009NMP03001NMUif009NMP04001NMUif0002GWH00`00GWIN
MP02GWH00`00GWINMP03GWH00`00GWH00003HWH01000HWIRMP000V9f00L006:FHYIRUP00HYH00004
HYH00`00HYIRUP03HYH00`00HYIRUP03HYH00`00IYIVUP04IYH00`00IYIVUP02IYH00`00I[H00004
I[H00`00I[MV]`03I[L00`00I[MV]`03I[L00`00I[MV]`040004I[L00`00J[L00003J]L01000J]L0
06[G0P0000AZe`00J]L000AZe`03001Zef[G009Ze`03001Ze`00009Ze`06001Zmf[g001Zm`0016[g
00T006[gJ_MZm`00K_L006kg000016kg00D006kgK_M^m`00009^m`8000A^m`05001^n6khK_P00002
KaP00`00KaQ_6003KaP200000flH001_6002KaP01@00LcQc>7<h00000W<h00D006liKcU_>@0000=_
>@03001K75/L009K7003001>o@0000<000=>o@06001K7000001K70000Woo0P00LWoo001gOol3000>
Ool30004E_d00`00E_eFo@030003E_d00`00E_eFo@030004E_d00`00E_d00002E_d00`00E_eFo@02
E_d00`00E_d00002E_d01000E_eFoEKm0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d01000
0eKm00<005KmE_d00`000eKm00<005KmE_d00`0015Km00H005Km000005Km0004E_d30002E_d01000
E_eFoEKm0`0015Km00<005[lF_`00`000U:k00@003Wi>OT0008af@L00005AQP003Vg>KL00002=KL0
1000?OPmn0000d7h00@003gh?OP000=1n0040011n47h0003@OP01000@OM1m`000d7g00D0047g@OM1
m`000091m`050015mdGgAOL00003AOL01@00AOM5mdGg00000TGg00D004GgAOM5m`0000=5m`050015
mdGgAOL00003AOL00`00BOL000030002BOL01@00BOM9mdWg000014Wg00@004XGBQL000=:5`03001>
5dhG009>5`03001>5`0000<0009>5`03001>5ThF009>5P05001>5ThFCQH00004CQH300000dhF001B
5P03DQH01@00DQIB5U8F0000158F0P000U8F00<0058FDQH00U8F00<0058fDSH00U8f0P000U8f00<0
05HfESH00UHf00@005HfESIF=P8000AF=P03001F=UHf009F=P06001F=UHf001F=P0015Hf00@005Hf
ESIF=P8000AF=P03001J=UXf009J=P03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF009JEP04
001JEUYFFUH20004FUH01000FUIJEP000UYF00<005iFGUH00UiF00<005iF00000eiF00@005ifGWIN
MP8000ENMP8000=NMP07001NMUifGWH005if00001Eif00<0069fHWH00f9f0P000f9f00@006:FHYH0
009RUP07001RUV:FHYH006:F000016:F00<006:FHYH00f:F00<006JFIYH016JF00<006JFIYH00fJF
00<006JfI[H00fJf00<006JgI[L00fJg00<006JgI[L00fJg0`000VJg00<006Jg00000VJg00@006Zg
J[L0009Ze`0:001Zef[G001Ze`00J]L006[G0005J]L01@00J]MZef[G00000V[G00<006[G000016[g
00<006[gJ_L00V[g00D006[g001Zm`0000=^m`03001^mfkg009^m`03001^m`00009^m`04001^mfkg
0004K_L01@00K_L006kh00000flH00<006lHKaP00VlH00@006lHKaP000=_6005001_>000LcP00002
LcP01@00LcP006li00000fli0P000U/L10000dkm00<004kmC_d00`0015/L0P000Woo00<007ooOol0
Kgoo001fOol2000=Ool30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@030003E_d00`00E_eF
o@030004E_d00`00E_eFo@030004E_d00`00E_d00002E_d01P00E_eFoEKm001Fo@800003E_d005Km
00=Fo@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00<000=Fo@03001FoEKm00@000=Fo@06001F
o@00001Fo@0015Km00<005Km00000UKm00<005KmE_d00UKm0`000U/m00D005:kD[]B^`00008in@04
000afC7I0002@OT00`00@OQ1n0080003?OP01000@OQ1n0000Sgh00D0047h@OQ1n0000091n0050011
n47h@OP00003@OL01000@OM1m`000d7g00@0047g@OL000=5m`050015mdGgAOL00003AOL01@00AOM5
mdGg00000dGg00H004GgAOM5m`00AOL70002BOL01@00BOM9mdWg000014Wg00D004WgBOM9m`0000=:
5`06001:5dXGBQL004hG10000ThG00D004hGCQM>5`0000A>5P05001>5ThFCQH00003CQH20003CQH0
0`00DQIB5P02DQH01@00DQIB5U8F00000e8F0P00158F00D0058FDQIB5P0000=B=P8000AB=P05001F
=UHfESH00002ESH00`00ESH00005ESH00`00ESIF=P02ESH20002ESH00`00ESIF=P02ESH01P00ESIF
=P00ESH000AF=P04001J=UXfFSH20005FUH01000FUIJEUYF0P0015YF00H005YFFUH005YF0005FUH2
0003FUH00`00GUINEP03GUH00`00GUINEP02GUH01P00GWINMP00GWH000ENMP03001NMUif009NMP04
001NMUif0002GWH00`00GWINMP03GWH00`00HWIRMP03HWH00`00HWIRMP03HWH20003HYH01000HYIR
UP000V:F00L006:FHYIRUP00HYH00003HYH00`00HYH00004IYH00`00IYH00004IYH00`00I[IV]P02
I[H00`00I[H00003I[L01000I[H006Jg0`0000EV]`00I[MV]`00009V]`04001V]fJg0002J[L00`00
J]L00004J]L01000J]MZef[G0P0016[G00<006[G00000V[G00D006[GJ]MZe`0000EZm`05001Zmf[g
J_L00002J_L00`00J_L00003K_L01@00K_M^mfkg00000Vkg00<006kg00000fkg00D006kgK_M^m`00
00=^m`07001_66lHKaP006lH00000VlH00D006lHKaQ_6000009_6005001_>6lhKcP00003LcP01000
LcQc>0000fli00<006liKcT00P000e/L00<004kmC_d010000Tkm00<005/LFa`00U/L0P000Woo00<0
07ooOol0Kgoo001fOol00`00Ool0000:Ool20002E_d01P00E_eFoEKm001Fo@800003E_d005Km00=F
o@<0009Fo@04001FoEKmE_d30003E_d00`00E_eFo@040003E_d00`00E_eFo@030004E_d00`00E_eF
o@030003E_d01000E_d000000UKm00@005KmE_eFo@<0009Fo@03001FoEKm009Fo@<000=Fo@03001F
oEKm00<000AFo@03001FoEKm00<000=Fo@03001FoEKm00<000AFo@04001Fo@000002Ech01@00FceK
?E/m00000U:k00@003Wi>OT000<af@040011nD7i0002@OP01000?MPmf0000SgH30000d7h00@0047h
@OP000=1n0040011md7g0003@OL01@00@OM1md7g00000T7g00D004GgAOM5m`0000=5m`040015mdGg
0002AOL;0002AOL01000AOM5m`000dWg00<004WgBOL00TWg00D004WgBOM9m`0000=9m`05001:5dXG
BQL00002BQL30002CQL01@00CQM>5dhG000014hG00D004hFCQI>5P0000A>5P<00003CQH004hF00=>
5P05001B5U8FDQH00004DQH300000e8F001B5P03DQH00`00DQIB5P02DQH300000e8f001B=P03DSH0
0`00ESIF=P02ESH20003ESH00`00ESIF=P02ESH01000ESIF=UHf0P0015Hf00<005HfESH00UHf0P00
0UHf00<005HfESH00UHf00@005XfFSH0009J=P03001JEUYF009JEP06001JEUYF001JEP001EYF0P00
0eYF00<005YFFUH00UYF00<005YFFUH00eYF00@005iFGUINEP8000ENEP8000=NMP03001NMUif009N
MP03001NMUif00=NMP8000ANMP07001NMUifGWH0069f0000169f00<0069fHWH00f9f00<006:FHYH0
0f:F0P000f:F00@006:FHYH0009RUP04001RUV:F0002HYH01@00IYIVUVJF00000VJF00L006JFIYIV
UP00IYH00002I[H01000I[IV]P000VJg00<006JfI[H00P0000EV]`00I[MV]`00009V]`06001V]fJg
001V]`0016Zg00<006[GJ]L00f[G00L006[GJ]MZe`00J]L00002J]L01P00J]MZe`00J]L000AZe`03
001Zmf[g009Zm`03001Zm`00009Zm`05001Zmf[gJ_L00003K_L00`00K_L00002K_L01@00K_M^mfkg
00000fkg00D006kg001^m`0000A^m`04001_66lH0002KaP00`00KaP00003KaP01@00KaP006lH0000
0flh00@007<hLcP000=c>0800003KcT006li009_>@03001K75/L009K70<0009>o@03001>oDkm009>
o@06001K7000001K70000goo00<007ooOol0KWoo001fOol01000Oomoo`001goo0`0015Km00<005Km
E_d00`000eKm00H005Km000005Km0004E_d00`00E_d00002E_d01000E_eFoEKm0`0015Km00<005Km
E_d00`000eKm00<005KmE_d010000eKm00<005KmE_d00`0015Km00<005Km00000UKm00H005KmE_eF
o@00E_d200000eKm001Fo@03E_d30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@030003E_d0
0`00E_eFo@030004Ech80002>OT01@00<MTafC7I00000T7i00D0047h@OQ1n000008mf004000mf3gH
0002?OP01@00?OPmn3gh00000SgH9`0000=5m`00AOL00TGg00D004GgAOM5m`0000=5m`040015mdGg
0004BOL01@00BOM9mdWg00000dWg00<004WgBOL00TWg00P004XGBQL004XG001:5`000dhG00<004hG
CQL00ThG00D004hGCQM>5`0000A>5P03001>5P00008000=>5P03001>5ThF009>5P05001B5U8FDQH0
0003DQH20003DQH00`00DQIB5P02DQH01000DQIB5U8F0P000e8f00<0058fDSH00U8f00@005HfESIF
=P8000AF=P03001F=UHf009F=P06001F=UHf001F=P0015Hf00@005HfESIF=P8000AF=P03001F=UHf
009F=P8000=J=P03001JEUYF009JEP03001JEP0000=JEP03001JEUYF009JEP03001JEUYF009JEP04
001JEUYFFUH20005FUH01P00GUINEP00GUH000ENEP03001NMUif009NMP04001NMUifGWH20005GWH0
0`00GWINMP03GWH01000GWINMP000V9f00L0069fHWIRMP00HWH00004HWH00`00HYIRUP03HYH00`00
HYIRUP03HYH20003HYH00`00HYH00004HYH01000IYIVUP000VJF00@006JFIYH0009VUP04001V]VJf
0002I[H00`00I[L0000400000fJg001V]`02I[L00`00I[L00004I[L00`00J[MZ]`03J[L00`00J]MZ
e`02J]L01P00J]L006[G001Ze`800003J]L006[G00=Ze`03001Zef[G009Ze`03001Ze`00009Zm`06
001Zmf[g001Zm`0016[g00@006kgK_L0009^m`03001^m`0000A^m`04001^mfkg0003K_L00`00K_M^
m`02K_L01@00KaP006lH00000flH00D006lHKaQ_600000=_6009001_>6lhKcP006lh001c>000009c
>004001c>7<h0003KcT01000KcT005/L0P0000=K7000C_d00dkm00<004kmC_d00`0015/L00D007oo
Oomoo`0006moo`00MWoo00D007ooOomoo`00009oo`@000=Fo@03001FoEKm00@000=Fo@03001FoEKm
00<000=Fo@03001FoEKm00<000AFo@03001Fo@00009Fo@03001FoEKm009Fo@<0009Fo@04001FoEKm
E_d30003E_d00`00E_eFo@040003E_d00`00E_eFo@030004E_d00`00E_eFo@030003E_d01P00E_d0
0000E_d000AFo@06001Fo@00001Fo@0015Km0`000eKm00<005KmE_d00`000eLM00H005Ln000005;l
0003@Yd00`00>QXj6P040002<MT01000@OU1n@000d7h00@003gH?MP000<mf004000mn3gh0003?OP0
0`00?MP00003?MP01000@OQ1n0000d7g00D0047g@OM1m`000091m`050011md7g@OL00002@OL01@00
@OM1md7g00000dGg00D004GgAOM5m`000095m`050015mdGgAOL00003AOL00`00AOM5m`02AOL01000
AOM5m`000dWg00D004WgBOM9m`0000A9m`030019m`0000H000=:5`05001>5dhGCQL00003CQL01@00
CQM>5dhG00000dhF0`000ThF00<004hFCQH00ThF00D004hFCQI>5P0000AB5P<00003DQH0058F00=B
5P05001B5U8FDQH00002DQH00`00DQH00004DSH01@00DSIB=U8f00000UHf00<005Hf000015Hf00<0
05HfESH00eHf0P000UHf00<005HfESH00UHf00H005HfESH005Hf0004ESH01000ESIF=UHf0P001EXf
00@005YFFUIJEP8000AJEP04001JEUYFFUH20004FUH01000FUIJEP000UYF00<005YFFUH00UYF00<0
05iF00000eiF00<005iFGUH00UiF00<005ifGWH00Uif00@005ifGWH0009NMP03001NMUif009NMP03
001NMUif00=NMP03001NMP0000=RMP04001RMV9f0002HWH01`00HWIRMV9f001RMP0000ARUP03001R
UV:F00=RUP03001RUV:F00=RUP03001RUV:F00=RUP03001VUP0000AVUP8000=VUP03001V]P0000=V
]P<000AV]P03001V]fJg00=V]`03001V]fJg00=V]`03001Z]fZg009Z]`03001Ze`00009Ze`06001Z
ef[G001Ze`000V[G0P001F[G00D006[GJ]MZe`00009Ze`03001Zm`0000AZm`03001Zmf[g009Zm`80
009^m`05001^mfkgK_L00004K_L01@00K_L006kg00000fkg00D006kgK_M^m`0000=_6003001_66lH
009_60800003KaP006lH00=_6004001_>6lh0003KcP01000LcQc>0000g<h00@006liKcT000=_>@03
001K75/L009K7003001>oDkm00@0009>o@03001K75/L00<000=oo`03001oogoo06eoo`00MGoo00<0
07ooOol00Woo0`000eKm00@005KmE_eFo@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00<000=F
o@03001FoEKm00@000=Fo@06001Fo@00001Fo@0015Km00<005Km00000UKm00@005KmE_eFo@<0009F
o@03001FoEKm009Fo@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00<000=Fo@03001FoEKm00@0
00=Fo@06001Fo@00001Fo@0015Km0`000eLM00<005LMEad00`000e;l00L004:M@Ye2W@00>QX00002
=KP300001C7I0011nD7i00000T7h00@003gH?MP000<mf004000mn3gh0003?OP01000?MPmf0000cgH
00@0047h@OP000=1m`040011md7g0002@OL01@00@OM1md7g00000d7g00@0047g@OL000=5m`030015
mdGg0095m`040015mdGg0003AOL01@00AOM5mdGg00000dGg00@004GgAOL000=9m`030019mdWg0099
m`030019m`0000<00099m`050019mdWgBOL00003BQL01@00CQM>5dhG00000dhG00<004hGCQL00ThG
0`0000=>5P00CQH00ThF00<004hFCQH00ThF00D004hFCQI>5P0000=B5P8000=B5P03001B5U8F009B
5P03001B5U8F009B5P80009B5P03001B=U8f009B=P03001B=U8f009B=P8000=F=P03001F=UHf009F
=P04001F=UHfESH20004ESH00`00ESIF=P02ESH20002ESH00`00ESIF=P02ESH01P00ESIF=P00FSH0
00EJ=P06001JEUYF001JEP0015YF00H005YFFUH005YF0005FUH20003FUH00`00FUIJEP03FUH00`00
GUINEP02GUH01000GUINEUiF0P001Eif0P000eif00L005ifGWINMP00GWH00005GWH00`00HWIRMP03
HWH20003HWH01000HWIRMP000V9f00L006:FHYIRUP00HYH00004HYH00`00HYIRUP03HYH00`00HYIR
UP04HYH00`00IYIVUP03IYH00`00IYIVUP03IYH00`00I[H0000200000fJf001V]P04I[H00`00I[MV
]`03I[L00`00I[MV]`02I[L00`00I[L00002J[L01P00J]MZe`00J]L000AZe`03001Zef[G009Ze`03
001Zef[G009Ze`03001Ze`00009Ze`05001Zef[GJ]L00005J_L01@00J_MZmf[g00000Vkg0P0016kg
00D006kgK_M^m`0000=^m`09001^mfkgK_L006lG001^m`0000A_6005001_66lHKaP00002KaP00`00
KaQ_6002KaP01000KcP0000016lh00<007<h00000g<h00D007<h001_>@00009_>@03001_>@00009K
70@0009>o@03001>oDkm00@000=K7005001oogooOol0001^Ool007Eoo`03001oogoo0080009Fo@03
001FoEKm009Fo@03001Fo@00009Fo@04001FoEKmE_d30002E_d00`00E_eFo@02E_d30003E_d00`00
E_eFo@030004E_d00`00E_eFo@030003E_d00`00E_eFo@030004E_d00`00E_d00002E_d01P00E_eF
oEKm001Fo@80009Fo@04001FoEKmE_d30003E_d00`00E_eFo@040003E_d00`00E_eFo@030004E_d0
0`00E_eFo@030003E_d01P00E_d00000E_d000AG7@<000=Jo003001Bo5;l00<00007@Yd003XJ>QX0
03Fh00000SFh30000SgH00@003gh?OP000<mn004000mf3gH0003?MP01000@OQ1n0000d7g00D0047g
@OM1m`000091m`050011md7g@OL00002@OL01@00@OM1md7g00000dGg00D004GgAOM5m`000095m`05
0015mdGgAOL00003AOL01@00AOM5mdGg00000TGg00<004WgBOL00TWg00<004Wg00000`000TWg00D0
04WgBOM9m`0000=9m`05001:5dXGBQL00003CQL00`00CQM>5`02CQL00`00CQL000020003CQH00`00
CQI>5P02CQH01@00CQI>5ThF000014hF0`0000=B5P00DQH00e8F00D0058FDQIB5P0000=B5P8000AB
5P05001B=U8fDSH00003DSH20004ESH00`00ESIF=P02ESH01P00ESIF=P00ESH000AF=P04001F=UHf
ESH20004ESH00`00ESIF=P02ESH20003FSH00`00FSIJ=P02FSH00`00FUH00002FUH00`00FUIJEP03
FUH20003FUH00`00FUIJEP02FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015iF00@005iFGUH0009N
EP03001NMUif009NMP03001NMUif009NMP04001NMUif0002GWH00`00GWINMP02GWH20005HWH00`00
HWIRMP03HWH20003HWH01000HYIRUP000V:F00L006:FHYIRUP00HYH00003HYH00`00HYH00005HYH0
0`00IYIVUP03IYH00`00IYIVUP02IYH30003I[H00`00I[H00003I[H00`00I[H00003I[L00`00I[L0
0002I[L01P00I[MV]`00J[L000AZe`03001Zef[G00=Ze`04001Zef[GJ]L30002J]L01P00J]MZe`00
J]L000AZe`03001Zmf[g009Zm`05001Zm`00J_L00003K_L00`00K_M^m`02K_L01@00K_L006kg0000
16kg00@006kgK_L000=_5`03001_66lH009_6080009_6005001_66lHKaP00003KaP01000KcQ_>000
16lh00<006lh00000g<h00D007<hLcQc>000009_>@04001_>FliKcT20002Fa`00`00C_e>o@040002
C_d00`00FaaK7002Fa`20003Ool00`00Oomoo`1[Ool007Eoo`D000=Fo@03001FoEKm00<000AFo@03
001Fo@00009Fo@06001FoEKmE_d005Km0P0000=Fo@00E_d00eKm0`000UKm00<005KmE_d00UKm0`00
0eKm00<005KmE_d00`000eKm00<005KmE_d00`0015Km00<005KmE_d00`0015Km00<005Km00000UKm
00@005KmE_eFo@<0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00<0
00=Fo@06001G7@00001Fo00015[l0`0000=>>000=KP00P000SXJ00@003Fh=KP0008e^004000mn3gh
0003?OP00`00?MPmf0080003?OP00`00?MP00003?MP01000@OQ1n0000d7g00D0047g@OM1m`000091
m`050011md7g@OL00003@OL01000@OM1m`000dGg00D004GgAOM5m`000095m`050015mdGgAOL00003
AOL00`00AOM5m`02AOL01@00AOM5m`00BOL010000TWg00D004WgBOM9m`0000A9m`050019mdWgBOL0
0003BQL01P00CQM>5dhG001>5`@0009>5P03001>5ThF009>5P05001>5ThFCQH00004CQH00`00CQH0
00020003DQH00`00DQIB5P02DQH00`00DQIB5P02DQH300000e8F001B5P03DQH00`00DSIB=P02DSH3
00000e8f001F=P03ESH00`00ESIF=P02ESH00`00ESH00002ESH00`00ESIF=P02ESH01P00ESIF=P00
ESH000AF=P04001F=UHfESH20004FSH00`00FSIJ=P03FSH00`00FUIJEP02FUH00`00FUIJEP02FUH0
0`00FUIJEP02FUH01000FUIJEUYF0P001EYF00H005YFFUH005iF0005GUH20003GUH01000GWINMUif
0P001Eif0P0015if00@005ifGWH0009NMP03001RMV9f009RMP03001RMV9f00=RMP03001RMV9f00=R
MP8000=RUP04001RUV:F0002HYH01000HYIRUP000V:F00<006:FHYH00V:F00<006JF00000fJF00<0
06JF0000100000EV]P00I[IV]P00009V]P04001V]VJf0002I[H01000I[MV]`000VJg00<006Jg0000
16Jg00<006[GJ]L00f[G00<006[GJ]L00V[G00<006[G00000V[G00D006[G001Ze`0000AZe`03001Z
ef[G009Ze`03001Zm`00009Zm`05001Zmf[gJ_L00004K_L01@00K_M^mfkg00000fkg00<006kgK_L0
0Vkg00@006kg000000A_5`05001_66lHKaP00002KaP20003KaP01@00KaP006lH00000flh00D006lh
KcQ_>000009_>005001c>7<hLcP00003LcP00`00KcT00004KcT01000FaaK75/L0`000Tkm00<004km
C_d00Tkm00H005/L000005/L0003Ool00`00Oomoo`1[Ool007Aoo`8000AFo@03001FoEKm00<000=F
o@03001FoEKm00<000AFo@03001FoEKm00<000=Fo@04001Fo@000002E_d01P00E_eFoEKm001Fo@80
0003E_d005Km00=Fo@<000=Fo@03001FoEKm00<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00<0
00AFo@03001Fo@00009Fo@06001FoEKmE_d005Km0P0000=Fo@00E_d00eKm0`000UKm00<005KmE_d0
0UKm0`000eKm00<005KmE_d00`000eKl00H005[l000005Ii0003CSP00`00=KPe^0030003=KP01000
=KPe^0000Sgh00L003gh?OPmn000?MP00003?MP00`00?MPmf0080003?MP01000@OQ1n0000d7g00@0
047g@OL00091m`050011md7g@OL00003@OL01000@OM1m`000dGg00<004GgAOL00TGg00@004GgAOL0
00=5m`060015mdGgAOL004Gg1`000TWg00D004WgBOM9m`0000A9m`050019mdWgBOL00003BOL01@00
BQM:5dXG00000ThG0`000ThF00D004hFCQI>5P0000A>5P05001>5ThFCQH00003CQH30002CQH00`00
DQIB5P02DQH01@00DQIB5U8F00000e8F0P000e8F00<0058FDQH00U8F00@0058fDSIB=P8000AB=P03
001F=UHf009F=P04001F=UHfESH20004ESH00`00ESIF=P02ESH20002ESH00`00ESIF=P02ESH01P00
ESIF=P00ESH000EJ=P04001J=UXfFSH20004FUH01000FUIJEUYF0P0015YF00H005YFFUH005YF0005
FUH00`00FUH00003GUH00`00GUINEP02GUH00`00GUINEP02GUH01000GWINMP000Uif00<005ifGWH0
0Uif00<005ifGWH00eif00<005if00000eif00L0069fHWIRMP00HWH00004HWH00`00HWIRMP03HWH0
0`00HYIRUP03HYH20003HYH01000HYIRUP000f:F00@006:FHYH0009VUP03001VUVJF00@0009VUP04
001V]VJf0002I[H01000I[IV]P000VJf00H006JfI[H006Jg0004I[L00`00I[MV]`03I[L00`00J]MZ
e`02J]L00`00J]L00002J]L01P00J]MZe`00J]L000=Ze`03001Zef[G00=Ze`05001Zef[GJ]L00002
J_L00`00J_L00004J_L02@00K_M^mfkg001^m`00K_L00004K_L01@00K_M^mfkg00000Vkg00<006lG
KaL00VlG00<006lH00000VlH00@006lHKaP000=_6005001_66lHKaP00003KcP01@00KcP006lh0000
0Vlh00D006lh001c>00000=c>003001c>00000A_>@03001_>@0000800003Fa`004km00=>o@03001>
oDkm00<000AK7005001oogooOol0001/Ool007Eoo`03001FoEKm009Fo@<000=Fo@03001FoEKm00<0
00=Fo@03001FoEKm00@000=Fo@03001FoEKm00<000AFo@03001FoEKm00<000=Fo@06001Fo@00001F
o@0015Km0`000UKm00@005KmE_eFo@<000AFo@03001FoEKm00<000=Fo@03001FoEKm00<000AFo@03
001FoEKm00<000=Fo@06001Fo@00001Fo@0015Km00H005Km000005Km0004E_d30003E_`00`00E_aF
o0020004EWT01000CSQ>>0000SFh00<002Uh:GP010000SFh00@003gh?OP000<mn004000mf3gH0003
?MP00`00?MP00003?MP00`00?MPmf00>00001D7g0011md7g00000d7g00@0047g@OL000=1m`060015
mdGgAOL004Gg3`000TGg00@004GgAOL000=9m`030019mdWg0099m`050019mdWgBOL00003BOL01@00
BOM9mdWg00000dXG00D004hG001>5P0000=>5P03001>5ThF009>5P05001>5ThFCQH00004CQH30000
0dhF001>5P02CQH00`00DQIB5P02DQH00`00DQIB5P02DQH300000e8F001B5P03DQH01@00DQIB5U8F
00000U8f00<0058F0000158f00<005HfESH00UHf00H005HfESH005Hf0004ESH01000ESIF=UHf0P00
15Hf00<005HfESH00UHf0P000UHf00<005XfFSH00eXf00H005XfFSH005Xf0004FUH01P00FUIJEP00
FUH000EJEP8000=JEP03001JEUYF009JEP8000ANEP04001NEUiFGUH20005GUH20003GWH01000GWIN
MUif0P001Uif00<005ifGWH00Uif00@0069fHWH0009RMP07001RMV9fHWH0069f0000169f00<006:F
HYH00f:F00<006:FHYH00f:F0P0016:F00<006:F00000fJF10000VJF00<006JF00000fJf00<006Jf
000016Jf0P0016Jf00<006JgI[L00fJg00<006JgI[L00VJg00<006Zg00000V[G00@006[GJ]L0009Z
e`06001Zef[G001Ze`000f[G0P000f[G00<006[G00000V[G00D006[gJ_MZm`0000AZm`05001^m`00
K_L00003K_L00`00K_M^m`02K_L00`00K_L00002K_L01000K_M^m`000flG00H006lHKaP006lH0003
KaP01@00KaQ_66lH00000flH00@006lhKcP000=_>004001_>6lh0003KcP01@00LcQc>7<h00000W<h
00D006liKcU_>@00009_>@03001K75/L009K7003001>oDkm00@000=>o@03001K75/L00<000=oo`03
001oogoo06Uoo`00MGoo0P0000EFo@00001Fo@0000AFo@<0009Fo@04001FoEKmE_d30003E_d00`00
E_eFo@040003E_d00`00E_eFo@040003E_d00`00E_eFo@030003E_d01P00E_d00000E_d000AFo@03
001Fo@00009Fo@03001FoEKm009Fo@<0009Fo@04001FoEKmE_d30003E_d00`00E_eFo@040003E_d0
0`00E_eFo@030003E_d00`00E_eFo@040003E_d01P00E_d00000E_d000AFo0<00003E]/005Ii00=F
N@05001>>4hhCSP00002=KP00`00:GP00002=KP40002?OP01@00?OPmn3gh00000SgH00D003gH?MPm
f000008mf007000mf3gH?MP003gH00000cgH00@0047G@ML000=1e`030011ed7G01D00095m`040015
mdGg0003AOL01@00AOM5mdGg00000dGg00D004GgAOM5m`0000=9m`050019mdWgBOL00003BOL01@00
BOM9mdWg000014Wg00<004XG00000P000dhF00D004hFCQI>5P0000=>5P05001>5ThFCQH00003CQH2
0003CQH00`00CQI>5P02CQH01@00DQIB5U8F00000e8F0P000e8F00<0058FDQH00U8F00<0058FDQH0
0U8F0P000e8F00<0058fDSH00U8f00L005HfESIF=P00ESH00002ESH00`00ESIF=P02ESH01P00ESIF
=P00ESH000AF=P03001F=UHf009F=P03001F=UHf009F=P03001J=UXf009J=P03001J=P0000=J=P03
001JEUYF009JEP8000=JEP03001JEUYF009JEP03001JEUYF009JEP07001JEUYFFUH005YF000015iF
00@005iFGUH0009NEP03001NEUiF009NEP03001NMUif009NMP04001NMUif0002GWH00`00GWINMP03
GWH00`00GWINMP03GWH20003HWH01000HWIRMP000V9f00L0069fHWIRMP00HYH00004HYH00`00HYIR
UP03HYH00`00HYIRUP04HYH01000IYIVUVJF0`001FJF00<006JfI[H00fJf00<006JfI[H00fJf00<0
06JfI[H00fJf00<006JgI[L00VJg00<006Jg00000VJg00@006ZgJ[L0009Ze`06001Zef[G001Ze`00
16[G00L006[GJ]MZe`00J]L00002J]L01P00J]MZe`00J]L000AZm`05001Zmf[gJ_L00002K_L00`00
K_L00003K_L01@00K_M^mfkg00000Vkg00<006kg00000Vkg00<006lG00000VlG00D006lHKaQ_6000
00=_6005001_6000KaP00003KaP01@00KcP006lh00000flh0P0000=_>000KcP00Vlh0P0000Uc>000
LcQc>000LcP006li00000fli0P000U/L10000dkm00<004kmC_d010000U/L00D007ooOomoo`0006]o
o`00H7oo100047oo00<007ooOol00P000eKm00H005Km000005Km0004E_d00`00E_d00002E_d01000
E_eFoEKm0`000eKm00@005KmE_eFo@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00<000=Fo@03
001FoEKm00<000AFo@06001Fo@00001Fo@0015Km00<005Km00000UKm00@005KmE_eFo@<000=Fo@03
001FoEKm00@000=Fo@03001FoEKm00<000AFo@03001FoEKm00<000=Fo@06001Fo000001G7@000eKK
00D005IiEWUFN@0000=>>004000e^3Fh0002:GP01000=KPe^0000SWH10000cgh00<003gH00000cgH
00@003gH?MP000<mf004000mf3gH0003?MP01000@MM1e`000T7G00D0047G@MM1e`000091m`050011
md7g@OL00003@OL01000@OM1m`000dGg00D004GgAOM5m`0000=5m`040015mdGg0004AOL01@00AOM5
mdGg00000TGg00D004WgBOM9m`0000=9m`030019mdWg0099m`060019mdWgBOL004Wg10000TWg00D0
04hFCQI>5P0000=>5P05001>5ThFCQH00004CQH300000dhF001>5P03CQH01@00CQI>5ThF0000158F
0`0000=B5P00DQH00e8F00D0058FDQIB5P0000=B5P8000AB5P03001B=U8f009B=P04001F=UHfESH2
0004ESH00`00ESIF=P02ESH20002ESH00`00ESIF=P02ESH01000ESIF=UHf0P0015Hf00<005XfFSH0
0UXf0P0015Xf00<005YFFUH00UYF00<005YFFUH00UYF00@005YFFUIJEP8000AJEP04001JEUYF0002
FUH00`00GUINEP03GUH20003GUH01000GUINEUiF0P001Eif0P000eif00<005ifGWH00Uif0P001Eif
00<0069fHWH00f9f0P000f9f00@0069fHWH0009RUP07001RUV:FHYH006:F000016:F00<006:FHYH0
16:F10000VJF00<006JFIYH00fJF00<006JfI[H00fJf00<006JfI[H00fJf00<006JfI[H00VJf00<0
06Jf00000VJg00@006JgI[L0009V]`06001Z]fZg001Ze`0016[G00<006[GJ]L00f[G00H006[GJ]MZ
e`00J]L30004J]L00`00J_MZm`02J_L00`00J_L00002J_L01@00K_M^mfkg00000fkg00<006kg0000
0Vkg00D006kgK_M^m`0000=^m`05001_5`00KaL00004KaP01000KaQ_60000flH00D006lHKaQ_6000
00=_>005001_>6lhKcP00002KcP01@00KcQ_>6lh00000W<h00D007<hLcQc>000009c>005001_>Fli
KcT00002KcT20003Fa`00`00C_e>o@040002C_d01000FaaK75/L0P000goo00<007ooOol0J7oo001N
Ool8000>Ool00`00Oomoo`02Ool00`00E_eFo@030003E_d00`00E_eFo@040003E_d00`00E_d00002
E_d00`00E_eFo@02E_d00`00E_d00002E_d01000E_eFoEKm0`000eKm00<005KmE_d010000eKm00<0
05KmE_d00`000eKm00<005KmE_d010000eKm00<005KmE_d00`0015Km00<005Km00000UKm00@005Km
E_eFo@<0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00<000=G7@05
001FfeKKE]/00003EWT00`00CSP000040002:GP01`00=KPe^3Fh000if000008if0P000<mf003000m
f00000<mf004000mf3gH0003?MP01000@MM1e`000d7G00D0047G@MM1e`000091m`050011md7g@OL0
0003@OL01000@OM1m`000dGg00D004GgAOM5m`000095m`050015mdGgAOL00003AOL01@00AOM5mdGg
00000dGg00@004WgBOL000A9m`030019m`0000L00099m`050019mdWgBOL00003CQH01@00CQI>5ThF
000014hF00<004hF00000P000dhF00<004hFCQH00ThF00D004hFCQI>5P0000=B5P8000=B5P03001B
5U8F009B5P03001B5U8F009B5P<00003DQH0058F00=B5P03001B=U8f009B=P06001F=P00001F=P00
15Hf00@005HfESIF=P8000AF=P05001F=UHfESH00002ESH00`00ESH00004ESH00`00FSIJ=P020000
0eXf001J=P03FSH01000FUIJEUYF0P0015YF00H005YFFUH005YF0005FUH20004FUH00`00GUINEP02
GUH00`00GUINEP02GUH01P00GUINEP00GUH000ENMP03001NMUif00=NMP04001NMUif0002GWH00`00
GWINMP02GWH00`00HWIRMP03HWH00`00HWIRMP03HWH20003HYH01000HYIRUP000V:F00L006:FHYIR
UP00HYH00003HYH40003IYH00`00IYH00003IYH00`00IYH00003I[H00`00I[H00003I[H00`00I[H0
0002I[H01000I[IV]P000VJg00H006JgI[L006Jg0004J[L00`00J]MZe`03J]L00`00J]MZe`02J]L0
1@00J]L006[G00000f[G0P0016[G00D006[gJ_MZm`00009Zm`03001Zm`0000A^m`09001^mfkgK_L0
06kg001^m`0000A^m`04001^mfkg0003KaL00`00KaQ_6002KaP01@00KaP006lH00000flH0P0000=_
6000KcP00flh00@006lhKcP000=_>004001_>6lh0003LcP01000LcQc>0000g<h0P0000=_>@00KcT0
0Vli00<005/LFa`00U/L0`000Tkm00<004kmC_d00Tkm0`000U/L00D007ooOomoo`0006Uoo`00GWoo
0P0017oo0P003Woo00<007ooOol00goo0P000eKm00<005KmE_d00`0015Km00<005KmE_d00`000eKm
00<005KmE_d00`0015Km00<005Km00000UKm00@005KmE_eFo@<0009Fo@03001FoEKm009Fo@<000=F
o@03001FoEKm00<000AFo@03001FoEKm00<000=Fo@03001FoEKm00<000AFo@03001Fo@00009Fo@06
001FoEKmE_d005Km0P0000=Fo@00E_d00eKm0`000UKm00<005KmE_d00UKm0`000eLM00@005LMEad0
009Ff`L000966003000eUcFG00<000<e^006000if3WH000if0000cgH00<003WH>MP020000cgH00<0
03gH00000cgH00D0047G@MM1e`000091e`050011ed7G@ML00002@OL01@00@OM1md7g00000d7g00@0
047g@OL000=5m`050015mdGgAOL00003AOL01000AOM5m`000dGg00D004GgAOM5m`0000=5m`060019
mdWgBOL004Wg10000TWg00D004WgBOM9m`0000=9m`030019mdWg0099m`05001>5ThFCQH00003CQH0
0`00CQH000030002CQH00`00CQI>5P02CQH01@00CQI>5ThF000014hF0`0000=B5P00DQH00e8F00D0
058FDQIB5P0000=B5P8000AB5P03001B5U8F009B5P04001B=U8fDSH20003ESH00`00ESIF=P02ESH0
1P00ESIF=P00ESH000AF=P03001F=UHf009F=P8000=F=P03001F=UHf009F=P8000=J=P03001J=UXf
009J=P06001JEUYF001JEP001EYF0P000eYF00<005YFFUH00UYF00<005YFFUH00eYF00@005iFGUIN
EP8000ENEP8000=NEP03001NMUif009NMP03001NMUif00=NMP03001NMP0000=NMP07001NMUifGWH0
069f0000169f00<0069fHWH00f9f00<006:FHYH00f:F0P000f:F00@006:FHYH000=RUP@0009RUP04
001VUVJF0002IYH01000IYIVUP000VJF00@006JfI[H0009V]P04001V]VJf0002I[H01000I[IV]P00
0VJf00<006Jg000016Jg00<006ZgJ[L00fZg00<006[GJ]L00V[G00<006[G00000V[G00H006[GJ]L0
06[G0003J]L20003J]L00`00J]L00002J_L01@00J_MZmf[g000016kg00D006kg001^m`0000=^m`03
001^mfkg009^m`05001^m`00K_L00003KaL01@00KaQ_66lH00000flH00D006lHKaQ_6000009_6003
001_>6lh009_>004001_>0000003KcP01000LcP000000g<h00D007<h001c>000009c>004001cF7=H
0003KcT01000KcT005/L0P0000=K7000C_d00dkm00<004km00000P0015/L0P000Woo00<007ooOol0
Igoo001MOol20006Ool2000=Ool30003Ool00`00E_eFo@02E_d30003E_d00`00E_eFo@040003E_d0
0`00E_eFo@030003E_d00`00E_eFo@030004E_d00`00E_d00002E_d01P00E_eFoEKm001Fo@800003
E_d005Km00=Fo@<0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm00<000=Fo@03001FoEKm00<0
00AFo@03001FoEKm00<000=Fo@06001Fo@00001Fo@0015Km00@005Km0000009Fo@03001G7ELM00L0
0092F`04001:>DXi0003AQP01@00=ILeU`00<IL00P000SFh00@003WH>MP0008if007000mf3gH?MP0
03WH00000cgH00<003gH?MP020000cgH00@0047G@ML00091e`050011ed7G@ML00002@OL01@00@OM1
md7g00000d7g00@0047g@OL000=5m`050015mdGgAOL00003AOL01000AOM5m`0014Gg00D004GgAOM5
m`000095m`030019mdWg00<00099m`050019mdWgBOL00003BOL00`00BOM9m`02BOL01@00BOM9mdWg
00000dhF00<004hFCQH00`000ThF00D004hFCQI>5P0000A>5P05001>5ThFCQH00003CQH20003DQH0
0`00DQIB5P02DQH00`00DQIB5P02DQH300000e8F001B5P03DQH00`00DQIB5P02DQH01P00DSIB=P00
DSH000AF=P03001F=UHf009F=P80009F=P03001F=UHf009F=P04001F=UHfESH20004ESH00`00ESIF
=P02ESH00`00FSIJ=P03FSH00`00FSIJ=P02FSH20003FUH00`00FUIJEP02FUH00`00FUIJEP02FUH0
1000FUIJEUYF0P001EYF00H005iFGUH005iF0005GUH00`00GUINEP02GUH01`00GWINMUif001NMP00
00ENMP03001NMUif009NMP04001NMUif0002HWH01`00HWIRMV9f001RMP0000ARMP03001RUV:F00=R
UP03001RUV:F00=RUP800003HYH0000000800003HYH006:F009RUP03001VUP0000=VUP04001VUVJF
0002IYH00`00I[H00003I[H00`00I[H00003I[H00`00I[H00004I[H00`00I[MV]`03I[L00`00J[MZ
]`02J[L00`00J]L00002J]L01P00J]MZe`00J]L000AZe`06001Zef[GJ]L006[G0P0000MZe`00J]MZ
e`00J_L00004J_L01@00K_M^mfkg00000Vkg00<006kg00000fkg00D006kgK_M^m`0000=^m`09001_
5flGKaL006lG001_600000A_6004001_66lH0003KaP01@00KcQ_>6lh00000Vlh00D006lhKcQ_>000
009c>005001c>7<hLcP00003LcP01000LcQc>0000g=H00@006liKcT000=_>@03001K75/L009K7003
001>o@0000<000=>o@06001K7000001K70000goo00<007ooOol0IWoo001MOol20006Ool2000<Ool2
0006Ool01000E_d000000UKm00@005KmE_eFo@<0009Fo@03001FoEKm009Fo@<000=Fo@03001FoEKm
00<000=Fo@03001FoEKm00<000AFo@03001FoEKm00<000=Fo@04001Fo@000002E_d01P00E_eFoEKm
001Fo@800003E_d005Km00=Fo@<000=Fo@03001FoEKm00<000=Fo@03001FoEKm00@000=Fo@03001F
oEKm00<000=Fo@03001FoEKm00<000AFo@<0009Fo0040016_DJm0004@U/01000BSU:>@000dHH00<0
03FG00000S6G0`0000@e^000>MP000<if004000mf3gH0002>MP01`00?MPmf3gH000mf00000<mf003
000mf3gH00P000=1e`050011ed7G@ML00002@OL01@00@OM1md7g00000d7g00@0047g@OL000=5m`05
0015mdGgAOL00002AOL01P00AOM5mdGg0015m``00003BOL004Wg0099m`030019mdWg0099m`050019
mdWgBOL00003BOL01@00BOM9mdWg00000dhF00D004hF001>5P0000A>5P05001>5ThFCQH00003CQH0
0`00CQI>5P02CQH300000dhF001B5P03DQH01@00DQIB5U8F00000e8F0P00158F00<0058FDQH00U8F
00L0058FDQIB5P00DSH00002DSH00`00ESIF=P02ESH01000ESIF=UHf0P0015Hf00D005HfESIF=P00
009F=P03001F=P0000AF=P04001F=UHfESH20005FSH01000FSIJ=UXf0P0015YF00@005YFFUIJEP80
00AJEP04001JEUYF0002FUH00`00FUIJEP03FUH20003GUH00`00GUINEP02GUH00`00GUINEP02GUH0
1000GWINMP000Uif00<005ifGWH00eif00<005ifGWH00eif0P000f9f00@0069fHWH0009RMP07001R
MV9fHWH0069f000016:F00<006:FHYH00f:F0`0016:F00<006:FHYH00f:F00<006JFIYH00fJF0P00
16JF00<006JfI[H00fJf00<006JfI[H00fJf00<006JfI[H00fJf00<006JgI[L00VJg00<006Zg0000
0VZg00@006[GJ]L0009Ze`05001Zef[GJ]L00005J]L02@00J]MZef[G001Ze`00J]L00004J]L00`00
J_MZm`02J_L00`00K_L00002K_L01@00K_M^mfkg00000fkg00D006kg001^m`0000A^m`04001_5flG
0003KaL00`00KaQ_6002KaP01@00KaP006lH00000VlH00D006lh001_>00000=_>0800003KcP007<h
009c>0800003LcP007<h00=c>003001c>00000=cF004001cF0000003KcT20002Fa`40003C_d00`00
C_e>o@030004Fa`01@00Oomoogoo0000Igoo001LOol20008Ool2000<Ool00`00Oomoo`05Ool20004
E_d00`00E_d00002E_d01P00E_eFoEKm001Fo@800003E_d005Km00=Fo@<000=Fo@03001FoEKm00<0
00=Fo@03001FoEKm00@000=Fo@03001FoEKm00<000AFo@03001FoEKm00<000=Fo@06001Fo@00001F
o@0015Km0`000UKm00@005KmE_eFo@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00<000=Fo@04
001Fo@000002F_`01@00E_aFo5Kl00000TJm00D0049K@U]2F`00009:>@05001664HHAQP00002=IL0
0`00<IL00002=KP50002>MP01000?MPmf0000SWH00D003gH?MPmf000008mf004000mf3gH0002?MP0
1@00?MPmf3gH00000SgG9`000TGg00D004GgAOM5m`0000=5m`040019mdWg0004BOL01@00BOM9mdWg
00000dWg00D004WgBOM9m`0000A9m`03001>5P00008000=>5P05001>5ThFCQH00003CQH00`00CQI>
5P02CQH00`00CQH000020003CQH00`00DQIB5P02DQH01@00DQIB5U8F00000U8F00<0058F0000158F
00<0058FDQH00U8F00@0058FDQIB5P8000AB=P05001F=UHfESH00002ESH00`00ESH00004ESH00`00
ESIF=P02ESH20002ESH00`00ESIF=P02ESH01000ESIF=P000UHf00<005XfFSH00UXf00H005XfFSH0
05Xf0004FUH01P00FUIJEP00FUH000EJEP8000=JEP03001JEUYF00=JEP03001NEUiF009NEP04001N
EUiFGUH20005GUH20004GWH01`00GWINMUif001NMP0000ANMP03001RMV9f00=RMP8000=RMP04001R
MV9f0002HWH02000HYIRUV:F001RUP00HYH40006HYH00`00HYIRUP03HYH00`00IYIVUP03IYH00`00
IYIVUP03IYH00`00I[IV]P03I[H00`00I[IV]P03I[H00`00I[IV]P02I[H00`00I[H00002I[L01000
J[MZ]`000VZg00H006[GJ]L006[G0004J]L00`00J]MZe`02J]L01@00J]L006[G00000f[G00<006[G
00000f[G00D006[gJ_MZm`00009^m`03001^m`0000A^m`04001^mfkg0003K_L00`00K_M^m`02K_L0
1@00KaL006lG00000flG00D006lHKaQ_600000=_6004001_66lH0003KcP01@00KcQ_>6lh00000Vlh
00D007<hLcQc>000009c>003001c>7<h009c>003001cF00000=cF004001cF7=H0003KcT00`00KeY_
FP020003Fa`00`00C_e>o@040002D_d00`00FaaK7002Fa`20002Ool00`00Oomoo`1UOol005aoo`80
00Qoo`8000aoo`03001oogoo00Moo`03001FoEKm00<000AFo@03001FoEKm00<000=Fo@06001Fo@00
001Fo@0015Km0`000UKm00@005KmE_eFo@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00@000=F
o@03001FoEKm00<000=Fo@06001Fo@00001Fo@0015Km00<005Km00000UKm00@005KmE_eFo@<0009F
o@03001FoEKm009Fo@<000=Fo@03001FoEKm00<000AJo003001Fo5Kl00P0009:>@05001664HHAQP0
0002=IL01000<ILaU`000SFh00<003WH>MP020000SWH00@003gH?MP0008mf005000mf3gH?MP00002
?MP01000?MPmf0000cgG00@0047G@ML000=1e`040011ed7G0003@ML01@00@MM1ed7G00000T7G00D0
047g@OM1m`0000=5m`050015mdGgAOL00002AOL01@00AOM5mdGg00000dGg00D004GgAOM5m`0000=9
m`050019mdWgBOL00003BOL01@00BOM9mdWg000014Wg00<004Wg00000`000TWf00D004hFCQI>5P00
00A>5P04001>5ThF0003CQH30002CQH00`00CQI>5P02CQH01@00DQIB5U8F0000158F0P000e8F00D0
058FDQIB5P0000AB5P06001B5P00001B5P00158f00<005HfESH00UHf0P000UHf00<005HfESH00UHf
00@005HfESIF=P8000AF=P03001F=UHf009F=P8000=F=P03001J=UXf00=J=P80009J=P03001JEUYF
00=JEP8000=JEP03001JEUYF009JEP03001JEUYF00=JEP04001JEUYFFUH20004GUH01000GUINEP00
0UiF00<005iFGUH00UiF00<005ifGWH00eif00@005ifGWH0009NMP04001NMUifGWH20005HWH00`00
HWIRMP03HWH20003HWH01@00HYIRUP00HYH00`000V:F00<006:F000016:F00<006:F00000f:F00<0
06JF000016JF00<006JFIYH00VJF00<006Jf00000fJf00<006Jf00000fJf00<006Jf00000VJf00@0
06JfI[H0009V]`06001Z]fZg001Z]`0016[G00<006[GJ]L00V[G00<006[G00000V[G00H006[GJ]L0
06[G0003J]L00`00J]L00002J]L00`00J_L00002J_L01@00K_M^mfkg000016kg00@006kg000000A^
m`05001^mfkgK_L00003KaL02@00KaM_5flG001_6000KaP00004KaP01000KaQ_60000flh00@006lh
KcP000=_>004001c>7<h0003LcP01@00LcQc>7<h00000W=H0P0000=cF000LeP00W=H0P0000A_>@00
KeY_FP8000AK70<0009Bo@03001BoE;m009Bo@06001K7000001K7@000goo00<007ooOol0I7oo001L
Ool20008Ool2000;Ool00`00Oomoo`09Ool20003E_d00`00E_eFo@040003E_d00`00E_eFo@030003
E_d01P00E_d00000E_d000AFo@03001Fo@00009Fo@04001FoEKmE_d30003E_d01000E_eFoEKm0`00
0eKm00<005KmE_d010000eKm00<005KmE_d00`000eKm00<005KmE_d00`0015Km00<005Km00000UKm
00H005KmE_eFo@00E_d200000eKm001Fo@03E_d30003E_d00`00F_aJo00400001E:k000inSWj0000
0S7I1@000dHH00<003FG00000S6G00L003Fh=KPe^000>MP00003>MP00`00>MPif0040003?MP01000
?MPmf0000SgH00@003gH?MP000<mf005000mecgG?ML00002@ML01000@MM1e`000d7G00@0047G@ML0
00=1e`050011ed7G@ML00002@OL01@00AOM5mdGg00000dGg00@004GgAOL000A5m`050015mdGgAOL0
0003AOL01000BOM9m`000dWg00D004WgBOM9m`0000A9m`030019m`0000<00099mP050019mTWfBOH0
0003CQH00`00CQI>5P02CQH01000CQI>5ThF0`0000=>5P00CQH00ThF00<004hFCQH00ThF00D0058F
DQIB5P0000=B5P8000AB5P03001B5U8F009B5P04001B5U8FDQH20003DQH00`00DSIB=P02DSH01000
ESIF=UHf0P0015Hf00D005HfESIF=P00009F=P03001F=P0000AF=P04001F=UHfESH20004ESH00`00
FSIJ=P03FSH00`00FSIJ=P02FSH00`00FUIJEP02FUH00`00FUIJEP02FUH01000FUIJEUYF0P001EYF
00H005YFFUH005iF0005GUH20003GUH01000GUINEUiF0P001Eif00<005if00000eif00@005ifGWH0
009NMP03001RMV9f009RMP03001RMV9f00=RMP03001RMV9f00=RMP@0009RUP03001RUP00009RUP05
001RUV:FHYH00002HYH01000HYIRUP000VJF00L006JFIYIVUP00IYH00002IYH01000I[IV]P000VJf
00@006JfI[H0009V]P06001V]VJf001V]P000fJf00<006Jg000016Zg00<006[GJ]L00f[G00D006[G
J]MZe`00009Ze`04001Zef[G0003J]L02000J]MZef[G001Ze`00J]L20002J_L00`00J_L00004K_L0
1@00K_M^mfkg00000Vkg00<006kgK_L00Vkg00D006kg001^m`0000A_5`04001_5flG0003KaP00`00
KaQ_6002KaP01000KaP000000flh00D006lh001_>000009_>005001c>000LcP00002LcP01@00LcP0
07<h00000W=H00@007=HLeP000=cF004001cF7=H0002KeX01@00KeY_FP00Fa`00P0000=K7000D_d0
0e;m00<005;mD_d00`000e/M0P000goo00<007ooOol0Hgoo001LOol20008Ool2000;Ool00`00Oomo
o`0:Ool01000E_eFoEKm0`000eKm00<005KmE_d010000eKm00<005KmE_d00`000eKm00<005KmE_d0
0`0015Km00<005Km00000UKm00<005KmE_d00UKm00<005Km00000UKm00@005KmE_eFo@<000=Fo@03
001FoEKm00@000=Fo@03001FoEKm00<000=Fo@03001FoEKm00<000AFo@03001FoEKm00<000=Fo@06
001Fo@00001Fo@0015Km0`000U/M00D005:kD[]B^`00008inP04000afC7I0002?OT800000c6G000e
^002=KP01000>MPif0000cWH00<003WH00000SWH20000SgH00D003gH?MPmf000008mf005000mecgG
?ML00002@ML01@00@MM1ed7G00000T7G00D0047G@MM1e`0000=1e`040011ed7G0003@OL01@00AOM5
mdGg00000dGg00@004GgAOL000=5m`050015mdGgAOL00003AOL01000BOM9m`0014Wg00H004WgBOM9
m`00BOL40002BOH01@00BOI9mTWf000014Wf00D004hFCQI>5P0000=>5P03001>5ThF008000A>5P05
001>5ThFCQH00003CQH00`00DQIB5P02DQH300000e8F001B5P03DQH00`00DQIB5P02DQH01P00DQIB
5P00DQH000AB5P05001B=U8fDSH00002ESH00`00ESH00004ESH00`00ESIF=P02ESH20002ESH00`00
ESIF=P02ESH01P00ESIF=P00ESH000EF=P04001J=UXfFSH20004FSH01000FUIJEUYF0P0015YF00@0
05YFFUH0009JEP03001JEUYF009JEP03001JEP0000=NEP03001NEUiF009NEP03001NEUiF009NEP04
001NEUiF0002GUH00`00GWINMP02GWH20005GWH20003GWH01`00HWIRMV9f001RMP0000ARMP03001R
MV9f009RMP8000ERUP03001RUP0000=RUP04001RUV:F0002HYH01000HYIRUP000VJF00@006JFIYH0
009VUP04001VUVJF0002I[H01000I[IV]P000VJf00<006Jf000016Jf00<006JfI[H00fJf00<006Zg
J[L00fZg00<006[GJ]L00V[G00<006[G00000V[G00H006[GJ]L006[G0004J]L02000J]MZef[G001Z
e`00J]L20003J_L00`00K_M^m`02K_L01@00K_L006kg00000fkg00D006kgK_M^m`0000=^m`03001_
5flG009_5`04001_5`000004KaP01@00KaQ_66lH00000VlH00D006lhKcQ_>00000=_>004001_>6lh
0003LcP01000LcQc>0000g<h00@007=HLeP000=cF004001cF7=H0003LeP00`00KeX00003KeX20004
Fa`00`00D_eBo@040002D_d01P00Fad00000Ead000=oo`03001oogoo06=oo`00G7oo0P0027oo0P00
2goo00<007ooOol02goo00<005Km00000UKm00@005KmE_eFo@<000=Fo@03001FoEKm00@000=Fo@03
001FoEKm00<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00<000AFo@03001Fo@00009Fo@04001F
oEKmE_d30002E_d00`00E_eFo@02E_d30003E_d00`00E_eFo@030003E_d00`00E_eFo@040003E_d0
0`00E_eFo@030003E_d01P00E_d00000Ead000AK7@04001B^e:k0003>OX01P00<MTaf@00?OT000<m
n003000if3WH00@0008e^004000if3WH0003>MP01000>MPif0000SWH00@003WH>MP0008mf0D0008m
f004000mf3gH0003?ML01000@MM1e`000d7G00D0047G@MM1e`000091e`050011ed7G@ML00003@ML0
1000@OM1m`000dGg00D004GgAOM5m`000095m`050015mdGgAOL00003AOL01@00AOM5mdGg00000dWg
00<004Wg00001`000TWf00D004WfBOI9mP0000A9mP050019mTWfBOH00003CQH01000CQI>5ThF0`00
00=>5P00CQH00dhF00D004hFCQI>5P0000A>5P03001B5P00008000AB5P03001B5U8F009B5P07001B
5U8FDQH0058F00000U8F00<0058FDQH00U8F00<0058fDSH00U8f0P000UHf00<005HfESH00UHf00@0
05HfESIF=P8000AF=P03001F=UHf009F=P8000=F=P03001F=UHf009F=P06001J=UXf001J=P0015Xf
00H005YFFUH005YF0005FUH20003FUH00`00FUIJEP03FUH00`00GUINEP02GUH01000GUINEUiF0P00
1EiF0P000eiF00L005ifGWINMP00GWH00005GWH00`00GWINMP02GWH01000HWIRMP000V9f00H0069f
HWIRMP00HWH400000f9f001RUP05HYH00`00HYIRUP02HYH00`00HYH00004HYH20004IYH20003IYH0
0`00IYH00004I[H20004I[H00`00I[IV]P03I[H00`00I[IV]P03I[H00`00J[MZ]`02J[L00`00J[L0
0002J]L01P00J]MZe`00J]L000AZe`03001Zef[G009Ze`05001Ze`00J]L00003J]L01000J_MZm`00
0V[g00D006kgK_M^m`0000=^m`07001^mfkgK_L006kg00000Vkg00D006kgK_M^m`0000=_5`04001_
5flG0004KaP01@00KaP006lH00000flH0P0000=_>000KcP00flh00@006lhKcP000=c>003001c>000
00Ac>0800009LeP007=HLeP007=I001cF000009cF003001cF@0000=_FP04001[Nf]k0002Fa`40002
D]`00`00D_eBo@030004Ead01@00Oomoogoo0000I7oo001LOol20008Ool2000;Ool3000<Ool00`00
E_eFo@02E_d00`00E_d00002E_d01000E_eFoEKm0`000UKm00<005KmE_d00UKm0`000eKm00<005Km
E_d00`0015Km00<005KmE_d00`000eKm00<005KmE_d00`0015Km00<005Km00000UKm00H005KmE_eF
o@00E_d200000eKm001Fo@03E_d30002E_d01000E_eFoEKm0`000eKm00<005KmE_d010000eKm00<0
05KmE_d00`000eLM00<005/MFad02@000S7I00@003gi?OT000<mn003000if000008e^0<00004=KP0
03WH0003>MP01000>MPif0000cWH00<003WH00000cgH00<003gH?MP020000cgG00@0047G@ML00091
e`050011ed7G@ML00002@ML01@00@MM1ed7G00000d7G00@0047g@OL000=5m`050015mdGgAOL00002
AOL01@00AOM5mdGg000014Gg00H004GgAOM5m`00BOL30002BOL01@00BOM9mdWg00000dWf00<004Wf
BOH00TWf00D004WfBOI9mP0000=9mP06001>5ThFCQH004hF0P0000=>5P00CQH00ThF00D004hFCQI>
5P0000=>5P04001>5ThFCQH30002DQH00`00DQIB5P02DQH00`00DQIB5P02DQH01000DQIB5U8F0P00
158F00D0058FDQIB5P0000=B=P8000AF=P05001F=UHfESH00002ESH00`00ESH00004ESH01000ESIF
=UHf0P0015Hf00<005HfESH00UHf00<005Xf00000eXf00<005XfFSH00UXf0P000eYF00<005YFFUH0
0UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005iFGUH00UiF00H005iFGUH005iF0005GUH00`00
GUINEP02GUH01000GWINMP000eif00<005ifGWH00Uif00<005ifGWH00eif0P000f9f00<0069fHWH0
10000f9f00<0069f00001F:F00<006:FHYH00f:F00<006:FHYH00f:F00<006JFIYH00fJF00<006JF
IYH00fJF00<006JfI[H00fJf00<006JfI[H00fJf00<006JfI[H00VJf00<006Jf00000fJf00<006Zf
00000VZg00H006ZgJ[L006[G0004J]L00`00J]MZe`03J]L01@00J]MZef[G00000V[G00<006[G0000
0f[G00X006[gJ_L006[g001^m`00K_L000A^m`09001^mfkgK_L006kg001^m`0000=^m`03001_5`00
009_5`04001_5flG0003KaP01@00KaQ_66lH00000flH00@006lhKcP000A_>004001c>0000003LcP0
0`00LcP00004LcP01000LeQcF0000W=H00D007=ILeUcF@00009cF003001cFG=I00800003KeX006]k
009[N`<0009K7003001Bg5;L00@000=Bo@03001G7ELM00<000=oo`03001oogoo065oo`00G7oo0P00
27oo0P002Woo0P003goo00<005KmE_d00`0015Km00<005Km00000UKm00H005KmE_eFo@00E_d20002
E_d01000E_eFoEKm0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`000eKm00<005KmE_d0
0`0015Km00<005KmE_d00`000eKm00H005Km000005Km0004E_d00`00E_d00002E_d01000E_eFoEKm
0`000eKm00<005KmE_d010000eKm00<005LMEad00`000TJm00@003hk?S/0008ef@@0008mn@05000m
n3gh?OP00002>MP00`00=KP00002=MP50003>MP00`00>MP00003>MP01000>MPif0000cgH00<003gH
00000cgH00<003gG?ML02P0000E1e`00@MM1e`0000=1e`050011ed7G@ML00002@ML01@00@OM1md7g
00000dGg00D004GgAOM5m`000095m`060015mdGgAOL004Gg200000=5m`00BOL00TWg00D004WgBOM9
m`0000A9mP050019mTWfBOH00003BOH00`00BOI9mP02BOH00`00CQH000020003CQH01@00CQI>5ThF
000014hF00@004hFCQI>5P<00003CQH0058F00=B5P03001B5U8F009B5P06001B5U8FDQH0058F0P00
00=B5P00DQH00e8F00<0058FDQH00U8F0`0000=B5P00ESH00eHf00<005HfESH00UHf0P000UHf00<0
05HfESH00UHf00H005HfESH005Hf0005ESH01000ESIF=UHf0P0015Xf00<005XfFSH00UXf00<005YF
FUH00UYF00@005YFFUIJEP8000EJEP04001JEUYFFUH20005GUH20003GUH00`00GUINEP02GUH00`00
GUINEP03GUH20004GWH01000GWINMUif0P001Eif00<0069fHWH00f9f0`000V9f00@0069fHWH0009R
MP03001RUV:F009RUP03001RUP0000ARUP03001RUV:F00=RUP03001VUVJF00=VUP03001VUVJF00=V
UP03001V]VJf00=V]P03001V]VJf009V]P03001V]P00009V]P04001V]VJf0002I[H01P00J[IZ]P00
J[L000AZ]`03001Zef[G00=Ze`03001Zef[G009Ze`03001Ze`00009Ze`05001Zef[GJ]L00003J]L0
0`00J_L00002J_L01@00K_M^mfkg000016kg00D006kg001^m`0000=^m`05001^mfkgK_L00002KaL0
0`00KaL00002KaL00`00KaL00002KaP01@00KaQ_66lH00000VlH00D006lhKcQ_>00000=_>004001c
>7<h0003LcP01000LcQc>0000g<h00L007=HLeQcF000LeP00004LeT00`00LeP00002LeT01000LgUc
N@000f]k00<006^l00000e/L0`000U;l00<005;mD_d00U;m0`000UKm00D007ooOomoo`0006=oo`00
G7oo0P0027oo0P002goo00<007ooOol03Woo0P000eKm00<005KmE_d010000eKm00<005KmE_d00`00
15Km00<005Km00000UKm00H005KmE_eFo@00E_d200000eKm001Fo@03E_d30003E_d00`00E_eFo@03
0003E_d00`00E_eFo@040003E_d00`00E_eFo@030003E_d00`00E_eFo@030004E_d00`00E_d00002
E_d01000E_eFoEKm0`000UKm00<005KmE_d00UKm0`000eKm00@004JmA[d0008n>`04000efCGI0002
<KP30003?OP01000>MPif0000SFh00@003GH=MP0008ef0P0008if004000if3WH0003?MP01000?MPm
f0000cgH00<003gG00000cgG00@003gG?ML00091eb@00095m`050015mdGgAOL00003AOL01@00BOM9
mdWg00000dWg00D004WfBOI9mP0000=9mP030019mTWf0099mP030019mP0000<0009=mP03001>5ThF
009>5P04001>5ThF0004CQH00`00CQI>5P020004CQH01@00DQIB5U8F0000158F00@0058FDQIB5P80
00=B5P03001B5U8F009B5P04001B5U8FDQH20003DQH00`00ESIF=P02ESH01000ESIF=UHf0P0015Hf
00<005HfESH00UHf0P000eHf00<005HfESH00UHf00H005HfESH005Hf0004FSH01000FSIJ=UXf0P00
15YF00@005YFFUH0009JEP03001JEUYF009JEP04001JEUYF0002FUH00`00GUINEP02GUH00`00GUIN
EP02GUH01000GUINEUiF0P001EiF00<005ifGWH00eif00@005ifGWH0009NMP03001NMUif009NMP03
001RMV9f00@000ERMP8000ARMP04001RUV:F0002HYH01`00HYIRUV:F001RUP0000=RUP03001VUP00
00=VUP03001VUP0000=VUP03001VUP0000=V]P03001V]P00009V]P04001V]VJf0002I[H01P00I[IV
]P00I[H000AZ]P03001Z]fZg00=Z]`03001Zef[G009Ze`03001Ze`00009Ze`06001Zef[G001Ze`00
16[G00/006[GJ]MZe`00J_L006[g001^m`00009^m`05001^mfkgK_L00002K_L00`00K_L00003K_L0
1@00K_M^mfkg00000flG00T006lGKaM_5`00KaL006lH00000flH00D006lH001_6000009_>005001_
>000KcP00003LcP200002G<h001c>7<h001c>000LcP00003LeP00`00LeP00004LeT00`00LeT00002
LeT01000LgUcNG=i0P0000=[N`00Jk`00V^l0`0000=Fo000D_`00e;l00H005;m000005Km0003E_d2
0003Ool00`00Oomoo`1POol005eoo`8000Ioo`8000]oo`03001oogoo015oo`03001FoEKm00<000AF
o@03001FoEKm00<000=Fo@03001FoEKm00<000AFo@03001FoEKm00<000=Fo@06001Fo@00001Fo@00
15Km0`000UKm00@005KmE_eFo@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00<000=Fo@03001F
oEKm00<000AFo@03001Fo@00009Fo@06001FoEKmE_d005Km0P000U[l00<005KmE_d01@000Shk00L0
03GI=MTef@00<KP00002>OT3000013gh000if0000cFh00H003GH=MP003GH0003>MP00`00>MPif003
000013WH000if0000cgH00@003gH?MP000<mf004000mecgG0003?ML00`00?ML00003@ML01@00@MM1
ed7G00000T7G00D0047G@MM1e`0000=1e`040011ed7G0003@ML01@00AOM5mdGg00000TGg00D004Gg
AOM5m`0000=5m`050015mdGgAOL00003AOL01@00BOM9mdWg00000dWg00D004WfBOI9mP0000A9mP03
0019mP0000<00099mP05001=mTgfCOH00004CQH01@00CQI>5ThF00000dhF00D004hF001>5P0000A>
5P03001B5U8F009B5P06001B5U8FDQH0058F0P0000=B5P00DQH00e8F00D0058FDQIB5P00009B5P03
001B5P0000AB5P05001F=UHfESH00002ESH00`00ESH00004ESH00`00ESIF=P02ESH00`00ESIF=P02
ESH00`00ESIF=P02ESH00`00ESH00002ESH00`00FSIJ=P02FSH01P00FSIJ=P00FSH000EJEP8000=J
EP03001JEUYF009JEP03001JEP0000=JEP03001NEUiF009NEP03001NEUiF009NEP04001NEUiF0002
GUH00`00GUINEP02GUH00`00GWINMP04GWH20003GWH01000GWINMUif10000f9f00<0069fHWH00f9f
00<0069fHWH00f9f00<006:F00000f:F00@006:FHYH0009RUP04001RUV:F0002IYH01000IYIVUP00
0VJF00@006JFIYH0009VUP04001V]VJf0002I[H01000I[IV]P000VJf00<006Jf000016Jf00<006Zf
J[H00fZf00<006ZgJ[L00VZg00<006[F00000V[G00H006[GJ]L006[G0004J]L00`00J]MZe`02J]L0
1@00J]L006[G00000f[g00P006kgK_L006kg001^m`000Vkg00D006kgK_M^m`0000=^m`05001^m`00
K_L00004KaL01000KaM_5`000flG00D006lHKaQ_600000=_6004001_>6lh0003KcP01@00LcQc>7<h
00000W<h00D007<hLcQc>000009c>005001cF7=HLeP00002LeP01@00LeUcFG=I00000W=I0P0000Ec
F@00LgUcN@00009cVP04001[_6^lJk`20004E_`00`00D_aBo0030004E_d3000015Km001oogoo0P00
HWoo001MOol20006Ool2000;Ool00`00Oomoo`0BOol20002E_d00`00E_eFo@02E_d30003E_d00`00
E_eFo@030003E_d00`00E_eFo@040003E_d00`00E_eFo@030003E_d01P00E_d00000E_d000AFo@03
001Fo@00009Fo@04001FoEKmE_d30003E_d00`00E_eFo@040003E_d00`00E_eFo@030003E_d00`00
E_eFo@030004E_d00`00E_eFo@030003F_`30002C[/00`00=OTen@030003=MT01P00<KPa^000>OT0
008if0D0008e^004000ef3GH0002=MP01`00>MPif3WH000if000008if0D000<mf003000mf00000<m
f004000mecgG0003?ML01000?MLme`000d7G00@0047G@ML00091e`050011ed7G@ML00003@ML01000
@MM1e`000d7G00D004GgAOM5m`0000=5m`040015mdGg0004AOL01@00AOM5mdGg00000dGg00@004Wg
BOL000=9m`030019mTWf0099mP030019mP0000<00099mP050019mTWfBOH00004COH01@00CQI>5ThF
00000dhF00@004hFCQI>5P8000=>5P05001>5ThFCQH00004DQH01000DQIB5U8F0P000e8F00<0058F
DQH00U8F00<0058FDQH00U8F0P000U8F00<0058FDQH00U8F00<005HfESH00UHf0P000UHf00<005Hf
ESH00UHf00@005HfESIF=P8000AF=P03001F=UHf00=F=P03001F=UHf009F=P03001J=UXf009J=P80
00=J=P03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF009JEP04001NEUiF
GUH20005GUH20003GUH01`00GUINEUiF001NMP0000ENMP03001NMUif009NMP03001NMP0000800003
HWH0069f009RMP8000ERMP03001RMV9f00ARMP03001RUV:F00=RUP8000=RUP03001RUP0000=VUP03
001VUP0000=VUP03001VUP0000=VUP03001V]P0000=V]P03001V]P0000AV]P03001V]VJf00=V]P03
001Z]VZf009Z]P03001Z]P00009Z]`04001ZeV[F0002J]L01@00J]MZef[G00001F[G00D006[GJ]MZ
e`00009Ze`03001Ze`0000=Zm`05001^mfkgK_L00002K_L00`00K_L00004K_L01000K_M^m`000fkg
00<006lGKaL00VlG00D006lG001_5`0000=_5`05001_66lHKaP00003KaP01000KcQ_>0000flh00@0
07<hLcP000=c>004001c>7<h0003LcP200002G=H001cF7=H001cF@00LeT00002LeT01000LgUcN@00
0W=i00<007>JLiX00P0000=[_00000000U^N00<005KlE_`010000UKm00<005KmE_d00`0015Km0P00
0Woo00<007ooOol0Ggoo001NOol20004Ool2000<Ool00`00Oomoo`0COol01P00E_eFoEKm001Fo@80
0003E_d005Km00=Fo@<000=Fo@03001FoEKm00<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00<0
00=Fo@03001FoEKm00<000AFo@03001Fo@00009Fo@04001FoEKmE_d30002E_d00`00E_eFo@02E_d3
0003E_d00`00E_eFo@030003E_d00`00E_eFo@040003E_d01@00F_`005/M000014jk00@003Gi000Y
^@80008ef@04000a^36h0002>OT01000>MPif0000SWH1`000SGH00D003WH>MPif000008if004000i
f3WH0002>MP80003?MP00`00?ML00003?ML01000?MLme`000d7G00D0047G@MM1e`000091e`050011
ed7G@ML00003@ML01000@MM1e`000d7G00D004GgAOM5m`000095m`050015mdGgAOL00003AOL01@00
AOM5mdGg00000dGg00@004WgBOL000A9m`030019mP0000<00099mP050019mTWfBOH00004BOH01@00
COI=mTgf00000dhF00H004hFCQI>5P00CQH200000dhF001>5P02CQH00`00CQI>5P02CQH01P00DQIB
5U8F001B5P800003DQH0058F00=B5P05001B5U8FDQH00003DQH20004DQH01@00DQIB5U8F00000eHf
0P0015Hf00D005HfESIF=P00009F=P03001F=P0000EF=P04001F=UHfESH20004ESH01000FSIJ=UXf
0P0015Xf00@005YFFUIJEP8000EJEP04001JEUYFFUH20004FUH01000GUINEP000UiF00<005iFGUH0
0UiF00<005iFGUH00UiF00@005iFGUH0009NMP03001NMUif00=NMP04001NMUifGWH40003HWH01000
HWIRMP000V9f00L0069fHWIRMP00HWH00005HWH00`00HYIRUP03HYH00`00HYIRUP03HYH00`00IYIV
UP03IYH00`00IYIVUP03IYH00`00IYIVUP03IYH00`00I[IV]P03I[H00`00I[IV]P03I[H00`00I[IV
]P02I[H00`00J[H00002J[H01000J[IZ]P000VZg00H006[FJ]H006[G0004J]L00`00J]MZe`02J]L0
0`00J]L00002J]L01@00J]MZef[G00000f[g00<006kg00000Vkg0P000Vkg00<006kgK_L00Vkg00D0
06kg001^m`0000=^m`05001_5flGKaL00003KaL02@00KaM_5flG001_5`00KaP00003KaP01000KaP0
00000flh00D007<h001c>000009c>005001c>000LcP00002LcP01000LeQcF0000W=H00D007=ILeUc
F@00009cF@07001cNG=iLgT007=i00000W>J00<006oj00000P000U^N10000UKm00<005KmE_d01000
0eKm00<005KmE_d00`000goo00<007ooOol0GWoo001NOol8000<Ool00`00Oomoo`0DOol00`00E_eF
o@030003E_d01P00E_d00000E_d000AFo@<0009Fo@04001FoEKmE_d30003E_d00`00E_eFo@040003
E_d00`00E_eFo@030003E_d00`00E_eFo@030004E_d00`00E_d00002E_d01P00E_eFoEKm001Fo@80
0003E_d005Km00=Fo@<0009Fo@04001FoEKmE_d30003E_d00`00E_eFo@030003Fad01@00C[]>^djk
00000SGi00<002Vi00000P0000@ef@00<KP000<in@06000if3WH000if0000cGH00<003GH=MP00`00
0cWH00@003WH>MP000<if003000if00000<if003000mf3gH00P000<me`03000me`0000=1e`050011
ed7G@ML00002@ML01@00@MM1ed7G00000d7G00@0047G@ML000=1e`050015mdGgAOL00003AOL01000
AOM5m`000dGg00D004GgAOM5m`0000=5m`060019mdWgBOL004Wg10000TWf00D004WfBOI9mP0000A9
mP050019mTWfBOH00003COH00`00CQI>5P02CQH00`00CQH000020003CQH01@00CQI>5ThF000014hF
00@0058FDQIB5P8000=B5P03001B5U8F009B5P03001B5U8F009B5P<00003DQH0058F00=B5P05001B
5U8FDQH00002ESH00`00ESH00004ESH00`00ESIF=P02ESH20003ESH00`00ESIF=P02ESH01P00ESIF
=P00ESH000AF=P06001J=UXf001J=P0015Xf00H005YFFUH005YF0005FUH01P00FUIJEP00FUH000EJ
EP8000=NEP04001NEUiFGUH20005GUH20004GWH01000GWINMUif0P0000=NMP0000000Uif00<0069f
HWH00f9f0P000f9f00@0069fHWH0009RMP03001RMV9f009RMP03001RUP0000ARUP03001RUV:F00=R
UP03001VUVJF00=VUP03001VUVJF00=VUP03001VUVJF00=VUP03001V]VJf00=V]P03001V]VJf009V
]P03001V]P00009V]P04001Z]VZf0002J[H01P00J[IZ]P00J[L000AZeP03001Zef[G009Ze`03001Z
e`00009Ze`06001Zef[G001Ze`0016[G00@006[gJ_L0009^m`03001^m`00009^m`03001^m`0000=^
m`05001^mfkgK_L00003K_L01@00KaL006lG000016lG00@006lGKaL000=_5`05001_66lHKaP00002
KaP01@00KcQ_>6lh00000g<h00@007<hLcP000=c>004001c>7<h0003LeP200002G=H001cFG=I001c
F@00LeT00002LgT01@00LgT00000LiX00`000V?l0`000Tkm00@005KmE_eFo@<000=Fo@03001FoEKm
00@000=Fo@04001oogoo001POol0061oo`@000ioo`<001Eoo`8000=Fo@03001FoEKm00<000=Fo@06
001Fo@00001Fo@0015Km00<005Km00000UKm00@005KmE_eFo@<0009Fo@03001FoEKm009Fo@<000=F
o@03001FoEKm00<000=Fo@03001FoEKm00<000AFo@03001FoEKm00<000=Fo@06001Fo@00001Fo@00
15Km00<005Km00000UKm00@005KmE_eFo@<000=G7@05001K7E/MFad00002C[/01P00=OTen@00:KT0
008af@D0008in@04000if3WH0002>MP01`00=MPef3GH000ef000008ef0<00004>MP003WH0003>MP0
1000>MPif0000cWH00<003gH00000cgG00<003gG?ML020000d7G00@0047G@ML00091e`050011ed7G
@ML00003@ML01000@MM1e`000d7G00D004GgAOM5m`0000=5m`040015mdGg0004AOL01P00AOM5mdGg
0015m`L00099mP050019mTWfBOH00004BOH01@00BOI9mTWf00000dWf00<004gfCOH00Tgf00<004hF
00000`000ThF00<004hFCQH00ThF00D004hFCQI>5P0000=>5P06001B5P00001B5P00158F00D0058F
DQIB5P0000=B5P8000=B5P03001B5U8F009B5P03001B5U8F009B5P80009F=P03001F=UHf009F=P04
001F=UHfESH20004ESH00`00ESIF=P02ESH00`00ESH00003ESH00`00ESIF=P02ESH20002FSH00`00
FSIJ=P03FSH20003FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP02FUH00`00GUINEP02
GUH01P00GUINEP00GUH000ENEP03001NMUif00=NMP03001NMUif00@000ANMP03001RMV9f00=RMP03
001RMV9f009RMP04001RMV9f0003HWH01000HWIRMP000V:F00L006:FHYIRUP00HYH00003HYH00`00
HYH00003IYH00`00IYH00003IYH00`00IYH00003IYH00`00I[H00003I[H00`00I[H00002I[H01000
I[IV]P000VJf00H006ZfJ[H006Zf0004J[H00`00J]IZeP03J]H01@00J]MZef[G00000V[G00@006[G
J]L000=Ze`03001Zef[G009Ze`80009Zm`05001^mfkgK_L00003K_L200001Fkg001^mfkg00000fkg
00@006kgK_L000=_5`03001_5flG009_5`05001_5`00KaL00003KaL200000flH001_6002KaP01@00
KcQ_>6lh00000g<h00<007<h000017<h0P0000Ec>000LeQcF000009cF004001cFG=I0003LeT01000
LgUcN@000W=i00<007>J00000P0000ESo000001K?@0000A>o@<00003E_d005Km00=Fo@<0009Fo@03
001FoEKm009Fo@80009oo`03001oogoo05eoo`00LGoo0P0067oo00<005KmE_d010000eKm00<005Km
E_d00`000eKm00<005KmE_d00`0015Km00<005Km00000UKm00H005KmE_eFo@00E_d200000eKm001F
o@03E_d30003E_d00`00E_eFo@030003E_d00`00E_eFo@040003E_d00`00E_eFo@030003E_d00`00
E_eFo@030004E_d00`00E_d00003E_d00`00EaeG7@0;0002:KT01000<MTaf@000SGI1`000SWH00D0
03GH=MPef000008ef003000ef000008if0D0008if004000if3WH0003>MP01000?MPmf0000SgG00@0
03gG?ML000<me`03000mecgG00L00005@ML0047G@ML00003@ML01@00@MM1ed7G00000T7G00D0047G
@MM1e`0000=5m`040015mdGg0003AOL00`00AOL000070002AOL01000BOI9mP000dWf00<004WfBOH0
0TWf00D004WfBOI9mP0000=9mP050019mTWfBOH00003COH30002COH01@00CQI>5ThF000014hF00D0
04hFCQI>5P0000=>5P8000=B5P03001B5U8F009B5P05001B5U8FDQH00002DQH00`00DQH00004DQH0
1@00DQIB5U8F00000e8F0P0015Hf00D005HfESIF=P00009F=P03001F=P0000AF=P03001F=UHf009F
=P8000AF=P03001F=UHf009F=P03001J=UXf009J=P03001J=UXf009J=P03001JEUYF009JEP03001J
EUYF009JEP8000AJEP04001JEUYFFUH20005GUH20003GUH00`00GUINEP02GUH00`00GWINMP03GWH4
0002GWH01000GWINMUif0P001F9f00<0069fHWH00f9f0P00169f00@0069fHWH0009RUP04001RUV:F
0002HYH01000HYIRUP000V:F00@006JFIYH0009VUP04001VUVJF0002IYH01000IYIVUP000VJf00@0
06JfI[H0009V]P04001V]VJf0002I[H00`00I[H00004J[H00`00J[IZ]P03J[H00`00J]IZeP02J]H0
0`00J]H00002J]L01P00J]MZe`00J]L000AZe`05001Zef[GJ]L00002J]L20004K_L01000K_M^mfkg
0P0000A^m`00K_L000=^m`80009^m`05001_5flGKaL00003KaL01@00KaM_5flG00000flG00@006lH
KaP000=_6005001c>000KcP00003LcP00`00LcP00004LcP01000LcQc>0000W=H00L007=HLeQcF000
LeT00004LeT00`00LgT00002LgT00`00LiYcVP0200000gOI001K?@02Fcd60004E_d01P00E_d00000
E_d000AFo@06001Fo@00001Fo@000goo00<007ooOol0G7oo001aOol00`00Oomoo`0HOol20003E_d0
0`00E_eFo@040003E_d00`00E_eFo@030003E_d00`00E_eFo@030004E_d00`00E_eFo@030003E_d0
1P00E_d00000E_d000AFo@<0009Fo@04001FoEKmE_d30003E_d00`00E_eFo@040003E_d00`00E_eF
o@030003E_d00`00E_eFo@030004E_d30002E_d01000A[e6_@000Shj00<0036h<KP00P0000LY^@00
<MTaf@00=MT00003=MT00`00=MPef0030003=MP01000=MPef0000SGH00@003WH>MP0008if0<00004
>MP003WH0003>MP01000?MPmf0000cgG00@003gG?ML0008me`04000mecgG0003?ML00`00@MM1e`0P
0002AOL01@00AOM5mdGg00000dGg00D004WfBOI9mP0000=9mP050019mTWfBOH00003BOH01@00BOI9
mTWf000014Wf0`0000==mP00COH00Tgf00<004hFCQH00ThF00D004hFCQI>5P0000=>5P06001>5P00
001>5P00158F00D0058FDQIB5P0000AB5P80009B5P03001B5U8F009B5P03001B5U8F009B5P<00003
DQH005Hf00=F=P03001F=UHf009F=P80009F=P03001F=UHf009F=P03001F=UHf00800003ESH005Hf
00=F=P04001F=UHfESH20004FSH01000FSIJ=UXf0P0015YF00L005YFFUIJEP00FUH00004FUH01P00
FUIJEP00FUH000ENEP03001NEUiF009NEP07001NEUiFGUH005iF00000Uif100015if00@005ifGWH0
009NMP04001RMV9fHWH20005HWH00`00HWIRMP03HWH00`00HWH00004HYH20003HYH01000HYIRUP00
0V:F00@006JFIYH0009VUP04001VUVJF0002IYH01000IYIVUP000VJf00<006Jf00000fJf00<006Jf
000016Jf00<006ZfJ[H00fZf00<006ZfJ[H00VZf00<006Zf00000V[F00H006[FJ]H006[G0004J]L0
0`00J]MZe`02J]L00`00J]L00002J]L01000J]MZe`0016kg00<006kg00000Vkg00D006kg001^m`00
00=^m`03001^mfkg008000=_5`03001_5`00009_5`05001_5flGKaL00002KaL01@00KaQ_66lH0000
0VlH00D007<hLcQc>00000=c>004001c>7<h0003LcP01`00LcQc>7<h001cF00000=cF003001cF000
00AcF@06001cN@00001cN@000W>J0P000WOI00H005/m000005[l0004C]d00`00E_eFo@030004E_d0
0`00E_eFo@030004E_d01000Oomoo`00GWoo001aOol00`00Oomoo`0IOol01000E_eFoEKm0`000UKm
00<005KmE_d00UKm0`000eKm00<005KmE_d00`000eKm00<005KmE_d010000eKm00<005KmE_d00`00
0eKm00H005Km000005Km0004E_d00`00E_d00002E_d01000E_eFoEKm0`000eKm00<005KmE_d01000
0eKm00<005KmE_d00`000eKm00H005Km000005[l0004E_d01000A[e6_@000Shj00@0036h000]V080
008af@04000efCGI0003=MT00`00=MP00002=MP3000013GH000ef0000SGH00L003WH>MPif000>MP0
0002>MP50003>MP00`00?MP00003?ML01000?MLme`000cgG00@003gG?ML0008me`050011ed7G@ML0
0002@ML01@00@MM1ed7G00000d7G00@0047G@ML000=1e`050015edGGAML00003AML01000AOM5m`00
0dGg00D004GgAOM5m`0000A5m`040019mTWf0003BOH01@00BOI9mTWf00000dWf00<004WfBOH00TWf
00<004Wf00000P000dgf00<004gfCOH00Tgf00D004hFCQI>5P0000=>5P04001>5ThFCQH20003CQH0
0`00DQIB5P02DQH01@00DQIB5U8F00000e8F0P00158F00D0058FDQIB5P0000=B5P8000=B5P03001F
=UHf009F=P04001F=UHfESH20004ESH00`00ESIF=P02ESH20003ESH00`00ESIF=P02ESH01P00ESIF
=P00FSH000AJ=P06001J=UXf001J=P0015YF00@005YFFUH0009JEP03001JEUYF00=JEP8000=JEP03
001NEUiF009NEP03001NEUiF009NEP04001NEUiF0002GUH30003GWH00`00GWINMP03GWH20003GWH0
1000HWIRMP000V9f00<0069fHWH00V9f00<0069fHWH0169f00<006:FHYH00f:F00<006:FHYH00f:F
0P0016:F0P0016JF0P0016JF0P0016Jf00<006JfI[H00fJf00<006JfI[H00fJf00<006ZfJ[H00VZf
00<006Zf00000VZf00@006ZfJ[H0009ZeP05001ZeV[FJ]H00005J]L01@00J]MZef[G00000V[G00<0
06[G00000f[G00D006kgK_M^m`00009^m`03001^m`0000=^m`8000=^m`04001^mfkg0003KaL01P00
KaM_5`00KaL000=_5`04001_5`000003KaP01@00LaP006lH00000g<h0P0000Uc>000LcQc>000LcP0
07<h00000g<h00<007=H00000g=H00@007=HLeP000=cF@03001cN@00009cN@03001cVW>J0080009g
f@03001cF00000AJo003001>gDkM00@000=Fo@03001FoEKm00@0009Fo@03001FoEKm00<000=oo`03
001oogoo05]oo`00LGoo00<007ooOol06Woo00<005Km00000UKm00H005KmE_eFo@00E_d200000eKm
001Fo@03E_d30003E_d00`00E_eFo@030003E_d00`00E_eFo@040003E_d00`00E_eFo@030003E_d0
0`00E_eFo@030004E_d00`00E_d00002E_d01000E_eFoEKm0`000UKm00<005KmE_d00UKm0`000eKm
00<005KmE_d00`000e[l00<005KmE_d01@000Shj00@0036h<KP0008]V0<0008ef@05000efCGI=MT0
0002=MP00`00=MP00002=MP50002=MP01000>MPif0000SWH00@003WH>MP0008if0P0008me`04000m
ecgG0003?ML01000?MLme`000cgG00L0047G@MM1e`00@ML00003@ML01@00@MM1ed7G00000T7G00D0
047G@MM1e`0000=5e`050015edGGAML00002AOL00`00AOM5m`02AOL01@00AOM5mdGg00000dGg00D0
04WfBOI9mP000099mP050019mTWfBOH00004BOH00`00BOH000030002BOH00`00COI=mP02COH01@00
COI=mTgf00000dhF00<004hFCQH00ThF0`0000=>5P00CQH00dhF00D0058FDQIB5P0000AB5P<00003
DQH0058F00=B5P05001B5U8FDQH00002DQH00`00DQH00004DQH00`00ESIF=P02ESH300000eHf001F
=P03ESH01000ESIF=UHf0P001EHf00<005HfESH00UHf0P000eXf00<005XfFSH00UXf0P000eXf00<0
05YFFUH00UYF0P0015YF00<005YFFUH00UYF00<005YFFUH00UYF00@005iFGUINEP8000ENEPD00003
GUH005if009NMP8000ENMP03001NMUif009NMP04001RMV9f0002HWH01`00HWIRMV9f001RMP0000ER
MP03001RUV:F00=RUP03001RUV:F00=RUP03001RUV:F00=RUP03001VUVJF00=VUP03001VUVJF00=V
UP03001V]VJf00=V]P03001V]VJf00=V]P03001V]VJf009V]P03001V]P00009Z]P04001Z]VZf0002
J[H01P00J[IZ]P00J]H000AZeP03001Zef[G009Ze`03001Ze`00009Ze`05001Zef[GJ]L00003J]L0
0`00K_L00002K_L01@00K_M^mfkg000016kg00D006kg001^m`0000=^m`05001_5flGKaL00003KaL0
1@00KaM_5flG00000VlG00D006lHKaQ_600000=c6005001c>7<hLcP00002LcP01@00LcQc>7<h0000
0W<h00D007<hLcQc>000009cF080000;LeP007=HLeP007=I001cF@00LgT00003LgT01`00LiX007OI
001gf@00009cF003001Jo5[l009Jo0<000=>g@03001FoEKm00@0009Fo@03001FoEKm00@000=Fo@05
001oogooOol0001LOol0075oo`03001oogoo01]oo`03001FoEKm009Fo@03001FoEKm00<000=Fo@06
001Fo@00001Fo@0015Km0`000UKm00@005KmE_eFo@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm
00<000=Fo@03001FoEKm00<000AFo@03001Fo@00009Fo@06001FoEKmE_d005Km0P0000=Fo@00E_d0
0eKm0`000eKm00<005[lF_`00`000TjK00<0037I<MT00`000S6h00@002fH;IP0008a^@<000<ef@04
000ef3GH0002=MP01000=MPef0000SFh10000SWH00@003WH>MP000<if003000if00000<if003000i
f3WH00<00005?ML003gG?ML00002?ML01@00?MLmecgG00000SgG00D0047G@MM1e`000091e`050011
ed7G@ML00003@ML01000@MM1e`000d7G00D004GGAMM5e`0000=5e`040015mdGg0003AOL01@00AOM5
mdGg00000dGg00D004WfBOI9mP0000=9mP060019mTWfBOH004Wf10000TWf00D004WfBOI9mP0000A=
mP05001=mTgfCOH00004CQH00`00CQH000020003CQH00`00CQI>5P02CQH01@00DQIB5U8F00000e8F
0P000e8F00<0058FDQH00U8F00<0058FDQH00U8F0P000U8F00<0058FDQH00U8F00@005HfESIF=P80
00=F=P03001F=UHf009F=P06001F=UHf001F=P001EHf00@005HfESIF=P8000AJ=P03001J=UXf009J
=P03001J=UXf009J=P03001JEUYF009JEP03001JEUYF00=JEP04001JEUYFFUH20004FUH01000GUIN
EP000UiF00@005iFGUINEP<000ANEP04001NMUif0002GWH00`00GWINMP02GWH00`00GWINMP03GWH2
0003HWH01000HWIRMP000V9f00<0069fHWH00V9f00<0069f00000f:F00<006:F000016:F00<006:F
HYH00f:F00<006JFIYH00fJF00<006JFIYH00fJF00<006JfI[H00VJf00<006Jf00000fJf00<006Jf
00000VJf00@006JfI[H0009Z]P06001Z]VZf001Z]P0016Zf00<006[FJ]H00V[F00<006[F00000V[G
00H006[GJ]L006[G0004J]L02@00J]MZef[G001^m`00K_L00004K_L02@00K_M^mfkg001^m`00K_L0
0003K_L01@00KaL006lG000016lG00D006lGKaM_5`00009_5`05001_66lHKaP00003LaP01000LcQc
>0000g<h00@007<hLcP000=c>0800005LcP007=HLeP00002LeP01@00LeQcF7=H00000W=I00<007=i
00000g=i00<007=i00000P0000Qgf@00LeQcF000LcP005[l0P000U/L00<004kMC]d010000UKm00@0
05KmE_eFo@<000=Fo@03001FoEKm00<0009oo`03001oogoo05Yoo`00LGoo00<007ooOol077oo00<0
05KmE_d010000eKm00<005KmE_d00`000eKm00H005Km000005Km0004E_d00`00E_d00002E_d01000
E_eFoEKm0`000eKm00<005KmE_d010000eKm00<005KmE_d00`000eKm00<005KmE_d00`0015Km00<0
05KmE_d00`000eKm00H005Km000005Km0004E_d300000e/M001>V`03CY/00`00<MT00002:IT30003
;IP00`00<KT00002<MT3000013GI000ef0000SGH00L003GH=MPef000=KP00002=KP500000cWH000i
f002>MP01000>MPif0000SWH00@003WH>MP0008me`L00005?ML003gG?ML00002?ML01@00@MM1ed7G
00000T7G00D0047G@MM1e`0000=1e`040011ed7G0003@ML01@00AMM5edGG00000dGG00@004GgAOL0
00=5m`050015mdGgAOL00003AOL01@00BOI9mTWf00000TWf1`000TWf00D004WfBOI9mP0000A9mP05
001=mTgfCOH00003COH01000CQI>5ThF0`000ThF00<004hFCQH00ThF00D004hFCQI>5P0000AB5P<0
0003DQH0058F00=B5P05001B5U8FDQH00003DQH20004DQH01@00DQIB5U8F00000UHf00<005HF0000
15Hf00<005HfESH00UHf0P000eHf00<005HfESH00UHf00H005HfESH005Hf0004FSH01000FSIJ=UXf
0P0015Xf00@005YFFUIJEP8000EJEP06001JEUYF001JEP001EYF0P000eiF1P001EiF00<005if0000
0eif00@005ifGWINMP8000ENMP03001RMV9f00=RMP8000ARMP04001RMV9f0002HWH01000HYIRUP00
0V:F00L006:FHYIRUP00HYH00003HYH00`00IYH00003IYH00`00IYH00003IYH00`00IYH00002I[H0
1000I[IV]P000VJf00@006JfI[H0009V]P06001V]VJf001Z]P0016Zf00<006ZfJ[H00fZf00D006[F
J]IZeP00009ZeP04001Zef[G0003J]L00`00J]MZe`02J]L01@00J]L006[G00000fkg00<006kgK_L0
0Vkg00D006kg001^m`0000=^m`80009^m`05001_5flGKaL00004KaL01@00KaL006lG00000VlG00D0
06lG001_600000=c6004001c>0000003LcP01@00LcP007<h00000W<h00@007<hLcP0009cF005001c
F7=HLeP00002LeP01000LeUcFG=I0P000g=i00D007=iLgT007NI0080009cF005001c>7<hLcP00004
Fa`30002C]d00`00E_eFo@02E_d300000eKm001Fo@03E_d30002E_d01@00Oomoogoo0000Fgoo001a
Ool3000MOol20003E_d00`00E_eFo@040003E_d00`00E_eFo@030003E_d00`00E_eFo@030004E_d0
0`00E_d00002E_d01000E_eFoEKm0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`000eKm
00<005KmE_d010000eKm00<005KmE_d00`000eKm00H005Km000005LM0003Fad01@00CY]>VdjK0000
0S7I00@002VI000]^@80008]V006000a^C6i000af@000SGI1@0000<ef000=MP00SGH00@003Fh=KP0
008e^003000e^3Fh00@0008if004000if3WH0003>MP01000>MPif0000SgG00@003gG?ML0008me`T0
00=1e`030011e`0000=1e`050011ed7G@ML00002@ML01@00@MM1ed7G00000dGG00D004GGAMM5e`00
0095m`050015mdGgAOL00004AOL01P00AOM5mdGg0019mP@00003BOH004Wf0099mP050019mTWfBOH0
0004BOH01@00BOI9mTWf00000dgf00<004gfCOH00Tgf0`0000==mP00CQH00ThF00<004hFCQH00ThF
00D004hFCQI>5P0000=B5P8000=B5P03001B5U8F009B5P03001B5U8F009B5P<00003DQH0058F00=B
5P03001B5U8F009B5P80009F5P03001F=UHf009F=P04001F=UHfESH20004ESH00`00ESIF=P03ESH2
0002ESH00`00FSIJ=P02FSH01P00FSIJ=P00FSH000AJ=P04001JEUYF0002FUH00`00FUIJEP03FUH2
0003FUH00`00FUIJEP02FUH01000GUINEUiF0P000UiF00@005iFGUH000ENEP03001NMUif009NMP04
001NMUif0002GWH00`00GWINMP02GWH00`00HWIRMP03HWH00`00HWIRMP03HWH00`00HWH00003HWH0
1000HYIRUP000V:F00@006:FHYH0009RUP04001RUV:F0002IYH01000IYIVUP000VJF00@006JFIYH0
009VUP04001V]VJf0002I[H01000I[IV]P000VJf00<006Jf000016Jf00<006ZfJ[H00fZf00<006Zf
J[H00VZf00<006[F00000V[F00H006[FJ]H006[G0004J]L01@00J]MZef[G00000V[G00<006[G0000
0fkg00D006kgK_M^m`0000=^m`03001^mfkg009^m`05001^m`00K_L00003KaL01@00KaM_5flG0000
0flG00D006lGKaM_5`00009_5`05001c67<HLaP00002LcP01@00LcQc>7<h00000g<h00@007<hLcP0
00=c>0800009LeP007=HLeP007=H001cF000009cF@06001cN@00001cN@000W=i00@007NI001gV080
0003LeP007<h009c>0800005Fa`00000Fa`00004C]d00`00E_d000020004E_d01P00E_d00000E_d0
00=Fo@8000=oo`03001oogoo05Qoo`00LGoo00<007ooOol07Woo00@005KmE_eFo@<000=Fo@03001F
oEKm00@000=Fo@03001FoEKm00<000=Fo@03001FoEKm00<000AFo@03001Fo@00009Fo@06001FoEKm
E_d005Km0P0000=Fo@00E_d00eKm0`000eKm00<005KmE_d00`000eKm00<005KmE_d010000eKm00<0
05KmE_d00`000eLM00<005/MFad01@000S7I00D002VI:IT002fi00@0008a^@04000afC7I0002=MT0
0`00=MPef0040002=MP01000=KPe^0000cFh00<003Fh00000SVh0`0000@if000>MP000<if004000i
f3WH0003?ML01000?MLme`000SgG00D003gG?MLme`00008me`P000=1e`050011ed7G@ML00002@ML0
1@00@MM1ed7G00000dGG00D004GGAMM5e`000095m`060015mdGgAOL004Gg20000TWf00D004WfBOI9
mP000099mP030019mTWf0099mP050019mTWfBOH00003BOH00`00COI=mP02COH00`00COH000020003
COH00`00CQI>5P02CQH01@00CQI>5ThF000014hF0`0000=B5P00DQH00e8F00D0058FDQIB5P0000=B
5P8000=B5P03001B5U8F009B5P04001B5U8FDQH20004EQH01@00ESIF=UHf00000UHf00<005Hf0000
15Hf00<005HfESH00eHf00<005HfESH00UHf00<005XfFSH00UXf0P000eXf00<005XfFSH00UXf0P00
0eYF00<005YFFUH00eYF00<005YFFUH00UYF00@005YFFUIJEPD0009NEP8000=NEP03001NEUiF00=N
EP03001NMUif00=NMP8000=NMP07001NMUifGWH0069f0000169f00<0069fHWH0169f00<0069fHWH0
0f9f0P0016:F0P000f:F00@006:FHYH0009VUP04001VUVJF0002IYH01000IYIVUP000VJF00<006Jf
000016Jf0P0016Jf00<006JfI[H00fJf00<006ZfJ[H00VZf00<006Zf00000VZf00H006[FJ]H006[F
0004J]H00`00J]MZe`02J]L00`00J]L00002J]L01@00J]MZef[G00000fkg00<006kg00000Vkg00D0
06kgK_M^m`0000=^m`05001^m`00K_L00003KaL01@00KaL006lG000016lG00@006lGKaL000=_5`05
001c67<HLaP00002LcP01@00LcQc>7<h00000g<h00<007<h00000g<h00@007=HLeP0009cF005001c
F7=HLeP00002LeT00`00LgT00002LgT02000LgUcN@00MiT007NH0002MgL01@00LcQc>7<h00000W=I
00<005/LFa`00U/L00<004kM00000`000eKm00<005KmE_d00`0015Km0`0000=Fo@00Ool00Woo00<0
07ooOol0F7oo001`Ool00`00Oomoo`0POol00`00E_d00002E_d01000E_eFoEKm0`000eKm00<005Km
E_d010000eKm00<005KmE_d00`000eKm00<005KmE_d00`0015Km00<005KmE_d00`000eKm00H005Km
000005Km0004E_d30002E_d01000E_eFoEKm0`000eKm00<005KmE_d010000eKm00<005LMEad00`00
00A6_@00>S/j>`@0008YV@03000]^@00008a^@@0008af@07000efCGI=MT003GH00000SFh0`0000@e
f000=KP000<e^006000e^3Fh000i^0000SVh1@000SWH00@003WH>MP000<me`04000mecgG0003?ML0
1000?MLme`000SgG00D003gG?MLme`000091eb000095mP050015mTGfAOH00003BOH01@00BOI9mTWf
00000dWf00D004WfBOI9mP0000=9mP030019mTWf0099mP03001=mP0000<0009=mP03001=mTgf009=
mP05001>5ThFCQH00003CQH01000CQI>5ThF0P000e8F00<0058FDQH00U8F00D0058FDQIB5P00009B
5P03001B5P0000AB5P05001B5U8FDQH00002DQH00`00DQH00004EQH00`00ESIF=P02ESH20003ESH0
0`00ESIF=P02ESH01000ESIF=UHf0P0015Hf00<005XfFSH00UXf00<005XfFSH00UXf00<005XfFSH0
0UXf00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00<000ENEP03001NEUiF00=NEP04
001NEUiFGUH20005GWH00`00GWINMP02GWH01000GWINMP000V9f00L0069fHWIRMP00HWH00005HWH0
0`00HWIRMP03HWH00`00HYIRUP03HYH00`00HYIRUP03HYH20004IYH20004IYH20004IYH00`00I[IV
]P03I[H00`00I[IV]P03I[H00`00I[IV]P02I[H00`00J[H00002J[H01000J[IZ]P000VZf00D006[F
J]IZeP0000EZeP05001Zef[GJ]L00002J]L00`00J]L00004J]L02@00K_M^mfkg001^m`00K_L00003
K_L00`00K_L00002K_L00`00K_M^m`020003KaL01000KaM_5`0016lG00D006lG001_5`00009_5`05
001c5`00LaP00002LcP01@00LcP007<h00000g<h00<007<h00000g<h00D007=HLeQcF000009cF009
001cF7=HLeP007=I001cN@0000=cN@800006LgT007NI001gV0000WMg0P0000Ac>000LeUcF@80009K
70@000=>o@03001FoEKm00@0009Fo@03001FoEKm00<000AFo@05001oogooOol0001IOol0071oo`03
001oogoo025oo`8000=Fo@03001Fo@00009Fo@04001FoEKmE_d30002E_d00`00E_eFo@02E_d30003
E_d00`00E_eFo@030003E_d00`00E_eFo@040003E_d00`00E_eFo@030003E_d01P00E_d00000E_d0
00AFo@03001Fo@00009Fo@04001FoEKmE_d30003E_d00`00E_eFo@040002E_d01000A[e6_@000SXk
00<0036h<KP00`000Rfi00@0036i<KT0008a^@<000<ef@06000ef3GH000e^0000SFh1@000SFh00@0
03Fh=KP0008i^004000i^3Vh0002>MP300001CWH000if3WH00000SgG00D003gG?MLme`00008me`07
000mecgG?ML003gG00000cgG00@0047G@ML000=1e`050011ed7G@ML00002@ML01@00@MM1ed7G0000
0d7G00D004GGAMM5e`000095e`050015mdGgAOL00003AOH01@00AOI5mTGf000014Wf00@004WfBOH0
00=9mP050019mTWfBOH00004BOH00`00BOH000030002COH01@00COI=mTgf000014gf00D004hFCQI>
5P0000A>5P<00003CQH0058F00=B5P05001B5U8FDQH00004DQH20002DQH00`00DQIB5P02DQH00`00
DQIB5P02DQH20002DQH00`00EQIF5P02EQH01000ESIF=UHf0P0015Hf00<005HfESH00UHf00H005Hf
ESH005Hf0004ESH01000FSIJ=UXf0P0015Xf00@005XfFSIJ=P8000EJEP06001JEUYF001JEP0015YF
0`000eiF00<005iFGUH00UiF00<005iFGUH00eiF00@005iFGUH0009NEP03001NMUif009NMP03001N
MUif00=NMP8000=RMP04001RMV9f0002HWH00`00HWIRMP02HWH00`00HWH00004HWH00`00HYIRUP03
HYH00`00HYIRUP03HYH00`00IYIVUP03IYH00`00IYIVUP03IYH00`00IYIVUP03IYH00`00I[IV]P03
I[H00`00I[IV]P02I[H00`00I[H00002I[H01000J[IZ]P000VZf00H006ZfJ[H006Zf0004J]H00`00
J]IZeP02J]H00`00J]H00002J]L01@00J]MZef[G000016[G00D006kg001^m`0000=^m`05001^mfkg
K_L00002K_L00`00K_L00003K_L300000flG001_5`02KaL01@00KaM_5flG00000flG00@006lGKaL0
00=c5`04001c>7<h0003LcP01@00LcQc>7<h00000W<h0P0000=c>000LeP00W=H00@007=H000000=c
F006001cF000001cN@000W=i00P007MiMgT007NI001gV0000WMg00@007MGMeL0009cF@03001_FFmI
008000=K7003001>oDkm00@0009Fo@03001FoEKm00@000=Fo@03001FoEKm00<000=oo`03001oogoo
05Ioo`00L7oo00<007ooOol08goo00<005KmE_d00`000eKm00<005Km00000UKm00H005KmE_eFo@00
E_d200000eKm001Fo@03E_d30003E_d00`00E_eFo@030003E_d00`00E_eFo@040003E_d00`00E_eF
o@030003E_d00`00E_eFo@030004E_d00`00E_d00002E_d01000E_eFoEKm0`000e[l00<005KmE_d0
1@000SXk00<0036h00000RVH0P0000L]^@00<KTa^@00<KT00002<KT40002=MP01000=KPe^0000SFh
00<003Fh=KP00`0000@e^000=KP0008i^007000i^3Vh>KP003WH00000SWH1`0000Dme`00?MLme`00
008me`05000mecgG?ML00002?ML01@00?MLmecgG00000T7G00@0047G@ML000=1e`050011ed7G@ML0
0002@ML01@00@MM1ed7G00000dGG00D004GGAMM5e`000095m`030015mTGf0095mP050015mTGfAOH0
0003BOH01@00BOI9mTWf00000TWf00<004WfBOH00TWf00<004Wf00000`000TWf00D004gfCOI=mP00
00A=mP05001=mTgfCOH00004CQH00`00CQH000020003CQH00`00DQIB5P02DQH01@00DQIB5U8F0000
0e8F0P00158F00D0058FDQIB5P0000=B5P8000AB5P05001F5UHFEQH00002ESH00`00ESH00004ESH0
0`00ESIF=P02ESH00`00ESH00003ESH01@00ESIF=UHf00000UXf00<005Xf000015Xf00@005XfFSH0
009J=P03001JEUYF009JEP03001JEP0000=JEP@00003FUH005iF00=NEP07001NEUiFGUH005iF0000
15iF00<005iF00000eiF00@005ifGWINMP8000ENMP03001RMV9f00=RMP8000ARMP04001RMV9f0002
HWH01`00HWIRMV9f001RMP0000=RUP03001RUP0000ARUP03001VUVJF00=VUP03001VUVJF00=VUP03
001VUVJF009VUP03001V]P0000=V]P03001V]P00009V]P04001V]VJf0002I[H01P00J[IZ]P00J[H0
00AZ]P03001ZeV[F009ZeP03001ZeP00009ZeP06001ZeV[F001Ze`0016[G00D006[GJ]MZe`00009^
m`03001^m`0000=^m`05001^mfkgK_L00003K_L01P00K_M^mfkg001^m`800009KaL006lGKaL006lG
001_5`0000A_5`04001_5flG0003LaL200000g<h001c>002LcP200001G<h001c>7<h00000W<h00D0
07=HLeQcF000009cF005001cF7=HLeP00002LeP00`00LgP00002LgT01000MgUgNGMi0`0000AgV000
MgL000=gE`03001cF@0000=_F@03001K75/L009K70<0009Bo@04001FoEKmE_d30003E_d00`00E_eF
o@040003E_d01000Oomoo`00F7oo001`Ool00`00Oomoo`0TOol20003E_d00`00E_eFo@030003E_d0
0`00E_eFo@030003E_d01P00E_d00000E_d000AFo@<0009Fo@04001FoEKmE_d30003E_d00`00E_eF
o@040003E_d00`00E_eFo@030003E_d00`00E_eFo@030004E_d01@00E_d005Km000015[l0`0000A>
V`00<MXafP@0008a^004000YV000;KT20002<KT01P00<KTa^@00<KT0008a^0@0008e^007000e^3Fh
=KP003Fh00000SFh1@000SVh00@003Vh>KP0008if004000if3WH0002>ML00`00>MLie`050003?ML0
1000?MLme`000SgG00D003gG?MLme`000091e`050011ed7G@ML00003@ML01000@MM1e`000d7G00D0
047G@MM1e`0000=5e`040015edGG0003AOL01@00AOI5mTGf00000dGf00D004WfBOI9mP0000=9mP06
0019mTWfBOH004Wf10000TWf00D004WfBOI9mP0000A=mP05001=mTgfCOH00003COH01000CQI>5ThF
0`000ThF00<004hFCQH00ThF00D0058FDQIB5P0000AB5P<00003DQH0058F00=B5P05001B5U8FDQH0
0002DQH00`00DQH00004DQH00`00EQIF5P02EQH20003ESH00`00ESIF=P02ESH01000ESIF=UHf0P00
15Hf00<005HfESH00UHf0P000eXf00<005XfFSH00UXf0P000eXf00<005YFFUH00eYF00<005YFFUH0
0`000eYF0P0015iF00@005iFGUH0009NEP03001NEUiF00=NEP03001NEUiF009NEP04001NMUif0002
GWH00`00GWINMP02GWH00`00HWIRMP03HWH00`00HWIRMP03HWH00`00HWH00003HWH01000HWIRMP00
0V9f00@006:FHYH0009RUP07001RUV:FHYH006JF00000fJF00<006JF00000fJF00<006JF00000VJF
00@006JfI[H0009V]P04001V]VJf0002I[H01P00I[IV]P00I[H000AZ]P03001Z]VZf00=Z]P05001Z
eV[FJ]H00002J]H00`00J]H00004J]H00`00J]MZe`02J]L00`00J]L00002J]L01@00K_M^mfkg0000
0fkg00D006kg001^m`0000A^m`05001^mfkgK_L00002K_L20002KaL01@00KaM_5flG000016lG00@0
07<G000000=c5`04001c>7<h0003LcP01000LcQc>0000g<h00@007<hLcP000=cF003001cF7=H0080
0005LeP007=HLeP00002LgP00`00LgT00003MgT01@00MiT007NH00000WMg00H007MGMeL007Mh0003
KeT01000KeX005/L0P0000=K7000D_d00e;m0`0000=Fo@00E_d00eKm0`000UKm00<005KmE_d00UKm
0P000Woo00<007ooOol0EGoo001`Ool00`00Oomoo`0UOol00`00E_eFo@040003E_d00`00E_eFo@03
0003E_d00`00E_eFo@030003E_d01P00E_d00000E_d000AFo@03001Fo@00009Fo@04001FoEKmE_d3
0003E_d00`00E_eFo@040003E_d00`00E_eFo@030003E_d00`00E_eFo@030003E_d01P00F_`00000
Fad000=>V`06000afS7J000UV@000S6h00@002VH:IP0008]^@<0008a^@04000a^C6i0002<KP00`00
=KPe^00200001CFh000e^3Fh00000SFh00@003Fh=KP0008e^0@0008i^004000if3WH0003>MP01000
>MLie`000SWG00<003gG?ML01`0000@me`00?ML000<me`050011ed7G@ML00002@ML01@00@MM1ed7G
00000d7G00@0047G@ML000=1e`050015edGGAML00003AML01000AOM5m`000dGf00D004GfAOI5mP00
00=9mP050019mTWfBOH00002BOH30002BOH01@00BOI9mTWf000014Wf00D004gfCOI=mP0000==mP03
001=mTgf009=mP<00003COH004hF009>5P03001>5ThF009>5P05001B5U8FDQH00003DQH20003DQH0
0`00DQIB5P02DQH00`00DQIB5P02DQH20002DQH00`00DQIB5P02DQH01000EQIF5UHF0P0015Hf00<0
05HfESH00UHf00H005HfESH005Hf0004ESH01000ESIF=UHf0P0015Xf00<005XfFSH00UXf00<005Xf
FSH00eXf00@005YFFUIJEP@0009JEP06001JEUYF001JEP001EiF0P0015iF00@005iFGUINEP8000EN
EP8000=NMP07001NMUifGWH005if0000169f00<0069fHWH0169f00<0069fHWH00f9f0P000f9f00@0
06:FHYH0009RUP04001RUV:F0002IYH01000IYIVUP000VJF00@006JFIYH0009VUP04001VUVJF0002
I[H01000I[IV]P000VJf00<006Jf000016Jf00<006ZfJ[H00fZf00<006ZfJ[H00VZf00<006[F0000
0V[F00D006[FJ]IZeP0000EZeP05001Zef[GJ]L00002J]L00`00J]L00004K_L01@00K_M^mfkg0000
0Vkg00<006kgK_L00Vkg00D006kg001^m`0000A^m`04001_5flG0003KaL01@00KaM_5flG00000W<G
00D007<GLaMc5`0000=c>004001c>7<h0003LcP01000LcQc>0000W<h00D007=H001cF000009cF004
001cF7=H0002LeP01P00LgQcN000LgT000=gN@03001gV@00009gV003001gM`00009gE`03001gN7Mh
00800004KeT006mJKeX20004Fa`00`00D_eBo@020004E_d01P00E_d00000E_d000AFo@06001Fo@00
001Fo@000goo00<007ooOol0E7oo001`Ool00`00Oomoo`02000TOol20003E_d00`00E_eFo@040003
E_d00`00E_eFo@030003E_d00`00E_eFo@030003E_d00`00E_eFo@030004E_d00`00E_d00002E_d0
1000E_eFoEKm0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`000eKm00<005KmE_d00`00
0e/M00D004jKCY]>V`00008afP03000UV@000080008YV004000]^Bfi0002;KT30002<KT02000<KPa
^36h000e^000=KP20002=KP01000=KPe^0000cFh00<003Fh00000SFh1@000SWH00@003WH>MP0008i
e`04000iecWG0003?ML01000?MLme`000SgG1@000cgG00@0047G@ML00091e`050011ed7G@ML00003
@ML01000@MM1e`000d7G00D004GGAMM5e`0000=5e`040015mdGg0003AOH00`00AOI5mP02AOH01P00
BOI9mTWf0019mP@00003BOH004Wf0099mP030019mTWf0099mP050019mTWfBOH00003COH00`00COI=
mP02COH00`00COH000020003COH00`00CQI>5P02CQH01@00CQI>5ThF0000158F0`0000=B5P00DQH0
0e8F00D0058FDQIB5P0000=B5P8000AB5P05001B5U8FDQH00002EQH00`00EQH00004ESH00`00ESIF
=P02ESH00`00ESH00002ESH00`00ESIF=P02ESH01P00ESIF=P00ESH000AJ=P04001J=UXfFSH20005
FSH00`00FUH000030005FUH20003FUH00`00GUINEP02GUH00`00GUINEP03GUH01P00GUINEP00GUH0
00ENEP03001NMUif009NMP04001NMUif0002GWH01000HWIRMV9f0P001V9f00<0069fHWH00f9f00<0
069fHWH00f9f0P0016:F0P000fJF00<006JF00000fJF00<006JF00000fJF00<006JF000016Jf0P00
16Jf00<006JfI[H00fJf00<006ZfJ[H00VZf00<006Zf00000VZf00H006[FJ]H006[F0004J]H00`00
J]IZeP02J]H00`00J]H00002J]L01@00J]MZef[G000016kg00D006kg001^m`0000=^m`05001^mfkg
K_L00003K_L00`00K_M^m`02K_L01000KaL000000flG00D006lG001_5`0000=c5`800003LaL007<h
009c>005001c>000LcP00002LcP01`00LcP007<h001c>00000=cF004001cF7=H0003LeP2000017=H
001cN0000W=i0P0000AgN@00MiT0009gV003001gN00000=gE`03001gN000009gN004001_FVmJ0002
Kg/00`00FaaK70040002D]`00`00E_eFo@030004E_d00`00E_eFo@030004E_d01000Oomoo`00EWoo
001_Ool4000WOol01000E_eFoEKm0`000UKm00<005KmE_d00UKm0`000eKm00<005KmE_d00`000eKm
00<005KmE_d00`000eKm00<005KmE_d00`0015Km00<005Km00000UKm00H005KmE_eFo@00E_d20000
0eKm001Fo@03E_d30003E_d00`00E_eFo@030003Ead01000FaeK7@000djK00H0037J<MX002FI0002
;KT200001bVH000]^Bfi000]^@00008a^@800005<KT0036h<KP00002=KP00`00=KPe^00400000cFh
000e^002=KP01000=KPe^0000SFh00<003Fh=KP010000SWH00D003WG>MLie`00008ie`07000mecgG
?ML003gG00000cgG00<003gG?ML030000d7G00@0047G@ML000=1e`050011ed7G@ML00003AML01000
AMM5e`000dGg00H004GfAOI5mP00AOH80002BOH01000BOI9mP0014Wf00D004WfBOI9mP0000=9mP05
001=mTgfCOH00003COH30002COH00`00COI=mP02COH01@00CQI>5ThF00000dhF00@0058FDQIB5P80
00=B5P03001B5U8F009B5P03001B5U8F009B5P<00003DQH0058F00=B5P03001B5U8F009B5P8000=F
5P03001F=UHf009F=P04001F=UHfESH20004ESH00`00ESIF=P02ESH20002ESH00`00FSIJ=P02FSH0
1000FSIJ=P000UXf00<005XfFSH00UXf0`000eYF00<005YFFUH00UYF00<005YFFUH00UYF00@005iF
GUINEP8000ENEP03001NEP0000=NEP03001NEUiF009NEP03001NMUif00=NMP8000=NMP04001RMV9f
0002HWH00`00HWIRMP02HWH20005HWH00`00HWIRMP03HWH00`00HYIRUP03HYH00`00IYIVUP03IYH0
0`00IYIVUP03IYH00`00IYIVUP03IYH00`00I[IV]P03I[H00`00I[IV]P03I[H00`00I[IV]P02I[H0
0`00J[H00002J[H01000J[IZ]P000VZf00D006[FJ]IZeP0000AZeP03001ZeP00009ZeP06001ZeV[F
001Ze`0016[G00D006kgK_M^m`00009^m`03001^m`00009^m`03001^m`00009^m`05001^mfkgK_L0
0003K_L01000KaM_5`000flG00D006lGKaM_5`0000=c5`04001c5g<G0003LcP01@00LcQc>7<h0000
0W<h00D007<hLcQc>000009c>004001cF7=HLeP200001G=H001cF7=H00000W=H00H007=hLgP007=i
0002MgT2000017NI001gV0000WMh0P0000EgE`00MgQgN000009gN003001_FP0000=_N`<0009K7003
001Bg5;L00@000=Fo@03001FoEKm00@0009Fo@03001FoEKm00<000=oo`03001oogoo05=oo`00Kgoo
00<007ooOol0:Goo00<005Km00000UKm00H005KmE_eFo@00E_d200000eKm001Fo@03E_d30003E_d0
0`00E_eFo@030003E_d00`00E_eFo@030003E_d00`00E_eFo@030004E_d00`00E_eFo@030003E_d0
1P00E_d00000E_d000AFo@<0009Fo@03001G7ELM00`0008UV@04000]^@00;KT20002;KT01`00;KT]
^@00<KT0036h0080008a^004000e^3Fh0002=KP00`00=KPe^0040002=KP01000=KPe^0000cFh00<0
03Fh00000SVh1@000SWG00@003WG>ML000<me`04000mecgG0002?ML01000?MLme`000cgG00D003gG
?MLme`000091eb000095mP050015mTGfAOH00003BOH01@00BOI9mTWf00000dWf00D004WfBOI9mP00
00=9mP03001=mTgf009=mP<00003COH004gf009=mP03001=mTgf009=mP05001>5ThFCQH00004CQH3
00000dhF001B5P03DQH01@00DQIB5U8F00000e8F0P000e8F00<0058FDQH00U8F00@0058FDQIB5P80
00AF5P03001F=UHf009F=P06001F=UHf001F=P0015Hf00<005HfESH00UHf00<005HfESH00UHf00<0
05XfFSH00UXf0P000eXf00<005Xf00000P0000=J=P00FUH00eYF00<005YFFUH00UYF00<005YFFUH0
0UYF00H005iFGUH005iF0006GUH00`00GUINEP02GUH01000GUINEUiF0P001Eif00<005ifGWH00eif
0P000f9f00D0069fHWIRMP00009RMP07001RMV9fHWH0069f0000169f00<006:FHYH00f:F00<006JF
IYH00fJF00<006JFIYH00fJF00<006JFIYH00fJF00<006JfI[H00fJf00<006JfI[H00VJf00<006Jf
00000VJf00@006ZfJ[H0009Z]P06001Z]VZf001Z]P0016[F00<006[FJ]H00V[F00<006[F00000V[F
00D006[FJ]IZeP0000AZe`03001^e`00009^m`05001^mfkgK_L00003K_L01@00K_L006kg00000fkg
00<006kg00000Vkg00<006lGKaL00P000VlG00D006lGKaM_5`00009c5`05001c5g<GLaL00003LcP0
1@00LcQc>7<h00000W<h00L007<hLcQc>000LcP00003LeP01000LeQcF0000W=H00T007=HLeQcF000
LgP007=i00000gMi00<007Mi00000WNH00<007Mh00000WMh00@007MhMgP0009gN003001cN@0000=_
N`03001[_00000=K70<000=Bo003001FoEKm00@0009Fo@03001FoEKm00@000=Fo@05001oogooOol0
001DOol006moo`03001oogoo02Yoo`03001FoEKm009Fo@03001FoEKm00<000=Fo@06001Fo@00001F
o@0015Km0`0000=Fo@00E_d00eKm0`000eKm00<005KmE_d00`000eKm00<005KmE_d010000eKm00<0
05KmE_d00`000eKm00H005Km000005Km0003E_d30002E_d01@00A[e6_DJm00000Shk00<002fi;KT0
0`000Rfi00<002fi;KT00`000Rfi00@0036i<KT0008a^0@00003=KP003Fh008e^003000e^000008e
^0<00004=KP003Fh0003=KP01000=KPe^0000SVh00<003Vg>KL010000SWG00D003gG?MLme`00008m
e`05000mecgG?ML00002?ML01000?MLme`000cgG00@0047G@ML000=1e`050011ed7G@ML00002@ML0
1@00@MM1ed7G00000dGG00D004GGAMM5e`000095eP050015eTGFAMH00003AOH01@00AOI5mTGf0000
14Wf00@004WfBOH000=9mP050019mTWfBOH00004BOH00`00COH000020003COH00`00COI=mP02COH0
1@00COI=mTgf00000dhF00@004hFCQI>5P8000=>5P03001B5U8F009B5P03001B5U8F009B5P<00003
DQH0058F00=B5P05001B5U8FDQH00002DQH00`00DQH00004EQH00`00ESIF=P02ESH00`00ESH00002
ESH00`00ESIF=P02ESH01000ESIF=UHf0P0015Hf00@005XfFSIJ=P8000=J=P<000=J=P8000AJEP04
001JEUYFFUH20005FUH20003GUH00`00GUINEP02GUH20004GUH01000GUINEP000UiF00<005ifGWH0
0Uif00<005ifGWH00eif00<0069fHWH00V9f00@0069fHWH000=RMP04001RMV9f0002HWH01`00HWIR
MV9f001RUP0000=RUP03001RUP0000=VUP03001VUP0000=VUP03001VUP0000=VUP03001VUP0000=V
]P03001V]P00009V]P04001V]VJf0002I[H01P00J[IZ]P00J[H000AZ]P03001ZeV[F009ZeP03001Z
eP00009ZeP06001ZeV[F001ZeP0016[F00D006[GJ]MZe`00009^e`03001^m`0000A^m`04001^mfkg
0003K_L01@00K_M^mfkg00000Vkg00<006kg00000VlG00<006lG00000P000flG00D007<G001c5`00
009c5`05001c=`00LcP00003LcP01000LcP000000g<h00<007<h00000g=H00L007=HLeQcF000LeP0
0003LeP01P00LgP00000LgT0009gN@08001gNGMi001gV000MgP000=gN0800004MgP007Mh0002LgT2
00000fmk001[_002Jk`300000eKl001Bo003D_`30002E_d01000E_eFoEKm0`000eKm00<005KmE_d0
0`000Woo00<007ooOol0DWoo000BOol4000>Ool3000?Ool40009Ool<0009Ool6000AOol00`00Oomo
o`0[Ool00`00E_eFo@040003E_d00`00E_eFo@030003E_d01P00E_d00000E_d000=Fo@06001Fo@00
001Fo@0015Km0`000eKm00<005KmE_d00`000eKm00<005KmE_d010000eKm00<005KmE_d00P0015Km
00<005Km00000U[l00D005KmE_eFo@0000=6_@08000n>chk000]^@00:IP0008]^@04000]^Bfi0002
;KT30002<KT01000<KPa^0000S6h10000SFh00H003Fh=KP003Fh0002=KP50002=KP01000=KPe^000
0cVh00<003Vg00000SVg1@000cgG00<003gG00000cgG00@003gG?ML000<me`07000mecgG?ML0047G
00000d7G00D0047G@MM1e`000091e`050011ed7G@ML00003AML01@00AMM5edGG00000TGF00D004GF
AMI5eP0000A5mP050015mTGfAOH00003BOH01000BOI9mP000dWf00<004WfBOH00TWf00<004Wf0000
0`000Tgf00<004gfCOH00Tgf00D004gfCOI=mP0000==mP03001>5ThF009>5P<00003CQH004hF00=>
5P05001B5U8FDQH00003DQH20003DQH00`00DQIB5P02DQH00`00DQIB5P02DQH20002DQH00`00EQIF
5P03EQH01000ESIF=UHf0P0015Hf00D005HfESIF=P00009F=P03001F=P0000AF=P05001J=UXf001J
=P040002FSH01P00FSIJ=P00FSH000AJEP04001JEUYF0002FUH00`00FUIJEP02FUH00`00GUINEP02
GUH01`00GUINEUiF001NEP0000ENEP8000=NEP07001NMUifGWH005if000015if00<0069fHWH00f9f
0P00169f00@0069fHWH0009RMP04001RMV9f0002HYH01000HYIRUP000V:F00@006JFIYH0009VUP04
001VUVJF0002IYH01000IYIVUP000VJF00@006JfI[H0009V]P04001V]VJf0002I[H00`00I[H00004
J[H00`00J[IZ]P03J[H01@00J]IZeV[F00000V[F00<006[F000016[F00<006[FJ]H00V[F00<006[F
00000V[G00D006kGK]M^e`0000A^m`05001^m`00K_L00003K_L01@00K_M^mfkg00000fkg00D006lG
KaM_5`00009_5`05001_5flGKaL00003LaL01@00LaMc5g<G00000W<g00D007<hLcQc>000009c>005
001c>7<hLcP00002LcP200000g=H001cF002LeP00`00LeP00003LeP01P00LgQcN000MgP0009gN@05
001gNGMi001gN00200001GMh001gN7Mh00000WMh00<007Mh00000W=i00@007>jLkX0009[_0<000AF
o006001Bo000001Fo@0015Km0`0000=Fo@00E_d00eKm0`000UKm00D007ooOomoo`0005=oo`0047oo
20002goo1@0037oo20001goo30001goo2P003goo00<007ooOol0;7oo0P000eKm00<005KmE_d01000
0eKm00<005KmE_d00`000eKm00<005KmE_d00`000eKm00H005Km000005Km0004E_d30003E_d00`00
E_eFo@030003E_d00`00E_eFo@040002E_d00`00E_eFo@030004F_`00`00E_eFo@080002;KT00`00
:IP000020003;KT00`00;KT00002;KT30003<KP00`00<KP00002<KP40002=KP01000=KPe^0000SFh
00<003Fh=KP00`0000@e^000=KP000<i^004000i]cVg0002>KL00`00>KLi]`080002?ML01000?MLm
e`000cgG00D003gG?MLme`000091e`050011ed7G@ML00003@ML01000@MM1e`000d7G00D004GGAMM5
e`0000=5e`040015eTGF0003AMH01@00AOI5mTGf00000dGf00D004WfBOI9mP000099mP030019mTWf
0099mP030019mP0000<00099mP05001=mTgfCOH00004COH01@00COI=mTgf000014gf00<004hF0000
0P000dhF00<004hFCQH00ThF00D0058FDQIB5P00009B5P03001B5P0000AB5P05001B5U8FDQH00003
DQH20004DQH00`00EQIF5P02EQH01P00ESIF=P00ESH000AF=P03001F=UHf009F=P8000=F=P03001F
=UHf009F=PD000EJ=P03001J=P0000=J=P03001JEUYF009JEP8000=JEP03001JEUYF009JEP03001N
EUiF009NEP04001NEUiF0003GUH00`00GUINEP02GUH00`00GUINEP02GUH01000GWINMP000Uif00@0
05ifGWINMP8000ERMP03001RMV9f00ARMP8000ARMP8000=RUP04001RUV:F0002HYH01000IYIVUP00
0VJF00@006JFIYH0009VUP04001VUVJF0002IYH00`00I[H00003I[H00`00I[H00004I[H00`00J[IZ
]P03J[H00`00J[IZ]P02J[H00`00J[H00002J]H01P00J]IZeP00J]H000AZeP05001ZeV[FJ]H00002
J]H00`00J]L00004K]L01@00K_M^mfkg00000fkg00T006kgK_M^m`00K_L006kg000016kg00@006lG
KaL000=_5`80009_5`05001c5g<GLaL00002LaL01@00LcMc=g<g00000g<h00<007<hLcP00P0000Ec
>000LcQc>000009cF005001cF7=HLeP00002LeP200001G=H001cN7=h00000WMh00<007Mi00000WMi
00H007MhMgP007Mh0002MgP01000MgQgN7Mh0P000W=i00D007>jLkX006oi008000=KWP03001Fo5Kl
00<000AFo@03001Fo@00008000AFo@06001Fo@00001Fo@000eKm0P000goo00<007ooOol0D7oo000@
Ool20004Ool2000;Ool5000<Ool20004Ool20008Ool30006Ool20007Ool30005Ool3000>Ool00`00
Oomoo`0^Ool00`00E_eFo@030003E_d00`00E_eFo@040003E_d00`00E_eFo@030003E_d00`00E_eF
o@030003E_d01P00E_d00000E_d000AFo@<0009Fo@04001FoEKmE_d30003E_d00`00E_eFo@030003
E_d00`00F_aJo00400000djK000anP02<OX00`009KT00002;KT00`00:IP00002;KT2000022fi000]
^Bfi000]^@00;KT20002<KP01P00<KPa^000<KP0008a^0@0008e^007000e^3Fh=KP003Fh00000SFh
1@000SVh00@003Vg>KL000<i]`03000i]`0000<i]`03000m]cfg00<00005?ML003gG?ML00002?ML0
1@00?MLmecgG00000T7G00D0047G@MM1e`0000=1e`040011ed7G0003@ML01@00AMM5edGG00000dGG
00@004GFAMH000=5eP050015mTGfAOH00003AOH01@00BOI9mTWf00000dWf00<004Wf00000`000TWf
00D004WfBOI9mP0000A=mP05001=mTgfCOH00003COH01000COI=mTgf0`000Tgf00<004hFCQH00ThF
00D004hFCQI>5P0000AB5P80009B5P03001B5U8F009B5P05001B5U8FDQH00002DQH00`00DQH00004
DQH00`00EQIF5P02EQH00`00ESH00002ESH00`00ESIF=P02ESH01000ESIF=UHf0P0015Hf00@005Hf
ESIF=P<000=J=P03001J=UXf009J=P8000AJ=P03001JEUYF009JEP03001JEUYF009JEP04001JEUYF
FUH20005GUH20004GUH00`00GUINEP02GUH00`00GUINEP03GUH20003GWH01000GWINMP000V9f00<0
069fHWH00V9f00<0069fHWH0169f00<0069fHWH00f9f00<006:FHYH00f:F0P0016:F0P0016JF0P00
16JF0P0016JF00<006JfI[H00fJf00<006JfI[H00fJf00<006ZfJ[H00VZf00<006Zf00000fZf00D0
06Zf001ZeP0000AZeP03001ZeV[F009ZeP03001ZeP00009ZeP05001ZeV[FJ]H00004K]L00`00K_L0
0002K_L01@00K_M^mfkg00000Vkg00D006kgK_M^m`0000A^m`05001_5`00KaL00002KaL00`00LaL0
00020003LaL01@00LaL007<G00000W<g00D007<g001c>000009c>004001c>7<h0002LcP01000LeQc
F7=H0P0000EcF000LeQcF000009cF004001cN7=h0002MgP01P00MgP00000MgT0009gN006001gN7Mh
001gN0000gMh00`007Mi000007=i001c^P00KoT006?l0002Fih40002E_d00`00E_eFo@040003E_d0
0`00E_eFo@030004E_d3000015Km001oogoo0P00DWoo000?Ool20006Ool2000:Ool5000;Ool20006
Ool20008Ool3000GOol2000=Ool00`00Oomoo`0`Ool20002E_d01000E_eFoEKm0`000eKm00<005Km
E_d010000eKm00<005KmE_d00`000eKm00<005KmE_d00`000eKm00H005Km000005Km0004E_d00`00
E_d00002E_d01000E_eFoEKm0`000eKm00<005KmE_d00`000U[l00D004jKCY]>V`0000<anP03000U
^@000080008YV004000]^@00;KT20002;KT01@00;KT]^@00;KT010000S6h00@0036h<KP0008a^003
000a^36h00800005=KP003Fh=KP00002=KP01000=KPe^0000SFh0`0000@i^000>KL000<i]`04000i
]cVg0002>KL01000?KLm]`000SgG1`0000<me`00?ML00SgG00<0047G00000d7G00D0047G@MM1e`00
0091e`050011ed7G@ML00003AML01@00AMM5edGG00000TGF00D004GFAMI5eP0000=5mP030015mTGf
0095mP060019mTWfBOH004Wf0`000TWf00D004WfBOI9mP0000A9mP05001=mTgfCOH00003COH00`00
COI=mP02COH300000dgf001=mP02COH00`00CQI>5P02CQH01@00CQI>5ThF00000e8F0P00158F00D0
058FDQIB5P0000AB5P80009B5P03001B5U8F009B5P03001F5UHF009F5P8000AF=P05001F=UHfESH0
0002ESH00`00ESH00004ESH60004FSH01`00FSIJ=UXf001J=P0000AJ=P04001JEUYFFUH20004FUH0
1000FUIJEP000UiF00<005iFGUH00UiF00<005iFGUH00eiF00@005iFGUINEP8000ENEP03001NMUif
00=NMP8000=RMP07001RMV9fHWH0069f00001F9f00<0069fHWH00f9f00<006:FHYH00f:F00<006:F
HYH00f:F00<006JFIYH00fJF00<006JFIYH00fJF00<006JFIYH00fJF00<006JfI[H00fJf00<006Jf
I[H00VJf00<006Zf00000fZf00H006ZfJ[H006Zf0003J[H00`00J]IZeP03J]H01@00J]IZeV[F0000
0V[F00<006[F000016[F00D006kGK]M^e`00009^m`03001^m`0000=^m`80009^m`05001^mfkgK_L0
0003K_L01@00KaM_5flG00000flG00<007<GLaL00P000W<G00D007<GLaMc5`00009c=`05001c=g<g
LcL00002LcP01000LcQc>7<h0P0000Ec>000LeQcF000009cF004001cF7=H0003LeP2000017=h001g
N0000WMh00<007Mh00000WMh00H007MhMgP007Mh0003MgP00`00MgT00002MiT01@00LkX006oi0000
0V?l0`000Tkm00<005KmE_d010000eKm00<005KmE_d010000UKm00<005KmE_d00`0015Km0P000Woo
00<007ooOol0Cgoo000?Ool20006Ool2000;Ool3000<Ool20006Ool20009Ool3000GOol2000<Ool0
1000Ool00000;goo00<005KmE_d00UKm00<005Km00000UKm00@005KmE_eFo@<000=Fo@03001FoEKm
00@0009Fo@03001FoEKm00@000=Fo@03001FoEKm00<000=Fo@03001FoEKm00<000AFo@05001Fo@00
E_d00004E_d30002Ead01@00F_aJo5[l00000djK00H0037j<OX002Fi0002;KT30002;KT00`00;KT]
^@030002;KT00`00;KT00002;KP40002<KP02000<KPa^36h000a^000<KP20002=KP01000=KPe^000
0cFh00<003Fh00000SFh1@000SVg00@003Vg>KL000<i]`03000m]`0000<me`04000mecgG0002?ML9
0003@ML01`00@MM1ed7G0011e`0000=1e`050015edGGAML00003AML01@00AMI5eTGF00000dGF00H0
04GfAOI5mP00AOH800000dWf0019mP02BOH00`00BOI9mP02BOH01@00BOI9mTWf00000dgf00<004gf
COH00Tgf00<004gf00000P000dgf00<004gfCOH00Tgf00D004hFCQI>5P0000A>5P<00003DQH0058F
00=B5P05001B5U8FDQH00003DQH20004DQH01@00DQIB5U8F00000UHF0P0000=F5P00ESH00eHf00<0
05HfESH00UHf0P000UHf00<005HfESH00`000UHf00<005Xf000015Xf00@005XfFSH0009J=P03001J
=UXf009J=P06001JEUYF001JEP001EYF0P000eiF00<005iFGUH00UiF00<005iFGUH00eiF00@005iF
GUH0009NEP03001NEUiF009NEP03001NMUif00=NMP03001RMV9f009RMP04001RMV9f0002HWH00`00
HWIRMP02HWH00`00HWH00003HWH20005HYH00`00HYIRUP03HYH00`00IYIVUP03IYH00`00IYIVUP03
IYH00`00IYIVUP02IYH00`00IYH00003I[H00`00I[H00003I[H01P00J[IZ]P00J[H000=Z]P03001Z
]P0000=Z]P03001ZeV[F009ZeP03001ZeP00009ZeP05001ZeV[FJ]H00004J]H00`00K]H00002K]L0
1@00K_M^mfkg00000fkg00<006kgK_L00P000fkg00<006kg00000Vkg00D006lGKaM_5`00009_5`04
001c5g<GLaL20002LaL01@00LaMc5g<G00000W<g00@007<gLcMc=`800005LcP007<hLcP00002LcP0
1@00LeQcF7=H00000W=H0P0000EcF000LeQcF000009gN003001gN000009gN003001gN7Mh00800004
MgP007Mh0002MgP2000017Mh001gN@000gNI100000ESo000001K?@00009>o@@000=Fo@03001FoEKm
00@0009Fo@03001FoEKm00@000=Fo@03001FoEKm00<0009oo`03001oogoo04moo`003Woo0P0027oo
0P0067oo0P0027oo0P002Goo0`005Woo0P0037oo0P00<Woo00<005KmE_d00`0015Km00<005Km0000
0UKm00@005KmE_eFo@<0009Fo@04001FoEKmE_d30003E_d00`00E_eFo@040003E_d00`00E_eFo@03
0003E_d00`00E_eFo@030003E_d01P00E_d00000E_d000AG7@03001Jo5[l00P0008U^@05000]^@00
:KT00003;KT00`00;KT00002;KT30002;KT01000;KP]^0000S6h0`000c6h00@0036h<KP0008a^0@0
0003=KP003Fh008e^004000e^3Fh0002=KP00`00>KLi]`03000013Vg000i]`000cVg00@003fg?KL0
00<me`04000mecgG0002?ML01@00?MLmecgG00000SgG30000d7G00D004GGAMM5e`0000=5e`030015
eP0000X00095mP050019mTWfBOH00003BOH01@00BOI9mTWf00000dWf00D004WfBOI9mP0000==mP04
001=mTgfCOH30002COH00`00COI=mP02COH01@00COI=mTgf00000dhF00@004hFCQI>5P8000=B5P03
001B5U8F009B5P03001B5U8F009B5P<00003DQH0058F00=B5P03001B5U8F009B5P8000=F5P03001F
=UHf009F=P04001F=UHfESH20003ESH30003ESH20003FSH00`00FSIJ=P02FSH20004FSH00`00FSIJ
=P02FSH20003FUH00`00FUIJEP02FUH00`00GUINEP02GUH01`00GUINEUiF001NEP0000ENEP8000=N
EP04001NEUiFGUH20005GWH00`00HWIRMP03HWH20004HWH01000HWIRMP000V9f00@0069fHWH0009R
MP07001RUV:FHYH006:F00000f:F00<006JF00000fJF00<006JF00000fJF00<006JF00000VJF00@0
06JFIYH000=V]P06001V]VJf001V]P000fZf00<006Zf000016Zf00L006ZfJ[IZ]P00J]H00003J]H0
1@00J]H006[F000016[F00D006[FJ]IZeP00009^eP03001^e`0000A^m`05001^mfkgK_L00002K_L0
1@00K_M^mfkg00000Vkg00<006kg00000flG00D006lG001_5`00009c5`03001c5`00008000=c5`04
001c=`000003LcL01000LcQc>0000W<h00D007<hLcQc>000009cF004001cF7=H0002LeP01000LeQc
F0000gMh0P000WMh00@007MhMgP0009gN006001gN7Mh001gN0000WMi0P0000QgN@00MiUgV@00MkT0
07?i0P000e/m0`000TkM00<005KmE_d00UKm0`000UKm00@005KmE_eFo@<000=Fo@03001FoEKm00@0
009Fo@05001oogooOol0001@Ool000ioo`8000Qoo`8001Qoo`8000Qoo`8000Yoo`<001Eoo`8000ao
o`03001oogoo039oo`8000=Fo@03001FoEKm00<000AFo@03001Fo@00009Fo@07001FoEKmE_d005Km
00000UKm00@005KmE_eFo@<000=Fo@03001FoEKm00@000=Fo@03001FoEKm00<000=Fo@03001FoEKm
00<000=Fo@03001G7ELM00@0009:g@040012Fd9K0002;MT30002;KT00`00:KT000030002;KT00`00
;KT00002;KT2000022fi000]^2fh000a^000<KP20002<KP01000<KPa^0000S6h00<003Fh=KP01000
0SFh00@003Fh=KP000<e^003000i]`00008i]`D0008i]`04000m]cfg0003?ML01000?MLme`000SgG
00D003gG?MLme`00008me`050011ed7G@ML00003@ML00`00@MM1e`0>00000dGF0015eP02AMH01@00
AMI5eTGF00000dGf00D004WfBOI9mP0000=9mP050019mTWfBOH00003BOH01@00BOI9mTWf000014gf
0`0000==mP00COH00Tgf00<004gfCOH00Tgf00D004gfCOI=mP0000A>5P<00003CQH0058F00=B5P05
001B5U8FDQH00003DQH20003DQH00`00DQIB5P02DQH01000DQIB5U8F0P001EHF00D005HfESIF=P00
009F=P04001F=P00ESH200000eHf001F=P02ESH20004FSH00`00FSIJ=P02FSH00`00FSIJ=P03FSH0
0`00FSIJ=P02FSH00`00FUIJEP02FUH01000FUIJEUYF0P0015iF00@005iFGUH0009NEP03001NEUiF
00=NEP03001NEUiF009NEP04001NEUiF0002GUH01000GWINMUif0P001F9f00<0069fHWH00f9f00<0
069f00000f9f00@0069fHWH0009RMP04001RUV:F0002HYH01000HYIRUP000VJF00@006JFIYH0009V
UP04001VUVJF0002IYH01000IYIVUP000fJF00<006Jf00000fJf00<006Jf000016Zf00<006ZfJ[H0
0fZf00D006ZfJ[IZ]P00009ZeP03001ZeP0000=ZeP03001ZeV[F009ZeP03001ZeP00009ZeP05001^
eVkFK]H00004K_L01@00K_L006kg00000fkg00D006kgK_M^m`0000=^m`05001_5flGKaL00003KaL0
1000LaMc5`000g<G0P000W<G00@007<gLcL000=c=`05001c>7<hLcP00002LcP02P00LcQc>000LeP0
07=H001cF0000g=H00<007=H00000gMh00P007Mh000007Mh001gN0000gMh00D007Mh001gN00000=g
N@03001gV@00009gV@06001g^@00LoT007OI0P0000AK?@00F_`000A>g@06001Fo@00001Fo@0015Km
0`0000=Fo@00E_d00eKm0`000UKm00<005KmE_d00`000goo00<007ooOol0CGoo000>Ool20008Ool2
000HOol20008Ool2000;Ool3000DOol2000<Ool00`00Oomoo`0dOol00`00E_eFo@030003E_d00`00
E_eFo@030004E_d00`00E_eFo@030003E_d00`00E_d00002E_d01000E_eFoEKm0`000eKm00<005Km
E_d010000eKm00<005KmE_d00`000eKm00<005KmE_d00`000e<M00D004[MB]e:g@000092F`05000]
f@009IT00002;KT00`00:KT00002:KT40002;KT01000;KT002fi0P000Rfh00D0036h<KP0036h00<0
0004<KP0036h0003<KP00`00=KP00002=KP3000013Fh000e^0000cFh00@003Vg>KL0008i]`03000i
]cVg00<00004>KL003fg0003?ML01@00?MLmecgG00000SgG00L003gG?MLme`00?ML00003@ML01@00
@MM1ed7G00000T7G00D0047G@MM1e`0000=1eP050015eTGFAMH00002AMH01@00AMI5eTGF00000dGF
00<004GfAOH00TGf00D004WfBOI9mP000099mP050019mTWfBOH00003BOH00`00BOI9mP02BOH00`00
COH000020003COH00`00COI=mP02COH01@00COI=mTgf00000dgf00@004hFCQI>5P8000=>5P03001B
5U8F009B5P05001B5U8FDQH00002DQH00`00DQH00004DQH01@00DQIB5U8F00000U8F00<005HF0000
1EHF00<005HfESH00UHf0P0000AF=P00000000=F=P06001F=UHf001F=P0015Xf00@005XfFSIJ=P80
00EJ=P04001J=UXfFSH20004FUH01P00FUIJEP00FUH000ENEP8000ANEP04001NEUiFGUH20005GUH2
0003GUH01000GWINMP000Uif00<0069fHWH00V9f00<0069fHWH0169f00<0069fHWH00f9f0P000f9f
00@006:FHYH0009RUP04001RUV:F0002IYH01000IYIVUP000VJF00@006JFIYH0009VUP03001VUP00
00AVUP03001V]P0000AV]P03001Z]VZf00=Z]P03001Z]VZf009Z]P05001Z]P00J[H00003J]H00`00
J]H00003J]H01@00J]IZeV[F00000V[F00<006[F000016kF00D006kgK_M^m`0000=^m`09001^mfkg
K_L006kg001^m`0000A^m`05001_5flGKaL00003KaL01000LaMc5`000g<G00D007<G001c5`00009c
=`800003LcL007<h009c>004001c>0000002LcP01@00LeQcF7=H00000W=H00H007=HLeP007MH0003
MgP00`00MgP00002MgP01000MgQgN0000WMh00H007Mh000007Mh0002MgT03000MiUgV@00MiT007Ni
001cn@00MmT0009cN005001Jo5[lF_`00002C]d30004E_d00`00E_eFo@020004E_d01P00E_d00000
E_d000=Fo@<000=Fo@04001oogoo001?Ool000ioo`8000Qoo`8001Qoo`8000Qoo`8000aoo`<001=o
o`8000aoo`03001oogoo03Eoo`8000=Fo@03001FoEKm00<000=Fo@03001FoEKm00@000=Fo@03001F
oEKm008000AFo@03001Fo@00009Fo@04001FoEKmE_d30002E_d00`00E_eFo@02E_d30002E_d00`00
E_eFo@040003E_`00`00DaeC7@080002;MT00`009IT000020002:KT01P00:KTY^@00:KT0008]^@04
000]^Bfi0002;KT30002<KP00`00<KP00002<KP50002<KP01P00=KPe^000=KP0008e^0D0008e^004
000i]cVg0002>KL01000>KLi]`000SVg1@000cgG00@003gG?ML0008me`05000mecgG?ML00002?ML0
1@00@MM1ed7G00000d7G00<0047G00000d7G00D0047F@MI1eP0000=5eP050015eTGFAMH00003AMH0
1@00AMI5eTGF00000dGf00D004WfBOI9mP0000=9mP040019mTWf0004BOH00`00BOH000030002BOH0
0`00COI=mP02COH01@00COI=mTgf00000dgf00<004gfCOH00Tgf0`0000=>5P00CQH00dhF00D0058F
DQIB5P0000AB5P80009B5P03001B5U8F009B5P03001B5U8F009B5P8000=F5P03001F5UHF009F5P04
001F=UHfESH40002ESH00`00ESIF=P02ESH20002ESH00`00FSIJ=P02FSH01000FSIJ=P000UXe00<0
05XfFSH00UXf00H005XfFSH005Xe0005FUH20003FUH00`00GUINEP02GUH00`00GUINEP03GUH01P00
GUINEP00GUH000ENEP03001NEUiF009NEP04001NMUif0002GWH01`00HWIRMV9f001RMP0000ERMP03
001RMV9f00=RMP03001RMV9f00=RMP8000ARUP8000AVUP8000AVUP8000AVUP03001VUVJF00AVUP03
001V]VJf00=V]P03001Z]VZf009Z]P03001Z]P00009Z]P06001Z]VZf001Z]P0016[F00L006[FJ]IZ
eP00J]H00002J]H01@00J]IZeV[F000016kF00<006kg00000Vkg00D006kgK_M^m`0000=^m`04001^
mfkg0004K_L01@00KaL006lG00000flG00@007<G000000=c5`03001c5`000080009c=`04001c=g<g
0003LcP01000LcQc>0000g<h00L007=HLeQcF000LeP00002LeP00`00MeQgF00200001GMh001gN7Mh
00000WMh00<007Mh00000WMh00H007MhMgP007Mh0002MgT01@00MiUgV@00MiT00P0000Eg^@00001g
f@00009cN080009Jo0@000=>g@03001FoEKm00@0009Fo@03001FoEKm00<000AFo@<00003E_d005Km
00=Fo@80009oo`03001oogoo04aoo`003Woo0P0027oo0P0067oo0P0027oo0P003Goo0`004Goo0P00
37oo00<007ooOol0=Woo00<005KmE_d00UKm0`000eKm00<005KmE_d00`000eKm00<005KmE_d01000
0UKm00<005KmE_d00`0015Km00<005Km00000UKm00H005KmE_eFo@00E_d200000eKm001Fo@02E_d3
0003E_d00`00E_aFo0040003Dah01@008Wh001gl00000RgI00<002FI00000RVi0`000bVi00<002Vi
00000P000Rfi00@002fi;KT0008]^0<0008a^004000a^36h0002<KP40002=KP01000=KPe^0000SFh
00<003Fh=KP00`0000@e^000>KL000<i]`03000i]`0000<i]`03000i]cVg00P0008me`05000mecgG
?ML00002?ML01@00@MM1ed7G00000d7G00@0047G@ML000=1e`050011eT7F@MH00003AMH01000AMI5
eP000dGF00D004GFAMI5eP0000=5mP050019mTWfBOH00003BOH01P00BOI9mTWf0019mP@00099mP05
0019mTWfBOH00004COH01@00COI=mTgf000014gf00<004gf00000P000dhF00<004hFCQH00ThF00D0
058FDQIB5P0000=B5P8000AB5P05001B5U8FDQH00003DQH20004EQH00`00EQIF5P02EQH00`00ESH0
00030004ESH00`00ESIF=P02ESH00`00ESIF=P02ESH00`00FSIJ=P02FSH20003FSD00`00FSIJ=P03
FSH20003FSD00`00FUIJEP02FUH00`00FUIJEP02FUH01000GUINEUiF0P001EiF00<005iF00000eiF
00<005iFGUH00UiF00<005iFGUH00eiF0P000eif00@0069fHWH0009RMP03001RMV9f009RMP8000ER
MP03001RMV9f00=RMP03001RUV:F00=RUP03001VUVJF00=VUP03001VUVJF00=VUP03001VUVJF00=V
UP03001VUVJF00AVUP03001V]VJf009V]P03001V]P00009Z]P04001Z]VZf0002J[H01@00J[IZ]VZf
00001F[F00T006[FJ]IZeP00J]H006[F000016[F00D006kFK]I^eP00009^m`03001^m`0000=^m`05
001^m`00K_L00003K_L01@00K_M^mfkg00000flG00D006lGKaM_5`00009c5`05001c5g<GLaL00003
LaL20002LcL01000LcMc=`000g<h00<007<hLcP00P0000=c>000LeP00W=H00<007=H00000g=H00<0
07MH00000WMh00@007MhMgP0009gN006001gN000001gN0000WMh00H007MhMgP007Mi0002MiT00`00
MiT00002MiT200001GOI001cN7=h00000W=I0P000e/L00<004kMC]d010000UKm00<005KmE_d01000
0UKm00<005KmE_d00`0015Km00H005Km000005Km0003Ool00`00Oomoo`1;Ool000ioo`8000Qoo`80
01Qoo`8000Qoo`8000ioo`8000Uoo`8000Eoo`<000aoo`03001oogoo03Moo`06001Fo@00001Fo@00
15Km0`000eKm00<005KmE_d00`000eKm00<005KmE_d00`000eKm00<005KmE_d00`0015Km00<005Km
E_d00`000eKm00<005Km00000UKm00@005KmE_eFo@<000=Jo003001C7U<N00D000047O`000000002
9IT01@00:KT002Vi00000bVi00<002Vi00000RVi0`000bfi00@002fh000]^080008a^006000a^36h
000a^0000S6h10000SFh00L003Fh=KPe^000=KP00002=KL50002>KL01000>KLi]`000SVg00@003Vg
>KL000<m]`03000m]cfg00D000<me`03000me`0000=1e`050011ed7G@ML00002@ML01@00@MM1ed7G
00000d7F00D004GFAMI5eP000095eP050015eTGFAMH00003AMH01@00AOI5mTGf000014Wf00@004Wf
BOH00099mP<00099mP050019mTWfBOH00004BOH01@00COI=mTgf00000dgf00@004gfCOI=mP<0009=
mP03001>5ThF009>5P05001>5ThFCQH00004DQH300000e8F001B5P03DQH01@00DQIB5U8F00000U8F
00<0058F000015HF00@005HFEQIF5P@0009F5P03001F=UHf009F=P04001F=UHfESH20004ESH00`00
FSIJ=P02FSH00`00FSEJ=@02FSD00`00FSIJ=P03FSH00`00FSEJ=@02FSD00`00FUIJEP02FUH00`00
FUIJEP02FUH01000GUINEP000UiE00<005iFGUH00eiF00<005iFGUH00UiF00@005iFGUINEP8000EN
EP03001NMUif00=NMP8000ARMP04001RMV9f0002HWH01`00HWIRMV9f001RMP0000ARMP03001RUV:F
00=RUP03001VUVJF00=VUP03001VUVJF00=VUP03001VUVJF009VUP03001VUP0000AVUP03001V]P00
009V]P04001V]VJf0002J[H01P00J[IZ]P00J[H000AZ]P03001ZeV[F009ZeP05001ZeP00J]H00003
J]H00`00J]IZeP02J]H00`00K]H00002K]H01@00K_M^mfkg000016kg00D006kg001^m`00009^m`03
001^m`00009^m`05001_5flGKaL00003KaL01000LaMc5`000g<G00H007<GLaMc5`00LcL20002LcL0
1@00LcL007<h00000W<h00@007<hLcP000=cF003001cF7=H00800005LeP007MHMeP00002MgP20000
17Mh001gN0000WMh00<007Mh00000WMh00D007MhMgP007NH00800004MiT007NI0003MiT400000g=h
001cF@02LeT00`00FaaK7002Fa`30002D]d00`00E_eFo@040003E_d00`00E_eFo@030003E_d00`00
E_eFo@030004E_d01000Oomoo`005goo2P002goo10003Woo10002goo000>Ool20008Ool2000HOol2
0008Ool2000?Ool20008Ool9000=Ool3000hOol20003E_d01P00E_d00000E_d000AFo@<000=Fo@03
001FoEKm00<000=Fo@03001FoEKm00<000=Fo@03001FoEKm00@000=Fo@03001FoEKm008000AFo@03
001Fo@00009Fo@04001Jo5[lF_`30002D_d00`003K/=^`0200029MX30002:KT00`00:KT000030002
:KT01000:KT002fi0P000Rfi00D002fh;KP002fh00@0008a^004000a^36h0002<KP01P00<KP00000
=KP000<e^004000e^3Fh0002=KL00`00=KLe]`0200001CVg000i]cVg00000cVg00@003Vg>KL0008m
]`05000m]cfg?KL00002?KL80003@ML01000@MM1e`000T7G00D0047G@MM1e`0000=1eP050015eTGF
AMH00002AMH01@00AMI5eTGF000014GF00H004GfAOI5mP00BOH800000dWf0019mP02BOH00`00BOI9
mP02BOH01@00BOI9mTWf00000dgf00<004gfCOH00Tgf0`0000==mP00COH00Tgf00<004hFCQH00ThF
00D004hFCQI>5P0000=B5P8000=B5P03001B5U8F009B5P03001B5U8F009B5P8000=B5P03001F5UHF
009F5P<00003EQH0000000AF5P05001F=UHfESH00002ESH00`00ESD00004ESH01000FSIJ=UXf0P00
1EXe00@005XfFSIJ=P8000AJ=@04001JEUYFFUH20005FUH20003GUD00`00GUINEP03GUH00`00GUIN
EP02GUH01000GUINEP000UiF00<005iFGUH00UiF00<005ifGWH00eif00<0069fHWH00f9f00@0069f
HWH0009RMP04001RMV9f0002HWH01`00HWIRMV9f001RMP0000=RUP03001VUP0000=VUP03001VUP00
00=VUP03001VUP0000=VUP03001VUP0000=VUP04001V]VJf0002I[H01P00I[IV]P00J[H000AZ]P03
001Z]VZf009Z]P03001Z]P00009ZeP06001ZeV[F001ZeP000f[F00D006[FJ]IZeP00009^eP03001^
eP0000A^m`05001^mfkgK_L00003K_L02@00K_M^mfkg001^m`00K_L00003KaL01@00KaL006lG0000
0W<G00D007<G001c5`0000=c5`03001c=`0000800003LcL007<g009c=`04001c>7<h0003LcP20000
1G=H001cF7=H00000W=H00@007MHMeP0009gN006001gN7Mh001gN0000WMh00<007MhMgP00P0000Ag
N000MgP0009gV005001gV@00MiT00003MiT2000017^h001kM`000g=I00@006mJ001K70800004Fa`0
05;MD]d40003E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@030003Ool00`00
Oomoo`0DOol:0009Ool8000:Ool80009Ool000ioo`8000Qoo`8001Qoo`8000Qoo`8000moo`8000Qo
o`800003Ool0000000<000ioo`03001oogoo03Yoo`03001FoEKm00<000=Fo@06001Fo@00001Fo@00
15Km0`0000=Fo@00E_d00eKm0`000eKm00<005KmE_d00`000eKm00<005KmE_d010000UKm00<005Km
E_d00`0015Km00<005[l00000e/L00D005;mD_d000fk00<000049MX002Fj9KX3000012Vi000Y^BVi
10000RVi00<002fi00000`000Rfh00<002fh00000Rfh10000S6h00H0036h<KPa^000<KP40002=KP0
1000=KPe^0000SFg00D003Fg=KL003Vg00<00003>KL003Vg008i]`04000i]cVg0003?KL01000?KLm
]`000Sfg00D003gG?MLme`00008me`L00005@ML0047G@ML00003@ML01@00@MI1eT7F00000dGF00@0
04GFAMH000=5eP030015eP0000L00099mP050019mTWfBOH00003BOH01@00BOI9mTWf00000dWf00D0
04WfBOI9mP0000A=mP03001=mP00008000==mP03001=mTgf009=mP05001>5ThFCQH00004CQH30000
0e8F001B5P03DQH01@00DQIB5U8F00000e8F0P00158F00<005HF00000`000UHF00<005HF000015HF
00<005HfESH00UHf0P000eHe00D005HfESIF=P00009J=P04001J=EXe0004FSD01P00FSIJ=P00FSD0
00AJ=@04001JEUYF0002FUD00`00FUIJEP02FUH00`00GUENE@03GUD01000GUINEUiF0P001EiF0P00
0eiF00@005iFGUINEP8000ENMP03001RMV9f00=RMP03001RMP0000=RMP04001RMV9f0002HWH01000
HWIRMP000V9f00@006:FHYH0009VUP04001VUVJF0002IYH01000IYIVUP000VJF00@006JFIYH000=V
UP04001VUVJF0002I[H00`00I[H00004I[H00`00J[IZ]P03J[H00`00J[IZ]P02J[H00`00J[H00002
J]H01@00J]IZeV[F00000f[F00<006[F00000V[F00D006kFK]I^eP0000A^m`05001^m`00K_L00004
K_L01000K_M^m`000fkg00D006lGKaM_5`0000=_5`05001c5g<GLaL00002LaL01@00LaMc5g<G0000
0g<g0P0000=c=`00LcL00W<g0P0000Ec>000LcQc>000009cF004001cF7=H0003LeP2000017MH001g
N0000gMh0P000WMh00@007MhMgP0009gN003001gN000009gV003001gVGNI008000=gV@800004NkP0
07]gNgL2000017=I001_FVmJ0P000e/L0`000U;L00<005KmE_d00UKm0`000UKm00@005KmE_eFo@<0
00=Fo@03001FoEKm00<000=Fo@05001oogooOol0000IOol2000=Ool20004Ool2000:Ool20004Ool2
0009Ool000moo`8000Ioo`8001Yoo`8000Ioo`8000Moo`8000Moo`8000Qoo`8001Aoo`03001oogoo
03]oo`8000=Fo@03001FoEKm00<000=Fo@06001Fo@00001Fo@000eKm00H005Km000005Km0004E_d3
0003E_d00`00E_eFo@030003E_d00`00E_eFo@030003E_d00`00E_eFo@030004Fa`800029MX01@00
9KX002Fi00000RVi00H002Vi:KT002VI0002:KT00`00;KT00002;KP40002;KP01000;KP]^0000S6h
0`000c6h00<0036h00000S6h0`0000@e^000=KP000<e]`03000e]`0000<i]`@0008i]`04000i]cVg
0003?KL01`00?KLm]cfg000m]`0000<me`04000mecgG0003?ML00`00@MM1e`0I0002AMH01@00AMI5
eTGF00000dWf00D004WfBOI9mP0000=9mP050019mTWfBOH00003BOH01@00BOI9mTWf00000dgf0`00
0Tgf00<004gfCOH00Tgf00D004gfCOI=mP0000=>5P04001>5ThFCQH20003DQH00`00DQIB5P02DQH0
0`00DQIB5P02DQH300000e8F001B5P02DQH30003EQH00`00EQH00002EQH00`00EQIF5P02EQH01000
ESIF=UHf0P0015He00<005HfESH00UHf0P000eXe00<005XeFSD00UXe00<005Xf00000eXe00<005Xe
FSD00UXe0P000eYE00<005YFFUH00UYF00<005iEGUD00eiE00@005iFGUH0009NE@03001NEUiF009N
EP03001NEUiF009NEP04001NEUiF0002GWH01`00GWINMUif001RMP0000ERMP03001RMV9f00=RMP80
00ARMP8000=RMP04001RUV:F0002IYH01000IYIVUP000VJF00@006JFIYH000=VUP03001VUP0000=V
UP03001VUP0000AV]P03001V]VJf00=V]P03001Z]VZf009Z]P03001Z]P00009Z]P06001Z]VZf001Z
eP0016[F00T006[FJ]IZeP00J]H006[F000016kF00D006kgK_M^m`00009^m`03001^m`0000=^m`05
001^m`00K_L00003K_L01@00KaM_5flG00000flG00@007<GLaL000=c5`05001c5g<GLaL00003LcL0
0`00LcL00003LcL01000LcMc=`000W<h00@007=HLeQcF0800005LeP007=HLeP00002MeP00`00MgP0
0003MgP02000MgP00000MgP007Mh0003MgP20002MiP01@00MiUgV@00MiT00P0000=gV@00MkT00P00
0W]g00@007MhMgP0009_FP04001_N`00Fa`200000e/L001Bg003D]`01P00E_d00000E_d000AFo@<0
0003E_d005Km00=Fo@<0009Fo@03001FoEKm00<0009oo`03001oogoo01Moo`8000aoo`8000Ioo`80
00Qoo`8000Ioo`8000Qoo`003goo0P001Woo0P006Woo0P001Woo0P001goo0`001Woo0P0027oo0P00
57oo00<007ooOol0?7oo00<005KmE_d010000eKm00<005KmE_d00`000eKm00<005KmE_d00`000eKm
00H005Km000005Km0004E_d30003E_d00`00E_eFo@030003E_d00`00E_eFo@030003E_d01P00Fa`0
0000Fa`0009>V`04000MN0000CT300029KX00`009KT000030002:KT00`00:IT000020002;KT01@00
;KP]^000;IP00P0000<]^000;KP00Rfh00@0036h000a^080008a^006000a^36h000a^0000SFh1@00
0SFg00@003Fg=KL0008i]`03000i]cVg00<00005>KL003Vg>KL00002?KL01@00?KLm]cfg00000Sfg
00D003gG?MLme`00008me`04000mecgG0003@ML01000@MM1e`000d7F00D0047F@MI1eP0000=1eP04
0015eTGF0003AMH01@00AMI5eTGF00000dGF00<004WfBOH00TWf00D004WfBOI9mP000099mP050019
mTWfBOH00003BOH00`00BOI9mP02BOH300000dgf001=mP02COH00`00COI=mP02COH01@00COI=mTgf
000014hF0`0000=>5P00DQH00e8F00D0058FDQIB5P0000=B5P8000AB5P<0009B5P04001F5UHFEQH2
0004EQH01@00EQIF5UHF00000UHf00<005He000015He00<005HfESH00UHf00<005XeFSD00UXe00<0
05XeFSD00eXe00<005XeFSD00UXe00<005XeFSD00UXe00<005YEFUD00UYE00L005YFFUIJEP00FUD0
0004GUD00`00GUH00003GUD00`00GUINEP02GUH00`00GUINEP03GUH20003GWH01000GWINMP000V9f
00<0069fHWH00f9f00<0069fHWH00f9f00<0069fHWH00f9f00<0069fHWH00f9f0P0016JF0P0016JF
0P0016JF00<006JF000016JF00<006JfI[H00fJf00<006JfI[H00VJf00<006Zf00000VZf00H006Zf
J[H006Zf0004J[H00`00J]IZeP02J]H01@00J]H006[F00000f[F00<006kFK]H00VkF00<006kf0000
0Vkg00D006kgK_M^m`0000=^m`06001^mfkg001^m`000Vkg00D006lG001_5`0000=_5`05001c5`00
LaL00002LaL01@00LaL007<G00000g<g00L007<g001c=`00LcL00003LcL01000LcQc>0000W=H00@0
07=HLeP0009cF004001gF7MHMeP20003MgP00`00MgP00002MgP01000MgQgN0000WMh00X007NH0000
07NH001gV@00MiT0009gV@05001g^@00NkP00002NgL01P00MgQgN000KeX000=_N`03001K75/L009K
7003001Bg5;L00<000AFo@03001Fo@00008000AFo@06001Fo@00001Fo@000eKm0`000UKm00D007oo
Oomoo`0001Qoo`8000aoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`0047oo0P0017oo0P0077oo0P00
17oo0P0027oo100017oo0P002Goo0P0057oo00<007ooOol0?Goo0P000eKm00<005KmE_d010000eKm
00<005KmE_d00`000eKm00<005KmE_d00`000eKm00H005Km000005Km0004E_d300000eKm001Fo@03
E_d30003E_d00`00E_eFo@030003Fa`01@00CY]>V`007GP00P000QfJ0`0000@U^@009ITUV@@00004
:IT002VI:IT200001Rfi000]^2fh000]V0<000<]^005000a^36h000a^0030000136h000a^0000S6h
00@003Fh=KP0008e^0800005=KL003Fg=KL00003>KL00`00>KL00002>KL700001Cfg000m]cfg0000
0Sfg00D003gG?MLme`00008me`05000mecgG?ML00002@ML01@00@MM1ed7G00000T7F00D0047F@MI1
eP0000=1eP050015eTGFAMH00002AMH00`00AMI5eP02AMH01@00AMI5eTGF00000dWf00D004WfBOI9
mP0000=9mP040019mTWf0004BOH00`00BOH000020003COH00`00COI=mP02COH01@00COI=mTgf0000
0dgf00@004hFCQI>5P8000=>5P03001B5U8F009B5P05001B5U8FDQH00002DQH00`00DQH00002DQH3
0004DQH01P00EQIF5P00EQD000AF5P03001F5UHF009F5P80009F=@03001F=EHe009F=@04001F=UHf
ESH20005FSD01000FSEJ=EXe0P0015Xe00@005XeFSEJ=@8000AJE@04001JEUYF0002FUD00`00GUEN
E@03GUD00`00GUENE@02GUD01000GUINEUiF0P001EiF00<005ifGWH00Uif00@005ifGWH000=RMP07
001RMV9fHWH0069f0000169f00<0069fHWH00f9f00<0069fHWH00f9f00<006JFIYH00fJF00<006JF
IYH00fJF00<006JFIYH016JF00<006JFIYH00fJF00<006JfI[H00VJf00<006Jf00000VJf00@006Zf
J[H0009Z]P06001Z]VZf001Z]P0016Zf00<006[FJ]H00V[F00D006[F001ZeP0000=ZeP03001^eVkF
009^eP05001^mP00K_L00004K_L01@00K_M^mfkg00000fkg00D006kgK_M^m`00009_5`05001_5flG
KaL00003LaL01@00LaMc5g<G00000W<G00D007<gLcMc=`00009c=`05001c=`00LcL00002LcL01000
LcP000000W=H00L007=HLeQcF000LeP00003MeP01P00MgP00000MgP0009gN006001gN7Mh001gN000
0WMh00<007NH00000WNH00D007NI001gV@00009gV@03001g^@000080009kM`06001gN7Mh001gV@00
0fmk00<006^l00000U/L10000U;l00<005KmE_d010000eKm00<005KmE_d00`0015Km0`0000=Fo@00
E_d00UKm0P000goo00<007ooOol05Goo0P002goo0P0027oo0P001Woo0P0027oo0P001goo000@Ool8
000LOol80009Ool8000:Ool:000;Ool00`00Oomoo`0oOol01000E_eFoEKm0`000eKm00<005KmE_d0
10000eKm00<005KmE_d00`000eKm00<005KmE_d00`000eKm00H005Km000005Km0003E_d01P00E_d0
0000E_d000AFo@<000=G7@04001K75/L0002CY/02@007GP000Cg000MVP008IX000029KT01P009ITU
V@009IT0008YV@04000YV@00:IT20002;KP00`00;IP00002;IP200001bfh000a^36h000a^000008a
^0@0008a^008000e^3Fh=KP003Fh000e]`<00003=KL003Vg008i]`04000i]cVg0002>KL01000>KLi
]`000SVg100000@m]`00?KL000<me`05000mecgG?ML00002?ML01@00@MM1ed7G00000T7G00D0047F
@MI1eP0000=1eP050011eT7F@MH00002AMH01@00AMI5eTGF00000dGF00D004GFAMI5eP0000=9mP05
0019mTWfBOH00003BOH01P00BOI9mTWf0019mP@00099mP03001=mTgf009=mP05001=mTgfCOH00003
COH00`00COI=mP02COH300000dgf001>5P03CQH01@00DQIB5U8F0000158F0P000U8F0`000U8F00<0
058FDQH00U8F00<005HF00000UHE00<005HFEQH00UHF00<005HFEQH00UHF00<005HeESD00UHe00D0
05HeESEF=@00009F=P04001F=EHe0004FSD01P00FSEJ=@00FSD000AJ=@06001J=EXe001J=@001EYE
0P000eYE00<005iEGUD00eiE00<005iEGUD00UiE00@005iFGUH0009NE@03001NEUiF009NEP03001N
MUif00=NMP8000ARMP04001RMV9f0002HWH01`00HWIRMV9f001RMP0000=RMP8000ERMP03001VUVJF
00=VUP03001VUVJF00=VUP03001VUVJF00AVUP03001VUVJF009VUP03001VUP00009V]P04001V]VJf
0002I[H01P00J[IZ]P00J[H000AZ]P03001Z]VZf009Z]P03001ZeP00009ZeP06001ZeV[F001ZeP00
0V[F00<006kF00000VkF00D006kfK_I^mP0000A^m`05001^m`00K_L00004K_L01000K_M^m`000flG
00D006lGKaM_5`0000=c5`04001c5g<G0003LaL02`00LcMc=g<g001c=`00LcL007<g00000W<g00@0
07<hLcP000=cF006001cF7=H001gF0000gMH00<007Mh00000WMh00@007MhMgP0009gN008001gN000
001gN000MiP000=gV0<00004MiT007NI0002MkT02000MkT00000NgL007Mh0002MiT2000016mk001[
_6^l0`000UKl00<005;lD_`010000eKm00<005KmE_d010000UKm00<005KmE_d00`0015Km00D005Km
001Fo@0000=oo`03001oogoo01Eoo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8000Moo`004Woo1000
87oo10003Goo1@002goo2P002goo00<007ooOol0@7oo00<005Km00000UKm00@005KmE_eFo@<000=F
o@03001FoEKm00@0009Fo@03001FoEKm00@000=Fo@03001FoEKm00<000=Fo@03001FoEKm00<000=F
o@04001Fo@000002E_d00`00EaeG7@0;00001@Cg000000008IX010000RFI00<002FI00000P000RVI
00<002VI:IT00`000RfH00@002fH000]V0<00005<KP0036h<KP00002<KP01000<KP000000S6h00@0
03Fh=KP0008e^003000e]cFg00@0008i]`04000i]cVg0003>KL01000>KLi]`000SVg00<003fg?KL0
1@000cgG00@003gG?ML0008me`050011ed7G@ML00003@ML01000@MI1eP000d7F00D0047F@MI1eP00
0095eP050015eTGFAMH00003AMH01@00AMI5eTGF00000dWf00D004WfBOI9mP0000=9mP030019mTWf
00<00099mP050019mTWfBOH00004COH01@00COI=mTgf000014gf00<004gf00000P000dgf00<004hF
CQH00ThF00D0058FDQIB5P0000=B5PD00003DQH0058F00=B5P04001B5U8FDQH20004EQD01@00EQIF
5UHF00000eHF0P0015He00<005HeESD00UHe0P000eHe00<005XeFSD00UXe00<005Xe00000eXe00<0
05XeFSD00UXe0P000eXe00<005YEFUD00UYE00<005YEFUD00eYE00@005iEGUENE@8000ENE@8000=N
E@04001NEUiFGUH20005GWH00`00HWIRMP03HWH00`00HWH00003HWH01000HWIRMP000V9f00@0069f
HWH0009RMP07001RMV9fHWH006:F00000fJF00<006JF00000fJF00<006JF000016JF00<006JF0000
0VJF00@006JFIYH0009V]P06001V]VJf001V]P0016Zf00<006ZfJ[H00fZf00D006ZfJ[IZ]P00009Z
eP03001ZeP0000AZeP09001ZeV[FJ]H006kF001^eP0000A^mP05001^mfkgK_L00003K_L00`00K_M^
m`02K_L01@00K_L006kg00000VlG00D007<G001_5`0000=c5`05001c5`00LaL00002LaL01@00LcL0
07<g00000W<g00P007<gLcL007<g001c=`000W<h0P0000EcF000LeQcF000009gF0800005MeP007Mh
MgP00002MgP2000017Mh001gN0000WMh00H007Mh000007NH0002MiP01`00MiT007NI001gV@00009g
^@03001g^@00009gV@03001gN000009gV@05001g^WNj001[_00200000e^N001Fo002E_`30003E_d0
0`00E_eFo@040002E_d00`00E_eFo@040003E_d00`00E_eFo@030003E_d01@00Oomoogoo00005Woo
0P002goo0P0027oo0P001Woo0P0027oo0P001goo001/Ool30011Ool00`00E_eFo@02E_d00`00E_d0
0002E_d01000E_eFoEKm0`000eKm00<005KmE_d00`000eKm00<005KmE_d010000eKm00<005KmE_d0
0`000eKm00<005KmE_d00`000eKm0`000UKm00@004JmA[d0008j6P09000QN0001?L001Ui000QVP00
008QV@@000049IT002VI0002:IT01000:ITYV@000RVH0`000RfH00<002fH;IP0100000<a^000<KP0
0S6h00<0036h00000`000SFh00@003Fh=KP0008e]`03000e]cFg00<00004>KL003Vg0003>KL01000
>KLi]`000SVg00D003fg?KLm]`00008m]`P0008me`050011ed7G@ML00003@ML01000@MI1eP000d7F
00D0047F@MI1eP0000=5eP040015eTGF0003AMH01@00AMI5eTGF000014Wf00H004WfBOI9mP00BOH4
00000dWf0019mP03BOH01@00BOI9mTWf00000dgf00D004gfCOI=mP0000==mP<0009=mP03001=mTgf
009=mP05001>5ThFCQH00004DQH50004DQH00`00DQIB5P02DQH01P00DQIB5P00DQD000AF5@05001F
5UHFEQH00002EQH00`00EQD00004ESD01000ESEF=EHe0P0015He00<005XeFSD00eXe00<005XeFSD0
0UXe00<005XeFSD00UXe00<005XeFSD00UXe00@005YEFUEJE@8000EJE@04001NEEiE0002GUD00`00
GUENE@02GUD00`00GUENE@02GUD01000GUINEP000UiE00<005ifGWH00Uif00<0069fHWH0169f00<0
069fHWH00f9f0P000f9f00@0069fHWH0009RMP04001RMV9f0002HYH01000IYIVUP000VJF00L006JF
IYIVUP00IYH00003IYH01000IYIVUP000VJF00H006JFIYH006Jf0004I[H00`00J[IZ]P03J[H00`00
J[IZ]P02J[H00`00J[H00002J[H01P00J]IZeP00J]H000AZeP04001ZeV[F0002K]H00`00K]H00003
K_H00`00K_H00002K_L01@00K_M^mfkg00000fkg00D006kgK_M^m`00009_5`05001c5g<GLaL00003
LaL01@00LaMc5g<G00000W<G00D007<gLcMc=`00009c=`04001c=g<gLcL200001G<g001c>7<h0000
0W=H00L007=HLeQcF000MeP00002MeP01000MgQgN0000WMh00H007MhMgP007Mh0002MgP01P00MgQg
N000MiP0009gV003001gV@00009gV@80009g^@03001g^@0000=gV@80009gV@03001g^WNj00@000=K
WP05001Fo000E_d00004E_d30002E_d00`00E_eFo@040003E_d00`00E_eFo@040002E_d00`00E_eF
o@030003Ool00`00Oomoo`0COol2000;Ool20008Ool20006Ool20008Ool20007Ool006]oo`8004Ao
o`03001FoEKm00<000AFo@03001Fo@00009Fo@04001FoEKmE_d30003E_d00`00E_eFo@030003E_d0
0`00E_eFo@040002E_d00`00E_eFo@040003E_d00`00E_d00002F_`01@00E_eFoEKm00000TJm00T0
03XJ>QX0025h0004m`006GT00`000R6I00<002FI00000RFI00<002VI00000P000bVI00D002VH000Y
V000008]V004000]V2fH0002;IP30003<KP00`00<KP00002<KP50002=KP01P00=KLe]`00=KL0008e
]`D0008i]`05000i]cVg>KL00002>KL01000?KLm]`000Sfg00D003fg?KLm]`00008m]`D000=1e`04
0011ed7G0002@MH01@00@MI1eT7F00000d7F00D004GFAMI5eP000095eP030015eTGF0095eP060015
eTGFAMH004Wf20000TWf00D004WfBOI9mP0000=9mP050019mTWfBOH00003COH00`00COI=mP02COH3
00000dgf001=mP02COH00`00COI=mP02COH01@00CQI>5ThF00000e8F0`000e8F00<0058FDQH00U8F
00L0058FDQIB5P00DQH00002DQD00`00EQEF5@02EQD00`00EQIF5P02EQH20003EQD01@00ESEF=EHe
00000UHe00<005He00001EHe00@005XeFSEJ=@8000AJ=@04001J=EXeFSD20004FSD01P00FUEJE@00
FUD000EJE@03001NE@0000=NE@03001NEEiE009NE@03001NEEiE00=NE@8000=NE@07001NMUifGWH0
05ie00001F9f00<0069fHWH00f9f00<0069fHWH00f9f0P000f9f00@0069fHWH0009RUP04001VUVJF
0003IYH00`00IYH00003IYH01000IYIVUP000VJF00<006JF000016JF00<006JfI[H00fJf00<006Zf
J[H00VZf00<006Zf00000VZf00H006ZfJ[H006Zf0004J]H00`00J]IZeP02J]H01@00J]H006[F0000
0fkF00<006kfK_H00Vkf00D006kf001^m`0000=^m`03001^m`00009^m`05001^mfkgK_L00002KaL0
1@00LaMc5g<G00000g<G00D007<GLaMc5`00009c5`04001c=g<gLcL200001G<g001c=g<g00000W<g
0P0000=c>000LeP00W=H0P0000EcF000MeQgF000009gF0800004MgP007Mh0003MgP20002MgP01000
MgQgN0000WNH00D007NH001gV@00009gV@08001gV@00001g^@00MkT0009gV@07001gV@00001gV@00
MkX00P000V?l1P000eKm00H005Km000005Km0003E_d30003E_d00`00E_eFo@040002E_d00`00E_eF
o@040002E_d01@00Oomoogoo00005Goo0P002goo0P0027oo0P001Woo0P0027oo0P001goo001/Ool0
0`00Oomoo`13Ool20003E_d00`00E_eFo@030004E_d01@00E_d005Km000015Km0`000UKm00@005Km
E_eFo@<000=Fo@03001FoEKm00<000=Fo@03001FoEKm00<000AJo003001FoEKm00@0008j6P03000Q
N000008000036GT001fI0080008QV@03000UV@0000800004:IT002VI:IT200001RVI000YV2VH000Y
V0800008;IP002fH;IP002fH000]V080008a^004000a^36h0002<KP00`00<KPa^00200001CFh000e
]cFg00000SFg00@003Fg=KL0008i]`<00005>KL003Vg>KL00002>KL01`00?KLm]cfg000m]`0000<m
]`05000m]cfg?KL00002?KL<0003@MH01@00@MI1eT7F00000TGF00H004GFAMI5eP00AMH80002AMH0
1@00BOI9mTWf00000dWf00D004WfBOI9mP0000=9mP050019mTWfBOH00004COH00`00COH000020003
COH00`00COI=mP02COH01@00COI=mTgf000014hF0`0000=B5P00DQH00e8F00<0058FDQH00U8F00@0
058FDQIB5P8000AB5@05001F5EHEEQD00003EQH20004EQD00`00ESEF=@02ESD20002ESD00`00ESEF
=@03ESD01P00FSEJ=@00FSD000AJ=@06001J=EXe001J=@001EXe0P000eYE00<005YEFUD00eYE00<0
05iEGUD00UiE00@005iEGUENE@8000ENE@03001NEEiE009NE@04001NMUif0002GWD00`00HWIRMP02
HWH20005HWH00`00HWIRMP03HWH00`00HWIRMP03HWH20004HYH20004IYH00`00IYH00003IYH00`00
IYH00004IYH00`00IYIVUP03IYH00`00I[IV]P02I[H00`00J[H00002J[H01000J[IZ]P000VZf00D0
06ZfJ[IZ]P0000EZeP05001ZeV[FJ]H00002J]H00`00J]H00003K]H01@00K_I^mVkf00000fkf00<0
06kgK_L00Vkg00D006kg001^m`0000=^m`04001_5`000003LaL01@00LaL007<G00000g<G00@007<G
000000=c=`04001c=g<g0003LcL00`00LcMc=`040002LeP01000MeQgF0000WMH00@007MHMeP0009g
N004001gN7Mh0002MgP02000MgP00000MgP007Mh0002MiP02P00MiP00000MiT007NI001gV@000WNi
00<007Ni00000WNI00<007NI00000WNi00D007Nj000006?l00800003Fcd004km009>o@03001FoEKm
00<000AFo@<00003E_d005Km00=Fo@<0009Fo@04001FoEKmE_d30003E_d00`00E_eFo@020003Ool0
0`00Oomoo`0BOol2000;Ool20008Ool20006Ool20008Ool20007Ool006aoo`03001oogoo04Eoo`03
001FoEKm00<000=Fo@03001FoEKm00<000=Fo@06001Fo@00001Fo@0015Km00<005Km00000UKm00@0
05KmE_eFo@<000=Fo@03001FoEKm00<000=Fo@03001Jo5[l00@00004CY/002gJ;MX300028GP20002
6GT00`007ITMV@03000012FI000UV@000RVI00@002VI000YV@80008YV004000YV000;IP20002;IP0
1@00;IP]V000;IP00`0000@a^000<KP000<a^004000a^000<KL20002=KL01000=KLe]`000SFg00@0
03Vg>KL0008i]`D0008i]`05000m]cfg?KL00002?KL01@00?KLm]cfg00000Sfg00@003fg?KL000=1
e`050011eT7F@MH00002@MHA0002AMH01@00AMI5eTGF00000dGF00D004WfBOI9mP0000A9mP040019
mTWf0004BOH01000BOI9mP000dgf0`000Tgf00<004gfCOH00Tgf00D004gfCOI=mP0000==mP03001>
5P0000<000AB5P05001B5U8FDQH00004DQH01P00DQIB5P00DQD000AB5@05001F5EHEEQD00002EQH0
0`00EQD00004EQD00`00ESEF=@02ESD00`00ESEF=@02ESD00`00ESEF=@02ESD00`00FSD00003FSD0
0`00FSEJ=@02FSD20003FSD00`00FSEJ=@02FSD00`00FUEJE@02FUD00`00FUEJE@02FUD20004GUD0
1000GUENE@000UiE00<005iEGUD00UiE00<005iEGUD00eiE0P0015ie00@0069fHWH0009RM@04001R
MV9fHWH20005HWH00`00HWIRMP03HWH00`00HYIRUP03HYH00`00IYIVUP04IYH00`00IYIVUP03IYH0
0`00IYIVUP03IYH00`00IYIVUP02IYH00`00I[H00003I[H00`00J[H00002J[H01P00J[IZ]P00J[H0
00AZ]P03001ZeV[F009ZeP03001ZeP00009ZeP05001ZeV[FJ]H00003K]H01@00K]H006kf000016kf
00D006kgK_M^m`0000=^m`05001^mfkgK_L00002KaL00`00LaMc5`02LaL01000LaMc5`000g<G00@0
07<GLaL000=c=`05001c=g<gLcL00002LcL01000LcMc=`000W<g0P000W=H00<007MHMeP00P0000Ag
F000MeP000=gN003001gN000009gN003001gN000009gN003001gN000009gV00:001gV7NH001gV000
MiT007NI0003MkT3000017NI001gV@000WNi00<007Nj00000`0015/m00<004km00000`000eKm00<0
05KmE_d00P0015Km00H005Km000005Km0004E_d300000eKm001Fo@03E_d30002E_d01@00Oomoogoo
00004goo0P002goo0P0027oo0P001Woo0P0027oo0P001goo001[Ool00`00Oomoo`17Ool20003E_d0
0`00E_eFo@030003E_d00`00E_eFo@030003E_d00`00E_eFo@030004E_d01@00E_d005Km000015Km
0`000eKm00<005KmE_d00`000U[l00P004jKCY]>V`00;MX0025i0P0000<QN0005CL00P0000HIN@00
7IT0026I00029IT00`009IT000020002:IT00`00:ITYV@030002:IP00`00;IP]V0030002;IP00`00
;IP00002;IP40003<KP00`00<KP00003<KL400000cFg000e]`02=KL01000>KLi]`000SVg00<003Vg
>KL01@000Sfg00@003fg?KL000<m]`07000m]cfg?KL003fg00000d7G00D0047F@MI1eP000091eP05
0011eT7F@MH00003@MH01@00AMI5eTGF00000TGF00D004GFAMI5eP0000=5eP030015eTGF0095eP05
0019mTWfBOH00003BOH01@00BOI9mTWf00000dWf00@004WfBOI9mP<00003COH004gf009=mP03001=
mTgf009=mP05001=mTgfCOH00003COH400000dgf001B5P03DQH00`00DQIB5P02DQH00`00DQIB5P02
DQH20002DQD00`00DQEB5@02DQD00`00EQEF5@02EQD20002EQD00`00EQEF5@02EQD01000ESEF=EHe
0P0015He00<005HeESD00UHe0P0015Xe00<005XeFSD00UXe00<005XeFSD00UXe00<005XeFSD00UXe
00<005YEFUD00UYE00L005YEFUEJE@00GUD00005GUD20003GUD01000GUENEEiE0P001EiE00<005ie
GWD00eie00@0069fHWH0009RM@04001RMV9f0002HWD01000HWIRMV9f0P001F9f00<006:FHYH00f:F
00<006JFIYH016JF00<006JFIYH00fJF00<006JFIYH00VJF00<006JF00000fJF00<006Jf00000VJf
00H006ZfJ[H006Zf0004J[H00`00J[IZ]P02J[H00`00J[H00002J]H01P00J]IZeP00J]H000AZeP09
001^eVkFK]H006kF001^mP0000=^mP05001^mP00K_L00004K_L01@00K_M^mfkg00000VlG00D007<G
LaMc5`0000=c5`05001c5g<GLaL00002LaL01@00LcMc=g<g00000W<g00L007<g001c=`00LcL00003
LcL200001G=H001gF7MH00000WMH00@007MHMeP0009gN006001gN000001gN0000WMh00<007MhMgP0
0P000gNH00<007NH00000WNH0`0000]gV@00MkUg^@00MkT007Ni001gV@00009g^@07001g^P00LoT0
07?i00000U/m10000dkL00<005KmE_d010000UKm00<005KmE_d00`0015Km00<005Km00000P0015Km
00H005Km000005Km0003E_d20002Ool00`00Oomoo`0AOol2000;Ool20008Ool20006Ool20008Ool2
0007Ool006]oo`03001oogoo04Qoo`03001FoEKm00@000=Fo@03001FoEKm00<000=Fo@03001FoEKm
00<000=Fo@03001FoEKm00<000=Fo@06001Fo@00001Fo@0015Km0`0000=G7@00F_`00e[l00@004jK
CY/0008]fP03000QN@00008000035CL001ei0080008MV@03000QV@00008000049IT002FI0003:IT0
1000:IT002VH0P0000DYV000;IP]V000008]V0<0008]V005000]V2fH000aV0020002<KP01000<KPa
^0000S6g00<003Fg=KL010000SFg00@003Vg>KL0008i]`05000i]cVg>KL00002>KL3000013fg000m
]`000cfg00D003fg?KLm]`00008m]`050011ed7G@ML00003@MH00`00@MH00003@MH01@00@MI1eT7F
00000dGF00@004GFAMH000A5eP050015eTGFAMH00003AMH01@00BOI9mTWf00000dWf00D004WfBOI9
mP0000=9mP030019mTWf008000==mP03001=mTgf009=mP05001=mTgfCOH00003COH60003COH00`00
DQIB5P02DQH00`00DQIB5P02DQH01000DQIB5U8F0P00158E00D0058EDQEB5@0000=F5@8000AF5@05
001F5EHEEQD00002ESD00`00ESD00004ESD01`00ESEF=EHe001F=@0000AJ=@04001J=EXeFSD20004
FSD01000FSEJ=EXe0P0015YE00@005YEFUD000=NE@03001NEEiE009NE@03001NEEiE009NE@04001N
EEiE0002GUD00`00GUENE@02GUD00`00GWENM@03GWD00`00HWH00003HWD01000HWIRMP000V9e00@0
069fHWH0009RMP07001RMV9fHWH0069f00000f:F00<006JF000016JF00<006JF00000fJF00<006JF
00000VJF00@006JFIYH0009VUP06001V]VJf001V]P0016Zf00<006ZfJ[H00fZf00<006ZfJ[H00VZf
00<006Zf00000V[F00D006[FJ]IZeP0000AZeP05001^eP00K]H00003K]H01@00K_I^mVkf00000Vkf
00<006kg00000fkg00D006kg001^m`00009_5`05001c5`00LaL00003LaL01@00LaL007<G00000W<G
00D007<g001c=`00009c=`05001c=g<gLcL00002LcL01@00LcMc=`00MeL00`0000=gF000MeP00WMH
00<007MH00000WMh00H007MhMgP007Mh0002MgP01@00MgQgN000MiP00P0000AgV000MiP0009gV005
001gV@00MiT00002MkT00`00MkT00002MkT300002GNi001g^P00LoT007?i001cN@020003E_`00`00
C]a>g0040002E_d00`00E_eFo@040002E_d00`00E_eFo@040003E_d00`00E_eFo@030004E_d30000
0eKm001oo`02Ool00`00Oomoo`0@Ool2000<Ool20006Ool20008Ool20006Ool20008Ool006]oo`03
001oogoo04Uoo`8000=Fo@03001FoEKm00@0009Fo@03001FoEKm00@000=Fo@03001FoEKm00<000=F
o@03001FoEKm00<000=Fo@06001Fo@00001Fo@000eLM00<005[lF_`0200000<QN@008GT00P0000@E
=`007GTMN@<000048IT0026I00029IT00`009IT000030002:IT00`00:IP000020003;IP01000;IP0
02fH0P000RfH00D002fH;IP0036H00<00004<KP0036h0003<KL00`00=KL00002=KL200000cFg000i
]`02>KL01000>KLi]`000SVg00@003Vg>KL0008i]`D0008m]`05000m]cfg?KL00002?KL01@00@MM1
ed7G00000d7F00@0047F@MH000=1eP050011eT7F@MH00003AMH01000AMI5eP000dGF00D004GFAMI5
eP0000=5eP050019mTWfBOH00003BOH01@00BOI9mTWf00000TWf100000=9mP00COH00dgf00D004gf
COI=mP0000==mP03001=mP0000D00003COH004gf00==mP03001B5U8F009B5P06001B5U8FDQH0058F
0P0000=B5@00DQD00e8E00D0058EDQEB5@00009F5@03001F5@0000AF5@03001F5EHE009F5@8000=F
=@05001F=EHeESD00002ESD01000ESEF=@0015Xe00H005XeFSD005Xe0004FSD01000FSEJ=@000UXe
00<005YEFUD00UYE0P0015iE00<005iEGUD00UiE00<005iEGUD00eiE0P000eiE00L005iEGUENE@00
GUD00005GWD00`00HWERM@03HWD20003HWD01000HWIRMP000V9f00@0069fHWH0009RMP04001RUV:F
0002IYH01@00IYIVUVJF00000VJF00@006JFIYH0009VUP04001VUVJF0002IYH00`00IYH00004I[H2
0004J[H00`00J[IZ]P02J[H00`00J[H00002J[H01P00J[IZ]P00J]H000AZeP05001ZeV[FJ]H00002
K]H00`00K]H00003K]H01@00K_I^mVkf00000fkf00D006kgK_M^m`0000=^m`09001_5flGKaL007<G
001c5`0000=c5`04001c5g<G0003LaL01000LcMc=`000g<g00L007<gLcMc=`00LcL00002LcL01000
MeMgEgMG0P0000MgF000MeQgF000MeP00003MgP00`00MgP00002MgP200001WMh001gN000MiP0009g
V0800006MiP007NH001gV@000WNI00D007Ni001g^@00009g^@0;001g^@00MkT007Nj001cn@00LoT0
0002LgT00`00E_aFo002E_`30002D]`00`00E_eFo@040003E_d00`00E_eFo@030003E_d00`00E_eF
o@040002E_d00`00E_eFo@030004E_d01@00Oomoogoo00004Goo0P0037oo0P001Woo0P0027oo0P00
1Woo0P0027oo001[Ool00`00Oomoo`1:Ool01000E_eFoEKm0`000UKm00@005KmE_eFo@<000=Fo@03
001FoEKm00@000=Fo@03001FoEKm00<000=Fo@03001FoEKm00<000=Fo@03001G7ELM00<0009:g@04
000nFciK0002:KT300002B5i000001Dg000MN@007GT000028IT00`008IT00002000012FI000UVBFI
100000@YV000:IPYV0800006;IP002fH;IP002fH10000RfH00<0036H00000S6H10000c6g00L003Fg
=KL003Fg000e]`030002>KL01000>KLi]`000cVg00<003Vg00000cVg00<003fg?KL00`0000<m]`00
?KL00Sfg00<003fg00000d7G00D0047F@MI1eP000091eP050011eT7F@MH00003@MH01@00AMI5eTGF
00000TGF00D004GFAMI5eP0000=5eP050015eTGFAMH00003BOH00`00BOI9mP02BOH00`00BOH00003
0002BOH01@00BOI9mTWf00000dgf00D004gfCOI=mP00009=mP<0009=mP8000==mP03001=mTgf009=
mP03001B5U8F009B5P04001B5U8FDQH20003DQD00`00DQEB5@02DQD00`00DQEB5@02DQD20002EQD0
0`00EQEF5@02EQD01000EQEF5EHE0P0015He00<005HeESD00UHe0P0015He00<005XeFSD00UXe0P00
0eXe00<005XeFSD00UXe0P000eXe00<005YEFUD00UYE00<005iEGUD00eiE00@005iEGUENE@8000EN
E@03001NEEiE009NE@04001NEEiE0002GUD00`00GWENM@03GWD00`00HWERM@03HWD00`00HWERM@03
HWD20003HWH01000HWIRMP000V9f00@006:FHYH000=VUP04001VUVJF0002IYH01000IYIVUP000VJF
00<006JF000016JF0P0016Jf00<006ZfJ[H00VZf00<006Zf00000VZf00H006ZfJ[H006Zf0004J[H0
0`00J]IZeP02J]H00`00J]H00002J]H01@00K]I^eVkF00000fkF00D006kf001^mP0000A^mP05001^
mfkgK_L00003K_L01000KaM_5`000g<G00D007<GLaMc5`0000=c5`04001c5g<G0003LcL200000g<g
001c=`02LcL00`00LcL00003LcL01`00MeMgEgMG001gF000009gF003001gF7MH00800004MgP007Mh
0002MgP01P00MgQgN000MgP0009gV00:001gV7NH001gV000MiP007NI0002MiT02P00MkT00000MkT0
07Ni001g^@000WNi100000Qcn@00LgUcN@00KgX005Kl0P0000=K7000D]`00U;L0`000UKm00<005Km
E_d00UKm0`000UKm00<005KmE_d010000UKm00<005KmE_d010000eKm00<005KmE_d00P0000Aoo`00
000000eoo`<00003Ool0000000eoo`8000Aoo`8000Yoo`8000Aoo`8000Uoo`00Jgoo0`00Bgoo00<0
05Km00000UKm00L005KmE_eFo@00E_d00002E_d01000E_eFoEKm0`000eKm00<005KmE_d010000UKm
00<005KmE_d010000eKm00<005KmE_d00`000e<M00@004[MB]d0008nF`08000Y^@007GT0025i000M
N@80008MN@03000MN@00008000048IT0026I00029IT01P009ITUV@009IP0008YV004000YV000:IP2
0002;IP00`00;IP00002;IP40002<IP01@00<IPaV000<IP00P000S6g00@003Fg=KL0008e]`03000e
]cFg00@0008i]`05000i]cVg>KL00002>KL01000>KLi]`000Sfg00<003fg?KL02@000d7G00@0047F
@MH00091eP050011eT7F@MH00003@MH01@00AMI5eTGF00000TGF00D004GFAMI5eP0000=5eP030015
eTGF0095eP060019mTWfBOH004Wf10000TWf00D004WfBOI9mP0000=9mP05001=mTgfCOH00003COH3
0002COH300000dgf001=mP03COH01@00COI=mTgf0000158F00H0058F0000058E0004DQD01@00DQEB
5E8E00000e8E0P0015HE00D005HEEQEF5@00009F5@03001F5@0000AF=@04001F=EHeESD20005ESD0
0`00FSEJ=@02FSD00`00FSEJ=@02FSD00`00FSEJ=@02FSD00`00FSEJ=@02FSD01000FUEJEEYE0P00
1EiE00@005iEGUD0009NE@03001NEEiE009NE@03001NEEiE00=NE@8000ANE@04001NMEieGWD20005
HWD00`00HWERM@03HWD00`00HWIRMP03HWH20004HWH20004IYH00`00IYH00004IYH20004IYH00`00
IYIVUP03IYH00`00I[IV]P03I[H00`00J[IZ]P02J[H00`00J[H00002J[H01P00J[IZ]P00J[H000AZ
]P03001ZeV[F009ZeP05001ZeP00J]H00004K]H01@00K]I^eVkF00000Vkf00<006kfK_H00Vkf00D0
06kf001^m`0000=^m`05001^m`00KaL00003LaL01000LaMc5`000g<G00D007<G001c5`00009c=`04
001c=g<g0003LcL00`00LcMc=`0200000g<g001gE`02MeL01000MeP000000WMH00<007MH00000WMh
0P0000AgN000MgP000=gN080009gV004001gV7NH0002MiP3000017NI001gV@000WNi00L007Ni001g
^@00MkT00002MkT01000MkT007OI0`0000AcN@00KgY_NP8000AK70<00003D_`005Km00=Fo@06001F
o@00001Fo@000eKm0`000UKm00<005KmE_d010000eKm00<005KmE_d010000UKm00D007ooOomoo`00
00aoo`H000eoo`P000Yoo`P000Uoo`00JWoo0P00CWoo00<005KmE_d00UKm00<005KmE_d00`000eKm
00<005Km00000UKm00@005KmE_eFo@<000=Fo@03001FoEKm00<000=Fo@03001FoEKm00@0009Fo003
001C7E<M00P0008Y^@03000MN@000080008MN@<000047GT001ei00028IT00`008IT0000200039IT0
0`009IP000020002:IP00`00:IPYV0030002;IP01@00;IP]V000;IP00P0000<aV000<IP00S6H00<0
036H00000P0000@a]`00=KL0008e]`04000e]cFg0002=KL50002>KL01000>KLi]`000cVg00<003fg
00000cfg00D003fg?KLm]`00008m]`L00005@MH0047F@MH00003@MH01@00@MI1eT7F00000dGF00@0
04GFAMH000=5eP060015eTGFAMH004GF20000TWf00D004WfBOI9mP0000A9mP040019mTWf0003COH4
00000dgf001=mP030004COH01@00COI=mTgf00000dgf00<0058FDQH00U8F0P000e8E00<0058EDQD0
0U8E00<0058EDQD00U8E0`0000=B5@00EQD00eHE00<005HEEQD00UHE0P000UHE00<005HeESD00UHe
00H005HeESD005He0005ESD01000FSEJ=EXe0P0015Xe00@005XeFSEJ=@8000AJ=@04001JEEYE0002
FUD00`00GUENE@03GUD20003GUD01000GUENEEiE0P001EiE00<005iEGUD00eiE00@005ieGWD0009R
M@04001RMF9eHWD20005HWD00`00HWIRMP03HWH00`00HWIRMP03HWH00`00IYIVUP04IYH00`00IYIV
UP03IYH00`00IYIVUP03IYH00`00IYIVUP03IYH00`00I[IV]P02I[H00`00J[H00002J[H01P00J[IZ
]P00J[H000AZ]P03001Z]VZf009Z]P03001ZeP00009ZeP05001ZeV[FJ]H00004K]H01@00K]H006kF
00000fkf00D006kfK_I^mP0000=^mP03001^mfkg009^m`05001^m`00KaL00002LaL01@00LaL007<G
00000g<G00@007<GLaL000=c=`04001c=g<g0003LcL00`00LcL00002LcL01@00MeMgEgMG00000WMH
10000WMH00H007MhMgP007Mh0002MgP01@00MgQgN000MgP00P0000AgV000MiP0009gV005001gV000
MiP00002MiT00`00MkT00002MkT3000037Ni001g^@00MkT007OI001gf000MkP0009_NP04001[_6^l
0002Fa`20004D_`00`00E_eFo@030004E_d300000eKm001Fo@02E_d30003E_d00`00E_eFo@040002
E_d00`00E_eFo@030002Ool00`00Oomoo`0=Ool3000?Ool4000>Ool4000;Ool006Yoo`03001oogoo
04ioo`03001FoEKm00@000=Fo@03001FoEKm008000AFo@03001Fo@00009Fo@04001FoEKmE_d30003
E_d00`00E_eFo@030003E_d00`00E_aFo0030003Dah01@008Wh001Wl00000RVi00@001ei000MV@80
00047GT001ei00027GT00`007GT000020000126I000UV@000bFI00D002FH000UV000008YV005000Y
V2VH000YV00200000bfH000]V002;IP00`00;IP000020003<IP00`00<IP00002<IL50002=KL01000
=KLe]`000SFg00<003Fg=KL00`0000@i]`00>KL000<i]`04000m]cfg0002?KL01@00?KLm]cfg0000
0Sfg00D003ff?KHm]P000091]Qd00095eP050019eTWFBMH00003BOH00`00BOI9mP02BOH01@00BOI9
mTWf00000dWf10000dgf0`000Tgf00<004gfCOH00Tgf00D004gfCOI=mP0000==mP03001B5U8F0080
0003DQD0058E00=B5@05001B5E8EDQD00003DQD20003DQD00`00EQEF5@02EQD01000EQEF5EHE0P00
15HE00<005HeESD00UHe0P000eHe00<005HeESD00UHe00H005XeFSD005Xe0004FSD01P00FSEJ=@00
FSD000EJ=@8000=JE@03001NEEiE00=NE@03001NEEiE009NE@04001NEEiE0002GUD00`00GUENE@02
GUD00`00GUENE@03GUD00`00GWD00003HWD01000HWERM@000V9e00@0069eHWERM@8000ERMP03001R
MV9f00=RMP03001VUVJF00AVUP03001VUVJF00=VUP03001VUVJF009VUP03001VUP0000=VUP03001V
UP00009V]P06001Z]VZf001Z]P0016Zf00<006ZfJ[H00fZf00<006ZfJ[H00VZf00D006[F001ZeP00
00AZeP03001^eVkF009^eP05001^eP00K]H00002K_H00`00K_H00002K_H01@00K_I^mVkf00000fkg
00D006kgK_M^m`0000=c5`04001c5g<G0003LaL01@00LaMc5g<G00000W<g00P007<gLcL007<g001c
=`000W<g00@007<gLcL000=gE`03001gF000009gF0800005MeP007MhMgP00002MgP00`00MgP00002
MgP00`00MgP00002MiP00`00MiP00002MiP00`00MiP00002MiP01@00MiT007Ni00000WNi00d007Ni
001g^@00MkT007Ni001gf@00MmP00002MkP00`00KgX00003Jk`30002E_`00`00D_aBo0040002E_d0
0`00E_eFo@030004E_d01@00E_d005Km000015Km0`000UKm00<005KmE_d010000UKm00D007ooOomo
o`00045oo`00JWoo00<007ooOol0Cgoo0P000eKm00<005KmE_d010000UKm00<005KmE_d00`0015Km
00D005Km001Fo@0000AFo@<0009Fo@04001FoEKmE_d30003F_`00`00DaiC7P04000011Wl00000000
0Qei00<001fI7IT00`0000PMN@00000001ei000QN@000R6I00<002FI00000`000RFH00<002FH0000
0P000bVH00<002VH00000P000bfH00@002fH000]V080008aV004000aV36H0002<IL00`00<ILaU`02
00001CFg000e]cFg00000cFg00<003Fg00000SVg1@000SVg00@003fg?KL000<m]`07000m]cfg?KL0
03fg00000cff00D0046f@KI1]P000091eP050011eT7F@MH00003@MH01@00@MI1eT7F00000TGF00D0
04GFAMI5eP0000=5eP050015eTGFAMH00003BMH00`00BOI9mP02BOH01@00BOI9mTWf00000dWf00<0
04Wf00000P000dgf0`0000==mP00COH00dgf00D004gfCOI=mP0000==mP03001=mTgf009=mP8000=B
5@03001B5E8E009B5@05001B5E8EDQD00002DQD00`00DQD00004DQD01@00EQEF5EHE00000UHE00<0
05HE000015HE00<005HeESD00UHe00<005HeESD00UHe00<005HeESD00eHe0P000eXe00<005XeFSD0
0UXe0P000eXe00<005XeFSD00UXe00<005YEFUD00eYE00@005iEGUENE@8000ENE@8000=NE@07001N
EEiEGUD005iE00001EiE00<0069eHWD00V9e00@0069eHWD0009RM@04001RMF9e0002HWD01`00HWIR
MV9f001RM@0000=RMP03001RM@0000AVUP03001VUP0000=VUP03001VUP0000=VUP03001VUP00009V
UP04001VUVJF0002I[H01P00J[IZ]P00J[H000AZ]P03001Z]VZf009Z]P03001Z]P00009Z]P06001Z
eV[F001ZeP000f[F00<006kF00000VkF00D006kFK]I^eP0000=^mP05001^mP00K_H00003K_H01@00
K_H006kg000016kg00@007<GLaL000=c5`04001c5g<G0003LaL01`00LcL007<g001c=`0000=c=`04
001c=g<g0002LcL01@00MeL007MG00000WMH00<007MHMeP0100000IgN000MgQgN000MgP200001GMh
001gN7Mh00000WNH0`0000QgV000MiQgV000MiP007NH0P0000Ig^@00MkT007Ni0002MkT300001GNi
000007OH00000WNh00D007Ni000006^l00800004Gih005KlE_`40002E_d00`00E_eFo@040003E_d0
0`00E_eFo@030003E_d01P00E_d00000E_d000=Fo@<0009Fo@04001FoEKmE_d20003Ool00`00Oomo
o`0nOol006Yoo`03001oogoo055oo`03001FoEKm00<000=Fo@03001FoEKm00<000=Fo@03001FoEKm
00<000=Fo@06001Fo@00001Fo@0015Km00D005Km001Fo@0000AJo0<000=Bo@<0008Q^P8000087GT0
01fI000MN@007GT0008MN@<000068GT00000000UV@000RFI100000<UV000:IP00P000RVH00<002VH
00000RVH0P0000H]V000;IP]V000;IP30000136H000aV0000c6G00@0036G000eU`80008e]`07000e
]cFg=KL003Fg00000cVg00<003Vg>KL00`0000@i]`00?KL000<m]`05000m]cfg?KL00002?KL01@00
?KHm]Sff00000T6f00@0047F@MH000=1eP050011eT7F@MH00003@MH01@00AMI5eTGF00000TGF00D0
04GFAMI5eP0000A5eP050019eTWFBMH00003BOH01@00BOI9mTWf00000dWf0P000TWf00<004gfCOH0
0P0014gf00D004gfCOI=mP0000A=mP04001=mTgf0003COH20005DQD01@00DQEB5E8E0000158E0P00
0U8E00<0058EDQD00U8E00<005HEEQD00UHE0P000UHE00<005HEEQD00UHE00@005HeESEF=@8000AF
=@03001F=EHe00=F=@03001J=EXe009J=@03001J=EXe009J=@03001J=EXe009J=@03001J=EXe009J
=@03001JEEYE00=JE@06001NEEiE001NE@001EiE00<005iEGUD00UiE00@005iEGUD0009NE@03001N
EEiE00=NE@03001RMF9e00=RM@8000=RM@04001RMF9e0002HWD01000HWIRMP000V9e00@0069fHWH0
009RM@05001VUVJFIYH00002IYH01000IYIVUP000VJF00@006JFIYH0009VUP04001VUVJF0002IYH0
0`00I[H00004J[H00`00J[IZ]P02J[H00`00J[H00002J[H01P00J[IZ]P00J[H000AZeP03001ZeV[F
009ZeP05001^eP00K]H00004K]H01000K_I^mP000fkf00<006kfK_H00Vkf00D006kf001^m`0000=^
m`05001c5`00LaL00002LaL01@00LaL007<G00000W<G00D007<gLcMc=`00009c=`04001c=g<gLcL2
000017<g001c=`000gMG00@007MHMeP0009gF006001gF7MH001gN0000WMh00H007MhMgP007Mh0002
MgP02000MiQgV000MiP007NH0002MiP00`00MiP00002MiP01`00MkT007Ni001g^@00009g^@04001g
^@00MkT3000017OH001g^0000WNi0`000UnN10000eKm00<005KmE_d00`000eKm00<005KmE_d01000
0UKm00<005KmE_d00`0015Km0`0000=Fo@00E_d00eKm00D005Km001Fo@0000=oo`03001oogoo03io
o`00JWoo00<007ooOol0DWoo0P000eKm00<005KmE_d00`000eKm00<005KmE_d00`000eKm00<005Km
E_d00`000eKm00<005KmE_d00`000eKm00@005[l0000009K7003001BoE;m00D000038KX001fJ0080
008MV@03000MN@00008000087GT001ei000QN@008GT0008UV@06000UVBFI000UV0000RFH00<002VH
00000`000RVH00@002VH000]V0<00004;IP002fH0002;IP40003<IL00`00<IL00003=IL40002=KL0
1000=KLe]`000SVg00@003Vg>KL0008i]`D0008m]`05000m]cfg?KL00002?KL01@00?KHm]Sff0000
0d6f00@0047F@MH000=1eP050011eT7F@MH00003@MH01000AMI5eP000dGF00D004GFAMI5eP0000=5
eP050019eTWFBMH00003BOH01000BOI9mTWf100000=9mP00BOH0100000==mP00COH00dgf00D004gf
COI=mP0000A=mP04001=mTgfCOH300000dgf001B5@04DQD01@00DQEB5E8E00000e8E0P00158E00D0
058EDQEB5@0000=F5@8000AF5@05001F5EHEEQD00002ESD01000EQEF5@0015He00@005HeESEF=@80
00AJ=@04001J=EXeFSD20004FSD01`00FSEJ=EXe001J=@0000AJE@03001NE@0000=NE@03001NEEiE
009NE@03001NEEiE009NE@04001NEEiE0002GUD00`00GUENE@02GUD20005HWD00`00HWERM@03HWD2
0003HWD01000HWIRMP000V9e00@0069fHWH000=RM@04001VUVJF0002IYH01000IYIVUP000VJF00<0
06JF000016JF0P0016JF00<006ZfJ[H00fZf00<006ZfJ[H00VZf00<006Zf00000VZf00H006ZfJ[H0
06Zf0004J]H01@00J]IZeV[F00000VkF00<006kF00000fkF00D006kf001^mP0000=^mP05001^mVkf
K_H00003K_H01@00K_M^mfkg00000g<G00D007<GLaMc5`00009c5`05001c5g<GLaL00003LcL00`00
LcL00003LcL01000LcMc=`000W<g00@007MGMeMgE`800004MeP007MH0003MeP20003MgP00`00MgP0
0002MgP200001WMh001gV000MiP0009gV0800006MiP007NH001gV0000WNi0`0000ig^@00MkT007Ni
001g^@00MmT007OI001g^0000WNi0P0000AOo000000000=>o@03001FoEKm00@0009Fo@03001FoEKm
00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00<000AFo@03001FoEKm00<000=Fo@05001oogoo
Ool0000oOol006Yoo`03001oogoo0080051oo`03001FoEKm009Fo@<0009Fo@03001FoEKm00@000=F
o@03001FoEKm00<000=Fo@03001FoEKm00<000=Fo@03001FoEKm00<000=K70<0009>V`03000IN@00
00<0008MVP<000047GT001ei00027GT00`007GT0000200000b5i0000000200029IT00`009IP00002
000012VH000YV2VH10000RVH00<002fH;IP00`000RfH00D002fH;IP0036G0080008aU`04000aUc6G
0002=IL00`00=ILeU`03000013Fg000e]`000cVg00<003Vg00000cVg00<003Vg>KL00`0000Dm]`00
?KLm]`00008m]`05000m]Sff?KH00003@KH01000@MI1eP000d7F00D0047F@MI1eP0000=1eP040015
eTGF0003AMH01@00AMI5eTGF00000dGF00D004WFBMI9eP0000=9mP030019mP0000<00003BOH00000
00800099mP05001=mTgfCOH00003COH00`00COI=mP02COH01@00COI=mTgf00000Tgf0P0014gf00<0
058EDQD00U8E00D0058EDQEB5@00009B5@03001B5@0000AB5@05001B5E8EDQD00002EQD00`00EQD0
0004EQD00`00EQEF5@02EQD20003EQD00`00ESEF=@02ESD01P00ESEF=@00FSD000AJ=@06001J=EXe
001J=@0015Xe00@005XeFSD0009J=@03001JEEYE00=JE@03001NEEiE009NE@04001NEEiEGUD20005
GUD20004GUD01000GUENE@000UiE00<0069eHWD00V9e00<0069eHWD00f9e00<0069eHWD00f9e0P00
169e0P00169e00<006JF000016JF0P0016JF0P0016JF00<006JFIYH00fJF00<006ZfJ[H00VZf00<0
06Zf00000VZf00H006ZfJ[H006Zf0004J[H00`00J]IZeP02J]H01@00J]H006[F000016kF00<006kF
K]H00VkF00D006kf001^mP00009^mP05001^mP00K_H00004K_H01@00K_M^mfkg00000g<G00@007<G
LaL000=c5`800003LaL007<g009c=`03001c=`0000=c=`07001c=g<gLcL007<g00000gMG00@007MG
MeL0009gF005001gF7MH001gN00200001gMh001gN7Mh001gN000009gN005001gV000MiP00002MiP0
2000MiQgV000MiP007NH0002MkT03@00MkT007Ni001g^@00MkT007Ni001gf@00009gf@<00003MkT0
00000080009K?@03001>oDkm00@0009Fo@04001FoEKmE_d30002E_d00`00E_eFo@040003E_d00`00
E_eFo@030003E_d00`00E_eFo@040002E_d00`00E_eFo@030003Ool00`00Oomoo`0lOol006Yoo`<0
05=oo`06001Fo@00001Fo@000eKm0`000eKm00<005KmE_d010000UKm00<005KmE_d010000eKm00<0
05KmE_d00`000eKm00D005/L001K700000A>V`04000IN@005IX2000011fJ000MV@000Qei00<001ei
00000P0000HMN@007GT0025i00028GT4000012FH000UV0000RVH00H002VH:IP002VH0002:IP01@00
;IP]V000;IP00P0000<]V000;IP00RfH00<0036G00000P0000@aU`00<IL000<eU`03000eU`00008e
U`@000<i]`04000i]cVg0002>KL01000>KLi]`000Sfg100000Dm]`00?KLm]`00008m]P050011]T6f
@KH00002@MH01@00@MI1eT7F00000d7F00D0047F@MI1eP0000=5eP040015eTGF0003AMH01@00AMI5
eTGF00000dWF00<004WfBOH00`0000=9mP0000000P000TWf00D004WfBOI9mP0000==mP03001=mTgf
009=mP05001=mTgfCOH00003COH300000dgf001=mP03COH00`00DQEB5@02DQD00`00DQEB5@02DQD2
0002DQD00`00DQEB5@02DQD00`00DQEB5@02DQD20002EQD00`00EQEF5@02EQD01000EQEF5EHE0P00
15HE00<005HeESD00UHe00<005He00000eXe00<005XeFSD00UXe0P000eXe00<005XeFSD00UXe0P00
0eXe00<005YEFUD00eYE00<005iEGUD00UiE00@005iEGUD0009NE@03001NEEiE009NE@03001NEEiE
00=NE@04001NEEiE0002GUD01000HWERMF9e0P001F9e00<0069eHWD00f9e00<0069eHWD00f9e00<0
069eHWD0169e00<006JFIYH00fJF00<006JFIYH00fJF00<006JFIYH00fJF00<006JFIYH00VJF00<0
06Jf00000VZf00H006ZfJ[H006Zf0004J[H00`00J[IZ]P03J[H01@00J]IZeV[F00000V[F00<006[F
000016kF00D006kFK]I^eP0000=^mP09001^mVkfK_H006kf001^mP0000=^mP05001^mP00K_L00003
LaL01@00LaL007<G00000W<G00@007<GLaL000=c=`04001c=g<g0003LcL01P00LcMc=`00McL000=g
E`07001gEgMGMeL007MH00000WMH00@007Mh001gN080009gN003001gN00000=gN0<00004MiP007NH
0003MiP300001WNH001g^@00MkT0009g^@@00004MkT007OI0002MmT01000MkT007OI0`0015/m0`00
0TkL00<005KmE_d00UKm0`0000=Fo@00E_d00UKm0`000eKm00<005KmE_d010000UKm00<005KmE_d0
10000UKm00<005KmE_d010000UKm00D007ooOomoo`0003ioo`00JGoo00<007ooOol0EGoo0P000eKm
00<005Km00000UKm00@005KmE_eFo@<000=Fo@03001FoEKm00<000=Fo@03001FoEKm00@0009Fo@03
001FoEKm00<000=K7006001>VdjKCY/001Ui0P000QFJ0`0000PMV@00000001ei000MN@000Qei00<0
01ei00000P000R5i00<0025h00000RFH00H002FH000002VH0002:IP00`00:IP000020003;IP01P00
;IP00000;IP0008]V003000aU`00008aU`@000<eU`03000eU`0000<eU`04000e]`000002>KL01000
>KLi]`000cVg00@003Vg>KL0008m]`03000m]cfg00L00003?KH0046f0091]P030011eP0000=1eP05
0011eT7F@MH00003@MH01@00AMI5eTGF00000TGF00D004GFAMI5eP0000A5eP030019eTWF00L00099
mP050019mTWfBOH00004BOH01000COI=mP0014gf00H004gfCOI=mP00COH200000dgf001=mP02COH0
1@00COI=mTgf0000158E00@0058EDQEB5@8000AB5@05001B5E8EDQD00003DQD20004EQD01@00EQEF
5EHE00000UHE00<005HE00001EHE00<005HeESD00UHe00<005XeFSD00UXe00<005XeFSD00UXe00<0
05XeFSD00UXe00<005XeFSD00UXe00<005XeFSD00eXe00@005YEFUEJE@8000ENE@8000=NE@03001N
EEiE009NE@03001NEEiE00=NE@03001NE@0000=NE@04001RMF9e0002HWD01000HWERMF9e0P001F9e
00<0069eHWD00f9e00<0069eHWD0169e00<006JFIYH00fJF00<006JFIYH00fJF00<006JFIYH00VJF
00<006JF00000fJF00<006Jf00000VZf00H006ZfJ[H006Zf0004J[H00`00J[IZ]P02J[H00`00J]H0
0002J]H01@00J]IZeV[F000016kF00D006kF001^eP0000A^mP04001^mVkf0003K_H01@00K_I^mVkf
00000fkf00D007<GLaMc5`0000=c5`04001c5g<G0003LaL02`00LcMc=g<g001c=`00LcL007<g0000
0W<g00@007LgMcL000=gE`05001gEgMG001gE`0200001GMH001gN7Mh00000WMh0P0000AgN000MgP0
009gN005001gV000MiP00002MiP03000MiQgV000MiP007Nh001g^@00MkT0009g^@04001g^@00MkT3
00002GOI001gf@00MkT007OI001_n00300001E/m000005Kl000014kL00<005Km00000P0015Km0`00
00=Fo@00E_d00eKm0`000UKm00<005KmE_d010000UKm00<005KmE_d010000eKm00<005KmE_d00P00
0goo00<007ooOol0>goo001YOol00`00Oomoo`1GOol00`00E_eFo@020004E_d00`00E_d00002E_d0
1000E_eFoEKm0`000eKm00<005KmE_d00`000eKm00<005KmE_d00`000eLM00<005/LFa`01@000QUi
0P0000PEVP006IX001fI000IN@000Qei00<001ei00000P0000<MN@007GT00P000R5i00<0025h0000
0P0000<UV0009GP00P000RVH00@002VH000YV080008]V004000]V000;IP20002;IP01000<ILaU`00
0S6G00@0036G0000008eU`04000eUcFG0002=IL00`00=KLe]`03000013Vg000i]`000cVg00@003Vg
>KL0008m]`05000m]cfg?KL00002?KH00`00?KHm]P090003@MH01@00@MI1eT7F00000d7F00@004GF
AMH000=5eP060015eTGFAMH004GF20000TWF00D004WfBOI9mP0000A9mP050019mTWfBOH00003COH0
1@00COI=mTgf00000dgf0P000dgf00D004gfCOI=mP0000A=mP03001B5E8E009B5@<00003DQD0058E
00=B5@05001B5E8EDQD00002DQD00`00DQD00004EQD00`00EQEF5@02EQD20002EQD00`00EQEF5@03
EQD01000ESEF=EHe0P0015Xe00@005XeFSEJ=@8000AJ=@04001J=EXeFSD20005FSD01000FUEJE@00
0UYE00<005iEGUD00UiE00<005iEGUD00UiE00L005iEGUENE@00GUD00005GUD00`00GUENE@03GUD2
0003HWD01000HWERM@000V9e00L0069eHWERM@00HWD00003HWD00`00HWD00004HWD00`00IYD00003
IYH00`00IYH00003IYH00`00IYH00003IYH00`00IYH00002IYH01P00I[IV]P00J[H000AZ]P03001Z
]VZf009Z]P03001Z]P00009Z]P06001ZeV[F001ZeP0016[F00D006kFK]I^eP00009^eP03001^eP00
00=^mP05001^mP00K_H00003K_H01@00K_I^mVkf00000fkf00D007<GLaMc5`0000=c5`04001c5g<G
0002LaL01@00LcL007<g00000W<g00@007<gLcL000=c=`07001g=`00MeL007MG00000WMG00H007MG
MeL007MH0002MgP01@00MgQgN000MgP00P0000MgN000MgQgN000MiP00002MiP00`00MiP00002MiP0
0`00MiP00002MkP300004gNi001g^@00MkT007Ni001g^@00MmT007OI001g^@00MmT006oh0080009c
N@03001Fo5Kl009Fo003001>g00000<000=Fo@03001FoEKm008000AFo@06001Fo@00001Fo@000eKm
0`000UKm00<005KmE_d010000eKm00<005KmE_d010000UKm00D007ooOomoo`0003aoo`007goo1000
3Woo0`003goo100037oo1P0047oo00<007ooOol0F7oo0P000UKm00<005KmE_d00`0015Km00D005Km
001Fo@0000AFo@<000=Fo@03001FoEKm00<000=Fo@03001G7ELM00<00004B]d003iK?U/400001@3g
000000006IX00`0000PIN@00000001ei000MN@000Qei00<001ei7GT00`0000@QN0008GP0008UV003
000UN2Eh00<0008YV006000YV000000]V0000RfH00<002fH;IP0100000DaU`00<ILaU`00008aU`<0
0004=IL003FG0003=IL00`00=KL00002=KL50002>KL01@00>KLi]cVg00000Sfg00@003fg?KL0008m
]P05000m]Sff?KH00003?KH00`00@KI1]P0L0003BMH01@00BMI9eTWF000014Wf00D004WfBOI9mP00
00=9mP05001=mTgfCOH00004COH300000dgf001=mP03COH01000COI=mP0014gf00@0058EDQEB5@80
00=B5@03001B5E8E009B5@03001B5E8E009B5@80009B5@03001F5EHE009F5@03001F5EHE009F5@03
001F5EHE009F5@03001F5EHE009F5@06001F=EHe001F=@0015Xe00H005XeFSD005Xe0004FSD01000
FSEJ=@000UXe00<005XeFSD00UXe00<005YE00000eYE00<005iEGUD00UiE00<005iEGUD00UiE00@0
05iEGUD0009NE@03001NEEiE00=NE@03001NEEiE00=NE@03001RMF9e009RM@04001RMF9e0002HWD0
1000HWERM@000V9e00@0069eHWD0009RM@05001RMF9eHWD00002IYD01000IYIVUP000VJF00@006JF
IYH0009VUP04001VUVJF0002IYH00`00IYH00004I[H00`00J[IZ]P03J[H00`00J[IZ]P02J[H00`00
J[H00002J[H01@00J]IZeV[F000016[F00<006kF00000VkF00D006kFK]I^eP0000A^mP05001^mP00
K_H00002K_H01@00K_H006kf00000fkf00D007<G001c5`0000=c5`04001c5`000003LaL01000LcMc
=`000W<g00@007<gLcMc=`800005LcL007LgMcL00002MeL01`00MeMgEgMG001gE`00009gF0800004
MgP007Mh0003MgP3000027Mh001gV7NH001gV000MiP2000017NH001gV0000WNh00d007Nh001g^000
MkT007Ni001g^@00MkT00002MmT400000gOI001_n0020002LgT00`00KgX00002E_`30003D]`00`00
E_eFo@040002E_d00`00E_eFo@030004E_d300000eKm001Fo@02E_d30003E_d00`00E_eFo@040002
E_d00`00E_eFo@030002Ool00`00Oomoo`0jOol001eoo`P000]oo`D000aoo`P000Qoo`X000ioo`03
001oogoo05Uoo`03001FoEKm00<000=Fo@03001FoEKm00<000=Fo@06001Fo@00001Fo@0015Km0`00
00=Fo@00E_d00eKm0`000U<M00@004[MB]d0008nF`0?000QN@000?L001EI000IVP006GT001Ui000I
N@00008MN@03000MN@000080008MN@03000QN@00008QN003000QN0000080008UN009000UN000000Y
V000:IP002VH00<00005;IP002fH;IP00002;IP30003<IL00`00<IL00002<IL40003=IL00`00=KL0
0003=KL00`00>KLi]`0300001CVg000i]cVg00000Sfg00D003fg?KLm]`00008m]P04000m]Sff0003
?KH01000@KI1]P000d7F00D0047F@MI1eP0000=1eP050015eTGFAMH00002AMH00`00AMH000020003
AMH01@00BMI9eTWF000014WF00D004WfBOI9mP0000=9mP050019mTWfBOH00003COH00`00COI=mP03
0003COH00`00COI=mP02COH01@00COI=mTgf00000dgf00H0058E0000057e0004DQD01@00DQEB5E8E
00000e8E0P00158E00D005HEEQEF5@0000=F5@8000AF5@03001F5EHE00=F5@8000=F=@03001J=EXe
009J=@8000=J=@03001J=EXe009J=@8000=J=@03001J=EXe00=J=@03001JEEYE009JE@04001NEEiE
GUD20005GUD20004GUD01000GUENEEiE0P001EiE00<0069eHWD00f9e0P000f9e00@0069eHWD0009R
M@04001RMF9e0003HWD01000HWERM@000VJE00@006JFIYH0009VUP04001VUVJF0002IYH00`00IYH0
0004IYH20004I[H00`00J[IZ]P02J[H00`00J[H00002J[H01P00J[IZ]P00J[H000AZeP03001ZeV[F
009ZeP05001^eP00K]H00004K]H01@00K_I^mVkf00000fkf00D006kfK_I^mP00009^mP03001^mVkf
009^mP04001c5g<G0004LaL00`00LaL00003LaL01@00LcMc=g<g00000W<g00@007<gLcL0009c=`04
001g=gLg0003MeL2000017MG001gE`000WMH00@007MhMgP0009gN003001gN7Mh00<00007MiP007NH
MiP007NH00000WNH00X007NH000007NH001g^000MkP0009g^0@00004MkT007Ni0002MmT01000MmT0
07OI1@000W=i00<006mjKgX00`000U/L00<005;LD]`010000UKm00<005KmE_d010000UKm00<005Km
E_d00`0015Km00D005Km001Fo@0000AFo@<0009Fo@04001FoEKmE_d30002E_d01@00Oomoogoo0000
>goo000MOol20004Ool2000;Ool5000<Ool20004Ool20008Ool30005Ool3000=Ool00`00Oomoo`1J
Ool20003E_d00`00E_eFo@030003E_d00`00E_eFo@030003E_d01P00E_d00000E_d000=Fo@04001F
o@000002E_`00`00DaeC7@050002?U/00`008GT0000200001AEI000000006GT00`0000PIN@000000
01ei000MN@000aei00<0025i00000P0000@QN0008GP000<UN003000UN0000080008YV003000YV2VH
00<000<]V004000]V000;IL20002<IL01000<ILaU`000S6G00@0036G0000008eU`04000e]cFg0002
=KL01000>KLi]`000SVg1@000Sfg00D003fg?KLm]`00008m]P05000m]Sff?KH00003?KH01000@KI1
]P000T7F00D0047F@MI1eP0000=1eP050015eTGFAMH00002AMH20002AMH00`00AMI5eP02AMH01@00
BMI9eTWF00000dWF00D004WfBOI9mP0000=9mP050019mTWfBOH00003COH30002COH00`00COI=mP02
COH01@00COI=mTgf00000dgf00@004gfCOI=mP8000=Am@03001B5E8E009B5@05001B5E8EDQD00002
DQD00`00DQD00004DQD01@00EQEF5EHE00000UHE00<005HE000015HE00<005HEEQD00UHE0P0015He
00<005XeFSD00UXe00<005XeFSD00UXe00<005XeFSD00UXe00<005XeFSD00UXe00<005XeFSD00eXe
00<005YEFUD00UYE00@005iEGUD0009NE@03001NEEiE009NE@03001NEEiE00=NE@04001NEEiE0002
GUD01000GUENEEiE0P001F9e00<0069eHWD00f9e0P00169e0P00169e00<0069e000016JE0P0016JF
0P0016JF0P0016JF00<006JfI[H00VJf00<006Zf00000fZf00D006Zf001Z]P0000AZ]P03001ZeV[F
009ZeP03001ZeP00009ZeP05001^eVkFK]H00004K]H01@00K]H006kf000016kf00@006kfK_H000=^
mP05001^mVkfK_H00003LaL01@00LaMc5g<G00000W<G00@007<GLaL000=c=`05001c=`00LcL00002
LcL00`00LcMc=`0200001GLg001gEgMG00000WMG0P0000AgE`00MeP000=gN003001gN000009gN005
001gN000001gV00200001WNH001gV000MiP0009gV007001gV000MkP007Nh00000WNh00@007Ni001g
^@<0000;MkT007OI001gf@00MmT007OI001gf@0200001g=i001_NVmj001[_000009K70@0009Bo003
001FoEKm00@000=Fo@03001FoEKm00<000=Fo@03001FoEKm00<000=Fo@06001Fo@00001Fo@0015Km
0`0000=Fo@00E_d00UKm0P000goo00<007ooOol0>7oo000LOol20006Ool2000:Ool5000;Ool20006
Ool2000@Ool2000=Ool00`00Oomoo`1LOol00`00E_eFo@030003E_d00`00E_eFo@030003E_d00`00
E_eFo@030003E_d00`00E_eFo@030003E_`30003Dah50000425i000=>0005ET001Ei000IN@006GT0
01Ui000IN@000Qei00X001ei000001ei000QN@008GP0008QN009000QN000000UN0009GP002Eh0080
0006:IP002VH:IP002VH0P000RfH00D002fH;IP002fG00800005<IL0036G<IL00002<IL00`00<ILa
U`03000013FG000e]`000cFg00<003Vg00000cVg00<003Vg>KL01@000Sfg00@003ff?KH000<m]P05
000m]Sff?KH00002@KH01@00@MI1eT7F00000d7F00D0047F@MI1eP000095eP<00003AMH004GF0095
eP050015eTGFAMH00003BMH01@00BMI9eTWF00000dWf00D004WfBOI9mP0000A9mP<00003COH004gf
009=mP03001=mTgf009=mP05001=mTgfCOH00003COH01P00COH00000COD000AAm@05001B5E8EDQD0
0004DQD20002DQD00`00DQEB5@02DQD00`00EQEF5@02EQD20003EQD01@00EQEF5EHE00000UHE0P00
00=F5@00ESD00eHe00@005XeFSEJ=@8000AJ=@03001J=EXe009J=@03001J=EXe00=J=@04001J=EXe
FSD20005FUD20003GUD00`00GUENE@02GUD00`00GUENE@03GUD00`00GUD00003GUD01000GUENE@00
0V9E00<0069eHWD00V9e00<0069eHWD00f9e00<0069eHWD00f9e00<0069eHWD0169e00<006JEIYD0
0fJE00<006JFIYH00fJF00<006JFIYH00fJF00<006JFIYH00fJF00<006JfI[H00VJf00<006Zf0000
0VZf00H006ZfJ[H006Zf0004J[H00`00J]IZeP02J]H01@00J]H006[F000016kF00<006kFK]H00VkF
00D006kF001^mP0000=^mP05001^mP00K_H00002K_H01@00L_H006kf00000g<G00D007<G001c5`00
009c5`05001c5`00LaL00003LcL01000LcMc=`000W<g00@007<gLcL0009g=`05001gEgMGMeL00002
MeL00`00MeL00002MeP01@00MgQgN000MgP00P0000MgN000MgQgN000MiP00002MiP01@00MiP007NH
00000WNH00<007NHMiP00`0001Eg^000MkP007Ni001g^@00MkT007OI001gf@00MmT007OI001gf@00
MmT00P0000Eg^000001_NP00009[_0<000=Fo003001Bo5;l00<000=Fo@03001FoEKm00@0009Fo@03
001FoEKm00@0009Fo@03001FoEKm00<000AFo@03001Fo@00008000AFo@05001Fo@00E_d00003Ool0
0`00Oomoo`0hOol001aoo`8000Ioo`8000]oo`<000aoo`8000Ioo`80015oo`8000aoo`03001oogoo
05eoo`80009Fo@03001FoEKm00@0009Fo@03001FoEKm00@000=Fo@03001FoEKm00<000=Fo@03001F
o000009Jo003001C7U<N00@0008Af`<000053CP00000000EN@0300001AUi000000006GT00`0000<M
N@007GT00P000R5i00P0025h000QN0008GP002Eh0P000REh00H002Eh000002VH0002:IP01P00:IP0
0000;IP0008]V004000]U`00<IL300000c6G000aU`02<IL00`00<IL00002=IL40003=KL01000>KLi
]`000SVg00D003Vg>KLi]`00008i]`<00004?KL003ff0003?KH01@00?KHm]Sff00000T6f00D0047F
@MI1eP0000=1eP040011eT7F@MH300001DGF0015eTGF00000dGF00D004GFAMI5eP0000=9eP050019
eTWFBMH00003BOH00`00BOI9mP02BOH00`00BOH000020003COH00`00COI=mP02COH01@00COI=mTgf
00000dgf00@004gfCOI=mP8000==m@03001AmE7e009Am@05001B5E8EDQD00003DQD20004DQD01@00
DQEB5E8E00000eHE0P0015HE00<005HEEQD00UHE0P000eHE00<005HeESD00UHe00H005XeFSD005Xe
0004FSD01000FSEJ=EXe0P001EXe00@005XeFSD0009J=@03001JEEYE009JE@03001NEEiE009NE@04
001NEEiEGUD20006GUD00`00GUENE@02GUD01000GUENE@000V9E00@0069eHWERM@8000ERM@03001R
MF9e00=RM@03001RMF9e00ARM@03001VUFJE00=VU@03001VUVJF00=VUP03001VUVJF00=VUP03001V
UVJF009VUP03001VUP00009V]P06001Z]VZf001Z]P0016Zf00<006ZfJ[H00VZf00<006Zf00000V[F
00H006[FJ]H006[F0003K]H00`00K]H00002K]H01@00K]I^eVkF000016kf00D006kf001^mP00009^
mP05001bmP00K_H00003LaL01@00LaL007<G00000W<G00@007<GLaL000=c=`04001c=g<gLcL20000
1G<g001c=g<g00000WLg00@007MGMeL0009gE`06001gEgMG001gF0000WMh00H007MhMgP007Mh0002
MgP01P00MiP007NH001gV0<00004MiP007NH0002MiP03@00MkP007Nh001g^000MkT007Ni001g^@00
009gf@@00005MmT007OI001gf@020002MkP01000MkT006^l0P0000=OOP00E_`00eKl0`0000=Fo@00
E_d00eKm0`000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00<005KmE_d010000eKm00<0
05KmE_d00`000eKm00D007ooOomoo`0003Uoo`006goo0P0027oo0P0067oo0P0027oo0P0047oo0P00
2goo00@007oo000005eoo`04001FoEKmE_d30003E_d00`00E_eFo@030003E_d00`00E_eFo@040002
E_d00`00E_eFo@030003F_`30002D_d05`001K/0017K000EVP003CP001EI000EN@005GT001Ui000I
N@006GT001Ui00000Qei00<001ei7GT00`0000@QN0000000008QN003000UN2Eh00<000039GP002Uh
0080008YV004000YV000;IP300001BfH000]UbfG00000S6G10000S6G00@0036G<IL0008eU`04000e
U`000002=KL01000>KLi]`000cVg00@003Vg>KL0008i]`03000m]Sff00D0008m]P05000m]Sff?KH0
0003@KH01000@MI1eP000d7F1@000dGF00@004GFAMH000=5eP050015eTGFAMH00003BMH01@00BMI9
eTWF000014Wf00<004Wf00000`000TWf00<004gfCOH00Tgf00D004gfCOI=mP0000==mP03001=mTgf
009=mP<00003COD004ge00==m@05001AmE7eDOD00004DQD300000e8E001B5@03DQD01@00DQEB5E8E
00000UHE00<005HE000015HE00<005HEEQD00UHE00<005HEEQD00eHE00<005HeESD00UHe0P000eXe
00D005XeFSEJ=@00009J=@04001J=EXe0004FSD00`00FSD00003FSD00`00FUEJE@02FUD00`00GUEN
E@02GUD01000GUENE@000UiE00<005iEGUD00UiE0P001EiE0P000f9E00@0069eHWD0009RM@07001R
MF9eHWD0069e00000f9e00<0069e0000169e0P0016JE0P0016JF00<006JE00000fJF00<006JF0000
0VJF00H006JFIYH006Jf0004J[H20004J[H00`00J[IZ]P02J[H01@00J[H006[F000016[F00<006kF
K]H00VkF00D006kF001^eP0000A^eP05001^mVkfK_H00003K_H01000K_I^mP000g;f00D007<GLaMc
5`0000=c5`04001c5g<G0003LaL01000LcMc=`000g<g00@007<gLcL0009c=`0:001g=gLg001gE`00
MeL007MG0002MeL00`00MeL00003MgP00`00MgP00002MgP200001GMh001gV000MiP00P0000IgV000
MiP007NH0002MiP00`00MkP00002MkP300001GNi000007Ni00000WOI00@007OI001gf@@00003MmT0
0000009g^005001g^@00JoT00004Ggh01P00E_`00000E_d000=Fo@06001Fo@00001Fo@000eKm0`00
0UKm00<005KmE_d010000eKm00<005KmE_d00`000eKm00<005KmE_d010000UKm00<005KmE_d00`00
0goo00<007ooOol0=Woo000KOol20008Ool2000HOol20008Ool2000@Ool2000;Ool2001POol00`00
E_d00002E_d01000E_eFoEKm0`000eKm00<005KmE_d00`000eKm00<005KmE_d00`000eKm00<005[l
00000U/L00H005;mD_eBo@001K/300001AFJ000000005ET00`0000DEN@00000001Ui00<000096GT0
00007GT001ei000MN000008QN0<000078GP002Eh9GP002Eh00000REh00<002Uh:GP00`000RVH00<0
02fH;IP0100000D]U`00<ILaU`00008aU`800005<IL0036G<IL00002=IL00`00=ILeU`03000013Fg
000i]`000cVg00L003Vg>KLi]`00>KL00003?KH00`00?KHm]P0300000cff000m]P02?KH01000@KI1
]P000T7F00<0047F00000P000d7F00D004GFAMI5eP000095eP050015eTGFAMH00003AMH00`00BMI9
eP02BMH01P00BMI9eTWF0019mP@00099mP050019mTWfBOH00004COH01@00COI=mTgf00000dgf00@0
04gfCOI=mP8000==m@03001=mDge009=m@05001AmE7eDOD00003DQD20003DQD00`00DQEB5@02DQD0
0`00DQEB5@02DQD20002EQD00`00EQEF5@02EQD01000EQEF5EHE0P001EHE00<005HeESD00UHe00<0
05XeFSD00UXe00<005XeFSD00UXe0P000eXe00<005XeFSD00UXe0P0015Xe00@005YEFUEJE@8000EN
E@8000=NE@07001NEEiEGUD005iE00001EiE00<0069EHUD00f9E0P000f9e00@0069eHWD0009RM@04
001RMF9e0002HWD00`00HWERM@02HWD00`00IWD00003IYD00`00IYD00003IYH00`00IYD00002IYH0
1000IYIVUP000VJF00H006JFIYH006Jf0004J[H00`00J[IZ]P02J[H00`00J[H00002J[H01P00J[IZ
]P00J]H000AZeP05001^eVkFK]H00002K]H00`00K]H00003K]H01@00K_H006kf000016kf00@006kf
K_H000=bmP04001c5g<G0004LaL01000LaMc5`000W<G00D007<g001c=`00009c=`07001c=g<gLcL0
07<g00000gLg00@007MGMeL0009gE`05001gEgMG001gE`0200001gMh001gN7Mh001gN000009gN003
001gV000009gV0<0009gV0<00004MiP007Nh0002MkP01000MkP007Nh0`0000]g^@00MmT007OI001g
f@00MmT007OI00@00008MkP007Ni001[n@00Go`0009OOP<000AFo@03001Fo@00008000AFo@<00003
E_d005Km009Fo@<000=Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009F
o@05001oogooOol0000hOol001]oo`8000Qoo`8001Qoo`8000Qoo`80011oo`8000]oo`03001oogoo
061oo`03001FoEKm009Fo@05001Fo@00E_d00004E_d30003E_d00`00E_eFo@030003E_d00`00E_eF
o@020004Fa`00`00D_eBo@0300005@3h000EVP004ET001EI000EN@005GT001Ei000IN@006GT001Ui
000IN@0200027GT00`007GP0000200001B5h0000025h00000REh00<002Eh00000P000RUh00H002Uh
000002VH0002;IP00`00;IL]U`030003<IL01000<IL0036G0`0000<aU`00=IL00SFG00<003FG0000
0SFG1@000SVg00D003Vg>KLi]`00008i]`04000m]Sff0002?KH00`00?KHm]P090000147F00000000
0d7F00D0047F@MI1eP000095eP050015eTGFAMH00003AMH01P00AMI5eTGF0019ePP00099eP050019
mTWfBOH00004BOH01@00COI=mTgf00000dgf00<004gfCOH00Tgf0`0000==m@00COD00dge00D004ge
COE=m@0000=Am@06001B5E8E001Am@00158E00D0058EDQEB5@0000=B5@8000AF5@05001F5EHEEQD0
0002EQD01000EQEF5@0015HE00@005HeESEF=@8000AJ=@03001J=EXe009J=@03001J=EXe009J=@07
001J=EXeFSD005Xe000015Xe00@005YEFUD0009NE@03001NEEiE009NE@03001NEEiE009NE@04001N
EEiE0003GUD00`00GUENE@02GUD00`00HUERE@03HUD00`00HWERM@02HWD01000HWERM@000V9e00@0
069eHWD000=RM@04001RMF9e0002IWD01000IYEVU@000VJE00@006JFIYH0009VU@04001VUVJF0002
IYH00`00IYH00004IYH00`00J[IZ]P03J[H00`00J[IZ]P02J[H01@00J[H006Zf000016Zf00<006[F
J]H00V[F00D006kF001^eP0000A^eP03001^eVkF009^eP05001^mP00K_H00003K_H01@00K_H006kf
00000W;f00D007<F001c5`0000=c5`05001c5`00LaL00002LaL01000LcMc=`000g<g00D007<gLcL0
07Lg0080009g=`07001gEgMGMeL007MG00000WMG00<007MG00000WMg00H007MhMgP007Mh0003MgP3
00002WNH001gV7NH001gV000MiP007Nh0P0000Ig^000MkP007Nh0002MkP200002gOI001gf@00MmT0
07OI001gf@00MmT00P0000Ugf@00MmT007Ni001[n@00Go`010000U;m00<005KmE_d010000UKm00<0
05KmE_d00`0015Km00D005Km001Fo@0000AFo@<0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0
00=Fo@03001FoEKm008000=oo`03001oogoo03Eoo`006goo0P0027oo0P0067oo0P0027oo0P0047oo
0P002goo00<007ooOol0HGoo00<005KmE_d00`000eKm00H005Km000005Km0004E_d30002E_d00`00
E_eFo@040002E_d00`00FaaK700400001DjK000IN@000?P00`0000dAF@00000001Ei000EN@005GT0
01Ui000IN@0300026GT300001aeh000MN0008GP0025h0080008UN005000UN0009GP00003:GP00`00
:GP000020003;IP01000;IL002fG0P000S6G00<0036G00000c6G10000SFG00@003FG=IL0008eU`03
000eUcFG00<00005>KL003Vg>KL00002>KL01@00?KHm]Sff00000Sff00@003ff?KH000<m]P030011
]P0000l00003AMH004GF00/00095eP050019eTWFBMH00003BMH00`00BOI9mP02BOH01@00BOI9mTWf
00000dgf00<004gfCOH00Tgf00<004gf00000P000dge00<004geCOD00Tge00D004geCOE=m@0000AA
m@80009Am@03001B5E8E009B5@05001B5E8EDQD00002DQD00`00DQD00004EQD00`00EQEF5@02EQD2
0003EQD00`00EQEF5@02EQD01P00ESEF=@00ESD000AJ=@04001J=EXeFSD20004FSD01000FSEJ=@00
0UXe00<005XeFSD00eXe0P000eiE00<005iEGUD00UiE00<005iEGUD00eiE0P0015iE00@005iEGUEN
E@8000ERE@03001RMF9e00=RM@8000ARM@8000ARM@03001RM@0000=VM@03001VU@0000=VU@03001V
UP0000AVU@8000AVUP03001VUVJF00=VUP03001Z]VZf009Z]P03001Z]P00009Z]P06001Z]VZf001Z
]P0016Zf00<006[FJ]H00V[F00D006kF001^eP0000A^eP05001^eVkFK]H00003K_H01@00K_I^mVkf
00000fkf00D007;fL_IbmP00009c5P05001c5g<GLaL00003LaL01000LaMc5`000g<g0P0000=c=`00
LcL00W<g00<007Lg00000WLg00L007MGMeMgE`00MeL00002MeL01000MeMgE`000WMg0P0000AgN000
MgP0009gN005001gV000MiP00002MiP300002gNH001g^7Nh001g^000MkP007Nh00000WNh0P000WOI
100000Egf@00MmT007OI00800005MmT007OI001cnP050002Fcd00`00D_eBo@040003E_d00`00E_eF
o@030003E_d00`00E_eFo@030003E_d01P00E_d00000E_d000=Fo@<0009Fo@03001FoEKm00@000=F
o@03001FoEKm00@0009Fo@05001oogooOol0000fOol001]oo`8000Qoo`8001Qoo`8000Qoo`8000mo
o`8000aoo`03001oogoo069oo`8000=Fo@03001FoEKm00<000=Fo@06001Fo@00001Fo@000eKm0`00
0eKm00<005KmE_d00`000U/L00H004jKCY]>V`006GT200001`ej000AF@004ET001Ei00<000075GT0
0000000IN@006ET00P0000@IN@006GP0008MN005000MN0008GP000028GP300029GP02@009GP00000
:GP002Uh000YN0020002;IP01@00;IL]U`00;IL00P0000DaU`00<ILaU`00008aU`03000aUc6G0080
0005=IL003FG=IL00002=IL01000=ILeU`000SVG0`0000Di]`00>KLi]`0000<m]P04000m]Sff0002
?KH00`00?KHm]P030002@KH01000@KI1]P000d6f00D0047F@MI1eP000091eP<00003AMH004GF0095
eP050015eTGFAMH00003AMH01@00BMI9eTWF000014WF00D004WfBOI9mP0000=9mP05001=mTgfCOH0
0003COH30002COD00`00COE=m@02COD01@00COE=mDge00000dge00@0057eDOEAm@8000AAm@05001B
5E8EDQD00004DQD20002DQD00`00EQEF5@02EQD01000EQEF5EHE0P0015HE00<005HEEQD00eHE0P00
0eHe00D005XeFSEJ=@00009J=@03001J=@0000EJ=@8000AJ=@03001J=EXe009J=@03001NEEiE009N
E@04001NEEiEGUD20005GUD00`00GUENE@03GUD01000GUENE@000UiE00@0069EHUERE@8000ERM@03
001RMF9e00=RM@03001RMF9e00=RM@03001RM@0000AVM@8000AVU@8000AVU@03001VUVJF00=VUP03
001VUVJF009VUP03001Z]P0000=Z]P05001Z]P00J[H00004J[H00`00J[IZ]P02J[H00`00J]H00002
J]H01@00K]I^eVkF000016kF00D006kF001^eP0000A^mP05001^mVkfK_H00003K_H01000L_IbmP00
0g<F00D007<GLaMc5`0000=c5`800005LaL007<gLcL00002LcL01@00LcMc=g<g00000WLg0P0000Eg
=`00MeMgE`00009gE`800004MeL007MG0002MgL01P00MgMgM`00MgP0009gN003001gV000009gV080
0008MiP007NH001gV000MkP0009g^0<00003MkP007Nh0080009gf@04001gf@00MmT3000027OI0000
0000MmT007OI0002LoX3000016ok001K?E/m0`000e;L00<005KmE_d010000UKm00<005KmE_d01000
0UKm00<005KmE_d00`0015Km0`0000=Fo@00E_d00UKm0`000eKm00<005KmE_d010000UKm00<005Km
E_d00`000Woo00<007ooOol0=7oo000KOol20008Ool2000HOol20008Ool20007Ool20005Ool3000<
Ool00`00Oomoo`1TOol00`00E_eFo@030003E_d00`00E_eFo@030003E_d00`00E_d00002E_d01000
E_eFoEKm0`000eLM00@005/LFa`0009>V`03000IN@00008000073GX00000000AF@005GT00P000QEi
0P000QUi00L001UI6ET001Ui000IN003000011eh000000000R5h00T0025h000002Eh000UN0009GP0
0P000RUh00H002Uh000002fH0002;IL01000;IL002fG0`0000<aU`00<IL00S6G00@0036G000aU`<0
0003=IL003FG008eU`03000eU`0000<iU`03000i]`0000800003>KL003ff008m]P06000m]Sff?KH0
03ff0`000Sff00@0046f@KH00091]P050011]T6f@KH00003@MH01@00@MI1eT7F00000dGF00@004GF
AMH000=5eP030015eTGF0095eP050019eTWFBMH00003BMH01@00BOI9mTWf00000dWf00<004gfCOH0
0Tgf0`0000==m@00COD00Tge00<004geCOD00Tge00D004geCOE=m@0000A=m@<00003DOD0057e00=A
m@05001B5E8EDQD00003DQD20004DQD01@00EQEF5EHE00000UHE00<005HE00001EHE00<005HEEQD0
0UHE00<005HeESD00UHe00<005XeFSD00UXe0P000eXe00<005XeFSD00UXe00<005XeFSD00eXe00<0
05XeFSD00UXe00<005iEGUD00UiE00@005iEGUD0009NE@03001NEEiE009NE@03001NEEiE00=NE@04
001NEEiE0002GUD01000HUERE@000V9e00<0069eHWD00V9e00<0069eHWD00f9e00<0069eHWD0169e
00<006IeIWD00fIe00<006JEIYD00fJE00<006JEIYD00fJE00<006JFIYH00VJF00<006JF00000fJF
00<006Zf00000VZf00H006ZfJ[H006Zf0004J[H00`00J[IZ]P02J[H01@00J]H006[F000016kF00D0
06kFK]I^eP00009^eP03001^eP0000=^mP05001^mP00K_H00003K_H200000g;f001c5P02LaH01@00
LaH007<G00000g<G00@007<GLaL0009c=`05001c=g<gLcL00002LcL01000McMg=`000WLg00L007MG
MeMgE`00MeL00002MeL2000017MG001gM`000gMg0P000gMh00D007NH001gV000009gV007001gV000
MiP007Nh00000WNh018007Nh001g^000MkP007Nh001gf@00MmT007OI001gf@00MmT400000gOI0000
0002LoX30002Ko/30002E]`00`00D]aBg0040002E_d00`00E_eFo@040002E_d00`00E_eFo@040002
E_d00`00E_eFo@030004E_d01@00E_d005Km000015Km0`000UKm00<005KmE_d010000UKm00D007oo
Oomoo`0003Eoo`006goo0P0027oo0P0067oo0P0027oo0P001goo2@0037oo00<007ooOol0IWoo0P00
0UKm00<005KmE_d010000eKm00<005KmE_d00P0015Km00D005Km001Fo@0000AG7@/000053GX000eI
000AF@0300001AEI000000005ET00P0000<IN@006ET00`0000@IN0007EP0008MN08000<QN003000Q
N0000080008UN003000UN2Eh00<00003:GP002Uh00<00005;IL002fG;IL00002;IL30003<IL00`00
<IL00003<IL40002=IL01000=ILeU`000SVG00@003Vg>KLi]`@0008m]P04000m]Sff?KH200000cff
000m]P02?KH01@00@KI1]T6f00000T6f00D0046f@KI1]P0000=1eP040011eT7F0003AMH01@00AMI5
eTGF00000dGF00D004GFAMI5eP0000=9eP050019eTWFBMH00003BOH00`00BOI9mP02BOH00`00COH0
00020003COD00`00COE=m@02COD01@00COE=mDge00000dge00@004geCOE=m@8000=Am@03001AmE7e
009Am@03001B5E8E009B5@<00003DQD0058E00=B5@03001F5EHE009F5@8000=F5@03001F5EHE009F
5@04001F5EHEEQD20004ESD00`00FSEJ=@02FSD00`00FSEJ=@02FSD00`00FSEJ=@02FSD00`00FSEJ
=@03FSD01000FSEJ=EXe0P001EiE0P000eiE00L005iEGUENE@00GUD00005GUD20003GUD01000HUER
E@000V9e00@0069eHWERM@8000ARM@03001RM@0000ERM@03001VMFIe00=VM@03001VUFJE00=VU@03
001VUFJE009VU@03001VU@0000=VUP03001VUP00009VUP06001Z]VZf001Z]P0016Zf00<006ZfJ[H0
0VZf00<006Zf00000VZf00H006[FJ]H006[F0003K]H00`00K]H00002K]H01@00K]I^eVkF000016kf
00@006kfK_H000A^mP04001bmP000003LaH01000LaIc5P000g<G00D007<GLaMc5`00009c=`08001c
=g<g001c=`00LcL0009g=`03001g=gLg00800005MeL007MGMeL00002MeL00`00MeL00002MgL01@00
MgMgM`00MgP00P0000IgN000MiP007NH0003MiP3000027NH00000000MkP007Nh0002MkP400002gOI
001gf@00MmT007OI001gf@00MmT00P0000Egn@00000007?j00<00005Ko/00000Gih00003E]`30002
E_d00`00E_eFo@040002E_d00`00E_eFo@040003E_d00`00E_eFo@030003E_d00`00E_eFo@030003
E_d01P00E_d00000E_d000=Fo@<0009Fo@03001FoEKm00<0009oo`8003Aoo`006goo0P0027oo0P00
67oo0P0027oo0P001goo0P0000=oo`0000000`003Goo00@007oo000006Ioo`03001FoEKm00<000=F
o@03001FoEKm00@0009Fo@03001FoEKm00<000=Fo@06001G7@00001C7@000T[m00L003iK?U/001ei
0000e`0300000`eI0000000200001aEI000EF@005ET001EI0080008IF@80008IN003000MF0000080
00087GP000008GP0025h000QN08000079GP002Eh9GP002Eh00000RUh00<002Uh:GP0100000H]U`00
;IL]U`00;IL20002<IL01000<ILaU`000S6G00<003FG=IL00P0000DeU`00=ILeU`0000<iU`04000i
]cVg0002>KH300000cff000000020002?KH01@00?KHm]Sff00000d6f00@0046f@KH000=1]P050011
eT7F@MH00003@MH01000AMI5eP000dGF00D004GFAMI5eP0000=5eP050019eTWFBMH00003BMH00`00
BOI9mP02BOH00`00BOH000030002BOH00`00COE=m@02COD01@00COE=mDge00000dge00<004geCOD0
0Tge0`0000==m@00DOD00e7e00D0057eDOEAm@0000=B5@8000=B5@03001B5E8E009B5@04001F5EHE
EQD20004EQD00`00EQEF5@02EQD01P00EQEF5@00EQD000AF=@04001J=EXeFSD20004FSD01`00FSEJ
=EXe001J=@0000AJ=@04001J=EXe0002FSD00`00GUENE@02GUD00`00GUENE@02GUD01000GUENE@00
0UiE00<005iEGUD00eiE00<005iEGUD00eiE0P000f9e00@0069eHWD0009RM@07001RMF9eHWD0069e
0000169e00<0069e00000fIe00<006JE00000fJE00<006JE00000fJE00<006JE00000VJF00H006JF
IYH006JF0004J[H20004J[H00`00J[IZ]P02J[H01@00J[H006Zf000016[F00<006kFK]H00VkF00D0
06kF001^eP0000A^eP05001^mVkfK_H00003K_H01@00K_I^mVkf00000W;f00D007<FLaIc5P0000=c
5P05001c5g<GLaL00002LaL01000LcL000000g<g00@007<gLcL0009g=`04001g=gLg0002MeL01000
MeMgE`000WMG00H007MGMeL007Mg0002MgL00`00MgP00002MgP2000017NH001gV0000WNH00L007NH
001kV000MkP00002MkP20002MkP01000MkP007Nh0`0000Qgf@00001gf@00MmT007OI0P0000Egn@00
MoT007?i00D000AOWP<00003E_d005Km009Fo@<000=Fo@03001FoEKm00<000=Fo@03001FoEKm00@0
009Fo@03001FoEKm00@0009Fo@03001FoEKm00<000AFo@<00003E_d005Km009Fo@<0009Fo@<00003
Ool007oo03=oo`0077oo0P001Woo0P006Woo0P001Woo0P0027oo0P004goo0P00JGoo0P000eKm00<0
05KmE_d00`000eKm00<005KmE_d00`000eKm00<005KmE_d00`000e<M00@004[mB_d0008nF`0;000M
N@00000=F@003ET000eI000AF@03000011EI000000000QEI0`0000/IF@00000001eH000MF0007GP0
01eh0080008QN006000QN000000UN0000REh00<002Eh00000P000RUh00<002Ug:GL00P0000H]U`00
;IL]U`00;IL30000136G000aU`000S6G00D003FG=IL003FG00<00003=IL003VG008iU`04000i]cVg
0002>KH<0002?KH01@00@KI1]T6f00000T6f00D0046f@KI1]P0000=1eP050011eT7F@MH00003AMH0
1000AMI5eP000dGF00D004GFAMI5eP0000=9eP030019eTWF0099eP030019mP0000<00099mP050019
mTWfBOH00004COD01@00COE=mDge00000dge00@004geCOE=m@8000==m@03001AmE7e009Am@05001A
mE7eDOD00002DQD00`00DQD00004DQD01@00DQEB5E8E00000UHE00<005HE000015HE00<005HEEQD0
0eHE0P000eHE00D005HeESEF=@00009J=@03001J=@0000AJ=@04001J=EXe0002FSD00`00FSEJ=@03
FSD20003FSD00`00GUENE@02GUD00`00GUENE@02GUD01000GUENE@000UiE00<005iEGUD00eiE00<0
05iEGUD00eiE00<0069eHWD00V9e00@0069eHWD0009RM@04001RMF9e0003HWD01000HWERM@000V9e
00@006IeIWD0009VU@04001VUFJE0002IYD01000IYEVU@000VJE00<006JF000016JF0P0016Zf00<0
06ZfJ[H00VZf00<006Zf00000VZf00H006ZfJ[H006Zf0004J]H01@00K]I^eVkF00000fkF00<006kF
K]H00VkF00D006kf001^mP0000=^mP05001^mP00K_H00003L_H01000LaIc5P000g<F00D007<F001c
5`0000=c5`03001c=`0000=c=`04001c=g<gLcL2000017Lg001g=`000gMG0P0000AgE`00MeL0009g
E`03001gM`0000=gM`03001gN000009gN005001gV000MiP00002MiP00`00MiP00002NiP500002gNh
001g^000MkP007Nh001gf000MmP00`0000Agf@00001gf@800007MoT007Oi001cn@00LoT00P0000=O
n@000000100015Km00D005Km001Fo@0000AFo@<0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0
009Fo@03001FoEKm00@0009Fo@03001FoEKm00<000AFo@05001Fo@00E_d00004E_d01@00Oomoogoo
0000<goo000LOol20006Ool2000JOol20006Ool20008Ool2000COol00`00Oomoo`1YOol00`00E_eF
o@040003E_d00`00E_eFo@030003E_d00`00E_eFo@030003E_`00`00DaeC7@0700001Aei00000000
3ET00`0000P=F@00000AF@005ET001EI0P0000PEF@005ET001UI000IF0000QeH00<001eH00000P00
0Qeh0`0000<QN0008GP00P000REh00D002Eh000YN00000<YN004000YM`00;GL20002;IL00`00;IL0
0002<IL40003<IL00`00=IL00003=IL40002>IL01000>KLi]cVg0`000cVf00D003ff?KHm]P00008m
]P<00005?KH0046f@KH00002@KH01@00@KI1]T6f00000d7F00D0047F@MI1eP0000=5eP040015eTGF
0003AMH01@00AMI5eTGF000014WF00<004WF00000`000TWF00D004WfBOI9mP0000A9mP05001=mDge
COD00003COD00`00COE=m@02COD300000dge001=m@03COD01@00DOEAmE7e0000157e0P000U8E00<0
058EDQD00U8E00<0058EDQD00U8E0P000eHE00<005HEEQD00UHE00<005HEEQD00UHE00<005HEEQD0
0UHE00<005HeESD00UHe0P000eXe00<005XeFSD00UXe0P000eXe00<005XeFSD00eXe00<005XeFSD0
0UXe00@005iEGUENE@8000ENE@8000ANE@04001NEEiEGUD20005GUD00`00HWERM@03HWD20003HWD0
0`00HWD00004HWD01000HWERM@000V9e00@006IeIWD0009VU@04001VUFJE0002IYD00`00IYD00004
IYD20004IYH00`00J[IZ]P03J[H00`00J[IZ]P02J[H01@00J[H006Zf000016Zf00<006[FJ]H00V[F
00D006kF001^eP0000A^eP03001^eVkF009^eP05001^mP00K_H00003K_H01@00K_H006kf00000W;f
00D007<F001c5P0000=c5P04001c5W<F0003LaL01000LcMc=`000W<g00D007<gLcMc=`00009g=`04
001g=gLg0002MeL01000MeMgE`000WMG00<007MG00000WMg0P0000AgM`00MgP0009gN003001gV7NH
00<00004MiP007NH0002NiP01000NkP007^h0`0000Qg^000MkP007Nh001gf0000WOH0P0000Egf@00
000007OI00<00005MoT007?i001cn@0200001Eoi001K?E/m00000dkm00<005KmE_d00`000eKm00H0
05Km000005Km0003E_d30002E_d00`00E_eFo@040002E_d00`00E_eFo@040003E_d00`00E_eFo@03
0003E_d00`00E_eFo@030003E_d00`00E_eFo@030003Ool00`00Oomoo`0`Ool001eoo`8000Aoo`80
01aoo`8000Aoo`8000Uoo`8001=oo`03001oogoo06Yoo`8000=Fo@03001FoEKm00@0009Fo@03001F
oEKm00@0009Fo@03001Fo5Kl00@0009Bo@03000ZORYn0080008MN@8000053ET000eI000=F@030000
115I000000000QEI0`0000DEF@00000001UH00<000037EP001eH008000047GP0025h00028GP00`00
8GPQN00300029GP02000:GP00000:GP002Ug0003;GL30002;IL01@00<ILaU`00<IL00P000S6G00@0
03FG=IL0008eU`03000eUcFG00800003>IL0000000<0008i]P04000i]SVf0003?KH01000?KHm]P00
0Sff100000E1]P00@KI1]P0000=1]P040011eT7F0003@MH01@00AMI5eTGF00000TGF00<004GFAMH0
0TGF00H004GFAMI5eP00BMH40002BMH01@00BMI9eTWF000014Wf00D004WfBOI9mP0000==m@05001=
mDgeCOD00003COD20003COD00`00COE=m@02COD01@00DOEAmE7e00000e7e0P00158E00D0058EDQEB
5@0000AB5@03001F5EHE009F5@03001F5EHE009F5@04001F5EHEEQD20004EQD00`00ESEF=@02ESD0
0`00FSEJ=@02FSD00`00FSEJ=@02FSD00`00FSEJ=@03FSD00`00FSEJ=@02FSD00`00FSEJ=@02FSD0
1000GUENE@000UiE00<005iEGUD00UiE00<005iEGUD00eiE00@005iEGUD0009NE@04001NEEiEGUD2
0005HWD00`00HWERM@03HWD20004HWD00`00HWD00004HWD20004IYD20004IYD20004IYD00`00IYIV
UP03IYH00`00J[IZ]P02J[H00`00J[H00002J[H01P00J[IZ]P00J[H000AZ]P03001ZeV[F009ZeP05
001^eP00K]H00003K]H00`00K]H00002K]H01@00K_I^mVkf00000fkf00D006kfK_I^mP0000=bmP04
001c5W<F0003LaH01@00LaIc5W<F00000W<G00P007<gLcL007<g001c=`000W<g00L007LgMcMg=`00
McL00002MeL01`00MeMgEgMG001gE`00009gE`03001gM`00009gM`800004MgP007Mh0002MiP01000
MiP007^H0P0000IgV000NiP007^h0002NkP00`00NkP0000200001GNh000007OH00000WOH0P000WOI
0P0000=gf@0000000P0000Agn@00001cn@@000=K?@L0009Fo@03001FoEKm00<000AFo@<00003E_d0
05Km009Fo@<000=Fo@03001FoEKm00<000=Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03
001FoEKm00@0009Fo@05001oogooOol0000bOol001eoo`P001aoo`P000Uoo`X000]oo`03001oogoo
06]oo`04001FoEKmE_d30003E_d00`00E_eFo@030003E_d00`00E_eFo@030003F_`00`00D_eBo@0<
00000`eI0000000200000a5I000AF@02000031EI000AF@005ET001EH000IF0006EP0008MF003000M
F000008MN003000QN0000080008QN009000UN000000UN000:GP002Ug0080008YM`05000]Mbeg000]
M`0200001BfG000aUc6G00000S6G0P0000DaU`00=ILeU`00008eU`03000eUcFG00D0008i]`04000i
]SVf0003>KH01`00?KHm]Sff000m]P0000<m]P03000m]Sff00/00003@MH0047F0091eP050015eTGF
AMH00002AMH00`00AMH000070002BMH01@00BMI9eTWF000014WF00D004WfBOI9mP0000=9mP05001=
mDgeCOD00004COD300000dge001=m@03COD01@00COE=mDge00000e7e00H0057eDOD0057e0004DQD0
1@00DQEB5E8E00000e8E0P0015HE00<005HEEQD00UHE00H005HEEQD005HE0004EQD01000ESEF=EHe
0P0015Xe00@005XeFSEJ=@8000EJ=@04001J=EXeFSD20005FSD20003GUD00`00GUENE@02GUD00`00
GUENE@03GUD00`00GUD00003GUD01000GUENE@000V9E00<0069eHWD00V9e00<0069eHWD00f9e00<0
069eHWD0169e00<0069eHWD00f9e00<006JEIYD00fJE00<006JEIYD00fJE00<006JEIYD00fJE00<0
06JFIYH00VJF00<006ZE00000VZf00H006ZfJ[H006Zf0004J[H00`00J[IZ]P02J[H00`00J[H00002
J]H01@00K]I^eVkF000016kF00D006kF001^eP0000A^mP04001^mVkf0004K_H01000L_IbmP000g<F
00@007<FLaH000=c5P05001c5`00LaL00002LcL01000LcMc=`000g<g00H007LgMcL007Lg0003MeL0
1@00MeMgE`00MeL00P0000EgE`00MgMgM`00009gM`0:001gM`00001gN000MiP007NH0002NiP01`00
NiP007^H001k^000009k^003001k^00000800007MkP00000001gf000MmP00P000WOI0P0000=gf@00
MoT00P0000=gn@0000001P0000EK?@00001Fg00000=>g003001FoEKm00@0009Fo@03001FoEKm00<0
00AFo@05001Fo@00E_d00004E_d30002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00
E_eFo@040002E_d00`00E_eFo@030003Ool00`00Oomoo`0_Ool001moo`@0021oo`@000]oo`X000Yo
o`03001oogoo06eoo`03001Fo@00009Fo@04001FoEKmE_d30003E_d00`00E_eFo@030003E_d00`00
F_aJo0030003C_d400000aFJ0000000400000`eI0000000300024ET300002A5I000EF@005EP001UH
000IF00300027EP30000125h000QN0000b5h00<002Eh00000P000RUh00H002Ug000002Ug0002;GL0
0`00;GL]M`030003<IL01000<IL0036G0`0000<eU`00=IL00SFG10000SFG0`0000@i]`00>KH000<i
]P05000m]Sff?KH00002?KH01000?KHm]P000cff00@0046f@KH000=1]P030011]T6f00h00095eP05
0015eTGFAMH00003BMH00`00BMI9eP02BMH01@00BMI9eTWF00000dWf00D004WfBOI9mP0000A=m@03
001=m@00008000==m@03001=mDge009=m@05001=mDgeCOD00004DOD20002DOD00`00DQEB5@02DQD0
1@00DQEB5E8E00000U8E00<0058E00001EHE00<005HEEQD00UHE0P000eHE00D005HEEQEF5@00009F
=@03001F=@0000AJ=@04001J=EXe0002FSD00`00FSEJ=@02FSD01000FSEJ=@000UXe00<005XeFSD0
0UXe00<005iEGUD00UiE00L005iEGUENE@00GUD00005GUD00`00GUENE@02GUD01000GUENE@000V9E
00@0069eHWERM@8000ERM@03001RMF9e00ARM@03001RMF9e00=RM@03001VUFJE00=VU@03001VUFJE
00=VU@03001VUFJE009VU@03001VU@0000=VUP03001ZU@00009Z]P06001Z]VZf001Z]P0016Zf00<0
06ZfJ[H00VZf00D006Zf001ZeP0000A^eP05001^eVkFK]H00002K]H00`00K]H00003K_H01@00K_H0
06kf00000fkf00D007;f001bmP00009c5P05001c5P00LaH00003LaH01000LaMc5`000W<g00@007<g
LcMc=`800005LcL007LgMcL00002McL200001GMG001gEgMG00000WMG00<007MG00000WMg00@007Mg
MgL0009gM`03001gM`00009gV005001gV000NiP00002NiP300001g^h001k^000NkP007^h0080000:
MkP00000MmP007OH001gf@00MmT200000gOI001gn@0200000gOi001cn@050002LiT00`00E]aFg002
E]`00`00C]`000030003E_d00`00E_eFo@030003E_d00`00E_eFo@030003E_d01P00E_d00000E_d0
00=Fo@<0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@000=Fo@03001FoEKm00<000=Fo@04001o
ogoo000aOol006Ioo`03001oogoo06ioo`03001FoEKm009Fo@05001Fo@00E_d00004E_d30002E_d0
0`00E_eFo@040002F_`00`00C_e>o@0400001`5I000EVP002ET000eI0080008=F@09000=F@00000A
F@004ET0015I00<000085EP00000000IF0006EP0008MF003000MF000008QN009000QN000000QN000
9GP002Eh00800004:GP002Ug:GL30003;GL01000;GL002eg0P000S6G00<0036G00000c6G1`000SFG
00@003FG=IL0008iUPD0008i]P05000m]Sff?KH00002?KH01@00?KHm]Sff00000Sff00@0046f@KH0
00=1]P050011]T6f@KH00003@MH01@00AMI5eTGF00000TGF00D004GFAMI5eP0000=5eP030019eTWF
0099eP050019eTWFBMH00003BMH01@00BOI9mTWf00000dWf00@004geCOE=m@<0009=m@03001=mDge
009=m@05001=mDgeCOD00003COD01000DOEAmE7e0P00157e00D0058EDQEB5@0000AB5@8000=B5@03
001F5EHE009F5@04001F5EHEEQD20004EQD00`00EQEF5@02EQD20003ESD00`00FSEJ=@02FSD20003
FSD00`00FSEJ=@03FSD20003FSD00`00FSEJ=@02FSD00`00GUENE@02GUD01000GUENE@000UiE00<0
05iEGUD00eiE00<005iEGUD00eiE0P000f9E00@0069eHWD0009RM@07001RMF9eHWD0069e0000169e
0P00169e0P0016JE00<006JE00000fJE00<006JE00000fJE00<006JE00000VJF00H006ZEJYD006Zf
0004J[H00`00J[IZ]P02J[H00`00J[H00002J[H01P00J[IZ]P00J]H000=^eP05001^eP00K]H00004
K]H00`00K_I^mP02K_H01000K_I^mP0016kf00@007;fL_H000=c5P04001c5W<F0003LaH01@00LaMc
5g<G00000W<g00@007<gLcL0009g=`07001g=gLgMcL007Lg00000WMG00L007MGMeMgE`00MeL00002
MeL200001gMg001gMgMg001gM`00009gM`07001gV000MiP007^H00000W^H00L007^h001k^000NkP0
0002NkP20002MkP20002MmP400000gOI001gf@0200001WOi000007Oi001cn@D000=cV@80009Fg0<0
00=Bg003001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00<000AFo@<00003E_d005Km
009Fo@<000=Fo@03001FoEKm00<000=Fo@03001FoEKm00@0009Fo@03001FoEKm00<0009oo`03001o
ogoo02ioo`00IWoo00<007ooOol0Kgoo00<005KmE_d00`000eKm00H005Km000005Km0003E_d30003
E_d00`00F_aJo0030003C_h200001@5I000000002ET00P0000<9F@003ET00P000PeI0`0000<AF@00
4ET00P000QEH0P000QUH00L001UH000001eH000MF00300000b5h000QN00200029GP02@009GP00000
:GP002Ug000YM`020002;GL00`00;GL00002;GL200001C6G000aUc6G00000S6G1@0000<eU`00=IL0
0SFG00<003FG00000cVF00<003VF>IH00`0000Di]P00?KHm]P00008m]P05000m]Sff?KH00003?KH0
1000@KI1]P000d6f00@0046f@KH000=1eP050015eTGFAMH00002AMH00`00AMI5eP02AMH01@00AMI5
eTGF00000dWF00D004WFBMI9eP0000=9eP050019mTWfBOH00004BOH300000dge001=m@02COD00`00
COE=m@02COD01@00COE=mDge000014ge0`0000=Am@00DOD00e7e00D0058EDQEB5@0000=B5@8000AB
5@03001F5EHE009F5@06001F5EHE001F5@0015HE00<005HEEQD00UHE00<005HeESD00UHe00<005Xe
FSD00UXe00<005XeFSD00UXe00<005XeFSD00eXe00<005XeFSD00UXe00@005XeFSEJ=@8000ENE@80
00=NE@03001NEEiE009NE@8000ENE@03001REF9E009RE@04001RMF9e0002HWD01000HWERM@000V9e
00<0069eHWD00V9e00<0069e00000f9e00<006Ie00000fJE00<006JE00000VJE00@006JEIYD0009V
U@06001VUFJE001VUP0016ZE00<006ZfJ[H00fZf00<006ZfJ[H00VZf00D006Zf001Z]P0000AZ]P03
001^eVkF009^eP05001^eP00K]H00004K]H01@00K_I^mVkf00000fkf00D006kfK_I^mP0000=bmP04
001c5W<F0003LaH01000LaIc5P000g<G00D007<G001c=`00009c=`03001g=gLg00800005McL007Lg
McL00002MeL200001gMG001gEgMG001gE`00009gM`06001gMgMg001gM`000WMg00`007^H000007NH
001kV000NiP007^h0002NkP300001G^h001k^000MkP00`0000Egf000MmP007OH00D00003MoT007Oi
00800006LoT00000001WmP000g>I00<006mj00000P000U/L00<005;LD]`010000UKm00<005KmE_d0
10000UKm00<005KmE_d010000UKm00<005KmE_d00`0015Km0`0000=Fo@00E_d00eKm0`000UKm00<0
05KmE_d010000UKm00<005KmE_d010000UKm00D007ooOomoo`0002moo`00IWoo0`00L7oo0P000eKm
00<005KmE_d00`000eKm00<005Km00000UKm00@005KmE_eFo@<000=K7003001>oTkn00@000031GX0
00UI00<000032ET00000008000053ET000eI000AF@0300001AEH000000005EP00`0000<IF0006EP0
0P0000@MF0007EP0008QN009000QN25h000UN0009GP002Eg0080008YM`06000YM`00000]M`000Reg
00@002eg000]M`<00003<IL000000080008aU`03000eU`000080008eU`04000eUcFG0002>IH01000
>IHiUP000SVF100000@m]P00?KH000<m]P05000m]Sff?KH00002@KH01@00@KI1]T6f00000d6f00D0
047F@MI1eP0000=5eP040015eTGF0003AMH01@00AMI5eTGF00000dWF00D004WFBMI9eP0000=9eP03
0019mTWf0099mP030019mP00008000==m@03001=mDge009=m@05001=mDgeCOD00003COD01000COE=
mDge0P000e7e00<0057eDOD00U7e00<0058EDQD00U8E0`0000=B5@00DQD00e8E00<005HEEQD00eHE
0P000UHE00<005HEEQD00UHE00@005HEEQEF5@8000AF=@03001J=EXe009J=@03001J=EXe00=J=@04
001J=EXeFSD20004FSD01000FSEJ=@000Uhe00<005iEGUD00UiE00<005iEGUD00eiE00@005iEGUD0
009NE@03001NEEiE009NE@03001REF9E00=RE@8000=RM@04001RMF9e0003HWD01000HWERM@000V9e
00@0069eHWD0009VM@04001VUFJE0002IYD01000IYEVU@000VJE00<006JE000016JE0P0016ZE00<0
06ZfJ[H00VZf00<006Zf00000VZf00H006ZfJ[H006Zf0004J[H01@00K]I^eVkF00000fkF00<006kF
K]H00VkF00D006kF001^mP0000=^mP05001^mP00K_H00003L_H01@00L_H007<F00000W<F00D007<F
001c5P0000=c5`04001c5g<G0002LcL01000McMg=`000WLg00@007LgMcL0009gE`04001gEgMG0002
MeL01000MeMgE`000WMg0P0000IgM`00MgL007Mg0002NiP01@00NiP007^H00000W^H00P007^h001k
^000NkP007^h0`0000=g^000MmP00`0000Mgf000MmP007OH001gf00>00001W>I001_NP00Jk`000=K
70<0009Bo003001FoEKm00@0009Fo@03001FoEKm00@000=Fo@03001FoEKm00<000=Fo@03001FoEKm
008000AFo@06001Fo@00001Fo@000eKm0`000UKm00<005KmE_d010000UKm00<005KmE_d00`000Woo
00<007ooOol0;Goo001UOol2001dOol00`00E_eFo@030003E_d00`00E_eFo@020004E_d01@00E_d0
05Km000015/L0`000Tkm0`0000<5NP0000000P0000D9F@002CT000eI00<000033ET0015I00800008
5EP001EH000EF0005EP0008IF003000IF000008MF005000MF0008GP000028GP300029GP02@009GLU
M`00:GL002Ug000YM`0300001Beg000]Mbeg00000Reg0`000c6G00<0036G00000cFG10000SFG00L0
03VF>IHiUP00>IH00003>IH00`00>KHi]P050002?KH01@00?KHm]Sff00000T6f00D0046f@KI1]P00
00=1]P050011eT7F@MH00003AMH01000AMI5eP000dGF00D004GFAMI5eP0000=9eP050019eTWFBMH0
0004BMH00`00BOH000030002BOD00`00COE=m@02COD01@00COE=mDge00000dge00<004geCOD00Tge
0`0000==m@00DOD00e7e00D0057eDOEAm@0000=B5@8000=B5@03001B5E8E009B5@03001F5EHE009F
5@8000AF5@05001F5EHEEQD00002EQD00`00EQD00004ESD01`00FSEJ=EXe001J=@0000AJ=@06001J
=EXe001J=@001EXe0P000ehe00<005iEGUD00UiE00<005iEGUD00eiE00@005iEGUD0009NE@04001N
EEiEGUD20005HUD00`00HWERM@03HWD20004HWD00`00HWD00003HWD00`00HWD00003IWD00`00IYD0
0004IYD20004IYD20004IYD00`00JYEZU@02JYD00`00J[D00003J[H01P00J[IZ]P00J[H000=Z]P03
001Z]VZf009Z]P05001^eP00K]H00004K]H00`00K]I^eP02K]H01@00K]H006kf00000fkf00D006kf
001^mP0000=bmP05001bmP00LaH00002LaH01000LaIc5P000g<G00@007<GLaMc5`800005LcL007Lg
McL00002McL01000McMg=`000WMG00<007MGMeL00P0000AgE`00MeL0009gM`06001gMgMg001gM`00
0WMg00<007^H00000W^H0`0000QkV000NkP007^h001k^0000W^h00<007^h00000P0000=gf0000000
0P0000Egf000MmP007OH00800006MoT00000MoT007?i0`0000Mcn000NkQk^000KgX00003Jk`30000
0eKl001Bo002D_`30003E_d00`00E_eFo@030003E_d00`00E_eFo@040002E_d00`00E_eFo@040002
E_d00`00E_eFo@030004E_d300000eKm001Fo@02E_d30002E_d00`00E_eFo@040003E_d01000Oomo
o`00;Woo001VOol00`00Oomoo`1cOol20002E_d00`00E_eFo@040002E_d00`00E_eFo@030003E_d0
1000Fa`000000UlL00<004kmC_d01@0000<5F@002ET00`0000H9>@00000=>@003ET300001A5H0000
00005EP00`0000HEF000000IF0006EP3000011eH000000000b5h0`0000@UN0009GLUM`<0008YM`03
000YMbUg00<0008]M`@00003<GL00000008aU`04000aUc6G0002=IL00`00=ILeU`040003>IH01000
>IHiUP000SVF00D003Vf>KHi]P00008m]P<00005?KH003ff?KH00002@KH01@00@KI1]T6f00000d6f
00D0047F@MI1eP0000=5eP040015eTGF0003AMH01@00AMI5eTGF00000dWF00<004WFBMH00TWF00<0
04WF00000`000TWE00D004WeBOE9m@0000A=m@05001=mDgeCOD00003COD01000COE=mDge0P000dge
00<0057eDOD00U7e00D0057eDOEAm@00009B5@03001B5@0000AB5@05001B5E8EDQD00002EQD20000
0eHE001F5@03EQD00`00EQEF5@02EQD20003EQD01@00ESEF=EHe00000UXe00@005XeFSD000AJ=@03
001J=@0000=J=@03001J=EXe009J=@03001N=Ehe009N=@07001NEEiEGUD005iE000015iE00<005iE
00000eiE00@005iEGUD0009NE@03001REF9E009RE@03001RMF9e00=RM@03001RMF9e00=RM@03001R
M@0000ARM@8000AVM@8000AVU@03001VUFJE00=VU@03001VUFJE00=VU@03001ZUFZE009ZU@03001Z
]@00009Z]P07001Z]VZfJ[H006Zf00000fZf00<006ZfJ[H00VZf00D006kF001^eP0000=^eP03001^
eP00009^eP05001^eVkFK]H00003K_H01@00K_I^mVkf00000g;f00D007;fL_IbmP00009c5P05001c
5W<FLaH00002LaL01@00LaMc5g<G00000W<g00@007LgMcL0009g=`07001g=`00McL007MG00000WMG
00H007MGMeL007MG0002MgL01000MgMgMgMg0`0000YgM`00NiQkV000NiP007^H001kV0800003NkP0
07^h0080009k^006001k^000NmP007OH0`0000Igf000001gf000MmP200001WOi000007Oi001cn@<0
0006LoP00000NkP007OI0P000V^l0P0015Kl00D005;l001Fo@0000AFo@<0009Fo@03001FoEKm00@0
009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00<000AFo@<00003E_d005Km
009Fo@<000=Fo@03001FoEKm00<0009oo`03001oogoo02]oo`00IWoo00<007ooOol0M7oo00<005Km
E_d00`000eKm00<005KmE_d00`000eKm00<005KmE_d00`000elL0`0000M>V`000000004i0005F@02
00000`Ti0009>@0300000`di0000000200002a5H000A>0005EP001EH000EF0005EP00P0000@IF000
6EP0008MF0<0008QN003000QF000008000<UM`<00006:GL002Ug:GL002Ug0`0000@]M`00;GL0008a
M`800005<IL0036G<IL00002=IL01P00=ILeUcFG000eUP80008iUP04000iUSVF0003>IH01000>KHi
]P000Sff00<003ff?KH0100000Dm]P00@KI1]P000091]P050011]T6f@KH00003@MH01@00AMI5eTGF
00000TGF00D004GFAMI5eP0000A5eP060019eTWFBMH004WF10000TWE00D004WEBME9e@0000A9m@05
001=mDgeCOD00003COD00`00COE=m@02COD300000dge001=m@03COD01@00DOEAmE7e0000157e0P00
0U8E00<0058EDQD00U8E00<0058EDQD00U8E0P000eHE00<005HEEQD00UHE00<005HEEQD00UHE00<0
05HEEQD00UHE00<005HeESD00UHe0P000eXe00<005XeFSD00eXe00<005XeFSD00UXe00<005XeFSD0
0UXe00<005heGSD00Uhe00@005iEGUD0009NE@03001NEEiE00=NE@03001NEEiE009NE@04001NEEiE
0002GUD01000HUEREF9E0P001F9e00<0069eHWD0169e00<0069eHWD00f9e00<006IeIWD00fIe00<0
06JEIYD00fJE00<006JEIYD00fJE00<006JEIYD00VJE00<006JE00000VZE00L006ZeJ[EZ]@00J[H0
0004J[H01`00J[IZ]VZf001Z]P00009Z]P05001^eVkFK]H00004K]H01@00K]H006kF000016kF00@0
06kfK_H000A^mP05001bmW;fL_H00003L_H01000LaIc5P000W<F00D007<F001c5`0000=c5`06001c
=g<g001g=`000gLg00@007LgMcL0009gE`04001gEgMG0002MeL00`00MeL00002MgL02000MgMgM`00
MgL007]g0002NiP01@00NiP007^H00000W^H00d007^h001k^000NkP007^h001k^000NmP00002MmP2
00000gOH00000002000017OH000007Oi0P0000=gn@00LoT00`0000Ecn000001k^000009gf@@0009O
OP03001Fo5Kl00<000=Fo@06001Fo@00001Fo@000eKm0`000UKm00<005KmE_d010000UKm00<005Km
E_d010000UKm00<005KmE_d010000eKm00<005KmE_d00P0015Km00D005Km001Fo@0000AFo@<0009F
o@04001oogoo000]Ool006Eoo`03001oogoo07Ioo`8000=Fo@03001FoEKm00<000=Fo@03001FoEKm
00<000=Fo@05001O7000Fa`00003CY/300001P4i000000Di0009>@@000053CT000dh000=>0030000
1A4h000EF0005EP00`000QEH00P001UH000IF0007EP001eH0P0000DQN0008EP0025H0080008UM`03
000UM`0000800005:GL00000000YM`02000022eg000]Mbeg000aM`00<IL300000c6G000eU`02=IL0
1000=ILeU`000SFF0`0000@iUP00>IH000<iUP07000i]SVf>KH003ff00000cff00<003ff?KH01`00
00=1]P00@KH00T6f00D0047F@MI1eP0000=5eP040015eTGF0003AMH00`00AMH000070002BMD01@00
BME9eDWE000014WE00D004WeBOE9m@0000==m@05001=mDgeCOD00003COD20003COD00`00COE=m@02
COD01@00DOEAmE7e00000e7e0P00158E00D0058EDQEB5@0000AB5@03001F5EHE00=F5@05001F5EHE
EQD00003EQD20004EQD00`00ESEF=@02ESD00`00FSEJ=@03FSD00`00FSEJ=@02FSD00`00FSEJ=@02
FSD01000FSEJ=EXe0P001Ehe0P000eiE00<005iEGUD00eiE00<005iEGUD00eiE0P000eiE00@0069E
HUD0009RE@07001RMF9eHWD0069e00001F9e00<0069eHWD00f9e00<006IeIWD00fIe00<006JEIYD0
0VJE0P0016JE00<006JE00000fJE00D006JE001ZU@0000AZ]@03001Z]P0000AZ]P05001Z]VZfJ[H0
0002J[H00`00J[H00003K]H00`00K]I^eP02K]H01@00K]H006kF00000fkF00D006kf001^mP0000=^
mP05001bmP00L_H00003L_H01@00LaH007<F00000W<F00@007<FLaH000=c5`05001c=g<g001g=`02
0002McL01000McMg=gLg0P0000AgE`00MeL0009gE`06001gM`00001gM`000WMg00<007Mg00000W]g
0P0000QkV000NiP007^H001kV0000W^h100000Ak^000NkQk^080009gf080009gf0X00004MoT00000
LoT300000gOh00000002MmT2000015om001OOUmn10000UKm00<005KmE_d00`0015Km0`0000=Fo@00
E_d00UKm0`000eKm00<005KmE_d00`000eKm00<005KmE_d00`000eKm00<005KmE_d010000UKm00<0
05KmE_d00`000eKm00H005Km000005Km0003E_d20002Ool00`00Oomoo`0ZOol006Eoo`03001oogoo
07Moo`03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00<000=K7005001>VdjK000=
>00500001PDi000000Di0009>@<000063CP000003CP0014h0`0000<EF0005CP00P0000DEF0000000
01UH00<000037EP001eH00<000038EP0025H008000039GL002Eg00@0008YM`04000YM`00;GL20002
;GL01000<GLaM`000S6G10000SFG00L003FG=ILeU`00=IH00002=IH40003>IH01@00>KHi]SVf0000
0Sff00@003ff?KH000<m]P04000m]Sff0002@KHF0002AMH01@00BMI9eTWF00000dWE00<004WEBMD0
0TWE00D004WEBME9e@0000=9m@05001=mDgeCOD00004COD300000dge001=m@03COD01@00COE=mDge
00000e7e00H0057eDOD0057e0004DQD01@00DQEB5E8E00000e8E0P001EHE00D005HEEQEF5@00009F
5@03001F5@0000AF5@04001F=EHeESD20005FSD01000FSEJ=EXe0P0015Xe00@005XeFSD0009J=@03
001N=Ehe009N=@03001NEEiE00=NE@04001NEEiEGUD20005GUD00`00GUENE@02GUD01000HUERE@00
0V9E00@0069eHWD0009RM@03001RMF9e009RM@03001RM@0000=RM@8000AVM@03001VU@0000=VU@03
001VU@0000=VU@03001VU@00009VU@06001VUFJE001ZU@001FZe00<006ZfJ[H00VZf00D006Ze001Z
]P0000=Z]P03001Z]P00009^eP03001^eP00009^eP05001^eVkFK]H00004K]H01000K_I^mP0016kf
00D007;f001bmP0000=bmP04001c5W<F0002LaH01@00LaIc5W<F00000W<G00L007<gLcMc=`00McL0
0002McL01@00McMg=gLg00000WMG00<007MG00000WMG00H007MgMgL007Mg0003MgL01@00MgL007]g
00000W^G00L007^H001kV000NiP00002NkP01000NkP007^h0`0000=k^00000000WOH0P000WOH0P00
00Igf000001gn000MoP200000g?h00000008000017OI000005om10000U;m00<005KmE_d010000UKm
00<005KmE_d00`0015Km00D005Km001Fo@0000AFo@<0009Fo@03001FoEKm00@0009Fo@03001FoEKm
00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00<000AFo@<00003E_d007oo009oo`03001oogoo
02Uoo`00IGoo00<007ooOol0N7oo0P000eKl00<005KmE_d00`000eKm00<005KmE_d00`000eLM00<0
05/LFa`0100000<=>00000000`0000D5>@00000000Di008000032CP000dh00<000033CP0014h0080
008EF003000E>000008EF080008IF0<000047EP001eH7EP300000b5H000UE`0500001BEg000002Ug
00000RUg00<002eg;GL00`000S5g00@0036G<IL0008aU`800003=IL003FG008eU`03000eUP0000<e
UP04000iUP000002>IH01@00>KHi]SVf00000Sff00D003ff?KHm]P00008m]P05000m]Sff?KH00002
@KH01@00@KI1]T6f00000d6f00D004FfAKI5]P000095eP050015eTGFAMH00003AMH01@00BMI9eTWF
000014WE00D004WEBME9e@0000=9e@050019mDWeBOD00004COD00`00COD000020003COD00`00COE=
m@02COD01@00COE=mDge0000157e0P000U7e00<0058EDQD00U8E00D0058EDQEB5@00009B5@03001F
5@0000EF5@03001F5EHE009F5@8000=F5@05001F5EHEEQD00002ESD00`00FSD00005FSD01000FSEJ
=@000UXe00<005XeFSD00UXe0P000eXe00<005heGSD00Uhe00<005iEGUD00eiE00@005iEGUD0009N
E@03001NEEiE009NE@03001NEEiE00=NE@8000=RE@04001RMF9e0003HWD01000HWERM@000V9e00@0
069eHWD0009VM@07001VMFIeIWD006JE00000VJE00@006JEIYD0009VU@06001VUFJE001VU@0016JE
00<006ZeJ[D016Ze00<006ZfJ[H00VZf00D006Ze001Z]P0000AZ]P05001^eVkFK]H00002K]H00`00
K]H00003K]H01@00K]I^eVkF00000fkf00D006kfK_I^mP0000=bmP05001bmW;fL_H00003LaH01000
LaIc5P000W<F00D007<F001c5`00009c=`03001g=gLg00800005McL007LgMcL00003MeL00`00MeL0
0002MeL00`00MgL00002MgL2000017Mg001gM`000W]g00<007^GNiL00`0000ekV000NiP007^h001k
^000NkP007^h001k^00300001GOH001gf000MmP00P0000Igf000001gn000MoP200000g?h001cn003
00001W?i000007Oi001cnP@000=K7@03001BoE;m00<000=Fo@03001FoEKm00<000=Fo@03001FoEKm
00<000=Fo@06001Fo@00001Fo@000eKm0`000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm
00<005KmE_d010000UKm00<005KmE_d00`0015Km00@007ooOol002]oo`00IGoo0`00NGoo00@005Kl
E_aFo0<000=Fo@03001FoEKm00<000=Fo@03001G7ELM00<00004B_d003iK?U/500000`4i00000002
00001`Di000000002CP000dh008000053CP00000000A>00300025CP300001AUH000000006EP00P00
00HMF0007EP0025H00028EP200001bEG000UM`009GL002Ug00<00006:GL002eg;GL002eg0P000S5g
00<0036G00000S6G00<0036G00000P000SFG00@003FF=IH0008eUP03000iUSVF00<00005>IH003Vf
>KH00002?KH01@00?KHm]Sff00000cff00@003ff?KH00091]P050011]T6f@KH00003@KH01@00AKI5
]TFf00000dGF00@004GFAMH000A5eP050019eTWFBMH00003BMD01@00BME9eDWE00000dWE00D004We
BOE9m@0000==m@<0009=m@03001=mDge009=m@05001=mDgeCOD00003COD01000DOEAmE7e0P00157e
00D0058EDQEB5@0000AB5@8000=F5@03001F5EHE009F5@04001F5EHEEQD20004EQD00`00EQEF5@02
EQD20003FSD00`00FSEJ=@03FSD20003FSD00`00FSEJ=@02FSD00`00FSEJ=@02FSD01000GSEN=Ehe
0P001EiE00<005iE00000eiE00@005iEGUENE@8000ENE@03001REF9E00=RE@8000ARM@04001RMF9e
0002HWD01000HWERM@000VIe00@006IeIWD0009VU@03001VU@0000=VU@03001VU@0000AVU@8000AV
U@03001Z]FZe00=Z]@03001Z]@00009Z]P06001Z]FZe001Z]P0016Zf00@006kFK]H000=^eP03001^
eP00009^eP05001^eP00K]H00003K_H01@00K_H006kf000017;f00@007;fL_H000=c5P05001c5P00
LaH00002LaH01000LaIc5P000W<g00@007LgMcL0009g=`05001g=gLgMcL00002MeL01P00MeL00000
MeL0009gM`03001gM`00009gM`800004MgL007]g0002NiL01`00NiL007^G001kV000009k^0800004
NkP007^h0002NkP200001g_H00000000MmP007OH00<00003MoP0000000800003LoP007?h00<0000;
LoT00000MoT007?j001[nP00Km`00002Fad40002D]`00`00E_eFo@040002E_d00`00E_eFo@040002
E_d00`00E_eFo@030004E_d300000eKm001Fo@02E_d30002E_d00`00E_eFo@040002E_d00`00E_eF
o@040003E_d00`00E_eFo@030003E_d00`00E_eFo@020003Ool00`00Oomoo`0XOol006Aoo`8007ao
o`05001Fo000Ead00004E_d30002E_`00`00E_eFo@040002Dad02@00B_e:o@00?U/001EH0000M003
00000`4i0005>@0400001@Th000000002CP0100000@A>0004CP0008E>00:000E>0006EP001UH000I
F0007EP200027EP500029EL300029GL00`00:GLYM`030003;GL01P00;GL00000<GL0008aU`04000a
Uc6G0002<IL200001CFG000eUSFF00000cFF00<003VF00000SVF100000@i]P00?KH000<m]P05000m
]Sff?KH00002?KH01@00@KI1]T6f00000d6f00D0046f@KI1]P0000=5]P040015eTGF0003AMH01@00
AMI5eTGF00000dWF00D004WEBME9e@0000=9e@050019eDWEBMD00004BOD300000dge001=m@02COD0
0`00COE=m@02COD01@00COE=mDge000014ge0`0000=Am@00DOD00e7e00D0058EDQEB5@0000=B5@80
00AF5@03001F5EHE009F5@06001F5EHE001F5@0015HE00<005HEEQD00UHE00<005XeFSD00UXe00<0
05XeFSD00eXe00<005XeFSD00UXe00<005XeFSD00UXe00<005XeFSD00UXe00@005heGSD0009N=@03
001NEEiE00=NE@03001NEEiE009NE@04001NEEiE0002GUD00`00GUENE@02GUD00`00HUERE@03HUD0
0`00HWERM@03HWD00`00HWD00004HWD20003IWD00`00IWD00004IYD20004IYD20004IYD00`00IYEV
U@02IYD00`00JYD00004J[D01@00J[D006Zf000016Ze00<006ZfJ[H00VZf00D006kF001^eP0000A^
eP09001^eVkFK]H006kF001^eP0000=^mP05001^mP00K_H00003L_H01@00L_H007;f00000g<F00@0
07<FLaH0009c5P04001c5W<FLaH200001G<g001g=gLg00000WLg0P0000Eg=`00MeMgE`00009gE`03
001gE`00009gM`04001gMgMg0002MgL01@00NgL007]g00000W^G00<007^G00000W^G0`0000Uk^000
NkP007^h001k^000NkP00P000W_H00<007OH00001P0000=gn00000000`0000Ecn000000007?i0080
0006MoT007?j001[nP000VoL0`000UKL00<005;LD]`010000UKm00<005KmE_d010000UKm00<005Km
E_d010000UKm00<005KmE_d00`0015Km0`0000=Fo@00E_d00UKm0`000eKm00<005KmE_d00`000eKm
00<005KmE_d010000UKm00<005KmE_d010000UKm00D007ooOomoo`0002Uoo`00IGoo00<007ooOol0
Ngoo00H005LMEaeG7@00E_d200000eKm001Fo002E_`30003E_`00`00DaeC7@040002?U/00`005EP0
000200000`4H0001>@0200000`Dh0005>00400001@Th0009>0003CP00`0000dA>000000E>0005CP0
01UH000IF0006EP000027EP30000125H000000000bEG0`0000HUM`00:GLYM`00:GL20002;GL01000
;GL002eg0P000S6G00@0036G<IL0008aU`03000eUP0000800003=IH003FF008eUP03000iUP0000<i
UP03000iUSVF00D0008m]P05000m]Sff?KH00003?KH01000@KI1]P000d6f00D0046f@KI1]P0000=5
]P040015eTGF0003AMH01@00AMI5eTGF00000dWF00D004WEBME9e@0000=9e@030019eDWE0099e@03
0019m@00008000==m@03001=mDge009=m@05001=mDgeCOD00003COD01000COE=mDge0P000e7e00<0
057eDOD00U7e00<0058EDQD00U8E00D0058E001B5@0000AF5@03001F5EHE00=F5@80009F5@03001F
5EHE009F5@04001F5EHEEQD20004FSD00`00FSEJ=@02FSD20004FSD01000FSEJ=EXe0P001EXe0P00
0ehe00<005iEGUD00eiE00<005iEGUD00UiE00@005iEGUD0009NE@04001NEEiEGUD20005HUD00`00
HWERM@04HWD00`00HWERM@03HWD00`00IWEVM@03IWD20004IYD00`00IYEVU@03IYD00`00IYEVU@03
IYD00`00IYEVU@02IYD00`00JYD00003J[D01P00J[EZ]@00J[H000AZ]@03001Z]VZf009Z]P05001^
eP00K]H00004K]H01000K]I^eP000fkF00D006kfK_I^mP0000=^mP03001bmW;f009bmP04001bmW;f
0003LaH01`00LaIc5W<F001c5P0000=c5P04001g=WLf0002McL01000McMg=`000WLg00L007MGMeMg
E`00MeL00002MeL2000017Mg001gM`000WMg00H007]gNgL007]g0002NiL02000NiL007^G001kU`00
NkP300003g^h001k^000NkP007_H001kf000MmP007OH001gf00300000gOh0000000<00001G?j0000
0000Km`00P0000AOO@00E]aFg0@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@000=Fo@03001F
oEKm00<000=Fo@03001FoEKm008000AFo@05001Fo@00E_d00004E_d30002E_d00`00E_eFo@040002
E_d00`00E_eFo@040002E_d00`00E_eFo@030002Ool00`00Oomoo`0WOol006Aoo`03001oogoo07eo
o`03001G7ELM00<000=Fo@03001Fo000009Fo004001Fo5KlE_`30003D_d900001P4H0000004H0005
>08000031CP000Th00<000082CP000003CP0014h000A>08000055CP00000000IF006000011eH000Q
F25H0`000REG00<002EG00000P000bUg00H002Ug000002eg0002;GL00`00;GL]M`030003<IL00`00
<IL00003=IH40002=IH01000>IHiUP000SVF00D003VF>IHiUP00008iUP<00005?KH003ff?KH00003
?KH01000@KI1]P000d6f00D0046f@KI1]P0000=5]P050015eTGFAMH00002AMH01@00AMI5eTGF0000
0dWF00D004WEBME9e@0000A9e@030019e@0000<00099m@03001=mDge009=m@05001=mDgeCOD00003
COD00`00COE=m@02COD300000dge001Am@03DOD01@00DOEAmE7e0000158E0P000e8E00<005HEEQD0
0UHE00<005HEEQD00UHE00<005HEEQD00UHE00D005HEEQEF5@00009F5@03001F5@0000AJ=@07001J
=EXeFSD005Xe000015Xe00@005XeFSD0009J=@03001J=EXe009J=@03001N=Ehe009N=@03001NEEiE
009NE@8000ENE@8000=NE@04001NEEiE0002GUD01`00HUEREF9E001RE@0000ERM@03001RMF9e00=R
M@03001VMFIe00=VM@03001VUFJE00=VU@03001VUFJE00=VU@03001VUFJE009VU@03001VU@0000=V
U@06001ZUFZE001Z]@0016Ze00<006ZeJ[D00VZe00<006Ze00000VZf00D006kFK]I^eP0000A^eP05
001^eP00K]H00003K]H01@00K_I^mVkf00000fkf00D007;fL_IbmP0000=bmP04001c5W<F0003LaH0
1000LaH000000g<F00@007LfMcH0009g=`04001g=gLg0002McL200001gMG001gEgMG001gE`00009g
M`06001gMgMg001gM`000W]g00`007^G000007^G001kU`00NiL007^G0002NkP00`00NkP000020000
37^h000007_H001kf000MmP007OH001gf0<00005MoP007Oh001gn00200000g?h00000002000017?i
000007?i0`0000=Wm`0000000Umm0`000eKm00<005KmE_d00`000eKm00<005KmE_d00`000eKm00<0
05KmE_d010000UKm00<005KmE_d010000UKm00<005KmE_d00`000eKm00H005Km000005Km0003E_d3
0002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d01@00Oomoogoo0000:7oo001TOol00`00
Oomoo`1nOol20003Ech00`00E_eFo@020004E_`00`00E_`00002F_`00`00D_eBo@0400000aGL0000
000200000`3h0000000200000`4H0000000200001PDh000000Th0009>0<000063CP00000000A>000
0QDh1P000aeH00H001eH000QF0008EL200001BEG000UE`009EL00P000RUg00@002Ug000YM`<00006
;GL002eg;GL002eg0P000S6G00@0036G<IL0008eUP03000eUSFF00800005=IH003VF>IH00003>IH0
1000>IHiUP000SVF00<003ff?KH0100000Dm]P00?KHm]P000091]P050011]T6f@KH00003@KH01@00
AKI5]TFf00000dGF00@004GFAMH000=5eP050019eTWFBMH00004BMD00`00BMD000030002BMD01@00
BOE9mDWe000014ge00D004geCOE=m@0000==m@04001=mDgeCOD20003COD00`00DOEAm@02DOD01@00
DOEAmE7e00000e8E0P00158E00<005HEEQD00UHE00@005HEEQEF5@8000AF5@03001F5EHE009F5@80
00=F5@05001J=EXeFSD00002FSD01@00FSEJ=EXe000015Xe0P000eXe00<005XeFSD00UXe00<005he
GSD00Uhe00D005iEGUENE@00009NE@03001NEEiE009NE@03001NEEiE009NE@04001NEEiE0002GUD0
1000HUERE@000V9E00<0069eHWD00V9e0P00169e0P001FIe00<006JEIYD00VJE0P0016JE00<006JE
00000fJE00<006JE00000VJE00L006ZEJYEZU@00J[D00004J[D00`00J[EZ]@02J[D01@00J[D006Zf
000016kF00<006kFK]H00VkF00D006kF001^eP00009^eP05001^mP00K_H00003K_H01@00L_H007;f
00000g;f00D007<F001c5P0000=c5P03001c5P0000=c5P0:001g=WLf001g=P00McL007Lg0002McL0
1000MeMgE`000WMG00@007MGMeL0009gM`800004MgL007Mg0002NgL01000NiL007^G0P0000ekU`00
NiL007^G001k^000NkP007^h001k^003000027_H000007OH001gf000MmP300001GOh001gn000MoP0
0P0000=cn00000000P0000=cn@0000000W?i0P0000=Wm`00Go/00`0000=Bo@00E_d00eKm0`000UKm
00<005KmE_d010000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm
00<005KmE_d00`0015Km0`0000=Fo@00E_d00UKm0`000UKm00<005KmE_d010000UKm00<005KmE_d0
0`000goo00<007ooOol09Goo001TOol00`00Oomoo`20Ool60002D_d00`00E_aFo0030003F_`30002
C_d01P004O`001GL0009NPH000030AP00000008000071CP000000009>0002CP00P0000<=>0003CP0
0P0000<A>00000001@0000HIF000000MF0007EP300000b5G000QE`0300000bEG000UE`0200001BUg
000YMbUg00000RUg0`000beg00<002eg00000`000S6G00@003FF=IH0008eUP03000eUP0000800003
>IH003VF008iUP07000iUSVF>IH003VF00000cff00<003ff?KH0100000Dm]P00@KI1]P000091]P05
0011]T6f@KH00003AKH01@00AMI5eTGF00000TGF00<004GFAMH00TGF00H004WFBMI9eP00BMD40002
BMD01@00BME9eDWE000014We00D004geCOE=m@0000==m@03001=mDge009=m@<00003COD004ge00==
m@05001AmE7eDOD00004DOD300000e7e001B5@03DQD00`00EQEF5@02EQD01P00EQEF5@00EQD000AF
5@03001F5EHE009F5@03001F5EHE009F5@03001J=EXe009J=@8000AJ=@03001J=EXe009J=@03001J
=EXe009J=@04001J=EXeFSD20004GSD01000GUENE@000eiE00<005iEGUD00UiE00<005iEGUD00eiE
0P000eiE00@0069EHUD0009RE@03001RMF9e009RM@03001RM@0000=RM@03001RM@0000=VM@03001V
M@0000=VU@03001VU@0000=VU@03001VU@00009VU@07001VUFJEIYD006JE000016ZE00<006ZeJ[D0
0VZe00<006Ze00000VZe00H006ZeJ[D006Zf0003K]H00`00K]H00002K]H01@00K]I^eVkF00000fkF
00D006kf001^mP0000=^mP05001bmP00L_H00003L_H01000LaIc5P000g<F00@007<FLaH0009c5P05
001g=WLfMcH00002McH01000McMg=`000WLg00<007MGMeL00P0000AgE`00MeL0009gM`06001gMgMg
001gM`000W]g00<007^G00000W^G00d007^G001kU`00NiL007^h001k^000NkP00002NkP200000g_H
0000000200000gOH001gf00200001WOh000007Oh001gn0800003LoP0000000800003LoT00000009c
n@800006IoL00000001K?@000e;m00H005Km000005Km0003E_d30002E_d00`00E_eFo@040002E_d0
0`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@030004E_d3
00000eKm001Fo@02E_d30003E_d00`00E_eFo@030003E_d01000Oomoo`009goo001TOol00`00Oomo
o`22Ool01000Acm7?`000U;m0`000e[l00<005[l00000e[l00D004kmC_d0017l00<000032GX00000
00L000030AP00000008000052CP000000009>00300003@dh000000004CP001Dh000E>0006EP001Th
0080008MF0<0000:8EL0025G8EL002EG000UE`009EL300001RUg000YMbUg000YM`80008]M`03000]
M`00008aM`@000<eUP03000eUP0000<eUP@0008iUP05000iUSVF>IH00002>IH01000?KHm]P000cff
00<003ff?KH01`0000=1]P00@KH00T6f00D004FfAKI5]P0000=5eP050015eTGF0015eP080002BMD0
1@00BME9eDWE000014WE00D004WeBOE9m@0000==m@05001=mDgeCOD00003COD20003COD00`00COE=
m@02COD01@00DOEAmE7e00000e7e0P00157e00<0058EDQD00U8E00<005HEEQD00UHE0P000eHE00D0
05HEEQEF5@0000=F5@8000AF5@03001J=EXe009J=@03001J=EXe00=J=@03001J=EXe009J=@03001J
=EXe009J=@04001J=EXe0002FSD00`00GSEN=@02GSD20004GUD01000GUENEEiE0P001EiE00<005iE
GUD00eiE0P00169E00@0069eHWD0009RM@04001RMF9e0002HWD01000IWEVM@000VIe00@006JEIYD0
009VU@04001VUFJE0002IYD00`00IYD00004IYD00`00IYD00004JYD00`00J[EZ]@02J[D01@00J[D0
06Ze000016Ze00<006kFK]H00VkF00D006kF001^eP0000A^eP04001^eVkF0003K_H01@00K_I^mVkf
00000g;f00D007;fL_IbmP0000=c5P04001c5W<F0002LaH01@00LaH007<F00000WLf00@007LfMcIg
=P800004McL007Lg0002MeL01P00MeMgE`00MeL000=gM`03001gMgMg0080009kM`06001kUg^G001k
U`000W^G0`0000=kU`0000000W^h00@007^h001k^080009kf0800003MmP0000000L00004MoP00000
LoP200000g?h0000000400000g?i000000030003Fcd60004E_d300000eKm001Fo@02E_d30003E_d0
0`00E_eFo@030003E_d00`00E_eFo@030003E_d00`00E_eFo@030003E_d00`00E_eFo@030003E_d0
0`00E_eFo@020004E_d01@00E_d005Km000015Km0`000UKm00<005KmE_d00`0000=oo`0000009Woo
001TOol00`00Oomoo`020021Ool50003D_d00`00F_aJo0020004F_`700001P4i0000004H00016080
00030AP0004H008000030AP000DH00@000032CP00000008000093CP00000000A>0005CP001Dh00<0
008I>004000MF0007EL200000b5G000QE`0300029EL00`009ELUE`030002:GL00`00:GLYM`020000
12eg000]M`000c5g00@0035g0000008eUP04000eUSFF0002=IH00`00=IHeUP0200000cVF000iUP02
>IH01000>IHiUP000cff00@003ff?KH000<m]P040011]T6f0002@KHB0002AMD01@00BME9eDWE0000
0dWE00<004WEBMD00TWE00D004WEBME9e@0000=9m@05001=mDgeCOD00004COD300000dge001=m@03
COD01@00COE=mDge00000e7e00H0057eDOD0057e0004DOD00`00DQEB5@02DQD01000EQEF5EHE0P00
15HE00D005HEEQEF5@00009F5@03001F5@0000AF5@04001J=EXeFSD20005FSD01000FSEJ=EXe0P00
15Xe00@005XeFSD0009J=@03001N=Ehe009N=@03001NEEiE00=NE@04001NEEiE0002GUD00`00GUEN
E@02GUD00`00GUENE@03GUD00`00HUERE@03HUD00`00HWD00003HWD00`00HWD00003HWD01000IWEV
M@000VIe00<006JE00000fJE00<006JE000016JE0P001FJE00<006ZEJYD00VZE00<006Ze00000VZe
00H006ZeJ[D006Ze0004J[D01@00K]I^eVkF00000VkF00<006kF00000fkF00D006kF001^eP0000=^
mP04001^mVkf0004L_H01000L_IbmP000g<F00D007<F001c5P00009c5P04001c5W<F0002McH01@00
McIg=WLf00000WLg00<007Lg00000gMG00H007MGMeL007MG0002MgL01@00MgMgM`00NgL00P0000Ik
M`00NiL007^G0002NiL01000NiL007^g0`0000Uk^000NkP007^h001kf000NmP00P0000Egf000MmP0
07OH00800004MoP00000MoP>00001V_i000006oK001K?@800003E]`005;L009Bg003001FoEKm00<0
00AFo@<00003E_d005Km00=Fo@<0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001F
oEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00<000=Fo@06001Fo@00001Fo@000UKm1000
0UKm0P000Woo00<007ooOol08goo001TOol30024Ool01000<[lb_`000U;m10000U[l00@005[l0000
009Jo005001>oDkm0001V`0400000`4H0000000200001P4H0000004H0001608000031AP000TH00<0
00072CP000dh000=>0004CP00`0000<E>0005CP00P0000LI>000000001eG000ME`0200028EL30000
1REG000UEbEG000UE`80008YM`04000YM`00;GL300001Beg000aMc5g00000S5g0P0000DeUP00=IHe
UP00008eUP05000eUSFF000iUP030002>IH01000>IHiUP000cff00D003ff?KHm]P00008m]P040011
]T6f0003@KH01@00@KI1]T6f00000d6f00D004FfAKI5]P000095e@050015eDGEAMD00003BMD00`00
BME9e@02BMD01@00BME9eDWE00000dWE00D004WeBOE9m@0000A=m@03001=m@00008000==m@03001=
mDge009=m@05001=mDgeCOD00004DOD20002DOD00`00DOEAm@02DOD00`00DQEB5@02DQD01P00EQEF
5@00EQD000AF5@03001F5EHE009F5@8000=F5@05001F5EHEEQD00002FSD01000FSEJ=@0015Xe00@0
05XeFSD0009J=@03001J=EXe009J=@8000=J=@03001N=Ehe009N=@03001NEEiE00ANE@8000=NE@04
001NEEiEGUD20005GUD00`00HUERE@03HUD00`00HWD00004HWD20004HWD20004IWD20004IYD20004
IYD00`00IYEVU@04IYD00`00JYEZU@02JYD00`00J[D00002J[D01@00J[EZ]FZe000016Ze00<006Ze
00000VkF00D006kFK]I^eP0000A^eP05001^eP00K]H00002K_H01@00K_H006kf00000g;f00D007;f
001bmP0000=c5P04001c5W<F0002LaH01000LaIc5W<F0P0000=g=P00McH00WLf00H007LgMcL007Lg
0002MeL01P00MeMgE`00MeL0009gM`06001gMgMg001kM`000W]g0P0000QkU`00NiL007^G001kU`00
0W^g0P0000Ak]`00001k^0800003NmP007_H00800005MmP007OH001gf00200001WOh000007Oh001g
n0800003LoP0000000800003LoP0000000800003JoT00000009_f`8000AFg003001Bg5;L00<000=F
o@03001FoEKm008000AFo@06001Fo@00001Fo@000eKm0`000UKm00<005KmE_d010000UKm00<005Km
E_d010000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00<005KmE_d00`000eKm0`000UKm
00<005KmE_d00`000Woo00<007ooOol08goo001SOol00`00Oomoo`26Ool50003C_d00`00F_aJo002
0004F_`900000`4H0000000600000`4H00000005000010TH000000Th0`0000<=>0004CP00P000QDh
00<001Dh00000QTh0`0000PME`007ELME`008EL0025G0P0000HUE`009ELUE`009EL2000012Ug000Y
M`000beg00<002eg00000c5g00@0035g000aMP<00003=IH003FF008eUP03000eUP0000<iUP<00004
>IH003VF0003?KH01@00?KHm]Sff00000cff00@0046f@KH00091]P050011]T6f@KH00003@KH01@00
AKI5]TFf00000dGE00D004GEAME5e@0000=9e@050019eDWEBMD00003BMD01@00BME9eDWE00000dWe
00@004geCOE=m@<0009=m@03001=mDge009=m@05001=mDgeCOD00003COD01000DOEAmE7e0P00157e
00<0057eDOD00U7e00<0058EDQD00U8E0P000UHE00<005HEEQD00UHE00@005HEEQEF5@8000AF5@03
001F5EHE009F5@8000=J=@03001J=EXe00=J=@8000=J=@03001J=EXe009J=@03001J=EXe009J=@07
001N=EheGSD005he00001EiE00<005iEGUD00UiE00@005iEGUD0009NE@07001NEEiEGUD0069E0000
1F9E00<0069eHWD00f9e00<0069eHWD00f9e00<006IeIWD00fIe00<006JEIYD00fJE00<006JEIYD0
0fJE00<006JEIYD00fJE00<006ZE00000VZE00H006ZeJ[D006Ze0004J[D00`00J[EZ]@02J[D01@00
J[D006kF000016kF00D006kFK]I^eP0000=^eP05001^mVkfK_H00002K_H00`00L_IbmP02L_H01000
L_IbmP000g<F00D007<FLaIc5P00009c5P04001c5W<F0002McH01@00McIg=WLf00000WLg00<007Lg
00000WMG00H007MGMeMgE`00MeL200001gMg001gMgMg001kM`00009kM`05001kU`00NiL00002NiL0
1000NiL007^g0P000W^g00<007^g00000P0000Ikf000001kf000MmP2000017OH000007Oh0P0000=g
n000MoP00P0000=cn00000000P0000=cn00000000P0000I[n@00000006oK0002Hid00`00E]aFg004
0002E_d00`00E_eFo@040002E_d00`00E_eFo@030004E_d300000eKm001Fo@02E_d30002E_d00`00
E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d01P00
E_d00000E_d000=Fo@<0009Fo@05001oogooOol0000TOol006=oo`03001oogoo08Qoo`@0009>o@<0
009Jo006001Jo000001K70000dkm00<0005I00001@0000<160000?P00P0000<1600000000P0000@5
60001AP00089608000032AP000dh00<000044CP0000000025CP01`006CP001Tg000ME`00008ME`<0
00038EL0025G0080008UE`04000UE`00:GL20002:GL00`00;GL]M`030003<GL00`00<GL00003<GH3
0003=IH01000=IHeUP000SVF00<003VF>IH01@000Sff00D003ff?KHm]P0000<m]P040011]T6f0003
@KH01@00@KI1]T6f00000d6f00D004FfAKI5]P000095e@050015eDGEAMD00003BMD01@00BME9eDWE
00000dWE00D004WEBME9e@0000A9m@<00003COD004ge009=m@03001=mDge009=m@05001=mDgeCOD0
0004COD300000e7e001Am@03DOD00`00DOEAm@02DOD01000DQEB5E8E0P0015HE00D005HEEQEF5@00
009F5@03001F5@0000AF5@03001F5EHE009F5@03001J=EXe009J=@03001J=EXe00=J=@03001J=EXe
009J=@03001J=EXe009J=@03001J=EXe009J=@04001N=Ehe0002GSD00`00GUENE@03GUD00`00GUEN
E@02GUD01000GUENE@000UiE00L005iEGUENE@00HUD00005HUD00`00HWERM@03HWD00`00HWERM@03
HWD00`00IWEVM@03IWD00`00IYEVU@03IYD00`00IYEVU@02IYD00`00IYD00004IYD01@00JYD006ZE
000016Ze0P000fZe00<006Ze00000VZe00H006ZeJ[D006kF0003K]H01@00K]H006kF000016kF00@0
06kfK_H000=^mP05001bmW;fL_H00003L_H01000LaIc5P000g<F00D007<F001c5P00009c5P04001g
=WLf0002McH01P00McMg=gLg001g=`800007MeL007MGMeL007MG00000WMg0P0000AgM`00NgL0009k
M`03001kUg^G00<0000:NiL007^G001k]`00NkL007^g0002NkL200000g_H0000000200000gOH001g
f002000017Oh000007Oh0P0000Agn000001cn0<00004LoP00000LoT80002Hid40002E_d00`00E_eF
o@040002E_d00`00E_eFo@040002E_d00`00E_eFo@030004E_d300000eKm001Fo@02E_d30003E_d0
0`00E_eFo@030002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@030004E_d3
00000eKm001Fo@02E_d20003Ool00`00Oomoo`0QOol000Moo`@000ioo`<000moo`@000ioo`<000eo
o`H0011oo`03001oogoo08Yoo`@00003C_d005[l009Jo0<000=K7003001>oDkm00D000030AT0004H
00T000070AP00000000560002AP00`0000<960003CP00P0000@A>0004CP0008E>0<000046CL00000
00037EL30000125G000QEb5G0`0000@UE`00:GLYM`800006:GL002eg;GL002eg0P000S5g00@0035g
<GL0008aMP04000eUP000002=IH01000=IHeUP000SVF00D003VF>IHiUP00008iUP<00005?KH003ff
?KH00003?KH01000@KI1]P000d6f00D0046f@KI1]P0000=1]P050015]TFfAKH00002AMD01@00AME5
eDGE00000dWE00D004WEBME9e@0000=9e@030019eDWE0099e@030019m@00008000==m@03001=mDge
009=m@05001=mDgeCOD00003COD01000COE=mDge0P000e7e00<0057eDOD00U7e00<0057eDOD00U7e
00H0058EDQD0058E0004EQD00`00EQEF5@02EQD20002EQD00`00EQEF5@02EQD01000EQEF5EHE0P00
1EXe00<005XeFSD00UXe00<005XeFSD00UXe00@005XeFSEJ=@8000EJ=@8000=N=@03001NEEiE009N
E@8000ENE@8000=NE@04001NEEiE0002HUD00`00HUERE@02HUD20004HWD20004HWD20004IWD20004
IYD00`00IYD00003IYD00`00IYD00003IYD01P00JYEZU@00JYD000AZ]@03001Z]FZe009Z]@03001Z
]@00009Z]@05001Z]FZeJ[D00004K]H01@00K]H006kF00000fkF00D006kF001^mP00009^mP05001b
mP00L_H00003L_H01@00LaH007<F00000g<F00@007<FLaH0009c5P08001g=WLf001g=P00McH0009g
=`03001g=`00009gE`04001gEgMG0002MeL01P00MgMgM`00NgL0009kM`03001kM`00009kU`04001k
U`00NiL200000g^G001k]`020002NkL01000NkL000000W_H0P0000=kf00000005@0000=[n0000000
0`0000AOn`00000000=Bo@03001FoEKm00<000=Fo@03001FoEKm00<000=Fo@03001FoEKm00<000=F
o@03001FoEKm008000AFo@05001Fo@00E_d00004E_d30002E_d00`00E_eFo@030003E_d00`00E_eF
o@030003E_d00`00E_eFo@030003E_d00`00E_eFo@020004E_d01@00E_d005Km00000goo00<007oo
Ool08Goo0005Ool8000;Ool5000<Ool8000<Ool3000;Ool:000>Ool00`00Oomoo`2;Ool30002C_d0
0`00F_`00003F_`00`00FaaK70030003C_h300000`4I0000000300000`3h0000000400001P4H0000
00DH0009608000092AP00000000=>0004CP0014h008000055CP00000000I=`0300027EL01@007EL0
025G00000R5G00H002EG000002EG0002:GL30003;GL01P00;GL00000<GL0008aM`04000aMS5f0002
=IH200001CFF000eUSFF00000cVF00@003VF>IH0008iUP03000mUSfF00@00005?KH003ff?KH00002
@KH01@00@KI1]T6f00000d6f00D0046f@KI1]P0000=5]P050015eDGEAMD00002AMD01@00BME9eDWE
00000dWE00<004WEBMD00TWE00<004WE00000`000TWE00<004geCOD00Tge00D004geCOE=m@0000==
m@03001=mDge009=m@<00003COD0057e00=Am@05001AmE7eDOD00005DOD20002DQD00`00EQEF5@02
EQD00`00EQEF5@02EQD00`00EQEF5@02EQD01@00EQEF5EHE00000UHE00@005HEEQD000AJ=@04001J
=EXeFSD20004FSD01000FSEJ=@000UXe00<005XeFSD00UXe00<005heGSD00ehe00@005iEGUD0009N
E@03001NEEiE009NE@03001NEEiE009NE@03001NE@0000ARE@04001REF9E0002HWD01`00HWERMF9e
001RM@0000=RM@03001VM@0000=VM@03001VU@0000=VU@03001VU@00009VU@07001VUFJEIYD006JE
000016ZE00<006ZeJ[D00fZe00D006ZeJ[EZ]@00009Z]@03001Z]@0000AZ]@05001^eVkFK]H00003
K]H00`00K]I^eP02K]H01@00K]H006kf00000Vkf00D007;f001bmP0000=bmP04001c5W<F0003LaH0
1@00LaIc5W<F00000W<F00@007LfMcH0009g=P04001g=gLg0002McL00`00MeMgE`02000017MG001g
E`000WMg00<007]gNgL00P0000QkM`00NgL007^G001kU`000W^G00h007^G001k]`00NkL007^g001k
]`00NkL007_H0P0000Ekf000NmP007OH00800004MoP00000MoP2000017?h000007?h100000A_n000
001[n0L0009K?@03001BoE;m00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001F
oEKm00@0009Fo@03001FoEKm00<000=Fo@06001Fo@00001Fo@000UKm10000UKm00<005KmE_d01000
0UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00<005KmE_d00`000eKm00D007ooOomoo`00
029oo`001Goo0P0017oo0P002goo1@0037oo0P0017oo0P003Goo0P002goo0`001Goo0`003Goo00<0
07ooOol0S7oo00<0018M00000`0015[l0`000U/L2@0000<160000?P00`0000H0n0000?P0004H0002
0AP400000`TH0009600200001`dh000000004CP0014g008000055CL00000000I=`0200000aeG000M
E`0300038EL01@009EL002EG00000RUg00@002Ug0000008]M`04000]M`00;GL300000c5g000aMP02
<GH01000=IH003FF0`0000<eUP00>IH00SVF00L003VF>IHiUP00>IH00003?IH00`00?KHm]P040000
13ff0011]P000d6f00D0046f@KI1]P0000=1]P050015]TFfAKH00003AMD01000AME5e@000dWE00<0
04WEBMD00TWE00<004WE00000`000TWE00D004WEBME9e@0000A=m@05001=mDgeCOD00003COD01000
COE=mDge0P000dge00<0057eDOD00U7e00D0057eDOEAm@0000AAm@8000AB5@05001F5EHEEQD00003
EQD20004EQD00`00EQEF5@02EQD20003EQD00`00FSEJ=@02FSD01000FSEJ=@000UXe00<005XeFSD0
0UXe0P000eXe00<005XeFSD00UXe00<005heGSD00ehe00@005iEGUD0009NE@03001NEEiE009NE@03
001NEEiE00=NE@8000ARE@04001REF9E0002HWD01000HWERM@000V9e00@0069eHWD0009VM@04001V
MFIe0002IYD01000IYEVU@000fJE00<006JE00000fJE00<006JE000016ZE00<006ZeJ[D00VZe00<0
06Ze00000VZe00@006ZeJ[EZ]@8000=Z]@03001^e@00009^eP05001^eVkFK]H00003K]H01@00K]I^
eVkF00000fkf00@007;fL_H000=bmP05001c5W<FLaH00002LaH02`00LaIc5W<F001c5P00LaH007Lf
00000gLf0P0000Ag=`00McL0009gE`04001gEgMG0002MeL01P00MgMgM`00NgL0009kM`03001kM`00
009kU`05001kU`00NiL00002NiL5000027^g000007^g001kf000NmP200000g_H001gf002000017Oh
000007Oh0P0000Acn000001cn0@00004KoP00000JoP200000f_h000000020002Fcd40002D]`00`00
E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00
E_eFo@030003E_d30002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@040002
E_d00`00E_eFo@040002E_d00`00E_eFo@030003Ool00`00Oomoo`0OOol000Aoo`8000Ioo`8000Yo
o`D000]oo`8000Ioo`8000aoo`<001=oo`8000eoo`03001oogoo08eoo`<0009>o@04001Jo0000002
F_`00`00Fa`00002Ga`600000`3h0001600300000`3h0000n00300000`4H0001600400001`TH0000
00002AP000dh0080008A>00:000A=`005CL001Dg000I=`007CL3000011eG000000000R5G00<002EG
00000P000bUg00P002Ug000002eg000]M`000beg0`000c5f00<003FF00000cFF10000SVF00D003VF
>IHiUP00008iUP04000mUSfF0003?KH00`00?KHm]P050003@KH01000@KI1]P000d6f00D004FfAKI5
]P0000=5e@050015eDGEAMD00003BMD00`00BMD000030002BMD01@00BME9eDWE000014WE00D004ge
COE=m@0000==m@03001=mDge009=m@<00003COD004ge00==m@05001AmE7eDOD00004DOD01P00DOD0
0000DOD000AB5@05001F5EHEEQD00002EQD00`00EQD00004EQD00`00EQEF5@02EQD00`00EQEF5@02
EQD00`00FSEJ=@03FSD20003FSD00`00FSEJ=@02FSD00`00FSEJ=@02FSD01`00FSEJ=EXe001N=@00
00AN=@03001NE@0000=NE@04001NEEiEGUD20005GUD00`00HUERE@03HUD00`00HUD00003HWD00`00
HWD00003HWD00`00HWD00003IWD00`00IWD00003IYD00`00IYD00004IYD00`00IYD00004IYD00`00
JYEZU@02JYD00`00JYD00003J[D01@00J[D006Ze000016Ze00<006ZeJ[D00VZe00D006kE001^eP00
00=^eP03001^eP00009^eP05001^eVkFK]H00002K_H01@00L_IbmW;f00000g;f00P007<FLaH007<F
001c5P000g<F00@007<FLaH0009g=P04001g=WLf0002McH01000McMg=`000WMG00<007MGMeL00P00
00AgE`00MgL0009kM`03001kMg]g00<00006NiL007^G001kU`000W^G00H007^g001k]`00NkL30000
1W^g000007_H001kf0800004MmP00000MoP2000017Oh000007?h0P0000=cn00000000P0000=_n000
00001`0000A_f`000000009Fg004001Bg5;LD]`30002E_d00`00E_eFo@040002E_d00`00E_eFo@04
0002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d01P00E_d00000E_d000=Fo@<0009Fo@03
001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@05
001oogooOol0000QOol000Aoo`8000Ioo`8000]oo`<000aoo`8000Ioo`8000aoo`<001Aoo`8000]o
o`03001oogoo08moo`030001f`0000@000=Jo0800003Ga`000000080009>g@<000030?P0000000<0
00030?P0000000<000030AP00000008000031AP00000008000052AP00000000=600300024CL01`00
5CL001Dg000I=`00008M=`04000ME`008EL200001B5G000UE`009EL00P000RUg00@002Ug000YM`<0
0006;GL002eg;GL0035f0P000S5f00@003FF=IH0008eUP03000eUSFF00800003>IH003VF008iUP04
000iUSVF0003?IH01000?KHm]P000cff00<003ff?KH01`0000=1]P00@KH00T6f00D004FfAKI5]P00
00=5e@030015e@0000H00099e@050019eDWEBMD00004BMD01@00BME9eDWE00000dge00D004geCOE=
m@0000==m@8000==m@03001=mDge009=m@05001AmE7eDOD00004DOD20003DOD00`00DQEB5@02DQD0
0`00EQEF5@02EQD20003EQD01@00EQEF5EHE00000eHE0P001EHE00<005XeFSD00UXe00<005XeFSD0
0UXe00<005XeFSD00UXe00<005XeFSD00UXe00@005XeFSD0009N=@03001N=Ehe00=N=@03001NEEiE
009NE@04001NEEiE0002GUD00`00GUENE@02GUD00`00HUERE@04HUD00`00HWERM@03HWD20004HWD2
0004IWD20004IYD20005IYD00`00IYEVU@03IYD00`00JYEZU@02JYD00`00JYD00002J[D01P00J[EZ
]@00J[D000AZ]@05001Z]FZeJ[D00002K]D00`00K]H00003K]H01@00K]H006kF00000fkF00D006kf
001^mP00009bmP05001bmP00L_H00003LaH01000LaIc5P000g<F00@007<FLaIc5P800005McH007Lf
McH00002McH2000017Lg001gE`000WMG00<007MGMeL00P0000AgM`00NgL0009kM`04001kM`00NiL2
00002W^G001kU`00NiL007^g001k]`000W^g0P0000Eke`00000007_H00800004NmP00000MmP20000
17Oh000007Oh0P0000=cn0000000200000=[n0000000100000=SW@00E]`00eKL0`0000=Fo@00E_d0
0UKm0`000eKm00<005KmE_d00`000eKm00<005KmE_d00`000eKm00<005KmE_d00`000UKm00<005Km
E_d00`0015Km0`0000=Fo@00E_d00UKm0`000eKm00<005KmE_d00`000eKm00<005KmE_d00`000eKm
00<005KmE_d00`000eKm00<005KmE_d00P000goo00<007ooOol07Woo0003Ool20008Ool2000HOol2
0008Ool2000<Ool2000DOol2000;Ool01000Ool00000Sgoo0P0014km00@005[l001O7080009O70@0
0003CY/00000008000040?P000000?P500001P3h0000003h0001608000051AP000TH000960020000
0`dH000=5`0200001A4g000000005CL00`000Qdg0`0000<QE`008EL00`0000<UE`009EL00P0000@Y
M`00:GL000<YM`03000]M`00008]M`03000aMS5f00800005<GH003FF=IH00002=IH01@00=IHeUP00
=IH00`000SVF00@003VF>IH000<mUP05000m]Sff?KH00002?KH01000?KHm]P000d6f00<0046f@KH0
3`0000=5e@00AMD00TGE00D004WEBME9e@0000A9e@050019eDWEBMD00003BMD01@00COE=mDge0000
14ge0`0000==m@00COD00dge00D004geCOE=m@0000=Am@04001AmE7eDOD20005DOD01@00DQEB5E8E
00000eHE0P0015HE00D005HEEQEF5@00009F5@03001F5@0000EF5@04001J=EXeFSD20004FSD01000
FSEJ=EXe0P001EXe0P000ehe00<005heGSD00ehe00<005iEGUD00UiE00@005iEGUD0009NE@07001N
EEiEGUD005iE00001F9E00<0069eHWD00f9e00<0069eHWD00f9e00<006IeIWD00fIe00<006JEIYD0
0fJE00<006JEIYD016JE00<006JEIYD00VJE00<006JE00000VZE00H006ZEJYD006Ze0004J[D00`00
J[EZ]@02J[D00`00J[D00002J[D01@00K]E^eFkE00000fkF00H006kFK]H006kF0003K]H01@00K_H0
06kf00000W;f00D007;f001bmP00009c5P05001c5W<FLaH00002LaH01@00LaIc5W<F00000WLf00@0
07LfMcH0009g=P04001g=WLf0002MeL01000MeMgE`000WMG00D007]g001kM`00009kM`03001kM`00
009kU`05001kU`00NiL00002NiL01000NkL000000W^g0P000W_G0P0000=ke`0000003`0000=cn000
00000P0000A_n000001[n0D000ASW@03001Fg5KL008000AFo@03001Fo@00009Fo@03001FoEKm00@0
009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00<000=Fo@03001FoEKm0080
00AFo@05001Fo@00E_d00004E_d30002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00
E_eFo@040002E_d01000Oomoo`0087oo0003Ool20008Ool2000HOol20008Ool2000<Ool3000COol2
000;Ool2002COol00`00C_e>o@05000015lL000000000U/L00@004jKCY]>V`@000030?P0000000@0
00030?P00000008000030?P00000008000031AP00000008000063AP000dH000=5`000Q4g0P000QDg
0P000adg0`0000XQE`008ELQE`009EL002EG000UE`<00004:GL002Ug:GL30003;GL01000<GH0035f
0`0000<eUP00=IH00SFF00@003FF=IH0008eUP<00004>IH003VF0003?IH01@00?KHm]Sff00000cff
00<003ff00000d6f00D0046f@KI1]P0000=1]@050015]DFeAKD00003AKD01000AME5e@000dGE00<0
04WEBMD00TWE00D004WEBME9e@0000=9e@050019eDWEBMD00004COD00`00COE=m@020003COD00`00
COE=m@02COD01@00COE=mDge0000157e00D0057e001Am@0000EAm@05001B5E8EDQD00002EQD00`00
EQD00004EQD00`00EQEF5@02EQD20003EQD00`00EQEF5@02EQD01P00FSEJ=@00FQD000AJ=@04001J
=EXe0002FSD00`00FSEJ=@02FSD00`00GSEN=@03GSD01000GSEN=Ehe0P001EiE0P000eiE00@005iE
GUD0009NE@03001REF9E009RE@8000ERM@03001RMF9e00=RM@03001VMFIe00=VM@03001VUFJE00=V
U@03001VUFJE00=VU@03001VU@0000=VU@03001VU@00009ZU@04001ZUFZEJYD20004J[D00`00J[EZ
]@02J[D01@00J[D006Ze000016kE00D006kFK]I^eP0000=^eP05001^eVkFK]H00003K_H01@00L_Ib
mW;f00000W;f00D007<FLaIc5P00009c5P05001c5P00LaH00003LaH01P00McIg=P00McH000=g=P03
001g=WLf00800004MeL007MG0002MeL01P00NgMkM`00NgL0009kM`05001kM`00NiL00002NiL30000
2g^G001k]`00NkL007^g001k]`00NmL00P000W_G0P0000Ake`00001gm`800004MoL00000LoL30000
0g?g00000003000016oh000006_h0`0000A[m`00Go/0009SW@@0009Fo@03001FoEKm00<000=Fo@<0
009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0
009Fo@03001FoEKm00<000=Fo@06001Fo@00001Fo@000eKm0`000UKm00<005KmE_d010000UKm00<0
05KmE_d010000UKm00<005KmE_d00`000Woo00<007ooOol07Goo0003Ool20008Ool2000HOol20008
Ool2000=Ool2000COol2000;Ool00`00Oomoo`2COol4000014[m001O70000Ulm00D005/LFaaK7000
009>V`030005600000@000040?L000000?L500000`3h0000000200000`DH00000002000010dH0000
00000PdG0`0000DE=`005CL001Tg008000067CL001dg000QE`000R5G0`000REG00H002EG9EL002Ug
0002:GL01000;GL000000Reg00<0035f00000c5f10000SFF00@003FF=IH0008eUP03000iUSVF00D0
008mUP05000m]Sff?KH00003?KH01000?KHm]P000d6f00@0046f@KH000=1]@050015]DFeAKD00003
AKD01@00AME5eDGE00000dGE00D004WEBME9e@0000=9e@050019eDWEBMD00003BMD00`00COE=m@02
COD300000dge001=m@03COD01@00COE=mDge00000dge00<0057eDOD00U7e0P000U7e00<0057eDOD0
0e7e00<0058EDQD00U8E0P000UHE00<005HEEQD00UHE00<005HEEQD00UHE00<005HEEQD00UHE00<0
05HEEQD00eHE0P000eXE00<005XeFSD00UXe0P000eXe00<005XeFSD00UXe00<005heGSD00ehe00@0
05heGSD0009N=@03001NEEiE009NE@03001NEEiE009NE@04001NEEiE0002GUD00`00HUERE@02HUD0
0`00HUD00003HWD20004HWD20004IWD20004IYD00`00IYD00004IYD00`00IYD00002IYD01P00IYEV
U@00JYD000AZU@03001Z]FZe009Z]@03001Z]@00009Z]@06001Z]FZe001Z]@000fkE00D006kE001^
eP0000A^eP05001^eVkFK]H00003K_H01000L_IbmP000g;f00@007<FLaH000=c5P04001c5W<F0003
LaH01@00McIg=P00McH00P000WLf00@007LfMcH0009gEP03001gE`0000=gE`04001kM`00NgL20000
17]g001kM`000W^G00H007^G001kU`00NiL200000g^g00000002NkL200001G_G001ke`00NmL00P00
00Ake`00001gm`800004MoL00000LoL300000g?g0000000300000foh0000000400000f_g001On`04
0002D_d00`00E_eFo@040002E_d01P00E_d00000E_d000=Fo@<0009Fo@03001FoEKm00@0009Fo@03
001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00<000AFo@<0
0003E_d005Km009Fo@<0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@05001oogooOol0
000NOol000=oo`8000Qoo`8001Qoo`8000Qoo`8000eoo`8001=oo`8000]oo`03001oogoo095oo`<0
0004:KT004[mB_d20004Gcd00`00FaaK700;00000`3g0000000400000`3h0000000200000`3h0005
600200000`TH0000000200023AL010004AL001Dg0`0000<I=`006CL00P0000@M=`00000000<QE`<0
00049EL002EG9EL30003:GL01P00;GL00000;GL0008aMP04000aMS5f0002<GH200001CFF000eUSFF
00000SFF00D003VF>IHiUP00008iUP800003?IH003ff008m]P05000m]Sff?KH00002?KH01@00@KI1
]T6f00000d6f00D0046e@KE1]@0000=5]@050015]DFeAKD00002AMD01@00AME5eDGE00000dWE00D0
04WEBME9e@0000=9e@030019eDWE0099e@03001=m@00008000==m@03001=mDge009=m@05001=mDge
COD00004COD00`00DOEAm@020004DOD00`00DOEAm@02DOD00`00DQEB5@02DQD00`00EQEF5@02EQD0
1@00EQEF5EHE00000eHE0P0015HE00<005HEEQD00eHE00<005XEFQD00UXE00<005XeFSD00UXe00<0
05XeFSD00UXe00L005XeFSEJ=@00GSD00004GSD00`00GSD00003GSD00`00GUENE@02GUD00`00GUEN
E@03GUD20004GUD01000HUERE@000V9E00L0069eHWERM@00HWD00003HWD00`00IWD00003IWD00`00
IWD00003IYD00`00IYD00003IYD01P00IYEVU@00IYD000AVU@8000AZU@03001Z]FZe009Z]@05001Z
]@00J[D00004J[D00`00K]E^e@02K]D01@00K]D006kF00000fkF00D006kF001^eP0000=^mP05001b
mP00L_H00002L_H01@00LaH007<F00000W<F00D007<FLaIc5P00009c5P07001g=WLfMcH007Lf0000
0WLf00D007LfMcIg=P00009gEP03001gE`00009gE`07001kMg]g001kM`00NgL00P0000AkM`00NiL0
009kU`80009kU`03001k]`0000800005NkL007^g001ke`02000017_G000007_G0P0000Agm`00001g
m`800005LoL00000001cm`0700000f_g00000002000016_g000000000e/m00<005;mD_d00`000UKm
00<005KmE_d00`0015Km0`0000=Fo@00E_d00UKm0`000eKm00<005KmE_d00`000UKm00<005KmE_d0
10000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00<005KmE_d00`0015Km0`0000AFo@00
E_eFo@@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00<0009oo`03001oogoo01aoo`000goo0P00
27oo0P0067oo0P0027oo0P003Goo0`004Goo0P0037oo00<007ooOol0SWoo0`000goo00@002Vi0000
009:o@03001O?Elm00@00004C_d003iK?U/600001@3g000000000=L00P0000H0m`000000m`000?L4
00001PCg000000TG000=5`8000053AL0014G000E=`0300000aTg000I=`02000011dg000000000R5G
00<0025G00000P000REG00@002UG0000008YM`04000]M`00;GH300001C5f000aMS5f00000S5f00<0
03Ef00000P000SFF00@003FF=IH0008iUP05000iUSVF000iUP030002?KH01@00?KHm]Sff00000Sff
00D0046f@KI1]P0000=1]P050011]D6e@KD00003AKD01@00AKE5]DFe00000TGE00D004GEAME5e@00
00=9e@050019eDWEBMD00004BMD00`00BMD000030002CMD00`00COE=m@02COD01@00COE=mDge0000
0dge00<004geCOD00Tge0`0000==m@00DOD00e7e00<0057eDOD00U7e00@0058EDQEB5@8000AF5@03
001F5EHE009F5@05001F5@00EQD00004EQD00`00EQEF5@02EQD20004FQD00`00FSEJ=@02FSD00`00
FSEJ=@02FSD01000FSEJ=@000Uhe00<005heGSD00ehe00<005heGSD00Uhe00@005iEGUENE@8000EN
E@03001NEEiE00=NE@03001RE@0000=RE@04001RMF9e0002HWD01000HWERM@000VIe00@006IeIWD0
009VM@04001VUFJE0003IYD00`00IYD00004IYD20004IYD00`00JYEZU@02JYD00`00JYD00002J[D0
1P00J[EZ]@00J[D000AZ]@05001^eFkEK]D00003K]D00`00K]I^eP02K]H01@00K]H006kF00000fkf
00D007;f001bmP00009bmP04001c5W<F0003LaH02000LaIc5P00MaH007<F0002McH00`00McIg=P02
00001GLf001g=WLf00000WMF00<007MF00000WMG00H007]gNgL007]g0002NgL01@00NgL007^G0000
0W^G00D007^G001kU`00009k]`800007NkL00000001ke`00NmL00P0000Ake`00001ge`800004MoL0
0000MoL200000g?g0000000300001Fog00000000JoL01`0000A_f`00FceK?@@0009Bg003001FoEKm
00<000=Fo@03001FoEKm008000AFo@05001Fo@00E_d00004E_d30002E_d00`00E_eFo@030003E_d0
0`00E_eFo@030003E_d00`00E_eFo@030003E_d00`00E_eFo@030002E_d00`00E_eFo@030003E_d3
0003E_d00`00E_eFo@030003E_d00`00E_eFo@030002E_d01@00Oomoogoo00007Goo0003Ool20008
Ool2000HOol20008Ool2000>Ool20009Ool20005Ool3000<Ool00`00Oomoo`2;Ool30006Ool01000
:KTY^@000T[m10000ULn00@004kmC_d0008nF`80000303<0000000D000070=L000000000m`000?L0
1@0000D4m`00000000TG008000043AL000004AL3000011Dg000000000QTg00@001dg000M=`800005
8EL0025G000QE`0200029EL02000:EL00000:GL002eg0003;GH30003<GH00`00<GH00003=GH20000
1CFF000eUSFF00000cVF00@003VF>IH0008iUP<00005?KH003ff?KH00002?KH01@00@KI1]T6f0000
0d6f00D0046e@KE1]@0000=5]@050015]DFeAKD00002AMD01@00AME5eDGE00000dWE00<004WEBMD0
0TWE00<004WE00000`000TWE00D004gECME=e@0000A=m@05001=mDgeCOD00004COD00`00COE=m@02
0004COD01@00DOEAmE7e00001E7e00D0058E001B5@0000AF5@03001F5EHE009F5@8000=F5@05001F
5EHEEQD00003EQD00`00EQD00004FQD01000FSEJ=EXe0P001EXe0P000ehe00<005heGSD00ehe00<0
05heGSD00Uhe00@005iEGUD0009N=@03001NEEiE009NE@03001NEEiE00=NE@03001RE@0000=RE@03
001RM@0000=RM@03001RM@0000=VM@03001VM@0000=VM@03001VU@0000AVU@03001VU@0000AVU@03
001VUFJE00=VU@03001ZUFZE009ZU@03001ZU@00009Z]@05001Z]FZeJ[D00004J[D01@00K]D006kE
000016kE00D006kFK]I^eP0000=^eP05001^mVkfK_H00003L_H01000L_IbmP000g<F00@007<FLaH0
00=c5P04001g5WLF0003McH00`00McH00002McH01000McIg=P000gMF00P007MF000007MG001kM`00
0W]g00<007]g00000W]g00T007^G001kU`00NiL007^G00000W^g0P000W^g00<007^g00004`0000=c
m`00KoL0100000=[m`0000001@000VoK0`000UKL00<005;LD]`010000UKm00<005KmE_d010000UKm
00<005KmE_d00`000eKm00H005Km000005Km0003E_d30002E_d00`00E_eFo@040002E_d00`00E_eF
o@040002E_d00`00E_eFo@040002E_d00`00E_eFo@030003E_d01@00E_d005Km000015Km0`000UKm
00<005KmE_d010000UKm00<005KmE_d00P000goo00<007ooOol06Woo0003Ool20008Ool2000HOol2
0008Ool2000>Ool20009Ool9000<Ool00`00Oomoo`29Ool3000:Ool50003E_d:00000a5H00000002
0000103G0000003G0`0000<0e`000?L01@0000<0m`001?L00P0000H95`002AL000dG00024AL20000
0aDg000E=`0200001aTg000000007CL001dg00<000038EL0025G008000059EL002UG000YE`030000
1Reg000]MRef000]MP80008aMP04000aMS5f0002=GH01000=GH000000SFF00D003VF>IHiUP00008i
UP04000iUSVF0002?IH400001Cff000m]Sff00000T6f00D0046f@KI1]P0000=1]@050015]DFeAKD0
0003AKD01000AME5e@000dGE00<004WEBMD00TWE00<004WE00000`000TWE00D004WEBME9e@0000A=
e@05001=mDgeCOD00003COD00`00COE=m@02COD300000dge001=m@03COD00`00DOEAm@02DOD00`00
DOEAm@02DOD20003DQD01@00EQEF5EHE00000eHE0P0015HE00<005HEEQD00UHE00<005HE00000eHE
00D005XEFQEJ5@00009J=@04001J=EXe0004FSD00`00GSEN=@03GSD01000GSEN=Ehe0P001Ehe0P00
0ehe00L005iEGUENE@00GUD00005GUD00`00HUERE@03HUD20004HWD20004IWD20004IWD20005IYD0
0`00IYEVU@03IYD00`00IYEVU@02IYD00`00IYD00002JYD01P00JYEZU@00J[D000AZ]@03001Z]FZe
009Z]@05001^e@00K]D00003K]D01@00K]D006kF000016kF00D006kfK_I^mP0000=bmP04001bmW;f
0002LaH01@00LaH007<F00000W<F00D007LFMaIg5P00009g=P04001g=WLf0002McH200001gLf001g
EWMF001gEP00009gE`800004NgL007]g0002NgL01000NgL007^G0P00015kU`00NiL007^G001k]`00
NkL007^g001k]`00NmL007_G00800004NmL00000MoL2000017Og000007Og100000=cm`00KoL02000
00EWm`00000006oK00800004Hgd005KLE]`40002E_d00`00E_eFo@040002E_d00`00E_eFo@040002
E_d00`00E_eFo@030004E_d3000015Km001FoEKm10000UKm00<005KmE_d010000UKm00<005KmE_d0
10000UKm00<005KmE_d010000UKm00<005KmE_d00`000eKm00H005Km000005Km0003E_d30002E_d0
0`00E_eFo@040002E_d01000Oomoo`0077oo0003Ool20008Ool2000HOol20008Ool2000?Ool20008
Ool200000goo00000003000=Ool30026Ool3000=Ool01P00CSQ>>4hh001Fo@80009O7006001:oT[n
000^OP000QGL1P0000<0e`000000100000<0e`0000000`0000<0m`0000000P0000L4m`00000000TG
000=5`0300001Q4G000E=`005CL0008I=`<0000:7CL001dg7CL0025G000QE`009EL200000bUG000Y
E`02:EL00`00;GL00002;GH00`00;GH]MP0200001C5f000aMS5f00000SEf00@003Ef=GHeMP<000<i
UP04000iUSVF0002>IH01@00?IHmUSfF00000SfF1`0000E1]P00@KI1]P0000=1]@050015]DFeAKD0
0003AKD01@00AME5eDGE00000dGE00<004WE00000`000TWE00D004WEBME9e@0000A9e@05001=eDgE
CMD00003COD00`00COE=m@02COD00`00COE=m@020003COD00`00COE=m@02COD00`00DOEAm@02DOD0
1000DOEAmE7e0P00158E00D005HEEQEF5@00009F5@03001F5@0000AF5@03001F5EHE009F5@8000AF
5@03001J5EXE009J5@8000=J=@03001J=EXe009J=@03001N=Ehe00=N=@04001N=Ehe0002GSD00`00
GSEN=@02GSD00`00GSEN=@02GSD01000GUENE@000UiE00<005iEGUD00eiE00<0069EHUD00f9E00<0
069eHWD00f9e00<006IeIWD00fIe00<006IeIWD00fIe00<006JEIYD016JE00<006JEIYD00VJE00<0
06JE00000fJE00<006JE00000VZE00@006ZEJYEZU@8000=Z]@03001Z]@00009Z]@05001^eFkEK]D0
0004K]D01@00K]D006kF00000fkF00D006kf001^mP0000=bmP05001bmP00L_H00002LaH01000LaIc
5P000g<F00X007LFMaH007Lf001g=P00McH0009g=P04001g=WLf0002MeH01000MeIgEP000WMG00<0
07]g00000W]g00<007]g00000W]g00@007^G001kU`<00004NiL007^gNkL200001g^g001k]`00NmL0
07_G00800004NmL00000MoL2000017Og000007Og100000=cm`00KoL0200000=Wm`00000010000V=m
0`000eKm00<005KmE_d00`000eKm00<005KmE_d00`000UKm00<005KmE_d010000UKm00<005KmE_d0
0`000eKm0`000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00<0
05KmE_d010000UKm00<005KmE_d00`0015Km0`0000=Fo@00E_d00UKm0`000UKm00<005KmE_d00`00
0Woo00<007ooOol06Goo0004Ool20006Ool2000JOol20006Ool2000@Ool20008Ool2000COol00`00
Oomoo`23Ool3000AOol01@00CSQ>>4hh000015lL1`0000<Eg0002GX00P0000<0]P0000000P0000@0
e`000000e`D000030?L0000000<000031?L000Cg008000062AL000003AL0014G0`000QDg00L001Tg
000I=`007CL000027CL300028EL01P009EL00000:EL0008YE`<000<]MP04000]MP00<GH300000c5f
000eMP02=GH01@00=GHeMP00=IH00P000SVF00D003VF>IHiUP00008iUP04000mUSfF0003?IH01000
?KHm]P000T6f100000=1]P00@KD00T6e00D004FeAKE5]@0000=5]@050015eDGE0015e@040002BMD0
1@00BME9eDWE000014WE00D004WEBME9e@0000==e@05001=mDgeCOD00004COD300000dge001=m@03
COD00`00COE=m@02COD01@00DOEAmE7e00000U7e00<0057e0000158E00<005HEEQD00UHE0P000UHE
00<005HEEQD00UHE00@005HEEQEF5@8000EF5@03001J5EXE009J5@03001J=EXe009J=@04001J=EXe
FSD20005GSD01000GSEN=@000Uhe00<005heGSD00Uhe00<005heGSD00Uhe00@005iEGUD0009NE@03
001NEEiE009NE@8000ERE@03001RMF9e00=RM@03001VMFIe00=VM@03001VMFIe00=VM@03001VUFJE
00=VU@03001VU@0000=VU@03001VU@00009VU@06001VUFJE001ZU@0016ZE00<006ZeJ[D00VZe00D0
06Ze001Z]@0000A^e@05001^eFkEK]D00003K]D00`00K]I^eP02K]H01@00K_H006kf00000g;f00@0
07;fL_H0009c5P05001c5W<FLaH00002LaH01@00MaIg5WLF00000WLf00@007LfMcH0009g=P03001g
=WLf00800004MeH007MF0002MeL00`00NgMkM`0200000g]g00000002NgL00`00NiL00002NiL00`00
NiL0000200001g^g001k]`00NkL007^g00800003NmL007_G00800004MmL00000MoL300001GOg0000
0000LoL01P0000=[m`0000001`0000=On`0000000P000U;m00<005KmE_d010000UKm00<005KmE_d0
10000UKm00<005KmE_d00`000eKm00<005KmE_d00`000eKm00D005Km001Fo@0000=Fo@<000=Fo@03
001FoEKm00<000=Fo@03001FoEKm00<0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03
001FoEKm00<000AFo@<00004E_d005KmE_d40002E_d01@00Oomoogoo00006Woo0004Ool20006Ool2
000JOol20006Ool20007Ool20007Ool20008Ool2000COol00`00Oomoo`21Ool2000DOol01`00CSQ>
>000H]P005lL0080009O6`050012gT;N000F7@0300000`Uj0000000500000`3G0000000400000`3G
0000000300001`3g0004m`001?L000TG00<000033AL0014G0080008E=`<000046CL0000000027CL0
1P007CL000008EL0008UE`03000YE`00008YE`04000YEP000002;GH00`00;GH00003<GH30003=GH0
1000=GHeMP000SFF0`0000DiUP00>IHiUP00008iUP05000mUSfF?IH00002?IH01@00?KHm]Sff0000
0T6f00<0046e@KD04P000TGE00D004WEBME9e@0000A9e@050019eDWEBMD00003BMD01@00CME=eDgE
000014ge00<004ge00000P000dge00<004geCOD00Tge00<004geCOD00Tge00<0057eDOD00U7e0P00
0U7e00<0058EDQD00U8E00<005HEEQD00UHE00<005HEEQD00UHE00D005HEEQEF5@00009F5@03001F
5@0000EF5@03001J5EXE009J5@03001J=EXe009J=@04001J=EXe0002GSD00`00GSEN=@03GSD20003
GSD01000GSEN=Ehe0P001Ehe0P0015iE00@005iEGUD0009RE@04001REF9EHUD20004HWD20004IWD2
0004IWD00`00IYD00004IYD00`00IYD00002IYD01P00IYEVU@00IYD000AVU@8000AZU@05001Z]FZe
J[D00002J[D00`00J[D00003K]D00`00K]D00002K]D01@00K]E^eFkE00000fkF00D006kfK_I^mP00
00=bmP05001bmW;fL_H00002LaH02000LaIc5P00LaH007<F0002MaH01000McIg=WLf0P0000Ag=P00
McH0009g=P04001gEWMF0002MeH01P00MeMgE`00NgL0009kM`05001kM`00NgL00002NiL02000NiL0
07^G001k]`00NkL300001g^g001k]`00NmL007_G00800004NmL00000MoL3000017Og000007?g1P00
00=_m`00JoL02`000U/m00<005;mD_d010000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm
00<005KmE_d010000UKm00<005KmE_d00`000eKm00D005Km001Fo@0000AFo@<0009Fo@03001FoEKm
00@0009Fo@03001FoEKm00<000=Fo@03001FoEKm00<000=Fo@03001FoEKm00<0009Fo@03001FoEKm
00<000=Fo@<0009Fo@03001FoEKm00<0009oo`03001oogoo01Qoo`001Goo0P0017oo0P0077oo0P00
17oo0P0027oo0P0027oo0P001goo0P004goo00<007ooOol0OWoo0`005Woo00<004hh00000f;H0P00
0elK200000@9NP000000e`<000030=H0000000@000030=L0000000<000030?L0000000800084m`09
00095`00000=5`004AL0014G008000055CL00000000I=`0300027CL01`007CL000008EL002EG00<0
00<YE`06000YEP00000]MP000Ref00D0035f<GH0035f0080008eMP07000eMSEf=GH003FF00000SFF
0`0000DiUP00>IHiUP0000<mUP05000mUSfF?IH00002?KH01000@KI1]P000d6e00D0046e@KE1]@00
00=1]@050015]DFeAKD00002AMD01@00AME5eDGE000014WE00D004WEBME9e@0000=9e@050019eDWE
BMD00003CMD01000COE=mDge0`000Tge00<004geCOD00Tge00D004geCOE=m@0000A=m@04001AmE7e
DOD20004DOD01@00DQEB5E8E00000eHE0P0015HE00<005HEEQD00UHE0P000UHE00<005HEEQD00eHE
00@005XEFQEJ5@8000AJ=@04001J=EXe0002GSD00`00GSEN=@03GSD00`00GSEN=@02GSD01000GSEN
=@000Uhe00<005heGSD00Uhe00<005iEGUD00eiE00@005iEGUD0009RE@07001REF9EHUD0069E0000
0f9e00<0069e00000fIe00<006Ie00000fIe00<006JE00000fJE00H006JEIYD006JE0004IYD20004
IYD00`00JYEZU@02JYD00`00J[D00002J[D01@00J[EZ]FZe000016kE00D006kE001^e@0000=^e@03
001^e@00009^eP05001^mVkfK_H00002L_H02@00L_IbmW;f001c5P00LaH00002LaH01000LaIc5P00
0gLF00@007LfMcH0009g=P04001g=WLf0002McH00`00MeIgEP02000017MF001gE`000W]g00<007]g
NgL00`0000AkM`00NiL0009kU`04001kU`000002NkL00`00NkL0000500000g_G001ke`02000017OG
000007Og1`0000Mcm`00000006og001[m`0300000f?g00000004000016^l001K?E/m0`000U;L00<0
05KmE_d010000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00<0
05KmE_d00`000eKm00H005Km000005Km0002E_d40002E_d00`00E_eFo@040002E_d00`00E_eFo@04
0002E_d00`00E_eFo@040002E_d00`00E_eFo@030003E_d01@00E_d005Km00000eKm0`000eKm00@0
07ooOol001Uoo`001Goo200077oo200027oo30001goo2P002goo00<007ooOol0Ngoo0`006Woo00<0
06;HH]P00V;H00D006[h001O6`00009O6`04000ngSkN?]h600000`3G0000000600000`3G00000003
00000`3G0000000300021?L300000`Sg000=5`0200000a4G000A5`0200001ADG000I=`006CL00P00
00DM=`007CL0024g008000039EL002EG0080008YE`04000YEP00;EH300001Bef000aMS5f00000S5f
0P0000<eMP00=GH00SEf00<003FF00000cFF00<003VF00000P0000<iUP00?IH00SfF00D003fF?IHm
UP00008m]P050011]T6f@KH00002@KD01@00@KE1]D6e00000d6e00D004FeAKE5]@0000=5e@050015
eDGEAMD00003BMD01@00BME9eDWE00000dWE00D004WEBME9e@0000A=e@<00003COD004ge009=m@03
001=mDge009=m@03001=mDge009=m@03001=mDge009=m@<00003DOD0057e00=Am@03001B5E8E009B
5@05001F5@00EQD00004EQD00`00EQEF5@02EQD00`00EQEF5@02EQD00`00EQEF5@03EQD00`00FQD0
0002FQ@00`00FSEJ=@02FSD20003GSD00`00GSEN=@02GSD20004GSD01000GSEN=@000Uhe00<005he
GSD00Uhe00<005iEGUD00eiE00<005iE00000f9E00@0069EHUD0009RE@04001RMF9e0002HWD01000
IWEVM@000VIe00@006IeIWD000=VU@03001VU@0000AVU@8000AVU@03001VUFJE00=VU@03001ZUFZE
009ZU@05001Z]@00J[D00004J[D01@00K]E^eFkE00000VkE00<006kE00000fkE00D006kE001^eP00
00=^mP05001bmP00L_H00003L_H01000LaIc5P000g<F00@007<FLaH0009g5P05001g=WLfMcH00002
McH2000017Lf001g=P000WMF00@007MFMeH0009gE`03001kM`00009kM`04001kM`00NgL200004G^G
001kU`00NiL007^g001k]`00NkL007^g001ke`00NmL02`0000Igm`00001cm`00LoL300000fog0000
000300000f?g000000040002Jk`300000eKL001Bg002D]`30003E_d00`00E_eFo@030003E_d00`00
E_eFo@030002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@030003E_d30002
E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@040002
E_d00`00E_eFo@030003E_d01@00E_d005Km000015Km1@0067oo0007Ool4000POol4000:Ool<0007
Ool:000:Ool00`00Oomoo`1iOol3000MOol01@00H]QRf6;H00000f[h00@005lKGa]O6`T000030AP0
0000008000040;H000000=L600000`3G000000030000103g000000Cg0P0000<8m`003AL00`0000DA
5`004AL001DG00<000036CL001dg0080008M=`03000Q=`00008UE`08000UE`00000YE`00:EH000<]
EP<000<aMP04000aMP00<GH30002=GH01000=IHeUP000SFF00@003VF>IHiUP@0008mUP05000mUSfF
?IH00003?KH01000@KI1]P000d6e00D0046e@KE1]@0000=1]@050015]DFeAKD00002AMD01@00AME5
eDGE00000dWE00D004WEBME9e@0000=9e@030019eDWE0099e@03001=e@00008000==m@03001=mDge
009=m@05001=mDgeCOD00004COD01000COE=mDge0P000e7e00<0057eDOD00U7e00<0058EDQD00U8E
0P000eHE00D005HEEQEF5@0000=F5@8000AF5@03001F5EHE00=F5@8000=J5003001J=EXe009J=@03
001N=Ehe009N=@07001N=EheGSD005iE00001Ehe0P000ehe00@005heGSEN=@8000INE@03001REF9E
009RE@03001RE@0000=RE@03001RM@0000=RM@04001VMFIe0002IWD00`00IWD00004IYD00`00IYD0
0004IYD00`00IYEVU@03IYD00`00IYEVU@02IYD00`00JYD00002JYD01P00J[EZ]@00J[D000=Z]@03
001^e@00009^e@05001^eFkEK]D00003K]D01P00K]E^e@00K]H000=^mP04001bmW;f0003L_H01@00
LaIc5W<F00000W<F00P007<FLaH007LF001g5P000WLf00@007LfMcH0009g=P03001g=P0000=gEP03
001gEWMF00800003MeL0000000=kM`80009kM`05001kU`00001kU`0200001W^g001k]g^g001k]`80
0007NmL007_G001ke`00NmL00P0000Ige`00001gm`00MoL200000g?g001cm`0900000f?g00000004
00001F^l000006=M00000eKL00<005;L00000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm
00<005KmE_d00`000eKm00<005KmE_d00`000UKm00<005KmE_d010000UKm00H005Km000005Km0003
E_d30002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eF
o@040002E_d00`00E_eFo@030003E_d01P00E_d00000E_d0009oo`03001oogoo01Ioo`00H7oo00<0
07ooOol0MWoo0`008Goo00<006;H000016[h0P0000=O6`00Ha/00V<K00D003jn?[h0006K00<00005
0?L000000000]P0700000`3G000000030000103G0000003g0P0000<4m`002?L00P0000@=5`000000
008A5`03000E5`00008000036CL001dg0080000:7CL0024g8CL002EG000UE`009EH300001RUF000]
EReF000]MP80008aMP03000aMP0000<aMP800005=GH003FF=IH00003=IH01000>IHiUP000SVF0`00
00DmUP00?IHmUP0000<m]P040011]T6f0003@KD01@00@KE1]D6e00000d6e00D004FeAKE5]@000095
e@050015eDGEAMD00003BMD01@00BME9eDWE000014WE00<004WEBMD00`000TgE00<004geCOD00Tge
00D004geCOE=m@0000==m@03001=mDge009=m@06001=mDge001=m@00157e00D0057eDOEAm@0000AB
5@03001F5EHE009F5@05001F5EHEEQD00002EQD00`00EQD00004EQD00`00EQEF5@03EQD00`00FQAJ
5002FQ@00`00FSEJ=@02FSD00`00GSEN=@02GSD01000GSEN=@000eiE00<005heGSD00Uhe00<005he
GSD00Uhe00@005heGSD0009N=003001NEEiE00=NE@03001REF9E00=RE@8000ARE@8000=RM@03001V
M@0000AVM@8000EVU@03001VUFJE00=VU@03001VUFJE009VU@03001VU@0000=VU@05001ZU@00JYD0
0004J[D00`00J[EZ]@02J[D01@00K]D006kE000016kE00D006kEK]E^e@0000=^e@05001^mVkfK_H0
0003L_H01@00L_IbmW;f00000W<F00D007<F001c5P00009c5P04001g5WLF0002McH01@00McIg=WLf
00000WLf00<007Lf00000WMF00@007MFMeH0009kEP03001kM`00009kM`05001kM`00NgL00002NiL0
3000NiL007^G001k]`00NkL007^g001k]`800005NmL007_G001ke`02000017OG000007Og100000=c
m`0000004P0016=M00<005KL00000P000eKm0`000UKm00<005KmE_d010000UKm00<005KmE_d01000
0UKm00<005KmE_d010000UKm00<005KmE_d00`000eKm00<005KmE_d00P0015Km00D005Km001Fo@00
00=Fo@<000=Fo@03001FoEKm00<0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001F
oEKm00@0009Fo@03001FoEKm00<000=Fo@800003Ool007oo01Moo`00H7oo00<007ooOol0Lgoo0`00
9Goo00<006[hJ_P00V[h00@006[hJ_P000AS6`T000030?L0000000L000030=L0000000<000080=L0
00000=L0003g0004m`H000043AL000004AL3000011DG000000000Qdg0`000R4g0`000REG00H002EF
9EH002UF0002;EH00`00;GH]MP0200001C5f000aMS5f00000S5f00<0035f00000P0000<eUP00=IH0
0SFF00@003VF>IH0008iUP03000iUSVF00@00005?IH003ff?KH00002@KH01@00@KE1]D6e00000d6e
00D0046e@KE1]@0000=5]@050015eDGEAMD00002AMD01@00BME9eDWE000014WE00@004WEBME9e@<0
0003BMD004gE009=e@03001=mDge009=m@05001=mDgeCOD00003COD00`00COE=m@03COD20002COD0
0`00DOEAm@02DOD01@00DOEAmE7e00000e8E0P0015HE00<005HEEQD00UHE0P000eHE00<005HEEQD0
0UHE00<005HEEQD00UHE00<005XDFQ@00UXD00@005XeFSEJ=@8000EN=@8000ANE@03001N=Ehe009N
=@03001N=Ehe009N=@04001N=Ehe0002GS@00`00GUENE@02GUD20005HUD00`00HUERE@03HUD00`00
HWERM@03HWD20004IWD00`00IYEVU@04IYD00`00IYEVU@02IYD20004IYD00`00IYD00002IYD01P00
JYEZU@00JYD000AZ]@05001Z]FZeJ[D00002K]D00`00K]D00003K]D01@00K]D006kE000016kE00D0
06kfK_I^mP00009bmP05001bmP00L_H00003LaH01`00LaH007<F001c5P0000=g5P800005McH007Lf
McH00002McH00`00McH00002MeH01@00MeIgEWMF00000W]F0P000W]g00<007]g00000W]g00<007^G
00000W^G1@0000Qk]`00001k]`00NmL007_G0P0000Ake`00001ge`800005MoL00000001cm`040000
0fof0000000=000015om001SGF=M10000UKm00H005Km000005Km0003E_d30002E_d00`00E_eFo@04
0002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@03
0003E_d00`00E_d00002E_d00`00E_eFo@040002E_d00`00E_eFo@030003E_d00`00E_eFo@030002
E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d02000E_d00000E_d007oo000HOol0061oo`<0
071oo`<002Qoo`05001Zn6[hJ_P00003J_P200000f<K00000002Ha/00`00>[hj_P0800000`2f0000
000800002P3G0000003G0000e`000?L000Cg0P0000H8m`003AL000dG00024AL200000aDG000I5`02
00000adg000M=`0200028CL3000012EG000UEREF0`000beF00@002ef000]MP80008aMP04000aMS5f
0003<GH30003=IH01`00>IHiUSVF000iUP0000<iUP03000mUSfF00@00004?KH0046f0003@KD01@00
@KE1]D6e00000d6e00D004FeAKE5]@0000=5e@040015eDGE0004BMD01P00BME9eDWE0019e@<000=9
e@03001=eDgE009=e@05001=mDgeCOD00003COD00`00COE=m@02COD01000COE=mDge0P000dge00<0
057eDOD00U7e00<0057eDOD00U7e00D0058E001Em00000AF5@03001F5EHE009F5@03001F5EHE009F
5@03001F5EHE009F5@04001F5EHEEQD20004FQ@01000FSEJ=@000Uhe00<005heGSD00Uhe00<005iE
GUD00eiE00@005heGSEN=@8000EN=@8000=N=005001NEEiEGUD00002GUD00`00HUERE@02HUD00`00
HUERE@03HUD00`00HWERM@03HWD00`00IWEVM@03IWD00`00IYEVU@03IYD20004IYD00`00IYD00002
IYD01P00IYEVU@00IYD000AZU@03001Z]FZe009Z]@03001Z]@00009Z]@05001^eFkEK]D00004K]D0
1@00K]D006kE00000fkE00D006kE001^mP0000=bmP05001bmP00L_H00002LaH01@00LaIc5W<F0000
0W<F00@007LFMaH0009g=P05001g=WLfMcH00002McH01P00McH00000MeH0009gEP05001kEW]F001k
MP0200001W]g001kM`00NgL0009kU`0<001kU`00NiL007^g001k]`00NkL007^g0P0000=ke`00NmL0
0P0000Ake`00001gm`800003MoL0000000800003LoH0000000<00003JoH0000000T0009Oo@<000=G
7@03001FoEKm008000AFo@05001Fo@00E_d00003E_d30003E_d00`00E_eFo@030002E_d00`00E_eF
o@040002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@030003E_d30002E_d0
0`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@030003E_d00`00E_eFo@030002E_d0
0`00E_eFo@030004E_d2000HOol005moo`8006moo`<002aoo`03001Zn00000=Zn004001^mfkg0004
Ha/800001@3g000000000;H0200000P0e`000000e`000=L0003G100000<4m`0000000P000PdG00T0
014G000A5`005AL001TG00000Qdg00L001dg0000024g000Q=`0300029EH01000:EH000000ReF00<0
02ef00000Ref0P0000<aMP00<GH00S5f00D0035f<GH003Ef0080008eUP05000iUSVF>IH00002>IH0
1000>IHiUP000cfF00<003fE?ID01@000T6e00D0046e@KE1]@0000=1]@050015]DFeAKD00003AMD0
1@00AME5eDGE00000dWE00<004WE00000`000TWE00<004WEBMD00TWE00D004gECME=e@0000==m@05
001=mDgeCOD00004COD400000dge001=m@03COD01@00DOEAmE7e0000157e0P000eGd00D005HEEQEF
5@0000=F5@8000AF5@03001F5EHE009F5@06001F5EHE001Em0001EXD0P000ehe00<005heGSD00Uhe
00<005iEGUD00eiE00@005heGSD0009J=@03001N=Ehe009N=@03001N=5hd009N=004001NEEiE0003
GUD01000HUEREF9E0P00169E0P001F9e00<006IeIWD00VIe00<006JE000016JE00<006JE00000VJE
00@006JEIYD0009VU@04001VUFJEIYD20004JYD00`00J[EZ]@02J[D01@00J[D006Ze000016kE00D0
06kEK]E^e@0000=^e@03001^eFkE009^e@05001^e@00K_H00002L_H01@00L_IbmW;f00000g<F00@0
07<FLaIc5P800005LaH007LFMaH00002McH01000McIg=P000WLf00<007Lf00000WMF00@007MFMeH0
00=kEP80009kMP800006NgL007]g001kU`000W^G0P0000Ak]`00NkMk]a<00003LoH0000000<00003
KoH0000000h0009G7@03001G7ELM00@0009Fo@03001FoEKm00<000=Fo@03001Fo@00009Fo@03001F
oEKm00@0009Fo@03001FoEKm00<000=Fo@03001FoEKm00<0009Fo@03001FoEKm00@0009Fo@03001F
oEKm00@0009Fo@06001Fo@00001Fo@000eKm0`000UKm00<005KmE_d010000UKm00<005KmE_d01000
0UKm00<005KmE_d010000UKm00<005KmE_d00`000eKm00<005KmE_d00P0000=oo`00Ool05Woo001P
Ool00`00Oomoo`1[Ool2000`Ool01@00J_QZn6[h00000fkg0P0000=S6`0000000V<K00<003Zn>[h0
100000<0m`0000001@0000@0]P000000]P8000050;H0003G0000e`0500000`Cg0008m`0200023AL3
0000114G000000000QTG00H001dg000M=`007CL200000b4g000Q=P0200029EH01P00:EH00000;EH0
008]MP03000]MRef00<000<aMP04000aMS5f0002=GH200000cFF000iUP02>IH01000>IHiUP000cVF
00@003fF?IH000<mU@03000m]Cfe00<00003@KD0046e0091]@050011]D6e@KD00003AKD01P00AME5
eDGE0015e@L00099e@050019eDWEBMD00004BMD01@00CME=eDgE00000dge00<004geCOD00Tge00<0
04ge00000P0014ge00<004geCOD00Tge00D0057eDOEAm@0000=Am@8000AEm003001F5EHE009F5@05
001F5@00EQD00005EQD00`00EQEF5@02EQD20003EO@00`00FQAJ5002FQ@00`00GSEN=@02GSD01`00
GSEN=Ehe001N=@0000ENE@8000=J=@03001N=Ehe009N=@03001N=5hd009N=004001NEEiE0003GUD0
1`00HUEREF9E001NE00000=RE@03001RM@0000=RM@8000AVM@03001VU@0000=VU@04001VUFJE0002
IYD01P00IYEVU@00IYD000AVU@03001ZUFZE009ZU@03001ZU@00009Z]@06001Z]FZe001Z]@000fkE
00<006kE00000VkE00D006kEK]E^e@0000=^e@05001^eFkEK]D00003L_H01@00L_IbmW;f00000W<F
00D007<FLaIc5P00009g5P04001g5WLF0002McH01@00McH007Lf00000WLf00<007Lf00000WMF0P00
00MgEP00NeIkEP00NgH00002NgH01@00NgH00000NgL00P000W^G00X007^G001k]`00NkL007^g001k
]`800003NmL007_G00800004NmL00000MoL200000gOg001cmP0@00000dne00000002C_d00`00EaeG
7@040002D_`00`00E_eFo@040002E_d00`00E_eFo@030003E_d30002E_d00`00E_eFo@040002E_d0
0`00E_eFo@040002E_d00`00E_eFo@030003E_d00`00E_eFo@030002E_d00`00E_eFo@030004E_d3
00000eKm001Fo@02E_d30002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@04
0002E_d00`00E_eFo@040002E_d2000GOol005moo`03001oogoo06Uoo`<003=oo`03001Zn00000=^
m`03001^mfkg008000=S6`/000030;H00000008000090;H000000000]P000;H0003G008000060=L0
00000=L000Cg0P0000@8m`00000=5`<000034AL00000008I5`<000047CL001dg7CL200000b4g000Q
=P0200001BEF000YEP00:EH00`0000H]MP00;GH]MP00<GH20002<GH02000<GHaMS5f000eMP00=GH3
0002>IH01000>IHiUP000cVF00D003fF?IHmUP00008mU@04000m]Cfe0002@KDC00000dGE0019e@02
BMD01@00BME9eDWE000014WE00D004WEBME9e@0000==e@03001=mDge009=m@03001=mDge00<0009=
m@03001=mDge00==m@05001=mDgeCOD00004DOD01@00DOD0057d000015Gd00<005HEEQD00UHE0P00
0eHE00<005HEEQD00UHE00@005HEEQEF5@8000AEm003001J55XD009J5003001N=Ehe009N=@04001N
=Ehe0002GSD00`00GUENE@03GUD00`00FSEJ=@02FSD01000GSEN=Ehe0P001Ehd0P0015iE00@0069E
HUD0009NE004001REF9E0002HWD01`00HWERMF9e001RE000009VM@05001VUFJEIYD00002IYD01P00
IYEVU@00IYD000AVU@8000AVU@03001ZUFZE009ZU@03001ZU@00009Z]@05001Z]FZeJ[D00004K]D0
1@00K]D006kE00000fkE00<006kE00000VkE00D006kEK]E^e@00009bmP09001bmW;fL_H007;f001c
5P0000=c5P06001g5WLF001g5P000gLf00@007LfMcH0009g=P06001g=WLf001gEP000W]F00H007]F
NeH007]f0002NgH04`00NgIkMP00NiH007^G001kU`00NiL007^g001k]`00NkL007^g00800003NmL0
07_G00800004NmL00000MoL200000gOg001cmP0300000fof0000000:000014ne001K?@000Tkm0`00
0e;L00<005;lD_`00`000UKm00<005KmE_d010000UKm00H005Km000005Km0003E_d30002E_d00`00
E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@030003E_d00`00
E_eFo@020004E_d30002E_d00`00E_eFo@030002E_d00`00E_eFo@040002E_d00`00E_eFo@040002
E_d00`00E_eFo@040002E_d00`00E_eFo@03000GOol005moo`03001oogoo06Ioo`<003Moo`05001^
mfkgK_L00003K_L01@00K_L006<K00000V<K00<003Zn>[h01`0000<0]P0000001P0000<0]P000;H0
0P0000@0e`000000e`D000032?L000Sg008000063AL0014G000E5`000QTG0`0000XM=`007CLM=`00
8CL0024f000UEP800003:EH002UF008YEP03000]MP00008]MP03000aMS5f00800003<GH0035f008a
MP03000eMP0000<eMP<00004>IH003VF0003>IH01@00?IHmUSfF00000cfE00<003fe00000d6e00D0
046e@KE1]@0000=1]@050015]DFeAKD00003AKD01000AME5e@0014WE00D004WEBME9e@0000=9e@05
0019eDWEBMD00003CMD00`00COE=m@02COD300000dge001=m@02COD00`00COE=m@03COD01@00COE=
mDge0000157e0P000U7d00<005GdEO@00UGd00@005HEEQEF5@8000AF5@03001F5EHE009F5@06001F
5EHE001Am00015Gd00@005XDFQAJ508000EN=@8000=N=@03001NEEiE00=NE@03001J=EXe009J=@04
001N=Ehe0002FQ@00`00GSAN=002GS@00`00GUENE@03GUD00`00HUD00003GU@01000HUERE@000V9e
00@0069eHWD0009RE004001VMFIe0003IYD00`00IYD00004IYD20004IYD00`00IYEVU@02IYD00`00
IYD00002JYD01P00JYEZU@00J[D000AZ]@05001^eFkEK]D00002K]D00`00K]D00003K]D01@00K]D0
06kE00000fkE00D007;e001bmP0000=bmP04001bmW;f0003LaH01@00MaIg5P00MaH00P000WLf00@0
07LfMcIg=P800004McH007Lf0002MeH00`00NeIkEP02000017]F001kMP000W]f00<007]f00000W^F
0`0000=kU`00NiL00P000W^g00D007^g000007_G00800003NmL007_G00800005MmL00000001gm`03
00000g?f0000000>00000e/m000000020002D[/00`00D]aBg0040002E_d00`00E_eFo@030003E_d0
0`00E_eFo@020004E_d30002E_d00`00E_eFo@030002E_d00`00E_eFo@040002E_d00`00E_eFo@04
0002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@020004E_d30002E_d00`00
E_eFo@030003E_d00`00E_eFo@030002E_d00`00E_eFo@040002E_d00`00E_eFo@040002Ool00`00
Oomoo`0EOol005moo`03001oogoo06=oo`<003Yoo`05001^mfkgK_L00002K_L01@00K_M^mfkg0000
0f<K500000<0]P000000100000<0e`000=L00P0000L4m`002?L000Sg000=5`0300002ADG000001TG
000I5`007CL000027CL300028CH01P009EH00000:EH0008YEP<000<]MP04000aMP00<GH30002<GH0
1000=GHeMP000SEf00<003FF=IH010000cVF00D003fF?IHmUP0000<mU@04000m]Cfe0002@KD01@00
@KE1]D6e00000d6e00D004FeAKE5]@0000=5]@050015eDGEAMD00003BMD01@00BME9eDWE00000dWE
00D004WEBME9e@0000A=e@03001=mDge008000==m@03001=mDge009=m@03001=mDge009=m@05001=
mDgeCOD00003DOD20003DO@00`00EOAEm002EO@01P00EQEF5@00EQD000AF5@03001F5EHE00=F5@80
009Am003001Em5Gd009Em007001J55XDFQ@005hd000015he00<005heGSD00ehe00@005iEGUENE@80
00AJ=@04001N=Ehe0002FQ@00`00GSAN=002GS@00`00GUENE@04GUD20003GU@00`00HUD00003HWD0
0`00HWD00003HU@00`00IWD00004IYD00`00IYD00004IYD00`00IYEVU@03IYD00`00IYEVU@02IYD0
0`00IYD00002JYD01000JYEZUFZE0P000fZe00<006kE00000VkE00D006kEK]E^e@0000=^e@06001^
eFkE001^e@000fkE00@007;eL_D000=bmP05001bmW;fL_H00002LaH01`00MaIg5WLF001g5P0000=g
=P04001g=WLf0002McH01000McIg=P000WMF00<007]F00000W]F0P0000AkMP00NgH0009kMP06001k
UP00NiH007^F0`0000Mk]`00NkL007^g001k]`0200000g_G001ke`02000017_G000007Og2`0000=[
mP0000002P000UKK00<005:kD[/010000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00<0
05KmE_d00P0015Km0`000UKm00<005KmE_d00`000eKm00<005KmE_d00`000UKm00<005KmE_d01000
0UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00H005Km000005Km0003E_d30002E_d00`00
E_eFo@040002E_d00`00E_eFo@030002E_d00`00E_eFo@040006Ool00`00Oomoo`0EOol005moo`03
001oogoo061oo`<003ioo`03001^m`0000=^m`04001^mfkgK_L200001F<K001S6f<K00000cZn2`00
00<0UP0000001P0000<0e`000=L00P0000<0e`0000000P000PSg00<000dG00000P0000DE5`000000
01TG00<0008M=`06000M=P00000Q=P000REF00<002UF00000RUF00@002UF0000008]MP04000aMS5f
0002<GH200001C5f000eMSEf00000SEf00H003FF=IHeUP00>IH20002>IH01@00?IHmUSfF00000cfE
00@003fe?KD000=1]@050011]D6e@KD00003@KD01@00AKE5]DFe00000dFe00@004GEAMD000=9e@05
0019eDWEBMD00003BMD00`00BME9e@02BMD01000CME=eDgE0`0000==e@00COD00dge00D004geCOE=
m@0000A=m@03001=mDge009=m@05001Am@00CM@00004DO@00`00EOAEm002EO@20002EQD00`00EQEF
5@02EQD00`00EQEF5@02EQD20003DO@00`00EOAEm002EO@01000FQAJ50000Uhd00<005heGSD00Uhe
00<005heGSD00ehe00@005iEGUD0009NE@03001J=EXe009J=@8000=J5007001N=5hdGS@0069D0000
1EiE00<005iDGU@00eiD0P00169e0P00169D0P001FJE00<006JEIYD00fJE00<006JEIYD00VJE00<0
06JE00000VJE00H006JEIYD006ZE0004JYD00`00J[EZ]@02J[D01@00K]D006kE000016kE00D006kE
K]E^e@0000=^e@05001^eFkEK]D00003L_D01@00L_IbmW;f00000W;f00D007<F001c5P00009g5P04
001g5WLF0002McH01@00McIg=WLf00000WLf0P0000Ag=P00MeH0009kEP08001kEW]F001kMP00NgH0
009kMP03001kUW^F0080009kUP03001kUP0000@00004NkL00000NmL200000g_G001ke`0200000gOG
00000002000017?f000007?f3@0000E_n`00HieSW@00009Ff`<0009Fo@03001FoEKm00@0009Fo@03
001FoEKm00@0009Fo@03001FoEKm00@0009Fo@06001Fo@00001Fo@000eKm0`000UKm00<005KmE_d0
10000UKm00<005KmE_d00`000eKm00<005KmE_d00`000UKm00<005KmE_d010000UKm00<005KmE_d0
0`0015Km0`0000AFo@00E_eFo@@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00<000Yoo`03001o
ogoo01Eoo`00Ggoo00<007ooOol0GGoo0`00@Woo0P000Vkg00D006kgK_M^m`00009^m`03001S6f<K
009S6aD000030;H0000000@000030=L000Cg00800088m`<000053AL001DG000E5`02000011TG0000
00000Qdg00L001df0000024f000UEP030003:EH01P00:EH00000;GH0008aMP05000aMS5f000aMP03
00000cEf000eMP02=GH01000=IHeUP000SVF0`0000DiUP00?IHmUP0000<mU@04000m]Cfe0003@KD0
1@00@KE1]D6e00000d6e00D004FeAKE5]@0000=5]@040015eDGE0004BMD01000BME9e@000dWE00<0
04WEBMD00TWE00<004gE00000P000dgE00<004geCOD00Tge00D004geCOE=m@0000A=m@03001=mDge
009=m@80009=e003001Am57d009Am003001Em5Gd009Em003001F5EHE009F5@05001F5EHEEQD00002
EQD200000e7e001Am003DO@00`00EOAEm002EO@20003GS@01`00GSEN=Ehe001N=@0000AN=@03001N
E@0000=NE@03001J=EXe009J=@03001J55XD009J5007001N=5hdGS@0069D00001EiE00<005iDGU@0
0eiD00<0069eHWD00f9e00<0069DHU@00f9D00<006JEIYD016JE00<006JEIYD00VJE00<006JE0000
0fJE00<006JE00000VJE00@006JEIYEVU@8000AZU@05001Z]FZeJ[D00002K]D00`00K]D00003K]D0
1@00K]D006kE000016kE00D006kEK]E^e@00009bm@05001bm@00L_H00003L_H01000LaIc5P000gLF
00L007LF001g=P00McH00002McH01000McIg=P000WLf00H007MFMeH007]F0002NeH02000NgIkMP00
NgH007]f0002NiH03000NiH007^F001kUP00NkH007^f001k]Pd00003MoH0000000800003LoH00000
00d0009SW@@0009Fo@03001FoEKm00<000=Fo@03001FoEKm00<0009Fo@03001FoEKm00@0009Fo@03
001FoEKm00<000AFo@<00004E_d005KmE_d40002E_d00`00E_eFo@040002E_d00`00E_eFo@040002
E_d00`00E_eFo@030002E_d00`00E_eFo@040002E_d00`00E_eFo@030003E_d30002E_d00`00E_eF
o@040002E_d00`00E_eFo@04000=Ool00`00Oomoo`0EOol005moo`<005Yoo`<004Moo`03001^m`00
009^m`05001^mfkgK_L00003Ha/01000Ha]S6`000SZn3`0000<0]P000000100000<0e`000=L00P00
00@4m`000008m`8000043AL0000000025AL010006AL001TG0P0000DM=`007CH0024f008000039EH0
02EF0080008YEP04000YEP00;EH300001C5f000aMS5f00000c5f0`000cEf00L003FF=IHeUP00>IH0
0002>ID400001CfF000mUCfE00000Sfe00D0046e@KE1]@0000=1]@050011]D6e@KD00003AKD01@00
AKE5]DFe00000dGE00D004WEBME9e@000099e@030019eDWE0099e@030019e@0000<00099e@03001=
eDgE009=e@05001=mDgeCOD00004COD00`00COE=m@02COD00`00COE=m@020003CM@00`00DOAAm002
DO@00`00EOAEm002EO@00`00EQEF5@02EQD00`00EQEF5@02EQD20003DOD00`00DOAAm002DO@00`00
EOAEm002EO@20003GS@01000GSEN=@000Uhe00<005heGSD00ehe00<005iEGUD00UiE00@005XeFSEJ
=@8000AJ5004001N=5hd0002HU@00`00GUENE@02GUD20005GU@00`00HWERM@03HWD00`00HUARE003
HU@00`00IYEVU@03IYD00`00J[D00003IYD00`00IYD00002IYD01P00IYEVU@00IYD000AVU@03001Z
UFZE009ZU@03001Z]@00009Z]@05001^eFkEK]D00004K]D01@00K]D006kE00000fkE00D006kE001^
e@0000=bm@05001bm@00L_H00002L_H01@00LaIc5W<F00000WLF00@007LFMaH0009g=P04001g=WLf
0003McH00`00McIg=P02000017MF001kEP000W]F00@007]f001kMP800008NgH007^F001kUP00NiH0
009kUP800004NkH007^fNkH200001W_F000007_F001keP800003MoH0000000@00005LoH00000001[
m@0:000015oj000000000U;m00<005KmE_d010000UKm00<005KmE_d010000UKm00<005KmE_d00`00
0eKm00<005KmE_d00`000UKm0P0000AFo@00000000=Fo@<0009Fo@03001FoEKm00@0009Fo@03001F
oEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00<000=Fo@03001FoEKm00<0009Fo@06001F
o@00001Fo@000eKm0`000UKm00<005KmE_d010004Woo00<007ooOol057oo001NOol2001IOol3001;
Ool01@00K_M^mfkg00000Vkg00D006kg001S6`0000=S6a00000309H0000000D000030;H0000000<0
00031?L000Cg008000032?L000dG00<000075AL00000000I5`006AH00P0000DM=P008CHQ=P00008U
EP08000UEP00000YEP00:EH000<]EP800005<GH0035f<GH00002<GH01000<GH000000SEf00L003FF
=IHeUP00>IH00003>ID00`00?IDmU@04000013fE000m]@000d6e00D0046e@KE1]@0000=1]@050015
]DFeAKD00003AKD01@00AME5eDGE00000dWE00H004WEBME9e@00BMD40002BMD00`00BME9e@02BMD0
1@00CME=eDgE000014ge00D004geCOE=m@0000A=m@<00003CM@004gD00==e005001Am57dDO@00003
EO@20004EQD00`00EQEF5@02EQD00`00DOEAm@02DOD00`00DOAAm002DO@00`00EOAEm002EO@00`00
GSAN=002GS@01000GSEN=@000Uhe00<005heGSD00ehe00<005iEGUD00UiE00H005XeFSD005XE0005
FQ@20004HU@01`00GUENEEiE001NE00000=NE08000ARM@8000ARE003001VM00000AVU@03001Z]@00
009VU@06001VUFJE001VU@0016JE0P0016JE00<006ZEJYD00VZE00<006Ze00000VZe00D006kEK]E^
e@0000=^e@05001^eFkEK]D00004K]D01@00K]D006kE00000W;e00D007;eL_Ebm@0000=bmP08001c
5W<F001g5P00MaH0009g5P03001g=WLf00800005McH007LfMcH00002McH01P00MeIgEP00NeH0009k
EP07001kMW]f001kMP00NgH00P0000ekUP00NiH007^F001kUP00NkH007^f001k]P0200001W_F0000
07_F001keP800003MoH0000000800003LoH000000100009K?@03001BoE;m00<0009Fo@03001FoEKm
00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00<000=Fo@05001Fo@00
E_d00003E_d30002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d0
0`00E_eFo@040002E_d00`00E_eFo@020004E_d00`00E_d00002E_d00`00E_eFo@03000FOol00`00
Oomoo`0DOol005ioo`03001oogoo05Ioo`8004moo`03001^m`00009^m`05001^mfkgK_L00003Ha/0
1000Ha]S6`000SZn4P0000<0]P0000000`0000`0e`00000000Cg0008m`003AL0013g00025AL30000
0aTG000I5P0200002Qdf000Q=R4f000UEP009EH002UF0P000RUF00D002eF;EH002eF0080008aMP04
000aMS5f0002<GH200000cEf000eUP02=IH01000>IHiUP000SVE00D003fE?IDmU@00008mU@D00091
]@050011]D6e@KD00003@KD01@00AKE5]DFe00000dFe00D004GEAME5e@0000A9e@030019e@000080
0099e@050019eDWEBMD00004BMD01@00CME=eDgE000014ge00D004geCOE=m@0000==m@8000==e003
001=e4gD009=e005001Am57dDO@00002EO@01000FSAJ=0000eHE00@005HEEQEF5@8000EAm@05001A
m57dDO@00004EO@00`00GSAN=003GS@20004GSD01000GSEN=Ehe0P001EiE0P000UXE00<005XDFQ@0
0eXD0P00169D00@005iEGUD0009NE007001NE5iDGU@0069d00000f9e00<0069D00000f9D00<006Id
00000fJE00H006ZeJ[D006JE0004IYD20004IYD00`00IYEVU@02IYD20003JYD01P00J[EZ]@00J[D0
00=^e@03001^e@00009^e@05001^eFkEK]D00003K]D01@00K]E^eFkE00000g;e00D007;eL_Ebm@00
009bmP05001c5W<FLaH00002MaH01000MaIg5P000WLf00@007LfMcH0009g=P05001g=WLfMcH00002
MeH01@00NeH007]F00000W]f00<007]f00000W]f00D007^F000007^F00800009NiH007^f001k]P00
NkH007^f00800006NmH00000NmH007_F0`0000=gmP0000000`0000=_m@00000030000U/m10000U;L
00<005KmE_d00`000eKm00<005KmE_d00`000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm
00<005KmE_d00`000eKm00<005Km00000UKm00<005KmE_d00`000eKm00<005KmE_d00`000UKm00<0
05KmE_d010000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00<005KmE_d00`000eKm0`00
6Goo00<007ooOol057oo001NOol00`00Oomoo`1COol3001BOol01@00K_M^mfkg00000fkg0P0000=S
6`00Ha/00V<K4`0000<0UP000000100000@0eP000000eP8000031?L000Sg008000094?L000005AL0
01DF000I5`00008I5P03000M=P00008Q=P<000049EH002UF:EH200001BUF000]EReF00000ReF00@0
035f<GH000<aMP04000aMP00=GH30002=IH01000>IHiUP000cVE00@003fE?ID000<mU@03000mUCfE
00<00003@KD0046e0091]@050011]D6e@KD00003AKD01@00AKE5]DFe00000dGE00<004WE00000`00
00=9e@00BMD00TWE00<004WEBMD00TWE00D004WEBME9e@0000A=e@05001=mDgeCOD00004COD30000
0dgD001=e002CM@00`00CMA=e002CM@00`00DOAAm002DO@00`00EO@00002FS@01@00EQEF5EHE0000
0UHE00<005HE00001E7e00D0057dDOAAm00000=Em08000EN=003001N=Ehe00=N=@04001N=Ehe0002
HUD00`00GUENE@02GUD00`00FQEJ5@02FQD00`00FQAJ5002FQ@00`00HUARE003HU@00`00GUD00003
GU@01000GUANE0000V9d00@0069eHWD0009RE004001RE69D0003IW@01000IYEVU@000fZe0P0016JE
00<006JEIYD00fJE00<006JEIYD00VJE00<006Id00000VZE00@006ZeJ[EZ]@8000=^e@05001^e@00
K]D00003K]D00`00K]D00002K]D01@00K]E^eFkE00000g;e00P007;eL_D007<E001bmP000W<F00D0
07LFMaIg5P00009g5P04001g=WLf0002McH200001GLf001g=WLf00000WMF00H007]F000007]F0002
NgH01@00NgH007]f00000W^F00<007^F00000P0000=kUP00NkH00P000W^f0P0000IkeP00001keP00
NmH300000gOf0000000200000g?f0000000=000016^l000000000UKL00<005;LD]`010000UKm00<0
05KmE_d010000UKm00<005KmE_d00`000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00<0
05KmE_d00`000eKm0`000UKm00<005KmE_d010000UKm00<005KmE_d00`000eKm00<005KmE_d00`00
0UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00@005Km000001aoo`03001oogoo01Aoo`00
GWoo00<007ooOol0D7oo0`00EWoo00<006kg00000fkg00@006kgK_L000=S6`04001S6f<K0002>[h<
00000`2E0000000500002P2f0000003F0000eP001?L000Sg0`0000D@m`00000001DF00<0008I5P<0
008Q=P06000Q=P00000UEP000RUF0`000beF00<002eF;EH00`000c5f00<0035f00000cEf0P0000De
UP00>IHiUP0000<iU@05000mUCfE?ID00002?ID01000?IDmU@000SfE100000=1]@00@KD00T6e00D0
04FeAKE5]@0000=5]@030015e@0000<00099e@040019eDWE0004BMD01@00BME9eDWE000014WE00D0
04gECME=e@0000A=m@03001=m@00008000==e003001=e4gD009=e005001=e4gDCM@00004DO@20003
FS@00`00EQEF5@02EQD20003EQD00`00DOEAm@02DOD01@00DOAAm57d00000UGd00@005XdFS@000AN
=003001N=Ehe00=N=@04001N=Ehe0002HUD00`00GUENE@02GUD00`00FQEJ5@02FQD00`00FQAJ5002
FQ@00`00HUARE004HU@20003GU@01000GUANE0000V9d00@0069eHWD0009RE004001RE69D0003IW@0
0`00IYD00004J[D00`00IYEVU@03IYD00`00IYEVU@02IYD20003IYD01000IWAVM0000VZE00D006Ze
J[EZ]@0000A^e@05001^e@00K]D00003K]D01@00K]D006kE00000fkE00D007;E001bm@0000=bm@04
001c5G<E0003LaH02000MaIg5P00MaH007LF0002McH00`00McH00002McH01@00McIg=WLf00000WMF
00D007]F001kEP00009kMP03001kMP00009kMP03001kUP00009kUP800004NiH00000NkH200000g^f
001k]P0200001W_F000007_F001keP@00003LoH0000001400003Hed005KL009Fg0<0009Fo@03001F
oEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00<000=Fo@03001FoEKm00<0009Fo@800003
E_d000000080009Fo@06001Fo@00001Fo@000eKm0`000UKm00<005KmE_d010000UKm00<005KmE_d0
10000UKm00<005KmE_d00`000UKm00<005KmE_d010000UKm00<005KmE_d00`007Woo00<007ooOol0
57oo001NOol00`00Oomoo`1=Ool3001JOol01@00K_M^mfkg00000fkg0P0000=S6`00Ha/00f<K5@00
00X0]P000000eP000=H0003F0004m`8000053?H00000000@mP02000011DF000000000QTF0`000R4f
00D0024f000UEP00008YEP04000YEP000002;EH01@00;EH]EP00;GH00P000S5f00@0035f<GH0008e
MP03000eMP0000800003>IH003VE008iU@05000mUCfE?ID00003?ID00`00?ID00003?ID00`00?IDm
U@0?0002BMD01@00BME9eDWE00000dWE00D004WEBME9e@0000=9e@030019eDWE0099e@05001=eDgE
CMD00003COD30002CM@01@00CMA=e4gD000014gD00D004gDCMA=e00000AAm003001J=5Xd009J=003
001F5EHE009F5@03001F5EHE009F5@03001AmE7e009Am@03001Am57d009Am003001Em000009J=004
001N=5hdGS@20006GSD20003HUD01000GUENEEiE0P0015XE00@005XDFQAJ508000IRE003001NE5iD
009NE003001NE00000=RM003001RM@0000=RE004001RE69D0003IW@00`00IYD00004J[D00`00IYEV
U@02IYD20004IYD00`00IWD00002IYD01P00IWAVM000JYD000AZ]@05001^eFkEK]D00003K]D00`00
K]E^e@02K]D01@00K]D006kE00000fkE00D007;E001bm@00009bm@05001c5G<ELaD00002LaH01@00
MaIg5WLF00000WLF00@007LfMcH0009g=P04001g=WLf0002McH01P00MeIgEP00NeH0009kEP800006
NgH007]f001kMP000W^F00@007^F0000009kUP03001k]P0000h00003MoH0000000D00003JoD00000
00X000ASG@05001Fg000E_d00003E_d30002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d0
0`00E_eFo@040002E_d00`00E_eFo@030003E_d00`00E_eFo@020004E_d3000015Km001FoEKm1000
0UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00<005KmE_d00`000eKm00<005KmE_d00`00
8Goo00<007ooOol057oo001NOol00`00Oomoo`1:Ool3001NOol00`00K_L00003K_L00`00KaM_5`02
0003Ha/00`00Ha/00002>[h@0000102F0000002f0P000P3F1`0000P<mP00000@mP005AH001DF0P00
00<I5P007CH00P0000<Q=P008CH00`000RUF00<002UF:EH00P0000D]EP00;EH]EP00008]MP800005
<GH0035f<GH00002=GH01000=GHeMSEf0`000cVE00D003fE?IDmU@0000<mU@04000mUCfE0002?ID0
1@00?IDmUCfE00000d6e00D004FeAKE5]@0000=5]@050019eDWEBMD00004BMD01000BME9e@000dWE
00<004WEBMD00TWE00D004WEBME9e@0000A=e@<00003BMD004gD009=e003001=e4gD009=e005001=
e4gDCM@00003CM@00`00DOAAm002DO@00`00FSAJ=002FS@01000EQEF5EHE0P0015HE00<0057eDOD0
0U7e00<0057dDO@00U7d0P000eXd00L005hdGSAN=000IYD00005GSD00`00HUERE@02HUD01000GUEN
E@000UiF00D005XEFQEJ5@0000=J5003001N=00000ERE003001NE5iD00=NE08000ARM08000=RE003
001RE00000EVM003001Z]FZe009Z]@03001Z]@0000=VU@03001VM@00009VU@04001VMFIe0002IYD0
1000IWAVM6Id0P000fZe00<006kE00000VkE00D006kEK]E^e@0000=^e@05001^eFkEK]D00004K]D0
1000L]Ebe@000g;e00P007<ELaD007LF001c5P000WLF00D007LFMaIg5P00009g=P0<001g=WLf001g
=P00McH007Lf001gEP000W]F00<007]F00000W]f0P0000IkMP00NgH007^F0002NiH2000017^F001k
]W^f0P0000=k]P00NmH00P0000QkeP00001keP00MmH007Of1@0000=_mP0000002@0000EOm`00001O
o@00009SG@<000=Fo@03001Fo@00009Fo@03001FoEKm00<000=Fo@03001FoEKm00<0009Fo@03001F
oEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm008000=Fo@<000=F
o@03001FoEKm00<0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@002Ao
o`03001oogoo01Aoo`00GWoo00<007ooOol00P00AGoo0`00HWoo0P000Vkg00T006lGKaM_5`00KaL0
06<K00000f<K400000D0U@000000002f00<00080eP0;0000eP000004eP003?H000cf000@mP030000
0aDF000I5P0200000adf000M=P0200000b4f000U=P020002:EH01000:EH002UF0P000beF00@002ef
000aMP<00003<GH003Ef008eMP05000eMSEf000eM@020002>ID01@00?IDmUCfE00000cfE00@003fE
?ID000<mU@04000mUCfE0003@KD01@00AKE5]DFe00000dFe00<004WEBMD00TWE00D004WEBME9e@00
0099e@030019eDWE0099e@050019eDWEBMD00004BMD00`00CMD000020003BMD01@00CMA=e4gD0000
14gD00D004gDCMA=e00000==e004001Am57dDO@20005FS@00`00EQD00002FSH00`00EQEF5@02EQD0
1@00DOEAmE7e00000e7d0P0015Xd00@005hdGS@0009VU@03001N=Ehe00=N=@03001REF9E00=RE@80
00=NEP05001J5EXEFQD00002FQ@01000GSAN=000169D0P001EiD00<0069dHW@00f9d00<0069DHU@0
0f9D0P001FId00<006ZeJ[D00VZe00<006Ze00000VJE00@006IeIWD0009VU@06001VMFIe001VU@00
16Id00<006ZeJ[D00VZe00H006kEK]D006kE0002K]D00`00K]D00002K]D01@00K]E^eFkE00000fkE
00D007;EL]Ebe@00009bm@05001c5G<ELaD00002MaH01@00MaIg5WLF00000WLF00L007Lf001g=P00
McH00002McH00`00McIg=P02000017MF001kEP000W]F00D007]fNgH007]f00800003NgH00000009k
UP80009kUP07001k]P00001k]P00NmH00P0000QkeP00001keP00MmH007Of0P0000=cmP0000001@00
00=Se0000000100000AOm`00001Oo@@0009G7@03001FoEKm00<000=Fo@<0009Fo@03001FoEKm00@0
009Fo@03001FoEKm00<0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0
009Fo@03001Fo@00009Fo@03001FoEKm00@0009Fo@03001FoEKm00<0009Fo@03001FoEKm00@0009F
o@03001FoEKm00@002Qoo`03001oogoo01Aoo`00GGoo1000A7oo0`00Igoo00<006kg00000VlG00D0
06lGKaM_5`0000=S6`06001S6`00>[h0005I4P0000@0]P000000eP8000030=H000000080008<mP03
000@mP00008000035AH001TF00<0008M=P8000038CH002Df00800006:EH002UF:EH002UF0P000ReF
00<002ef00000c5f0`000cEf00@003Ef=GH0008eM@<00005>ID003fE?ID00003?ID01000?IDmU@00
0cfE00D003fE?IDmU@0000=1]@050015]DFeAKD00003AKD01@00BME9eDWE00000dWE00D004WEBME9
e@0000=9e@050019eDWEBMD00003BMD30002BMD01@00BME9eDWE000014gD00D004gDCMA=e00000==
e003001=e4gD009=e003001Am000009F5003001J=5Xd009J=08000=J=P03001F5EHE009F5@03001A
mE7e009Am@05001Am000DOD00004FS@01000GSAN=0000VJE00<005heGSD00Uhe0P001F9E00<005iF
GUH00UiF00<005XEFQD00UXE0P000ehd00<0069DHU@00V9D00<006ZE000015iD00<0069dHW@00f9d
00<0069DHU@00f9D00<006IdIW@00fId00<007;E00000VZe00H006ZeJ[D006JE0003IWD00`00IYD0
0004IWD20004IW@00`00J[EZ]@02J[D01@00K]E^eFkE00000fkE00H006kEK]D006kE0002K]D00`00
K]D00002K]D02000L]Ebe@00L_D007;e0002LaD01@00MaIg5WLF00000WLF00D007LFMaIg5P00009g
=P06001g=WLf001g=P000gLf00<007MF00000W]F00H007]FNeH007]f0002NgH04P00NgH007^F001k
UP00NiH007^F001k]P00NkH007^f001keP800005NmH00000001geP0200000gOf0000000300000foe
0000000=0002Ead00`00EaeG7@040002E_d01P00E_d00000E_d000=Fo@<0009Fo@03001FoEKm00@0
009Fo@03001FoEKm00<000=Fo@03001FoEKm00<0009Fo@03001FoEKm00@0009Fo@03001FoEKm00<0
00=Fo@<0009Fo@03001FoEKm00@0009Fo@03001FoEKm00<0009Fo@03001FoEKm00@002eoo`03001o
ogoo01=oo`00GGoo00<007ooOol0@Woo0`00Jgoo00@006lGKaL000A_5`800003Ha/006<K009S6`<0
00030ET0000000h000040;H000000;H300000`3F0004eP0200023?H30000113f000000000QTF00<0
01df00000Qdf00H0024f000U=P009CH20002:EH00`00:EHYEP0200001BeF000]MRef00000S5f00@0
035f0000008eMP07000eMSEf=GH003Ee00000SVE100000DmU@00?IDmU@00008mU@05000mUCfE?ID0
0003?ID01@00@KE1]D6e00000dFe00D004FeAKE5]@0000=9e@050019eDWEBMD00003BMD01@00BME9
eDWE000014WE0`0000=9e@00BMD00TWE00<004WEBMD00TWE00D004gDCMA=e00000==e005001=e4gD
CM@00004CM@20003EQ@00`00FSAJ=002FS@00`00FSIJ=P02FSH00`00EQEF5@02EQD00`00DOEAm@02
DOD20002DOD00`00FSAJ=003FS@20003IYD01@00GSEN=Ehe00000V9e00<0069EHUD00V9E00<005iF
GUH00UiF00<005XEFQD00UXE0P0015hd00@0069DHU@0009ZU@04001NE5iDGU@20004HW@20005HU@0
0`00IWAVM003IW@01@00L]D006Ze000016Ze0P0016Ie0P0016Ie00<006IdIW@00VId00<006ZD0000
0VZe00<006kEK]D00VkE00D006kEK]E^e@0000=^e@05001^eFkEK]D00002K]D00`00K]D00002L]D0
1000L_Ebm@000g<E00P007LFMaH007LF001g5P000WLF00@007LfMcIg=P800004McH007Lf0002McH0
0`00MeIgEP02000017]F001kEP000W]f00<007]f00000W]f0`0000=kUP00NiH00P000W^f0P0000=k
]P00NmH00P0000QkeP00001keP00MmH007Of0`0000=cm@00KoD00P0000=We000000020000U<N00<0
05LMEad00`000e;l00<005KmE_d00P0015Km0`0000AFo@00E_eFo@@0009Fo@03001FoEKm00@0009F
o@03001FoEKm00@0009Fo@03001FoEKm00<0009Fo@03001FoEKm00@0009Fo@06001Fo@00001Fo@00
0eKm0`000UKm00<005KmE_d010000UKm00<005KmE_d00`00<Goo00<007ooOol04goo000TOol4000>
Ool3000<Ool:000>Ool00`00Oomoo`10Ool2001_Ool00`00KaL00003KaL01000KaM_5`000f<K00@0
06<K000j_Pl0000;09D000000000UP000;H0002f0000eP02000010SF000<mPcf0P0000<@mP004?H0
0P0000@I5P007CH0008M=P<0008U=P06000U=P00000YEP000RUF00<002eF00000P0000D]MP00<GHa
MP00008aMP800003=GH003Ef008eMP03000eM@0000<iU@03000mUCfE00@00004?ID003fE0003?ID0
1@00?IDmUCfE00000d6e00D004FeAKE5]@0000=5]@050019eDWEBMD00003BMD01@00BME9eDWE0000
14WE00<004WE00000P000dWE00D004WEBME9e@0000A9e@05001=e4gDCM@00003CM@00`00CMA=e002
CM@00`00CMA=e0020004EQ@00`00FSAJ=002FS@00`00FSIJ=P03FSH01@00EQEF5EHE00000e7e0P00
157e00<005XdFS@00UXd0P000fJE00@005heGSD000=RM@04001REF9EHUD20004GUH01000FQEJ5EXE
0P001Ehd00@0069DHU@0009ZU@07001NE5iDGU@0069e00000f9d00<006ZE00000f9D00<006Id0000
0fId00H007;EL]D006Ze0004J[D00`00IWEVM@03IWD00`00IWEVM@03IWD00`00IWAVM002IW@01P00
JYAZU000J[D000=^e@05001be@00K]D00004K]D01@00K]E^eFkE00000fkE00D007;EL]Ebe@00009b
m@05001c5G<ELaD00002MaH01000MaIg5P000gLF00@007LfMcH0009g=P03001g=P0000=g=P03001g
EP00009kEP06001kEW]F001kMP000W]f00H007]f001kUP00NiH300001G^F001k]P00NkH00P0000=k
eP00NmH00P0000AkeP00001geP<00005LoD00000001_m@0:0002Fcd70002D]`00`00D_aBo0040002
E_d00`00E_eFo@020003E_d30003E_d00`00E_eFo@030002E_d00`00E_eFo@040002E_d00`00E_eF
o@040002E_d00`00E_eFo@030003E_d00`00E_eFo@020004E_d3000015Km001FoEKm10000UKm00<0
05KmE_d01000=7oo00<007ooOol04goo000ROol8000;Ool5000;Ool:000>Ool00`00Oomoo`0mOol3
001bOol01@00KaM_5flG00000flG0P0000=S6`00Ha/00V<K3@0000<0M00000001@0000<0UP000;H0
0P0000@0eP000008eP8000093?H000cf000@mP004?H001TF00<0008M=P06000M=P00000U=P000RDf
0P0000@YEP00:EH000<]EP03000]MP0000<aMP04000aMP00<GH20003=GH01000=GDeM@000SVE00D0
03fE?IDmU@00008mU@D0008mU@05000mUCfE?ID00003@KD01@00AKE5]DFe00000dFe00D004WEBME9
e@0000A9e@060019eDWEBMD004WE10000TWE00D004WEBME9e@0000A9e@050019eDWEBMD00003CM@0
0`00CMA=e002CM@01000CMA=e4gD0`0000==m@00EQ@00eHD00@005XdFSAJ=08000EJ=P03001F5EHE
009F5@<00003CQH0057e00=Am@03001J=5Xd009J=003001VUFJE00=VU@8000ARM@04001REF9E0002
I[H00`00GUINEP02GUH01@00FQD005Hf00001Ehd00<0069D00000fZE00@005iDGU@0009RM@04001R
M69d0002JYD01`00HUARE69D001VM00000=VM005001beG;EL]D00005J[D00`00IWEVM@03IWD00`00
IWEVM@02IWD00`00HU@00003IW@01P00JYAZU000J[D000=^e@05001be@00K]D00003K]D01@00K]D0
06kE000016kE00@007;EL]D0009bm@05001c5@00LaD00002MaH01@00MaIg5WLF00000WLF00D007Lf
McIg=P00009g=P03001g=P00009g=P04001gEWMF0002NeH200000g]F00000002NgH00`00NgIkMP02
0002NiH00`00NiH0000400001W^f000007_F001kePL00003MoD0000000@00003Jm@0000000L00004
Fcd005KK0003D[`00`00D]aBg0040002E_d00`00E_eFo@040002E_d00`00E_d00002E_d00`00E_eF
o@040002E_d00`00E_eFo@030002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eF
o@040002E_d00`00E_eFo@020003E_d30002E_d00`00E_eFo@04000hOol00`00Oomoo`0COol0029o
o`8000Aoo`8000]oo`D000moo`80019oo`03001oogoo03Yoo`<007Ioo`03001_5`0000=_5`04001_
5flG0003Ha/01000Ha/003jn4P000P2F0P0000H0]P000000eP002=H3000010cf000@mP000Q3f00<0
01TF00000P000Qdf00T001df000002Df000U=P009CH00P000RUF00<002eF;EH00`000c5f00<0035f
00000S5f0P000SEf00@003Ee=GD000<iU@04000mUCfE0003?ID00`00?IDmU@0300001CfE000mUCfE
00000d6e00D004FeAKE5]@0000=5]@030019eDWE0099e@060019eDWEBMD004WE10000TWE00D004WE
BME9e@0000A9e@050019eDWEBMD00003BMD01@00CMA=e4gD000014gD00<004gD00000P000dge00<0
05HDEQ@00UHD00@005XdFS@0009VUP03001J=UXf009J=P04001F5EHEEQD20003CQH00`00DOEAm@02
DOD00`00FSAJ=002FS@00`00IYEVU@03IYD00`00HWERM@03HWD01000HUERE@000VJf00<005iFGUH0
0UiF0P000eHf00<005hdGS@00ehd0P000fZE00<005iD00000f9e00@0069dHW@0009ZU@04001RE69D
0003IW@01000IWAVM0000g;E00<006ZeJ[D00VZe0P0016Ie0P0016Ie00<0069D00000VId00<006ZD
JY@00VZD00D006kEK]E^e@00009be@03001^e@0000=^e@05001^e@00K]D00003K]D01@00K]D007;E
00000W;e00D007<E001c5@00009g5P08001g5WLF001g5P00MaH0009g=P06001g=WLf001g=P000WLf
00@007MFMeH0009kEP08001kEW]F001kMP00NgH0009kMP0<001kUP00NiH007^F001k]P00NkH007^f
1`0000IkeP00001geP00MoD?00000foL00000003E]/00`00D[aB_0030003E_d00`00E_eFo@030002
E_d00`00E_eFo@030003E_d30002E_d00`00E_eFo@040002E_d00`00E_eFo@030003E_d00`00E_eF
o@030002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_d00002E_d00`00E_eFo@03
000lOol00`00Oomoo`0COol0025oo`8000Ioo`8000Yoo`D000moo`80019oo`03001oogoo03Moo`<0
07Yoo`05001_5flGKaL00003KaL200000f<K001S6`02Ha/00`00?[hn_P0?00001@2E0000UP000;H0
1@0000<8eP002=H00P0000<<mP0000000Q3f00@001TF000I5P8000057CH001df000Q=P0200001BDf
000U=RDf00000RUF00D002eF;EH002eF0080008aMP04000aMS5f0002<GH200001CEf000eMCEe0000
0cVE00D003fE?IDmU@00008mU@04000mUCfE0002?ID30002?ID01@00@KE1]D6e00000dFe00D004Fe
AKE5]@0000=9e@030019e@0000<00099e@050019eDWEBMD00004BMD01@00BME9eDWE00000dWE00D0
04WEBME9e@0000A=e003001=e4gD00<00099e@03001=mDge009=m@03001F55HD009F5003001J=000
009VUP03001J=UXf00=J=P<00003DSH004hF00=>5P05001AmE7eDOD00003FS@00`00K_L00004IYD0
0`00HWERM@04HWD20003I[H01000GUINEUiF0P0015Hf00<005hdGS@00ehd00<006ZEJYD00fZE0P00
0f9e00<0069d00000fZE00@0069DHU@000=VM003001VM00000=be@03001bm@0000=Z]@03001RM@00
00=VM@03001VM@00009VM@07001RE69DHU@006Id000016ZD00D006kEK]E^e@0000=be@05001^eFkE
K]D00002K]D00`00K]D00003K]D01@00K]D007;E00000W;e00@007<ELaD000=g5P04001g5WLF0002
MaH01@00McIg=WLf00000WLf00H007Lf000007Lf0002MeH01000NeIkEP000W]F0`0000IkMP00NgH0
07^F0002NiH01P00NiH00000NkH0009k]P800003NmH007_F00@00005MmH00000001cm@0200000fod
0000000:000016=M001FfeKK10000UKm00<005KmE_d010000UKm00<005KmE_d00`000UKm00@005Km
0000009Fo@03001FoEKm00<0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm
00<0009Fo@03001FoEKm00@0009Fo@03001FoEKm00<000=Fo@<003moo`03001oogoo01=oo`008Goo
0P001Woo0P002goo0`0047oo0P004Goo00<007ooOol0=Goo0`00OWoo00<006lG00000flG00@006lG
KaL000AS6a00000307D000000080000709H000000000]P000=H00P000PSF00<000cf00000P0000L@
mP00000001TF000I5P0200001Adf000Q=R4f00000RDf00H002Df9CH002UF0003;EH01P00;EH00000
<GH0008aMP05000aMS5f000eM@0300000cEe000iU@02>ID01@00?IDmUCfE00000cfE00<003fE0000
0cfE00<003fE00000P000d6e00D004FeAKE5]@0000=5]@030019e@0000<00099]0050019eDWEBMD0
0003BMD00`00BME9e@02BMD01@00BME9eDWE00000dWE00<004WEBMD00TWE00@004gDCMA=e0<00003
COD004WE0099e@03001=mDge009=m@03001F55HD009F508000=VUP03001J=UXf009J=P8000=B=P03
001>5ThF009>5P05001AmE7eDOD00002FS@01000K_M^m`000fJE00<006KG00001F9e00<006JfI[H0
0VJf00H005iFGUH005IG0004ESH00`00GSAN=003GS@00`00JYEZU@03JYD00`00HWERM@03HWD20003
JYD00`00HU@00004IW@00`00IW@00003L]D00`00L_D00002J[D01000HWERM@000VIe00@006IeIWD0
009VM@07001RE69DHU@006Id00000fZD00<007Kd00000VkE00D007;EL]Ebe@0000=^e@05001^eFkE
K]D00003K]D01@00K]E^eFkE00000W;e00D007<ELaEc5@00009g5P04001g5WLF0003MaH01000McIg
=P000WLf00<007Lf00000WLf00@007MFMeH0009kEP07001kEW]F001kMP00NgH00P0000ekMP00NiH0
07^F001kUP00NkH007^f001k]P0200000g_F001keP0300000g_F0000000200000g?e0000000=0002
Hed30002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@020004E_d30002E_d0
0`00E_eFo@030002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@030002E_d0
0`00E_eFo@040002E_d01000E_d00000@Woo00<007ooOol04goo000POol20008Ool2000MOol2000A
Ool00`00Oomoo`0bOol30022Ool01@00KaM_5flG00000flG0P0000=S6`0000000V<K00D003jn?[h0
006K014000030;H0000000@000062=H00000000<mP000Q3f0`0000<I5P006AH00P0000LM=P008CHQ
=P009CH000029CH30003;EH01000;EH002eF0`0000DaMP00<GHaMP0000<eM@<000<iU@05000mUCfE
?ID00003?ID01000?IDmU@000SfE00@003fE?IDmU@h00099]0050019]4VdBK@00003BMD00`00BME9
e@02BMD01@00BME9eDWE00000dWE00D004WEBME9e@0000A9e@03001=e000008000==m@030019eDWE
0099e@05001=mDgeCOD00004EQ@00`00IYIVUP03IYH400000eIG001B=P03DSH01@00CQI>5ThF0000
157e00<005Xd00000Vkg00@006JEIYD0009Ve`03001RMF9e00=RM@03001V]VJf00=V]P80009FE`03
001F=UHf00=F=P07001N=5hdGS@006kg000016ZE00<0069eHWD00f9e00<006ZEJYD00fZE0P001FId
00D007;EL]Ebe@00009bm@03001Z]@0000=RM@03001VM@0000=VM@03001VM@0000ARE08000AZU005
001fm000K]D00003L]D00`00K]D00002K]D01@00K]E^eFkE00000fkE00D006kEK]E^e@00009bm@08
001c5G<E001g5@00MaH0009g5P08001g5WLF001g=P00McH0009g=P03001g=P00009g=P800005MeH0
07]FNeH00002NeH20002NgH01@00NgH00000NiH00P000W^F0P0000Ek]P00NkH007^f00800003NmH0
07_F00<00003MmH0000000800003LoD0000000T00003God000000080009G7@03001FoEKm00<000=F
o@03001FoEKm00<0009Fo@03001FoEKm00@0009Fo@06001Fo@00001Fo@000UKm10000UKm00<005Km
E_d00`000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00<005KmE_d00`000eKm00<005Km
E_d00P00AGoo00<007ooOol04Woo000POol20008Ool2000MOol2000AOol01000Ool00000;Woo0`00
QWoo00<006lG00000flG00@006lGKaL000AS6`h0000305@0000000@0000409D000000;H20000103F
000000SF1@0000H@mP005?H001TF00026AH00`007CH000028CH00`009CH000029CH01000:EH00000
0ReF00<002eF00000beF00<0035f00000c5f00D003Ee=GD003Ee0080008iU@05000mUCfE?ID00003
?ID01000?IDmU@000cfE00@003fE?ID000<mU0050015U4FDAI@00003AK@01@00BKA9]4Vd00000dVd
00<004WEBMD00TWE00D004WEBME9e@0000=9e@050019eDWEBMD00004BMD00`00BME9e@030002COD0
0`00COE=m@02COD01@00BME9eDWE00000dge00<005HDEQ@00UHD00<006JFIYH00fJF00<005IGEUL0
0UIG00<0058fDSH00U8f00D004hFCQI>5P0000AAm@8000A^m`8000=Ve`03001RMF9e009RM@03001_
600000=V]P8000AFE`03001F=UHf009F=P04001N=5hd0002K_L01000JYEZUFZE0P001F9e00<006ZE
JYD00fZE00<006IdIW@016Id00D007;EL]Ebe@0000=bm@8000ARM@8000AVM@8000ERE003001ZU6ZD
009ZU005001fm000K]D00003L]D01@00K]D006kE00000fkE00<006ZE00000VkE00P006kEK]D007;e
001bm@000W<E00@007LEMaD000=g5P04001g5WLF0002McH01000McIg=P000WLf00<007Lf00000W]F
00@007]FNeH0009kEP05001kMP00NgH00002NgH02000NiH007^F001kUP00NkH20002NkH200000g_F
001keP0300000g_F00000002000017?e000006od2`000ULM00<005LMEad010000UKm00<005KmE_d0
10000UKm00<005KmE_d00`000UKm00<005KmE_d00`000eKm0`000UKm00<005KmE_d010000UKm00<0
05KmE_d00`000eKm00<005KmE_d00`000UKm00<005KmE_d010000UKm00<005KmE_d01000Agoo00<0
07ooOol04Woo000POol20008Ool2000MOol2000AOol2000]Ool3002:Ool01@00KaM_5flG00000flG
0P0000=S6`0000000UlK00D004:n@[h000WL00P0000305@000000080000409D000000;H20000102f
000000CF0P0000<8eP003?H00`0000@DmP000000008I5P<0008Q=P<000<U=P06000YEP00000]EP00
0ReF00<002eF;EH00`000c5f00@003Ee=GD0008eM@<00005>ID003fE?ID00003?ID01000?IDmU@00
0cfE00@003fE?ID000<mU0050015U4FDAI@00003AK@01@00BKA9]4Vd000014Vd00D004WEBME9e@00
00=9e@050019eDWEBMD00004BMD01000BME9eDWE0`0000==m@00COD00Tge00<004geCOD00Tge00D0
04WEBME9e@0000==m@07001F55HDEQ@006[g00000fJF0P001EIG00D0058fDSIB=P0000=>5P04001A
mE7eDOD20005K_L00`00I]MVe`03I]L01000HWERM@000VlH00H006JfI[H006KI0004EUL00`00ESIF
=P02ESH01000GSAN=0000Vkg00@006ZEJYD0009Ve`07001RMF9eHWD006lG000016ZE00<006IdIW@0
0fId00<007<F00000W;E00D007;eL_Ebm@0000ERM@03001VMFIe00=VM@03001RE69D00ARE005001Z
U6ZDJY@00003M_@01@00L]EbeG;E00000VkE00<006kE00000fkE00D006ZE001^e@0000=^e@04001b
m@000003LaD01000MaEg5@000WLF00@007LFMaH000=g=P800004McH007Lf0002McH00`00NeIkEP02
00002g]F001kEW]F001kMP00NgH007]f00000W^F0`0000=kUP00NkH00P0000=k]P00NkH00P0000=k
eP00NmH0100000=gm@00LoD0100000=[e00000001@000U<N00<005LMEad00`000U;l00<005KmE_d0
10000UKm00<005KmE_d010000UKm00<005KmE_d00`000UKm00@005Km0000009Fo@03001FoEKm00<0
009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00<0009Fo@03001FoEKm00@0
04]oo`03001oogoo019oo`0087oo0P0027oo0P007Goo0P004Goo00<007ooOol0:Goo0`00SWoo00<0
06lG00000flG00<006lHKaP00P000elK3P0000<0E00000000`0000D0U@000000002f00<000071=H0
00SF000<mP003?H00P0000LDmP00000001TF000M5P0200028CH300029CH01000:EH002UF0`0000H]
EP00;EH]EP00<EH20002<GH01`00=GDeMCEe000eM@00008iM@<0008mU@04000mUCfE0002?ID01@00
?IDmUCfE00000SfE00D003fD?I@mU00000=5U0050015]4FdAK@00004BK@01@00BKA9]4Vd00000dWE
00D004WEBME9e@0000A9e@060019eDWEBMD004WE0`000dge00<004geCOD00Tge00D004geCOE=m@00
00=9e@03001=mDge009=m@03001F5000009Zm`04001VUVJF0002I_T00`00EUMFE`02EUL01@00DSIB
=U8f000014hF0`0000=Jn`00K_L00fkg0P001FKG00@0069eHWD0009_6003001V]P0000=Vf@05001F
EeIGEUL00005ESH20004K_L20003I]L01000HWERM@000VlG00L006ZEJYEZU@00I[L00004IW@01@00
LaH007;E000017;e00<0069eHWD00f9e00<006IeIWD00fIe00<0069DHU@00f9D0P000fZD00D007Kd
M_Afm00000=be@05001^eFkEK]D00003K]D01P00JYEZU@00K]D000=^e@04001bmG;e0002LaD02000
MaEg5@00MaD007LF0002MaH01000McIg=P000WLf00@007LfMcH0009g=P03001kEP00009kEP06001k
EW]F001kMP000W]f00P007]f001kUP00NiH007nF3P0000=ge@000000200000=O/`0000000`000U<N
10000U;L00<005;lD_`00`000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00<005KmE_d0
0P0015Km0`000UKm00<005KmE_d00`000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00<0
05KmE_d00`00Cgoo00<007ooOol04Woo000POol20008Ool2000MOol2000AOol00`00Oomoo`0WOol2
002BOol20002KaL02@00KaQ_66lH001_>000Ga/00002Ga/01@00A[e6_@005Qd0400000<0]P000;H0
0`0000<4eP002=H00P000Pcf00D001Cf000DmP00008I5P03000M5P00008Q=P08000Q=P00000U=P00
:EH000<YEP03000]EP0000<]EP06000aEP00000aMP000cEe00<003Ee00000cUe00<003fE00000P00
0cfE00<003fE00000cfE00D003fE?IDmU@0000<mU0050015U4FDAI@00003AK@01@00BKA9]4Vd0000
0dVd00D004WEBME9e@0000=9e@030019eDWE0099e@030019e@0000<0009=m@03001=mDge009=m@05
001=mDgeCOD00003COD01@00BME9eDWE000014ge0P000f[g00<006JF00000fKi00<005IGEUL00UIG
00<0058fDSH00U8f00<004hF00000P0015[k00@006kgK_L0009_V`03001VefKG009Ve`03001RM@00
00A_6003001VfFKI009Vf@05001FEeIGEUL00004ESH20005K_L00`00I]MVe`02I]L01000HWERM@00
0VlG00@006ZEJYD0009V]`05001VM6IdIW@00002LaH00`00L]D00003L_D20004HWD20004IWD00`00
JYD00004HU@00`00IW@00002JY@02000M_Afm000Ma@007;E0004K]D01@00K]E^eFkE00000fZE00D0
06kEK]E^e@0000=bm@04001c5G<E0002MaD01000MaEg5@000WLF00D007LfMcIg=P00009g=P800004
McH007Lf0002NeH00`00NeIkEP02000027]F001kMP00NgH007]f0002NiH20002OiH01`00OkH00000
NkH007^f00800005NmD007_E001ge@0700000f_D00000005000015/m000000000U:k00<005;LD]`0
10000UKm00<005KmE_d00`000eKm00<005KmE_d00`000UKm00<005KmE_d010000UKm00H005Km0000
05Km0002E_d40002E_d00`00E_eFo@030002E_d00`00E_eFo@040002E_d00`00E_eFo@04001BOol0
0`00Oomoo`0BOol0021oo`8000Qoo`8001eoo`80011oo`03001oogoo02Eoo`<009Ioo`03001_5`00
009_6005001_>6lhKcP00003Ga/D00000`2E0000000200001@2f0004eP002=H00`0000D<mP000000
01Cf008000036AH001dF008000058CH0024f000U=P020002:EH00`00:EHYEP030003;EH01000<EH0
035F0`000SEe00@003Ee=GD0008iM@04000mUCfE?ID300001CfE000mUCfE00000SfE00D003fE?IDm
U@0000<mU0050015U4FDAI@00003AK@01@00BKA9]4Vd00000dVd00D004WEBME9e@0000A9e@030019
eDWE00<0009=m@05001=mDgeCOD00004COD01@00COE=mDge00000dge00<004WEBMD00TWE00<004ge
COD00P001F[g00<006KiI_T00fKi00<005IGEUL00UIG00<0058f00000`000TZl00<005[kF_/00U[k
00<006kg000016nK00<006KGI]L00`0016lH0P0016KI00<005IGEUL00UIG100000=Jo000K_L00fkg
0P001FKG0P0016lG0P000fJg00D006IdIWAVM00000=c5P05001bmG;eL_D00002J[H01`00HWERMF9e
001VU@0000=VM@03001ZU@0000=RE006001VM6Id001ZU0000gKd00D007LD001be@0000=^e@03001^
e@00009^e@05001ZUFZEJYD00003K]D02000L_Ebm@00MaD007<E0002MaD00`00MaEg5@0200001GLF
001g=WLf00000WLf00@007LfMcH0009g=P06001kEW]F001kEP000W]F0P0000ekMP00NgH007]f001k
UP00NiH007nF001o]P0200000g^f001k]P0200000g_E001ke@0300001GOE00000000Km@02`000UKK
00<005:kD[/00`000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00<005KmE_d00`000UKm
00<005KmE_d00`000eKm0`000UKm00<005KmE_d010000UKm00<005KmE_d00`000UKm00<005KmE_d0
10000Woo00<007ooOol0DGoo00<007ooOol04Woo000POol20008Ool2000MOol2000@Ool00`00Oomo
o`0ROol3002JOol200000flH001_>002KcP01`00KeT005lK001O700000=:_003000^ORin00X00005
07D000000000]P0200020;H01P001=H000002=H0008<mP@000065?H000007AH001dF0P0000@Q=P00
9CHU=P800006:EH002UF:EH002eF0P000ReF00<0035F00000c5F0P0000DeM@00=GDeM@0000<iM@04
000mUCfE0002?ID50003?ID01000?IDmU@000cfD00D004FDAIA5U00000=5]0050019]4VdBK@00003
BK@00`00BME9e@02BMD01000BME9eDWE0`0000==m@00COD00Tge00<004geCOD00Tge00D004geCOE=
m@0000==m@03001=mDge009=m@040019eDWEBMD300000e[K001Zm`03J_L20005I_T01000EUMFEeIG
0`000U;L00<004ZlB[`00TZl00<005[kF_/01@000VnK10000U/M00D006lHKaQ_6000009[O003001V
fFKI009Vf@03001FE`00008000EJo004001^mfkg0002Ji`01000I]MVefKG0P001FlG00<006JgI[L0
0fJg00@006IdIW@000=c5P05001bmG;eL_D00002J[H01000HWERM@000VJE00@006IeIWD0009ZU@05
001RE69DHU@00002IW@00`00JY@00003M_@01000MaAg500016kE00D006kE001^e@0000=ZU@05001^
]000K]D00003L_D01000MaEg5@000WLE00@007LEMaD0009g5@05001g=WLfMcH00002McH00`00McIg
=P02000017Lf001kEP000W]F00D007]FNeH007]f00800003NgH00000009kUP80009oUP07001o]P00
001k]P00NkH00P0000Eke@00000007OE00h00004He`005KKE]/40002E_d00`00E_eFo@030002E_d0
0`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@030002E_d01000E_d000000UKm00<0
05KmE_d00`000UKm00<005KmE_d010000UKm00<005KmE_d00`001goo00<007ooOol0D7oo00<007oo
Ool04Woo000POol20008Ool2000MOol2000@Ool00`00Oomoo`0OOol3002OOol01@00KcQ_>6lh0000
0VmI0P000elL00<004ZlB[`00`0000=>o@0000003@0000D0U@000;H000CF00D000073?H0013f000D
mP005?H00P0000<M5P007AH00P0000LQ=P009CHU=P00:EH00003:EH01P00;EH00000;EH0008aEP05
000aES5F000aE@020002=GD01@00>GDiMCUe00000SfE00D003fE?IDmU@00008mU@<00005?ID003fE
?ID00003?I@01@00AIA5U4FD00000dFd00D004VdBKA9]00000A9]0060019eDWEBMD004WE0`000dge
00<004geCOD00Tge00D004geCOE=m@0000==m@05001=mDgeCOD00004COD00`00BMD000020004F]/0
1000J_MZm`000V^L00<006KiI_T00VKi00H005IG000005;L0004D]`00`00B[a:_0040003Dil40002
B_h00`00FaeK7@02Fad00`00KaP00003Jg`00`00I]UVf@040003B[d00`00F_aJo002F_`00`00K_L0
0003Ji`01P00I]L00000Fc`000A_5`8000EV]`03001VM00000=c5P05001gE`00L_D00003J[H00`00
HWD00003IYD00`00IWD00004JYD01000HUARE0000fId0P000WKd00D007LDMaAg500000=^e@06001^
eFkE001^e@000fZE00D006jd001^e@00009bm@05001g5GLEMaD00002MaD01000MaEg5@000WLE00@0
07LfMcH0009g=P04001g=WLf0002McH01P00NeIkEP00NeH0009kEP0?001kMW]f001kMP00NgH007^F
001kUP00OiH007nf00800003NkH007^f00800003NmD007_E00<00003MmD007?D00X0009SG0<0009F
o@03001FoEKm00@0009Fo@03001FoEKm00<000=Fo@03001FoEKm00<0009Fo@03001FoEKm00@0009F
o@03001FoEKm008000AFo@<0009Fo@03001FoEKm00<0009Fo@03001FoEKm00@000]oo`03001oogoo
04moo`03001oogoo019oo`008Goo0P001Woo0P007Woo0P0047oo00<007ooOol077oo0`00Xgoo00<0
06lh00000VmI00@006_kJo/0009O70<0009Ff`03001>o@0000T0000307D000000080000409D00000
0;H200000`CF0008eP030000113f000DmP000QCf00<001dF00000QdF00<0024f00000RDf0`000bUF
00@002eF000]EP80008aEP04000aES5F0002<ED200000cEe000iM@02>GD01@00?IDmUCfE00000SfE
00@003fE?ID0008mU@<00003?ID003fD008mU0050015U4FDAI@00003AK@00`00BKA9]002BK@01P00
BKA9]4Vd0019e@@00099m@03001=mDge009=m@05001=mDgeCOD00003COD01@00COE=mDge000014ge
00<004ge00000`000TZL00<005[KF]/00U[K00<006[g000016^L00<006KiI_T00`0015;L00<005;L
D]`010000dLo10000U<M00<004[nB_h00T[n00<005/MFad010000V]l10000e;m00<004ZmB[d00TZm
00<005[lF_`010000V^L0`0015/l00@006lGKaL0009[O003001V]fJg009V]`03001VM00000=c5P04
001gEgMG0005J[H20004IYD20004JYD00`00HU@00004IW@01@00M_Afm7Kd00000WLD00D007<E001^
e@0000A^e@03001ZUFZE009ZU@05001^]000K]D00002L_D02000MaEg5@00MaD007LE0002MaD01`00
MaD007Lf001g=P00009g=P04001g=WLf0002McH2000017]F001kEP000W]F00<007]f00000W]f0`00
00=kUP00NiH00P0000Eo]P00OkH007^f00800006NmH00000NmD007_E200000=Wd`0000001P000ULM
00<005KmE_d00`000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00<005KmE_d00`000UKm
00<005KmE_d010000UKm00H005Km000005Km0002E_d40002E_d00`00E_eFo@03000?Ool00`00Oomo
o`1@Ool00`00Oomoo`0AOol0025oo`8000Ioo`8001ioo`80011oo`<001Uoo`<00:Moo`800003KeT0
000000D0009Fo@03001FfeKK00<00003Fa`0000000T0000407D0000009D600000`SF0008eP050002
5?H300027AH300029CH010009CH000000RUF00<002eF00000ReF0P0000<aEP00<EH00S5F00<0035E
<ED00`000cUe00D003fE?IDmU@0000<mU@04000mUCfE0002?ID01@00;ED003fE00000SfD00D004FD
AIA5U00000A5]0060019]4VdBK@004Vd10000TWe00D004WeBOE9m@0000A=m@05001=mDgeCOD00003
COD00`00COE=m@02COD00`00COE=m@030002D[/00`00BYa:W002BY`00`00F]]Jf`050002Ji`40002
D_d00`00D]aBg002D]`30003Cel01000Acl000000U<M00<005<MDad00U<M00<004[nB_h010000dmO
0`000U<M00<005;mD_d00e;m00<004ZmB[d010000U>O10000TKn00<005/lFc`00U/l00<006lG0000
16]l00@006JgI[MV]`8000=c5P05001gEgMGMeL00005J[H00`00IYEVU@03IYD00`00JYEZU@03JYD0
0`00HU@00004IW@01000M_Afm0000gLD00D007<E001^e@0000A^e@05001ZUFZEJYD00003K[@01@00
L_EbmG;e00000WLE00@007LEMaD0009g5@04001g5GLE0002McH01000McIg=P000WLf00@007LfMcH0
009k=P03001kEP00009kEP09001kMW]f001kMP00NgH007nF00<00007OiH007nf001o]P00NkH00P00
00=keP000000100000=ge@0000001@0000=O/P0000000P0000AG7@00EaeG7@@0009Fo@03001FoEKm
00<0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00<0009Fo@03001FoEKm
00<000=Fo@<0009Fo@03001FoEKm00@001=oo`03001oogoo04moo`03001oogoo015oo`008Woo0P00
17oo0P006goo0`0000=oo`0000003goo0P0067oo0`00[7oo0P0017oo0P000UKm0`000e[l00<005/L
0000200000<0M00000000`0000D0U@000;H000CF00800088eP03000@mP00008000035?H001TF0080
00037AH0024F0080008U=P06000U=P00000YEP000ReF00<002eF;EH00`000c5F00D0035E<ED0035E
0080008iM@05000mUCfE?ID00003?ID01000?IDmU@000SfE00<002eE;ED00P000SfD00D004FDAIA5
U00000A5]0030019]00000<00099e@050019mDWeBOD00004BOD01@00COE=mDge00000dge00D004ge
COE=m@0000A=m@<00003D[/005:k00=B^`03001:W4ZL00D0009CW`@0009C7@03001BoE;m009Bo@04
001Bg0000002Ccl00`00Cem?G`040004Dad00`00DaeC7@040003B_h01P00Cel00000Dad000AC7@04
001BoE;mD_d40003Aal30003Dad01@00A_i6oTKn00000U/l100016]l00H006Jg000005lL0002LaH0
1`00MeMgEgMG001_>@0000=Z]P8000EVU@03001ZUFZE00AZU@03001VM6Id009VM005001g5@00M_@0
0002Ma@01@00LaEc5G<E000016kE00<006Ie00000VZE00D006jdK[A^]000009bm@04001g5GLE0003
MaD01000MaEg5@000WLE00<007LfMcH00P0000Eg=P00McIg=P00009g=P06001k=W/f001kEP000W]F
00<007]f00000W]f0P000WnF00<007nF00002`0000Eke@00NmD007OE00@00003Jm<0000000D0009G
7@<0009Bo003001FoEKm00@0009Fo@03001FoEKm00<000=Fo@03001FoEKm00<0009Fo@03001FoEKm
00@0009Fo@03001FoEKm00<0009Fo@06001Fo@00001Fo@000UKm100067oo00<007ooOol0CWoo00<0
07ooOol04Goo000ROol8000KOol6000@Ool00`00Oomoo`0COol3002fOol30002B_d00`00F_aJo003
00000elL0000000800000`1e000000020000102E000000CF0`0000H8eP004?H0013f00025?H00`00
6AH000027AH02@008AH000009CH002Df000YEP020002;EH01@00;EH]EP00;EH00P000S5F00@0035E
<ED0008aE@80008iM@04000mUCfE0003?ID01000?IDmU@000cfE00<002eE;ED00P000SfD00D004FD
AIA5U0000095]0<00099e@050019eDWEBMD00004BOD01@00BOE9mDWe00000dge00D004geCOE=m@00
00A=m@03001=m@00008000AB^`04001B^e:kD[/30004Ael30002Dad00`00DaeC7@02Dad00`00D_eB
o@040002Ccl40004Dad00`00DaeC7@040003Dad00`00B_i:oP030004Dad00`00DaeC7@050003Cah0
1P00Aal00000Dad000AC7@L0009CG`P000AO7003001c5P00009gE`04001_>Fli0002J[H00`00H[P0
0004IYD00`00KaL00005JYD00`00IWAVM002IW@01@00MaD007Kd00000WLD00D007<ELaEc5@0000A^
e@05001VM@00JYD00003K[@01@00M_@007;e00000WLE00X007LEMaD007LE001g5@00MaD0009g=P04
001g=WLf0002McH01000McIg=P000W/f00<007]F00000W]F01<007]fNgH007]f001kMP00OiH007nF
001oUP00OkH007nf001o]@0200001G_E00000000NmD04@000U;L00<005;lD_`00`000UKm00<005Km
E_d010000UKm00<005KmE_d010000UKm00<005KmE_d00`000UKm00<005KmE_d010000UKm00<005Km
E_d00P000eKm0`0077oo00<007ooOol0CWoo00<007ooOol04Goo000TOol4000POol3000?Ool00`00
Oomoo`0BOol2002jOol20002B_d30003Ga`00`00Ga`0000700002@1d0000000009D0002E0000]P02
000010CF0008ePSF0P0000H@mP00000DmP006AH200001AdF000Q5P008CH00P0000@U=P00:EHYEP80
0005;EH002eF;EH00002;EH200000c5F000aE@02<ED01000<ED003Ud0`000SfE00D003fE?IDmU@00
00<mU@04000mUCfE0002;ED00`00=GD000020003AI@300000dWE0019e@02BMD00`00BME9e@02BMD0
1@00BOE9mDWe00000dWe00D004geCOE=m@0000A=m@03001=m@0000<0009B^`03001B^e:k009B^`04
001B^`000003Cgl01P00Ael00000Dad000AC7@03001C7E<M00@000=?7P<000AC7@03001C7E<M00@0
00=C7@03001C7E<M00@000=C7@03001C7E<M00@000A?7P03001?7TlN00<000AC7@06001C7@00001C
7@0014Kn0`000e<M00<004;N@]h00T;N00<005lLGa`0100000=gE`00KcT00Vli00<006Zf00000f:h
00L006JEIYEVU@00KaL00004JYD20004IW@01000MaEg5@000gLD00H007<ELaD007;f0002K]D01P00
IWEVM@00JYD000=^]004001fm7Kd0003MaD01000MaEg5@000WLE00@007LEMaD0009g=P03001g=WLf
00800005McH007LfMcH00002NcH02000NeH00000NeH007]f0002NgH01P00NgH007nF001oUP800005
OkH007nf001o]@02000017_E000007_E0`0000Age@00001_e0<00003Hk8000000080009Bg003001B
g5;L00@0009Fo@03001FoEKm00<0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001F
oEKm00<0009Fo@03001FoEKm00@0009Fo@03001Fo@00021oo`03001oogoo04eoo`03001oogoo015o
o`00FWoo00<007ooOol03goo0`00_Goo0`000T[m00<005lLGa`03P0000D0M@0009D0002E00H00005
2=H00000000@mP0300000aTF000I5P020000124F000Q=R4f0P0000@U=P00:EHYEP<000<]EP04000]
EP00;EH20003<ED00`00<ED00003>G@300001CfE000mUCfE00000cfE00@003fE?ID0008]E@04000e
MCEe=GD50003BMD00`00BME9e@02BMD01@00BME9eDWE00000dWe00D004WeBOE9m@0000A=m@03001=
m@0000<0009B^`03001B^e:k009B^`03001B^e:k00@000=?O`<000AC7@03001C7E<M00@000=?7P06
001?7P00001C7@001E<M0`000U<M00<005<MDad00U<M0`000e<M00<005<MDad0100015<M00<004lN
Cah010000e<M00<005<MDad00`0015<M00H004Kn000005<M0005Dad00`00@]i2gP040003Feh20004
KcT20004H[P01000IYEVU@000flG00@006ZEJYD0009V]`04001VM6Id0003MaD01000MaAg50000g<E
00D007;f001^e@0000AVM@8000=^]004001fm7Kd0002MaD01000MaEg5@000gLE00H007LEMaD007Lf
0002McH01000McIg=P000WLf00H007/fNcH007]F0002NeH200004G]f001kMP00NgH007nF001oUP00
OiH007nf001o]P00OkD00P0000Eke@00000007_E00d000=Bg0<0009Fo@03001FoEKm00@0009Fo@03
001FoEKm00<0009Fo@03001FoEKm00@0009Fo@03001FoEKm00@0009Fo@03001FoEKm00<0009Fo@03
001FoEKm00<0029oo`03001oogoo04aoo`03001oogoo015oo`00FWoo00<007ooOol037oo0`00`7oo
00<001Gl00000T[m0`000e/L2P0000H0E0000000U@0009D200000`2e0004eP0300001@cF000@mP00
4?H00P0000<I5P006AH00P0000LQ5P008CHQ=P009CH00002:EH01000;EH000000ReF00D002eF;EH0
02eF0080008aE@03000aE@0000<iM0030011U46D00@00005?ID003fE?ID00002?ID01@00;ED]EBeE
00000SEe00D004FeAKE5]@0000A9e@050019eDWEBMD00003BMD01@00BOE9mDWe00000dWe00@004ge
COE=m@<0009B^`03001B^e:k009B^`03001B^e:k00@0009?O`D000=C7@03001C7E<M00@000=C7@03
001?7TlN00<000AC7@03001C7@0000800003Dad005<M00=C7@06001C7@00001C7@0015<M0`000e<M
00@005<MDaeC7@@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@04001C7E<MDad40003
?]h01P00Feh00000Fcd000=_>@03001S?00000AR^003001VU@0000A_5`03001ZU@0000=V]`04001V
M6Id0002MaD01@00NeH007LD00000W<E00H007;fL_H006kE0004IWD01@00K[A^]6jd00000WKd00D0
07/D001g5@00009g5@05001g5GLE001g=@020002McH01000McIg=P000WLf0P0000Mg=P00NcIk=P00
NeH00002NeH01`00NeH00000NgH007]f0080009oUP800005OkH007nf001o]@0200001G_E00000000
NmD00`0000Ece000000006OB00@0009Fg003001Bg000009Fo@03001FoEKm00<0009Fo@03001FoEKm
00@0009Fo@03001FoEKm00<000=Fo@03001FoEKm00<0009Fo@03001FoEKm00@0009Fo@03001FoEKm
00<002Ioo`03001oogoo04]oo`03001oogoo015oo`00FWoo00<007ooOol02Goo0`00a7oo00@001Gl
0000009>o@04001K70000002Fa`<0000102E0000002E100000<4e@0000000P0000H@mP004?H001TF
00026AH00`008AH000028CH00`009CH00002:EH00`00;EH]EP0200001BeF000]EReF00000ReF0P00
00DaE@00<EDaE@00008iM0050011U46D@I@00002@I@80003;ED01000=GDeM@000dFe00<004WEBMD0
0TWE00D004WEBME9e@0000=9e@050019mDWeBOD00004BOD300000e:k001B^`03D[/00`00D[]B^`04
0003Cgl30004Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad00`00
DaeC7@030004Dad01P00Dad00000Dad000AC7@@0009C7@03001C7E<M009C7@<000=C7@03001C7E<M
00@000=C7@03001C7E<M00D000=C7@03000ngSkN00<000AK?@03001_>@0000=S?003001R^6:h009R
^08000A_5`8000AV]`03001VM00000=g5@04001kEW]F0003LaD01@00L_IbmW;f00001FIe00D006jd
K[A^]000009fm004001k57/D0003MaD01000MaEg5@000WLe00<007Lf00000WLf00@007LfMcH0009g
=P04001k=W/f0002NeH00`00NeH00002NeH01@00NgD00000NgH00P0000EoUP00OiH007nf00800003
OkD007_E00800005NmD00000001ge00;000015KL000000000eKm0`000UKm00<005KmE_d00`000UKm
00<005KmE_d010000UKm00<005KmE_d010000UKm00<005KmE_d00`000UKm00<005KmE_d01000:Goo
00<007ooOol0C7oo00<007ooOol047oo001JOol00`00Oomoo`06Ool30038Ool30002C_d30003Fa`9
00000`1D0000000500001`2e000000001=D000cF00<000044?H001TF00026AH00`008AH000028CH3
0003:EH01000;EH002eF0P000ReF00D002eF;EH002eE0080008aE@04000iM3Ud0003@I@01@00@IA1
U46D00000d6E00@003fE0000008]E@05000eMCEe=GD00003AKD01@00BME9eDWE00000dWE00D004WE
BME9e@0000A9m@030019m@00008000AB^`04001B^e:kD[/30003Cgl01000Cgl000000U<M00<005<M
Dad00U<M0`000U<M00<005<MDad00U<M0`000e<M00<005<MDad0100015<M00<005<MDad010000e<M
00<005<MDad00`0015<M00@005<M0000009C7@03001C7E<M009C7@06001C7@00001C7@0015<M0`00
0e<M00<005<MDad0100015<M00<005<MDad010000d[n00<005/mFcd00`0016<l00@006:hH[QR^0<0
00=_5`03001WO00000AV]`03001VM000009g5@05001kEW]FNeH00002LaD00`00L_IbmP02L_H00`00
IWEVM@02IWD00`00JYD00002K[@01000M_Afm0000W/D00@007LEMaD0009g5@07001g=GLeMcD007Lf
00000WLf00@007LfMcH0009g=P800004NcH007]F0002NeH00`00NeH00002NgD00`00OiD000020000
1GnF001oUP00OkH00P0000=o]@00NmD0100000=ge000000030000UKm00H005Km000005Km0002E_d4
0002E_d00`00E_eFo@030002E_d00`00E_eFo@040002E_d00`00E_eFo@040002E_d00`00E_eFo@03
000^Ool00`00Oomoo`1;Ool00`00Oomoo`0@Ool005Yoo`<000=oo`<00<aoo`04000N7@000003C_d0
0`00Fa`00002Fa`900001P1D0000002E0000U@8000090;D000CE000<eP003=D0013f00<0008I5P<0
00<Q=P<0008YEP03000]EP00008]EP80008]EP03000]EP00008]E@800003<ED003Ud008iM0040011
U46D0003@I@01@00@IE1UD6E00000SfE0P0000<]E@00=GD00SEe00D004FeAKE5]@0000=9e@050019
eDWEBMD00004BMD00`00BOD000030002D[/00`00D[]B^`02D[/01000D[/000000Tmo00<004moCgl0
100015<M00H005<M000005<M0004Dad01P00Dad00000Dad000AC7@<000AC7@03001C7E<M00@000=C
7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@06001C7@00001C7@00
15<M0`0015<M00<005<MDad010000e<M00<004[nB_h010000eLn00H006<lHcaS?000H[P20003Fcd0
0`00KaL00003Ig`00`00I[MV]`02I[L20002MaD02000NeIkEP00McL007<E0003L_H20004IWD01@00
JYD006jd00000WKd00P007/DNa@007LD001g5@000WLE00H007LeMcD007Le0002McH01000McIg=P00
0WLf00@007/fNcH0009kEP08001kEW]F001kEP00NgD0009oU@800003OiD0000000T00005NmD00000
001ge00:0002E_d00`00E_eFo@030002E_d30002E_d00`00E_eFo@040002E_d00`00E_eFo@030003
E_d00`00E_eFo@030002E_d00`00E_eFo@04000bOol00`00Oomoo`1:Ool00`00Oomoo`0@Ool005Uo
o`80009oo`<00=1oo`<0009>o@<000=K70T00080E0<0000309D000000080]@040004e@0000023=D0
0`004?H0000200026AH300028CH01P009CD00000:EH0008]EP03000]EReF00800005;EH002eF;EH0
0002;ED00`00<ED00003>G@01@00@IA1U46D00000d6D00P0046E@IE1U@00?ID0024F0P000cEe00D0
04FeAKE5]@0000=9e@030019eDWE0099e@030019eDWE00<0009B^`03001B^e:k009B^`03001B^e:k
00@0009?O`@000AC7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@04001C7@000002Dad00`00
DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad00`00DaeC7@040003Dad0
0`00DaeC7@030004Dad01P00Dad00000Dad000EC7@<0009C7@03001C7E<M009C7@<000=?7P03001G
?ULn00L000EK?@8000AWO004001V]fJgI[L20003MaD01000NeIkEP000WLg00<007;fL_H00W;f00<0
06Zf00000VIe00H006ZEJYD006jd0002M_@01000NaAk50000WLD00D007LEMaEg5@00009g=@06001g
=@00001g=P000WLf00@007LfMcH0009k=P800006NeH007]F001kEP000W]e00@007nE0000009oU@04
001oU@00OkD200000gne001ke@0400000gOD00000005000016>a000000000UKm10000UKm0`000UKm
00<005KmE_d00`000UKm00<005KmE_d010000UKm00<005KmE_d010000UKm00<005KmE_d00`00=goo
00<007ooOol0BGoo00<007ooOol047oo001IOol4003DOol010009Ud000000dkm00<005/L00000U/L
200000@0E0000000U@80000509D0002e0004e@0300001@cE000@mP005?D00P0000<I5P007AD00P00
00DQ=P009CD002Te0080008]EP05000]EReF000]EP020002;EH01P00;ED]E@00<ED000<iM0050011
U46D@I@00003@I@01@00@IE1UD6E00000SfE00@0024F0000008eM@050015]DFeAKD00004BMD01000
BME9eDWE0`0000=B^`00D[/00e:k00<005:kD[/010000Tmo100015<M00<005<MDad010000e<M00<0
05<MDad010000e<M00<005<MDad0100015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@02
Dad30004Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00Dad0
000200000e<M001C7@03Dad01P00Dad00000Dad000A?7P<000=C7@060016oTKnA_h005/m0`000U=O
00H006MlIgaWO000I[L200001ElL001g5GLE00000W]F00D007LgMcMg=`0000=bmP04001Z]VZf0002
IWD01000JYEZUFZE0P000WKd00@007/DNa@0009g5004001g5GLE0002McD00`00McD00002McD01`00
McIg=WLf001g=P00009k=P04001kEW]F0002NeH01@00NeH007]e00000WnE0P0000EoU@00OiD007ne
00800003OkD007_E00800003NmD0000000800003Mm@006oC00T0009Fo@06001Fo@00001Fo@000UKm
10000UKm00<005KmE_d00`000UKm00<005KmE_d010000UKm00<005KmE_d01000>Woo00<007ooOol0
BGoo00<007ooOol047oo001IOol2003GOol30002C_d30003Fa`900000`1D0000000400020;D20000
10Re000<e@cE0P0000<Dm@005?D00P0000<M5@008AD00P0000@U=@00:CDY=@800005;EH002eF;EH0
0002;EH2000012eF000]EBeE0P0000DaE@00>G@iM00000=1U0050011U46D@I@00003@ID01000?IDm
U@000R4F0P0000<eM@00AKD00TFe00<004WEBMD00TWE00<004WE00000P0015:k00@005:kD[]B^`<0
00=?O`<000=C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03
001C7E<M00<000AC7@06001C7@00001C7@0015<M00H005<M000005<M0005Dad30003Dad00`00DaeC
7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad00`00DaeC7@030004Dad01P00Cah0
0000Dad000AC7@H000ECG`H000AO7005001g5@00NeH00003McL01@00LcL007;f00000fZf00@006Ie
IWD000=ZU@04001fm7Kd0002Na@02000MaAg5000NaD007LE0002McD00`00McD00002McD01000McIg
=P000WLf00@007/fNcH0009kEP800003NeH00000009kM@0:001oU@00OiD007nE001oU@00OkD20000
0gne001ke@0500000gOD000000080002E_d00`00E_eFo@030002E_d30002E_d00`00E_eFo@040002
E_d00`00E_eFo@030003E_d00`00E_eFo@03000oOol00`00Oomoo`18Ool00`00Oomoo`0@Ool005]o
o`03001oogoo0=Eoo`03000bO@000080009>o@03001K7000009K70/0000509D0002E0000]@050000
0`cE0000000200025?D300028AD200001bDe000Y=BTe000]EP0000<]EP03000]EReF00<000<]E@<0
008iM0050011U46D@I@00003@I@01@00@IE1UD6E00000SfE00P0024F8AH001Dh000eM@000dFe00<0
04WEBMD00`000U:k00<005:kD[/00U:k00@005:k0000009?O`04001?O`000002Dad00`00DaeC7@02
Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000AC7@03001C7E<M00@000=C7@03001C
7E<M00<000AC7@03001C7E<M00<000AC7@03001C7@0000800003Dad005<M00=C7@<0009C7@03001C
7E<M009C7@<000=C7@03001C7E<M00@000AC7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06
001C7@00001C7@0014[n00<005=O00000P0000=C7@00?]h00SkN00<005lLGa`00UlL0`0000=kEP00
McL00WLg00D007<g001bmP0000=Z]P03001VM@0000AZU@04001fm7Kd0002Na@01000MaAg50000W/E
00@007LeMcD0009g=@07001g=@00McH007Lf00000WLf00<007/f00000W]F00P007]ENeD007]F001k
M@000WnE0P000WnE0P0000=o]@00OkD00P0000Eke@00000007_E00<00005Lm@00000001W/P040002
E_d40002E_d30002E_d00`00E_eFo@030002E_d00`00E_eFo@040002E_d00`00E_eFo@040013Ool0
0`00Oomoo`17Ool00`00Oomoo`0@Ool005aoo`03001oogoo0=Eoo`T0009K70@00003018000000080
000505@000000000U@0300000`2e0008]@03000010cE000Dm@000QCe00<001dE00000R4E00<002De
00000RTe0`000beF00D002eF;EH002UF0080008]E@06000Pm@00000iM0000d6D00D0046D@IA1U000
00=1U@05000mUCfE?ID000028AH010005CP000000dFe0`0000=Jf`00D[/00e:k00<005:kD[/01000
0Tmo100015<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30004Dad00`00DaeC7@040003
Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad01P00Dad00000Dad0
00AC7@06001C7@00001C7@0015<M0`000e<M00@005<MDaeC7@@000=C7@03001C7E<M00@000=C7@03
001C7E<M00<000AC7@03001:oT[n00@000AC7@06000ngSkN?]h005lL0P000U]N0P000gLg00D007<g
LcMc=`0000EZ]P8000=ZU@07001g5@00M_@007/D00000gLD00<007/ENaD00P0000Ag=@00McD0009g
=@04001g=WLf0002McH01000NcIk=P000W]F00<007]ENeD00`0000]kM@00OiD007nE001oU@00OiD0
07ne00800004OkD00000NmD400000gOD0000000400000e^@001Bo0030002E_d01P00E_d00000E_d0
009Fo@@0009Fo@03001FoEKm00<0009Fo@03001FoEKm00@004Moo`03001oogoo04Moo`03001oogoo
011oo`00GGoo00<007ooOol0eGoo00D003il?W`nO000009Bo@<0009G7@<000030180000000@00004
09D0000009D300000`Re0008]@0300001aCe000DmACe000M5@00008Q5@03000U=@00008Y=@04000]
E@000002;EH01000;EH]EP000RUF00X002eE;ED0023e000]=@00>G@00091U0030011U46D0091U005
0011UD6E@ID00002?ID010008AHQ5P000QDh1@0015[K00<005:kD[/010000Tmo100015<M00<005<M
Dad010000e<M00<005<MDad00`0015<M00@005<M0000009C7@03001C7E<M009C7@<0009C7@03001C
7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@03
001C7E<M00<000AC7@06001C7@00001C7@0015<M10000e<M00<005<MDad010000e<M00<005<MDad0
10000e<M00<005<MDad0100015<M00<005<MDad01`000e]N00<005lm00000WLg00<007<gLcL00W<g
00<006ZfJ[H00fZf00<006ZEJYD00VZE00@007LEMaD0009k5004001g57LD0002NaD01000NcEk=@00
0WLe00@007LeMcD0009g=P800007McH007/fNcH007]F00000W]E00@007]E001kM@800005OiD007nE
001oU@0200000gne001o]@0200001G_E001ke@00Mm@030000UKm00<005KmE_d00`000UKm0`000UKm
00<005KmE_d010000UKm00<005KmE_d00`00C7oo00<007ooOol0Agoo00<007ooOol03goo001NOol2
003FOol00`00?W`nO0030002D_d00`00EaeG7@0800000`1D0000000300000`2E0000]@0200022;D0
10003=D000000QCe0`000R4E0`000bTe00H002eE000002eF0003;EH02000:EH00000;ED0023e0002
;CD20003@I@01P00@IA1U46D0011U@H0008Q5P04000E>1Dh0003BY`00`00F]]Jf`02F]/30003Cgl3
0004Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad01P00Dad00000
Dad000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad0100015<M00<005<MDad010000e<M
00<005<MDad010000e<M00<005<MDad00`0015<M00@005<M0000009C7@03001C7E<M009C7@<0009C
7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@04001C7E<MDad40003Dad01`00>[hj_SZn
001KGP0000=O?@03001g=`0000=c=`03001_>@0000=Z]P8000=ZU@04001g5GLEMaD200001G/D001g
57LD00000W/E00@007/eNcD0009g=@03001g=@00009g=P04001g=GLe0002NcH01000NeIkEP000W]E
0P000W]e00<007nE00000`0000IoU@00001o]@00OkD900000g?D000000060002E_d40002E_d30002
E_d00`00E_eFo@030002E_d00`00E_eFo@04001@Ool00`00Oomoo`16Ool00`00Oomoo`0?Ool0061o
o`03001oogoo0=Aoo`80009:_003001BoE;m00<0009Fo@X0000507D0002E0000]@0300000`Re000<
e@0300025?D300028AD30002:CD01000;ED0035E0`000ReF00@002UF000Y=@80008Pm@03000]=Bde
00<00003@I@0046D00@00095eP030015edGG00D0008E>006001:W4ZLBY`005[K0P000e>O00<004mo
00000U<M00<005<MDad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad0100015<M00<005<M
Dad00`0015<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30004Dad00`00DaeC7@040003
Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad01P00Dad00000Dad0
00AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad01@000e<M00<005<MDad01`0015lm0P00
0g<g00@006liKcT0009Z]P04001R]f:g0002JYD01000MaEg5@000W]E00@007LDMa@0009k5@05001k
=G/e001k=@020002McD01000McIg=P000WLe0P0000]k=P00NeIkEP00NeD007]E001kM@00009oU@04
001oU@00OiD700001G_E001ke000Mm@01`0000AS/000001Fo@<0009Fo@06001Fo@00001Fo@000UKm
10000UKm00<005KmE_d00`00EGoo00<007ooOol0AGoo00<007ooOol03goo001QOol00`00Oomoo`3D
Ool00`00B[a:_0030002E_d00`00E_eFo@0900001@1d0000000009D00P0000<0]@002;D00`0000L@
e@005?DDm@006?D000028AD020008AD00000:CD002eE0003<ED200001ReF000YERUF000Y=@800005
8?D002de;CD00002@KD30002BMD01@00AMI5eTGF00000dGG00<003Fh=KP010000TZL1@000U>O0`00
15<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040004Dad00`00DaeC7@040003Dad00`00
DaeC7@040003Dad00`00DaeC7@030004Dad01000Dad000000U<M00<005<MDad00U<M0`000U<M00<0
05<MDad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad0100015<M00<005<MDad00`0015<M
00<005<MDad00`0015<M00H005<M000005<M0004Dad30004Dad00`00DaeC7@040003Dad01P00A]i6
gTKN001O?@80009O?@03001c=`0000=_>@03001Z]P0000=R]`04001ZUFZE0002MaD01000NeEkE@00
0WLD00@007/ENaD0009k=@04001k=G/e0002McD01P00McIg=P00McD0009k=@04001kEW]F0002NeD0
2@00NeD007]e001oU@00OiD00002OiD200000gne001o]@0300000g_D0000000400000foC00000005
0002E_d00`00E_eFo@030002E_d30002E_d00`00E_eFo@04001HOol00`00Oomoo`15Ool00`00Oomo
o`0?Ool0069oo`03001oogoo0=Aoo`80009Fo003001FoEKm00<00003E_d0000000@0000503<00000
0000M@0600022;D500000aCe000Hm@0200001B4E000Q5@009CD00P000ReE00D0035E<ED002eF0080
008YEP06000Y=BTe000Pm@000Rde00D0046e@KE1]@0000=9e@030015eTGF0095eP050015edGGAML0
0002=KP00`00;Q`000030002Agl40003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0
00=C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M
00@000AC7@06001C7@00001C7@0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003
Dad01000DaeC7E<M10000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M
0005Dad30002Dad00`00DaeC7@02Dad60004Gcd20004KcT20004H[L00`00JYD00002MaD02000NeEk
E@00McH007LD0002NaD01000NcEk=@000W/e0`000WLf00@007LeMcD0009k=@800006NeH007]E001k
E@000W]e00H007nE001oU@00OiD200000gne001o]@0200000g_E001ke00200000gOD001cd`060000
15Km001FoEKm10000UKm0`000UKm00<005KmE_d00`00GGoo00<007ooOol0A7oo00<007ooOol03goo
001SOol2003EOol00`00E_aFo0030002E_d00`00E_eFo@080000301d0000001e0000U@000;D000Re
0008]@8000064=D000006?D001ce0P0000@Q5@009CDU=@800005;ED0035E<ED00002;EH200001bUF
000Y=BTe000Pm@00008]=@050011]D6e@KD00004BMD01@00AMI5eTGF00000dGG00D003Fh=KPe^000
008^70@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@04001C7@000002Dad00`00DaeC
7@02Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03
001C7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad0
1@000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<M0000
0P0000=C7@00Dad00e<M00H005<M000005<M0004A_h01000Gcd000000U/m00H006li000005ll0005
H[L20002MaD01000NeEkE@000WLf00@007/ENaD0009k=@04001k=G/e0002NcD01000McIg=P000WLe
00<007/e00000W/e0P0000YkE@00NeD007]e001oU@00OiD0009oU@800003OkD007ne00<00003Nm@0
000000H00005Ik400000001Fo@030002E_d01P00E_d00000E_d0009Fo@@0065oo`03001oogoo04=o
o`03001oogoo00moo`00IGoo00<007ooOol0dgoo0P000ULM00<005KmE_d00`0000=Fo@0000000`00
00<0<`0000000`0000@0M@000000]@<000052;D0013E000@e@0200000aSe000Lm@0200001b4E000U
=BDe000]E@0000<aE@06000]EReF000YEP000RTe0`000bde00D0046e@KE1]@0000=9e@050015eTGF
AMH00003AML01000=KPe^3Fh0`000e;m00<005<MDad010000e<M00<005<MDad010000e<M00<005<M
Dad0100015<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040004
Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad0
00AC7@<000=C7@03001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03
001C7E<M00<000EC7@03001C7E<M00<000AC7@030016oTKn00<000AK?@8000AO?004001R]f:gH[L2
0003MaD00`00NeD00003McH200001G/E001k=G/e00000W/e00<007/eNcD00P0000Ag=P00McD0009k
=@06001k=G/e001kE@000W]E00P007]e001oU@00OiD007nE0P0000=o]@00OkD00`0000Eke000Nm@0
07OC00800003Km<0000000D0009Fo@03001FoEKm00<0009Fo@<006Ioo`03001oogoo049oo`03001o
ogoo00moo`00IWoo00<007ooOol0dgoo00<005LMEad00`000UKm00<005Km0000200000D0M00007D0
002E008000030;D0000000<0008@e@03000Hm@00008Lm@03000Q5@00008U=@<000<aE@03000]EReF
00<000<Y=@<0008]=@050011]D6e@KD00003BMD01@00AMI5eTGF000014GG0`0000=Bg000D_d00e;m
0`000e<M00<005<MDad010000e<M00<005<MDad0100015<M00<005<MDad010000e<M00<005<MDad0
0`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003
Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01000Dad000000U<M00<005<MDad00U<M00H0
05<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad01000DaeC7E<M
10000e<M00<005<MDad010000d[n00H005/m000005Ln0004Gc`01P00H[MR]`00Ga`0009g5@04001k
EG]E0002McH01000McIg=P000W/e00@007/eNcD0009k=@04001k=G/e0002McD00`00NcD00002NcD0
0`00NeEkE@030002NgD200001GnE001oU@00OkD00P0000=o]@00OkD00P0000=ke00000002@000UKm
00<005KmE_d00`000UKm0`00JGoo00<007ooOol0@goo00<007ooOol03Woo001WOol00`00Oomoo`3C
Ool20002E_d00`00E_eFo@0:00001@1D0000M00007D0100000<0]@002;D00P000Q3E00<001Se0000
0Qce00<0024E00000RDe00@002de0000008aE@05000]EReF000Q5P020002:CD30002;CD01@00@KE1
]D6e00000dWE00<004GFAMH00TGF00<004GG00000P0015;L00H005;m000005Ln0004Dad30003Dad0
0`00DaeC7@040004Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad0
1000Dad000000U<M00<005<MDad00U<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003
Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad00`00DaeC7@030004Dad01P00Dad00000Dad0
00AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00D000=C7@03001C7E<M00@000=C7@03001:
oT[n00<000AG?P07001O?5llGc`006:g00000elL00<007LE00000W]E00@007LfMcH0009g=P04001k
=G/e0002NcD01000NcEk=@000W/e0P0000Ag=@00NcD0009k=@03001kE@00009kE@<00007OiD007nE
001oU@00OkD00P0000=o]@00OkD00`0000=ke000Mm<00`0000A[/P000000009Fo@@0009Fo@<006eo
o`03001oogoo049oo`03001oogoo00ioo`00J7oo0P00e7oo00<005KmE_d00`000UKm00<005Km0000
1`0000<0M00007D00P0000D0U@000;D000Re00<000044=D0000000027?D300039CD01P00;CD00000
<ED000<]EP03000Q5P00008Y=@03000De000008]=@050011]D6e@KD00004BMD00`00AMH000030003
D]`00`00D]aBg0030004Ech01000Dad000000U<M00@005<MDaeC7@<000=C7@03001C7E<M009C7@<0
00=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03001C7E<M00<0
00AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad0100015<M00<0
05<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@02
Dad30004Dad00`00DaeC7@040003Dad00`00DaeC7@040003C_h00`00EciG?P070004Ga`20002NeD0
1000McIg=P000WLf00D007Lf001k=@00009k=@03001k=@00009k=@06001k=G/e001k=@000W/e00@0
07]ENeD0009kE@03001kM@0000d00003Nm@0000000<00004Km800000Gi040002E_d01000E_d00000
LGoo00<007ooOol0@Goo00<007ooOol03Woo001ZOol00`00Oomoo`3BOol20002E_d00`00E_eFo@09
00000`1D0000M00500020;D2000010Re000@eA3E0`000Qce0`000RDe00@002de000iM0<0008]EP07
000Q5P00000Y=@005=@00P0000<]=@00@KD00T6e00@004WEBME9e@<0009Bg003001Bg5;L009Bg0<0
00=GGP03001G?ULn00@000AC7@03001C7@00009C7@03001C7E<M009C7@06001C7@00001C7@0015<M
0`000e<M00<005<MDad010000e<M00<005<MDad0100015<M00<005<MDad010000e<M00<005<MDad0
0`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040004Dad00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@06001C7@00001C7@00
1E<M0`000e<M00<005<MDad010000e<M00<004knC_h010000e<M00H003kN?]hngP00Ga`20002Ged0
0`00NeD00002McH01000McIg=P000WLf00@007/eNcD0009k=@04001k=G/e0002NcD00`00NcD00002
NcD00`00NeD00002NeD00`00NgEkM@0200001Gnd001oU@00OkD00P0000Mo]@00Ok@007_D001ke009
0002E_d00`00E_eFo@02001cOol00`00Oomoo`11Ool00`00Oomoo`0>Ool006]oo`03001oogoo0=9o
o`03001FoEKm00<0009Fo@h0000309D0002e00D000044=D0013E00027?D00`007?D000029CD00`00
;CD00003>G@200001BeF000Q5P008CH00P000QCD0P0000<]=@00@KD00T6e0`0000=Jn`00D]`00e;L
00@005;L0000009CG`03001GGUMN00@000AC7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@06
001C7@00001C7@0015<M0`000e<M00<005<MDad0100015<M00<005<MDad010000e<M00<005<MDad0
10000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30002Dad00`00DaeC7@03Dad30003
Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00DaeC7@030004
Dad00`00Dad0000200000e<M001C7@03Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@070004
Ged20002McH01000McIg=P000gLf0P0000Ek=@00NcEk=@00009k=@05001k=@00NcD00002NcD01000
NeEkE@000W]E00T007]e000007nd001oU@00OkD00P0000=o]@00Ok@00P0000=ke0000000100000A[
/P000000009Fo@@007Ioo`03001oogoo041oo`03001oogoo00ioo`00K7oo00<007ooOol0dWoo0P00
0UKm00<005KmE_d02`0000<0M0000000100000<0U@002;D00`0000L@e@00000Lm@007?D000029CD0
0`00;CD00003>G@00`00=GD0000200000b4F000Q=P0200000aCD000<mP020000146e0000000015[k
00<005;LD]`01@000U=O0`0015<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad0
0`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003
Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@03001C7@000080
0003Dad005<M00=C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0
00=C7@03001C7E<M00@000AC7@06001C7@00001C7@0015<M0`000U<M00<005<MDad00U<M0`000e<M
00H003Zn>[hj_P00Ged20002Gc`00`00McH00002McH01000McIg=P000WLf00@007/eNcD0009k=@05
001k=G/e001k=@0200001g/e001kEG]E001kE@00009kM@800005Ok@007nE001o]@0200000gne001o
]00400000gOC00000008001kOol00`00Oomoo`0oOol00`00Oomoo`0>Ool006eoo`03001oogoo0=9o
o`03001FoEKm00<0009Fo@H0000303<0001D0080000307@0000000@000032;D000be00<000045?D0
00007?D200001BDe000]=Bde00000SUd00L003Ee=GDeM@008AH000028CH200000aCD000<mP020002
BY`00`00F_]Jn`02F_/30004Dgl30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00
DaeC7@040003Dad00`00DaeC7@030004Dad01000Dad000000U<M00<005<MDad00U<M00H005<M0000
05<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad0
0`00DaeC7@040004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M
00@000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00H005<M
000005<M0004Dad60004Gc`20002McH01@00McIg=WLf00000WLf0P0000Ek=@00NcEk=@00009k=@05
001k=@00NcD00002NeD01`00NeEkE@00NgD007nD00800005OiD007ne001o]@0200001Gnd00000000
Nm@02@00Ogoo00<007ooOol0?Woo00<007ooOol03Woo001^Ool2003COol20002E_d00`00E_eFo@07
0000100c0000001d0P0000d0M00009D0002E0008]@003;D0013E000Dm@0200001ace000002De000]
=@0000<iM006000eMCEe000Q5P000R4f00H002eg000000cf0004BY`01000F_/000000eNO00H005=o
000005<M0004Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@04
0003Dad00`00DaeC7@040004Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<000=C7@03
001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@06
001C7@00001C7@0015<M0`000U<M00<005<MDad00U<M0`000e<M00<005<MDad010000e<M00@005<M
DaeC7@@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00001C7@0014;N00@0
05ll0000009O?003001g=P00009g=P04001g=WLf0002McH01000NcEk=@000W/e00<007/e00000W/e
0P0000IkE@00NeEkE@00NgD200001Gnd001oU@00OkD00P0000=o]@00Ok@0100000Egd`00000006^a
00<0081oo`03001oogoo03ioo`03001oogoo00ioo`00L7oo00<007ooOol0dGoo00<005KmE_d00`00
0UKm1@0000<0<`0005@00`000P1d0P0000P0U@00000000be000@e@000QCe00@001ce000De0800003
;CD003Ud008iM003000eMCEe00<0008Q=P04000]Mbeg;GL30002BY`50002Eil30004Dad01P00Dad0
0000Dad000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad0100015<M00<005<MDad00`00
15<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad00`00
DaeC7@040003Dad00`00DaeC7@040004Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00
Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad01@000e<M00<005<MDad0
10000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<004;N@]h00`0015ll0P000gLf00@0
07LfMcH0009g=P04001k=G/e0002NcD00`00NcD00002NcD00`00NcD00002NeD00`00NgEkM@030000
1GnE001o]@00OkD00P0000Eo]000Nm@007OC00<00003Km8000000080089oo`03001oogoo03ioo`03
001oogoo00eoo`00LGoo00<007ooOol0dGoo0P000UKm00<005KmE_d01P0000<0<`0000000`0000<0
M00009D00P0000<0U0003;D00`000QCe00<001ce00000QCD00<002de00000cUd00@003Ee=GDeM@<0
008Q=P04000]Mbeg0002<O/30002Agl40003Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad0
1P00Dad00000Dad000AC7@<000AC7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M
00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000U<M00<005<MDad00U<M0`00
15<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`00
15<M00H005<M000005<M0004Dad30004Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00
DaeC7@040003Dad00`00DaeC7@040002@]h01`00GcaO?5ll001O?000009g=P04001g=WLf0002McH0
1`00McH007/e001k=@00009k=@03001k=@00009k=@800005NeD007]e001oU00200001GnE001o]@00
OkD00P0000=o]00000000P0000=gd`0000001000Q7oo00<007ooOol0?Goo00<007ooOol03Goo001b
Ool00`00Oomoo`3AOol00`00E_eFo@030002E_d300000`0A00000004000207@400000`2D000<]@02
00025?D300025=@00`00;CD00003>G@01P00=GDeMCEe000M5P8000038CH002eg008]M`04000anc7k
<O/30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad01000Dad0
00000U<M00<005<MDad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<M
Dad010000e<M00<005<MDad00`0015<M00@005<M0000009C7@06001C7E<MDad005<M0P000U<M00<0
05<MDad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M
00<005<MDad00`0015<M00H005<M000005<M0005Dad30003Dad00`00DaeC7@040003Dad00`00DaeC
7@040003Dad00`00DaeC7@040003Dad01`00@]i2gT;N001O?00000=O?003001g=P00009g=P04001g
=WLf0002McH01P00NcEk=@00NcD0009k=@05001k=G/e001k=00200000g]e0000000:00000g_C001g
d`0300000fnb000000020025Ool00`00Oomoo`0lOol00`00Oomoo`0=Ool007=oo`800=9oo`80009F
o@03001FoEKm00@000030140000c00@0000807@0000009@0002D000<]@<0008Dm@80008De0800005
;CD003Ud>G@00003=GD010007AH001EH0P000beg00@0037k0000009K7003001C7E<M00@000=C7@03
001C7E<M00@000=C7@03001C7E<M00@000AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M
0`000U<M00<005<MDad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<M
Dad0100015<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003
Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00Dad000020000
0e<M001C7@03Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@07
0004Gc`20002McH01000McIg=P000gLf0P0000Ak=@00NcD0009k=@03001k=@00009k=003001oE000
00<00005Ok@007ne001o]@0200000g^d000000090026Ool00`00Oomoo`0lOol00`00Oomoo`0=Ool0
07Eoo`03001oogoo0=1oo`03001FoEKm00<00005E_d0000000004@0400000`1d0000000400001P2D
000000003;D0008Dm@<0008De0<000<iM004000eMCEe00027AH01@005EP00000;GL00`0015/L0`00
0e<M00<005<MDad010000e<M00<005<MDad0100015<M00<005<MDad010000e<M00<005<MDad00`00
15<M00H005<M000005<M0004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03
001C7E<M00@000AC7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M
0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad0
100015<M00H005<M000005<M0004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C
7@060012gT;N@]h005ll0P000Ull00<007Lf00000WLf00@007LfMcH0009g=P06001k=G/e001k=@00
0W/e00d007/dNc@007mD001oT@00Ok@007ne001o]@0200000g^d001kd`0200000gOC000000040028
Ool00`00Oomoo`0kOol00`00Oomoo`0=Ool007Ioo`03001oogoo0=1oo`80009Fo@03001Fo@0000<0
00030140000c00<0000307@0000000<0000509@000003;D000025?D00`007?@000025=@00`009AD0
000200000cUd000eM@02=GD01@007AHM5P005EP00P000dZl00H005/L000005]N0004Dad30004Dad0
0`00DaeC7@030004Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad0
0`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000AC7@03001C7E<M
00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M
00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad0100015<M00<005<MDad00`0015<M
00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@070004Gc`20002McH0
1@00McIg=WLf00000WLf0`000W/e00T007/eNcD007/d001oE000Oi400P0000Eo]000OkD007ne0080
0003Nk@0000000P008Yoo`03001oogoo03Yoo`03001oogoo00eoo`00Mgoo00<007ooOol0d7oo00<0
05KmE_d00`0000=Fo@0000001P000P1d0P0000<0U00000001@0000@Dm@007?@0008De003000U5@00
0091]@T000035EP004Zl00=:_0<000=KGP04001C7@000002Dad00`00DaeC7@02Dad30002Dad00`00
DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad0
0`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<000AC7@03001C7E<M00@000=C7@03001C7E<M
00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000U<M
00<005<MDad00U<M0`000e<M00<005<MDad0100015<M00<005<MDad010000e<M00<005<MDad01000
0e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad01P00@]i2gT;N001O?080009O
?003001g=P00009g=P04001g=WLf0002McH01P00NcEk=@00NcD0009k=004001oE000Oi4200001Wnd
000007ne001o]@<00003Nm<007?B00H008Yoo`03001oogoo03Yoo`03001oogoo00eoo`00N7oo0P00
dGoo0P000UKm0`0000<03`0000000`0000D0E00007@0001d00@0000309@000be00<000077?@00000
5=@002DE00000d6e00D004GFAMI5eP00008ef0@00003B[`0000000=CG`03001KGU]N00<000AC7@06
001C7@00001C7@0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC
7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad01000Dad000000U<M00<005<MDad0
0U<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<M
Dad00`0015<M00H005<M000005<M0004Dad01P00Dad00000Dad000AC7@<000=C7@04001C7E<MDad4
0003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000
Dad000AC7@H000AO?080009g=P05001g=WLfMcH00002McH30002NcD01@00NcAk=000Oe@00`0000Eo
]000OkD007ne00800003Nk@0000000P008aoo`03001oogoo03Yoo`03001oogoo00aoo`00NWoo00<0
07ooOol0d7oo0P000UKm2@000P1d0`0000L0M000000000be0008U002000011cd000000000RDE00@0
046e@KD000A5eP04000ef3GH0002<S`30002Del40003Dad00`00DaeC7@030004Dad00`00DaeC7@03
0004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03
001C7E<M00@000AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad0
10000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad0
0`0015<M00H005<M000005<M0004Dad40003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000A2gP04001O?0000002Gc`0
0`00McH00002McH01000McIg=P000WLf00T007/eNcD007/d001oE000Oi400P0000io]000001o]@00
OkD007^d001gdP00Lm8007?B0`00SWoo00<007ooOol0>Goo00<007ooOol037oo001kOol00`00Oomo
o`3@Ool00`00E_eFo@0800000`1D0000M00400000`1d00000002000229@010007?@0012d0P0000<U
5@00@KD00T6e00D004GFAMI5eP0000<ef003000b?38l00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad01000
15<M00<005<MDad00`0015<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M
0004Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad00`00DaeC7@030004Dad01000Dad000000U<M00<005<MDad00U<M0`000e<M
00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M
00<004;N@]h00`0015ll0P000gLf00@007LfMcH0009g=P<0009k=004001oE000Oi4200001Wnd0000
07ne001o]@/008moo`03001oogoo03Qoo`03001oogoo00aoo`00O7oo00<007ooOol0d7oo0P000UKm
1@0000<0<`0000001@0000<0M00009@00P000PRD00<001cd00000Q2d00<002DE00000d6e00D004GF
AMI5eP0000<ef0<000=Bo@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C
7@03001C7E<M00<000AC7@04001C7@000002Dad01000DaeC7E<M0`0015<M00<005<MDad010000e<M
00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004
Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00@000=C7@03001C7E<M00@000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad01000
0e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000T;N00L005llGcaO?000
Gc`00002McH01000McIg=P000WLf00@007LfMcH0009k=003001oE00000T00003Nk<007OB00<00004
Kk400000002@Ool00`00Oomoo`0hOol00`00Oomoo`0<Ool007eoo`800=5oo`03001FoEKm00d00080
M0@0000429@0000000024;@00`009AD00003@KD00`00AMI5eP02AMH300000e;L001Bo@03D_d30003
Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040004
Dad00`00Dad00002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02Dad30003Dad00`00DaeC7@04
0003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad01P00Dad00000
Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000AC7@03
001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000U<M00<005<MDad00U<M0`000e<M00<005<M
Dad010000e<M00<005<MDad010000e<M00L004;N@]i2gP00Gc`00003Gc`00`00McH00002McH01000
McIg=P000WLf0`0000=oE000Oi400P0000Io]@00001oU@00OiD;002AOol00`00Oomoo`0gOol00`00
Oomoo`0<Ool007moo`03001oogoo0<moo`80009Fo@D0000303<0001D0080000307@0001d00800004
4;@000RD29@200034;@20003@KD01000AMI5eTGF0P0015;L00H005;m000005Ln0004Dad30003Dad0
0`00DaeC7@040004Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad0
1P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<M
Dad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30003
Dad00`00DaeC7@040003Dad00`00DaeC7@040004Dad00`00DaeC7@040003Dad00`00DaeC7@030004
Dad01P00Dad00000Dad000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<0
05<MDad01`0015ll0P000WLf00@007LfMcH0009g=P05001g5WLF001oE00200002F^>00000000OiD0
07nE001k/`09002COol00`00Oomoo`0fOol00`00Oomoo`0<Ool0081oo`03001oogoo0<moo`03001F
oEKm00H0000403<0000007@50000112d0008U0RD0`000Q2d0`000d6e0`000U[l00<005;LD]`01000
0eLn00@005<M0000009C7@04001C7E<MDad30004Dad00`00DaeC7@040003Dad00`00DaeC7@040003
Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad01P00Dad00000Dad0
00AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad0100015<M00<005<MDad01000
0e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<MDad00`0015<M00H005<M000005<M
0004Dad30003Dad00`00DaeC7@040003Dad01P00@]i2gT;N001O?080009O?003001g=P00009g=P04
001g=WLf0002MaH00`00Oe@0000200001Wne000007nE001oU@X009Eoo`03001oogoo03Eoo`03001o
ogoo00aoo`00PGoo00<007ooOol0cgoo0P0000=Fo@0000000`0000<0<`0005@00`0000<0<`000000
0`0000<8U0005=D00P0000<@]0003=H01@0015[l0`0015MN00<005LnEch00`0015<M00<005<M0000
0U<M00<005<MDad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad0
10000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad0
0`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad0
1P00Dad00000Dad000AC7@<000AC7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M
00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M
00<005<MDad01`0015ll0P000WLf00@007LfMcH0009g5P05001kE@00001[SP0200001WnF000007nE
001k/`T009Eoo`03001oogoo03Eoo`03001oogoo00aoo`00PWoo0P00d7oo00<005KmE_d010000P0c
1@0000@0<`00000@]0<000035=D002UF00<000033=H004ZL009:W004001Jo0000003Fih00`00EeiG
GP040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M009C7@<0
00=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<0
00AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<0
05<MDad010000e<M00<005<MDad010000e<M00@005<M0000009C7@03001C7E<M009C7@<0009C7@03
001C7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C
7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00H004;N@]i2gP00Gc`20002Gc`0
0`00McH00002McH01@00MaIg5P00NeD00`0000Qo]@00001oU@00OiD007^c1@0000=[/0000000Ugoo
00<007ooOol0=Goo00<007ooOol02goo0024Ool00`00Oomoo`3>Ool200000eKm0000000200000`0c
0000000300001P0c0000012d000</`<000<YEP@0009:W0@0009KWP@000=C7@03001C7E<M00@000=C
7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00H005<M000005<M0004Dad30003Dad00`00
DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00
Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0
00AC7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M00H005<M000005<M0004Dad30003Dad0
0`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad0
1P00Dad00000Dad000AC7@H000AO?080009g=P05001g5WLF001kE@0300001gne001oUP00OiD007nE
00T009Uoo`03001oogoo03Aoo`03001oogoo00]oo`00QGoo00<007ooOol0cWoo00<005Km00002P00
00@0<`000000008</`03000De@00008YEP03000anS7j00<0009;G`@000=C7@03001C7E<M00@000=C
7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@06001C7@00001C7@00
15<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<M
Dad00`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040004Dad00`00DaeC7@030004
Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad01P00Dad00000Dad0
00AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00<000AC7@06001C7@00001C7@0014;N00@005ll0000009O?003001g=P00009g5P03001kE@00
00800003OkD007nF00800003OiD007^c00P009Uoo`03001oogoo03Aoo`03001oogoo00]oo`00QWoo
00<007ooOol0cWoo1@0000<04P0000000P0000<0U00000000`000Pbc00<001CE00000bUF00@0037j
<OXanP<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad01000
0e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00@005<M0000009C
7@04001C7E<MDad30004Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003
Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<000=C7@03001C
7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@030012
gT;N00<000AO?08000=g5P03001kE@0000D00003OiD007nE00@00003Lm800000008009]oo`03001o
ogoo03=oo`03001oogoo00]oo`00Qgoo0P00cgoo1@0000@04P000000M080000307@000000080008<
/`8000<YEP06000anP00001O700015<M0`000U<M00<005<MDad00U<M0`000e<M00<005<MDad01000
0e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00@005<M0000009C
7@04001C7E<MDad30004Dad00`00DaeC7@030004Dad00`00DaeC7@030004Dad00`00DaeC7@030004
Dad00`00DaeC7@030004Dad00`00Dad00002Dad00`00DaeC7@02Dad30002Dad00`00DaeC7@02Dad3
0003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@03
0004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03
001C7E<M00@000=C7@03001C7E<M00@00092gP07001O?5llGc`005lK00000WLF00<007]E00000P00
00=kU`00NgH0100000=kS`0000001P00W7oo00<007ooOol0<Woo00<007ooOol02goo0029Ool00`00
Oomoo`3=Ool400000`0B0000000400000`1d0000L`0200001@bc00000000:EH00`0015lL00@005<M
0000009C7@06001C7E<MDad005<M0P000U<M00@005<MDaeC7@<000AC7@03001C7E<M00<000AC7@03
001C7E<M00<000AC7@03001C7E<M00<000AC7@03001C7E<M00<000AC7@03001C7@00009C7@03001C
7E<M009C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03
001C7E<M00<000AC7@06001C7@00001C7@0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC
7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad0
0000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C
7@070012gT;N@]h005ll00000elK00@007LF001kE@800007NiL007]f001kE@00Og@0100000=c/P00
00000P00WWoo00<007ooOol0<Goo00<007ooOol02goo002:Ool00`00Oomoo`3>Ool300001`0B0000
000009D0001d00<00004:EH000003=H20003B[d01000GaaO75lL0`0015<M00<005<MDad00`0015<M
00<005<M00000U<M00<005<MDad00U<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M
00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC
7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00DaeC
7@030004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C
7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<M
Dad010000e<M00<005<MDad010000e<M00<005<MDad01`0015lK0P000W]E0P0000MkU`00NgH007]E
001oM008002OOol00`00Oomoo`0aOol00`00Oomoo`0;Ool008]oo`03001oogoo0<eoo`P0000309D0
001d0080008YEP8000033=H004Zm00=:_@03001O700000=OOP03001C7E<M00@000=C7@03001C7E<M
00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M
00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC
7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC
7@030004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C
7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<M
Dad010000e<M00<005<MDad010000e<M00H004;N@]i2gP00Ga/20002Gcd300001g^G001kMP00NeD0
07md00@00003Lk80000000800:1oo`03001oogoo035oo`03001oogoo00Yoo`00S7oo0P00cWoo1@00
00P0M00009D0001d0000L`000RUF10000TZm10000Umn10000e<M00<005<MDad010000e<M00<005<M
Dad00`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003
Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<000=C7@03001C
7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad01000
0e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad00`00
DaeC7@040003Dad00`00DaeC7@070004Gcd20002NiL01P00NgH007]E001oM0P00:9oo`03001oogoo
031oo`03001oogoo00Yoo`00SWoo00<007ooOol0bgoo0P0000<03P0000000P000P2E10000RUF00<0
03XJ>QX00`000U=O10000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`00
15<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00
DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@0
00=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<0
00AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<0
05<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@04
0003Dad01P00>[hj_SZn001O?@@00008NiL007]fNgH007]E001oM0L00:Aoo`03001oogoo02moo`03
001oogoo00Yoo`00Sgoo00<007ooOol0bgoo1`0000<0U@0000000P000bUF00@003XJ>QXj6P<000=C
7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC
7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<M
Dad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003
Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004
Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad02`00
00MkU`00NgH007]E001oM008002TOol00`00Oomoo`0_Ool00`00Oomoo`0:Ool0091oo`03001oogoo
0<Yoo`0300003@000080000507@00000000@m@020003:EH01000>QX000000UlL00<005<MDad01000
0e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`00
15<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00
DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@0
00=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<0
00AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<0
05<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30003D_d01000?]h00000
0Ull00T006li000007]f001kE@00Og@01`00YWoo00<007ooOol0;Woo00<007ooOol02Woo002AOol2
003;Ool600000`1d00000003000012UF000000001ElL0P0015<M00<005<MDad00`000e<M00<005<M
Dad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M
000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003
Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C
7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C
7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad01000
0e<M00<005<MDad00`0015<M00H005<M000005<M0004D_d20003Gc`01P00KcU_>@00LcL0009kE@03
001oM00000H00:Moo`03001oogoo02eoo`03001oogoo00Yoo`00Tgoo00<007ooOol0bGoo1@000P1d
0P0000<DmP0000000dJM00L005lLGaaO7000Hgd00004Dad30003Dad00`00DaeC7@030004Dad00`00
DaeC7@030004Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00
Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0
00=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<0
05<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H0
05<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@04
0003Dad00`00DaeC7@030004Dad01P00D_d00000E_`0009O?004001_>Fli0002LcL300000gmd0000
0005002XOol00`00Oomoo`0]Ool00`00Oomoo`0:Ool009Aoo`03001oogoo0<Uoo`D0000607@0013e
000DmP0014JM00<005lL00000f=m00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad0
1P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M
00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M
00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M
00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC
7@040003Dad00`00DaeC7@030004E_`01@00Gc`006li00000W<g00<007<FLaH02000ZWoo00<007oo
Ool0;7oo00<007ooOol02Woo002EOol00`00Oomoo`38Ool300000`1d0000M00300025?H00`00AYe6
W@040002Hgd30004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M
00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7E<M00<000=C7@04001C7@00
0002Dad01000DaeC7E<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad0
10000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad0
1P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M
00@000=>oP03001Fo5Kl00<0009_>@04001c=g<g0002LaH00`00NeH00005002[Ool00`00Oomoo`0/
Ool00`00Oomoo`09Ool009Ioo`03001oogoo0<Qoo`@00080M080008DmP<00097?`@000=K?@03001C
7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad01000
0e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<M00000U<M
00@005<MDaeC7@<000AC7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C
7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<M
Dad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M
000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00C_i>oP040002
Fa`00`00KcT00002LcL01@00LaIc5P00NeH01P00[Goo00<007ooOol0:goo00<007ooOol02Goo002G
Ool20038Ool50000101d000000000QCf00@001Ui000000=:oP03001K?E/m00@000=C7@03001C7E<M
00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M
00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<M00000U<M00<0
05<MDad00U<M0`000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad010000e<M
00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC
7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad0
0000Dad000AC7@<000=C7@03001C7E<M00@0009C7@04001C7E<MDad40002B_h01000FaaK75/L0P00
0W<g00H007<FLaIc5P00NeH200000g?B0000002^Ool00`00Oomoo`0[Ool00`00Oomoo`09Ool009Uo
o`03001oogoo0<Ioo`80000507@00000000@e@0400026GT00`00B_i:oP040003Ech00`00DaeC7@04
0003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03
001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06
001C7@00001C7@0015<M0`000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad0
10000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad0
1P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@0009C7@03001:oT[n009:oP<0009K7003001c
=`00009c5P03001kEP0000D00:moo`03001oogoo02Yoo`03001oogoo00Uoo`00VWoo00<007ooOol0
aGoo100000@<]0000000008e^0H000A?7P03001G?ULn00<000=C7@03001C7E<M00@000=C7@03001C
7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad01000
0e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M
0004Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00
DaeC7@030004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@0
00=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C
7@0015<M0`000U<M00<005<MDad01`0015/L0P000g<F00D007]F000007OE00800;5oo`03001oogoo
02Uoo`03001oogoo00Uoo`00Vgoo00<007ooOol0aGoo0`000Pbd00<0013E00000SFh00<0049J@UX0
0T9J00<004lNCah010000e<M00<005<MDad00`0015<M00<005<MDad00`000e<M00<005<MDad01000
0e<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00
DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0
00=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<0
00AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<0
05<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0003Dad3
0003Dad01P00A_i6oTKn001K70800005F_/007<FLaH00002NeH5002bOol00`00Oomoo`0XOol00`00
Oomoo`09Ool009aoo`800<Eoo`<0008<]003000@e@0000<e^0040012FT9J@UX30003Dad00`00DaeC
7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00DaeC7@030003Dad01P00Dad0
0000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C
7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<M
Dad00`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M
000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003
Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad300000e<M001C7@03Dad60004F_/01000LaH0
07]F0P0000=ge@000000/goo00<007ooOol0:7oo00<007ooOol02Goo002NOol00`00Oomoo`33Ool3
00023;@20003=KP01P00@UX00000Fcd000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@0
00=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@06001C7@00001C7@0015<M0`000e<M00<0
05<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<0
05<MDad00`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@04
0003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<000=C7@03
001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03
001C7E<M00<000AC7@06001C7@00001C7@000dKN00<005[kF_/00U[k0`0000=kEP0000000`00]7oo
00<007ooOol09goo00<007ooOol02Goo002OOol00`00Oomoo`32Ool400001@bd00000000=KP00`00
15/m00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00
DaeC7@040003Dad00`00DaeC7@030003Dad01000Dad000000U<M00@005<MDaeC7@<000=C7@03001C
7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad00`000e<M00<005<MDad01000
0e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad00`00
DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00
DaeC7@030004Dad01P00A]i6gTKN001Jn`80009K?@@00003Nm@007oo0;Eoo`03001oogoo02Moo`03
001oogoo00Qoo`00X7oo00<007ooOol0`Woo0P0000@]EP00000@m`8000=:_@03001K?E/m00<000AC
7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<M
Dad010000e<M00<005<MDad00`0015<M00<005<M00000U<M00@005<MDaeC7@<000=C7@03001C7E<M
00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M
00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad00`000e<M00<005<MDad010000e<M
00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC
7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC
7@070003Fcd3000017OE00000000]Woo00<007ooOol09goo00<007ooOol027oo002QOol20032Ool2
0002;EH200024?L00`00B[e:_@030003Feh00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0
00=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<0
00AC7@03001C7@00009C7@04001C7E<MDad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003
Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad0
00AC7@<0009C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00<000AC7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad00`00
0e<M00<005<MDad010000e<M00<005<MDad010000e<M00H003Zn>[hj_P00Fcd200001FMl000007nE
0000^7oo00<007ooOol09Woo00<007ooOol027oo002SOol00`00Oomoo`30Ool20002;EH60003Ccl0
0`00FeiKGP030003Dad00`00DaeC7@040003Dad01000Dad000000U<M00<005<MDad010000e<M00<0
05<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<0
05<M00000U<M00@005<MDaeC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@04001C7@000002Dad00`00DaeC
7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC
7@030004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C
7@03001C7E<M00@000=C7@03001C7E<M00L0009WO003001gV00000800;Uoo`03001oogoo02Eoo`03
001oogoo00Qoo`00Y7oo00<007ooOol0_goo0P000ReF00<003hJ?QX00ShJ00<004loCcl010000e<M
00<005<MDad00`0015<M00<005<MDad00`000e<M0`000e<M00<005<MDad010000e<M00<005<MDad0
10000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<M0000
0U<M00@005<MDaeC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0
00=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@<000=C7@03001C7E<M00<000=C7@03001C
7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C
7@00001C7@0015<M0`000U<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad01000
0e;L00<004:m00000VMl0`0000=oU@00Ool0^Woo00<007ooOol097oo00<007ooOol027oo002UOol0
0`00Oomoo`2oOol01@00;EH]EReF00000chJ0`000e<M00<005<MDad010000e<M00<005<MDad01000
0e<M00<005<M00000U<M00@005<MDaeC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C
7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7@00009C7@04
001C7E<MDad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M00@000=C7@03001C7E<M
00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@06001C7@00
001C7@000e<M0`000e<M00<005<MDad010000e<M00<005<MDad010000U<M00<005;LD]`00U;L0P00
0fMl00<007NH00000P00^goo00<007ooOol097oo00<007ooOol027oo002VOol2002oOol20002;EH0
1000?QX000000UlK00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<0
05<M00000U<M00@005<MDaeC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7@00009C7@04001C7E<M
Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC
7@030004Dad01P00Dad00000Dad000=C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C
7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@05001C7@00Dad00004
Dad30003Dad00`00DaeC7@040003Dad01P00DaeC7E<M001Bg080009C7@03001WO00000800003OiD0
07oo0;aoo`03001oogoo02=oo`03001oogoo00Qoo`00Z7oo00<007ooOol0_Goo1@0015lK0`000e<M
00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<M00000U<M00@0
05<MDaeC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03
001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7@00009C7@03001C7E<M00@000=C7@03001C
7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@05001C
7@00Dad00004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003
Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad01000Dad000000U<M00<005<MDad010000e<M
00<005<MDad01`0015<M0`0000AgV000OiD00;ioo`03001oogoo02=oo`03001oogoo00Moo`00ZGoo
00<007ooOol0_7oo0P000T:M00D005lKGa]O6`0000=SG003001C7E<M00<000=C7@03001C7E<M00@0
00=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7@00009C7@04001C7E<MDad30003
Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003
Dad00`00DaeC7@030003Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC
7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad01P00Dad00000Dad000AC7@<000=C
7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C
7@03001C7E<M00<000AC7@<000=C7@03001C7E<M00@000=C7@06001:oT[nB_h005<M0`0000A[nP00
001oU@800;moo`03001oogoo029oo`03001oogoo00Moo`00ZWoo00<007ooOol0^goo0`000T:M00<0
05lK000016=L0`000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad010000e<M
00<005<MDad00`0015<M00<005<M00000U<M00@005<MDaeC7@<000=C7@03001C7E<M00@000=C7@03
001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7@00009C7@04001C
7E<MDad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00
DaeC7@040003Dad00`00DaeC7@030003Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@0
00=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@06001C7@00001C
7@0015<M0`000e<M00<005<MDad02`0000AgV000OiD00<1oo`03001oogoo029oo`03001oogoo00Mo
o`00Zgoo0P00_7oo00<0001C00001@0000=SG00000000Ull00<005<MDad010000e<M00<005<MDad0
0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00<005<M0000
0U<M00@005<MDaeC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0
00=C7@03001C7E<M00<000AC7@03001C7@00009C7@04001C7E<MDad30003Dad00`00DaeC7@040003
Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@020004
Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00@0009C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`000e;m00@004Kn000000=S
?0D00<5oo`03001oogoo025oo`03001oogoo00Moo`00[Goo00<007ooOol0^Goo00@0001C00000093
?`<000AO?0<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03
001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7@0000=C7@03001C7E<M00<000=C7@03001C
7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@05001C
7@00Dad00004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003
Dad00`00DaeC7@040002Dad00`00DaeC7@030004Dad01000Dad000000U<M00<005<MDad010000e<M
00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`0015<M
00H005<M000005<M0004D_d20004Hc`01@00JaP007Mg0000`goo00<007ooOol087oo00<007ooOol0
1goo002^Ool00`00Oomoo`2iOol00`0005<000020003@]h01P00Gc`00000Gcd000AC7@<000=C7@03
001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03
001C7E<M00<000AC7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@0
00=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@06001C7@00001C7@0015<M0`000e<M00<0
05<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<0
05<MDad00`0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`00
0e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005;m000005Kl0003Hc`01000JaP007Mg
0P00`goo00<007ooOol087oo00<007ooOol01goo002_Ool00`00Oomoo`2hOol30000113e0012gT;N
0`0015lm00H005<M000005<M0004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad0
0`00DaeC7@040003Dad00`00DaeC7@040003Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M
00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M
00<000=C7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M
00<005<MDad010000U<M00<005<MDad010000e<M00H005<M000005<M0004Dad30003Dad00`00DaeC
7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC
7@030004E_`00`00Hc`00002JaP00`00MgL00035Ool00`00Oomoo`0OOol00`00Oomoo`07Ool00;1o
o`800;Qoo`<000044?D000000003A_h00`00GceO?@030004Dad01000Dad000000U<M00<005<MDad0
10000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad0
0`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@020004Dad01000Dad000000U<M00<0
05<MDad010000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<0
05<MDad00`0015<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@040002Dad00`00DaeC7@04
0003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Cah00`00E_aFo0030002JaP01000MgL00000
aWoo00<007ooOol07Woo00<007ooOol01goo002bOol00`00Oomoo`2fOol30000113e000IN@000TKn
0`000e/m00<005<MDad00`0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<0
05<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad3
0002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@04
0002Dad00`00DaeC7@030004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00
DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000AC7@<0
00=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001?7TlN00@0
00=Jn`05001[6000MgL00038Ool00`00Oomoo`0NOol00`00Oomoo`06Ool00;=oo`03001oogoo0;Eo
o`03000040000080008IN@8000=:oP03001K?E/m00<000=C7@06001C7@00001C7@0015<M0`000e<M
00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M
00<005<MDad00`0015<M00@005<M0000009C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03
001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@06001C7@00001C7@0015<M
0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad0
10000e<M00<005<MDad00`0015<M00@005<M0000009C7@03001C7E<M00@0009C7@03001C7E<M00@0
00=C7@03001C7E<M00@000=C7@03001C7E<M00@0009:oP03001Jne[k009Jn`800003MgL000000<Qo
o`03001oogoo01ioo`03001oogoo00Ioo`00]7oo00<007ooOol0]Goo0P0000<aU`006GT00QUi00<0
04[nB_h010000eLn00<005<MDad00`000e<M00H005<M000005<M0004Dad30003Dad00`00DaeC7@04
0003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@03
0004Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00
DaeC7@040003Dad00`00DaeC7@020004Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@0
00=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<0
00AC7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@06001:
oT[nB_h005[k0P0000AK?@00MgL00<Yoo`03001oogoo01eoo`03001oogoo00Ioo`00]Goo0P00]Goo
00@0000@000aU`H000=?7P03001G?ULn00@000=C7@03001C7E<M00<000=C7@04001C7@000002Dad0
0`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00<000=C7@03001C7E<M
00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00<000AC7@04001C7@00
0002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@04
0003Dad00`00DaeC7@040003Dad01P00Dad00000Dad000AC7@<0009C7@03001C7E<M00@000=C7@03
001C7E<M00@000=C7@03001C7E<M00L000=K?@800<aoo`03001oogoo01aoo`03001oogoo00Ioo`00
]goo00<007ooOol0/goo0P0000<aU`00ASX00dHj00<004lNCah010000e<M00<005<MDad010000e<M
00<005<MDad00`000e<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad0
0`000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M000005<M0004Dad30002Dad0
0`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad0
0`00DaeC7@030004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@04
0003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000=C7@<000=C7@03
001C7E<M00@000=C7@03001C7E<M00@000=C7@06000ngSkN?]h005/m0`00cGoo00<007ooOol06goo
00<007ooOol01Woo002hOol00`00Oomoo`2cOol01000<ILaU`000dHj0`000e<M00<005<MDad01000
0e<M00<005<MDad010000e<M00<005<M00000U<M00@005<MDaeC7@<000=C7@03001C7E<M00@000=C
7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC
7@04001C7@000002Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad00`00DaeC7@030003Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M
00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M
00<000AC7@<0009C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00T00<ioo`03
001oogoo01]oo`03001oogoo00Ioo`00^Goo00<007ooOol0/Woo0P0000<aU`00ASX00P000UlK00<0
05<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`0015<M00D005<M001C7@0000AC7@<0
00=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@0
00=C7@03001C7E<M00<000AC7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C
7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M0`00
0e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad01000
0e<M00<005<MDad00P0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000U;L00@004JL
AYa6W0800=1oo`03001oogoo01Yoo`03001oogoo00Ioo`00^Woo00<007ooOol0/Woo10001ElK0P00
0e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00@005<M0000009C
7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C
7@03001C7E<M00@000=C7@06001C7@00001C7@0015<M0`000U<M00<005<MDad010000e<M00<005<M
Dad010000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad00`0015<M00@005<M
0000009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M
00@000=C7@03001C7E<M00@0009C7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000U<M
00<005;LD]`00U;L00D004JL001[W0000=5oo`03001oogoo01Yoo`03001oogoo00Eoo`00^goo0P00
/Woo00D004:M@Ye2W@0000=O6`04001SG6=L0002Dad30003Dad00`00DaeC7@040003Dad00`00DaeC
7@040003Dad00`00DaeC7@030003Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad0
0`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad01P00Dad00000Dad000=C
7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M
00@000=C7@03001C7E<M00<000AC7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03
001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00<000AC7@06001C7@00001C7@0015<M
0`000e<M00D005<MDaeC7@00009Bg0<00003Ji`007oo0=5oo`03001oogoo01Yoo`03001oogoo00Eo
o`00_Goo00<007ooOol0/7oo00L004:M@Ye2W@00Ga/00003He`30003Dad00`00DaeC7@030003Dad0
0`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00Dad00002Dad01000DaeC7E<M0`000e<M00<0
05<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<0
05<MDad00`0015<M00<005<M00000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<M
Dad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00H005<M000005<M0004Dad30002
Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030003
Dad00`00DaeC7@030004Dad01000Dad000000U<M00<005<MDad020000U<M0P00e7oo00<007ooOol0
6Goo00<007ooOol01Goo002nOol00`00Oomoo`2`Ool600000f=L00000002Gc`00`00DaeC7@040003
Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00Dad00002Dad0
1000DaeC7E<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`000e<M
00<005<MDad010000e<M00<005<MDad00`0015<M0`000U<M00<005<MDad010000e<M00<005<MDad0
10000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`0015<M00H005<M0000
05<M0003Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad0
0`00DaeC7@040003Dad00`00DaeC7@030004Dad30003Dad01@00A_i6oP00Dad01000eGoo00<007oo
Ool067oo00<007ooOol01Goo002oOol00`00Oomoo`2aOol50004Gc`30003Dad00`00DaeC7@040003
Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00Dad00002Dad0
0`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad0
0`00DaeC7@040003Dad01P00Dad00000Dad000=C7@<000=C7@03001C7E<M00@000=C7@03001C7E<M
00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@03001C7@00
009C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@0
00=C7@03001C7E<M00@000=C7@06001C7@00001C7@0015<M2000egoo00<007ooOol05goo00<007oo
Ool01Goo0030Ool2002bOol01P00?]hngSkN001O?080009O?003001C7E<M00@000=C7@03001C7E<M
00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@<000=C7@03
001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03
001C7E<M00<000AC7@05001C7@00Dad00004Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@04
0002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad30003Dad00`00
DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00
DaeC7@030004Dad01P00Dad00000D[/0009:W004001[W6^L003GOol00`00Oomoo`0GOol00`00Oomo
o`05Ool00<9oo`03001oogoo0;1oo`03000ngSkN008000AO?0<000=C7@03001C7E<M00@000=C7@03
001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7@00009C7@04001C
7E<MDad30003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00
DaeC7@040003Dad00`00DaeC7@030003Dad01000Dad000000U<M00<005<MDad010000e<M00<005<M
Dad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00D005<M
001C7@0000AC7@<000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C
7@03001C7E<M00@000=C7@03001C7E<M00<000AB^`80009[W003001oogoo0=Moo`03001oogoo01Io
o`03001oogoo00Eoo`00`goo00<007ooOol0/7oo0P000SkN00@005ll0000009O?003001C7E<M00@0
00=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00<0
00AC7@03001C7@0000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C
7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@<000=C7@03001C7E<M
00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M
00<000=C7@04001C7@000002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@03
0003Dad00`00DaeC7@040003Dad00`00DaeC7@040002D]`01000D[]B^e:k0P000V^L00<007ooOol0
fGoo00<007ooOol05Goo00<007ooOol01Goo0034Ool00`00Oomoo`2`Ool00`00?]hngP030003Gc`3
0003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@04
0003Dad00`00DaeC7@030004Dad30002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00
DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad01@00Dad005<M000015<M0`00
0e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad01000
0e<M00<005<MDad00P0015<M0`000e<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<M
Dad010000e<M00<005<MDad010000e;m00L005;LD]aBg000D[/00002Eeh00`00Ji`0003LOol00`00
Oomoo`0EOol00`00Oomoo`04Ool00<Eoo`800;5oo`8000=2gP03001O?00000=O?003001C7E<M00<0
00=C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@0
00=C7@06001C7@00001C7@000e<M0`000e<M00<005<MDad010000e<M00<005<MDad010000e<M00<0
05<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00@005<M0000009C7@03001C
7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C
7E<M00@0009C7@06001C7@00001C7@0015<M0`000e<M00<005<MDad010000U<M00<005<MDad01000
0e<M00<005<MDad010000e<M00<005;mD_d01`000UMN0`00gGoo00<007ooOol05Goo00<007ooOol0
17oo0037Ool00`00Oomoo`2_Ool00`00@]i2gP030004Gc`30003Dad00`00DaeC7@030003Dad00`00
DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00
Dad00003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC
7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@020004Dad30003Dad00`00DaeC7@040003Dad0
0`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@020004Dad0
1000Dad000000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<0
05<MDad010000dlN00<004<O@al00`00hGoo00<007ooOol057oo00<007ooOol017oo0038Ool00`00
Oomoo`2_Ool20003@]h01000Gc`000000Ull00<005<MDad010000e<M00<005<MDad00`000e<M00<0
05<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`0015<M0`00
0U<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad01000
0e<M00<005<MDad010000U<M00@005<M0000009C7@03001C7E<M00@000=C7@03001C7E<M00@0009C
7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00<000AC
7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@000=?7P03001?7TlN
00@00>Eoo`03001oogoo01=oo`03001oogoo00Aoo`00bGoo00<007ooOol0[goo00<004;N@]h00`00
15ll0`000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<M
Dad00`000e<M00<005<MDad010000e<M00H005<M000005<M0003Dad30003Dad00`00DaeC7@040003
Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@020004
Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC
7@040003Dad00`00DaeC7@030003Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00<000=C
7@03001C7E<M00@000=C7@03001?7TlN00H00>Moo`03001oogoo01=oo`03001oogoo00Aoo`00bWoo
0P00/7oo0P000T;N00L005llGcaO?000Gc`00004Dad30003Dad00`00DaeC7@030003Dad00`00DaeC
7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad00`00Dad0
0002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@04
0003Dad00`00DaeC7@040002Dad01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00@0009C7@03
001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00<000AC7@04
001C7@000002Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040003D]`00`00
Jg`0003XOol00`00Oomoo`0BOol00`00Oomoo`04Ool00<aoo`03001oogoo0:moo`060012gT;N001O
?0000ell00@005<M0000009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@0
00=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@<000=C7@03001C
7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C
7E<M00<000=C7@04001C7@000002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC
7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@030004Dad30002Dad0
0`00DaeC7@040003Dad00`00DaeC7@040002D]`01`00D]aBg5;L001[O0000>Yoo`03001oogoo015o
o`03001oogoo00Aoo`00cGoo00<007ooOol0[goo100015ll0P0015<M0`000e<M00<005<MDad01000
0U<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad01000
0e<M00<005<M00000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad010000U<M
00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00P0015<M0`000e<M00<005<MDad0
10000U<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad0
10000e<M00@005<M0000009C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001Bg5;L009B
g005001Bg000Jg`0003/Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00<ioo`03001oogoo0:moo`05
0012gT;N001O?0020002Gc`01P00Dad00000Dad000AC7@<000=C7@03001C7E<M00<000=C7@03001C
7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@<0009C
7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C
7@03001C7E<M00@0009C7@06001C7@00001C7@0015<M0`000e<M00<005<MDad00`000e<M00<005<M
Dad010000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`0015<M0`000U<M
00<005<MDad010000e<M00D005<MDaeC7@00009Bg0@00003Jg`007oo0>]oo`03001oogoo015oo`03
001oogoo00=oo`00cgoo0P00/7oo1@000ell0`000e<M00@005<M0000009C7@03001C7E<M00@000=C
7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C
7@06001C7@00001C7@000e<M0`000e<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<M
Dad010000e<M00<005<MDad010000e<M00<005<MDad00P0015<M00@005<M0000009C7@03001C7E<M
00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M
00@000=C7@06001C7@00001C7@000e<M0`000e<M00<005<MDad020000e<N0P00kWoo00<007ooOol0
47oo00<007ooOol00goo003AOol00`00Oomoo`2^Ool01`00@]i2gT;N001O?00000=O7003001C7E<M
008000AC7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@000=C7@03
001C7E<M00<000=C7@03001C7E<M00<000AC7@03001C7@0000=C7@03001C7E<M00<000=C7@03001C
7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C
7E<M00<000AC7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00@0009C
7@03001C7E<M00@000=C7@03001C7E<M00<000AC7@<0009C7@03001C7E<M00@000=C7@06001:oT[n
B_h005<N0`00l7oo00<007ooOol03goo00<007ooOol00goo003BOol00`00Oomoo`2^Ool50004Ga`3
0002Dad01000Dad000000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad01000
0e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`0015<M0`000U<M00<005<M
Dad010000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad010000e<M00<005<M
Dad00`000e<M00@005<M0000009C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M
00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M008000AC7@<000=C7@03
001C7E<M00T00?9oo`03001oogoo00ioo`03001oogoo00=oo`00dgoo00<007ooOol0[Woo00H004;N
@]i2gP00Ga`20002Ga`00`00DaeC7@030003Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@03
0003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad01000Dad00000
0U<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad01000
0e<M00<005<MDad010000U<M00<005<MDad00`0015<M0`000e<M00<005<MDad00`000e<M00<005<M
Dad010000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad010000U<M00@005<M
0000009C7@03001C7E<M00@0009BVP07001>VdjKCY/006nl0000lWoo00<007ooOol03Woo00<007oo
Ool00goo003DOol2002_Ool50004Ga`30003Dad00`00Dad00002Dad00`00DaeC7@040003Dad00`00
DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00
DaeC7@030004Dad30002Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003
Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad01000Dad000000U<M00<005<MDad010000U<M
00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad010000e<M
00<005<MDad00P0015<M0`000U;K00<005:JDYX00U:J00D004jK001__0000?Aoo`03001oogoo00eo
o`03001oogoo00=oo`00eWoo00<007ooOol0[Goo00H004;N@]i2gP00Ga`20002Ga`00`00DaeC7@03
0003Dad30003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00
DaeC7@040002Dad00`00DaeC7@040003Dad01000Dad000000U<M00<005<MDad00`000e<M00<005<M
Dad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<M
Dad00`0015<M0`000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M
00<005<MDad010000e<M00<005<MDad010000U<M00H005<M000005;L0004D]/01000DYYBVU:J0`00
00=__000Ool0m7oo00<007ooOol037oo00<007ooOol00goo003GOol00`00Oomoo`2]Ool50004Ga`3
0003Dad00`00Dad00003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@030003
Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@030004Dad30002Dad00`00DaeC
7@040003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC
7@030003Dad01000Dad000000U<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad0
10000U<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad00`0015;L00H005;KD]]B
f`00DYX20002Eel2003fOol00`00Oomoo`0=Ool00`00Oomoo`02Ool00=Qoo`03001oogoo0:ioo`05
000ngSkN001O70020002Ga/00`00DaeC7@030004Dad30002Dad00`00DaeC7@040003Dad00`00DaeC
7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad01000Dad0
00000U<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad0
10000e<M00<005<MDad010000U<M00<005<MDad00`0015<M0`000e<M00<005<MDad00`000e<M00<0
05<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`000e;L00<0
05;LD]`0200000=GG`000000nGoo00<007ooOol037oo00<007ooOol00Woo003IOol2002_Ool40004
Ga/30003Dad01000Dad000000U;m00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad0
0`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad00`0015<M0`000e<M00<0
05<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<0
05<MDad00`000e<M00@005<M0000009C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C
7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@0009Bo@03001Bg5;L00@000=?G`H00?ao
o`03001oogoo00]oo`03001oogoo009oo`00fgoo00<007ooOol0[Goo00D004:m@[d005lK0080009S
?003001C7E<M00<000ABo@<000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M
00<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@04001C7@000002Dad00`00DaeC7@04
0002Dad00`00DaeC7@040003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@04
0002Dad00`00DaeC7@030004Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00
DaeC7@030003Dad00`00DaeC7@040003Dad00`00D_eBo@030003Ccl01000Cel00000ogoo17oo00<0
07ooOol02Woo00<007ooOol00Woo003LOol00`00Oomoo`2]Ool50003Hc`30003Dad01000D_d00000
0UKl00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad01000
0e<M00<005<MDad010000U<M00<005<MDad00`0015<M0`000e<M00<005<MDad00`000e<M00<005<M
Dad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00@005<M
0000009C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M
00@000=C7@03001C7E<M00@0009?7P03001??dlo00<00?moo`Ioo`03001oogoo00Yoo`03001oogoo
009oo`00gGoo00<007ooOol0[Goo00L003lO?alo7`00Hc`00002Eod00`00DaeC7@030004E_`30003
Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040003
Dad00`00DaeC7@030003Dad01000Dad000000U<M00<005<MDad010000U<M00<005<MDad010000e<M
00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad00`0015<M
0`000U<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad0
10000TlN00<004lNCah01000ogoo2Woo00<007ooOol02Goo00<007ooOol00Woo003NOol2002^Ool;
0003Cah01000E_`000000U/L00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad01000
0U<M00<005<MDad010000e<M00<005<MDad010000U<M00<005<MDad00`0015<M0`000e<M00<005<M
Dad00`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad010000e<M00<005<M
Dad00`000e<M00@005<M0000009C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M
00<000=C7@03001C7E<M00@000=C7@03001?7TlN00<00003Bgl000000?moo`aoo`03001oogoo00Qo
o`03001oogoo009oo`00h7oo00<007ooOol0[Woo00<007ooOol01Goo00<004lNCah00P0015/L0`00
0e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00<005<MDad01000
0e<M00<005<MDad00`000e<M00@005<M0000009C7@03001C7E<M00@0009C7@03001C7E<M00@000=C
7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00<000AC
7@<0009C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M
00@000=B^`03001[_0000?moo`eoo`03001oogoo00Qoo`03001oogoo005oo`00hGoo00<007ooOol0
[Goo00<007ooOol01Woo0P000T[n00@005/L0000009K7003001C7E<M00@000=C7@03001C7E<M00<0
00=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00<0
00AC7@<000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C
7E<M00@000=C7@03001C7E<M00<000=C7@04001C7@000002Dad00`00DaeC7@030003Dad00`00DaeC
7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040002DYX01`00D[]B^e:k001[_0000?moo`io
o`03001oogoo00Qoo`03001oogoo005oo`00hWoo00<007ooOol0[7oo00<007ooOol01goo00<004[n
B_h00`000e/L0`000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad010000U<M
00<005<MDad010000e<M00<005<MDad00`000e<M00@005<M0000009C7@03001C7E<M00@0009C7@03
001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03
001C7E<M00<000AC7@<0009C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@0
009B^`03001BVU:J009BVP05001B^`00Jk`0003oOol@Ool00`00Oomoo`07Ool00`00Oomoo`01Ool0
0>=oo`03001oogoo0:]oo`03001oogoo00Qoo`8000=6oP03001K7000009Nn`03001C7E<M00@000=C
7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C
7@03001C7E<M00<0009C7@@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M
00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@04001C7@000002Dad00`00DaeC7@03
0003Dad00`00DaeC7@040003Dad00`00DaeC7@030002D[/00`00D[]B^`02D[/00`00DYYBVP030000
0f^l001oo`3oOolAOol00`00Oomoo`06Ool00`00Oomoo`01Ool00>Aoo`800:]oo`03001oogoo00Uo
o`030016oTKn00<000ANn`8000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M
00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@0009C7@<000=C7@03001C7E<M00@0009C7@03
001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03
001C7E<M00@0009C7@@0009C7@03001C7E<M00@000=C7@03001C7E<M00@00003D[/005:k00=B^`03
001B^e:k00@0009CO`800?mooa=oo`03001oogoo00Ioo`03001oogoo005oo`00iWoo00<007ooOol0
Z7oo00<007ooOol02Woo0P000TJm00L005kkG_]Nn`00Hc`00002Dad40003D]`00`00DaeC7@040002
Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00Dad00002Dad0
0`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad0
0`00DaeC7@040002Dad00`00DaeC7@040003Dad30003Dad00`00DaeC7@030003Dad00`00DaeC7@04
0002D[/01@00D[]B^e:k00000U:k10000T=O1000ogoo5Woo00<007ooOol01Goo00<007ooOol00Goo
003WOol00`00Oomoo`2WOol00`00Oomoo`0;Ool01`00A[e6_DJm001Nn`0000=S?080009Bg003001B
g5;L009Bg0<000=C7@03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03
001C7E<M00<000=C7@<000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@03001C7E<M00@0
009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@04001C7@000002Dad00`00DaeC7@040002
Dad00`00DaeC7@040002D[/00`00D[]B^`02D[/00`00D[/000030002Bgl4003oOolKOol00`00Oomo
o`04Ool00`00Oomoo`01Ool00>Qoo`03001oogoo0:Ioo`03001oogoo00aoo`D000=S?003001Cg000
00=Bg004001Bg0000002Fa`00`00DaeC7@040002D_d00`00DaeC7@040003Dad00`00DaeC7@030003
Dad00`00DaeC7@040003Dad00`00Dad00002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad0
0`00DaeC7@040003Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@030004Dad3
0002Dad00`00DaeC7@040002D[/00`00D[]B^`02D[/00`00D[]B^`030002Cgl4003oOolPOol00`00
Oomoo`03Ool00`00Oomoo`01Ool00>Uoo`800:Ioo`03001oogoo00eoo`06000o?clo?cl006<l1@00
0U;L0P0015/L0`000e<M00<005;mD_d00`000e<M00<005<MDad010000e<M00<005<MDad00`000e<M
00<005<MDad010000U<M0`000e<M00<005<MDad010000U<M00<005<MDad010000e<M00<005<MDad0
10000U<M00<005<MDad010000e<M00<005<MDad00`000e<M00@005<M0000009C7@03001C7E<M00<0
009B^`03001B^e:k009B^`03001B^e:k00@0009?O`<00?moobAoo`03001oogoo00Aoo`40005oo`5o
o`00jgoo00<007ooOol0Xgoo00<007ooOol03Woo1@0017oo0`000TmO00@005/L0000009?gP03001C
7E<M00@0009Fo003001C7E<M00@000=C7@03001C7E<M00@0009C7@03001C7E<M00@000=C7@<0009C
7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C
7@03001C7E<M00@0009C7@03001C7E<M00@0009C7@@00003D[/005:k00=B^`03001B^e:k00@0009?
O`@00?moobQoo`03001oogoo00=oo`40005oo`5oo`00k7oo00<007ooOol0XWoo00<007ooOol06Woo
2`000TlN00@005KlE_aFo0<000=C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@04001C7@00
0002Dad00`00DaeC7@030003Dad00`00DaeC7@040002Dad00`00DaeC7@040003Dad00`00DaeC7@04
0002Dad00`00DaeC7@040003Dad00`00DaeC7@030003Dad30002D[/01@00D[]B^e:k00000U:k1000
0Tmo1000ogoo;Goo00<007ooOol00Woo0@000Goo0Goo003]Ool00`00Oomoo`2QOol00`00Oomoo`0T
Ool01`00Cai?7TlN001Fo00000=Jn`03001C7E<M00<000=C7@03001C7E<M00@0009C7@03001C7E<M
00@0009C7@@0009C7@03001C7E<M00@000=C7@03001C7E<M00<000=C7@03001C7E<M00@000=C7@03
001C7E<M00<000=C7@03001C7E<M00@0009C7@06001C7@00001B^`0015:k00<005:kD[/00`000Tmo
1000ogoo<Woo00D007ooOomoo`00009oo`00kWoo0P00XGoo00<007ooOol09Goo1@0015[k0`000U<M
00<005<MDad010000e<M00<005<MDad00`000e<M0`000e;m00<005<MDad00`000e<M00<005<MDad0
10000U<M00<005<MDad010000e<M00<005<MDad010000U;m00<005<MDad010000e<M00<005<MDad0
0P0015:k00<005:kD[/010000Tmo0`00ogoo=Woo00D007ooOomoo`00009oo`00l7oo00<007ooOol0
WWoo00<007ooOol09Goo00<004ZlB[`00TZl00@005[k0000009S?003001C7E<M00<000=Bg003001C
7E<M00@0009C7@06001C7@00001Bg00015;m0`000U<M00<005<MDad010000e<M00<005<MDad00`00
0e<M00<005<MDad010000U;L00<005;mD_d010000e<M00<005<MDad010000U:k00<005:kD[/01000
0Tmo1000ogoo>Woo00@007ooOol0009oo`00lGoo00<007ooOol0WGoo00<007ooOol09Woo00<004Zl
B[`00`0016<l0`000U;L00<005;LD]`010000e<M00<005<MDad00P0015;L00@005;m0000009G?P03
001C7E<M00<000=Bg003001C7E<M00@0009C7@03001C7E<M00@000=Bg003001Bg5;L00<000=G?P03
001C7E<M00@0009BVP04001B^e:kD[/30002Cgl4003oOoloOol00`00Ool00002Ool00?9oo`03001o
ogoo09aoo`03001oogoo02Moo`8000=7?`06001S?000001?g0000e;L0`000elL00<005<MDad01000
0U:k00<005;LD]`010000ULn100000=Bg000D]`00e;L0`000e<M00<005<MDad00`000U;K00<005;L
D]`00U;L0`000UMN00<005LnEch010000U:k00<005:JDYX00U:J00@005:k001?O`@00?mood=oo`04
001oogoo0001Ool00?=oo`8009aoo`03001oogoo02Uoo`X00005D]`004mOCel00002Ga`40002D[/0
1000D[]B^e:k0`000UMN10000T^O00H005;LD]aBg000D]`20002Fcd00`00DaeC7@0400000e:J001B
f`03D]/01000D]`000000U=O00<005MNEeh00`000T]o00<005:kD[/00U:k00<005:JDYX01@00ogoo
B7oo00<007oo00000Goo003eOol00`00Oomoo`2IOol00`00Oomoo`0bOol30002Cel60004D[/00`00
D[/00002Fed30003Ool50002D]`20004Fcd30002D[/01@00DYYBVU:J00000U;K10000U=O10000goo
10000U:k100000=GO`00Ool0ogooBgoo0P000Goo003fOol00`00Oomoo`2HOol00`00Oomoo`0eOol2
0005Ool20002D[/400000e]M001oo`09Ool30002Del01P00Fcd00000Ckh000AB^`03001BVU:J00<0
009CO`@000Yoo`<00093O`<00?moodaoo`<0005oo`00mgoo00<007ooOol0Ugoo00<007ooOol0?Woo
0P000TMO0`003Woo2@000U:k10000U]n0`004Goo0P00ogooBgoo100017oo003hOol2002GOol00`00
Oomoo`10Ool2000IOol30003@gl00`00Fgh0003oOomMOol40008Ool00?Yoo`03001oogoo09Aoo`03
001oogoo05ioo`D00?mooe]oo`<000aoo`00ngoo00<007ooOol0Tgoo00<007ooOol0ogoo^Woo1000
3goo003lOol00`00Oomoo`2BOol00`00Oomoo`3oOonfOol4000COol00?eoo`80099oo`03001oogoo
0?mook9oo`@001Moo`00ogoo00<007ooOol0Sgoo00<007ooOol0ogoo[Woo10006goo003oOol1Ool0
0`00Oomoo`2=Ool00`00Oomoo`3oOon/Ool3000OOol00?moo`9oo`03001oogoo08aoo`03001oogoo
0?moojQoo`@0029oo`00ogoo0goo0P00S7oo00<007ooOol0ogooY7oo10009Woo003oOol5Ool00`00
Oomoo`29Ool00`00Oomoo`3oOonPOol4000ZOol00?moo`Ioo`03001oogoo08Qoo`03001oogoo0?mo
oiaoo`@002ioo`00ogoo1goo00<007ooOol0Qgoo00<007ooOol0ogooVGoo0`00<Woo003oOol8Ool0
0`00Oomoo`26Ool00`00Oomoo`3oOonEOol4000eOol00?moo`Uoo`8008Ioo`03001oogoo0?mooi5o
o`@003Uoo`00ogoo2goo00<007ooOol0Pgoo00<007ooOol0ogooSGoo1000?Goo003oOol<Ool00`00
Oomoo`22Ool00`00Oomoo`3oOon9Ool40011Ool00?moo`eoo`03001oogoo085oo`03001oogoo0?mo
ohEoo`@004Eoo`00ogoo3Woo0P00PGoo00<007ooOol0ogooPWoo0`00BGoo003oOol@Ool00`00Oomo
o`1nOol00`00Oomoo`3oOomnOol4001<Ool00?mooa5oo`03001oogoo07eoo`03001oogoo0?moogYo
o`@0051oo`00ogoo4Woo00<007ooOol0O7oo00<007ooOol0ogooMWoo1000E7oo003oOolCOol2001l
Ool00`00Oomoo`3oOombOol4001HOol00?mooaEoo`03001oogoo07Uoo`03001oogoo0?moofmoo`<0
05aoo`00ogoo5Woo00<007ooOol0N7oo00<007ooOol0ogooJgoo1000Ggoo003oOolGOol00`00Oomo
o`1gOol00`00Oomoo`3oOomWOol4001SOol00?mooaQoo`8007Moo`03001oogoo0?moof=oo`@006Mo
o`00ogoo6Woo00<007ooOol0M7oo00<007ooOol0ogooGgoo1000Jgoo003oOolKOol00`00Oomoo`1c
Ool00`00Oomoo`3oOomLOol3001_Ool00?mooaaoo`03001oogoo079oo`03001oogoo0?mooeQoo`@0
079oo`00ogoo7Goo0P00LWoo00<007ooOol0ogooE7oo1000MWoo003oOolOOol00`00Oomoo`1_Ool0
0`00Oomoo`3oOom@Ool4001jOol00?moob1oo`03001oogoo06ioo`03001oogoo0?moodaoo`@007io
o`00ogoo8Goo00<007ooOol0KGoo00<007ooOol0ogooBGoo0`00PWoo003oOolROol2001]Ool00`00
Oomoo`3oOom5Ool40025Ool00?moobAoo`03001oogoo06Yoo`03001oogoo0?mood5oo`@008Uoo`00
ogoo9Goo00<007ooOol0JGoo00<007ooOol0ogoo?Goo1000SGoo003oOolVOol00`00Oomoo`1XOol0
0`00Oomoo`3oOoliOol4002AOol00?moobMoo`8006Qoo`03001oogoo0?moocEoo`@009Eoo`00ogoo
:Goo00<007ooOol0IGoo00<007ooOol0ogoo<Woo0`00VGoo003oOolZOol00`00Oomoo`1SOol00`00
Oomoo`3oOol_Ool4002LOol00?moob]oo`03001oogoo069oo`03001oogoo0?moob]oo`@00:1oo`00
ogoo;7oo0P00HWoo00<007ooOol0ogoo9goo1000Y7oo003oOol^Ool00`00Oomoo`1OOol00`00Oomo
o`3oOolSOol4002XOol00?moobmoo`03001oogoo05ioo`03001oogoo0?moob1oo`<00:aoo`00ogoo
<7oo00<007ooOol0GGoo00<007ooOol0ogoo77oo1000[goo003oOolaOol00`00Oomoo`1LOol00`00
Oomoo`3oOolHOol4002cOol00?mooc9oo`8005aoo`03001oogoo0?mooaAoo`@00;Moo`00ogoo=7oo
00<007ooOol0FGoo00<007ooOol0ogoo47oo1000^goo003oOoleOol00`00Oomoo`1HOol00`00Oomo
o`3oOol=Ool3002oOol00?moocIoo`03001oogoo05Moo`03001oogoo0?moo`Uoo`@00<9oo`00ogoo
=goo0P00Egoo00<007ooOol0ogoo1Goo1000aWoo003oOoliOol00`00Oomoo`1DOol00`00Oomoo`3o
Ool1Ool4003:Ool00?moocYoo`03001oogoo05=oo`03001oogoo0?aoo`@00<ioo`00ogoo>goo00<0
07ooOol0DWoo00<007ooOol0n7oo1000dWoo003oOollOol2001BOol00`00Oomoo`3eOol3003FOol0
0?moocioo`03001oogoo04moo`03001oogoo0?5oo`@00=Uoo`00ogoo?goo00<007ooOol0CWoo00<0
07ooOol0kGoo1000gGoo003oOom0Ool00`00Oomoo`1=Ool00`00Oomoo`3YOol4003QOol00?mood5o
o`8004eoo`03001oogoo0>Eoo`@00>Eoo`00ogoo@goo00<007ooOol0BWoo00<007ooOol0hWoo0`00
jGoo003oOom4Ool00`00Oomoo`19Ool00`00Oomoo`3NOol4003/Ool00?moodEoo`03001oogoo04Qo
o`03001oogoo0=Yoo`@00?1oo`00ogooAWoo0P00B7oo00<007ooOol0eWoo1000m7oo003oOom8Ool0
0`00Oomoo`15Ool00`00Oomoo`3BOol4003hOol00?moodUoo`03001oogoo04Aoo`03001oogoo0<mo
o`<00?aoo`00ogooBWoo00<007ooOol0@goo00<007ooOol0bgoo1000ogoo003oOom;Ool20013Ool0
0`00Oomoo`37Ool4003oOol4Ool00?moodeoo`03001oogoo041oo`03001oogoo0<=oo`@00?moo`Qo
o`00ogooCWoo00<007ooOol0?goo00<007ooOol0_goo1000ogoo37oo003oOom?Ool00`00Oomoo`0n
Ool00`00Oomoo`2kOol4003oOol@Ool00?mooe1oo`8003ioo`03001oogoo0;Qoo`<00?mooaAoo`00
ogooDWoo00<007ooOol0>goo00<007ooOol0]7oo1000ogoo5goo003oOomCOol00`00Oomoo`0iOol0
0`00Oomoo`2aOol4003oOolKOol00?mooeAoo`03001oogoo03Qoo`03001oogoo0:eoo`@00?mooamo
o`00ogooEGoo00<007ooOol0=goo00<007ooOol0ZGoo1000ogoo8goo003oOomFOol2000gOol00`00
Oomoo`2VOol3003oOolWOol00?mooeQoo`03001oogoo03Aoo`03001oogoo0:9oo`@00?moobYoo`00
ogooFGoo00<007ooOol0<goo00<007ooOol0WWoo1000ogoo;Woo003oOomJOol00`00Oomoo`0bOol0
0`00Oomoo`2JOol4003oOolbOol00?mooe]oo`80039oo`03001oogoo09Ioo`@00?moocIoo`00ogoo
GGoo00<007ooOol0;goo00<007ooOol0Tgoo0`00ogoo>Woo003oOomNOol00`00Oomoo`0^Ool00`00
Oomoo`2?Ool4003oOolmOol00?mooemoo`03001oogoo02eoo`03001oogoo08]oo`@00?mood5oo`00
ogooH7oo0P00;Goo00<007ooOol0Qgoo1000ogooAGoo003oOomROol00`00Oomoo`0ZOol00`00Oomo
o`23Ool4003oOom9Ool00?moof=oo`03001oogoo02Uoo`03001oogoo07moo`@00?moodeoo`00ogoo
I7oo00<007ooOol0:7oo00<007ooOol0O7oo0`00ogooDGoo003oOomUOol2000XOol00`00Oomoo`1h
Ool4003oOomDOol00?moofMoo`03001oogoo02Eoo`03001oogoo07Aoo`@00?mooeQoo`00ogooJ7oo
00<007ooOol097oo00<007ooOol0L7oo1000ogooG7oo003oOomYOol00`00Oomoo`0SOol00`00Oomo
o`1/Ool4003oOomPOol00?moofYoo`8002=oo`03001oogoo06Uoo`<00?moofAoo`00ogooK7oo00<0
07ooOol087oo00<007ooOol0IGoo1000ogooIgoo003oOom]Ool00`00Oomoo`0OOol00`00Oomoo`1Q
Ool4003oOom[Ool00?moofioo`03001oogoo01ioo`03001oogoo05eoo`@00?moofmoo`00ogooKgoo
0P007Woo00<007ooOol0FGoo1000ogooLgoo003oOomaOol00`00Oomoo`0KOol00`00Oomoo`1FOol3
003oOomgOol00?moog9oo`03001oogoo01Yoo`03001oogoo059oo`@00?moogYoo`00ogooLgoo00<0
07ooOol06Goo00<007ooOol0CWoo1000ogooOWoo003oOomdOol2000IOol00`00Oomoo`1:Ool4003o
Oon2Ool00?moogIoo`03001oogoo01Ioo`03001oogoo04Ioo`@00?moohIoo`00ogooMgoo00<007oo
Ool05Goo00<007ooOol0@goo0`00ogooRWoo003oOomhOol00`00Oomoo`0DOol00`00Oomoo`0oOol4
003oOon=Ool00?moogUoo`8001Aoo`03001oogoo03]oo`@00?mooi5oo`00ogooNgoo00<007ooOol0
4Goo00<007ooOol0=goo1000ogooUGoo003oOomlOol00`00Oomoo`0?Ool00`00Oomoo`0dOol4003o
OonIOol00?moogeoo`03001oogoo00ioo`03001oogoo031oo`@00?mooieoo`00ogooOWoo00<007oo
Ool03Goo00<007ooOol0;Goo0`00ogooXGoo003oOomoOol2000=Ool00`00Oomoo`0YOol4003oOonT
Ool00?mooh5oo`03001oogoo00Yoo`03001oogoo02Eoo`@00?moojQoo`00ogooPWoo00<007ooOol0
2Goo00<007ooOol08Goo1000ogoo[7oo003oOon3Ool00`00Oomoo`08Ool00`00Oomoo`0MOol4003o
Oon`Ool00?moohAoo`8000Qoo`03001oogoo01Yoo`<00?mookAoo`00ogooQWoo00<007ooOol01Goo
00<007ooOol05Woo1000ogoo]goo003oOon7Ool00`00Oomoo`04Ool00`00Oomoo`0BOol4003oOonk
Ool00?moohQoo`03001oogoo00=oo`03001oogoo00ioo`@00?mookmoo`00ogooRGoo0P000goo00<0
07ooOol02Woo1000ogoo`goo003oOon;Ool01000Oomoo`002Goo0`00ogooagoo003oOon<Ool00`00
Ool00005Ool4003oOoo:Ool00?mooheoo`800003Ool0000000800?moolioo`00ogooSWoo0P00ogoo
dWoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol0
0?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogoo
ogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOooo
OomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=o
o`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003o
OoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomo
oomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogoo
Hgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol0
0?mooomooomoof=oo`00ogooogooogooHgoo0000\
\>"], "Graphics",
  CellLabel->"From In[51]:=",
  Evaluatable->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
Control plot of interpolated vector potential.

restless Laplace...\
\>", "Text",
  PageBreakAbove->Automatic],

Cell["\<\
Timing[Do[{u=m;If[Mod[i,100]==0,
{err=Max[Abs[Flatten[u-m]]];
Print[i,\" residual error: \",err];
If[err<10^-6,Break[]]}]},{i,1,7000}]]\
\>", "Input",
  CellLabel->"In[54]:=",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}},
  Background->GrayLevel[0.849989]],

Cell[CellGroupData[{

Cell["\<\
ListPlot3D[u,ViewPoint->{1.300, -2.400, 2.000},
ImageSize->400,PlotRange->All]\
\>", "Input",
  CellLabel->"In[55]:=",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}},
  Background->GrayLevel[0.849989]],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000B`0003cA000`40O003h00Oogooogooogooogoo
]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOooo
OoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOond
Ool00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomo
oomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAo
o`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogoo
ogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo
003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOooo
OoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol0
0?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomo
oomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00
ogooogooogooEgoo0P00ogooFgoo003oOoooOoooOomDOol300000goo001oo`3oOomJOol00?mooomo
oomooe9oo`8000Aoo`800?mooeYoo`00ogooogooogooCgoo0`001Woo00<007oo0000ogooFGoo003o
OoooOoooOom=Ool20009Ool00`00Ool0003oOomIOol00?mooomooomoodYoo`<000]oo`04001oogoo
003oOomHOol00?mooomooomoodMoo`<000eoo`8000=oo`03001oogoo0?mooeEoo`00ogooogooogoo
AGoo0P003Woo0P0000=Fo@00Ool00Woo00<007ooOol0ogooEGoo003oOoooOoooOom2Ool3000>Ool2
0003E_d20003Ool00`00Oomoo`3oOomDOol00?mooomooomood1oo`8000moo`8000IFo@8000=oo`03
001oogoo0?mooe=oo`00ogooogooogoo?Goo0`003Woo0`0000=Fo@00E_d01EKm0P000goo00<007oo
Ool0ogooDgoo003oOoooOoooOolkOol2000>Ool30005E_d00`00E_eFo@03E_d30003Ool00`00Oomo
o`3oOomBOol00?mooomooomoocQoo`<000eoo`<00003E_d005Km00IFo@03001FoEKm00<00003E_d0
07oo00=oo`03001oogoo0?mooe5oo`00ogooogooogoo=Woo0P003Woo0P001EKm00<005KmE_d015Km
0`000UKm00@005KmE_d000=oo`03001oogoo0?mooe5oo`00ogooogooogoo<goo0`003Woo0P0025Km
00@005KmE_eFo@800003E_d005Km009Fo@05001FoEKmE_d00003Ool00`00Oomoo`3oOom@Ool00?mo
oomooomooc1oo`<000ioo`<00003E_d005Km00MFo@04001Fo@000004E_d01000E_eFo@000eKm0P00
0Woo00<007ooOol0ogooD7oo003oOoooOoooOol^Ool2000>Ool30005E_d00`00E_eFo@04E_d30007
E_d01000E_d005Km0P0000=Fo@00Ool00Woo00<007ooOol0ogooCgoo003oOoooOoooOol[Ool3000=
Ool300000eKm001Fo@06E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d01000E_d0000015Km00D0
07ooOomoo`000?mooe1oo`00ogooogooogoo:Goo0P003Goo0`001EKm00<005KmE_d015Km0`001UKm
00<005KmE_d015Km0`001UKm00@007ooOol00?mooe1oo`00ogooogooogoo9Woo0`0037oo0`0000=F
o@00E_d01UKm00@005KmE_eFo@800003E_d005Km00MFo@03001FoEKm00<00003E_d0000000IFo@05
001oogooOol0003oOom?Ool00?mooomooomoobAoo`8000eoo`8000EFo@03001FoEKm00AFo@04001F
o@000004E_d00`00E_eFo@05E_d30005E_d00`00E_eFo@04E_d20003Ool00`00Oomoo`3oOom<Ool0
0?mooomooomoob5oo`<000eoo`8000QFo@03001FoEKm00=Fo@8000MFo@04001FoEKmE_d300000eKm
001Fo@05E_d20002E_d300000eKm001oo`02Ool00`00Oomoo`3oOom<Ool00?mooomooomooamoo`80
00eoo`<0009Fo@03001FoEKm00EFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000005E_d0
0`00E_eFo@03E_d40005E_d01@00Oomoogoo0000ogooCGoo003oOoooOoooOolLOol3000<Ool30006
E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20008E_d01000E_eFoEKm0P0000=Fo@00E_d0
1UKm00D007ooOomoo`000?moodaoo`00ogooogooogoo6Goo0`003Goo0P0000=Fo@00E_d01eKm00<0
05KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01eKm00H005Km000005Km0002
E_d00`00E_eFo@04E_d20002Ool00`00Oomoo`3oOom:Ool00?mooomooomooaMoo`<000eoo`8000AF
o@03001FoEKm00EFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000=Fo@05001F
oEKmE_d00003E_d200000eKm001oo`02Ool00`00Oomoo`3oOom9Ool00?mooomooomooaAoo`<000=o
o`03001oogoo00Qoo`8000MFo@04001FoEKmE_d300000eKm001Fo@06E_d00`00E_eFo@0300000eKm
001Fo@06E_d00`00E_eFo@030002E_d01@00E_eFoEKm00000eKm00@005Km000000AFo@05001oogoo
Ool0003oOom:Ool00?mooomooomooa9oo`8000Moo`03001oogoo00Aoo`<00003E_d005Km00IFo@04
001Fo@000005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30006E_d01@00E_eFoEKm0000
0UKm0P001eKm00@007ooOol00?moodYoo`00ogooogooogoo3goo0`002Woo00<007ooOol00`001EKm
00<005KmE_d015Km0P0025Km00@005KmE_eFo@800003E_d005Km00IFo@04001FoEKmE_d200000eKm
001Fo@07E_d00`00E_eFo@0300000eKm001Fo@06E_d01@00Oomoogoo0000ogooBGoo003oOoooOooo
Ool=Ool2000=Ool300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@07E_d01000E_d00000
15Km00<005KmE_d015Km00@005Km000000AFo@03001FoEKm00EFo@@000AFo@03001FoEKm00AFo@80
00=oo`03001oogoo0?moodIoo`00ogooogooogoo2Woo0`003Goo0P001EKm00<005KmE_d015Km0`00
1EKm00<005KmE_d015Km0`001eKm00<005KmE_d00eKm0P001eKm00@005KmE_eFo@<00004E_d005Km
0005E_d00`00E_eFo@0300000eKm001oo`02Ool00`00Oomoo`3oOom6Ool00?mooomooomoo`Qoo`80
00ioo`8000QFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@030002E_d00`00E_eFo@05
E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d000001EKm0P001EKm0`001EKm00D007ooOomo
o`000?moodMoo`00ogooogooogoo1Goo0`003Goo0`000UKm00<005KmE_d01EKm00@005Km000000AF
o@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000QFo@04001F
oEKmE_d200000eKm001Fo@06E_d01@00Oomoogoo0000ogooAWoo003oOoooOoooOol2Ool3000=Ool3
0006E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01eKm00<005KmE_d00`00
00=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01eKm00@005Km000000AFo@03001FoEKm00AF
o@80009oo`03001oogoo0?moodAoo`00ogooogooogoo0P003Woo0P0000=Fo@00E_d01eKm00<005Km
E_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00EFo@<000EFo@03001FoEKm00AF
o@<000EFo@03001FoEKm00AFo@<000MFo@04001FoEKmE_d200000eKm001oo`02Ool00`00Oomoo`3o
Oom3Ool00?mooomoooaoo`<000ioo`8000AFo@03001FoEKm00EFo@<000EFo@03001FoEKm00AFo@80
00MFo@04001FoEKmE_d300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eF
o@0300000eKm00000007E_d01000E_d0000015Km00@007ooOol00?moodEoo`00ogooogoonWoo0P00
3goo0P001eKm00@005KmE_eFo@<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@04
001Fo@000005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30004E_d00`00E_d00006E_d2
0007E_d01000Oomoo`00ogooA7oo003oOoooOoogOol3000>Ool300000eKm001Fo@06E_d01000E_d0
00001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P0025Km00@005KmE_eFo@800003E_d0
05Km00IFo@03001FoEKm00<00003E_d005Km00AFo@04001FoEKm0002E_d300000eKm001Fo@06E_d0
1@00Oomoogoo0000ogoo@goo003oOoooOooeOol2000>Ool30005E_d00`00E_eFo@04E_d20008E_d0
1000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01eKm00@005Km000000AF
o@03001FoEKm00AFo@<000EFo@03001FoEKm009Fo@03001FoEKm00<000EFo@03001FoEKm00AFo@80
009oo`03001oogoo0?mood5oo`00ogooogooJWoo2P002goo10003Woo1000GGoo0`003Goo0`0000=F
o@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01eKm00@005Km000000AFo@03001FoEKm00AFo@<0
00EFo@03001FoEKm00AFo@<000MFo@04001FoEKmE_d200000eKm001Fo@06E_d01000E_eFoEKm0`00
00=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00Ool00Woo00<007ooOol0ogoo@7oo003oOoooOomZ
Ool:0009Ool8000:Ool8001IOol2000=Ool30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04
E_d30007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`000UKm00<005KmE_d01EKm
00@005Km000000AFo@03001FoEKm00AFo@03001Fo@00008000AFo@03001FoEKm00AFo@<000EFo@05
001oogooOol0003oOom1Ool00?mooomoofioo`8000eoo`8000Aoo`8000Yoo`8000Aoo`8005Ioo`<0
00eoo`800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<0009Fo@03
001FoEKm00EFo@04001Fo@000004E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d20007E_d0
0`00E_eFo@03E_d20002E_d00`00E_eFo@02E_d01000E_eFoEKm0`0000=Fo@00E_d01UKm1000ogoo
@Goo003oOoooOom^Ool2000<Ool20006Ool20008Ool20006Ool2001BOol3000>Ool20004E_d00`00
E_eFo@04E_d30005E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm
0P0000=Fo@00E_d01eKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000EFo@00E_eF
o@0000AFo@04001Fo@000005E_d00`00E_eFo@04E_d20002Ool00`00Oomoo`3oOolnOol00?mooomo
ofioo`8000aoo`8000Ioo`8000Qoo`8000Ioo`80051oo`8000ioo`<000MFo@04001FoEKmE_d20000
0eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@07E_d00`00E_eFo@0300000eKm001Fo@06E_d0
1000E_d0000015Km00<005KmE_d01EKm0`001EKm00<005KmE_d015Km0`001EKm00<005Km000015Km
0P0025Km00@005KmE_eFo@800003E_d007oo009oo`03001oogoo0?mooceoo`00ogooogooKWoo0P00
2goo0P0027oo0P001Woo0P0027oo0P00C7oo0`003Goo0`000UKm00<005KmE_d01EKm00@005Km0000
00AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@@000EFo@03001FoEKm00AFo@8000MFo@04
001FoEKmE_d300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_d000030000
0eKm001Fo@07E_d01000E_d0000015Km00@007ooOol00?moocmoo`00ogooogooKWoo0P002goo0P00
27oo0P001Woo0P0027oo0P00BWoo0P003Goo0`001UKm00<005KmE_d015Km0P001eKm00@005KmE_eF
o@800003E_d005Km00IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<00003E_d0
05Km00IFo@04001Fo@000005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00
E_eFo@04E_d30007E_d01000Oomoo`00ogoo?Woo003oOoooOom^Ool2000;Ool20008Ool20006Ool2
0008Ool20017Ool3000=Ool200000eKm001Fo@07E_d00`00E_eFo@0300000eKm001Fo@06E_d01000
E_d0000015Km00<005KmE_d015Km0`001UKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P00
25Km00@005KmE_eFo@800003E_d005Km00IFo@03001FoEKm00<00003E_d0000000IFo@03001FoEKm
00<0009Fo@03001FoEKm00EFo@05001oogooOol0003oOolmOol00?mooomoofioo`8000]oo`8000Qo
o`8000Ioo`8000Qoo`8004Eoo`8000ioo`8000AFo@03001FoEKm00EFo@<000EFo@03001FoEKm00AF
o@8000MFo@04001FoEKmE_d200000eKm001Fo@07E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00
E_eFo@0300000eKm001Fo@07E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d0
15Km0`001UKm00<005KmE_d015Km0P000Woo00<007ooOol0ogoo>goo003oOoooOom^Ool2000;Ool2
0008Ool20006Ool20008Ool20012Ool3000>Ool20007E_d01000E_eFoEKm0`0000=Fo@00E_d01UKm
00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00EFo@<000EFo@03001F
oEKm00AFo@<000EFo@03001FoEKm00AFo@<000MFo@04001FoEKmE_d200000eKm001Fo@05E_d20002
E_d300000eKm001Fo@07E_d00`00E_eFo@0300000eKm001oo`02Ool00`00Oomoo`3oOoljOol00?mo
oomoofioo`8000]oo`8000Qoo`8000Ioo`8000Qoo`80041oo`<000eoo`<00003E_d005Km00IFo@04
001Fo@000005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d00`00E_eFo@02E_d2
00000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@030002E_d00`00E_eF
o@05E_d01000E_d0000015Km00<005KmE_d00eKm10001EKm00<005KmE_d015Km10001EKm00D007oo
Oomoo`000?mooc]oo`00ogooogooKWoo0P002goo0P0027oo0P001Woo0P0027oo0P00?Goo0`000Woo
00<007ooOol027oo0`001EKm00<005KmE_d015Km0P0025Km00@005KmE_eFo@800003E_d005Km00IF
o@03001FoEKm00<00003E_d005Km00MFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00
E_eFo@04E_d30006E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<0
05KmE_d00`000UKm00<005KmE_d01EKm00@007ooOol00?mooc]oo`00ogooogooKWoo0P002goo0P00
27oo0P001Woo0P0027oo0P00>Woo0`001Woo00<007ooOol017oo0`0000=Fo@00E_d01UKm00<005Km
E_d00`000UKm00<005KmE_d01EKm00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm
00AFo@<000MFo@04001FoEKmE_d200000eKm001Fo@06E_d01000E_eFoEKm0P0000=Fo@00E_d01eKm
00<005KmE_d00`0000=Fo@00E_d01UKm00H005Km000005Km0002E_d00`00E_eFo@04E_d30006E_d0
0`00E_eFo@04E_d20002Ool00`00Oomoo`3oOolhOol00?mooomoofioo`8000aoo`8000Ioo`8000Qo
o`8000Ioo`8003Uoo`8000Yoo`03001oogoo00<000EFo@03001FoEKm00AFo@<000IFo@03001FoEKm
00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@030002E_d00`00E_eFo@05
E_d01000E_d0000015Km00<005KmE_d015Km00@005Km000000AFo@03001FoEKm00EFo@<000EFo@03
001FoEKm00AFo@8000=Fo@05001FoEKmE_d00003E_d200000eKm001Fo@07E_d00`00E_eFo@030000
0eKm001oo`02Ool00`00Oomoo`3oOolgOol00?mooomoofioo`8000aoo`8000Ioo`8000Qoo`8000Io
o`8003Ioo`<000eoo`800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00MFo@03001FoEKm
00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d2
0007E_d00`00E_eFo@03E_d20007E_d01000E_eFoEKm0`0000=Fo@00E_d01UKm00<005KmE_d00`00
00=Fo@00E_d00UKm00H005KmE_eFo@00E_d20004E_d00`00E_eFo@05E_d30005E_d01000Oomoo`00
ogoo>Goo003oOoooOomZOol300000goo0000000=Ool20004Ool2000:Ool20004Ool2000eOol2000>
Ool20004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d40005E_d00`00E_eFo@04E_d20007
E_d01000E_eFoEKm0P0000=Fo@00E_d01eKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d0
0`0000=Fo@00E_d01UKm00@005Km000000EFo@03001FoEKm00AFo@<000EFo@04001FoEKm0003E_d2
0007E_d01000E_eFoEKm0`0000=Fo@00E_d01UKm00@007ooOol00?moocQoo`00ogooogooJWoo1P00
3Goo20002Woo2000<Woo0`003Woo0P001eKm00@005KmE_eFo@800003E_d005Km00IFo@03001FoEKm
00<0009Fo@03001FoEKm00EFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00
E_eFo@05E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20008E_d01000E_eFoEKm
0P0000=Fo@00E_d01UKm00<005Km00000`0000=Fo@00E_d01UKm00@005Km000000EFo@03001FoEKm
00AFo@80009oo`03001oogoo0?moocEoo`00ogooogooKGoo0`003goo10003Woo1000<Woo0P003Woo
0`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<0
00EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d300000eKm001Fo@06E_d00`00E_eFo@030000
0eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@07E_d01000E_d0000015Km00<005KmE_d015Km
0`001EKm00<005KmE_d015Km0P001eKm00@005KmE_eFo@<00005E_d007ooOol0003oOolgOol00?mo
oomoolAoo`<000eoo`<000EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@07
E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d00000
1EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001eKm00@0
05KmE_eFo@800003E_d0000000IFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000005E_d0
1000Oomoo`00ogoo=Woo003oOoooOoo2Ool2000=Ool300000eKm001Fo@06E_d00`00E_eFo@030000
0eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d01EKm0`001EKm00<005KmE_d015Km0`001EKm
00<005KmE_d015Km0P0025Km00@005KmE_eFo@800003E_d005Km00IFo@03001FoEKm00<00003E_d0
05Km00IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@04001Fo@000004E_d00`00E_eFo@04E_d3
0005E_d00`00E_eFo@04E_d20008E_d00`00Ool0003oOolfOol00?mooomookmoo`<000aoo`<000EF
o@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@03001FoEKm009Fo@800003E_d005Km
00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00MFo@04001Fo@00
0004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@03E_d30006E_d2
0003E_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@07E_d01000Oomoo`00ogoo=Goo
003oOoooOonlOol3000=Ool200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00
E_eFo@0300000eKm001Fo@07E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d0
15Km0`001EKm00<005KmE_d015Km0`001eKm00@005KmE_eFo@800003E_d005Km00IFo@03001FoEKm
00<00003E_d005Km00IFo@03001FoEKm00<0009Fo@03001FoEKm00AFo@800003E_d0000000AFo@03
001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<0009oo`03001oogoo0?mooc9oo`00ogooogoo^Woo
0P003Woo0P0015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km
0`001eKm00@005KmE_eFo@800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001F
oEKm00<0009Fo@03001FoEKm00EFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eF
o@04E_d30006E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005Km
E_d00`000UKm00@007ooOol00?moocAoo`00ogooogoo]goo0`003Woo0P001eKm00@005KmE_eFo@80
0003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<0009Fo@03001FoEKm
00EFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30006E_d00`00E_eF
o@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01eKm
00<005KmE_d01@001eKm00@005Km000000AFo@03001FoEKm00AFo@<000IFo@04001oogoo003oOolc
Ool00?mooomookEoo`8000ioo`<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d3
0005E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00
E_d01UKm00<005KmE_d00`0000=Fo@00E_d01eKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km
000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@@000=Fo@03001Fo@0000IFo@8000MF
o@04001FoEKmE_d200000eKm001Fo@06E_d01@00Oomoogoo0000ogoo<Woo003oOoooOonbOol3000=
Ool30005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d0
0`000UKm00<005KmE_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001F
oEKm00AFo@<000EFo@03001FoEKm00AFo@@000EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d2
00000eKm001Fo@06E_d00`00E_eFo@030002E_d00`00E_eFo@02E_d01000E_eFo@000UKm0`0000=F
o@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@80009oo`03001oogoo0?mooc1oo`00ogoo
ogoo/7oo0P003Woo0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km0000
00AFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@04
001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d00`00E_eFo@03
00000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0`001UKm00D005KmE_eFo@00009F
o@<000EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001oo`02Ool00`00Oomoo`3o
Ool_Ool00?mooomoojeoo`<000ioo`8000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@80
00MFo@04001FoEKmE_d200000eKm001Fo@07E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eF
o@0300000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0`001UKm00<005KmE_d015Km
0`001EKm00<005KmE_d015Km0P001eKm00@005KmE_eFo@800003E_d005Km00MFo@03001FoEKm00<0
0003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d01@00Oomoogoo
0000ogoo<7oo003oOoooOon[Ool2000>Ool30007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<0
05KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00EFo@<000EFo@03001FoEKm
00AFo@<000EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@07E_d00`00E_eF
o@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km00<005Km
E_d01EKm100015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm00@007ooOol00?mo
oc1oo`00ogooogooZ7oo0`003Goo0`000UKm00<005KmE_d01EKm00@005Km000000AFo@03001FoEKm
00AFo@<000EFo@03001FoEKm00AFo@8000MFo@03001FoEKm009Fo@800003E_d005Km00IFo@03001F
oEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00
E_eFo@05E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm
0`0000AFo@00E_d000EFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km
00IFo@05001oogooOol0003oOol_Ool00?mooomoojEoo`<000eoo`<000IFo@03001FoEKm00AFo@80
00MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@07E_d01000E_d0
000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm
00<005KmE_d00UKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d0
0`0000=Fo@00E_d01UKm00@005Km000000EFo@8000EFo@<000EFo@03001FoEKm00AFo@<000EFo@03
001FoEKm00AFo@8000=oo`03001oogoo0?moobaoo`00ogooogooXgoo0P003Goo0`000UKm00<005Km
E_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000EF
o@03001FoEKm00AFo@<000MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm
001Fo@06E_d00`00E_eFo@0300000eKm001Fo@07E_d01000E_d0000015Km00<005KmE_d015Km0`00
1EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm0P000UKm0`0000=Fo@00E_d01UKm
00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00Ool00Woo00<007ooOol0ogoo
;7oo003oOoooOonPOol3000<Ool30006E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007
E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`000UKm00<005KmE_d01EKm00@005Km
000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000MF
o@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@03
00000eKm001Fo@06E_d40005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d01@00
Oomoogoo0000ogoo;Goo003oOoooOonNOol2000=Ool200000eKm001Fo@07E_d00`00E_eFo@030000
0eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km
0`001UKm00<005KmE_d015Km0P001eKm00@005KmE_eFo@800003E_d005Km00IFo@03001FoEKm00<0
0003E_d005Km00IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@04001Fo@000004E_d00`00E_eF
o@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20008E_d01000E_eFoEKm0P00
00=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00D007ooOomoo`000?moobaoo`00ogoo
ogooVgoo100037oo0P0015Km00<005KmE_d01EKm0`001EKm00<005KmE_d015Km0`001EKm00<005Km
E_d015Km0P001eKm00@005KmE_eFo@800003E_d005Km00MFo@03001FoEKm00<00003E_d005Km00IF
o@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04
E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<0
05KmE_d00`0000=Fo@00E_d01eKm00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm
00AFo@80009oo`03001oogoo0?moobYoo`00ogooogooVGoo0P0017oo00<007ooOol01goo0P001eKm
00<005KmE_d00UKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d0
0`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00EFo@<000EFo@03001FoEKm00AFo@80
00MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@07E_d00`00E_eF
o@0300000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km
0`0015Km0P001UKm0`001eKm00@005KmE_eFo@800003E_d005Km00IFo@03001FoEKm00<00003E_d0
07oo009oo`03001oogoo0?moobUoo`00ogooogooUWoo0`001goo00<007ooOol00goo0`000UKm00<0
05KmE_d01EKm00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03
001FoEKm00AFo@8000MFo@03001FoEKm009Fo@800003E_d005Km00IFo@03001FoEKm00<00003E_d0
05Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d40005E_d00`00
E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d0
15Km00<005Km00000UKm0`000UKm00<005KmE_d01EKm00@005Km000000AFo@03001FoEKm00AFo@<0
00EFo@05001oogooOol0003oOolZOol00?mooomooiAoo`8000]oo`03001oo`00008000IFo@03001F
oEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06
E_d00`00E_eFo@030002E_d00`00E_eFo@05E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm
00<005KmE_d015Km0P001eKm00@005KmE_eFo@800003E_d005Km00IFo@03001FoEKm00<0009Fo@03
001FoEKm00EFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d3
0005E_d00`00E_eFo@02E_d00`00E_d000020006E_d00`00E_eFo@03E_d30007E_d01000E_eFoEKm
0P0000=Fo@00E_d01UKm00@007ooOol00?moobYoo`00ogooogooTGoo0`0037oo0`000UKm00<005Km
E_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000EF
o@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@8000MFo@03001FoEKm00<00003E_d005Km00IF
o@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30006E_d00`00
E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<0
05KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`000UKm00<005KmE_d01EKm00@005Km000000AF
o@03001FoEKm00AFo@80009oo`03001oogoo0?moobMoo`00ogooogooSWoo0`0037oo0`000eKm00@0
05KmE_d000IFo@<000EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d0
0`00E_eFo@0300000eKm001Fo@07E_d00`00E_eFo@0300000eKm001Fo@06E_d30005E_d00`00E_eF
o@04E_d30005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01eKm00<005Km
E_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001F
oEKm00AFo@<0009Fo@04001FoEKm0006E_d30006E_d00`00E_eFo@03E_d30007E_d01000E_eFoEKm
0P0000=Fo@00Ool00Woo00<007ooOol0ogoo9Woo003oOoooOon<Ool2000=Ool200000eKm001Fo@07
E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d00000
15Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km10001EKm00<005KmE_d00UKm0P0000=Fo@00
E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km
000000AFo@03001FoEKm00EFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MF
o@04001FoEKmE_d200000eKm001Fo@02E_d01@00E_eFoEKm00000UKm0`0000=Fo@00E_d01UKm00<0
05KmE_d00`000UKm00<005KmE_d01EKm00@005Km000000AFo@04001oogoo003oOolXOol00?mooomo
ohUoo`<000ioo`03001FoEKm009Fo@03001FoEKm00EFo@<000EFo@03001FoEKm00AFo@<000EFo@03
001FoEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@030002E_d00`00
E_eFo@05E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<0
05KmE_d015Km0P001eKm00@005KmE_eFo@<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km
00IFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d01000E_eFo@000eKm0`001EKm
00<005KmE_d015Km0`001UKm00<005KmE_d015Km0P001eKm00@007ooOol00?moobMoo`00ogooogoo
Qgoo0P003goo0P001UKm00<005KmE_d00UKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00
E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000IF
o@03001FoEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm
001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d000001EKm00<005KmE_d015Km0`00
1EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm00@005Km001Fo@800003E_d005Km
00IFo@03001FoEKm00<00003E_d005Km00MFo@03001FoEKm00<00003E_d005Km00IFo@04001oogoo
003oOolWOol00?mooomoohAoo`<000ioo`<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eF
o@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P00
0UKm00<005KmE_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm
00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d30000
0eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d0
1000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km10001EKm00<005KmE_d015Km
0P000Woo00<007ooOol0ogoo97oo003oOoooOon2Ool2000>Ool30005E_d00`00E_eFo@04E_d20007
E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d0
0`0000=Fo@00E_d01UKm00@005Km000000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@80
00MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eF
o@0300000eKm001Fo@06E_d01000E_d000001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km
0`001EKm00<005KmE_d015Km0`001UKm00@005KmE_eFo@800003E_d005Km00IFo@03001FoEKm00<0
009Fo@03001FoEKm00EFo@03001FoEKm00<00003E_d007oo009oo`03001oogoo0?moob=oo`00ogoo
ogooOgoo0`003Goo0`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km0000
00AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000QFo@03
001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d0
0`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20008E_d01000E_eF
oEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00
00001UKm00@005Km000000AFo@03001FoEKm00AFo@<000IFo@03001FoEKm00=Fo@@000EFo@03001o
ogoo00800?moobAoo`00ogooogooOGoo0P003Goo0`001EKm00<005KmE_d015Km0`001EKm00<005Km
E_d015Km0P001eKm00@005KmE_eFo@800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IF
o@03001FoEKm00<0009Fo@03001FoEKm00EFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm
00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d0
0`00E_eFo@0300000eKm001Fo@07E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<005Km
E_d015Km0`001EKm00<005KmE_d015Km0P001eKm00@005KmE_eFo@800003E_d005Km00IFo@03001F
oEKm00<0009Fo@03001FoEKm00EFo@800003Ool007oo0?moob=oo`00ogooogooNWoo0`003Goo0P00
00=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm
00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000IFo@03001FoEKm009F
o@800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km
00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eF
o@04E_d30007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01EKm
0P000UKm0`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000IFo@03001FoEKm
00=Fo@<0009oo`03001oogoo0?moob5oo`00ogooogooMgoo0`003Woo0P0015Km00<005KmE_d015Km
0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm00@005KmE_eFo@800003E_d0
05Km00IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@04001Fo@000004E_d00`00E_eFo@04E_d3
0005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00
E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`000UKm00<005KmE_d01EKm00@0
05Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00=Fo@@000EFo@03001FoEKm00AFo@80
00MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@030002E_d01000Oomoo`00ogoo8goo
003oOoooOomeOol2000?Ool20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`00
00=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AF
o@<000IFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@03
00000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d0
15Km0`001EKm00<005KmE_d015Km0`001UKm00<005KmE_d015Km0P001eKm00@005KmE_eFo@800003
E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@04
001Fo@000004E_d00`00E_eFo@04E_d30006E_d01000Oomoo`00ogoo8Woo003oOoooOombOol3000>
Ool300000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km
0`001EKm00<005KmE_d015Km0P001eKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d0
0`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<0
00EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@030000
0eKm001Fo@07E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km
0`000UKm00@005KmE_d000IFo@<000EFo@03001FoEKm00AFo@8000MFo@03001FoEKm00<00003E_d0
05Km00IFo@05001oogooOol0003oOolQOol00?mooomoog1oo`8000ioo`<000EFo@03001FoEKm00AF
o@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00
E_eFo@0300000eKm001Fo@06E_d30006E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007
E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d0
0`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@@0
00EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@02E_d01@00E_eFoEKm0000
0UKm0`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm0`001EKm00<005KmE_d015Km
0P000Woo00<007ooOol0ogoo7goo003oOoooOom]Ool3000=Ool300000eKm001Fo@06E_d00`00E_eF
o@0300000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km
0`001EKm00<005KmE_d00UKm0P0000=Fo@00E_d01eKm00<005KmE_d00`0000=Fo@00E_d01UKm00<0
05KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm
00AFo@<000EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eF
o@030002E_d00`00E_eFo@05E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km00@0
05KmE_d000=Fo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm009Fo@800003E_d005Km00IF
o@03001FoEKm00<00003E_d007oo009oo`03001oogoo0?mooaioo`00ogooogooJgoo0P003Goo0`00
1EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm00<005KmE_d00`0000=Fo@00E_d0
1UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00EFo@<000EFo@03
001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d0
0`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km
00<005KmE_d015Km0`001UKm00<005KmE_d00eKm10001EKm00<005KmE_d015Km0P001eKm00<005Km
00000`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001F
oEKm00AFo@<000EFo@05001oogooOol0003oOolOOol00?mooomoofQoo`<000eoo`800003E_d005Km
00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@<000EFo@03
001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@03001FoEKm009Fo@800003E_d005Km00IF
o@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004
E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d01000
E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d00`00
00=Fo@00E_d01UKm0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm00@005Km
E_eFo@800003E_d005Km00IFo@04001oogoo003oOolOOol00?mooomoofIoo`8000ioo`8000AFo@03
001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm009Fo@800003E_d005Km00IF
o@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@04001Fo@00
0004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d0
1000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`00
00=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000IFo@03001FoEKm00AFo@<000EF
o@03001FoEKm009Fo@800003E_d0000000IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm
00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d20002Ool00`00Oomoo`3oOolL
Ool00?mooomoof=oo`<000ioo`8000MFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<0
0003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30006
E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=F
o@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<0
00EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@03001FoEKm00<00003E_d005Km
00MFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d20005E_d30005E_d00`00E_eF
o@04E_d30005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00Ool00Woo00<007oo
Ool0ogoo6goo003oOoooOomPOol4000=Ool300000eKm001Fo@06E_d30005E_d00`00E_eFo@04E_d3
0005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`00
0UKm00<005KmE_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm
00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d20000
0eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d3
0005E_d00`00E_eFo@04E_d40005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00
E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km
000000AFo@04001oogoo003oOolMOol00?mooomooeioo`8000Aoo`03001oogoo00Moo`<000EFo@03
001FoEKm009Fo@800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<0
0003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@04E_d30005
E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=F
o@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<0
00EFo@03001FoEKm00AFo@<000EFo@03001FoEKm009Fo@800003E_d005Km00IFo@03001FoEKm00<0
009Fo@03001FoEKm00EFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eF
o@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d01000Oomoo`00ogoo
77oo003oOoooOomKOol30007Ool00`00Oomoo`03Ool300000eKm001Fo@06E_d01000E_d0000015Km
00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm00@005Km
E_eFo@800003E_d005Km00MFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d0
05Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00
E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d0
1UKm00@005Km000000AFo@03001FoEKm00AFo@<000IFo@03001FoEKm00=Fo@@000EFo@03001FoEKm
00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d0
0`00E_eFo@0300000eKm001Fo@06E_d01@00Oomoogoo0000ogoo6goo003oOoooOomIOol2000;Ool0
0`00Ool000020005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<0
05KmE_d00`000UKm00<005KmE_d015Km00<005KmE_d00`000UKm00<005KmE_d01EKm00<005Km0000
15Km00<005KmE_d01EKm0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm00@0
05KmE_eFo@800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003
E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d0
1000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`000UKm00<005KmE_d01EKm00<005KmE_d0
1@001eKm00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001F
oEKm00AFo@80009oo`03001oogoo0?mooaUoo`00ogooogooEWoo0`0037oo0`0000=Fo@00E_d01UKm
00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000IFo@03001F
oEKm00=Fo@<000IFo@03001FoEKm00AFo@8000IFo@03001FoEKm009Fo@800003E_d005Km00IFo@03
001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d0
0`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d00`00E_eF
o@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km00<005Km
E_d015Km0`001UKm00<005KmE_d00eKm10000eKm00<005Km00001UKm0P001eKm00@005KmE_eFo@80
0003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d007oo009o
o`03001oogoo0?mooaQoo`00ogooogooE7oo0P0037oo0`001EKm00<005KmE_d015Km0`001EKm00<0
05KmE_d015Km0P001eKm00@005KmE_eFo@800003E_d005Km00MFo@03001Fo@000080009Fo@03001F
oEKm00EFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005
E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d0
1UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm0`001EKm00<0
05KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm00@005KmE_eFo@800003E_d005Km00IFo@03
001FoEKm00<0009Fo@03001FoEKm009Fo@04001FoEKm0002E_d300000eKm001Fo@06E_d01000E_d0
000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00D007ooOomoo`000?mooaUo
o`00ogooogooDGoo0`0037oo0P0000=Fo@00E_d01UKm00<005KmE_d00`000UKm00<005KmE_d015Km
00<005KmE_d00`000UKm00<005KmE_d01EKm00<005Km000015Km00<005KmE_d01EKm0P001UKm00<0
05KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm00@005KmE_eFo@800003E_d005Km00IFo@03
001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d0
0`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@02E_d200000eKm001Fo@06
E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d00000
15Km00<005KmE_d015Km0`001UKm00H005KmE_eFo@00E_d40005E_d00`00E_eFo@03E_d30007E_d0
1000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@007ooOol00?mo
oaUoo`00ogooogooCgoo0P003Goo0P0015Km00<005KmE_d015Km0`001UKm00<005KmE_d00eKm0`00
1UKm00<005KmE_d015Km0P001UKm00<005KmE_d00UKm0P0000=Fo@00E_d01UKm00<005KmE_d00`00
00=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AF
o@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@03001FoEKm00<00003E_d0
05Km00IFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005
E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d0
1UKm00<005KmE_d00`000UKm00<005KmE_d015Km00<005KmE_d00`000UKm00<005KmE_d01EKm00@0
05Km000000AFo@03001FoEKm00=Fo@@000EFo@03001FoEKm00AFo@80009oo`03001oogoo0?mooaIo
o`00ogooogooC7oo0`003Goo0P001eKm00@005KmE_eFo@800003E_d005Km00MFo@03001Fo@000080
009Fo@03001FoEKm00EFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eF
o@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d00`00E_eFo@030000
0eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d3
0005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00
E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km
000000AFo@03001FoEKm00AFo@<00003E_d005Km00=Fo@03001FoEKm00=Fo@<000IFo@03001FoEKm
00=Fo@<000IFo@03001FoEKm00<0009Fo@03001FoEKm00EFo@03001FoEKm00<00005E_d007ooOol0
003oOolHOol00?mooomoodUoo`<000eoo`<0009Fo@03001FoEKm00EFo@03001Fo@0000AFo@03001F
oEKm00EFo@8000IFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d2
00000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06
E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@02E_d20000
0eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d0
1000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km
0P001eKm00@005KmE_eFo@800005E_d005KmE_d00004E_d00`00E_eFo@0300000eKm001Fo@06E_d0
0`00E_eFo@030002E_d00`00E_eFo@04E_d30006E_d00`00E_eFo@03E_d40005E_d01000Oomoo`00
ogoo5goo003oOoooOom7Ool2000>Ool20006E_d00`00E_eFo@04E_d20006E_d00`00E_eFo@02E_d2
00000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06
E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d0
0UKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00
E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001F
oEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06
E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km00<005Km000015Km0`001EKm00<0
05KmE_d015Km0`001UKm00@005KmE_eFo@800003E_d005Km00IFo@03001FoEKm00<0009Fo@03001F
oEKm00AFo@05001oogooOol0003oOolFOol00?mooomoodAoo`<000eoo`<00003E_d005Km00IFo@03
001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eF
o@04E_d30005E_d00`00E_eFo@04E_d20007E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eF
o@0300000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km
0`001EKm00<005KmE_d015Km0P001eKm00@005KmE_eFo@800003E_d005Km00IFo@03001FoEKm00<0
0003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04
E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d200001UKm00000000E_d0
00MFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30006E_d0
0`00E_eFo@03E_d20002Ool00`00Oomoo`3oOolDOol00?mooomood9oo`8000eoo`<000EFo@03001F
oEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00
E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d30005E_d00`00E_eFo@04
E_d30005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d0
0`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm
00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d20000
0eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d3
0005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00
E_d01UKm00<005KmE_d00`0000=Fo@00Ool00Woo00<007ooOol0ogoo4goo003oOoooOoloOol3000=
Ool200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001F
o@06E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005Km
E_d00UKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=F
o@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03
001FoEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001F
o@06E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm
00<005KmE_d015Km0`001EKm00<005KmE_d00UKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=F
o@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<0
00EFo@05001oogooOol0003oOolDOol00?mooomooceoo`8000ioo`8000AFo@03001FoEKm00AFo@<0
00EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@03001FoEKm00<00003E_d005Km
00IFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d0
0`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm
00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AF
o@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@03001F
oEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000003E_d20006
E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=F
o@00E_d01UKm00@007ooOol00?mooaAoo`00ogooogoo>Woo0`003Woo0P001eKm00<005KmE_d00`00
00=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm
0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm00@005KmE_eFo@800003E_d0
05Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@04001F
o@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007
E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@03
00000eKm001Fo@06E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20005E_d00`00
E_d00003E_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@030000
0eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0P000Woo00<007ooOol0ogoo4Goo003o
OoooOolhOol2000>Ool300000eKm001Fo@06E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eF
o@04E_d30005E_d00`00E_eFo@02E_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06
E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<0
05KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm00@005KmE_eFo@800003E_d005Km00IFo@03
001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@<000EFo@03001FoEKm
00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm009Fo@800003E_d005Km00IFo@03001F
oEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00EFo@800003E_d0000000AFo@03
001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@04001FoEKm
E_d200000eKm001oo`02Ool00`00Oomoo`3oOol@Ool00?mooomoocEoo`<000eoo`<000EFo@03001F
oEKm009Fo@800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003
E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d0
0`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00
E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000EF
o@03001FoEKm00AFo@<000EFo@03001FoEKm009Fo@800003E_d005Km00IFo@03001FoEKm00<00003
E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d3
0005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@03E_d30007E_d01000E_eFoEKm0P0000=Fo@00
E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km
000000AFo@04001oogoo003oOolBOol00?mooomooc9oo`<000eoo`<00003E_d005Km00IFo@04001F
o@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007
E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d0
0`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<0
00EFo@03001FoEKm00AFo@8000MFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003
E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d0
0`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00
E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000EF
o@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@04001oogoo003oOolAOol00?mooomo
oc1oo`8000eoo`<000EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d0
0`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km
00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm00@005Km
E_eFo@800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d0
05Km00IFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d2
00000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06
E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`000UKm00@005KmE_d0
00IFo@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d0
0`00E_eFo@0300000eKm001Fo@06E_d20002Ool00`00Oomoo`3oOol>Ool00?mooomoobeoo`<000ao
o`<0009Fo@03001FoEKm00AFo@03001FoEKm00<0009Fo@03001FoEKm00AFo@04001Fo@000004E_d0
0`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d01000E_eF
oEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00
E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001F
oEKm009Fo@800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003
E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d0
0`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00
E_d00UKm00D005KmE_eFo@00009Fo@<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04
E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@02E_d200001EKm001oogoo0000ogoo47oo
003oOoooOol[Ool2000<Ool30006E_d00`00E_eFo@03E_d30006E_d00`00E_eFo@03E_d20007E_d0
1000E_eFoEKm0P000UKm00<005KmE_d015Km00<005KmE_d00`000UKm00<005KmE_d015Km00<005Km
E_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AF
o@<000EFo@03001FoEKm00AFo@8000MFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<0
0003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005
E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=F
o@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<0
00EFo@04001FoEKm0003E_d30005E_d00`00E_eFo@04E_d20007E_d00`00E_eFo@0300000eKm001F
o@06E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km00@007ooOol00?moo`moo`00
ogooogoo:7oo0`0037oo0P0000=Fo@00E_d01eKm00<005Km00000P000UKm00<005KmE_d01EKm00<0
05Km00000P000UKm00<005KmE_d015Km00@005Km000000EFo@03001FoEKm00=Fo@<000IFo@03001F
oEKm00=Fo@<000EFo@03001FoEKm00AFo@8000MFo@03001FoEKm00<00003E_d005Km00IFo@03001F
oEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@<000EFo@03001FoEKm00AF
o@<000EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@03
00000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d0
15Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm00<005KmE_d00`0000=F
o@00E_d01UKm00<005Km00000`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm0`00
1EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm00@007ooOol00?moo`ioo`00ogoo
ogoo9Woo0P0000=oo`00Ool02goo00<005KmE_d00UKm00<005KmE_d01EKm0P001UKm00<005KmE_d0
15Km0P001UKm00<005KmE_d00eKm0P0025Km00<005Km00000P000UKm00<005KmE_d01EKm00<005Km
00000P000UKm00<005KmE_d015Km00<005KmE_d00`000UKm00<005KmE_d015Km0`001EKm00<005Km
E_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d00UKm0P0000=Fo@00E_d01UKm00<0
05KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03
001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@03001FoEKm
00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km
00IFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm009Fo@80
0003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IF
o@04001oogoo003oOol>Ool00?mooomoob=oo`<000Aoo`03001oogoo00Moo`8000IFo@03001FoEKm
009Fo@800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001Fo@000080009Fo@03
001FoEKm00EFo@8000IFo@03001FoEKm00AFo@8000IFo@03001FoEKm00=Fo@<000IFo@04001FoEKm
E_d200000eKm001Fo@06E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d00`00E_eFo@0300000eKm
001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<0
05KmE_d015Km0P001eKm00@005KmE_eFo@800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km
00IFo@03001FoEKm00<00003E_d005Km00IFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm
00AFo@<000EFo@03001FoEKm009Fo@800003E_d005Km00IFo@03001FoEKm00<00003E_d0000000IF
o@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00
E_eFo@04E_d30005E_d00`00E_eFo@04E_d20002Ool00`00Oomoo`3oOol;Ool00?mooomoob5oo`80
00Qoo`03001oogoo00=oo`<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005
E_d00`00E_eFo@04E_d20006E_d00`00E_eFo@02E_d200000eKm001Fo@06E_d00`00E_eFo@030000
0eKm001Fo@06E_d00`00E_d000020002E_d00`00E_eFo@05E_d00`00E_d00004E_d00`00E_eFo@04
E_d30006E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=F
o@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@0
05Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm009Fo@80
0003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IF
o@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04
E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<0
05KmE_d00`0000=Fo@00Ool00Woo00<007ooOol0ogoo2Woo003oOoooOolNOol3000;Ool00`00Ool0
00020005E_d00`00E_eFo@04E_d20007E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@03
00000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P00
1UKm00<005KmE_d015Km0P001UKm00@005KmE_eFo@800003E_d005Km00MFo@03001Fo@000080009F
o@03001FoEKm00AFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04
E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d00`00E_eFo@0300000eKm
001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0`00
1EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm00@005KmE_eFo@800003E_d005Km
00EFo@80009Fo@<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004
E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@03E_d40005E_d01000Oomoo`00ogoo37oo003oOooo
OolKOol3000=Ool300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d30005E_d00`00
E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<0
05KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005Km000015Km00<0
05KmE_d01EKm0P001UKm00<005KmE_d00eKm0`001EKm00<005KmE_d015Km0P001eKm00<005KmE_d0
0`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d0
1UKm0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm00@005KmE_eFo@800003
E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@04
001Fo@000004E_d00`00E_eFo@03E_d40005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d2
0007E_d00`00E_eFo@0300000eKm001Fo@05E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d01@00
Oomoogoo0000ogoo2goo003oOoooOolIOol2000=Ool30005E_d00`00E_eFo@04E_d30005E_d00`00
E_eFo@02E_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@030000
0eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm
00<005KmE_d015Km0P001UKm00<005KmE_d00UKm0P0000=Fo@00E_d01UKm00<005Km00000P000UKm
00<005KmE_d015Km00<005KmE_d00`0000=Fo@00E_d01UKm0`001EKm00<005KmE_d015Km0`001EKm
00<005KmE_d015Km0`001EKm00<005KmE_d00UKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=F
o@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<0
00EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001F
o@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d30005E_d0
0`00E_eFo@03E_d30006E_d00`00E_eFo@03E_d20003Ool00`00Oomoo`3oOol8Ool00?mooomooaIo
o`<000aoo`<0009Fo@03001FoEKm00AFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004
E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d01000
E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=F
o@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@8000IFo@03001FoEKm00=Fo@<000EFo@03
001FoEKm009Fo@800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<0
0003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005
E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=F
o@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00H005Km000005Km0002E_d00`00E_eFo@04
E_d30005E_d00`00E_eFo@04E_d30005E_d01000E_eFoEKm0`0000=Fo@00E_d01EKm00<005KmE_d0
0`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00Ool00Woo00<007ooOol0ogoo27oo003oOooo
OolDOol2000<Ool30006E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@04E_d20007E_d01000E_eF
oEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00
E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001F
oEKm00AFo@8000MFo@03001FoEKm00<00003E_d005Km00IFo@03001Fo@000080009Fo@03001FoEKm
00AFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eF
o@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm
00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001F
oEKm00AFo@<000EFo@03001FoEKm00AFo@8000=Fo@05001FoEKmE_d00002E_d300000eKm001Fo@06
E_d00`00E_eFo@0300000eKm001Fo@05E_d01000E_d000001EKm00<005KmE_d00eKm0`001EKm00<0
05KmE_d015Km0`001EKm00<007ooOol00P00ogoo2Goo003oOoooOolAOol3000<Ool200000eKm001F
o@07E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d0
1000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km
0P001eKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005Km
E_d00`0000=Fo@00E_d01UKm0`001EKm00<005KmE_d015Km0P001UKm00<005KmE_d00eKm0P001eKm
00@005KmE_eFo@800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<0
0003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005
E_d00`00E_eFo@04E_d20007E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm
001Fo@06E_d00`00E_eFo@0300000eKm001Fo@02E_d01000E_eFoEKm0`001EKm00<005KmE_d00eKm
10001EKm00<005KmE_d00eKm0P001eKm00@005KmE_eFo@800003E_d005Km00IFo@03001FoEKm00<0
0003E_d005Km00IFo@800003Ool007oo0?moo`Qoo`00ogooogoo3goo0P003Woo00<005KmE_d00UKm
00<005KmE_d01EKm0P001UKm00<005KmE_d00eKm0`001UKm00<005KmE_d00eKm0P001eKm00<005Km
E_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00
E_d01UKm0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d00UKm
0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005Km00000P000UKm00<005Km
E_d015Km00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001F
oEKm00AFo@8000MFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IF
o@03001FoEKm00<00003E_d005Km00IFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AF
o@<000EFo@05001FoEKm001Fo@0200000eKm001Fo@05E_d00`00E_eFo@030002E_d00`00E_eFo@04
E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<0
05KmE_d015Km0P000Woo00<007ooOol0ogoo1Woo003oOoooOol<Ool3000>Ool20006E_d00`00E_eF
o@02E_d200000eKm001Fo@06E_d00`00E_d000020002E_d00`00E_eFo@05E_d00`00E_d000020002
E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00
E_eFo@02E_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@030000
0eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001UKm
00<005KmE_d00eKm0P001eKm00@005KmE_eFo@800003E_d005Km00IFo@03001FoEKm00<00003E_d0
05Km00IFo@03001FoEKm00<00003E_d005Km00IFo@<000EFo@03001FoEKm00AFo@<000EFo@03001F
oEKm00AFo@<000EFo@03001FoEKm009Fo@800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km
00IFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@03E_d30006E_d0
0`00E_eFo@03E_d30005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm
00<005KmE_d00`0000=Fo@00Ool00Woo00<007ooOol0ogoo1Goo003oOoooOol:Ool2000>Ool30000
0eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0P001UKm00<005KmE_d015Km0P001UKm
00@005KmE_eFo@800003E_d005Km00IFo@03001FoEKm00<0009Fo@03001FoEKm00AFo@03001FoEKm
00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d3
0005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`00
00=Fo@00E_d01UKm00<005Km00000P000UKm00<005KmE_d015Km00@005Km000000AFo@03001FoEKm
00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm009Fo@800003E_d005Km00IFo@03001F
oEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00
E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d200000eKm001Fo@03E_d0
1000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`00
00=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000EFo@04001oogoo003oOol7Ool0
0?mooomoo`Moo`<000eoo`<000EFo@03001FoEKm00AFo@8000MFo@03001FoEKm00<00003E_d005Km
00IFo@03001FoEKm00<00003E_d005Km00IFo@03001Fo@0000AFo@03001FoEKm00AFo@<000IFo@03
001FoEKm00=Fo@<000EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d0
0`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km
00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001UKm00<005KmE_d00eKm0P001eKm00<005Km
E_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001F
oEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d2
00000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@03000015Km001Fo@00
15Km00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm
00AFo@8000MFo@03001FoEKm00<00003E_d005Km00IFo@04001oogoo003oOol6Ool00?mooomoo`Ao
o`<000eoo`<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@<000EFo@03001FoEKm
00AFo@<000EFo@03001FoEKm00AFo@8000IFo@04001FoEKmE_d20002E_d00`00E_eFo@05E_d00`00
E_d000020002E_d00`00E_eFo@04E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km
00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm00<005Km
E_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005Km00000P000UKm00<0
05KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm00@005KmE_eF
o@800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km
00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d20004E_d2
0007E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eF
o@0300000eKm001Fo@06E_d30005E_d00`00E_eFo@04E_d20002Ool00`00Oomoo`3oOol3Ool00?mo
oomoo`9oo`8000eoo`<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm009Fo@800003E_d005Km
00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001Fo@00
00EFo@03001FoEKm00AFo@8000IFo@03001FoEKm00=Fo@<000EFo@03001FoEKm00AFo@8000MFo@03
001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003
E_d005Km00IFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000IFo@04001FoEKm
E_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001F
o@06E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005Km
E_d015Km0P001eKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01EKm
0P0000IFo@00000005Km0007E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005
E_d00`00E_eFo@02E_d200000eKm001Fo@06E_d00`00E_eFo@0300001EKm001oogoo0000ogoo1Goo
003oOoonOol3000<Ool30002E_d00`00E_eFo@04E_d00`00E_eFo@0300000eKm001Fo@06E_d01000
E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P00
1eKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km
E_d00`0000=Fo@00E_d01UKm0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm
00<005KmE_d00UKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d0
0`0000=Fo@00E_d01UKm00<005Km000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`00
1EKm00<005KmE_d015Km0P001eKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=F
o@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm0`001EKm00<005KmE_d015Km0`001EKm00<0
05KmE_d00eKm0`001EKm00<005KmE_d00UKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00
E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000EF
o@04001oogoo003oOol4Ool00?moooaoo`8000eoo`8000IFo@03001FoEKm00=Fo@<000EFo@03001F
oEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06
E_d00`00E_eFo@0300000eKm001Fo@06E_d30005E_d00`00E_eFo@04E_d20006E_d00`00E_eFo@03
E_d30005E_d00`00E_eFo@02E_d200000e9i001Fo@06E_d00`00E_eFo@0300000e9i001Fo@06E_d0
0`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<005Km
E_d015Km0`001EKm00<005KmE_d015Km0P001UKm00@005KmE_eFo@800003E_d005Km00IFo@03001F
oEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@<000EFo@03001FoEKm00AF
o@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm009Fo@800003E_d005Km00IFo@03001FoEKm
00<00003E_d005Km00EFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eF
o@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P00
00=Fo@00E_d01UKm00@007ooOol00?moo`=oo`00ogoonGoo0`003Goo0P0000=Fo@00E_d01UKm00<0
05Km00000P000UKm00<005KmE_d015Km00<005KmE_d00`000UKm00<005KmE_d015Km00@005Km0000
00AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm009Fo@800003E_d0
05Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001Fo@000080009Fo@03001FoEKm00AFo@04
001Fo@000004DWT00`00E_eFo@04E_d30005DWT00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d2
0007E_d01000E_eFoEKm0P0000=BN@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005Km
E_d00`0000=Fo@00E_d01EKm00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AF
o@<000EFo@03001FoEKm009Fo@800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03
001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eF
o@03E_d30004E_d20006E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`00
00=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00=F
o@<00003Ool007oo0?moo`9oo`00ogoomgoo0P003Woo0P0015Km00<005KmE_d015Km0P001UKm00<0
05KmE_d00eKm0`001UKm00<005KmE_d00eKm0P001eKm00<005KmE_d00`0000=Fo@00E_d01UKm00<0
05KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm
00AFo@8000IFo@03001FoEKm00=Fo@8000MBN@04001FoEKmE_d200000dhg001BN@06DWT00`00E_eF
o@0300000e9H001Fo@06E_d00`00E_eFo@0300000e9H001Fo@06E_d01000E_d00000159i00<005Km
E_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d00eKm0P001eKm00<005KmE_d00`00
00=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AF
o@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d200000eKm
001Fo@05E_d00`00E_eFo@0300000eKm001Fo@04E_d00`00E_d00002E_d300000eKm001Fo@06E_d0
1000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km
0P001UKm00<005KmE_d00`000UKm00@007ooOol00?moo`9oo`00ogoom7oo0`003Woo0P001eKm00<0
05KmE_d00`0000=Fo@00E_d01UKm00<005Km00000P000UKm00<005KmE_d01EKm00<005Km00000P00
0UKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm00@0
05KmE_eFo@800003DUT005Km00IFo@03001FoEKm00<00003DUP005Km00IFo@03001Fo@0000800003
CSL0059i00IBN@04001Fo@000004CSL00`00DWUBN@05DWT20005DUP00`00E_eFo@04E_d30005DUP0
0`00E_eFo@04E_d20007DWT00`00E_eFo@0300000e9H001Fo@06E_d00`00E_eFo@0300000eKm001F
o@06E_d00`00E_d000020002E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00
E_eFo@04E_d20007E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d0
1UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00=Fo@<000EFo@03
001FoEKm009Fo@03001Fo@00008000EFo@03001FoEKm00AFo@8000MFo@03001FoEKm00<00003E_d0
05Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00EFo@<000IF
o@04001oogoo003oOol1Ool00?mooo9oo`8000ioo`<00003E_d005Km00IFo@<000EFo@03001FoEKm
00AFo@8000IFo@03001FoEKm00AFo@8000IFo@04001FoEKmE_d20002E_d00`00E_eFo@04E_d00`00
E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d00000159I00<0
05KmE_d015Km0`001E9H00<005KmE_d015Km0P001Dhg00<0059iDWT01E9i00<004hgCSL014hg00<0
059iDWT0159i0P001e9H00<005KmE_d00`0000=>5`00DUP01U9H00<005KmE_d00`0000=>=`00DWT0
1e9i0P001E9H00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001UKm00@005KmE_eFo@800003
E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@04
001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d2
0006E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eF
o@0300000eKm001Fo@06E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d0
1000E_eFoEKm0P0000=Fo@00E_d01UKm00@007ooOol00?moo`5oo`00ogookgoo0`003Goo0`001EKm
00<005KmE_d00UKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d0
0`0000=Fo@00E_d01UKm00<005Km00001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d015Km0`00
1EKm00<005KmE_d015Km0P001e9I00<005KmE_d00`0000=>5`00DUP01U9H00<005KmE_d00`0000=>
5P00CSL014hg00<0059iDWT0159i0P001Thg00<0059iDWT00e9i00@005igGWL000MBF08000E>5`03
001BF59H00EBF08000E>=`03001BNE9i00ABN@8000MBF003001FoEKm00<00003DSP005Km00IFo@03
001FoEKm00<00003DUT005Km00IFo@03001Fo@0000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm
00AFo@<000EFo@03001FoEKm00AFo@8000MFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm
00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00EFo@<000EFo@03001FoEKm00AFo@<0
0003E_d005Km009Fo@03001FoEKm00AFo@<000EFo@03001FoEKm009Fo@800003E_d005Km00IFo@03
001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00EFo@04001Fo@000004E_d0
0`00E_eFo@04E_d20002Ool00`00Oomoo`3mOol00?moonaoo`<00003Ool007oo00Yoo`<0009Fo@03
001FoEKm00AFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d0
0`00E_eFo@04E_d20007E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_eFo@030002DUT0
0`00E_eFo@04E_d00`00E_eFo@0300000dhg001BF@07DUT20005CQL00`00DUQBF005DUP20005CQH0
0`00CSM>=`03CSL00`00DWUBN@02DWT01000GWMNM`001Thg00D0059iDWUBN@0000=NM`03001BF59H
00ABF08000I>5`03001BF59H00ABF08000I>=`03001BNE9i00=BN@04001NMeig0007DUP20005DSP0
0`00E_eFo@04E_d30005DUT00`00E_eFo@04E_d20006E_d00`00E_eFo@0300000eKm001Fo@06E_d0
0`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d30005E_d00`00E_eF
o@04E_d30005E_d00`00E_eFo@04E_d30005E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005Km
E_d00`0000EFo@00E_eFo@0000AFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d0
0`00E_eFo@04E_d30005E_d00`00E_eFo@03E_d40005E_d00`00E_eFo@03E_d20007E_d00`00E_eF
o@0300000eKm001oo`02Ool00`00Oomoo`3lOol00?moonYoo`8000Aoo`03001oogoo00Ioo`<000IF
o@03001FoEKm00=Fo@8000MFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm
001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d20006E_d00`00E_eFo@03E_d30006DUT00`00
E_eFo@03E_d30005CSL00`00DUUBF@04DUT20006CQL00`00DUQBF004DUP20006CQH00`00CSM>=`04
CSL01000DWUBN@000eig00<004hgCSL014hg00@0059iDWT000ANM`03001BF59H00=BF003001NMP00
00I>5`03001BF59H00=BF004001NMUif0006CSL01@00DWUBNE9i00000eig00<0059HDUP0159H0P00
1e8h00<005KmE_d00`0000=>5`00DUT01U9I00<005KmE_d00`0000=BF000E_d01EKm0`001EKm00<0
05KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d00UKm0P0000=Fo@00E_d01UKm
00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01EKm00@005Km000000AF
o@03001FoEKm00AFo@<000EFo@03001Fo@0000AFo@<000EFo@03001FoEKm00AFo@8000MFo@04001F
oEKmE_d200000eKm001Fo@05E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d00`00E_eFo@030000
0eKm001Fo@06E_d30005E_d01000Oomoo`00oWoo003oOooWOol30007Ool00`00Oomoo`02Ool30002
E_d00`00E_eFo@05E_d00`00E_d000020002E_d00`00E_eFo@04E_d01000E_d0000015Km00<005Km
E_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d00UKm0P0000=BN@00E_d01UKm00<0
05Km00000P0000=>=`00DUT01e9I00<005Km00000P0000=>5`00CSL01Dhg00<0059IDUT00e9I00<0
05ig00001ThG00<0059HDUP00e9H00<005if00001ThF00<004hgCSL014hg00<0059i00001Eig00<0
04hgCSL00dhg00<0059i00001Uig00D0059HDUQBF00000=NMP03001>5dhG00A>5`05001BF59HDUP0
0003GWH00`00CSM>=`04CSL01000DWUBN@0015ig00<0059HDUP00e9H00@005igGWL000MB>08000E>
5`03001BFE9I00ABF@<000EBF004001FoEKmE_d200000e9H001Fo@06E_d00`00E_eFo@0300000eKm
001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0`00
1EKm00<005KmE_d015Km0`001EKm00<005KmE_d00eKm0P001eKm00@005KmE_eFo@800003E_d005Km
00IFo@800006E_d00000001Fo@001eKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AF
o@03001FoEKm00=Fo@<000IFo@03001FoEKm00=Fo@<000EFo@03001FoEKm009Fo@800003E_d005Km
00IFo@04001oogoo003mOol00?moonEoo`8000]oo`04001oo`000006E_d00`00E_eFo@04E_d20006
E_d00`00E_eFo@03E_d20007E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d00`00E_eFo@030000
0eKm001Fo@06E_d01000E_d00000159i00<005KmE_d015Km0P001Dhg00<0059IDUT01U9I00<004hG
CQL00dhG00<004hgCSL014hg00D0059IDUUBF@0000=NM`03001>5dhG00A>5`05001BF59HDUP00003
GWH00`00CQI>5P04CQH00`00CSM>=`03CSL20006GWL00`00CSM>=`03CSL20007GWL01000DUQBF000
15if00<004hGCQL014hG00@0059HDUP000ANMP03001>=dhg00A>=`03001BN@0000INM`05001BF59H
DUP00003GWL00`00DSQB>005DSP00`00CQM>5`04CQL00`00DUUBF@03DUT00`00GWL00007DUP00`00
E_d00004DUP00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007
E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d0
0`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<0
00EFo@03001FoEKm00AFo@8000IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003
E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d20002Ool00`00Oomoo`3jOol00?moon9o
o`<000aoo`<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001Fo@000080009F
o@03001FoEKm00AFo@<000IFo@03001FoEKm00=Fo@<000EFo@03001FoEKm00AFo@8000MBN@04001F
oEKmE_d200000dhG001>=`04CSL00`00DUUBF@05DUT20005CQL00`00CSM>=`04CSL01000DUUBF@00
15ig00<004hGCQL014hG00@0059HDUP000ANMP03001>5ThF00A>5P03001>=dhg009>=`03001FE`00
00INM`03001>=dhg009>=`03001JE`0000MNM`03001BF00000ENMP03001>5dhG00A>5`03001BF000
00INMP03001>=dhg00=>=`8000MNM`04001BF59H0004GWL00`00DSQB>004DSP20007CQL01@00DUUB
FE9I00000eig00<0059HDUP01E9H00<0059HDUP0159H00@005KmE_eFo@800003DUP005Km00IFo@03
001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d0
0`00E_eFo@04E_d30005E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@04E_d20007E_d00`00E_eF
o@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001F
o@05E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20007E_d01000E_eFoEKm0P00
00EFo@00Oomoo`000?aoo`00ogooh7oo0P0037oo0`001EKm00<005KmE_d015Km0`001EKm00<005Km
E_d015Km0P001UKm00@005KmE_eFo@80009Fo@03001FoEKm00EFo@03001Fo@000080009Fo@03001F
oEKm00AFo@03001FoEKm00<00003CSP0059i00IBN@04001Fo@000004CQL00`00CSM>=`03CSL00`00
DUUBF@03DUT00`00GWH00005CQL00`00CSM>=`04CSL00`00DUT00005GWL00`00CQM>5`04CQL00`00
DUP00005GWH00`00CQI>5P04CQH00`00CSM>=`020003EUL00`00GWMNM`04GWL01000CSM>=`000eYG
00<005igGWL01Eig00<005ifGWH01Eif00<004hGCQL00dhG0P001eif00<004hgCSL00Thg00<005YG
00001eig00<0059H00001Uig00<0058hDSP00U8h00@005ifGWH000I>5`04001BFE9I0004GWL00`00
DUQBF004DUP20006DUP01000E_d00000159H00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`00
1EKm00<005KmE_d015Km0P001eKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d00`0000=F
o@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm0`001EKm00<005KmE_d015Km0`001EKm00<0
05KmE_d015Km0`001EKm00@005KmE_eFo@800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km
00IFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d01000Oomoo`00ngoo003oOooM
Ool3000<Ool20002E_d00`00E_eFo@04E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@03
00000eKm001Fo@06E_d00`00E_d00005E_d00`00E_eFo@04E_d20006E_d00`00E_eFo@03E_d30005
CSP00`00DWUBN@04DWT20006CQL00`00CSM>=`03CSL00`00DUUBF@02DUT01@00GWINMUif00001DhG
00<004hgCSL00dhg0P001eig00<004hGCQL00dhG0P001eif00<004hFCQH014hF0P001EIG00<005ig
GWL015ig00<004hg000015YG00<005igGWL01Eig00<005ifGWH01Eif00<004hGCQL00ThG00<005YG
00001eif00<004hgCSL00P000eYG00<005igGWL01Eig00<005igGWL01Eig00D0058hDSQB>00000=N
MP03001>5dhG00A>5`03001BF@0000ENM`03001BF59H00=BF004001NUejG0006DUP00`00DUQBF005
DUP00`00E_eFo@0300000e9H001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@03
00000eKm001Fo@06E_d30005E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@04E_d30005E_d00`00
E_eFo@02E_d200000eKm001Fo@05E_d20002E_d300000eKm001Fo@06E_d00`00E_eFo@0300000eKm
001Fo@05E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<0
05KmE_d015Km0P001eKm00@007ooOol00?Yoo`00ogoofgoo0P003Woo00<005KmE_d00eKm00<005Km
E_d00eKm0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001eKm00<005KmE_d00`00
00=Fo@00E_d01UKm00<005Km00000P0000=>=`00CSP01Dhh00<0059iDWT00e9i00<005ig00001ThG
00<004hgCSL014hg00@0059IDUT000ANMP03001>5dhG00=>5`03001>=dhg009>=`03001FE`0000MN
M`03001>5dhG009>5`03001FE`0000MNMP03001>5ThF00=>5P8000IFE`03001NMeig00ANM`8000IJ
E`03001NMeig00=NM`03001NM`0000INMP03001>5dhG008000=JE`03001NMUif00ENMP8000EJE`03
001NMeig00ANM`8000MNM`04001B>58h0004GWH00`00CQM>5`04CQL20007GWL01@00DUQBF59H0000
0ejG00<0059HDUP0159H00<0059HDUP01U9H0P001E9H00<005KmE_d015Km0`001EKm00<005KmE_d0
15Km0`001EKm00<005KmE_d00UKm0P0000=Fo@00E_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm
00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00=Fo@@000EFo@03001F
oEKm00AFo@<000EFo@03001FoEKm00=Fo@8000MFo@03001FoEKm00<00003E_d005Km00IFo@03001F
oEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@800003Ool007oo0?Uoo`00
ogoof7oo0`003Woo0P001eKm00<005Km00000P000UKm00<005KmE_d015Km00<005KmE_d00`0000=F
o@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm0`001EKm00<005KmE_d015Km0P001Dhg00<0
04hhCSP014hh00D0059iDWUBN@00009NM`03001>5dhG00E>5`03001>=dhg00=>=`03001BF@0000EN
MP03001>5dhG00=>5`03001>=dhg008000=FE`03001NMeig00ANM`03001>5dhG008000=FE`03001N
MUif00ANMP03001>5ThF009>5P03001F=`0000MFE`03001NMeig009NM`03001JE`0000IJE`03001N
Meig009NM`04001NMeig0007GWH20005FUL00`00GWINMP04GWH20006FUL00`00GWMNM`03GWL01000
GWMNM`001eig0P001Uif00<004hGCQL00ThG00<005YG00001eig00@0059HDUP000ANU`03001BF59H
00=BF003001RU`0000MBF003001BF59H00EBF003001FoEKm00<00003DUP005Km00IFo@03001FoEKm
00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@04E_d3
0005E_d00`00E_eFo@04E_d20007E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@030000
0eKm001Fo@05E_d00`00E_eFo@0300000eKm001Fo@06E_d30005E_d00`00E_eFo@04E_d30005E_d0
0`00E_eFo@04E_d30005E_d01000E_eFoEKm0`0000EFo@00Oomoo`000?Uoo`00ogooeWoo0P003Woo
0`0000=Fo@00E_d01UKm0P001UKm00<005KmE_d00eKm0`001EKm00<005KmE_d015Km0`001EKm00<0
05KmE_d00UKm0P0000=BN@00E_d01UKm00<005KmE_d00`0000=>5`00CSL014hg00<004hhCSP014hh
00@0059iDWT000ANM`03001>5dhG00A>5`03001>=dhg00=>=`8000MNMP03001>5dhG00=>5`8000EF
E`03001NMeig00ENM`8000EFE`03001NMUif00ANMP03001>5ThF008000=F=`03001FEeIG00AFE`05
001NMeigGWL00003FUL00`00FUMJE`04FUL01000GWMNM`0015ig00<005ifGWH015if00<005YGFUL0
15YG00<005ifGWH00eif00<005Yg00001eYG00D005igGWMNM`0000=NM`03001NMeig00ENM`03001N
MUif00ENMP05001>5dhGCQL00003FUL00`00GWMNM`04GWL00`00DUP00006GYL01@00DUQBF59H0000
0V:G00<0059HDUP0159H00<006:G00001e9H0P001E9H00<005KmE_d015Km0`001EKm00<005KmE_d0
15Km0P001eKm00<005Km00000P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<0
05KmE_d00`0000=Fo@00E_d01UKm0`000UKm00@005KmE_d000IFo@<000EFo@03001FoEKm00=Fo@<0
00EFo@03001FoEKm009Fo@800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001F
oEKm00<00003E_d005Km00EFo@04001Fo@000005E_d00`00Ool0003iOol00?mooeYoo`H000ioo`@0
065oo`<000eoo`<000EFo@03001FoEKm009Fo@800003E_d005Km00IFo@03001Fo@000080009Fo@03
001FoEKm00AFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004DWT00`00E_eFo@04E_d3
0005CQL00`00CSM>=`02CSL00`00CSQ>>004CSP00`00DWT00005GWL00`00CQM>5`04CQL01000CSM>
=dhg0P0000=FE`00GWH01Uif00<004hGCQL00ThG0P001UIG00<005igGWL015ig0P001UIG00<005if
GWH01Eif0P001EHg00<005IGEUL015IG00@005igGWL000AJE`03001JEeYG00AJE`03001NM`0000EN
M`03001NMUif00=NMP8000MJE`05001NMUifGWH00003FWL00`00FUMJE`04FUL01000GWMNM`0015ig
00<005igGWL015ig0P001eif00@004hGCQL000AJE`03001NMeig00ANM`8000MNU`04001BF59H0004
HYL00`00DUQBF002DUP01000HYMRU`001e9H00<0059HDUP01E9H00<005KmE_d00`0000=BF000E_d0
1UKm00<005KmE_d00`0000=Fo@00E_d01UKm0P001EKm00<005KmE_d015Km0`001EKm00<005KmE_d0
15Km0`001EKm00<005KmE_d00UKm0P0000=Fo@00E_d00UKm00D005KmE_eFo@00009Fo@<00003E_d0
05Km00EFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00E_eFo@04E_d30005
E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@03E_d20007E_d01000Oomoo`00n7oo003oOomHOol:
000:Ool8001LOol3000=Ool300000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0P00
1UKm00<005KmE_d00eKm0`001EKm00<005KmE_d015Km0P001e9i00<005KmE_d00`0000=>5P00CQL0
1DhG00<004hgCSL00dhg00<004hhCSP00dhh0P001Uig00<004hGCQL01DhG0`0015IG00<005ifGWH0
15if00<004hGCQL00P0000=F=`00EUL01UIG00<005igGWL00Uig00<005YG00001eIG00<005ifGWH0
0eif0P001UHg00<005IGEUL01EIG0P001EYG00<005YGFUL015YG0P001Uig00<005ifGWH00Uif00@0
05YfFWH000IJE`04001NMUif0004FWL00`00FUMJE`04FUL00`00GWL00006GWL00`00GWMNM`02GWL0
1000GWINMP001eif0P001EYG00<005igGWL00eig00<005ig00001ejG00<0059H00001F:G00D0059H
DUQBF00000=RU`03001BF59H00ABF003001RU`0000MBF08000EBF003001FoEKm00AFo@<000EFo@03
001FoEKm009Fo@800003E_d005Km00EFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<0
0003E_d005Km00IFo@04001Fo@000004E_d01000E_eFo@000eKm0`001EKm00<005KmE_d00eKm0`00
1EKm00<005KmE_d015Km0P001eKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=F
o@00E_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm0P000Woo00<007ooOol0mGoo003oOomHOol3
0005Ool30009Ool20004Ool2001JOol2000=Ool30005E_d00`00E_eFo@04E_d20007E_d00`00E_eF
o@0300000eKm001Fo@06E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_eFo@0300000dhh
001BN@07DWT20004CQH00`00CQM>5`04CQL00`00CSM>=`03CSL01000CSQ>>4hh0P0000=FE`00GWL0
1Uig00<004hGCQL00dhG0P001UIG00<005ifGWH01Eif0P0015Hg00<005IGEUL015IG00D005igGWMN
M`00009JE`03001FEeIG00EFE`03001NMUif009NMP03001JEP0000MF=`03001FEeIG00=FE`8000MJ
E`03001JEeYG009JE`03001JE`0000MNM`04001NMUif0003FWH00`00FUMJE`04FUL00`00GWH00005
FWL00`00FUMJE`04FUL20007GWL01@00GWMNMeig00000eif00<005ifGWH01Eif00<005YGFUL01EYG
00D005igGWMNM`0000=NM`03001NUejG00ENU`03001RUf:G00ERU`04001BF59H0004HYL00`00DUQB
F002DUP01000HYMRU`001U9H0P001e9H00<005KmE_d00`0000=BF000E_d01UKm00@005Km000000AF
o@03001FoEKm00=Fo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@03001F
o@0000<00003E_d005Km00EFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d0
05Km00IFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00=Fo@<000EFo@03001FoEKm009F
o@800005E_d007ooOol0003gOol00?moof5oo`8000Qoo`8000Ioo`8005Ioo`<000aoo`<0009Fo@03
001FoEKm00AFo@03001FoEKm00<00003E_d005Km00IFo@<000EFo@03001FoEKm00AFo@8000IFo@03
001FoEKm00=Fo@<000E>>003001BNE9i00ABN@8000I>5P03001>5dhG00A>5`03001>=dhg009>=`04
001>>0000004EUL00`00GWMNM`04GWL00`00CQM>5`02CQL00`00ESL00006EUL00`00GWINMP04GWH2
0005ESL00`00EUMFE`04EUL01000GWMNM`0015YG00<005IGEUL015IG00<005ifGWH00P000eYF00<0
05HgESL015Hg00<005IGEUL00UIG00<005YG00001eYG00D005YGFUMJE`0000=JE`03001NMeig00AN
M`03001NMP0000EJMP03001JEeYG00AJE`03001JMeYg00EJM`03001JEeYG009JE`03001JM`0000MN
M`04001NMeig0004GWH00`00GWINMP04GWH20007FUL01000GWMNM`0015ig00<005jGGYL015jG0P00
1f:G00<0059H00001F:G00D0059HDUQBF00000=RU`03001BF59H00=BF004001RUf:G0007DUP20005
DUP00`00E_eFo@04E_d20006E_d01000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=F
o@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm0`001EKm00<005KmE_d00eKm0`001EKm00<0
05KmE_d015Km0`001EKm00<005KmE_d00UKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00
E_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@04001oogoo003fOol00?mo
of9oo`8000Moo`8000Ioo`8005Aoo`8000eoo`8000IFo@03001FoEKm00=Fo@<000EFo@03001FoEKm
009Fo@800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001Fo@0000800003CSL0
04hh00E>>003001BNE9i00=BN@03001JEP0000I>5P03001>5dhG00A>5`03001>=dhg009>=`8000IF
E`03001NMeig00ANM`03001>5dhG0080009F=`03001FEeIG00EFE`03001NMUif009NMP03001FE`00
00IF=`03001FEeIG00AFE`8000EJE`03001FEeIG00EFE`8000EJEP03001F=eHg00AF=`03001FEeIG
008000=JE`03001JEeYG00AJE`04001JEeYG0004FUL00`00GWMNM`05GWL00`00FWIJMP04FWH00`00
FUMJE`03FUL20007FWL01@00FUMJEeYG00000eYg00<005igGWL01Eig0P001Uif00<005ifGWH00Uif
00@005igGWL000IJE`03001NM`0000ENM`03001NUejG00=NU`04001NUejG0007HYL00`00HYMRU`04
HYL01000DUQBF0001F:G00D0059HDUQBF00000=RU`03001BF59H00ABF08000MBF003001FoEKm00<0
0003DUP005Km00EFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005
E_d00`00E_eFo@02E_d200000eKm00000005E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eF
o@0300000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d00eKm
0`001EKm00<005KmE_d015Km0P001eKm00@007ooOol00?Eoo`00ogooHWoo0P001Woo0P0027oo0P00
D7oo0`0037oo0`0000=Fo@00E_d01UKm00<005Km00000P000UKm00<005KmE_d015Km00@005Km0000
00AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000E>=`03001>>4hh00A>>005001BNE9i
DWT00003FUH00`00CQI>5P03CQH00`00CQM>5`04CQL00`00CSM>=`0200000e8g001FE`05EUL00`00
GWMNM`05GWL20005ESL00`00EUMFE`04EUL01@00GWINMUif00000UIG00<005HgESL015Hg00<005IG
EUL00eIG0P001UYG00<005IGEUL015IG0P001UYF00<005HgESL01EHg0P001EYG00<005YGFUL01EYG
0P001EYG00<005igGWL015ig0P001UYf00<005YGFUL00UYG00@005YGFUL000IJM`04001JEeYG0004
FWL00`00GWMNM`04GWL20007GWH01@00GWINMUif00000eig00<005YGFUL01EYG00<005igGWL01Eig
00D005jGGYMNU`0000=NU`03001RUf:G00ARU`8000MRU`8000IRU`04001BF59H0004HYL00`00DUQB
F003DUP01000HYMRU`001e9H0P001E9H00<005KmE_d00eKm0P001eKm00<005KmE_d00`0000=Fo@00
E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00=Fo@<000EF
o@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000MFo@04001FoEKmE_d200000eKm001Fo@05
E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d01000Oomoo`00
mGoo003oOomROol20006Ool20008Ool2001>Ool2000<Ool30005E_d00`00E_eFo@04E_d20006E_d0
0`00E_eFo@03E_d20007E_d01000E_eFoEKm0P000UKm00<005KmE_d015Km00<005KmE_d00`0000=>
=`00CSL014hg00<004hhCSP014hh00@0059iDWT000AJEP03001>5ThF00A>5P03001>5dhG00A>5`80
00AB=`03001FEeIG00AFE`03001NMeig00=NM`8000IF=`03001FEeIG00AFE`04001NMUif0004EUL0
0`00ESMF=`03ESL00`00EUMFE`02EUL00`00EUL00007FUL00`00EUMFE`02EUL00`00FUL00007FUH0
0`00ESMF=`03ESL20006FUL00`00FUMJE`04FUL20007FUL00`00GWMNM`02GWL00`00FWL00007FWH0
1000FUMJE`000eYG00<005YgFWL01EYg0P001EYg00<005igGWL00eig00<005ig00001eif00@005if
GWH000ANM`03001JEeYG00AJE`8000MNM`04001NUejG0004GYL00`00HYMRU`03HYL01000HYMRU`00
1V:G00<006:GHYL01F:G00<0059H00001V:G00D0059HDUQBF00000=RU`03001BF59H00ABF08000MB
F003001Fo@0000800003DUP005Km00IFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AF
o@8000IFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00
E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d00eKm0`001EKm00<005KmE_d0
15Km0`001EKm00<005KmE_d015Km0P000Woo00<007ooOol0lWoo003oOomROol20006Ool20008Ool2
001;Ool3000<Ool20002E_d00`00E_eFo@04E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_d0
00020002E_d00`00E_eFo@05E_d00`00E_d00005E_d00`00E_eFo@03E_d30005CSL00`00CSM>=`03
CSL00`00CSQ>>003CSP00`00DWT00005FUH00`00CQI>5P04CQH00`00CQM>5`03CQL20005DSL00`00
EUMFE`04EUL00`00GWMNM`02GWL00`00EUL00006ESL00`00EUMFE`05EUL20005EUL00`00ESMF=`04
ESL01000EUMFE`000eIG00<005YGFUL015YG00D005IGEUMFE`00009JE`03001JEUYF00EJEP03001F
=eHg009F=`03001FE`0000MJE`03001JEeYG009JE`03001JE`0000MJE`05001NMeigGWL00003FWL0
0`00FWIJMP04FWH00`00FUL00005FUL00`00FWMJM`04FWL00`00FWMJM`05FWL01@00GWMNMeig0000
0eig00<005ifGWH01Eif0P001Uig00<005YGFUL00UYG00@005igGWL000INM`03001NU`0000INU`05
001RUf:GHYL00003HYL00`00HYMRU`04HYL00`00HYMRU`06HYL00`00HYMRU`05HYL01000DUQBF000
16:G00<0059HDUP00e9H00@006:GHYL000MBF003001BF59H00=BF003001FoEKm009Fo@800003DUT0
05Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00EFo@04001F
o@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20006
E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@03
00000eKm001oo`02Ool00`00Oomoo`3aOol00?moof9oo`8000Ioo`8000Qoo`8004Uoo`8000ioo`03
001FoEKm00=Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm00AFo@8000IFo@03001FoEKm00AFo@80
00MFo@03001Fo@0000800003CQL004hg00E>=`03001>=dhg00=>=`03001>>4hh00=>>08000MJEP03
001>5ThF00=>5P04001>5dhGCQL200000e8g001B=`04DSL00`00EUMFE`04EUL00`00GWMNM`020003
EUL00`00ESMF=`04ESL00`00EUMFE`03EUL20006EUL00`00ESMF=`04ESL00`00EUL00004EUL00`00
FUMJE`04FUL01000EUMFE`0015YG00<005YFFUH015YF00<005HgESL00P000eIG00<005YGFUL015YG
00D005YGFUMJE`0000=JE`03001JEeYG00AJE`04001NMeig0004FWL00`00FWIJMP05FWH00`00FUMJ
E`04FUL00`00FWMJM`03FWL20007FWL01000GWMNM`0015ig00<005ifGWH015if0P001eig00D005YG
FUMJE`0000=NM`03001NMeig00ENM`03001NUejG00ENU`04001RUf:G0004HYL00`00HYMRU`03HYL0
0`00HYL00007HYL00`00HYMRU`05HYL00`00DUP00006HYL01@00DUQBF59H00000f:G00<0059HDUP0
159H0P001U9H00@005Km000000ABF@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03
001FoEKm00=Fo@8000MFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km
00IFo@03001FoEKm00<00003E_d005Km00EFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm
00AFo@<000EFo@04001oogoo003cOol00?moof5oo`8000Moo`8000Qoo`8004Ioo`<000ioo`8000MF
o@03001Fo@000080009Fo@03001FoEKm00AFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm
00<00003E_d005Km00IFo@8000A>5`03001>=dhg00A>=`03001>=dhg00A>=`03001>>4hh00800003
EUL005YF00IJEP03001>5ThF00A>5P<000=B=`03001B=e8g00AB=`03001FEeIG00AFE`8000EFE`03
001F=eHg00AF=`03001FEeIG009FE`03001FE`0000MFE`03001F=eHg00=F=`8000IFE`03001JEeYG
00AJE`8000EJE`03001JEUYF00EJEP8000EFE`03001JEeYG00AJE`04001JEeYG0004FUL00`00FUMJ
E`05FUL20005FWL00`00FWIJMP04FWH20006FUL00`00FWMJM`02FWL01000FWMJM`001UYg00<005ig
00001Eig00<005ifGWH00eif00<005ig00001eig00@005YGFUL000ANM`03001NMeig00ANM`8000MN
U`03001RU`0000IRU`05001RUf:GHYL00002HYL00`00HYMRU`04HYL00`00HYL00007HYL00`00HYMR
U`05HYL01000DUQBF00016:G00<0059HDUP00e9H00@006:GHYL000IBF003001BFE9I00EBF@03001F
oEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00EFo@03001FoEKm00D000MFo@<0
00EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@04001FoEKmE_d200000eKm001F
o@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d01000Oomo
o`00lWoo003oOomIOol20005Ool30007Ool20008Ool20013Ool3000>Ool300000eKm001Fo@06E_d2
0006E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@02E_d200000dhG
001>5`04CQL00`00CSM>=`04CSL00`00CSM>=`03CSL00`00CSP00004EUL00`00FUIJEP04FUH00`00
CQI>5P03CQH20006DSL00`00DSMB=`03DSL00`00EUMFE`03EUL20006EUL00`00ESMF=`04ESL00`00
EUMFE`020003EUL00`00EUMFE`04EUL00`00ESMF=`02ESL00`00EUL00006EUL00`00FUMJE`03FUL2
0006FUL00`00FUIJEP04FUH20006EUL00`00FUMJE`05FUL20005FUL00`00FUMJE`04FUL20007FWL0
0`00FWIJMP02FWH00`00FUL00007FUL01000FWMJM`000eYg00<005YgFWL01EYg00<005igGWL01Eig
00D005ifGWINMP0000=NM`03001NMeig00ENM`8000INM`03001NMeig009NM`04001NMeig0007GYL0
0`00HYMRU`05HYL01000HYMRU`000f:G00<006:GHYL00f:G00@006:GHYL000MRU`03001RUf:G00ER
U`03001BF00000IRU`05001BF59HDUP00003HYL00`00DUQBF003DUP20008DUT20005E_d00`00E_eF
o@04E_d30005E_d00`00E_eFo@03E_d30003E_d00`00E_d00004E_d200000eKm001Fo@06E_d00`00
E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@05E_d01000E_d0000015Km00<0
05KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d00eKm0`000Woo00<007ooOol0
kgoo003oOomIOol90008Ool20008Ool20011Ool2000>Ool30005E_d00`00E_eFo@02E_d200000eKm
001Fo@06E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_eFo@0300000eKm001Fo@06E_d0
1000E_d000000dhG00<004hGCQL00dhG00<004hgCSL014hg00<004hgCSL00dhg0P001EIG00<005YF
FUH015YF00@004hFCQI>5P800003DSL0058g00EB=`03001B=e8g00AB=`07001FEeIGEUL005Hg0000
1eIG00<005HgESL015Hg0P001EIG00<005IGEUL015IG00<005HgESL00P000eIG00<005IGEUL00eIG
00<005YGFUL00UYG00<005YG00001eYG00<005YFFUH00UYF00<005YG00001eIG00<005YGFUL00eYG
0P001eYG00<005YGFUL00UYG00<005YG00001eYg00D005YfFWIJMP0000=JE`03001JEeYG00AJE`03
001JM`0000EJM`03001JMeYg00AJM`03001NMeig00ENM`04001NMUif0004GWL00`00GWMNM`04GWL2
0007GWL01@00GWMNMeig00000eig00<005jGGYL015jG0P001f:G00<006:G00001F:G00D006:GHYMR
U`0000=RU`03001RUf:G00ARU`03001RU`0000MRU`03001RUf:G00ERU`04001BF59H0005HYL01@00
DUQBF59H00000V:G00<0059IDUT0159I0P001eKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005Km
00000P0000=Fo@00E_d00eKm00D005KmE_d005Km008000AFo@03001FoEKm00AFo@<000EFo@03001F
oEKm00AFo@<000EFo@03001FoEKm00=Fo@8000MFo@03001FoEKm00<00003E_d005Km00IFo@03001F
oEKm00<00003E_d005Km00EFo@03001FoEKm00<0009Fo@04001oogoo003aOol00?mooeUoo`800003
Ool0000000<000Uoo`8000Qoo`8003ioo`<00003Ool007oo00Yoo`<00003E_d005Km00IFo@04001F
o@000004E_d00`00E_eFo@04E_d20006E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@04E_d20006
CQL00`00CQM>5`02CQL00`00CSM>=`04CSL01000CSM>=dhg0P0000=B=`00EUL01EIG00<005YFFUH0
15YF0`000e8g00<0058gDSL0158g00<0058gDSL0158g00@005IGEUL000=F=`03001FEeIG00AFE`03
001F=eHg00=F=`8000IFE`03001FEeIG00EFE`8000EFE`03001FEeIG00AFE`04001JEeYG0003FUL0
0`00FUMJE`04FUL01@00FUIJEUYF00000UYG00<005IGEUL01EIG00<005YGFUL00UYG00<005YG0000
1eYG00D005YGFUMJE`0000=JE`03001JMeYg00AJM`04001JMUYf0004FUL00`00FUMJE`05FUL00`00
FWMJM`04FWL00`00FWMJM`03FWL00`00GWL00006GWL00`00GWH00005GWL00`00GWMNM`03GWL00`00
GWL00007GWL01000GWMNM`0015ig00<005jGGYL00ejG00@005igGWL000MRU`03001RUf:G00ARU`04
001RUf:G0005HYL00`00HYMRU`02HYL01000HYMRU`001V:G0P001f:G00<0059H00001V:G00@0059H
DUP000=RU`03001BFE9I00=BF@04001R^6:h0006E_d30005E_d00`00E_eFo@04E_d20005E_d00`00
E_eFo@02E_d01000E_d000001eKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=F
o@00E_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm0`001EKm00<005KmE_d015Km0`001EKm00<0
05KmE_d00eKm0`001UKm00@007ooOol00?1oo`00ogooFGoo0P0047oo0P001Woo0P00?Goo0P001Goo
00<007ooOol01Goo0`001EKm00<005KmE_d015Km0P001eKm00<005KmE_d00`0000=Fo@00E_d01UKm
00<005Km00000P000UKm00<005KmE_d015Km00<005KmE_d00`0000=>5`00CQL01DhG00<004hGCQL0
0dhG00<004hgCSL014hg0`00158g00<005IGEUL00eIG00<005YFFUH00eYF0P001U8g00<0058gDSL0
158g00<0058gDSL00e8g00<005IG000015Hg00<005IGEUL015IG00@005HgESMF=`800003ESL005IG
00IFE`03001FEeIG00=FE`8000IFE`03001FEeIG00AFE`03001JE`0000AJE`03001JEeYG00AJE`04
001JEUYF0004FUL00`00EUMFE`04EUL00`00FUMJE`020003FUL00`00FUMJE`04FUL01000FUMJE`00
15YG00<005YgFWL01EYg0P001EYG00<005YGFUL015YG0P001UYg00<005YgFWL00UYg00@005igGWL0
00MNM`03001NMeig00ENM`05001NMeigGWL00003GWL00`00GWMNM`05GWL20006GWL01@00GYMNUejG
00000eig00<006:GHYL016:G0P001V:G00<006:G00001V:G00D006:GHYMRU`0000=RU`03001RUf:G
00=RU`04001RUf:G0007HYL00`00HYMRU`05HYL00`00DUP00005HYL01@00DUUBFE9I000016:h00<0
05KmE_d00`0000=B>000E_d01UKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d00`0000=F
o@00E_d01UKm0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d0
0UKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d00`0000=Fo@00
E_d01UKm00D007ooOomoo`000>moo`00ogooFGoo0P0047oo0P001Woo0P00>Woo0`0027oo00@007oo
Oomoo`<0009Fo@03001FoEKm00AFo@03001FoEKm00<00003E_d005Km00IFo@<000EFo@03001FoEKm
00AFo@8000IFo@03001FoEKm00=Fo@<000E>5`03001>5dhG00=>5`03001>5dhG00=>5`03001>=dhg
00=>=`8000IB=`03001FEeIG00=FE`03001JEUYF009JEP03001F=`0000IB=`03001B=e8g00AB=`03
001B=e8g00=B=`8000IF=`03001FEeIG00AFE`<000AF=`03001FEeIG00AFE`03001FEeIG009FE`03
001FE`0000MFE`03001FEeIG00=FE`8000IJE`03001JEeYG00AJE`8000EJE`03001FEeIG00EFE`80
00EJE`03001JEeYG00EJE`8000EJE`03001JMeYg00AJM`8000MJE`03001JEeYG009JE`04001JMeYg
0006FWL01000FWMJM`0015ig00<005igGWL015ig00<005igGWL01Eig00@005igGWL000ANM`03001N
Meig00ANM`8000MNM`04001NUejG0004GWL00`00HYMRU`03HYL01000HYMRU`001V:G00<006:GHYL0
1F:G00@006:GHYL000ERU`05001RUf:GHYL00003HYL00`00HYMRU`04HYL20008HYL00`00HYMRU`04
HYL01000DUUBF@001V:h0P001E8h00<005KmE_d015Km0`001EKm00<005KmE_d00eKm0`0000=Fo@00
E_d00UKm00<005KmE_d00UKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01EKm00<0
05KmE_d00`0000=Fo@00E_d01UKm00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm
00=Fo@<000EFo@03001FoEKm00AFo@80009oo`03001oogoo0>eoo`00ogooFGoo0P004Goo0P0017oo
0P00>Goo0P0037oo0`001UKm00<005KmE_d00eKm0`001EKm00<005KmE_d00UKm0P000UKm00<005Km
E_d015Km00<005KmE_d00`0000=Fo@00E_d01UKm00<005Km00000P0000=>5`00CQL01DhG00<004hG
CQL014hG00<004hGCQL00ThG00@004hgCSM>=`800003DSL0058g00EB=`03001FEeIG00AFE`04001J
EUYF0002ESL00`00DSMB=`04DSL00`00DSMB=`04DSL01000DSMB=e8g0P0000=B=`00ESL01EHg00<0
05IGEUL00eIG0P001UHg00<005IGEUL015IG00<005IGEUL00P000UIG00<005IGEUL01EIG00<005IG
EUL00UIG00<005IG00001UYG00<005YGFUL00eYG0P001UYG00<005IGEUL015IG0P001UYG00<005YG
FUL015YG0P001eYG00<005YgFWL00UYg00<005YG00001eYG00D005YGFUMJE`0000=JM`03001JMeYg
00AJM`03001JM`0000ENM`03001NMeig00=NM`03001NM`0000INM`03001NM`0000ENM`03001NMeig
00=NM`03001NM`0000MNM`03001NU`0000INM`05001RUf:GHYL00003HYL00`00HYMRU`04HYL00`00
HYMRU`06HYL20006HYL01000HYMRU`0016:G00<006:GHYL00f:G00@006:GHYL000MRU`03001RUf:G
00ARU`03001BF@0000MR^003001B>58h00EB>003001FoEKm00<00003DUP005Km00EFo@03001FoEKm
00<00005E_d005KmE_d00004E_d01000E_d0000015Km00<005KmE_d015Km0`001EKm00<005KmE_d0
0eKm0`001EKm00<005KmE_d015Km0P001eKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d0
0`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00Ool00Woo00<007ooOol0k7oo003oOomIOol:
0009Ool8000fOol3000<Ool300000eKm001Fo@06E_d00`00E_d000020002E_d00`00E_eFo@04E_d0
1000E_d000001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d015Km0P0014hG00<004hGCQL014hG
00<004hGCQL014hG00<004hGCQL00dhG0`00158g00<0058gDSL0158g00<005IGEUL00eIG00<005YF
000015Hg00<0058gDSL0158g00<0058gDSL0158g0`00158g00<005HgESL00eHg00<005IGEUL00UIG
00<005Hg00001UHg00<005IGEUL01EIG0P001EIG00<005IGEUL015IG00<005IGEUL00P000UIG00<0
05YGFUL015YG00<005YGFUL00UYG00<005YG00001eYG00<005IGEUL00UIG00<005YG00001eYG00<0
05YGFUL00UYG00<005YG00001eYG00D005YgFWMJM`0000=JE`03001JEeYG00AJE`04001JEeYG0004
FWL00`00FWMJM`04FWL20006GWL00`00GWMNM`02GWL01000GWMNM`001eig00<005igGWL01Eig00D0
05igGWMNM`0000=NM`03001NMeig00ENM`03001NMeig00ENM`04001RUf:G0004HYL00`00HYMRU`03
HYL00`00HYL00007HYL00`00HYMRU`05HYL00`00HYL00006HYL01@00HYMRUf:G00000f:G00<006:G
HYL016:G00<006:G00001V:G00<006:hH[P01F:h00<006Jf00001e8h0P001E9H00<005KmE_d00eKm
0`001EKm00<005Km000015Km0P001eKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d00`00
00=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm0`001EKm00<005KmE_d00eKm0`001EKm
00<005KmE_d015Km0`001EKm00<007oo00000P00kGoo003oOomIOol:000;Ool4000fOol2000<Ool3
0005E_d00`00E_eFo@04E_d20006E_d00`00E_eFo@03E_d20008E_d00`00E_d000020002E_d00`00
E_eFo@04E_d00`00E_eFo@0300000dhG001>5`04CQL00`00CQM>5`04CQL00`00CQM>5`03CQL00`00
CQM>5`02CQL20006DSL00`00DSMB=`04DSL00`00EUMFE`03EUL20005ESL00`00DSMB=`04DSL00`00
DSMB=`03DSL20006DSL00`00ESMF=`04ESL01000EUMFE`000UHg00<005HgESL01EHg00<005IGEUL0
0eIG0P001UIG00<005IGEUL01EIG0P001EIG00<005YGFUL015YG00@005YGFUL000=JE`03001JEeYG
00AJE`05001FEeIGEUL00003FUL00`00FUMJE`04FUL01@00FUMJEeYG00000eYG00<005YGFUL015YG
00@005YgFWL000AJE`03001JEeYG00EJE`8000IJM`03001JMeYg009JM`03001NM`0000MNM`04001N
Meig0003GWL00`00GWMNM`04GWL20007GWL01000GWMNM`0015ig00<005igGWL015ig0P001eig00<0
06:G00001V:G00D006:GHYMRU`00009RU`03001RUf:G00ERU`03001RUf:G00IRU`03001RUf:G00ER
U`04001RUf:G0004HYL00`00HYMRU`03HYL01000HYMRU`001V:G00<006:hH[P016:h00@006JfI[H0
00MB>003001BF59H00ABF003001FoEKm00<00003DWT005Km00IFo@800006E_d00000001Fo@001eKm
0`001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d00UKm0P0000=F
o@00E_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00@0
07ooOol00>eoo`00ogooYGoo0`002goo0`000UKm00<005KmE_d015Km00<005KmE_d00`0000=Fo@00
E_d01UKm00<005Km00000P000UKm00<005KmE_d01EKm0P001UKm00<005KmE_d00eKm0`0014hG00<0
04hGCQL00dhG00<004hGCQL014hG00<004hGCQL014hG100000=>=`00DSL01E8g00<0058gDSL0158g
00@005IGEUMFE`800003DSL005Hg00AF=`03001B=e8g00AB=`04001B=e8gDSL200000e8g001B=`05
DSL00`00ESMF=`04ESL00`00EUL00004ESL00`00ESMF=`04ESL00`00EUMFE`02EUL00`00EUL00006
EUL00`00EUMFE`04EUL20006EUL00`00FUMJE`04FUL00`00FUL00004FUL00`00FUMJE`04FUL01000
EUMFE`0015YG00<005YGFUL015YG00@005YGFUL000AJE`03001JEeYG00EJE`8000EJE`03001JEeYG
00AJE`8000MJM`05001JMeYgFWL00003GWL00`00GWMNM`04GWL00`00GWL00005GWL00`00GWMNM`02
GWL01000GWMNM`001Uig00<005ig00001Eig00<005igGWL00eig00@005igGWL000MNM`03001RUf:G
00ERU`04001RUf:G0004HYL00`00HYMRU`03HYL00`00HYL00007HYL00`00HYMRU`05HYL00`00HYL0
0006HYL01@00HYMRUf:G00000f:G00<006:GHYL00f:G00<006:g000016:h00D006JfI[IV]P0000IB
>003001RU`0000IBF08000EBN@03001FoEKm00AFo@<000EFo@03001FoEKm009Fo@800003E_d005Km
00EFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@00
0004E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20002Ool0
0`00Oomoo`3ZOol00?mooj9oo`<000aoo`8000IFo@03001FoEKm00=Fo@<000EFo@03001FoEKm00AF
o@8000IFo@03001FoEKm009Fo@800003E_d005Km00IFo@03001Fo@0000800003CQL004hG00E>5`03
001>5dhG009>5`03001>5dhG00A>5`03001>5dhG00=>5`8000E>=`03001B=e8g00AB=`03001B=e8g
00AB=`<000=B=`03001F=eHg00AF=`03001B=e8g00AB=`<000AB=`03001B=e8g00AB=`03001F=eHg
00=F=`8000EF=`03001F=eHg00AF=`03001FEeIG0080009FE`03001FEeIG00EFE`03001FEeIG009F
E`03001FE`0000IFE`03001JEeYG00AJE`8000IJE`03001JEeYG00AJE`8000EJE`03001JEeYG00EJ
E`8000EJE`03001JEeYG00AJE`8000MJE`03001JEeYG009JE`03001JEP0000MJM`04001JMeYg0004
GWL00`00GWMNM`05GWL00`00GWMNM`04GWL01@00GWMNMeig00000eig00<005igGWL01Eig00<005ig
GWL01Eig00D005igGWMNM`0000=NM`03001NMeig00ANM`8000MRU`03001RU`0000ERU`03001RUf:G
009RU`04001RUf:G0006HYL00`00HYL00007HYL00`00HYMRU`05HYL01000HYMRU`001F:G00D006:G
HYMRU`00009R]`03001R^6:h009R^003001V]VJf009V]P03001B>58h009B>004001RUf:G0006DUP0
0`00DWUBN@05DWT00`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d00eKm
0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001UKm00<005KmE_d00`0000=Fo@00
E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00Ool00Woo00<007oo
Ool0jGoo003oOonPOol2000=Ool200000eKm001Fo@06E_d00`00E_d000020002E_d00`00E_eFo@04
E_d00`00E_eFo@0300000eKm001Fo@06E_d01000E_d0000015Km00<005KmE_d015Km0P0014hG00<0
04hGCQL014hG00<004hGCQL00dhG00<004hGCQL014hG00<004hG00000P0000=>5`00CSL014hg00<0
058gDSL0158g00<0058gDSL00e8g0P001U8g00<005HgESL00eHg00<0058gDSL00e8g0P001U8g00<0
058gDSL0158g00<005HgESL00UHg00<005Hg00001EHg00<005HgESL01EHg0P001EIG00<005IGEUL0
15IG00D005IGEUMFE`00009FE`03001FEeIG00EFE`03001JEeYG009JE`03001FEP0000IJE`03001J
EeYG00=JE`8000MJE`03001JEeYG00=JE`8000MJE`03001JEeYG009JE`03001JE`0000MJE`05001J
EeYGFUL00003FUH00`00FWMJM`05FWL20005GWL00`00GWMNM`04GWL20006GWL01000GWMNM`0015ig
00<005igGWL015ig0P001eig00@005igGWL000ANM`03001NMeig00=NM`04001NMeig0007HYL00`00
HYMRU`05HYL01000HYMRU`000f:G00<006:GHYL00f:G00@006:GHYL000MRU`03001RUf:G00ERU`03
001RU`0000IRU`04001RUf:G0004H[L01000H[QR^0001FJf00D0058hDSQB>00000=RU`03001BF59H
00=BF003001RU`0000IBN@<000AFo@8000IFo@8000IFo@03001FoEKm00<00003E_d005Km00IFo@03
001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00EFo@<000EFo@03001FoEKm
00AFo@<000EFo@03001FoEKm00AFo@<000EFo@04001oogoo003[Ool00?mooieoo`<000eoo`8000AF
o@03001FoEKm00AFo@8000IFo@03001FoEKm00=Fo@<000EFo@03001FoEKm00AFo@8000MFo@03001F
oEKm00<00003CQL004hG00A>5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5dhG00=>5`<000A>
5`03001>=dhg00=>=`03001B=e8g00AB=`04001B=e8gDSL200000e8g001B=`05DSL00`00ESMF=`03
ESL01000DSMB=e8g0P0000=B=`00DSL01E8g00<0058gDSL0158g00<005HgESL00P000UHg00<005Hg
ESL015Hg00<005HgESL00eHg0P001UIG00<005IGEUL015IG00@005IGEUL000AFE`03001FEeIG00AF
E`05001JEeYGFUL00002EUH00`00FUMJE`04FUL00`00FUMJE`02FUL00`00FUL00007FUL00`00FUMJ
E`02FUL00`00FUL00007FUL01@00FUMJEeYG00000eYG00<005YGFUL015YG00@005YGFUL000AJEP03
001JMeYg00EJM`03001NMeig00ENM`03001NMeig009NM`04001NMeig0006GWL20006GWL00`00GWMN
M`02GWL01000GWMNM`001Uig00<005ig00001Uig00D005igGWMNM`0000=NM`03001RUf:G00ARU`80
00MRU`03001RU`0000ERU`05001RUf:GHYL00003HYL00`00HYMRU`04HYL00`00HYL00007HYL00`00
HYMRU`05HYL00`00HYL00005H[L00`00H[P00006I[H01000DSQB>0001F:G00D0059HDUQBF000009R
U`03001BNE9i00=BN@03001R^00000EFo@03001Fo@00009Fo@<00003E_d005Km00EFo@<000EFo@03
001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@04001FoEKmE_d200000eKm001Fo@06E_d0
0`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@05E_d01@00Oomoogoo0000
jWoo003oOonKOol2000>Ool20007E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_d000020002
E_d00`00E_eFo@04E_d00`00E_eFo@0300000eKm001Fo@06E_d30004CQL00`00CQM>5`03CQL00`00
CQM>5`04CQL00`00CQM>5`02CQL01000CQM>5dhG0P0000=>5`00CQL01DhG00<004hgCSL00dhg00<0
058gDSL0158g0`000e8g00<0058gDSL0158g00<005HgESL015Hg0`000e8g00<0058gDSL01E8g00<0
058gDSL0158g0P001EHg00<005HgESL00eHg00<005HgESL00UHg00<005Hg00001UIG00<005IGEUL0
1EIG0P001EIG00<005IGEUL015IG00@005YGFUL000AFEP03001JEeYG00AJE`04001JEeYG0003FUL0
0`00FUMJE`04FUL00`00FUMJE`020003FUL00`00FUMJE`04FUL01000FUMJE`0015YG00<005YGFUL0
1EYG0P001EYF00<005YgFWL015Yg0P001eig00D005igGWMNM`0000=NM`03001NMeig00ANM`03001N
Meig00ENM`05001NMeigGWL00003GWL00`00GWMNM`05GWL00`00GWMNM`05GWL01000GWMNM`0015ig
00<006:GHYL00f:G00@006:GHYL000MRU`03001RUf:G00ARU`04001RUf:G0005HYL00`00HYMRU`02
HYL01000HYMRU`001V:G0P0026:G00<006:gH[L01F:g00<006JfI[H01VJf0P001V:G00@0059HDUP0
00ARU`05001BNE9iDWT00003H[P00`00E_eFo@02E_d00`00E_d000020005E_d01000E_eFoEKm0P00
00=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01EKm
00@005Km000000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00=F
o@80009oo`03001oogoo0>Qoo`00ogooV7oo0`003Goo0`000UKm00<005KmE_d015Km0`001EKm00<0
05KmE_d015Km0P001UKm00<005KmE_d00eKm0`001EKm00<005KmE_d00UKm0P0000=>5`00CQL01DhG
00<004hGCQL00ThG00<004hGCQL014hG00<004hGCQL00dhG0`000dhG00<004hGCQL014hG00<004hg
CSL00dhg00<0058gDSL00e8g0P001U8g00<0058gDSL0158g00<005HgESL00UHg0P001U8g00<0058g
DSL0158g00<0058gDSL00e8g0P001UHg00<005HgESL00eHg00<005HgESL00P000UHg00<005IGEUL0
1EIG00<005IGEUL00eIG0P001UIG00<005IGEUL01EIG0P001EIF00<005YGFUL015YG00<005YG0000
15YG00<005YGFUL01EYG0P001EYG00<005YGFUL01EYG0P001EYG00<005YGFUL015YG0P001eYF00<0
05YgFWL00UYg00@005YfFWH000INM`04001NMeig0004GWL00`00GWMNM`04GWL00`00GWMNM`05GWL0
1000GWMNM`0015ig00<005igGWL015ig0P001eig00<005ig00001Uig00D006:GHYMRU`0000=RU`03
001RUf:G00ARU`8000IRU`03001RU`0000IRU`05001RUf:GHYL00003HYL00`00HYMRU`03HYL01000
HYMRU`001V:G0P001f:g00<006JfI[H01VJf00<006:GHYL01F:G00<0059H00001F:G00@0059iDWT0
00ER^003001FoEKm00<00003DUP005Km00IFo@03001Fo@0000AFo@03001FoEKm00AFo@<000EFo@03
001FoEKm00AFo@<000EFo@03001FoEKm00=Fo@8000MFo@03001FoEKm00<00003E_d005Km00IFo@03
001FoEKm00<00003E_d005Km00EFo@03001FoEKm00<00003E_d007oo009oo`03001oogoo0>Moo`00
ogooUWoo0P003Woo0P001UKm00@005KmE_eFo@80009Fo@03001FoEKm00AFo@03001FoEKm00<00003
E_d005Km00IFo@03001Fo@000080009Fo@03001FoEKm00AFo@04001Fo@000003CQL00`00CQM>5`04
CQL00`00CQM>5`03CQL00`00CQM>5`03CQL00`00CQM>5`02CQL20006CQL00`00CQM>5`03CQL00`00
CSM>=`03CSL01000DSMB=e8g0P0000=B=`00DSL01E8g00<0058gDSL0158g00L005HgESMF=`00DSL0
0006DSL00`00DSMB=`04DSL01000DSMB=e8g0P0000=F=`00ESL01EHg00<005HgESL015Hg0P001EHg
00<005IGEUL015IG00<005IGEUL00UIG00<005IG00001eIG00<005IGEUL00eIG0P001UIF00<005YG
FUL015YG0P001EYG00<005YGFUL015YG0P001UYG00<005YGFUL015YG0P001eYG00<005YGFUL00UYG
00<005YF00001eYF00D005YgFWMJM`0000=JMP03001NMeig00ENM`8000INM`03001NMeig009NM`03
001NMP0000MNM`8000INM`03001NMeig009NM`04001NMeig0007GWL00`00GWMNM`05GWL01000HYMR
U`0016:G00<006:GHYL00f:G00@006:GHYL000IRU`03001RUf:G00ERU`04001RUf:G0005HYL01@00
HYMRUf:G00000f:G00<006:GHYL00f:G00@006:GHYL000ER]`03001V]`0000MV]P03001RUf:G00IR
U`03001RUf:G00ARU`03001BN@0000MR^0800003DUP0059H009BF003001FoEKm00AFo@8000IFo@03
001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00EFo@03001FoEKm00<00003
E_d005Km00IFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00=Fo@<000EFo@05001oogoo
Ool0003XOol00?mooi=oo`<000eoo`<00003E_d005Km00IFo@03001Fo@0000EFo@03001FoEKm00=F
o@<000EFo@03001FoEKm00AFo@8000IFo@03001FoEKm00=Fo@8000I>5`03001>5dhG00=>5`03001>
5dhG00=>5`03001>5dhG00A>5`@00003CQL004hG00E>5`03001>5dhG00A>5`03001>=dhg00=>=`<0
00=B=`03001B=e8g00AB=`03001B=e8g00AB=`04001F=eHg0003DSL00`00DSMB=`03DSL00`00DSMB
=`05DSL30003ESL00`00ESMF=`05ESL00`00ESMF=`02ESL20006ESL00`00EUMFE`04EUL00`00EUMF
E`020003EUL00`00EUMFE`04EUL00`00EUMFE`02EUL00`00EUH00007EUH00`00FUMJE`02FUL00`00
FUH00006FUL00`00FUMJE`02FUL00`00FUH00007FUL00`00FUMJE`02FUL00`00FUH00007FUL01@00
FUMJEeYG00000eYF00<005YFFUH015YF00@005YgFWL000AJMP03001NMeig00ANM`8000MNM`05001N
MeigGWL00002GWH00`00GWMNM`05GWL00`00GWMNM`05GWL01@00GWMNMeig00000eig00<005igGWL0
15ig0P001eig00<006:G00001V:G00D006:GHYMRU`0000=RU`03001RUf:G00ARU`03001RUf:G00IR
U`8000IRU`04001RUf:G0005HYL01@00HYMRUf:G00000f:G00<006:gH[L00V:g00@006JgI[L000IV
]P03001VU`0000IRU`8000MRU`03001R^6:h00IR^004001BF59H0004DUP00`00E_eFo@0300000eKm
001Fo@05E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@02
E_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@05E_d00`00E_eFo@0300000eKm001F
o@06E_d01000Oomoo`00j7oo003oOonAOol2000=Ool30005E_d00`00E_eFo@04E_d20007E_d00`00
E_d000020002E_d00`00E_eFo@04E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_d000020000
0dhG001>5`05CQL00`00CQM>5`04CQL00`00CQM>5`02CQL00`00CQM>5`03CQL20005CQL00`00CQM>
5`03CQL00`00CQM>5`04CQL00`00CSM>=`02CSL20006DSL00`00DSMB=`04DSL00`00DSMB=`04DSL2
0004DSL00`00DSMB=`04DSL00`00DSMB=`03DSL20006ESL00`00ESMF=`04ESL01`00ESMF=eHg001F
=`0000IF=`03001FEeIG00EFE`8000EFE`03001FEeIG00AFE`03001FEeIG008000=FEP03001FEUIF
00AFEP05001JEeYGFUL00002FUH00`00FUMJE`04FUL01@00FUMJEeYG00000UYF00<005YGFUL01EYG
00D005YGFUMJE`0000=JEP03001JEeYG00AJE`04001JEeYG0004FUH00`00FUIJEP05FUH20006FWH0
0`00GWMNM`02GWL00`00GWH00007GWL01000GWMNM`0015if00<005igGWL015ig00<005igGWL01Eig
00@005igGWL000ANM`03001NMeig00=NM`04001NMeig0007GWL00`00HYMRU`05HYL01000HYMRU`00
16:G00<006:GHYL00f:G00<006:G00001f:G00<006:GHYL01F:G00<006:G00001V:G00@006:GHYL0
00ERU`04001R]f:g0003I[L00`00I[IV]P03I[H01000IYMVU`001F:G00@006:GHYL000IRU`03001R
^6:h00ER^005001V]`00DUP00004DUP30005E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eF
o@0300000eKm001Fo@06E_d00`00E_d0000200000eKm001Fo@06E_d01000E_d0000015Km00<005Km
E_d015Km0`001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d015Km0P000Woo00<007ooOol0iGoo
003oOon>Ool3000<Ool30002E_d00`00E_eFo@04E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d2
0006E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@04E_d20005CQL00`00CQM>5`03CQL00`00CQM>
5`04CQL00`00CQM>5`03CQL00`00CQL0000200000dhG001>5`04CQL00`00CQM>5`04CQL00`00CQM>
5`03CQL00`00CSM>=`0200000e8g001B=`05DSL00`00DSMB=`04DSL00`00DSMB=`03DSL20005DSL0
0`00DSMB=`04DSL00`00DSMB=`02DSL00`00DSL00006ESL00`00ESMF=`04ESL01000ESMF=`000eHg
00<005HgESL015Hg00<005IGEUL00eIG0P001UIG00<005IGEUL01EIG0P001EIF00<005IFEUH015IF
00@005YGFUL000AJEP03001JEeYG00=JE`04001JEeYG0004FUH00`00FUMJE`04FUL01000FUMJE`00
15YF00<005YGFUL01EYG0P001EYF00<005YFFUH015YF0P001eYf00D005igGWMNM`0000=NMP03001N
Meig00ENM`8000ENMP03001NMeig00=NM`03001NMP0000MNM`8000INM`05001NMeigGWL00003GWL0
0`00GWMNM`05GWL00`00HYMRU`05HYL00`00HYL00006HYL01@00HYMRUf:G00000V:G00<006:GHYL0
1F:G00<006:GHYL01V:G00<006:GHYL01F:G00<006:G00001V:G00@006:gH[L000AV]`05001V]VJf
I[H00004IYL01@00HYMRUf:G00000f:G00<006:GHYL00f:G00<006:g00001F:h00H006JgI[L0059H
0003DUP00`00H[P00006E_d30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d20005E_d0
0`00E_eFo@04E_d20007E_d00`00E_eFo@0300000eKm001Fo@05E_d00`00E_eFo@0300000eKm001F
o@06E_d00`00E_eFo@030002E_d01000Oomoo`00iWoo003oOon;Ool3000=Ool20006E_d00`00E_eF
o@03E_d30006E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_d000020002E_d00`00E_eFo@04
E_d00`00E_eFo@0300000dhG001>5`04CQL00`00CQM>5`04CQL00`00CQM>5`03CQL00`00CQM>5`02
CQL30004CQL00`00CQM>5`04CQL00`00CQM>5`03CQL00`00CQM>5`04CQL20004DSL00`00DSMB=`03
DSL00`00DSMB=`04DSL01000DSMB=e8g0P0000=B=`00DSL01E8g00<0058gDSL00e8g00<0058gDSL0
0P000U8g00<005HgESL015Hg00<005HgESL01EHg0P0015Hg00<005HgESL015Hg00<005IGEUL00UIG
00<005Hg00001eIG00<005IGEUL00eIG0P001UIF00<005IFEUH01EIF0P001EYF00<005YGFUL015YG
0P001EYF00<005YGFUL01EYG0P001EYF00<005YGFUL015YG0P001eYF00<005YFFUH00UYF00<005YF
00001eYf00@005igGWL000ANMP03001NMeig00ENM`03001NMUif00ANMP03001NMeig009NM`04001N
MUif0007GWL00`00GWMNM`05GWL01000GWMNM`0015ig00<005igGWL015ig00<005ig00001f:G00<0
06:GHYL01F:G00@006:GHYL000ARU`03001RUf:G00=RU`03001RU`0000MRU`03001RUf:G00IRU`03
001RUf:G00ERU`03001R]`0000EV]`04001V]VJf0005IYL01000HYMRU`001F:G00D006:GHYMRU`00
009R]`03001R^6:h009R^003001V]fJg009V]`80009BF005001R^6:hH[P00003E_d200000e9H001F
o@06E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@05E_d00`00E_eF
o@030002E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@04E_d30006
E_d00`00Ool0003VOol00?moohUoo`8000eoo`<00003E_d005Km00IFo@03001Fo@000080009Fo@03
001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000IFo@03001FoEKm00=Fo@<000A>5`03001>5dhG
00A>5`03001>5dhG00=>5`03001>5dhG00A>5`@00003CQL004hG00E>5`03001>5dhG00=>5`03001>
5dhG00=>5`03001>5dhG00=>5`8000EB=`03001B=e8g00AB=`03001B=e8g00AB=`<000AB=`03001B
=e8g00=B=`03001B=e8g00AB=`8000EB=`03001F=eHg00AF=`03001F=eHg00=F=`8000EF=`03001F
=eHg00AF=`03001FEeIG008000=F=`03001FEeIG00AFE`03001FEeIG009FE`03001FEP0000MFEP03
001FEUIF00=FEP8000IJEP03001JEeYG00AJE`03001JEUYF00AJEP03001JEeYG00AJE`8000MJEP03
001JEeYG009JE`03001JEP0000MJEP05001JEUYFFUH00003FUH00`00FWIJMP05FWH20005GWH00`00
GWMNM`04GWL20007GWH01000GWMNM`0015if00<005igGWL015ig00<005igGWL01Eig00<005ig0000
1Uig00<005igGWL00Uig00@005igGWL000MRU`03001RUf:G00ERU`03001RU`0000ERU`03001RUf:G
009RU`04001RUf:G0006HYL00`00HYL00007HYL00`00HYMRU`06HYL00`00I[MV]`04I[L00`00I[H0
0006IYL00`00HYL00006HYL01000HYMRU`0016:g00@006:hH[P000EV]`04001BF0000004H[P01000
E_d00000159H00<005KmE_d015Km0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d00eKm0`00
1UKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d0
0`0000=Fo@00E_d01UKm0P0000=oo`00Ool0i7oo003oOon6Ool3000<Ool30005E_d00`00E_eFo@04
E_d20006E_d01000E_eFoEKm0P000UKm00<005KmE_d015Km00<005KmE_d00`0000=Fo@00E_d01UKm
00<005Km00000P0000=>5`00CQL01DhG00<004hGCQL00dhG00<004hGCQL00dhG00<004hGCQL00dhG
0P0014hG00<004hGCQL014hG00<004hGCQL00dhG00<004hGCQL014hG00<004hG00000P0000=>5`00
DSL0158g00<0058gDSL0158g00<0058gDSL00e8g0P001U8g00<0058gDSL0158g00<0058gDSL00U8g
0P001U8g00<005HgESL015Hg00<005HgESL00UHg00<005Hg00001UHg00<005HgESL015Hg0P001EHg
00<005IGEUL015IG00<005IGEUL00P000UIF00<005IFEUH01EIF00<005IFEUH00UIF00<005IF0000
1eYF00<005YGFUL00UYG0P001eYF00<005YGFUL00UYG00<005YF00001eYF00D005YGFUMJE`0000=J
EP03001JEUYF00AJEP04001JEUYF0004FUH00`00FWIJMP05FWH00`00GWINMP05GWH00`00GWMNM`02
GWL01000GWINMP001Uif00<005ig00001Eif00<005igGWL00eig00<005if00001eig00<005igGWL0
1Eig00D005igGWMNM`0000=NM`03001RUf:G00ARU`03001RU`0000MRU`03001RUf:G00ERU`04001R
Uf:G0003HYL00`00HYMRU`03HYL01000HYMRU`001V:G00<006:G00001f:G00<006JgI[L01FJg00<0
06JGIYL01VJG00<006:GHYL01F:G00<006:G00001F:g00<006:h00001VJg00<0059H00001V:h00<0
059HDUP01E9H00<005KmE_d00`0000=BN@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01EKm00<0
05KmE_d00`0000=Fo@00E_d01UKm0`001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d015Km0`00
1EKm00<005KmE_d00UKm0P0000EFo@00Oomoo`000>Aoo`00ogooQ7oo0P0037oo0`000UKm00<005Km
E_d015Km00<005KmE_d00`0000=Fo@00E_d01UKm00<005Km00001EKm00<005KmE_d00eKm0`001EKm
00<005KmE_d015Km0P0014hG00<004hGCQL014hG00<004hGCQL00dhG00<004hGCQL014hG00<004hG
00000P0000=>5`00CQL014hG00<004hGCQL00dhG00<004hGCQL014hG00<004hGCQL00ThG0`001DhG
00<0058gDSL00e8g00<0058gDSL00e8g00@0058gDSMB=`800003DSL0058g00EB=`03001B=e8g00AB
=`03001B=e8g00800003DSL0058g00EB=`03001F=eHg00AF=`03001F=eHg0080009F=`03001F=eHg
00AF=`03001F=eHg00=F=`8000IF=`03001FEeIG00EFE`8000EFEP03001FEUIF00AFEP03001FEUIF
008000=FEP03001JEUYF00AJEP05001JEeYGFUL00002FUH00`00FUIJEP04FUH01@00FUMJEeYG0000
0eYF00<005YFFUH015YF00@005YGFUL000AJEP03001JEUYF00EJEP8000EJEP03001JMUYf00AJMP80
00MNMP05001NMeigGWL00003GWH00`00GWINMP05GWH00`00GWINMP04GWH00`00GWMNM`02GWL01000
GWINMP001eig00<005igGWL01Eig00@005igGWL000ENM`03001RUf:G009RU`04001RUf:G0007HYL0
0`00HYMRU`05HYL00`00HYL00005HYL01@00HYMRUf:G00000f:G00<006:GHYL00f:G00@006:GHYL0
00IRU`03001RU`0000IV]`03001VUfJG00IVU`03001RUf:G00IRU`03001R]f:g00ER]`03001V]fJg
00IV]`8000IR^003001BF59H00IBF08000EBN@03001FoEKm00AFo@<000EFo@03001FoEKm00=Fo@<0
00EFo@03001FoEKm009Fo@800003E_d005Km00EFo@03001FoEKm00<00003E_d005Km00IFo@03001F
oEKm00<00003E_d005Km00IFo@04001Fo@000004E_d00`00Ool0003TOol00?mooh5oo`<000aoo`80
00IFo@03001FoEKm00=Fo@<000EFo@03001FoEKm00AFo@8000MFo@03001Fo@000080009Fo@03001F
oEKm00AFo@03001FoEKm00<00003CQL004hG00A>5`03001>5dhG00=>5`03001>5dhG00A>5`03001>
5dhG009>5`<000A>5`03001>5dhG00=>5`03001>5dhG00A>5`03001>5dhG00=>5`03001>5`000080
0003CQL004hG00E>5`03001B=e8g00=B=`03001B=e8g00AB=`<000AB=`03001B=e8g00AB=`03001B
=e8g00=B=`03001B=`0000=B=`03001B=e8g00EB=`03001F=eHg00AF=`8000EF=`03001F=eHg00AF
=`07001F=eHgESL005Hg00001eHg00<005IGEUL00eIG0P001UIF00<005IFEUH01EIF0P001EIF00<0
05YFFUH015YF00@005YGFUL000=JEP03001JEUYF00AJEP04001JEeYG0004FUH00`00FUIJEP05FUH2
0005FUH00`00FUIJEP04FUH20007FUH00`00FWIJMP02FWH01000GWINMP001Uif00@005igGWL000AN
MP03001NMUif00ANMP8000MNMP04001NMeig0003GWH00`00GWMNM`04GWL00`00GWH00007GWL20006
GWL01@00HYMRUf:G00000f:G00<006:GHYL016:G00<006:G00001f:G00<006:GHYL016:G00@006:G
HYL000ERU`05001RUf:GHYL00003HYL00`00HYMRU`03HYL01000HYMRU`001FJg00<006:G00001VJG
00<006:G00001f:G00<006:gH[L01F:g00<006JgI[L01VJg0P001F:h00<006Zf00001e9H00<0059i
DWT01E9i00<005KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm00@005Km
000000AFo@03001FoEKm00=Fo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000IF
o@04001oogoo003SOol00?moogmoo`<000]oo`<00003E_d005Km00IFo@03001Fo@000080009Fo@03
001FoEKm00AFo@03001FoEKm00<00003E_d005Km00IFo@8000IFo@03001FoEKm00=Fo@<000A>5`03
001>5dhG00=>5`03001>5dhG00A>5`03001>5dhG00=>5`03001>5`0000800003CQL004hG00E>5`03
001>5dhG009>5`03001>5dhG00A>5`03001>5dhG00=>5`8000A>5`03001>5dhG00A>5`03001B=e8g
00AB=`03001B=e8g009B=`8000IB=`03001B=e8g00AB=`03001B=e8g00=B=`8000EB=`03001B=e8g
00AB=`03001F=eHg00=F=`8000IF=`03001F=eHg00AF=`04001F=eHg0003ESL00`00ESMF=`04ESL0
0`00EUMFE`02EUL00`00ESH00006EUH00`00EUIFEP04EUH20006EUH00`00FUIJEP05FUH20004FUH0
0`00FUIJEP05FUH20005FUH00`00FUIJEP04FUH20007FUH00`00FUIJEP02FUH00`00FUH00007FUH0
1@00FWIJMUYf00000eif00<005ifGWH01Eif0P001Uif00<005ifGWH00Uif00@005ifGWH000INMP03
001NM`0000ENMP03001NMeig009NM`04001NMUif0007GWL00`00GWMNM`05GWL01000HYMRU`001F:G
00<006:GHYL00V:G00@006:GHYL000IRU`8000IRU`03001RU`0000IRU`04001RUf:G0005HYL01@00
HYMRUf:G00000f:G00<006JgI[L00VJg00@006:GHYL000EVU`04001RUf:G0006HYL00`00H[L00005
H[L00`00I[L00006I[L00`00I[L00004H[P01000J[IZ]P001U9H00<006:g00001e9i0P001EKm00<0
05KmE_d00eKm0`001EKm00<005KmE_d015Km0P001UKm00<005KmE_d00`0000=Fo@00E_d01UKm00<0
05KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01EKm0P000Woo00<007ooOol0
h7oo003oOomlOol30003Ool00`00Oomoo`05Ool30005E_d00`00E_eFo@04E_d20006E_d00`00E_eF
o@03E_d30005E_d00`00E_eFo@02E_d200000eKm001Fo@06E_d00`00E_d0000200000dhG001>5`05
CQL00`00CQM>5`02CQL00`00CQM>5`04CQL00`00CQM>5`03CQL20004CQL00`00CQM>5`04CQL00`00
CQM>5`03CQL00`00CQM>5`03CQL01000CQM>5dhG0P0000=>5`00CQL014hG00<004hGCQL014hG00<0
058gDSL00e8g00<0058gDSL00P0000=B=`00DSL01E8g00<0058gDSL0158g00@0058gDSMB=`800003
DSL0058g00AB=`03001B=e8g00AB=`04001F=eHgESL200000eHg001F=`05ESL00`00ESMF=`04ESL0
0`00ESL00004ESL00`00ESMF=`04ESL00`00EUMFE`020002ESH00`00EUIFEP05EUH00`00EUIFEP02
EUH00`00EUH00007EUH00`00FUIJEP03FUH20006FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00007FUH01@00FUIJEUYF00000eYF00<005YFFUH015YF00@005YfFWH000AN
MP03001NMUif00ANMP8000MNMP05001NMUifGWH00003GWH00`00GWINMP05GWH00`00GWINMP04GWH0
1@00GWMNMeig00000eif00<005igGWL015ig0P0025ig0P001V:G00D006:GHYMRU`0000=RU`03001R
Uf:G00=RU`04001RUf:G0006HYL00`00HYMRU`05HYL00`00HYL00006HYL01000HYMRU`001F:G00@0
06JgI[L000ARU`05001VUfJGIYL00003HYL00`00HYMRU`03HYL01000H[MR]`0016:g00@006JgI[L0
00EV]`04001V]fJg0004H[P01000J[IZ]P001E9H00@006:gH[L000IBN@8000IFo@03001FoEKm00<0
0003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00EFo@<000EFo@03001FoEKm00AFo@<000EF
o@03001FoEKm00AFo@<000EFo@04001FoEKmE_d200001EKm001oogoo0000hWoo003oOomjOol20007
Ool00`00Oomoo`02Ool20002E_d00`00E_eFo@04E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00
E_d000020002E_d00`00E_eFo@04E_d01000E_d0000015Km00<005KmE_d015Km0P0014hG00<004hG
CQL014hG00<004hGCQL00dhG00<004hGCQL00dhG00@004hGCQM>5`800003CQL004hG00A>5`03001>
5dhG00=>5`03001>5dhG00=>5`03001>5dhG00A>5`<000=>5`03001>5dhG00=>5`03001>5dhG00A>
5`03001B=e8g00=B=`03001B=`0000AB=`03001B=e8g00AB=`03001B=e8g00AB=`<000=B=`03001B
=e8g00=B=`03001B=e8g00EB=`<000AF=`03001F=eHg00AF=`03001F=eHg00=F=`8000EF=`03001F
=eHg00EF=`8000EF=P03001FEUIF00AFEP05001FEUIFEUH00002EUH00`00EUIFEP05EUH00`00FUIJ
EP02FUH00`00FUH00006FUH00`00FUIJEP03FUH20007FUH01@00FUIJEUYF00000eYF00<005YFFUH0
15YF00@005YFFUH000AJEP03001JEUYF00EJEP8000INMP03001NMUif009NMP03001NMP0000MNMP04
001NMUif0004GWH00`00GWINMP04GWH20006GWH01000GWMNM`001Eif00<005igGWL00Uig00@005if
GWH000MNM`03001RUf:G00ERU`04001RUf:G0005HYL01@00HYMRUf:G00000f:G00<006:GHYL016:G
00<006:GHYL01V:G00<006:GHYL01F:G00<006:G00001V:G00@006JgI[L000ARU`04001VUfJG0005
HYL01@00HYMRUf:G000016:g00@006:gH[L000AV]`05001V]fJgI[L00003I[L20002H[P00`00J[IZ
]P02J[H01@00DUQBF59H00000f:g00<0059iDWT00e9i00@006;HH]P000EFo@<000EFo@03001FoEKm
00AFo@<000EFo@04001FoEKmE_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@06E_d0
0`00E_eFo@0300000eKm001Fo@05E_d01000E_d0000015Km00@007ooOol00>5oo`00ogooMgoo0`00
2Woo00@007ooOol000EFo@03001FoEKm00=Fo@<000EFo@03001FoEKm00AFo@8000IFo@03001FoEKm
00=Fo@<000IFo@03001FoEKm00<00003CSL004hG00A>5`03001>5dhG00=>5`03001>5dhG00=>5`03
001>5dhG00A>5`<000=>5`03001>5dhG00=>5`03001>5dhG00A>5`03001>5dhG009>5`03001>5dhG
00=>5`8000I>5`03001>5dhG009>5`03001>5dhG00A>5`03001B=e8g00=B=`8000EB=`03001B=e8g
00AB=`03001B=e8g00=B=`8000IB=`03001B=e8g00=B=`03001B=e8g00=B=`8000IF=`03001F=eHg
00AF=`03001F=eHg009F=`03001F=`0000IF=`03001F=eHg00AF=`03001F=UHf00AF=P03001FEUIF
00AFEP04001FEUIF0004EUH00`00EUIFEP04EUH00`00FUIJEP020003FUH00`00FUIJEP04FUH01@00
FUIJEUYF00000UYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00EJEP8000EJEP03001J
EUYF00AJEP8000MNMP05001NMUifGWH00003GWH00`00GWINMP05GWH20006GWH00`00GWINMP02GWH0
1000GWINMP001Uif0P001Uif00D005igGWMNM`0000=NMP03001NMeig00ANM`8000QRU`8000IRU`04
001RUf:G0004HYL00`00HYMRU`03HYL00`00HYL00006HYL20008HYL00`00HYMRU`05HYL00`00I[L0
0005HYL00`00IYL00006HYL01000HYMRU`001F:g00@006:gH[L000AV]`04001V]fJg0004I[L20002
H[P00`00J[IZ]P02J[H01000DUQBF0001F:g00D0059iDWUBN@0000=Rf003001FoEKm00<00003DWT0
05Km00IFo@03001FoEKm00<00003E_d005Km00IFo@03001Fo@0000AFo@03001FoEKm00AFo@<000EF
o@03001FoEKm00AFo@<000EFo@03001FoEKm00=Fo@8000MFo@04001oogoo003POol00?moogAoo`<0
00ioo`8000MFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001FoEKm00<00003E_d005Km00IF
o@03001Fo@00008000=Fo@03001FoEKm00=Fo@<000A>=`03001>5dhG00=>5`03001>5dhG00A>5`03
001>5dhG009>5`03001>5dhG00=>5`8000I>5`03001>5dhG009>5`03001>5dhG00A>5`03001>5dhG
00=>5`03001>5`0000800003CQL004hG00E>5`03001>5dhG00=>5`03001>5dhG00A>5`03001B=`00
00800003DSL0058g00AB=`03001B=e8g00AB=`04001B=e8gDSL200000e8g001B=`05DSL00`00DSMB
=`03DSL00`00DSMB=`02DSL00`00DSL00006ESL00`00ESMF=`04ESL00`00ESMF=`020003ESL00`00
ESMF=`03ESL00`00ESMF=`03ESL20006ESH00`00EUIFEP05EUH20005EUH00`00EUIFEP05EUH20005
FUH00`00FUIJEP04FUH01000FUIJEP000eYF00<005YFFUH01EYF0P001EYF00<005YFFUH015YF0P00
1eYF00<005YFFUH00UYF00<005YF00001eif00@005ifGWH000ANMP03001NMUif00ENMP03001NMUif
00ENMP05001NMUifGWH00003GWH00`00GWINMP04GWH00`00GWINMP05GWH01000GWMNM`0015if00<0
05igGWL00eig00@0069fHWH000MRU`03001RUf:G00ERU`03001RU`0000IRU`05001RUf:GHYL00002
HYL00`00HYMRU`03HYL01000HYMRU`001f:G00<006:GHYL01V:G00<006:GHYL01F:G00<006:GHYL0
1F:G00<006:G00001V:g00<006:g00001FJg00<006Jg00001FJg0P0000=R^000J[H016Zf00<0059H
00001V:g00@0059iDWT000ERf08000EBN@03001FoEKm00AFo@<000EFo@03001FoEKm00AFo@8000IF
o@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00EFo@03001FoEKm00<0
009Fo@03001FoEKm00AFo@800003Ool007oo0=moo`00ogooLWoo0P003Woo0`0000=Fo@0000001UKm
0P001UKm00<005KmE_d00eKm0`001EKm00<005KmE_d015Km0P001eKm00<005Km00000P0000=>=`00
CSL01Dhg00<004hGCQL00ThG00<004hGCQL014hG00<004hGCQL00dhG00<004hG00000P0000=>5`00
CQL01DhG00<004hGCQL00dhG00<004hGCQL00dhG00<004hGCQL00ThG0`0014hG00<004hGCQL014hG
00<004hGCQL00dhG00<004hGCQL00dhG0`001E8g00<0058gDSL00e8g00<0058gDSL0158g0`000e8g
00<0058gDSL0158g00<0058gDSL00e8g00<0058gDSL00P000U8g00<005HgESL01EHg00<005HgESL0
15Hg0P001EHg00<005HgESL015Hg00L005HgESMF=`00ESH00007ESH00`00EUIFEP03EUH20006EUH0
0`00EUIFEP04EUH20006FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00007FUH01@00FUIJEUYF00000eYF00<005ifGWH01Eif0P00
1Eif00<005ifGWH015if0P001eif00@005ifGWH000ANMP03001NMUif00ANMP03001NMUif00INMP80
00INMP05001NMeigGWL00003HWH00`00HYMRU`04HYL20008HYL00`00HYMRU`05HYL01000HYMRU`00
16:G00D006:GHYMRU`0000=RU`03001RUf:G00ARU`03001RU`0000IRU`8000MRU`03001RUf:G00IR
U`03001R]f:g00IR]`03001V]fJg00EV]`03001V]fJg00AV]`03001V]`0000MZ]P03001R]f:g00ER
]`03001BN@0000IRf003001BNE9i00EBN@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<0
0003E_d005Km00EFo@<000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00=Fo@<000IFo@03001F
oEKm00<00005E_d007ooOol0000MOol6000>Ool4002ZOol00?moofmoo`<000eoo`<000IFo@03001F
oEKm00<00003E_d005Km00IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001FoEKm00<00003
E_d005Km00IFo@8000A>=`03001>=dhg00A>=`03001>5dhG00=>5`03001>5dhG00=>5`03001>5dhG
009>5`<000E>5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5dhG00A>5`@00003CQL004hG00E>
5`03001>5dhG00A>5`03001>5dhG009>5`04001>5dhGCQL200000dhG001B=`05DSL00`00DSMB=`03
DSL00`00DSMB=`03DSL20006DSL00`00DSMB=`04DSL00`00DSMB=`03DSL20005DSL00`00ESMF=`04
ESL00`00ESMF=`03ESL20006ESL00`00ESMF=`04ESL01000ESMF=`000eHf00<005HfESH015Hf00<0
05IFEUH00UIF00<005IF00001eIF00<005IFEUH00UIF00<005YF00001eYF00<005YFFUH00eYF0P00
1UYF00<005YFFUH00eYF0P001eYF00D005YFFUIJEP00009JEP03001JEUYF00EJEP04001JEUYF0004
FUH00`00GWINMP05GWH00`00GWINMP05GWH00`00GWINMP02GWH01000GWINMP001eif0P001Uif00<0
05ifGWH00Uif00<005if00001eif00<005ifGWH01Eif00@005igGWL000ARMP03001RUf:G00=RU`04
001RUV:F0007HYL00`00HYMRU`05HYL00`00HYL00005HYL01000HYMRU`0016:G00<006:GHYL00f:G
00@006:GHYL000ERU`04001RUf:G0005HYL00`00HYL00007HYL00`00H[MR]`06H[L00`00I[MV]`05
I[L00`00I[MV]`04I[L00`00I[L00007J[H00`00H[MR]`06H[L00`00H]QRf004H]P00`00I]L00006
DWT30005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@03
00000eKm001Fo@05E_d00`00E_eFo@0300000eKm001Fo@06E_d30005E_d01000Oomoo`006Woo2P00
2Woo2000Z7oo003oOom]Ool2000=Ool30002E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@04E_d2
0006E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@02E_d200000dhh001>=`04CSL00`00CSM>=`03
CSL00`00CQM>5`03CQL00`00CQM>5`04CQL400000dhG001>5`05CQL00`00CQM>5`04CQL00`00CQM>
5`02CQL00`00CQM>5`03CQL20004CQL00`00CQM>5`04CQL00`00CQM>5`04CQL00`00CQM>5`03CQL3
0003CQL00`00DSMB=`04DSL00`00DSMB=`03DSL01000DSMB=e8g0P0000=B=`00DSL01E8g00<0058g
DSL0158g00<0058gDSL00U8g0P001U8g00<005HgESL015Hg00@005HgESMF=`800003ESL005Hg00IF
=`03001F=eHg00=F=`03001F=`0000AF=P03001F=UHf00AF=P03001FEUIF008000=FEP03001FEUIF
00AFEP05001FEUIFEUH00002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00
FUIJEP02FUH01000FUIJEP001UYF00@005YFFUH000AJEP03001JEUYF00EJEP8000EJEP03001NMUif
00ANMP8000MNMP05001NMUifGWH00003GWH00`00GWINMP05GWH00`00GWINMP05GWH01@00GWINMUif
00000Uif00<005ifGWH01Eif00<005ifGWH01Eif00<005ig00001V9f00D006:GHYMRU`0000=RUP03
001RUf:G00ARU`03001RU`0000MRU`03001RUf:G00ARU`03001RU`0000IRU`05001RUf:GHYL00004
HYL01@00HYMRUf:G00000f:G00<006:GHYL00V:G00@006:GHYL000IRU`03001R]`0000IR]`03001V
]`0000EV]`03001V]`0000EV]`800003I[L006Zf00AZ]P03001V]`0000IR]`8000ERf004001VefKG
0005DWT00`00H]T00007E_d00`00E_eFo@0300000eKm001Fo@05E_d30005E_d00`00E_eFo@04E_d3
0005E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@02E_d200000eKm001Fo@05E_d01000Oomoo`00
6Woo0`001Goo0`002Goo0P0017oo0P00Z7oo003oOomZOol3000=Ool20006E_d01000E_eFoEKm0P00
0UKm00<005KmE_d015Km00<005KmE_d00`0000=Fo@00E_d01UKm00<005Km00000P000UKm00<005Km
E_d015Km00@005Km000000A>>003001>=dhg009>=`03001>=dhg00A>=`03001>5dhG009>5`03001>
5dhG00=>5`8000E>5`03001>5dhG00=>5`03001>5dhG00A>5`03001>5dhG00=>5`03001>5`000080
0003CQL004hG00A>5`03001>5dhG00=>5`03001>5dhG00A>5`03001>5dhG009>5`8000I>5`03001B
=e8g00AB=`03001B=e8g00=B=`<000=B=`03001B=e8g00AB=`03001B=e8g00AB=`03001B=e8g0080
0003DSL0058g00EB=`03001F=eHg00EF=`<000AF=`03001F=eHg00AF=`03001F=eHg00=F=`8000EF
=P03001F=UHf00EF=P8000EFEP03001FEUIF00AFEP04001FEUIF0004FUH00`00FUIJEP04FUH00`00
FUIJEP020003FUH00`00FUIJEP04FUH01000FUIJEP000eYF00<005YFFUH01EYF0P001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005ifGWH00Uif00@005ifGWH000INMP04001NMUif0004GWH00`00
GWINMP04GWH20007GWH01000GWINMP0015if00<005ifGWH00eif00<005if00001eif00<0069fHWH0
1F9f00@006:GHYL000ARUP03001RUf:G00=RU`04001RUf:G0007HYL00`00HYMRU`05HYL00`00HYMR
U`05HYL01000HYMRU`001F:G00@006:GHYL000ERU`04001RUf:G0003HYL00`00HYMRU`03HYL01000
H[MR]`001F:g00@006JgI[L000AV]`04001V]fJg0005I[L01000I[MV]`0016Zf00@006JgI[L000ER
]`04001V]fJg0004H]P01@00I]MVefKG00000e9i00D006;IH]URf@0000IFo@<000EFo@04001FoEKm
E_d200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@05E_d00`00E_eFo@0300000eKm001F
o@06E_d01000E_d0000015Km00<005KmE_d00eKm0P000Woo00<007ooOol087oo0P0027oo0P001Woo
0P00Ygoo003oOomXOol2000=Ool30002E_d00`00E_eFo@04E_d00`00E_d00005E_d00`00E_eFo@03
E_d30005E_d00`00E_eFo@04E_d20006E_d00`00E_eFo@03E_d20006CSP00`00CSM>=`02CSL00`00
CSM>=`04CSL00`00CQM>5`03CQL00`00CQL0000200000dhG001>5`04CQL00`00CQM>5`04CQL00`00
CQM>5`03CQL00`00CQM>5`02CQL30004CQL00`00CQM>5`03CQL00`00CQM>5`04CQL00`00CQM>5`04
CQL400000dhG001>5`05CQL00`00DSMB=`04DSL00`00DSMB=`02DSL20006DSL00`00DSMB=`04DSL0
0`00DSMB=`04DSL20004DSL00`00DSMB=`04DSL00`00ESMF=`03ESL20006ESL00`00ESMF=`04ESL0
1000ESMF=eHg0P0000=F=P00ESH01EHf00<005HfESH00eHf0P001UIF00<005IFEUH01EIF0P001EYF
00<005YFFUH01EYF0P001EYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH015YF0P001eYF00D005ifGWINMP0000=NMP03001NMUif00ENMP8000INMP03
001NMUif009NMP04001NMUif0007GWH20005GWH00`00GWINMP02GWH01000GWINMP001eif00<0069f
HWH01F9f00<006:G00001V:F00D006:GHYMRU`0000=RU`03001RUf:G00ARU`03001RU`0000IRU`03
001RUf:G00ERU`03001RU`0000IRU`03001RU`0000IRU`04001RUf:G0004HYL01@00HYMRUf:G0000
16:g00D006:gH[MR]`0000AV]`04001V]fJg0004I[L01000I[MV]fJg0P000fJg00@006ZfJ[H000AV
]`05001R]f:gH[L00003I[L01@00H]QRf6;H000016KG00@0059iDWT000ERf@03001FoEKm00<00003
E_d005Km00EFo@04001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@03E_d30005E_d0
0`00E_eFo@04E_d20006E_d00`00E_eFo@0300000eKm001oo`02Ool00`00Oomoo`0POol20007Ool2
0006Ool2002WOol00?moofEoo`<000eoo`8000IFo@03001FoEKm00=Fo@<000IFo@03001Fo@000080
009Fo@03001FoEKm00AFo@03001FoEKm00<00003E_d005Km00IFo@03001Fo@0000800003DWT004hh
00E>>003001>=dhg00=>=`03001>=dhg00=>=`03001>5dhG009>5`<000E>5`03001>5dhG00=>5`03
001>5dhG00=>5`03001>5dhG00A>5`@00003CQL004hG00E>5`03001>5dhG009>5`03001>5dhG00A>
5`03001>5dhG00=>5`8000A>5`03001>5dhG00A>5`03001B=e8g00AB=`03001B=e8g00800003DSL0
058g00EB=`03001B=e8g00AB=`03001B=e8g00=B=`8000EB=`03001B=e8g00AB=`03001F=eHg009F
=`03001F=`0000IF=`03001F=eHg00EF=`<000AF=P03001F=UHf00=F=P03001F=UHf009F=P03001F
=P0000MFEP03001FEUIF00=FEP8000IJEP03001JEUYF00AJEP8000IJEP03001JEUYF00AJEP8000IJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0006FUH01000GWINMP00
15if00<005ifGWH015if0P001eif00D005ifGWINMP0000=NMP03001NMUif00ENMP03001NMUif00EN
MP04001NMUif0003GWH00`00GWINMP04GWH00`00GWH00007HWH00`00HYIRUP05HYH01000HYMRU`00
1F:G00<006:GHYL00V:G00@006:GHYL000ERU`03001RU`0000MRU`03001RUf:G00IRU`03001RUf:G
00ERU`03001RU`0000ERU`04001RUf:G0005H[L01000H[MR]`001FJg00@006JgI[L000AV]`06001V
]fJg001V]`000fJg00@006ZfJ[H000AV]`04001R]f:g0005I[L01000H]QRf00016KG00<0059i0000
1f;I0P001EKm00<005KmE_d00eKm0P001eKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d0
0`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01EKm0`001EKm00@007ooOol0029oo`80
00Ioo`8000Qoo`800:Ioo`00ogooHgoo0P003Goo0`0000=Fo@00E_d01UKm00<005Km00000P000eKm
00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0`001EKm00<005KmE_d015Km0P001E9i00<004hh
CSP014hh00<004hgCSL00Thg00<004hgCSL014hg100000=>5`00CQL01DhG00<004hGCQL00dhG00<0
04hGCQL00dhG00<004hGCQL00dhG0P0014hG00<004hGCQL014hG00<004hGCQL00dhG00<004hGCQL0
0dhG00@004hGCQM>5`800003CQL004hG00A>5`03001>5dhG00A>5`03001B=e8g00AB=`8000AB=`03
001B=e8g00=B=`03001B=e8g00AB=`04001B=e8gDSL200000e8g001B=`05DSL00`00DSMB=`03DSL0
0`00ESMF=`020002ESL00`00ESMF=`05ESL00`00ESMF=`03ESL20006ESH00`00ESIF=P03ESH00`00
ESIF=P020002ESH00`00EUIFEP05EUH00`00EUIFEP02EUH00`00EUH00007FUH00`00FUIJEP02FUH0
0`00FUH00007FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP03FUH00`00FUH00006FUH0
1@00FUIJEUYF00000eYF00<005YFFUH01EYF0P001Uif00<005ifGWH00Uif00<005if00001eif00@0
05ifGWH000ANMP03001NMUif00ANMP8000MNMP03001NMP0000ENMP03001NMUif009NMP04001NMUif
0007HWH00`00HYIRUP05HYH00`00HYL00006HYL01@00HYMRUf:G00000f:G00<006:GHYL00V:G00@0
06:GHYL000IRU`8000QRU`03001RUf:G00IRU`03001RUf:G00ARU`03001RU`0000IR]`03001R]`00
00IV]`03001V]`0000EV]`03001V]`00009V]`07001V]fJgI[L006Zf00001FJg00<006:g00001VJg
00<006;H00001VKG00<006;IH]T01V;I00<005KmE_d015Km00<005KmE_d00`000UKm00<005KmE_d0
15Km0`001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d00`0000=F
o@00E_d01UKm00@007ooOol0025oo`8000Ioo`8000Qoo`800:Ioo`00ogooH7oo0`0037oo0`001EKm
00<005KmE_d015Km0P001eKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000UKm
00<005KmE_d015Km00<005KmE_d00`0000=Fo@00DWT0159i00<004hhCSP014hh00<004hgCSL00Thg
00<004hgCSL00dhg0P001DhG00<004hGCQL00dhG00<004hGCQL00dhG00<004hGCQL014hG00<004hG
00000P0000=>5`00CQL014hG00<004hGCQL00dhG00<004hGCQL00dhG00<004hGCQL014hG0`000dhG
00<004hGCQL00dhG00<004hGCQL014hG00<0058gDSL00e8g0P001E8g00<0058gDSL0158g00<0058g
DSL0158g0`000e8g00<0058gDSL0158g00<0058gDSL0158g0P001EHg00<005HgESL015Hg00<005Hg
ESL00UHg00<005Hf00001UHf00<005HfESH015Hf0P001EHf00<005IFEUH015IF00<005IFEUH00P00
0UIF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00EJEP05001JEUYFFUH00002FUH0
0`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF
00AJEP8000MNMP05001NMUifGWH00003GWH00`00GWINMP05GWH20006GWH00`00GWINMP02GWH01000
GWINMP001eif00<005ifGWH015if00D005ifGWINMP0000=NMP03001RMV9f00ARMP03001RMP0000MR
UP03001RUf:G00ERU`04001RUf:G0005HYL01000HYMRU`000f:G00<006:GHYL00f:G00@006:GHYL0
00IRU`03001RU`0000MRU`03001RUf:G00ERU`03001R]f:g00IR]`03001V]fJg00IV]`03001V]fJg
00EV]`05001V]fJgI[L00004I[L00`00I[MV]`05I[L00`00I[MV]`06I[L00`00I]MVe`05I]L00`00
H]URf@05H]T00`00J_P00005E_d30006E_d00`00E_eFo@0300000eKm001Fo@05E_d00`00E_eFo@03
00000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@05E_d30005E_d00`00E_eFo@04E_d20000
0goo001oo`0POol20006Ool20008Ool2002VOol00?mooeeoo`<000aoo`<0009Fo@03001FoEKm00AF
o@03001FoEKm00<00003E_d005Km00IFo@8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=F
o@<000EFo@03001BNE9i009BN@03001>>4hh00A>>003001>=dhg00=>=`03001>=`0000800003CQL0
04hG00A>5`03001>5dhG00A>5`03001>5dhG00=>5`03001>5dhG009>5`<000A>5`03001>5dhG00=>
5`03001>5dhG00A>5`03001>5dhG009>5`03001>5dhG00=>5`8000I>5`03001>5dhG009>5`03001>
5dhG00A>5`04001B=e8gDSL200000e8G001B=`04DSL00`00DSMB=`04DSL00`00DSMB=`03DSL20006
DSL00`00DSMB=`03DSL00`00DSMB=`03DSL20006ESL00`00ESMF=`04ESL00`00ESMF=`020002ESH0
0`00ESIF=P05ESH00`00ESIF=P02ESH20006ESH00`00EUIFEP05EUH20005EUH00`00FUIJEP04FUH0
1000FUIJEP0015YF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00AJEP04001JEUYF0003
FUH00`00FUIJEP05FUH20006FUH00`00FUIJEP02FUH00`00GUH00007GWH01000GWINMP0015if00<0
05ifGWH01Eif00<005ifGWH01Eif00D005ifGWINMP0000=NMP03001NMUif00ANMP8000INMP04001N
MUif0005GWH00`00HWIRMP02HWH01000HWIRMP001f:F00<006:GHYL01V:G0P001V:G00@006:GHYL0
00ARU`05001RUf:GHYL00003HYL00`00HYMRU`03HYL01000HYMRU`001V:G00<006:G00001V:G00<0
06:gH[L01V:g00<006JgI[L01VJg00<006JgI[L01FJg00<006JgI[L00VJg00D006JgI[MV]`0000MV
]`03001V]fJg00EV]`8000IVe`03001Ve`0000ERf@04001Zn6[h0002E_d300000e9H001Fo@06E_d3
0005E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@04E_d30005E_d01000E_eFoEKm0P0000=Fo@00
E_d01UKm00<005KmE_d00`0000EFo@00Oomoo`00021oo`8000Ioo`8000Qoo`800:Ioo`00ogooFgoo
0P003Goo0P001UKm00<005KmE_d00eKm0`001EKm00<005KmE_d00UKm0P0000=Fo@00E_d01UKm00<0
05Km00000P000UKm00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d00eKm00<0059iDWT0
0e9i00<004hhCSP014hh00<004hgCSL010001DhG00<004hGCQL00ThG00<004hGCQL014hG00<004hG
CQL00dhG00<004hG00000P0000=>5`00CQL01DhG00<004hGCQL00ThG00<004hGCQL014hG00<004hG
CQL00dhG00<004hG00000P0000=>5`00CQL01DhG00<004hGCQL00dhG00<004hGCQL014hG0`000e8G
00<0058gDSL0158g00<0058gDSL00e8g00@0058gDSMB=`800003DSL0058g00EB=`03001B=e8g00AB
=`03001B=e8g00800003DSH005Hg00EF=`03001F=eHg00EF=`8000EF=P03001F=UHf00AF=P07001F
=UHfESH005Hf00001UHf00<005IFEUH015IF0P001UIF00<005YFFUH01EYF0P001EYF00<005YFFUH0
1EYF0P001EYF00<005YFFUH015YF00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00D0
05YFFUIJEP0000=NEP03001NMUif00ENMP8000ENMP03001NMUif00ANMP8000MNMP04001NMUif0004
GWH00`00GWINMP03GWH01000GWINMP001Uif0P001Uif00D0069fHWIRMP0000=RMP03001RUV:F00AR
UP03001RUP0000MRU`03001RUf:G00ERU`03001RU`0000ERU`04001RUf:G0005HYL01@00HYMRUf:G
00000f:G00<006:GHYL00f:G00@006:GHYL000ERU`03001V]`0000IR]`03001V]`0000IV]`03001V
]`0000EV]`03001V]`0000=V]`06001V]fJg001V]`001FJg00<006Jg00001FJg00@006KGI]L000AV
e`04001VefKG0004H]T00`00J_QZn002J_P20005DUP00`00E_eFo@02E_d200000eKm001Fo@05E_d0
0`00E_eFo@0300000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@05E_d01000E_d0000015Km
00<005KmE_d015Km0`001EKm00@007ooOol001ioo`8000Moo`8000Qoo`800:Ioo`00ogooF7oo0`00
37oo0`0000=Fo@00E_d01UKm00<005Km00000P000UKm00<005KmE_d015Km00@005Km000000AFo@03
001FoEKm00AFo@8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@03001BNE9i009BN@03
001>>4hh00=>>0@0009>5`03001>5dhG00A>5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5dhG
00=>5`8000A>5`03001>5dhG00A>5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5dhG009>5`<0
00E>5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5dhG00=>5`8000IB5`03001B=e8g00=B=`03
001B=e8g00AB=`<000=B=`03001B=e8g00AB=`03001B=e8g00AB=`03001B=`0000=B=P03001F=eHg
00EF=`03001F=eHg00=F=`8000IF=P03001F=UHf00AF=P04001F=UHf0003ESH00`00ESIF=P04ESH0
0`00EUIFEP02EUH00`00EUH00006EUH00`00FUIJEP04FUH20006FUH00`00FUIJEP04FUH20006FUH0
0`00FUIJEP04FUH20006FUH00`00FUIJEP03FUH20007FUH01000FUIJEP0015iF00<005ifGWH01Eif
00<005ifGWH01Eif00<005ifGWH00Uif00@005ifGWH000MNMP8000INMP05001NMUifGWH00003GWH0
0`00GWINMP04GWH00`00GWINMP05GWH01000HWIRMP001F9f00<006:FHYH00V:F00@006:FHYH000IR
U`8000QRU`03001RUf:G00ARU`03001RU`0000IRU`04001RUf:G0005HYL01@00HYMRUf:G00000f:G
00<006:GHYL00V:G00@006JgI[L000ER]`04001V]fJg0005I[L01000I[MV]`0016Jg00@006JgI[L0
00=V]`03001V]`00009V]`03001V]fJg009V]`04001V]fJg0004I[L01@00I]MVefKG00000fKG00<0
06KGI]L00VKG00@006;IH]T000EZn003001BF59H00EBF004001Fo@000004E_d00`00E_eFo@03E_d3
0005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@03E_d20007E_d00`00E_eFo@0300000eKm001F
o@05E_d01000Oomoo`005Woo0P001Goo0`001goo0P0027oo0P00YWoo003oOomFOol2000<Ool30005
E_d00`00E_eFo@04E_d20006E_d00`00E_eFo@03E_d30006E_d00`00E_eFo@0300000eKm001Fo@06
E_d00`00E_d0000200000eKm001Fo@06E_d00`00E_eFo@02E_d00`00DWUBN@02DWT00`00CSQ>>003
00000dXG001>5`04CQL00`00CQM>5`03CQL00`00CQM>5`03CQL00`00CQM>5`04CQL00`00CQL00002
00000dhG001>5`04CQL00`00CQM>5`03CQL00`00CQM>5`03CQL00`00CQM>5`04CQL400000dhG001>
5`05CQL00`00CQM>5`04CQL00`00CQM>5`02CQL01000CQM>5dhG0P0000=B5`00DQL01E8G00<0058g
DSL0158g00<0058gDSL00U8g0P001U8g00<0058gDSL0158g00<0058gDSL00e8g0P001E8f00<005Hg
ESL015Hg00<005HgESL00UHg00<005Hf00001UHf00<005HfESH01EHf0P0015Hf00<005HfESH015Hf
00D005IFEUIFEP00009FEP03001FEUIF00EFEP03001JEUYF009JEP03001JEP0000MJEP03001JEUYF
009JEP03001JEP0000MJEP03001JEUYF009JEP03001JEP0000MJEP05001JEUYFFUH00002FUH00`00
FUIJEP05FUH20005GUH00`00GWINMP04GWH20007GWH01@00GWINMUif00000eif00<005ifGWH01Eif
00<005ifGWH01Eif00@005ifGWH000ANMP03001NMUif00ANMP03001NMUif00INMP8000IRMP05001R
UV:FHYH00003HYH00`00HYMRU`03HYL01000HYIRUP001f:G00<006:GHYL01F:G00<006:GHYL01F:G
00<006:G00001V:G00@006:GHYL000ERU`04001RUf:G0004I[L01@00H[MR]f:g000016Jg00D006Jg
I[MV]`0000AV]`04001V]fJg0004I[L00`00I[MV]`020004I[L01000I[MV]`0016Jg00@006JgI[L0
00EVe`04001VefKG0004I]L00`00H]T00005J_P00`00J]H00006DUP20007E_d00`00E_d000020000
0eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@05E_d00`00E_eFo@030002E_d00`00E_eFo@04
E_d30005E_d00`00E_eFo@03E_d20002Ool00`00Oomoo`0COol90008Ool20008Ool2002VOol00?mo
oe=oo`<000]oo`<0009Fo@03001FoEKm00AFo@03001FoEKm00<00003E_d005Km00IFo@03001Fo@00
008000=Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm00AFo@8000EFo@03001FoEKm00AFo@H000=B
N@@000E:5`03001>5dhG009>5`03001>5dhG00A>5`03001>5dhG009>5`03001>5dhG00=>5`<000A>
5`03001>5dhG00=>5`03001>5dhG00A>5`03001>5dhG009>5`03001>5dhG00=>5`8000E>5`03001>
5dhG00=>5`03001>5dhG00A>5`03001>5dhG00=>5`<000=B5`03001B5e8G00AB5`03001B=e8g00AB
=`03001B=e8g00800003DSL0058g00EB=`03001B=e8g00AB=`03001B=e8g009B=`03001B=P0000EB
=P03001F=eHg00AF=`03001F=eHg0080009F=P03001F=UHf00EF=P03001F=UHf00=F=P8000EF=P03
001F=UHf00AF=P04001FEUIF0004EUH00`00EUIFEP04EUH01@00FUIJEUYF00000UYF00<005YFFUH0
1EYF00D005YFFUIJEP00009JEP03001JEUYF00EJEP05001JEUYFFUH00003FUH00`00FUIJEP04FUH0
1000FUIJEP000eYF00<005YFFUH01EYF00<005iFGUH01EiF00<005ifGWH00Uif00@005ifGWH000IN
MP04001NMUif0004GWH00`00GWINMP04GWH20007GWH00`00GWH00006GWH00`00GWINMP02GWH00`00
GWH00007GWH00`00HWIRMP05HWH01000HYIRUP001F:F00D006:GHYMRU`0000=RUP03001RUf:G00AR
U`03001RU`0000IRU`03001RUf:G00IRU`03001RUf:G00ERU`03001RU`0000IRU`04001RUf:G0004
I[L01000H[MR]`001FJg00@006JgI[L000EV]`04001V]fJg0004I[L01000I[MV]`001FJg00@006Jg
I[L000AV]`03001V]`0000IVe`03001Ve`0000IVe`03001Zn6[h00=Zn004001ZeV[F0005DUP01000
I]QVf0001UKm0P001EKm00<005KmE_d015Km0`001EKm00<005KmE_d00eKm0`001UKm00<005KmE_d0
0`0000=Fo@00E_d01EKm00<005KmE_d00`0000=Fo@00Ool00Woo00<007ooOol04Woo0P0000=oo`00
00000`002Goo0P0027oo0P00YWoo003oOomAOol2000<Ool20006E_d00`00E_eFo@03E_d30005E_d0
0`00E_eFo@04E_d20007E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_eFo@0300000eKm
001Fo@05E_d00`00E_eFo@0300000dhG000i]`02>KL40002BQL00`00BQM:5`04BQL00`00CQM>5`03
CQL00`00CQM>5`03CQL00`00CQM>5`03CQL00`00CQL0000200000dhG001>5`05CQL00`00CQM>5`02
CQL00`00CQM>5`04CQL00`00CQM>5`03CQL00`00CQL0000200000dhG001>5`04CQL00`00CQM>5`04
CQL00`00CQM>5`03CQL00`00CQM>5`02CQL20006DQL00`00DQMB5`04DQL00`00DSMB=`03DSL00`00
DSL00003DSL00`00DSMB=`04DSL00`00DSMB=`04DSL00`00DSMB=`020002DSH00`00DSIB=P03DSH0
0`00ESMF=`05ESL20005ESH00`00ESIF=P04ESH00`00ESIF=P02ESH00`00ESH00006ESH00`00ESIF
=P04ESH20005EUH00`00EUIFEP04EUH01000FUIJEP0015YF00<005YFFUH015YF00@005YFFUH000AJ
EP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJEP04
FUH00`00GUINEP05GUH01@00GWINMUif00000eif00<005ifGWH01Eif0P001Uif00<005ifGWH00Uif
00@005ifGWH000MNMP03001NMUif00ENMP05001NMUifGWH00002GWH00`00GWINMP05GWH00`00HWIR
MP06HWH20006HYH01000HYMRU`0016:F00<006:GHYL00f:G00@006:GHYL000ERU`03001RU`0000MR
U`03001RUf:G00IRU`03001RUf:G00ERU`03001RU`0000EV]`03001R]`0000IV]`03001V]`0000IV
]`03001V]`0000EV]`04001V]`000005I[L00`00I[L00006I[L00`00I]MVe`06I]L00`00I]MVe`05
I]L00`00J_QZn003J_P01@00J]IZeV[F00000e9H00<006KHI]P00VKH00<005KmE_d00`0000=BF@00
E_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005Km00000P0000=Fo@00E_d01UKm0`001EKm
00<005KmE_d00eKm0`001EKm00@007ooOol001Aoo`80011oo`8000Ioo`800:Moo`00ogooCWoo0`00
2goo0`000UKm00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d015Km00<005KmE_d00`00
00=Fo@00E_d01UKm0P001UKm00<005KmE_d00eKm0`001EKm00<005KmE_d00eKm0`0014hG00<003Vg
>KL00SVg00<004XGBQL00dXG00<004XGBQL00dXG00<004hGCQL00dhG00<004hGCQL00dhG00<004hG
CQL00ThG0`0014hG00<004hGCQL014hG00<004hGCQL00dhG00<004hGCQL00dhG00<004hGCQL00ThG
0`0014hG00<004hGCQL00dhG00<004hGCQL014hG00<004hGCQL014hG100000=>5`00DQL01E8G00<0
058GDQL0158G00<0058gDSL00e8g0P001E8g00<0058gDSL0158g00<0058gDSL0158g0P001E8f00<0
058fDSH00e8f00<005HgESL00eHg0P001UHf00<005HfESH015Hf00<005HfESH00P000UHf00<005Hf
ESH015Hf00<005HfESH00eHf0P001UIF00<005IFEUH01EIF0P001EYF00<005YFFUH01EYF0P001EYF
00<005YFFUH01EYF0P001EYF00<005YFFUH015YF0P001UYF00<005YFFUH00eYF00<005YF00001UiF
00@005ifGWH000ANMP03001NMUif00ANMP8000MNMP05001NMUifGWH00003GWH00`00GWINMP05GWH0
0`00GWINMP05GWH01000GWINMP0015if00<005ifGWH00eif00<0069f00001f9f00<006:FHYH01F:F
00<006:G00001V:F00D006:GHYMRU`0000=RU`03001RUf:G009RU`04001RUf:G0006HYL00`00HYL0
0007HYL00`00HYMRU`06HYL00`00I[MV]`05I[L00`00I[MV]`06I[L00`00I[MV]`06I[L00`00I[MV
]`05I[L00`00I[L00006I[L00`00I[MV]`05I[L00`00I]MVe`06I]L00`00I]MVe`04I]L00`00J]L0
0003J_P00`00J]IZeP02J]H01000DUQBF0001VKH0P001E9I00<005KmE_d00eKm0`001EKm00<005Km
E_d015Km0P001EKm00<005KmE_d00UKm0P0000=Fo@00E_d01EKm00<005KmE_d00`0000=Fo@00E_d0
1UKm00@007ooOol001=oo`80011oo`8000Ioo`800:Moo`00ogooC7oo0P0037oo0P001UKm00<005Km
E_d00eKm0P001UKm00<005KmE_d00eKm0`001EKm00<005KmE_d00UKm0P0000=Fo@00E_d01UKm00<0
05Km00000P000UKm00<005KmE_d015Km00<005Km00000P0000=>=`00CQL01DhG00<003Vg>KL00SVg
00<004XGBQL00TXG00<004XGBQL014XG00<004hGCQL00ThG00<004hGCQL014hG100000=>5`00CQL0
1DhG00<004hGCQL00dhG00<004hGCQL00dhG00<004hGCQL014hG100000=>5`00CQL01DhG00<004hG
CQL00dhG00<004hGCQL00dhG00<004hGCQL00dhG0P001DhG00<0058GDQL00e8G00<0058GDQL0158G
00@0058gDSMB=`800003DSL0058g00AB=`03001B=e8g00AB=`03001B=e8g00=B=`8000IB=P03001B
=U8f00=B=P03001F=eHg009F=`03001F=P0000IF=P03001F=UHf00EF=P8000EF=P03001F=UHf00AF
=P07001F=UHfESH005Hf00001eIF00<005IFEUH00eIF0P001UYF00<005YFFUH015YF0P001UYF00<0
05YFFUH015YF0P001eYF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH00UYF00@005YFFUH0
00MNEP8000INMP03001NMUif009NMP03001NMP0000MNMP04001NMUif0004GWH00`00GWINMP04GWH0
0`00GWH00007GWH20005GWH00`00GWINMP02GWH01000HWIRMP001V9f0P0026:F00<006:FHYH01F:F
00@006:GHYL000ERU`04001RUf:G0003HYL00`00HYMRU`03HYL01000HYMRU`001V:G00<006:G0000
1f:G00<006JgI[L01FJg00<006JgI[L01VJg00<006JgI[L01VJg00<006JgI[L01FJg00<006Jg0000
1VJg00<006JgI[L016Jg00<006Jg00001VKG00<006KG000016KG00D006[GJ]MZe`00009Zn003001Z
eV[F009ZeP03001BF00000MVf003001BFE9I00ABF@03001FoEKm00<00003E_d005Km00IFo@03001F
oEKm00<00003E_d005Km00EFo@04001Fo@000004E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@04
E_d20002Ool00`00Oomoo`0@Ool2000AOol20004Ool2002XOol00?moodUoo`<000aoo`800003E_d0
05Km00IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm00AF
o@04001Fo@000004E_d00`00E_eFo@04E_d20006E_d00`00E_eFo@03E_d20005CSL00`00CQM>5`03
CQL00`00>KLi]`02>KL00`00BQM:5`03BQL00`00BQM:5`03BQL00`00CQM>5`03CQL00`00CQM>5`02
CQL20005CQL00`00CQM>5`03CQL00`00CQM>5`04CQL00`00CQM>5`02CQL00`00CQM>5`03CQL20004
CQL00`00CQM>5`04CQL00`00CQM>5`03CQL00`00CQM>5`04CQL00`00CQL0000200000dhG001>5`04
CQL00`00DQMB5`04DQL00`00DQMB5`04DQL30003DSL00`00DSMB=`03DSL00`00DSMB=`04DSL01000
DSMB=e8g0P0000=B=P00DSH01E8f00<0058fDSH00e8f00<005HgESL00P000UHf00<005HfESH01EHf
00<005HfESH00eHf0P001UHf00<005HfESH015Hf00@005HfESH000=F=P03001FEUIF00AFEP03001F
EUIF009FEP03001FEP0000MJEP03001JEUYF009JEP03001JEP0000MJEP03001JEUYF009JEP03001J
EP0000MJEP05001JEUYFFUH00003FUH00`00FUIJEP04FUH01000FUIJEP000eYF00<005iFGUH01EiF
00<005ifGWH01Eif00D005ifGWINMP0000=NMP03001NMUif00ENMP8000INMP03001NMUif009NMP04
001NMUif0007GWH00`00GWINMP05GWH01000GWINMP000f9f00<0069fHWH00f9f00@0069fHWH000MR
UP03001RUV:F00ERUP03001RU`0000IRU`04001RUf:G0004HYL01@00HYMRUf:G00000f:G00<006:G
HYL00f:G00@006:GHYL000IRU`03001RU`0000EV]`03001V]`0000IV]`03001V]`0000IV]`03001V
]`0000EV]`04001V]`000005I[L00`00I[L00004I[L01000I[MV]`001FKG00@006KGI]L000=Ve`03
001Zef[G009Ze`03001Zn00000IZeP03001Vf6KH00EVf003001Ze`0000IBF@8000EFo@03001FoEKm
00AFo@<000EFo@03001FoEKm00=Fo@8000MFo@03001Fo@0000800003E_d005Km00IFo@03001FoEKm
00<00005E_d007ooOol0000BOol:0009Ool8002XOol00?moodIoo`<000=oo`03001oogoo00Moo`80
00AFo@03001FoEKm00AFo@8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@<000IFo@03
001FoEKm00<00003E_d005Km00IFo@03001Fo@0000800003CSP004hg00A>=`03001>5dhG00=>5`03
000i]cVg008i]`03001:5dXG00=:5`03001:5dXG00=:5`03001>5dhG00=>5`03001>5`0000800003
CQL004hG00A>5`03001>5dhG00=>5`03001>5dhG00A>5`03001>5dhG00=>5`03001>5`0000800003
CQL004hG00A>5`03001>5dhG00=>5`03001>5dhG00A>5`03001>5dhG009>5`<000A>5`03001>5dhG
00=>5`03001B5e8G00AB5`03001B5e8G00=B5`8000IB=`03001B=e8g00=B=`03001B=e8g00AB=`<0
00=B=P03001B=U8f00EB=P03001B=U8f00=B=P8000EF=P03001F=UHf00AF=P03001F=UHf009F=P03
001F=P0000IF=P03001F=UHf00AF=P03001F=P0000AF=P03001FEUIF00AFEP03001FEUIF008000=F
EP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF00<0
05YFFUH015YF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEP0000EJEP03001NEUiF00ANEP03
001NMUif00ENMP04001NMUif0004GWH00`00GWINMP05GWH00`00GWINMP05GWH01@00GWINMUif0000
0eif00<005ifGWH015if0P001eif00<005if00001F9f00D0069fHWIRMP0000=RMP03001RUV:F00AR
UP03001RUP0000MRUP03001RUf:G00ERU`03001RU`0000ERU`04001RUf:G0005HYL01@00HYMRUf:G
00000f:G00<006:GHYL00f:G00@006:GHYL000AV]`04001V]fJg0005I[L01000I[MV]`001FJg00@0
06JgI[L000AV]`03001V]fJg008000AV]`04001V]fJg0003I[L00`00I[MV]`02I[L01@00I]MVefKG
000016KG00@006KGI]L000EZe`03001ZeV[F00EZeP03001Vf6KH00AVf004001Zef[G0006DUT00`00
E_eFo@05E_d00`00E_eFo@0300000eKm001Fo@05E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d2
0005E_d00`00E_eFo@04E_d30005E_d01000Ool000004Goo2P002goo1000ZWoo003oOom4Ool20007
Ool00`00Oomoo`04Ool30006E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_d000020002E_d0
0`00E_eFo@04E_d00`00E_d000020003E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@04E_d20005
CSP00`00CSM>=`02CSL00`00CQM>5`04CQL00`00>KLi]`02>KL00`00BQM:5`02BQL00`00BQM:5`04
BQL00`00CQM>5`040004CQL00`00CQM>5`03CQL00`00CQM>5`04CQL00`00CQM>5`03CQL00`00CQM>
5`02CQL30004CQL00`00CQM>5`03CQL00`00CQM>5`04CQL00`00CQM>5`03CQL00`00CQM>5`020000
0dhG001>5`05CQL00`00CQM>5`03CQL00`00DQMB5`03DQL01000DQMB5e8G0P0000=B5`00DSL01E8g
00<0058gDSL00e8g00<0058gDSL00e8g0P001U8f00<0058fDSH0158f00<0058fDSH00U8f0P001UHf
00<005HfESH015Hf00<005HfESH00P000UHf00<005HfESH01EHf00<005HfESH00eHf0P001EHf00<0
05IFEUH01EIF0P001EIF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00AJEP04001JEUYF
0004FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP04FUH20006FUH00`00GUINEP03GUH00`00GUH0
0007GWH20005GWH00`00GWINMP04GWH20007GWH01000GWINMP001Eif00<005ifGWH00Uif00@005if
GWH000MNMP03001RMV9f00ARMP04001RMV9f0004HWH00`00HYIRUP03HYH01000HYIRUP001V:F0P00
26:G00<006:GHYL016:G00<006:G00001V:G00@006:GHYL000ERU`05001RUf:GHYL00004HYL01000
I[MV]`0016Jg00D006JgI[MV]`0000AV]`05001V]fJgI[L00004I[L01000I[MV]`0016Jg00D006Jg
I[MV]`0000AV]`04001V]fJg0004I[L01000I]MVe`001FKG00<006KG00001V[G00<006[FJ]H016[F
00<006[G000016KH00D006[GJ]MZe`0000EBF@03001Rf@0000IFo@<000EFo@03001FoEKm00=Fo@<0
00IFo@03001FoEKm00<00003E_d005Km00EFo@03001FoEKm00<00003E_d005Km00EFo@80009oo`03
001oogoo0=5oo`00ogoo@Goo0`002Woo00<007ooOol00`000eKm00<005KmE_d00eKm0`001EKm00<0
05KmE_d015Km0P001UKm00<005KmE_d00eKm0P001eKm00<005Km00000P000UKm00<005KmE_d015Km
00<005KmE_d00`0000=BN@00CSP014hh00<004hgCSL00dhg00<004hGCQL00dhG00<003Vg>KL00SVg
00<004XGBQL00dXG00<004XGBQL00TXG10000dXG00<004hGCQL00dhG00<004hGCQL00dhG00<004hG
CQL00dhG00<004hGCQL014hG100000=>5`00CQL01DhG00<004hGCQL00ThG00<004hGCQL014hG00<0
04hGCQL00dhG00<004hG00000dhG00<004hGCQL014hG00<004hGCQL00dhG00<0058GDQL0158G0`00
0e8G00<0058gDSL0158g00<0058gDSL00e8g00@0058gDSMB=`800003DSH0058f00EB=P03001B=U8f
00AB=P03001B=U8f00800003ESH005Hf00EF=P03001F=UHf00EF=P8000EF=P03001F=UHf00AF=P03
001F=UHf009F=P03001F=P0000IF=P03001FEUIF00AFEP03001FEUIF00AFEP03001JEUYF00EJEP80
00EJEP03001JEUYF00EJEP8000EJEP03001JEUYF00AJEP8000MJEP03001JEUYF009JEP03001JEP00
00MJEP05001NEUiFGUH00002GUH00`00GWINMP05GWH00`00GWINMP05GWH00`00GWINMP02GWH01000
GWINMP001eif0P001Uif00D005ifGWINMP0000=NMP03001NMUif00ANMP8000IRMP03001RMP0000IR
MP05001RUV:FHYH00003HYH00`00HYIRUP03HYH01000HYIRUP001f:G00<006:GHYL01F:G00<006:G
HYL01F:G00<006:G00001V:G00@006:GHYL000ERU`04001V]fJg0004I[L01000I[MV]`001FJg00@0
06JgI[L000EV]`04001V]fJg0004I[L01000I[MV]`001FJg00<006Jg00001FJg00<006KG00001fKG
00<006[GJ]L016[G00<006[G000016[F00@006[GJ]L000AVf003001Zef[G009Ze`05001BFE9IDUT0
0003H]T00`00E_eFo@0300000eKm001Fo@05E_d00`00E_eFo@0300000eKm001Fo@06E_d30005E_d0
0`00E_eFo@03E_d30005E_d00`00E_eFo@03E_d20002Ool00`00Oomoo`3AOol00?moocmoo`8000io
o`<000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001FoEKm00<00003E_d005Km00IFo@03
001Fo@000080009Fo@03001FoEKm00AFo@8000IFo@03001FoEKm00=Fo@<000EBN@03001>>4hh009>
>003001>=dhg00=>=`03001>5dhG00=>5`03000i]cVg008i]`03001:5dXG00=:5`03001:5`000080
0003BQL004XG00E:5`03001>5dhG009>5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5dhG00=>
5`8000A>5`03001>5dhG00A>5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5dhG00=>5`8000E>
5`03001>5dhG00=>5`03001>5dhG00A>5`03001B5e8G009B5`8000IB5`03001B=e8g00AB=`03001B
=e8g00=B=`<000=B=P03001B=U8f00AB=P03001B=U8f00EB=P8000AF=P03001F=UHf00AF=P03001F
=UHf00=F=P8000IF=P03001F=UHf00AF=P03001F=UHf0080009F=P03001F=UHf00AF=P03001FEUIF
00=FEP8000MFEP03001JEUYF00=JEP8000IJEP03001JEUYF00AJEP8000MJEP03001JEUYF009JEP03
001JEP0000MJEP05001JEUYFFUH00003FUH00`00FUIJEP04FUH01000GUINEP000eiF00<005ifGWH0
15if0P001eif00D005ifGWINMP0000=NMP03001NMUif00ENMP03001NMUif00ENMP04001NMUif0004
GWH00`00GWINMP03GWH01000GWINMP001V9f00<0069fHWH01F9f00@006:FHYH000ERUP05001RUV:F
HYH00003HYH00`00HYMRU`04HYL00`00HYH00006HYL00`00HYMRU`06HYL00`00HYMRU`05HYL00`00
HYL00006HYL00`00I[L00005I[L00`00I[L00006I[L00`00I[L00006I[L00`00I[L00005I[L00`00
I[L00007I[L00`00I[MV]`05I[L00`00I]MVe`06I]L00`00J]MZe`03J]L01000J]MZe`0016[F00D0
06[GJ]MZe`00009Vf003001Zef[G00=Ze`04001BFE9I0005H]T20005E_d00`00E_eFo@03E_d30005
E_d00`00E_eFo@02E_d200000eKm001Fo@05E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_d0
000200000eKm001oo`02Ool00`00Oomoo`3@Ool00?moocaoo`<000eoo`<000=Fo@03001FoEKm00=F
o@8000IFo@03001FoEKm00=Fo@<000EFo@03001FoEKm00AFo@8000IFo@03001FoEKm00<00003E_d0
05Km00IFo@03001Fo@0000800003E_d0059i00EBN@03001>>4hh00=>>003001>=dhg00=>=`03001>
5dhG00=>5`03000i]cVg008i]`03001:5dXG00@000A:5`03001:5dXG00A:5`03001>5dhG009>5`03
001>5dhG00A>5`03001>5dhG00=>5`03001>5`0000800003CQL004hG00A>5`03001>5dhG00=>5`03
001>5dhG00=>5`03001>5dhG00A>5`03001>5`0000800003CQL004hG00A>5`03001>5dhG00A>5`03
001>5dhG00=>5`03001B5e8G00800003DQL0058G00EB5`03001B=e8g00AB=`03001B=e8g009B=`80
00IB=P03001B=U8f00AB=P03001B=U8f00=B=P8000EF=P03001F=UHf00AF=P03001F=UHf009F=P03
001F=P0000IF=P03001F=UHf00EF=P8000EF=P03001F=UHf00AF=P05001FEUIFEUH00002ESH00`00
EUIFEP04EUH00`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP02FUH00`00FUH00007FUH01@00
FUIJEUYF00000UYF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF00AJEP03001NEP0000EN
EP03001NMUif009NMP03001NMP0000MNMP04001NMUif0004GWH00`00GWINMP04GWH20008GWH20006
GWH01@00GWINMUif00000eif00<0069fHWH0169f00<0069fHWH01F9f00<006:F00001V:F00@006:F
HYH000ARUP03001RUf:G00=RU`04001RUV:F0005HYL00`00HYL00007HYL00`00HYMRU`06HYL00`00
HYMRU`06HYL00`00I[MV]`05I[L00`00I[MV]`06I[L00`00I[MV]`06I[L00`00I[MV]`04I[L20008
I[L00`00I[MV]`05I[L00`00I]MVe`05I]L00`00J]L00003J]L00`00J]MZe`02J]L01000J]IZeP00
16[G00<006KH00001V[G00<0059I00001V;I00<005KmE_d015Km00<005KmE_d00`0000=Fo@00E_d0
1UKm00@005Km000000AFo@03001FoEKm00=Fo@<000EFo@03001FoEKm00AFo@8000EFo@05001oogoo
Ool0003AOol00?moocYoo`8000ioo`8000MFo@03001Fo@0000800003E_d005Km00IFo@03001Fo@00
0080009Fo@03001FoEKm00AFo@03001FoEKm00<00003E_d005Km00EFo@<000EFo@03001FoEKm00AF
o@8000EFo@03001BNE9i00=BN@03001>>4hh00=>>003001>=dhg00=>=`03001>5dhG009>5`T000=9
m`03001:5dXG00=:5`03001:5dXG00=:5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5dhG009>
5`<000A>5`03001>5dhG00=>5`03001>5dhG00A>5`03001>5dhG009>5`03001>5dhG00=>5`<000A>
5`03001>5dhG00=>5`03001>5dhG00A>5`03001>5dhG00=>5`03001B5`0000=B5`03001B5e8G00AB
5`03001B=e8g00AB=`03001B=e8g00800003DSH0058f00EB=P03001B=U8f00AB=P03001B=U8f009B
=P03001B=P0000EF=P03001F=UHf00AF=P03001F=UHf0080009F=P03001F=UHf00EF=P03001F=UHf
00=F=P8000IF=P03001F=UHf00AF=P04001FEUIF0003ESH00`00EUIFEP04EUH00`00FUIJEP020002
FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF00<005YFFUH015YF00@005YFFUH000AJEP03001J
EUYF00EJEP8000EJEP03001JEUYF00AJEP8000INEP05001NMUifGWH00003GWH00`00GWINMP05GWH2
0006GWH00`00GWINMP02GWH01000GWINMP001eif00<005ifGWH01Eif00@005ifGWH000ANMP03001R
MV9f00=RMP03001RMP0000MRMP03001RUV:F00ERUP03001RUP0000IRUP05001RUf:GHYL00003HYH0
0`00HYMRU`02HYL01000HYMRU`001V:G00<006:G00001f:G00<006:GHYL01V:G00<006JgI[L01FJg
00<006JgI[L01VJg00<006JgI[L01VJg00<006JgI[L016Jg0P001fJg00<006Jg00001FJg00<006KG
00001FKG00@006[GJ]L000=Ze`03001Zef[G009Ze`04001ZeV[F0005J]L00`00J]MZe`06J]L00`00
H]URf@04H]T00`00J_P00005E_d30005E_d00`00E_eFo@04E_d20006E_d00`00E_eFo@0300000eKm
001Fo@06E_d00`00E_eFo@0300000eKm001Fo@05E_d01000Oomoo`00dGoo003oOolgOol3000=Ool3
00000eKm001Fo@06E_d20005E_d00`00E_eFo@04E_d20006E_d00`00E_eFo@03E_d30005E_d01000
E_eFoEKm0P000UKm00<005KmE_d015Km00<005KmE_d00`0000=Fo@00E_d015Km00<0059iDWT0159i
00<004hhCSP00Thh00<004hgCSL00dhg00<004hG00000P0000=:5`00AOL00dGg00<004WgBOL014Wg
00<004XGBQL00TXG00<004XGBQL014XG00<004hGCQL00ThG00<004hGCQL00dhG00<004hG00000P00
00=>5`00CQL01DhG00<004hGCQL00ThG00<004hGCQL014hG00<004hGCQL00dhG00<004hG00000P00
00=>5`00CQL01DhG00<004hGCQL00dhG00<004hGCQL00dhG00<004hGCQL00dhG0P001E8G00<0058G
DQL0158G00<0058gDSL0158g0P00158f00<0058fDSH00e8f00<0058fDSH0158f00<0058fDSH00P00
0U8f00<005HfESH015Hf00<005HfESH015Hf0P001EHf00<005HfESH015Hf00<005HfESH00UHf00<0
05Hf00001UHf00<005HfESH015Hf00<005IF000015Hf00<005IFEUH01EIF0P001EYF00<005YFFUH0
15YF00@005YFFUH000AJEP03001JEUYF00EJEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000INEP04001NMUif0004GWH00`00GWINMP05GWH00`00GWINMP05GWH0
1@00GWINMUif00000eif00<005ifGWH015if0P001eif00<005if00001Uif00D0069fHWIRMP00009R
MP03001RMV9f00ERMP03001RUV:F00IRUP03001RUV:F00ERUP04001RUf:G0005HYH01000HYMRU`00
16:G00<006:GHYL00V:G00@006:GHYL000IRU`03001RU`0000IRU`03001V]`0000EV]`03001V]`00
00IV]`03001V]`0000IV]`8000IV]`03001V]`0000EV]`04001V]fJg0004I[L01000I]MVe`0016KG
00D006[GJ]MZe`00009Ze`03001Zef[G00=Ze`03001ZeP0000IZe`03001Zef[G00EZe`8000ERf@04
001Zn6[h0002E_d300000e9I001Fo@06E_d00`00E_eFo@0300000eKm001Fo@05E_d30005E_d00`00
E_eFo@04E_d30005E_d00`00E_eFo@03E_d20002Ool00`00Oomoo`3>Ool00?moocEoo`8000eoo`<0
00EFo@03001FoEKm009Fo@800003E_d005Km00EFo@03001FoEKm00<00003E_d005Km00IFo@03001F
o@000080009Fo@03001FoEKm00AFo@03001Fo@0000EFo@03001FoEKm00=Fo@<000EFo@03001FoEKm
00=Fo@03001BNE9i00=BN@03001>>4hh00=>>003001>=dhg00@000A:5`030015mdGg00=5m`030019
mdWg00=9m`03001:5dXG009:5`03001:5dXG00A:5`03001>5dhG009>5`03001>5dhG00=>5`8000A>
5`03001>5dhG00A>5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5dhG009>5`<000A>5`03001>
5dhG00A>5`03001>5dhG00=>5`03001>5dhG00A>5`03001>5`0000800003CQL0058G00AB5`03001B
5e8G00AB5`03001B=e8g00=B=`8000EB=P03001B=U8f00AB=P03001B=U8f00AB=P8000EB=P03001F
=UHf00=F=P03001F=UHf00=F=P8000IF=P03001F=UHf00AF=P03001F=UHf0080009F=P03001F=UHf
00EF=P03001F=UHf00=F=P8000IF=P03001FEUIF00AFEP03001JEUYF00AJEP03001JEUYF00EJEP80
00EJEP03001JEUYF00AJEP8000IJEP03001JEUYF00AJEP8000MJEP05001JEUYFFUH00003FUH00`00
GUINEP04GUH20005GWH00`00GWINMP04GWH20007GWH01000GWINMP0015if00<005ifGWH00eif00@0
05ifGWH000MNMP03001NMUif00ENMP04001RMV9f0004HWH00`00HWIRMP03HWH00`00HYH00007HYH0
0`00HYIRUP05HYH00`00HYL00006HYH01000HYMRU`0016:G00D006:GHYMRU`0000=RU`03001RUf:G
00=RU`04001RUf:G0005HYL01000I[MV]`0016Jg00@006JgI[L000EV]`04001V]fJg0005I[L01000
I[MV]`0016Jg0P0000=V]`00I[L00fJg00<006JgI[L00VJg00@006JgI[L000AVe`04001VefKG0005
J]L20007J]L00`00J]MZe`04J]L00`00J]L00005J]L01000J]MZe`000f;I00<006[hJ_P00V[h0P00
1E9I00<005KmE_d015Km0`001EKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=F
o@00E_d01EKm00<005KmE_d00`000UKm00@007ooOol00<moo`00ogoo<Woo0`0037oo0`000UKm00<0
05KmE_d015Km00@005Km000000AFo@03001FoEKm00=Fo@<000EFo@03001FoEKm00AFo@8000IFo@03
001FoEKm00=Fo@<000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001FoEKm009Fo@03001B
NE9i00=BN@04001>>4hhCSP50003BQL00`00BQM:5`03BQL00`00AOM5m`02AOL00`00BOM9m`03BOL0
0`00BQM:5`03BQL00`00BQM:5`03BQL00`00CQM>5`03CQL00`00CQL0000200000dhG001>5`04CQL0
0`00CQM>5`03CQL00`00CQM>5`03CQL00`00CQM>5`04CQL400000dhG001>5`05CQL00`00CQM>5`03
CQL00`00CQM>5`03CQL00`00CQM>5`03CQL30004CQL00`00DQMB5`03DQL00`00DQMB5`04DQL01000
DSMB=e8g0P0000=B=P00DSH0158f00<0058fDSH0158f00<0058fDSH00e8f0P001U8f00<005HfESH0
15Hf00L005HfESIF=P00ESH00006ESH00`00ESIF=P05ESH20005ESH00`00ESIF=P04ESH00`00ESIF
=P02ESH00`00ESH00006ESH00`00EUIFEP03EUH20006FUH00`00FUIJEP04FUH20007FUH00`00FUIJ
EP02FUH00`00FUH00007FUH00`00FUIJEP02FUH00`00FUH00007FUH01000FUIJEP0015YF00<005iF
GUH015iF00<005ifGWH01Eif00<005ifGWH00Uif00@005ifGWH000MNMP8000INMP05001NMUifGWH0
0003GWH00`00GWINMP05GWH00`00GWINMP05GWH01000HWIRMP00169f00<0069fHWH00V9f00@006:F
HYH000IRUP03001RUP0000MRUP03001RUV:F00ERUP03001RU`0000IRU`04001RUf:G0004HYL01@00
HYMRUf:G000016:G00D006:GHYMRU`0000AV]`04001V]fJg0004I[L01@00I[MV]fJg000016Jg00D0
06JgI[MV]`0000=V]`05001V]fJgI[L00002I[L00`00I[L00003I[L00`00I[MV]`02I[L01000I[MV
]`0016KG00<006KG00001V[G00<006[GJ]L01V[G00<006[GJ]L00f[G00@006[GJ]L000AZe`05001Z
ef[GJ]L00002H]T00`00J_QZn003J_P00`00DUUBF@05DUT00`00E_eFo@0300000eKm001Fo@05E_d3
0005E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@03E_d30006E_d00`00Ool0003?Ool00?moobmo
o`<000eoo`8000IFo@03001FoEKm00=Fo@<000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03
001FoEKm00<00003E_d005Km00IFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@8000IFo@03001F
oEKm00=Fo@H000=BN@H0009:5`03001:5dXG00A:5`03001:5dXG009:5`030015mdGg0095m`030019
mdWg00A9m`03001:5dXG009:5`03001:5dXG00A:5`03001>5dhG00@000A>5`03001>5dhG00=>5`03
001>5dhG00A>5`03001>5dhG009>5`03001>5dhG00=>5`8000A>5`03001>5dhG00A>5`03001>5dhG
00A>5`03001>5dhG009>5`04001>5dhGCQL200000dhG001>5`05CQL00`00DQMB5`03DQL00`00DQMB
5`04DQL30003DSH00`00DSIB=P04DSH00`00DSIB=P03DSH01000DSIB=U8f0P0000=B=P00DSH01E8f
00<005HfESH015Hf00@005HfESH0009F=P03001F=UHf00EF=P03001F=UHf00=F=P8000IF=P03001F
=UHf00AF=P03001F=UHf0080009F=P03001F=UHf00EF=P05001FEUIFEUH00002FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH00`00FUH00007FUH01@00FUIJEUYF00000UYF00<005YFFUH01EYF00D005YF
FUIJEP0000=JEP03001JEUYF00EJEP8000EJEP03001NEUiF00ANEP03001NMUif00ENMP05001NMUif
GWH00003GWH00`00GWINMP05GWH00`00GWINMP05GWH01000GWINMP0015if00<005ifGWH015if00<0
05if00001eif0P001F9f00D0069fHWIRMP0000=RUP03001RUV:F00=RUP04001RUV:F0007HYH00`00
HYIRUP06HYH00`00HYMRU`05HYL00`00HYL00005HYL01000HYMRU`001F:G00@006:GHYL000EV]`04
001V]fJg0004I[L01000I[MV]`001FJg00@006JgI[L000AV]`04001V]fJg0003I[L00`00I[L00002
I[L00`00I[MV]`03I[L00`00I[L00006I]L00`00J]MZe`05J]L00`00J]MZe`05J]L00`00J]L00004
J]L01@00J]MZef[G00000V[G00<006[GJ]L00V[G00<006;I00001F[h00<006[G00001U9I0`001EKm
00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d00`00
00=Fo@00E_d01UKm0P0000=oo`00Ool0cGoo003oOol]Ool2000=Ool30002E_d00`00E_eFo@04E_d0
0`00E_d000020003E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@04
E_d20007E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d0000200000dhg000i]`02>KL4
0003AQP00`00BQM:5`03BQL00`00BQM:5`03BQL00`00BQM:5`02BQL00`00AOM5m`03AOL00`00BOM9
m`03BOL00`00BQM:5`02BQL00`00BQM:5`03BQL40002BQL00`00CQM>5`04CQL00`00CQM>5`02CQL0
0`00CQM>5`04CQL00`00CQM>5`03CQL00`00CQL0000200000dhG001>5`04CQL00`00CQM>5`03CQL0
0`00CQM>5`04CQL00`00CQM>5`03CQL30003CQL00`00CQM>5`04CQL00`00DQMB5`03DQL00`00DQMB
5`03DQL20006DSH00`00DSIB=P03DSH00`00DSIB=P04DSH30003DSH00`00DSIB=P05DSH00`00ESIF
=P03ESH00`00ESH00004ESH00`00ESIF=P04ESH00`00ESIF=P02ESH00`00ESH00006ESH00`00ESIF
=P05ESH20005ESH00`00ESIF=P04ESH01000EUIFEP000eYF00<005YFFUH015YF00D005YFFUIJEP00
00=JEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP04FUH01000FUIJEP0015YF00<005YF
FUH01EYF00<005YFFUH01EYF00<005iFGUH00UiF00<005iF00001Uif00@005ifGWH000ANMP03001N
MUif00ANMP8000MNMP03001NMP0000INMP03001NMUif009NMP04001NMUif0007GWH00`00HWIRMP05
HWH01000HWIRMP0016:F00D006:FHYIRUP0000=RUP03001RUV:F00ARUP03001RUP0000MRUP03001R
Uf:G00IRU`03001RUf:G00ARU`03001RU`0000IRU`03001RU`0000IV]`03001V]`0000EV]`03001V
]`0000IV]`03001V]`0000IV]`8000AV]`05001V]`00I[L00007I[L00`00I]MVe`05I]L00`00J]MZ
e`04J]L00`00J]L00005J]L01000J]MZe`000f[G00<006[GJ]L00V[G00<006[G00001V[G00<006[h
J_P00f[h00@006[GJ]L000EBF@03001Vf@0000IFo@<000EFo@03001FoEKm00AFo@<000EFo@03001F
oEKm00=Fo@<000EFo@03001FoEKm009Fo@800005E_d007ooOol0003=Ool00?moobYoo`<000eoo`80
00IFo@03001FoEKm00=Fo@<000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080
009Fo@03001FoEKm00AFo@03001FoEKm00<0009Fo@03001FoEKm00AFo@8000IFo@03001FoEKm00=F
o@8000A>=`03000i]cVg008i]`03001664HH00A66003001:5dXG009:5`03001:5dXG00=:5`03001:
5dXG00=:5`030015mdGg0095m`030019mdWg00=9m`03001:5dXG00=:5`03001:5`0000800003BQL0
04XG00A:5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5dhG009>5`<000A>
5`03001>5dhG00=>5`03001>5dhG00A>5`03001>5dhG00=>5`03001>5dhG009>5`8000I>5`03001>
5dhG00=>5`03001B5e8G00=B5`04001B5e8GDQL200000e8F001B=P05DSH00`00DSIB=P04DSH00`00
DSIB=P02DSH20006DSH00`00DSIB=P04DSH00`00ESIF=P03ESH20005ESH00`00ESIF=P04ESH00`00
ESIF=P020002ESH00`00ESIF=P05ESH00`00ESIF=P03ESH20006ESH00`00ESIF=P04ESH00`00EUH0
0004FUH00`00FUIJEP04FUH01000FUIJEP0015YF00<005YFFUH01EYF0P001EYF00<005YFFUH01EYF
0P001EYF00<005YFFUH015YF0P001eYF00D005iFGUINEP00009NEP03001NMUif00ENMP8000INMP03
001NMUif009NMP04001NMUif0007GWH00`00GWINMP05GWH01@00GWINMUif00000eif00<005ifGWH0
15if0P001f9f00<0069f00001F:F00@006:FHYH000ERUP03001RUV:F009RUP04001RUV:F0006HYH0
0`00HYH00007HYL00`00HYMRU`05HYL00`00HYMRU`06HYL00`00I[MV]`06I[L00`00I[MV]`05I[L0
0`00I[MV]`06I[L00`00I[MV]`05I[L00`00I[MV]`03I[L01000I[MV]`0026Jg00<006KGI]L016KG
00<006KG000016[G00@006[GJ]L000AZe`03001Zef[G009Ze`04001Zef[G0005J]L00`00J]MZe`05
J]L00`00J_QZn003J_P01@00J]MZef[G00000e9I00D006KII]UVf@0000=Fo@800003E_d005Km00IF
o@03001FoEKm00<00003E_d005Km00EFo@03001FoEKm00<00003E_d005Km00IFo@04001Fo@000004
E_d00`00Ool0003=Ool00?moobQoo`8000eoo`<00003E_d005Km00IFo@03001Fo@00008000=Fo@03
001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@<000IFo@03001FoEKm
00<00003E_d005Km00IFo@03001Fo@0000800003DUT004hg00A>=`03000i]cVg008i]`03001664HH
00=66003001:5dXG009:5`03001:5dXG00A:5`03001:5dXG009:5`030015mdGg0095m`030019mdWg
00A9m`03001:5dXG00@000A:5`03001:5dXG00=:5`03001>5dhG00=>5`03001>5dhG00=>5`03001>
5dhG00A>5`@00003CQL004hG00E>5`03001>5dhG009>5`03001>5dhG00A>5`03001>5dhG00A>5`@0
0003CQL004hG00E>5`03001>5dhG00A>5`03001B5e8G00=B5`<000=B5P03001B=U8f00AB=P03001B
=U8f00AB=P03001B=U8f00800003DSH0058f00EB=P03001B=U8f00AB=P04001F=UHfESH200000eHf
001F=P04ESH00`00ESIF=P05ESH20005ESH00`00ESIF=P04ESH00`00ESIF=P02ESH00`00ESH00006
ESH00`00ESIF=P04ESH20006FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP04FUH20006FUH00`00
FUIJEP04FUH20007FUH00`00FUIJEP02FUH00`00FUH00007FUH01000GUINEP0015iF00<005ifGWH0
15if00<005ifGWH01Eif00D005ifGWINMP0000=NMP03001NMUif00ENMP03001NMUif00ENMP04001N
MUif0005GWH00`00GWINMP02GWH01000HWIRMP001f9f00<006:FHYH016:F00<006:F00001V:F00D0
06:FHYIRUP0000=RUP03001RUV:F00=RUP04001RUV:F0006HYL00`00HYH00006HYL00`00HYMRU`06
HYL00`00I[MV]`06I[L00`00I[MV]`05I[L00`00I[MV]`06I[L00`00I[MV]`05I[L00`00I[MV]`03
I[L01000I[MV]`001fJg00<006Jg000016KG00@006KGI]L000=Ze`03001Zef[G009Ze`04001Zef[G
0005J]L00`00J]L00006J]L00`00J]MZe`04J]L00`00J]L00003J_P00`00J]MZe`02J]L01000DUUB
F@001FKI00<005Km000015Km00<005KmE_d015Km0`001EKm00<005KmE_d00eKm0`001EKm00<005Km
E_d015Km0P001UKm00@007ooOol00<aoo`00ogoo9Goo0`0037oo0`001EKm00<005KmE_d015Km0P00
1eKm00<005Km00000P0000=Fo@00E_d01UKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km
00000P000UKm00<005KmE_d015Km0`001EKm00<005KmE_d015Km0P001E9I00<004hgCSL00Thg00<0
03Vg>KL00SVg00<004HHAQP00dHH00<004XGBQL00dXG00<004XGBQL00dXG00<004XGBQL00TXG00<0
04GgAOL00dGg00<004WgBOL01P000TXG00<004XGBQL014XG00<004XGBQL00TXG00<004hGCQL014hG
00<004hGCQL00ThG00<004hGCQL00dhG0P0014hG00<004hGCQL014hG00<004hGCQL00dhG00<004hG
CQL00dhG00<004hGCQL00dhG0P0014hG00<004hGCQL014hG00<004hGCQL014hG00<0058GDQL00U8G
0P001U8F00<0058fDSH0158f00<0058fDSH00e8f00<0058f00000e8f00<0058fDSH0158f00<0058f
DSH01E8f0`000eHf00<005HfESH015Hf00<005HfESH00eHf0P001UHf00<005HfESH015Hf00<005Hf
ESH00P000UHf00<005HfESH01EHf00<005HfESH00UHf00<005Hf00001UYF00<005YFFUH00eYF0P00
1eYF00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH00UYF00<005YF00001eYF00D005YFFUIJ
EP0000=JEP03001JEUYF00EJEP8000ENEP03001NMUif00=NMP8000MNMP04001NMUif0004GWH00`00
GWINMP04GWH00`00GWH00007GWH20006GWH01@00GWINMUif00000f9f00<0069fHWH0169f0P001f:F
00<006:FHYH01F:F00@006:FHYH000ERUP05001RUV:FHYH00003HYH00`00HYMRU`03HYL01000HYIR
UP001F:G00<006:G00001V:G00<006JG00001VJg00<006Jg00001FJg00<006Jg00001VJg00<006Jg
00001FJg00<006Jg000016Jg00D006Jg001V]`0000EV]`04001V]fJg0003I]L00`00I]MVe`02I]L0
1000J]MZe`0016[G00<006[G00001f[G00<006[GJ]L016[G00<006[G000016[G00D006[GJ]MZe`00
009Zn003001Zef[G009Ze`03001BF@0000MVf@03001FoEKm00AFo@03001FoEKm00<00003E_d005Km
00EFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00EFo@800003Ool0
07oo0<]oo`00ogoo8goo0P0037oo0`000UKm00<005KmE_d015Km00<005KmE_d00`000UKm00<005Km
E_d015Km0P001EKm00<005KmE_d015Km0P001UKm00<005KmE_d00eKm0P001UKm00@005KmE_eFo@80
009Fo@03001FoEKm00AFo@03001FoEKm00<00003E_d0059I00ABF@03001>=dhg009>=`03000i]cVg
00<i]`03001664HH00=66003001:5dXG009:5`03001:5dXG00=:5`03001:5dXG00=:5`030015mdGg
00D000=9m`03001:5dXG00=:5`03001:5dXG00=:5`03001:5dXG00=:5`03001>5dhG00=>5`03001>
5dhG00=>5`03001>5`0000800003CQL004hG00A>5`03001>5dhG00=>5`03001>5dhG00=>5`03001>
5dhG00A>5`03001>5`0000800003CQL004hG00A>5`03001>5dhG00A>5`03001>5dhG00=>5`03001B
5e8G00800003DQH0058F00EB5P03001B=U8f00AB=P03001B=U8f00=B=P8000EB=P03001B=U8f00AB
=P03001B=U8f00=B=P8000IF=P03001F=UHf00=F=P03001F=UHf009F=P03001F=P0000IF=P03001F
=UHf00EF=P8000EF=P03001F=UHf00AF=P05001F=UHfESH00002ESH00`00FUIJEP05FUH01`00FUIJ
EUYF001JEP0000MJEP05001JEUYFFUH00002FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF00<0
05YFFUH015YF00@005YFFUH000AJEP03001JEUYF00EJEP03001NEUiF00ANEP03001NMUif009NMP04
001NMUif0007GWH20006GWH00`00GWINMP02GWH01000GWINMP001eif00<005ifGWH01Eif00@005if
GWH000ARMP03001RMV9f00=RMP04001RMV9f0006HYH00`00HYIRUP06HYH20006HYH01000HYIRUP00
1F:F00D006:GHYMRU`0000=RUP03001RUf:G009RU`04001RUf:G0005HYL01000IYMVU`001FJg00@0
06JgI[L000AV]`04001V]fJg0005I[L01000I[MV]`0016Jg00@006JgI[L000AV]`80009V]`03001V
]fJg009V]`05001V]fJgI[L00002I]L00`00I]MVe`03I]L00`00J]L00006J]L00`00J]MZe`06J]L0
0`00J]MZe`03J]L01000J]MZe`000f[G00<006[GJ]L00V[G00<006[h00001V[G00<006KII]T01FKI
0P001UKm0`001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d00`00
00EFo@00Oomoo`000<]oo`00ogoo87oo0`0037oo0P001UKm00<005KmE_d00eKm0`001UKm00<005Km
E_d00`0000=Fo@00E_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005Km00000P000UKm00<0
05KmE_d015Km00<005Km00001EKm00<005KmE_d00eKm0`001EKm00<0059IDUT00U9I00<004hgCSL0
0dhg00<003Vg>KL00SVg00<004HHAQP00dHH00<004XGBQL00TXG00<004XGBQL014XG00<004XGBQL0
1@000TGg00<004WgBOL00dWg00<004XGBQL00dXG00<004XGBQL00dXG00<004XGBQL00dXG00<004hG
CQL00dhG00<004hGCQL00ThG0`0014hG00<004hGCQL00dhG00<004hGCQL014hG00<004hGCQL00ThG
00<004hGCQL00dhG0`0014hG00<004hGCQL00dhG00<004hGCQL014hG00<004hGCQL014hG0P000e8F
00<0058FDQH0158F00<0058fDSH0158f00@0058fDSIB=P800003DSH0058f00AB=P03001B=U8f00AB
=P03001B=U8f009B=P03001B=P0000IF=P03001F=UHf00=F=P03001F=UHf0080009F=P03001F=UHf
00EF=P03001F=UHf00=F=P8000IF=P03001F=UHf00AF=P04001F=UHf0004ESH00`00FUIJEP04FUH0
1000FUIJEP000eYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00AJEP04001JEUYF0004
FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP04FUH20007GUH01000GWINMP000eif00<005ifGWH0
1Eif00<005ifGWH01Eif00D005ifGWINMP0000=NMP03001NMUif00ANMP8000QNMP8000IRMP05001R
MV9fHWH00003HWH00`00HYIRUP03HYH00`00HYH00007HYH00`00HYIRUP05HYH00`00HYH00006HYH0
1000HYMRU`001F:F00@006:GHYL000ARU`05001RUf:GHYL00003IYL00`00I[MV]`02I[L01@00I[MV
]fJg000016Jg00@006JgI[L000AV]`03001V]fJg009V]`04001V]fJg0004I[L01@00I[MV]fJg0000
16Jg00@006JgI[L000EV]`8000MVe`03001Zef[G00EZe`03001Zef[G00EZe`03001Ze`0000=Ze`03
001Zef[G009Ze`04001Zef[G0005J]L00`00J]MZe`05J]L00`00I]UVf@04I]T01000J_QZn0000UKm
0`0000=BN@00E_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d0
1EKm0`001EKm00@007ooOol00<Yoo`00ogoo7Woo0P0037oo0`000UKm00<005KmE_d015Km00<005Km
00000P000UKm00<005KmE_d015Km0`001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d015Km0P00
1UKm00<005KmE_d00eKm0P001eKm00<005Km00000P000UKm00<005KmE_d00eKm00<0059IDUT00e9I
00<004hgCSL00Thg00<003Vg>KL00SVg00<004HHAQP00dHH00<004XGBQL00dXG00<004XGBQL01P00
0TWg00<004GgAOL00TGg00<004WgBOL014Wg00<004XGBQL00TXG00<004XGBQL014XG00<004XGBQL0
0TXG00<004hGCQL014hG100000=>5`00CQL01DhG00<004hGCQL00ThG00<004hGCQL014hG00<004hG
CQL00dhG00<004hG00000P0000=>5`00CQL01DhG00<004hGCQL00ThG00<004hGCQL014hG00<004hG
CQL00dhG0P001E8F00<0058FDQH0158F00<0058fDSH0158f0`000e8f00<0058fDSH00e8f00<0058f
DSH0158f00<0058fDSH00P000U8f00<005HfESH015Hf00<005HfESH015Hf0P001EHf00<005HfESH0
15Hf00<005HfESH00UHf00<005Hf00001UHf00<005HfESH01EHf0P001EHf00<005YFFUH015YF00<0
05YF000015YF00<005YFFUH01EYF0P001EYF00<005YFFUH01EYF0P001EYF00<005YFFUH015YF0P00
1eYF00<005YFFUH00UYF00@005iFGUH000INEP03001NMP0000ENMP03001NMUif00ANMP03001NMUif
00ENMP04001NMUif0005GWH00`00GWINMP02GWH01000GWINMP001eif00<0069fHWH01F9f00@0069f
HWH000ARMP03001RUV:F009RUP04001RUV:F0007HYH00`00HYIRUP06HYH00`00HYIRUP05HYH00`00
HYL00006HYH01000HYMRU`0016:G00@006:GHYL000EVU`05001V]fJgI[L00004I[L01000I[MV]`00
16Jg00D006JgI[MV]`0000AV]`04001V]fJg0004I[L00`00I[MV]`020004I[L00`00I[L00006I[L0
0`00I]MVe`06I]L00`00J]MZe`04J]L00`00J]L00005J]L01000J]MZe`000f[G00<006[GJ]L00V[G
00<006[G00001V[G00<006[GJ]L016[G00<006[g000016KI00<006[hJ_P00V[h0P001E9i00<005Km
E_d00eKm0`001EKm00<005KmE_d015Km0`001EKm00<005KmE_d00`0000=Fo@00E_d01EKm00@007oo
Ool00<Yoo`00ogoo6goo0`0037oo0P001UKm00<005KmE_d00eKm0P001UKm00@005KmE_eFo@80009F
o@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001FoEKm00<00003E_d005Km
00IFo@03001Fo@000080009Fo@03001FoEKm00AFo@8000IFo@03001FoEKm00=Fo@03001BFE9I009B
F@03001>=dhg009>=`03000i]cVg00<i]`03001664HH00=66003001:5dXG00D000=:5`030019mdWg
0099m`030015mdGg00=5m`030019mdWg00=9m`03001:5dXG00=:5`03001:5dXG00=:5`03001:5dXG
00=:5`03001>5dhG00@000A>5`03001>5dhG00A>5`03001>5dhG00=>5`03001>5dhG00=>5`03001>
5dhG009>5`<000A>5`03001>5dhG00A>5`03001>5dhG00=>5`03001>5dhG00A>5`03001>5`000080
0003CQH0058F00AB5P03001B5U8F00AB5P03001B=U8f00=B=P8000IB=P03001B=U8f00=B=P03001B
=U8f00AB=P8000EB=P03001F=UHf00AF=P03001F=UHf009F=P8000IF=P03001F=UHf00AF=P03001F
=UHf0080009F=P03001F=UHf00EF=P03001F=UHf00=F=P8000IF=P03001JEUYF00AJEP8000EJEP03
001JEUYF00AJEP8000IJEP03001JEUYF00AJEP8000MJEP03001JEUYF009JEP03001JEP0000MJEP05
001JEUYFFUH00003GUH00`00GUINEP05GUH00`00GWINMP04GWH00`00GWINMP03GWH00`00GWH00007
GWH20006GWH01@00GWINMUif00000eif00<005ifGWH01Eif00<0069fHWH01F9f00<0069f00001V9f
00@006:FHYH000ARUP03001RUV:F00=RUP03001RUP0000MRUP03001RUV:F00IRUP03001RUV:F00ER
UP03001RU`0000ERU`03001RU`0000IVU`04001V]fJg0005I[L01000I[MV]`0016Jg00@006JgI[L0
00EV]`03001V]`0000EV]`05001V]`00I[L00005I[L00`00I[MV]`05I[L00`00I]MVe`05I]L00`00
J]L00004J]L01000J]MZe`0016[G00D006[GJ]MZe`00009Ze`03001Zef[G00AZe`03001Zef[G00AZ
e`03001Ze`0000AZe`05001Zmf[gJ_L00002I]T00`00J_QZn003J_P00`00DWUBN@05DWT00`00E_d0
000200000eKm001Fo@06E_d00`00E_eFo@0300000eKm001Fo@05E_d30005E_d00`00E_eFo@03E_d2
0002Ool00`00Oomoo`37Ool00?mooaQoo`<000aoo`<00003E_d005Km00IFo@03001Fo@000080009F
o@03001FoEKm00AFo@03001Fo@0000EFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@<000EF
o@03001FoEKm00AFo@8000IFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm009Fo@03001B
FE9I009BF@03001>=dhg00=>=`03000i]cVg008i]`04001664HHAQP50002BQL00`00BQM:5`03BQL0
0`00BOM9m`03BOL00`00AOM5m`02AOL00`00BOM9m`03BOL00`00BQM:5`03BQL00`00BQM:5`03BQL0
0`00BQM:5`02BQL40003CQL00`00CQM>5`03CQL00`00CQM>5`03CQL00`00CQM>5`03CQL00`00CQM>
5`04CQL400000dhG001>5`05CQL00`00CQM>5`03CQL00`00CQM>5`03CQL00`00CQM>5`03CQL30004
CQH00`00DQIB5P03DQH00`00DQIB5P04DQH01000DSIB=U8f0P0000=B5P00DSH01E8f00<0058fDSH0
0e8f00<0058fDSH00e8f0P001U8f00<005HfESH015Hf00L005HfESIF=P00ESH00006ESH00`00ESIF
=P05ESH20005ESH00`00ESIF=P04ESH00`00ESIF=P02ESH00`00ESH00007ESH00`00FUIJEP02FUH0
0`00FUH00006FUH00`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP02FUH00`00FUH00007FUH0
1@00FUIJEUYF00000eYF00<005YFFUH015YF00@005YFFUH000ANEP03001NEUiF00ANEP8000INMP03
001NMUif009NMP04001NMUif0007GWH00`00GWINMP05GWH01000GWINMP0015if00<005ifGWH015if
00<005if00001f9f00<0069fHWH01F9f00@006:FHYH000ARUP03001RUV:F009RUP04001RUV:F0006
HYH00`00HYH00007HYH00`00HYIRUP06HYH00`00HYMRU`05HYL00`00IYMVU`05IYL00`00I[L00006
I[L00`00I[L00005I[L00`00I[L00007I[L00`00I[MV]`05I[L01000I[MV]`001FJg00<006JgI[L0
16Jg00<006KG00001FKG00@006[GJ]L000AZe`05001Zef[GJ]L00002J]L00`00J]MZe`03J]L20007
J]L00`00J]MZe`03J]L01000J]MZe`000f[G00<006[gJ_L00V[g00<006KI00001F[h00<006kg0000
1U9i0P001EKm00<005KmE_d015Km0`001EKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005Km0000
0P0000=Fo@00Ool00Woo00<007ooOol0aWoo003oOolFOol2000<Ool30005E_d00`00E_eFo@04E_d2
0006E_d00`00E_eFo@03E_d30006E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d00002
0002E_d00`00E_eFo@04E_d00`00E_eFo@030002E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@04
E_d60005DUT00`00CSM>=`0;0002AOL00`00BQM:5`02BQL00`00BQM:5`04BQL00`00BOM9m`02BOL0
0`00AOM5m`02AOL00`00BOM9m`04BOL00`00BQM:5`02BQL00`00BQM:5`04BQL400000dXG001>5`04
CQL00`00CQM>5`03CQL00`00CQM>5`04CQL00`00CQM>5`02CQL00`00CQM>5`03CQL20005CQL00`00
CQM>5`03CQL00`00CQM>5`04CQL00`00CQM>5`02CQL01000CQM>5dhG0P0000=>5P00CQH01DhF00<0
058FDQH00e8F00<0058FDQH0158F0`000e8F00<0058fDSH0158f00<0058fDSH00e8f00@0058fDSIB
=P800003DSH0058f00EB=P03001F=UHf00AF=P04001F=UHf0003ESH00`00ESIF=P04ESH00`00ESIF
=P03ESH20006ESH00`00ESIF=P04ESH00`00ESIF=P020002ESH00`00ESIF=P05ESH01@00FUIJEUYF
00000UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP03001JEUYF00EJEP05001JEUYFFUH00002
FUH00`00FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH01EYF0P001UiF00<005iFGUH00UiF00<0
05if00001eif00@005ifGWH000ANMP03001NMUif00ANMP03001NMUif00INMP8000INMP03001NMUif
009NMP04001NMUif0007HWH00`00HWIRMP05HWH00`00HYH00005HYH01@00HYIRUV:F00000f:F00<0
06:FHYH00f:F00@006:FHYH000IRUP03001RUP0000MRUP03001RUf:G00ERU`03001VUfJG00IVU`03
001V]fJg00IV]`03001V]fJg00EV]`03001V]fJg00IV]`03001V]fJg00EV]`04001V]fJg0004I[L0
0`00I[L00004I[L01000I]MVe`0016KG00<006[GJ]L00V[G00@006[GJ]L000AZe`03001Ze`0000IZ
e`03001Zef[G00EZe`03001Ze`0000AZe`05001Zef[GJ]L00002J]L00`00J_MZm`03J_L00`00J_QZ
n004J_P00`00K_L00005DWT00`00I_T00006E_d00`00E_eFo@0300000eKm001Fo@05E_d30005E_d0
0`00E_eFo@04E_d20005E_d01000Oomoo`00b7oo003oOolCOol4000:Ool30002E_d00`00E_eFo@04
E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_d000020003E_d00`00E_eFo@03E_d20006E_d0
0`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d30006E_d00`00E_d000020002E_d00`00E_eFo@04
E_d00`00E_eFo@0300000dhg000i]`02>KL90002AQL00`00@OM1m`03@OL00`00AOM5m`03AOL00`00
BQM:5`02BQL00`00BQM:5`03BQL00`00BOM9m`02BOL00`00AOM5m`03AOL00`00BOM9m`03BOL00`00
BQM:5`03BQL00`00BQM:5`040004BQL00`00CQM>5`04CQL00`00CQM>5`02CQL00`00CQM>5`04CQL0
0`00CQM>5`03CQL00`00CQL0000200000dhG001>5`04CQL00`00CQM>5`03CQL00`00CQM>5`04CQL0
0`00CQM>5`03CQL30003CQH00`00CQI>5P04CQH00`00DQIB5P03DQH00`00DQIB5P03DQH20006DQH0
0`00DSIB=P04DSH00`00DSIB=P03DSH30003DSH00`00DSIB=P05DSH00`00ESIF=P04ESH20004ESH0
0`00ESIF=P04ESH00`00ESIF=P02ESH00`00ESH00006ESH00`00ESIF=P05ESH20005ESH00`00ESIF
=P04ESH01000FUIJEP0015YF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP04001J
EUYF0004FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP04FUH20007GUH01@00GUINEUiF00000eif
00<005ifGWH015if00<005if00001Eif00<005ifGWH00eif00<005if00001eif00<005ifGWH01Eif
00D005ifGWINMP0000=NMP03001RMV9f00ARMP03001RMP0000MRMP03001RUV:F00ERUP04001RUV:F
0004HYH01@00HYIRUV:F00000f:F00<006:FHYH00f:F00@006:FHYH000IRUP03001RUP0000ERU`03
001VU`0000MVU`03001V]fJg00IV]`03001V]fJg00EV]`03001V]fJg00EV]`03001V]`0000EV]`05
001V]`00I[L00003I[L01000I[MV]`0016Jg00D006KGI]MVe`0000=Ve`03001Zef[G009Ze`04001Z
ef[G0005J]L00`00J]MZe`05J]L00`00J]MZe`04J]L01000J]MZe`000f[G00<006[GJ]L00V[G00<0
06[G00001V[g00<006[hJ_P00f[h00D006kgK_M^m`0000=BN@05001VnFKiI_T00005E_d30005E_d0
1000E_eFoEKm0P0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01EKm00@007ooOol00<Mo
o`00ogoo4Goo0P0017oo00<007ooOol01Goo0P001UKm00<005KmE_d00eKm0`001EKm00<005KmE_d0
15Km0P001eKm00<005Km00000P0000=Fo@00E_d01UKm00<005Km00000P000UKm00<005KmE_d015Km
00<005Km00000P000eKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0`0014hg00<003Vg>KL0
0SVg00<004GhAOP00TGh00<004HGAQL00dHG00<0047g@OL00d7g00<004GgAOL00TGg00<004XGBQL0
0TXG00<004XGBQL00dXG00<004WgBOL00dWg00<004GgAOL00TGg00<004WgBOL00dWg00<004XGBQL0
0TXG10000dXG00<004XGBQL00dXG00<004hGCQL00dhG00<004hGCQL00dhG00<004hGCQL00dhG00<0
04hGCQL00ThG0`0014hG00<004hGCQL00dhG00<004hGCQL014hG00<004hGCQL00dhG00<004hGCQL0
0ThG0P001ThF00<004hFCQH00dhF00<0058FDQH00e8F00@0058FDQIB5P800003DQH0058F00EB5P03
001B=U8f00AB=P03001B=U8f009B=P8000IB=P03001B=U8f00AB=P03001F=UHf00=F=P8000EF=P03
001F=UHf00AF=P03001F=UHf0080009F=P03001F=UHf00EF=P03001F=UHf00=F=P8000IF=P03001F
=UHf00EF=P8000EJEP03001JEUYF00AJEP8000EJEP03001JEUYF00EJEP8000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000MNEP04001NEUiF0004GWH00`00GWINMP05
GWH00`00GWINMP04GWH00`00GWINMP02GWH01000GWINMP001eif00<005ifGWH01Eif00@005ifGWH0
00ENMP03001RMV9f009RMP04001RMV9f0007HWH00`00HYIRUP05HYH00`00HYH00005HYH01000HYIR
UP001F:F00D006:FHYIRUP0000=RUP03001RUV:F00=RUP04001RUV:F0004HYL01000IYMVU`001VJG
00<006Jg00001VJg00<006Jg00001FJg00<006Jg00001FJg00@006JgI[L000AV]`06001V]fJg001V
]`000VJg00<006JgI[L00VJg00@006JgI[L000AVe`04001VefKG0005J]L00`00J]L00006J]L00`00
J]MZe`04J]L00`00J]L00004J]L00`00J]MZe`02J]L01000J]MZe`001F[G00<006[gJ_L016[g00<0
06[g00000f[h00<006kgK_L00Vkg00@0059iDWT000AVn@03001FoEKm00<00003E_d005Km00EFo@04
001Fo@000004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@03E_d20002Ool00`00Oomoo`34Ool0
0?moo`ioo`<000Moo`04001oogooOol30002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00
E_eFo@04E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d20005E_d00`00E_eFo@04E_d20006E_d0
0`00E_eFo@03E_d30006E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d0000200000e9I
001>=`05CSL00`00>KLi]`02>KL00`00AOQ5n002AOP00`00AQM65`02AQL00`00@OM1m`03@OL00`00
AOM5m`02AOL00`00BQM:5`02BQL00`00BQM:5`04BQL00`00BOM9m`02BOL00`00AOM5m`02AOL00`00
BOM9m`04BOL400000dXG001:5`04BQL00`00BQM:5`03BQL00`00CQM>5`03CQL00`00CQM>5`03CQL0
0`00CQM>5`04CQL400000dhG001>5`05CQL00`00CQM>5`03CQL00`00CQM>5`03CQL00`00CQM>5`04
CQL400000dhG001>5P05CQH00`00CQI>5P04CQH00`00DQIB5P03DQH30003DQH00`00DQIB5P04DQH0
0`00DSIB=P04DSH00`00DSIB=P0200000e8f001B=P05DSH00`00DSIB=P04DSH00`00ESIF=P02ESH0
0`00ESH00006ESH00`00ESIF=P04ESH20005ESH00`00ESIF=P04ESH00`00ESIF=P02ESH00`00ESH0
0006ESH00`00ESIF=P04ESH20006FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP04FUH2
0006FUH00`00FUIJEP04FUH20007FUH01@00FUIJEUYF00000eYF00<005iFGUH01EiF0P001Eif00<0
05ifGWH015if0P001eif00@005ifGWH000=NMP03001NMUif00ANMP03001NMP0000MNMP8000INMP05
001RMV9fHWH00003HWH00`00HWIRMP04HWH00`00HWH00007HYH00`00HYIRUP04HYH00`00HYH00006
HYH01000HYIRUP001F:F00D006:FHYIRUP0000ARUP04001RUf:G0003IYL00`00IYMVU`03IYL01000
I[MV]`001FJg00@006JgI[L000AV]`04001V]fJg0004I[L00`00I[MV]`02I[L01000I[MV]`0016Jg
0P000VJg00<006JgI[L00VJg00@006JgI[L000AVe`03001Ve`0000MZe`03001Zef[G00AZe`03001Z
e`0000AZe`04001Zef[G0004J]L00`00J]MZe`02J]L00`00J]L00006J]L00`00J_MZm`03J_L01000
J_MZm`000f[h00<006kgK_L00Vkg00<0059i00001VKi0P001EKm00<005KmE_d00eKm0P001eKm00<0
05KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d00`0000EFo@00Oomoo`000<Ioo`00ogoo37oo0P00
2goo0`001UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0`001UKm00<005KmE_d00`0000=F
o@00E_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005Km00000P000eKm00<005KmE_d00eKm
0P001UKm00<005KmE_d00eKm0P001E9I00<004hgCSL00dhg00<003Vg>KL00SVg00<004GhAOP00TGh
00<004HGAQL00THG00<0047g@OL00d7g00<004GgAOL00dGg00<004XGBQL00TXG00<004XGBQL00dXG
00<004WgBOL00TWg00<004GgAOL00dGg00<004WgBOL0100014XG00<004XGBQL014XG00<004XGBQL0
0TXG00<004hGCQL014hG00<004hGCQL00ThG00<004hGCQL00dhG0P0014hG00<004hGCQL014hG00<0
04hGCQL00dhG00<004hGCQL00dhG00<004hGCQL00dhG0P0014hG00<004hFCQH014hF00<004hFCQH0
14hF00<0058FDQH00U8F0P001U8F00<0058FDQH0158F00<0058fDSH0158f0P000e8f00<0058fDSH0
158f00<0058fDSH0158f00<005HfESH00P000UHf00<005HfESH015Hf00<005HfESH00eHf0P001UHf
00<005HfESH015Hf00<005HfESH00P000UHf00<005HfESH01EHf00<005HfESH00UHf00<005Hf0000
1eYF00<005YFFUH00UYF0P001eYF00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH00UYF00<0
05YF00001eYF00@005YFFUH000AJEP03001NEUiF00ENEP03001NMUif00ENMP03001NMUif009NMP04
001NMUif0006GWH00`00GWH00005GWH00`00GWINMP02GWH01000GWINMP001eif00<005ifGWH01Eif
00@0069fHWH000ERMP03001RMV9f009RMP04001RMV9f0006HYH20007HYH00`00HYIRUP05HYH00`00
HYH00006HYH01000HYIRUP001F:F00@006:GHYL000AVU`05001VUfJGIYL00004I[L01@00I[MV]fJg
000016Jg00@006JgI[L000AV]`05001V]fJgI[L00004I[L01000I[MV]`0016Jg0P0000=V]`00I[L0
16Jg00<006Jg00001VKG00<006[GJ]L01V[G00<006[GJ]L00f[G00@006[GJ]L000=Ze`03001Zef[G
009Ze`04001Zef[G0006J]L00`00J]MZe`04J]L00`00J_L00004J_L01`00J_MZmf[g001Zn00000I^
m`03001VnFKi00EVn@03001FoEKm00EFo@03001Fo@000080009Fo@03001FoEKm00AFo@<000EFo@03
001FoEKm00=Fo@<000EFo@04001oogoo0035Ool00?moo`Uoo`<000]oo`<0009Fo@03001FoEKm00AF
o@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@<000EF
o@03001FoEKm00=Fo@<000EFo@03001FoEKm00AFo@8000MFo@03001Fo@0000800003E_d005Km00IF
o@03001Fo@0000800003E_d0059I00ABF@03001>=dhg00=>=`03000i]cVg008i]`030015n4Gh0095
n00300165dHG00=65`030011md7g00=1m`030015mdGg0095m`03001:5dXG009:5`03001:5dXG00=:
5`030019mdWg00=9m`030015mdGg00D000=9m`03001:5dXG00=:5`03001:5dXG00=:5`03001:5dXG
00=:5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5`0000800003CQL004hG00A>5`03001>5dhG
00=>5`03001>5dhG00A>5`03001>5dhG00=>5`03001>5`0000800003CQL004hG00A>5`03001>5ThF
00A>5P03001>5ThF00=>5P03001B5U8F00800003DQH0058F00EB5P03001B5U8F00AB5P03001B=U8f
00=B=P8000EB=P03001B=U8f00AB=P03001B=U8f00AB=P8000EF=P03001F=UHf00AF=P07001F=UHf
ESH005Hf00001UHf00<005HfESH01EHf0P001EHf00<005HfESH015Hf00D005HfESIF=P00009F=P03
001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YF
FUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF00EJEP8000EJEP03001NEUiF00ANEP8000MNMP05
001NMUifGWH00003GWH00`00GWINMP05GWH00`00GWINMP04GWH01@00GWINMUif00000eif00<005if
GWH015if0P0025if0P001V9f00D0069fHWIRMP0000=RMP03001RUV:F00=RUP04001RUV:F0006HYH0
0`00HYIRUP06HYH00`00HYIRUP05HYH00`00HYH00006HYH00`00HYL00005IYL01000IYMVU`001FJg
00@006JgI[L000EV]`04001V]fJg0004I[L01000I[MV]`001FJg00<006Jg00001FJg0`001fJg00<0
06KGI]L01FKG00<006[GJ]L01F[G00<006[G000016[G00D006[GJ]MZe`00009Ze`03001Zef[G009Z
e`03001Ze`0000MZe`03001Zef[G00=Ze`04001Zmf[g0003J_L00`00J_MZm`02J_L00`00J_P00006
K_L00`00I_UVn@04I_T00`00JaP00006E_d20006E_d00`00E_eFo@0300000eKm001Fo@05E_d00`00
E_eFo@0300000eKm001Fo@05E_d01@00Oomoogoo0000a7oo003oOol7Ool2000<Ool20006E_d00`00
E_eFo@03E_d20006E_d00`00E_eFo@03E_d30006E_d00`00E_d000020002E_d00`00E_eFo@04E_d0
0`00E_d000020002E_d00`00E_eFo@04E_d00`00E_eFo@0300000eKm001Fo@06E_d20005E_d00`00
E_eFo@04E_d20005E_d00`00DUUBF@02DUT00`00CSM>=`04CSL00`00>KLi]`02>KL00`00AOQ5n002
AOP00`00AQM65`02AQL00`00@OM1m`03@OL00`00AOM5m`02AOL00`00BQM:5`02BQL00`00BQM:5`04
BQL00`00BOM9m`050002BOL00`00BOM9m`04BOL00`00BQM:5`02BQL00`00BQM:5`03BQL00`00BQM:
5`03BQL00`00CQM>5`03CQL00`00CQM>5`02CQL30004CQL00`00CQM>5`03CQL00`00CQM>5`04CQL0
0`00CQM>5`03CQL00`00CQM>5`02CQL30004CQL00`00CQM>5`03CQL00`00CQI>5P04CQH00`00CQI>
5P04CQH20004DQH00`00DQIB5P03DQH00`00DQIB5P04DQH00`00DSIB=P02DSH00`00DSH00005DSH0
0`00DSIB=P04DSH00`00DSIB=P03DSH20006ESH00`00ESIF=P04ESH01000ESIF=P000eHf00<005Hf
ESH015Hf00<005HfESH00eHf0P001UHf00<005HfESH015Hf00@005HfESH000AF=P03001JEUYF00AJ
EP04001JEUYF0003FUH00`00FUIJEP04FUH01000FUIJEP0015YF00<005YFFUH015YF00@005YFFUH0
00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001NEUiF009NEP03001NEP0000MNMP04001NMUif
0004GWH00`00GWINMP04GWH20006GWH01000GWINMP001Eif00<005ifGWH00Uif00@005ifGWH000MN
MP03001RMV9f00ERMP04001RMV9f0005HWH01@00HYIRUV:F00000f:F00<006:FHYH00f:F00<006:F
00001f:F00<006:FHYH01V:F00<006:FHYH01V:F00<006JGIYL016JG00<006JG00001VJg00<006Jg
00001VJg00<006Jg00001FJg00<006Jg00001fJg00<006JgI[L01FJg0P001fJg00<006KGI]L016KG
00<006[G00001F[G00@006[GJ]L000=Ze`03001Zef[G009Ze`03001Ze`0000IZe`03001Zef[G00EZ
e`03001Ze`0000=Ze`03001Zmf[g009Zm`04001Zmf[g0005J_L00`00K_M^m`04K_L00`00J_P00004
I_T01@00JaQ[66/H00000UKm0`0000=Fo@00E_d01EKm0`001EKm00<005KmE_d00eKm0`001EKm00<0
05KmE_d00eKm0P000Woo00<007ooOol0`Woo003oOol4Ool3000;Ool300000eKm001Fo@06E_d00`00
E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020003E_d00`00E_eFo@03E_d20006E_d00`00
E_eFo@03E_d20006E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@02E_d200000eKm001Fo@05E_d0
0`00E_eFo@0300000eKm001Fo@04E_d00`00DUUBF@03DUT00`00CSM>=`03CSL00`00>KLi]`02>KL0
0`00AOQ5n002AOP00`00AQM65`02AQL00`00@OM1m`03@OL00`00AOM5m`03AOL00`00BQM:5`02BQL0
0`00BQM:5`060002BOL00`00BOM9m`03BOL00`00BOM9m`03BOL00`00BQM:5`02BQL00`00BQM:5`04
BQL00`00BQM:5`02BQL00`00CQM>5`04CQL400000dhG001>5`05CQL00`00CQM>5`02CQL00`00CQM>
5`04CQL00`00CQM>5`03CQL00`00CQL0000200000dhG001>5`05CQL00`00CQM>5`02CQL00`00CQI>
5P04CQH00`00CQI>5P03CQH20005DQH00`00DQIB5P04DQH00`00DQIB5P03DQH00`00DSIB=P020002
DSH00`00DSIB=P03DSH00`00DSIB=P04DSH01000DSIB=U8f0P0000=B=P00ESH01EHf00<005HfESH0
15Hf00<005Hf000015Hf00<005HfESH015Hf00<005HfESH00UHf00<005Hf00001UHf00<005HfESH0
1EHf0P001EHf00<005YFFUH01EYF0P0015YF00<005YFFUH01EYF0P001EYF00<005YFFUH01EYF0P00
1EYF00<005YFFUH015YF0P001eYF00D005iFGUINEP0000=NEP03001NMUif00ENMP8000INMP03001N
MUif009NMP04001NMUif0006GWH20006GWH01@00GWINMUif00000eif00<005ifGWH015if0P00269f
0P001V9f00@006:FHYH000ARUP03001RUV:F009RUP04001RUV:F0006HYH00`00HYH00007HYH00`00
HYIRUP06HYH00`00IYMVU`05IYL00`00I[MV]`06I[L00`00I[MV]`06I[L00`00I[MV]`05I[L00`00
I[MV]`06I[L00`00I[MV]`05I[L20006I[L00`00I[L00004I]L01000J]MZe`0016[G00<006[GJ]L0
0V[G00@006[GJ]L000EZe`03001Zef[G00EZe`03001Zef[G00AZe`04001Zef[G0003J]L00`00J_MZ
m`02J_L00`00J_L00006J_L00`00K_M^m`03K_L01@00J_QZn6[h00000VKi00<006/HJaP00f/H0P00
1EKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d00`0000=Fo@00E_d01UKm00<005Km0000
0P000UKm00@007ooOol00<=oo`00ogoo0Goo0`002goo0`001EKm00<005KmE_d015Km0P001UKm00<0
05KmE_d00eKm0P001eKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000UKm00<0
05KmE_d015Km00<005Km00000P000UKm00<005KmE_d015Km00@005Km000000AFo@03001FoEKm00=F
o@<000EFo@03001FoEKm00=Fo@03001BFE9I009BF@03001>=dhg00=>=`03000i]cVg008i]`030015
n4Gh0095n00300165dHG00=65`030011md7g00=1m`030015mdGg00X000=9m`030019mdWg00=9m`03
0019mdWg0099m`030019mdWg00=9m`03001:5dXG00=:5`03001:5dXG00=:5`03001:5dXG00=:5`03
001>5dhG00@000A>5`03001>5dhG00A>5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5dhG00=>
5`8000A>5`03001>5dhG00A>5`03001>5dhG00=>5`03001>5ThF00A>5P03001>5P0000800003CQH0
058F00AB5P03001B5U8F00AB5P03001B5U8F00AB5P8000EB=P03001B=U8f00=B=P03001B=U8f00AB
=P<000=B=P03001F=UHf00EF=P03001F=UHf00=F=P8000EF=P03001F=UHf00AF=P03001F=UHf0080
009F=P03001F=UHf00EF=P03001F=UHf00=F=P8000IF=P03001JEUYF00AJEP8000IJEP03001JEUYF
00AJEP03001JEUYF00AJEP03001JEUYF00AJEP8000MJEP03001JEUYF009JEP03001JEP0000MJEP04
001NEUiF0004GUH00`00GWINMP05GWH00`00GWINMP05GWH01@00GWINMUif00000eif00<005ifGWH0
15if00<005ifGWH01Eif00@005ifGWH000ANMP03001NMUif00=NMP04001RMV9f0007HWH00`00HWIR
MP05HWH00`00HYH00006HYH01000HYIRUP000f:F00<006:FHYH00f:F00@006:FHYH000IRUP03001R
UP0000IRUP03001RUP0000IVU`03001V]fJg00IV]`03001V]fJg00IV]`03001V]fJg00EV]`03001V
]fJg00EV]`03001V]`0000EV]`03001V]`0000EV]`04001V]fJg0003I]L00`00J]MZe`02J]L01000
J]MZe`001F[G00<006[G00001V[G00<006[GJ]L016[G00<006[G000016[G00D006[GJ]MZe`00009Z
e`03001Zmf[g00AZm`03001Zmf[g00AZm`03001Zm`0000=^m`03001Zn6[h009Zn003001Vn@0000I[
6003001FoEKm00AFo@<000EFo@03001FoEKm00=Fo@<000EFo@03001FoEKm00AFo@8000IFo@04001o
ogoo0032Ool00?ioo`8000]oo`<0009Fo@03001FoEKm00AFo@03001FoEKm00<00003E_d005Km00IF
o@03001Fo@0000800003E_d005Km00IFo@8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=F
o@8000IFo@03001FoEKm00=Fo@<000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001FoEKm
009Fo@03001BFE9I009BF@03001>=dhg00A>=`03000i]cVg008i]`030015n4Gh0095n00300165dHG
00/00095m`030015mdGg0095m`030019mdWg00A9m`030019mdWg0099m`030019mdWg0099m`030019
mdWg00A9m`03001:5dXG009:5`03001:5dXG00=:5`03001:5dXG009:5`@000=:5`03001>5dhG00=>
5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5dhG00A>5`03001>5`0000800003CQL004hG00A>
5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5ThF00=>5P<000A>5P03001B5U8F00AB5P03001B
5U8F00=B5P03001B5U8F00=B5P8000IB=P03001B=U8f00=B=P03001B=U8f00=B=P8000IB=P03001F
=UHf00AF=P03001F=UHf009F=P03001F=P0000IF=P03001F=UHf00AF=P8000EF=P03001F=UHf00AF
=P03001F=UHf009F=P03001F=P0000MF=P03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00=J
EP8000MJEP03001JEUYF009JEP03001JEP0000MJEP05001JEUYFFUH00003FUH00`00FUIJEP05FUH2
0005GUH00`00GWINMP04GWH20007GWH01000GWINMP0015if00<005ifGWH015if00<005ifGWH01Uif
0P001Uif00D005ifGWINMP0000=RMP03001RMV9f00ARMP8000QRMP03001RUV:F00ERUP04001RUV:F
0004HYH01@00HYIRUV:F00000f:F00<006:FHYH00f:F00@006:FHYH000ERUP04001RUV:F0005IYL0
0`00IYH00006I[L00`00I[L00006I[L00`00I[L00005I[L00`00I[L00005I[L01000I[MV]`0016Jg
00@006JgI[L000AV]`03001V]fJg009V]`04001VefKG0004J]L00`00J]L00007J]L00`00J]MZe`04
J]L00`00J]L00004J]L01@00J]MZef[G00000V[G00<006[GJ]L00f[G0P001f[g00<006[gJ_L00f[g
00@006[gJ_L0009^m`03001Zn6[h00AZn003001[66/H00A[6003001_6000009Fo@<00003E_d005Km
00EFo@03001FoEKm00<00003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00EFo@800003Ool0
07oo0<5oo`00ngoo0`002goo0P001UKm00<005KmE_d00eKm0`001EKm00<005KmE_d015Km0P001EKm
00<005KmE_d00UKm0P0000=Fo@00E_d01UKm00<005Km00000P0000=Fo@00E_d01UKm00<005Km0000
0P000UKm00<005KmE_d015Km00<005Km00000P000eKm00<005KmE_d00eKm0P001UKm00<005KmE_d0
0eKm1P001E9I00<004hgCSL040000TGg00<004GgAOL00dGg00<004GgAOL00TGg00<004GgAOL00dGg
00<004WgBOL00dWg00<004WgBOL00TWg00<004WgBOL00dWg00<004WgBOL00dWg00<004XGBQL00TXG
00<004XGBQL014XG100000=:5`00BQL014XG00<004hGCQL00dhG00<004hGCQL014hG00<004hGCQL0
0ThG00<004hGCQL00dhG0`0014hG00<004hGCQL00dhG00<004hGCQL014hG00<004hGCQL00ThG00@0
04hFCQI>5P800003CQH004hF00E>5P03001B5U8F00=B5P03001B5U8F00=B5P04001B5U8FDQH20000
0e8F001B=P05DSH00`00DSIB=P03DSH01000DSIB=U8f0P0000=B=P00DSH01E8f00<005HfESH015Hf
00<005HfESH00P000UHf00<005HfESH015Hf00<005HfESH015Hf00<005HfESH015Hf00<005HfESH0
15Hf00<005HfESH00P000UHf00<005HfESH01EHf00D005YFFUIJEP00009JEP03001JEUYF00EJEP05
001JEUYFFUH00002FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF00<005YFFUH015YF00@005YF
FUH000AJEP03001JEUYF00EJEP03001NEUiF00ENEP03001NMUif009NMP04001NMUif0007GWH20006
GWH00`00GWINMP02GWH00`00GWH00007GWH00`00GWINMP05GWH01000GWINMP00169f00<0069fHWH0
0f9f00@0069fHWH000MRMP03001RUV:F00ERUP03001RUP0000ERUP04001RUV:F0005HYH01@00HYIR
UV:F00000f:F00<006:FHYH00V:F00D006:FHYIRUP0000AVU`04001VUVJF0005I[L01000I[MV]`00
1FJg00@006JgI[L000AV]`04001V]fJg0004I[L00`00I[MV]`02I[L01000I[MV]`000fJg0P000VJg
00<006JgI[L00fJg00<006KG00001V[G00<006[GJ]L01V[G00<006[GJ]L00f[G00@006[GJ]L000=Z
e`03001Zef[G009Ze`03001Ze`0000IZe`03001Zmf[g00EZm`03001Zm`0000=Zm`07001Zmf[gJ_L0
06kg00001f[h00<006/HJaP00f/H00@006lHKaQ_608000EFo@03001FoEKm00=Fo@<000EFo@03001F
oEKm00AFo@<000EFo@04001FoEKmE_d200001EKm001oogoo0000`Goo003iOol2000;Ool30002E_d0
0`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_eFo@0300000eKm001Fo@05
E_d01000E_d0000015Km00<005KmE_d015Km0P001EKm00<005KmE_d015Km0P001UKm00<005KmE_d0
0eKm0P001eKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P0000=BF000>KL00SVg
2@000dGg00<0047g@OL00T7g00<004GgAOL00TGg00<004GgAOL00TGg00<004GgAOL014Gg00<004Gg
AOL00TGg00<004GgAOL00TGg00<004WgBOL00dWg00<004WgBOL00dWg00<004WgBOL00TWg00<004Wg
BOL00dWg00<004XGBQL00dXG00<004XGBQL0100014XG00<004XGBQL014XG00<004hGCQL00ThG00<0
04hGCQL014hG00<004hGCQL00dhG00<004hG00000P0000=>5`00CQL01DhG00<004hGCQL00ThG00<0
04hGCQL014hG00<004hGCQL00dhG0`000dhF00<004hFCQH014hF00<0058FDQH0158F00<0058FDQH0
0e8F0`000e8F00<0058fDSH01E8f00<0058fDSH00e8f0`000e8f00<0058fDSH0158f00<005HfESH0
1EHf0P001EHf00<005HfESH00eHf00<005HfESH00eHf0P001UHf00<005HfESH01EHf0P001EHf00<0
05HfESH015Hf00@005YFFUH000AJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJEP04FUH0
1000FUIJEP0015YF00<005YFFUH01EYF0P001EYF00<005YFFUH015YF0P001eiF00D005ifGWINMP00
00=NMP03001NMUif00ENMP03001NMUif00ENMP05001NMUifGWH00002GWH00`00GWINMP05GWH00`00
GWINMP05GWH00`00GWH00006HWH01@00HWIRMV9f00000f9f00<0069fHWH0169f00<006:F00001f:F
00<006:FHYH016:F00<006:F00001V:F00@006:FHYH000ERUP05001RUV:FHYH00004HYH01000IYMV
U`0016JF00D006JgI[MV]`0000AV]`05001V]fJgI[L00004I[L01000I[MV]`0016Jg00D006JgI[MV
]`0000AV]`04001V]fJg0003I[L200000fJg001V]`06I[L00`00J]MZe`05J]L00`00J]MZe`05J]L0
0`00J]L00003J]L00`00J]MZe`02J]L01000J]MZe`001F[G00<006[GJ]L01F[G00<006[gJ_L016[g
00@006[gJ_L0009Zm`03001Zmf[g00=Zm`03001Zn6[h00EZn003001Zn00000=[6003001_66lH009_
6003001FoEKm00EFo@03001Fo@0000800003E_d005Km00IFo@03001FoEKm00<00003E_d005Km00EF
o@04001Fo@000004E_d01000Oomoo`00`7oo003fOol3000;Ool20006E_d00`00E_eFo@03E_d20006
E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@03E_d30006E_d00`00E_eFo@0300000eKm001Fo@05
E_d00`00E_eFo@0300000eKm001Fo@06E_d00`00E_d000020002E_d00`00E_eFo@04E_d20006E_d0
0`00E_eFo@03E_d20005DUP01@00>KLi]cVg000014Gh00<004GgAOL014Gg00<0047g@OL00T7g00<0
04GgAOL00TGg00<004GgAOL00TGg00<004GgAOL00dGg00<004GgAOL00TGg00<004GgAOL00TGg00<0
04WgBOL014Wg00<004WgBOL00TWg00<004WgBOL00TWg00<004WgBOL014Wg00<004XGBQL01@000dXG
00<004XGBQL00dXG00<004XGBQL00dXG00<004hGCQL00dhG00<004hGCQL00dhG00<004hGCQL00ThG
0`0014hG00<004hGCQL014hG00<004hGCQL00dhG00<004hGCQL00dhG00<004hGCQL00ThG0P001ThF
00<004hFCQH00dhF00<0058FDQH0158F00<0058FDQH00U8F0P001U8F00<0058fDSH0158f00<0058f
DSH00U8f0P001U8f00<0058fDSH0158f00<005HfESH00eHf0P001UHf00<005HfESH015Hf00L005Hf
ESIF=P00ESH00007ESH00`00ESIF=P03ESH20006ESH00`00ESIF=P05ESH20005FUH00`00FUIJEP04
FUH00`00FUH00004FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP04FUH20007FUH00`00FUIJEP02
FUH00`00GUH00007GUH01000GWINMP0015if00<005ifGWH015if0P001eif00@005ifGWH000ANMP03
001NMUif00=NMP03001NMP0000MNMP03001RMV9f00ERMP04001RMV9f0004HWH00`00HWIRMP03HWH0
1000HYIRUP001f:F00<006:FHYH01F:F00<006:FHYH01F:F00<006:F00001V:F00@006:FHYH000ER
UP04001VUfJG0004IYH01000I[MV]`001FJg00@006JgI[L000EV]`04001V]fJg0004I[L01000I[MV
]`001FJg00<006Jg000016Jg00<006Jg000026Jg00<006[GJ]L016[G00<006[G00001F[G00@006[G
J]L000=Ze`03001Zef[G009Ze`03001Ze`0000IZe`03001Zef[G00AZe`03001Zm`0000AZm`07001Z
mf[gJ_L006[g00001V[g00<006[hJ_P016[h00@006[hJ_P0009[6003001_66lH009_6003001_5`00
00IFo@8000EFo@03001FoEKm00AFo@<000EFo@03001FoEKm00=Fo@8000IFo@04001oogoo0030Ool0
0?Aoo`8000]oo`<0009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001F
o@000080009Fo@03001FoEKm00AFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@<000EFo@03001F
oEKm00=Fo@<000EFo@03001FoEKm00AFo@8000IFo@03001FoEKm00<00003E_d005Km00IFo@03001F
o@0000800003E_d0059H00ABF003000i]cVg008i]`030015n4Gh0095n0030015mdGg00=5m`030011
md7g0091m`030015mdGg0095m`030015mdGg0095m`030015mdGg00=5m`030015mdGg0095m`030015
mdGg00=5m`030019mdWg00=9m`030019mdWg0099m`030019mdWg00=9m`030019mdWg00H00099m`03
001:5dXG00=:5`03001:5dXG00=:5`03001:5dXG00=:5`03001>5dhG00=>5`03001>5dhG00A>5`@0
0003CQL004hG00E>5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5dhG00A>5`@00003CQH004hF
00E>5P03001>5ThF00A>5P03001B5U8F00=B5P03001B5P0000800003DQH0058F00EB5P03001B=U8f
00AB=P07001B=U8fDSH0058f00001U8f00<0058fDSH0158f00<005HfESH00UHf00<005Hf00001UHf
00<005HfESH015Hf00@005HfESH000=F=P03001F=UHf00AF=P03001F=UHf009F=P03001F=P0000IF
=P03001F=UHf00AF=P8000IJEP03001JEUYF00AJEP8000IJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000MJEP05001JEUYFFUH00003GUH00`00GUINEP05GUH20006GWH0
0`00GWINMP02GWH01000GWINMP001eif0P001Eif00<005ifGWH00Uif00@005ifGWH000MNMP03001R
MV9f00ERMP03001RMP0000IRMP05001RMV9fHWH00003HYH00`00HYIRUP04HYH00`00HYH00006HYH0
0`00HYIRUP06HYH00`00HYIRUP05HYH00`00HYH00006HYH00`00IYL00005IYH00`00I[L00006I[L0
0`00I[L00006I[L00`00I[L00005I[L00`00I[L00007I[L00`00I[MV]`03I[L00`00I[L00007I[L0
0`00J]L00004J]L01000J]MZe`0016[G00D006[GJ]MZe`00009Ze`03001Zef[G00AZe`03001Zef[G
00AZe`03001Ze`0000AZe`05001Zmf[gJ_L00002J_L00`00J_MZm`03J_L00`00J_MZm`04J_L00`00
J_L00004J_P01`00J_QZn6[h001[600000A_6005001_5flGKaL00002E_d300000e9i001Fo@05E_d0
0`00E_eFo@0300000eKm001Fo@05E_d00`00E_eFo@030002E_d00`00E_eFo@03E_d20002Ool00`00
Oomoo`2mOol00?5oo`<000]oo`8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IF
o@03001FoEKm00=Fo@<000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009F
o@03001FoEKm00AFo@03001FoEKm00<0009Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm00AFo@80
00EFo@03001BF59H009BF003000i]cVg008i]`030015n4Gh0095n0030015mdGg00=5m`030011md7g
0091m`030015mdGg0095m`030015mdGg0095m`030015mdGg00A5m`030015mdGg0095m`030015mdGg
0095m`030019mdWg00=9m`030019mdWg00=9m`030019mdWg00D000=9m`030019mdWg0099m`03001:
5dXG00A:5`03001:5dXG009:5`03001:5dXG00A:5`03001>5dhG009>5`03001>5dhG00=>5`8000A>
5`03001>5dhG00A>5`03001>5dhG00A>5`03001>5dhG009>5`03001>5dhG00=>5`8000E>5P03001>
5ThF00=>5P03001>5ThF00A>5P03001B5U8F00=B5P8000AB5P03001B5U8F00AB5P03001B=U8f00AB
=P04001B=U8f0003DSH00`00DSIB=P03DSH00`00DSIB=P04DSH00`00ESIF=P020002ESH00`00ESIF
=P05ESH00`00ESIF=P03ESH00`00ESH00004ESH00`00ESIF=P04ESH00`00ESIF=P020002ESH00`00
ESIF=P05ESH00`00ESIF=P02ESH00`00ESH00007FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00
FUIJEP03FUH20007FUH01@00FUIJEUYF00000UYF00<005YFFUH01EYF00@005YFFUH000ANEP03001N
EUiF00ENEP03001NMUif00ENMP05001NMUifGWH00003GWH00`00GWINMP05GWH00`00GWINMP04GWH0
1@00GWINMUif000015if00<005ifGWH00eif00<005if00001f9f00<0069fHWH01F9f00@0069fHWH0
00ERUP03001RUV:F009RUP04001RUV:F0005HYH00`00HYH00007HYH00`00HYIRUP06HYH00`00HYIR
UP06HYH00`00IYIVUP05IYH00`00I[MV]`06I[L00`00I[MV]`06I[L00`00I[MV]`05I[L00`00I[MV
]`06I[L00`00I[MV]`03I[L200000fJg001V]`04I[L01000J]MZe`0016[G00D006[GJ]MZe`00009Z
e`03001Zef[G00=Ze`8000MZe`03001Zef[G00=Ze`04001Zef[G0003J]L00`00J_MZm`02J_L00`00
J_L00006J_L00`00J_MZm`03J_L01@00J_MZmf[g00000V[h00<006[hJ_P00f[h00<006lHKaP00flH
00<006lGKaL00VlG0P001E9i00<005KmE_d00eKm0`001EKm00<005KmE_d00eKm0`001UKm00<005Km
00000P0000=Fo@00Ool00Woo00<007ooOol0_7oo003_Ool2000<Ool20002E_d00`00E_eFo@04E_d0
0`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d0
00020003E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d30006
E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_eFo@0300000eKm001Fo@04E_d00`00DUQB
F003DUP01@00>KLi]cVg00001DGh00<004GgAOL00dGg00<0047g@OL00T7g00<004GgAOL00TGg00<0
04GgAOL00TGg00<004GgAOL00dGg00<004GgAOL00TGg00<004GgAOL00TGg00<004WgBOL014Wg00<0
04WgBOL01@000TWg00<004WgBOL00dWg00<004WgBOL00dWg00<004XGBQL00dXG00<004XGBQL00dXG
00<004XGBQL00dXG00<004hGCQL00dhG00<004hG00000P0000=>5`00CQL014hG00<004hGCQL00dhG
00<004hGCQL014hG00<004hGCQL00ThG00@004hGCQM>5`800003CQH004hF00A>5P03001>5ThF00A>
5P03001>5ThF00=>5P04001B5U8FDQH200000e8F001B5P04DQH00`00DQIB5P04DQH00`00DSIB=P04
DSH20004DSH00`00DSIB=P04DSH00`00DSIB=P04DSH20005ESH00`00ESIF=P04ESH00`00ESIF=P03
ESH20005ESH00`00ESIF=P05ESH20005ESH00`00ESIF=P04ESH01@00ESIF=UHf00000UHf00<005YF
FUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP04
FUH01000FUIJEP0015YF00<005YFFUH01EYF0P001EiF00<005iFGUH015iF0P001eif00@005ifGWH0
00ANMP03001NMUif00ANMP8000MNMP04001NMUif0004GWH00`00GWINMP02GWH01000GWINMP001f9f
00<0069fHWH01F9f00<0069f00001V:F00D006:FHYIRUP0000=RUP03001RUV:F009RUP04001RUV:F
0006HYH00`00HYH00007HYH00`00HYIRUP06HYH00`00IYIVUP05IYH00`00I[MV]`06I[L00`00I[MV
]`06I[L00`00I[MV]`05I[L00`00I[MV]`05I[L00`00I[L00004I[L01000I[MV]`0016Jg00<006[G
J]L00V[G00@006[GJ]L000AZe`03001Ze`0000IZe`03001Zef[G00EZe`03001Ze`0000AZe`05001Z
ef[GJ]L00002J]L00`00J_MZm`03J_L00`00J_MZm`04J_L00`00J_L00004J_L01`00J_MZmf[g001Z
n00000IZn003001_66lH009_6003001_5flG00=_5`03001BNE9i00ABN@03001FoEKm00<00003E_d0
05Km00EFo@03001FoEKm00<0009Fo@03001FoEKm00AFo@8000EFo@04001oogoo002nOol00>aoo`<0
00eoo`03001FoEKm00=Fo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm
00=Fo@<000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm
00AFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@<000EFo@03001F
oEKm00=Fo@03001BF59H009BF003000i]cVg008i]`030015n4Gh0095n0030015mdGg00=5m`030011
md7g0091m`030015mdGg0095m`030015mdGg0095m`030015mdGg00=5m`030015mdGg0095m`030015
mdGg00=5m`030019mdWg00H00099m`030019mdWg00=9m`030019mdWg00=9m`030019mdWg0099m`03
001:5dXG00=:5`03001:5dXG00=:5`03001:5dXG00=:5`03001>5dhG009>5`<000A>5`03001>5dhG
00=>5`03001>5dhG00A>5`03001>5dhG00=>5`03001>5dhG00=>5`<000=>5P03001>5ThF00=>5P03
001>5ThF00A>5P03001>5ThF00A>5P<000=B5P03001B5U8F00=B5P03001B5U8F00AB5P03001B=U8f
00=B=P8000EB=P03001B=U8f00AB=P03001B=U8f00=B=P8000IF=P03001F=UHf00AF=P03001F=UHf
009F=P03001F=P0000IF=P03001F=UHf00=F=P8000IF=P03001F=UHf00AF=P04001F=UHf0004ESH0
0`00FUIJEP04FUH01000FUIJEP0015YF00<005YFFUH015YF00@005YFFUH000=JEP03001JEUYF00EJ
EP8000EJEP03001JEUYF00EJEP03001NEUiF00ENEP03001NEUiF009NEP04001NEUiF0007GWH20006
GWH00`00GWINMP02GWH01000GWINMP001Uif00<005if00001Eif00D005ifGWINMP0000=NMP03001R
MV9f00ARMP03001RMP0000MRMP03001RUV:F00ERUP04001RUV:F0005HYH01000HYIRUP000f:F00<0
06:FHYH00f:F00@006:FHYH000IRUP03001RUP0000IRUP03001VUP0000EVUP03001VUP0000IV]`03
001V]`0000IV]`03001V]`0000EV]`03001V]`0000EV]`04001V]fJg0004I[L01@00I[MV]fJg0000
0fJg00<006[GJ]L00V[G00@006[GJ]L000EZe`03001Zef[G00EZe`03001Zef[G00AZe`04001Zef[G
0003J]L00`00J]MZe`02J]L00`00J]L00006J_L00`00J_MZm`03J_L01000J_MZm`000f[g00<006[g
J_L00f[g00<006[hJ_P016[h00<006lH00000flH00<006lGKaL00VlG00<006kg00001U9i0P001EKm
00<005KmE_d00eKm0`001UKm00<005KmE_d00`0000=Fo@00E_d01EKm00@007ooOol00;eoo`00jGoo
0`003Woo0P001eKm00<005Km00000P0000=Fo@00E_d01UKm00<005Km00000P000UKm00<005KmE_d0
15Km00<005Km00000P000eKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001UKm00<005Km
E_d00eKm0`001UKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000UKm00<005Km
E_d015Km00<005KmE_d00UKm00<0059HDUP00U9H00<003Vg>KL00SVg00<004GhAOP00TGh00<004Gg
AOL00dGg00<0047g@OL00T7g00<004GgAOL00TGg00<004GgAOL00TGg00<004GgAOL014Gg00<004Gg
AOL00TGg00<004GgAOL01@000dGg00<004WgBOL00TWg00<004WgBOL00dWg00<004WgBOL00dWg00<0
04WgBOL00TWg00<004XGBQL014XG00<004XGBQL00TXG00<004XGBQL014XG100000=:5`00CQL01DhG
00<004hGCQL00ThG00<004hGCQL014hG00<004hGCQL00dhG00<004hGCQL00ThG0P001ThF00<004hF
CQH00dhF00<004hFCQH00dhF00<004hFCQH00dhF0P001U8F00<0058FDQH00U8F00<0058FDQH0158F
00@0058fDSIB=P800003DQH0058f00EB=P03001B=U8f00=B=P04001B=U8fDSH200000e8f001F=P05
ESH00`00ESIF=P04ESH00`00ESIF=P020002ESH00`00ESIF=P04ESH00`00ESIF=P02ESH00`00ESH0
0006ESH00`00ESIF=P05ESH20005ESH00`00FUIJEP05FUH20005FUH00`00FUIJEP04FUH00`00FUH0
0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP04FUH20007GUH01@00GUINEUiF0000
0eiF00<005ifGWH01Eif00<005ifGWH01Eif00D005ifGWINMP0000=NMP03001NMUif00ENMP03001N
MUif00ENMP04001NMUif0004GWH00`00HWIRMP02HWH01000HWIRMP001f9f00<006:FHYH01V:F0P00
1V:F00@006:FHYH000ARUP05001RUV:FHYH00003HYH00`00HYIRUP03HYH01000HYIRUP001F:F00@0
06JFIYH000AVUP04001VUVJF0005I[L01000I[MV]`001FJg00@006JgI[L000AV]`04001V]fJg0004
I[L00`00I[MV]`02I[L00`00I[MV]`020003I[L01000I[MV]`001F[G00<006[G00001V[G00<006[G
J]L016[G00<006[G000016[G00<006[GJ]L00V[G00@006[GJ]L000EZe`03001Zmf[g00AZm`03001Z
m`0000AZm`05001Zmf[gJ_L00002J_L00`00J_MZm`03J_L00`00J_QZn003J_P01`00KaQ_66lH001_
600000A_5`04001^mfkg0005DWT20006E_d00`00E_eFo@030002E_d00`00E_eFo@04E_d30005E_d0
0`00E_eFo@03E_d200000goo001oo`2lOol00>Moo`8000ioo`<0009Fo@03001FoEKm00AFo@8000EF
o@03001FoEKm00AFo@8000IFo@03001FoEKm00=Fo@8000MFo@03001Fo@000080009Fo@03001FoEKm
00AFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@80
00IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@H000EBF005000i]cVg>KL00005AOP00`00
AOM5m`03AOL00`00@OM1m`02@OL00`00AOM5m`02AOL00`00AOM5m`02AOL00`00AOM5m`0;0002AOL0
0`00AOM5m`03AOL00`00BOM9m`03BOL00`00BOM9m`02BOL00`00BOM9m`03BOL00`00BOM9m`03BOL0
0`00BQM:5`03BQL00`00BQM:5`03BQL00`00BQM:5`040004BQL00`00CQM>5`04CQL00`00CQM>5`03
CQL00`00CQM>5`03CQL00`00CQM>5`04CQL400000dhF001>5P05CQH00`00CQI>5P03CQH00`00CQI>
5P03CQH01000CQI>5ThF0P0000=>5P00DQH01E8F00<0058FDQH00e8F00<0058FDQH0158F0`000e8F
00<0058fDSH0158f00<0058fDSH0158f0`000e8f00<005HfESH01EHf00<005HfESH015Hf0P001EHf
00<005HfESH00eHf00D005HfESIF=P00009F=P03001F=UHf00EF=P03001F=UHf00=F=P8000IF=P03
001JEUYF00AJEP8000IJEP03001JEUYF00AJEP8000IJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000MNEP04001NEUiF0004GUH00`00GWINMP04GWH20007GWH01000GWIN
MP0015if00<005ifGWH015if0P001eif00<005if00001Eif00D0069fHWIRMP0000=RMP03001RMV9f
00ARMP03001RMP0000MRUP03001RUV:F00ERUP03001RUP0000ERUP04001RUV:F0005HYH01@00HYIR
UV:F000016:F00D006:FHYIRUP0000=VUP03001VUVJF009VUP04001VUVJF0004I[L01@00I[MV]fJg
000016Jg00<006JgI[L00VJg00@006JgI[L000AV]`05001V]fJgI[L00004I[L00`00I[MV]`020003
I[L00`00I[L00007J]L00`00J]MZe`04J]L00`00J]L00004J]L01000J]MZe`0016[G00<006[GJ]L0
0V[G00<006[G00001V[G00<006[gJ_L00f[g00@006[gJ_L000=Zm`03001Zmf[g009Zm`03001Zm`00
00EZm`03001Zn00000=Zn003001_66lH00=_6003001_5flG00=_5`05001^mfkgK_L00003DWT01000
I_UVn@001EKm0`001UKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d00`0000EFo@00Oomo
o`000;aoo`00i7oo0`003Goo0`001UKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d00`00
00=Fo@00E_d01UKm00<005Km00000P000UKm00<005KmE_d015Km0P001UKm00<005KmE_d00eKm0P00
1UKm00<005KmE_d00eKm0P001eKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P00
0UKm00<005KmE_d015Km00<005Km00000P0000=>=`00=IL00SFG2P0000<i]`00AOP00dGh00@004Gg
AOM5ma@000=5m`030015mdGg0095m`030015mdGg0095m`030015mdGg00A5m`030019mdWg0099m`03
0019mdWg00=9m`030019mdWg00=9m`030019mdWg0099m`03001:5dXG00=:5`03001:5dXG009:5`@0
00=:5`03001:5dXG00=:5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5dhG
00=>5`8000A>5P03001>5ThF00A>5P03001>5ThF00A>5P03001>5ThF00=>5P<000=>5P03001B5U8F
00AB5P03001B5U8F00=B5P03001B5U8F00=B5P8000IB5P03001B=U8f00=B=P03001B=U8f00=B=P80
00IB=P03001F=UHf00AF=P03001F=UHf00=F=P8000IF=P03001F=UHf00=F=P04001F=UHf0004ESH0
0`00ESIF=P04ESH00`00ESIF=P02ESH00`00ESH00007ESH00`00FUIJEP02FUH00`00FUH00007FUH0
0`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP03FUH00`00FUH00006FUH01@00FUIJEUYF0000
0eYF00<005iFGUH01EiF0P001UiF00<005ifGWH00Uif00<005if000025if0P001Uif00<005ifGWH0
0Uif00@005ifGWH000MNMP03001NMUif00ANMP04001RMV9f0005HWH00`00HWIRMP02HWH01000HWIR
MP001f:F00<006:FHYH01V:F00<006:FHYH016:F00<006:F00001V:F00@006:FHYH000ERUP04001R
UV:F0005IYH01000IYIVUP0016JF00D006JgI[MV]`0000AV]`05001V]fJgI[L00004I[L01000I[MV
]`0016Jg00@006JgI[L000EV]`05001V]`00I[L00004I[L00`00J]MZe`06J]L00`00J]MZe`03J]L0
1000J]MZe`000f[G00<006[GJ]L00V[G00@006[GJ]L000IZe`03001Zef[G00AZe`03001Ze`0000AZ
m`05001Zmf[gJ_L00002J_L00`00J_MZm`03J_L00`00J_MZm`03J_L01@00J_QZn6[h00000V[h00<0
06lHKaP00flH00<006lGKaL00VlG00<006kgK_L00Vkg00@0059iDWT000AVn@03001Fo@000080009F
o@03001FoEKm00AFo@<000EFo@03001FoEKm00=Fo@<000EFo@@00;]oo`00hWoo0P003Goo0`000eKm
00<005KmE_d00eKm0`001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d015Km0P001UKm00<005Km
E_d00`0000=Fo@00E_d01UKm00<005Km00000P0000=Fo@00E_d01UKm00<005Km00000P000UKm00<0
05KmE_d015Km0P001UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P0014hg00<003FG=IL0
0SFG00<0047h@OP00T7h00@003gG?MLme`X00095m`030011md7g0091m`030015mdGg0095m`030015
mdGg0095m`030015mdGg00=5m`030015mdGg00=5m`030015mdGg0095m`030015mdGg00=5m`030019
mdWg0099m`030019mdWg00=9m`030019mdWg00=9m`030019mdWg0099m`03001:5dXG00A:5`@00003
BOL004XG00A:5`03001:5dXG00=:5`03001>5dhG00A>5`03001>5dhG009>5`03001>5dhG00A>5`03
001>5`0000800003CQH004hF00A>5P03001>5ThF00A>5P03001>5ThF00=>5P03001>5ThF009>5P80
00I>5P03001B5U8F00AB5P03001B5U8F009B5P04001B5U8FDQH200000e8F001B5P05DQH00`00DSIB
=P04DSH01`00DSIB=U8f001B=P0000IB=P03001F=UHf00AF=P04001F=UHfESH200000eHf001F=P05
ESH00`00ESIF=P04ESH20005ESH00`00ESIF=P04ESH00`00ESIF=P020002ESH00`00ESIF=P05ESH0
1@00FUIJEUYF00000UYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00EJEP05001J
EUYFFUH00002FUH00`00FUIJEP04FUH01000FUIJEP0015YF00<005iFGUH01EiF00<005iFGUH01EiF
00D005ifGWINMP0000=NMP03001NMUif00ENMP03001NMUif00ENMP05001NMUifGWH00003GWH00`00
GWINMP05GWH00`00GWINMP05GWH20006HWH01@00HWIRMV9f00000f9f00<006:FHYH016:F00<006:F
00001f:F00<006:FHYH01F:F00<006:FHYH01F:F00<006:F00001V:F00<006:F00001VJF00@006JF
IYH000AVUP04001V]fJg0005I[L01000I[MV]`001FJg00<006Jg00001FJg00<006Jg00001fJg00@0
06JgI[L000AV]`03001Zef[G00EZe`03001Ze`0000AZe`05001Zef[GJ]L00002J]L00`00J]MZe`02
J]L00`00J]L00007J]L00`00J]MZe`03J]L01000J]MZe`000f[g00<006[gJ_L00V[g00<006[g0000
1V[g00<006[gJ_L00f[g00L006[hJ_QZn000J_P00005KaP00`00KaL00002KaL00`00K_M^m`03K_L0
0`00DWT00006I_T00`00E_eFo@04E_d00`00E_eFo@0300000eKm001Fo@05E_d00`00E_eFo@030000
0eKm001Fo@05E_d01000Oomoo`00^goo003OOol4000<Ool30006E_d00`00E_d000020002E_d00`00
E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_eFo@030002E_d00`00E_eFo@03
E_d30005E_d00`00E_eFo@04E_d20005E_d00`00E_eFo@04E_d20006E_d00`00E_eFo@0300000eKm
001Fo@06E_d00`00E_d0000200000eKm001Fo@06E_d00`00E_d0000200000e9i001>=`04CSL00`00
=ILeU`02=IL00`00@OQ1n002@OP01@00?MLmecgG00001D7g00<004GgAOL00TGg00<0047g@OL00T7g
00<004GgAOL00dGg00<004GgAOL00TGg00<004GgAOL00dGg00<004GgAOL00TGg00<004GgAOL00TGg
00<004GgAOL00dGg00<004WgBOL00dWg00<004WgBOL00dWg00<004WgBOL00TWg00<004WgBOL00dWg
00<004XGBQL0100014Wg00<004XGBQL014XG00<004XGBQL00TXG00<004hGCQL014hG00<004hGCQL0
0ThG00<004hGCQL00dhG0`0014hF00<004hFCQH00dhF00<004hFCQH014hF00<004hFCQH00dhF00<0
04hF00000P0000=>5P00CQH01DhF00<0058FDQH0158F00<0058FDQH00e8F0`000e8F00<0058FDQH0
158F00<0058fDSH0158f00@0058fDSH0009B=P03001B=U8f00AB=P03001F=UHf00EF=P<000=F=P03
001F=UHf00EF=P03001F=UHf009F=P8000IF=P03001F=UHf00EF=P8000EF=P03001F=UHf00AF=P04
001JEUYF0004FUH00`00FUIJEP04FUH01000FUIJEP0015YF00<005YFFUH015YF00@005YFFUH000=J
EP03001JEUYF00EJEP8000EJEP03001NEUiF00ANEP8000MNEP04001NMUif0004GWH00`00GWINMP05
GWH00`00GWINMP05GWH01000GWINMP0015if00<005ifGWH015if00<005if00001Uif00<0069fHWH0
1F9f00@0069fHWH000ERMP03001RUV:F009RUP04001RUV:F0006HYH00`00HYH00006HYH00`00HYIR
UP06HYH00`00HYIRUP06HYH00`00IYIVUP05IYH00`00IYH00005IYH00`00I[L00006I[L00`00I[L0
0007I[L00`00I[MV]`05I[L00`00I[MV]`06I[L01000I[MV]`000fJg00<006Jg00001F[G00@006[G
J]L000=Ze`03001Zef[G009Ze`03001Ze`0000IZe`03001Zef[G00EZe`03001Ze`0000=Ze`03001Z
ef[G009Ze`04001Zmf[g0005J_L00`00J_MZm`04J_L00`00J_L00003J_L00`00J_QZn003J_P00`00
KaQ_6003KaP01000KaM_5`000VlG00<006kgK_L016kg00<006KiI_T016Ki0P001UKm0`001EKm00<0
05KmE_d00eKm0`001EKm00<005KmE_d00eKm0P000Woo00<007ooOol0^7oo003MOol20004Ool00`00
Oomoo`06Ool30003E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03
E_d30006E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_eFo@0300000eKm001Fo@05E_d0
0`00E_eFo@030002E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@04E_d20005E_d00`00E_eFo@04
E_d20005DWT00`00CSM>=`02CSL00`00=ILeU`02=IL00`00@OQ1n002@OP00`00?MLme`02?ML00`00
@OM1m`03@OL00`00AOM5m`02AOL00`00@OM1m`02@OL00`00AOM5m`02AOL00`00AOM5m`02AOL00`00
AOM5m`03AOL00`00AOM5m`02AOL00`00AOM5m`02AOL00`00AOM5m`04AOL00`00BOM9m`02BOL00`00
BOM9m`03BOL00`00BOM9m`03BOL00`00BOM9m`050003BOL00`00BOM9m`03BOL00`00BQM:5`03BQL0
0`00BQM:5`03BQL00`00CQM>5`03CQL00`00CQM>5`03CQL00`00CQL0000200000dhG001>5P05CQH0
0`00CQI>5P02CQH00`00CQI>5P04CQH00`00CQI>5P03CQH20004CQH00`00CQI>5P04CQH00`00DQIB
5P04DQH00`00DQIB5P02DQH20006DQH00`00DQIB5P04DQH00`00DSIB=P03DSH00`00DSH00004DSH0
0`00DSIB=P04DSH00`00ESIF=P03ESH20006ESH00`00ESIF=P04ESH01`00ESIF=UHf001F=P0000MF
=P03001F=UHf00=F=P8000IF=P03001F=UHf00EF=P8000EJEP03001JEUYF00EJEP8000EJEP03001J
EUYF00AJEP03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001NEUiF009NEP04001N
EUiF0007GUH20005GWH00`00GWINMP04GWH20008GWH20006GWH00`00GWINMP02GWH01000GWINMP00
1Uif00<0069fHWH01V9f0P001V9f00D006:FHYIRUP0000=RUP03001RUV:F00=RUP04001RUV:F0005
HYH00`00HYH00007HYH00`00HYIRUP06HYH00`00IYIVUP06IYH00`00IYIVUP05IYH00`00I[MV]`06
I[L00`00I[MV]`06I[L00`00I[MV]`05I[L00`00I[MV]`05I[L01@00I[L006Jg00000VJg00@006Jg
I[L000AZe`03001Zef[G009Ze`04001Zef[G0005J]L00`00J]MZe`05J]L00`00J]MZe`04J]L01000
J]MZe`000f[G00<006[GJ]L00V[G00<006[g00001V[g00<006[gJ_L00f[g00D006[gJ_MZm`00009Z
m`03001Zn6[h00=Zn003001_66lH009_6007001_5flGKaL006lG00001fkg00<006KiI_T00fKi00@0
06/IJaT0009Fo@<00003E_d005Km00EFo@03001FoEKm00<00003E_d005Km00EFo@03001FoEKm00<0
009Fo@04001oogoo002iOol00=Yoo`<000Moo`03001oogoo00=oo`<000IFo@03001Fo@000080009F
o@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@00008000=Fo@03001F
oEKm00=Fo@8000IFo@03001FoEKm00=Fo@<000EFo@03001FoEKm00=Fo@<000IFo@03001Fo@000080
009Fo@03001FoEKm00AFo@03001FoEKm00<00003E_d005Km00EFo@03001FoEKm00<00003E_d0059i
00ABN@03001>=dhg009>=`03000eUcFG008eU`030011n47h0091n003000mecgG008me`030011md7g
00=1m`030015mdGg0095m`030011md7g0091m`030015mdGg0095m`030015mdGg00=5m`030015mdGg
0095m`030015mdGg00=5m`030015mdGg0095m`030015mdGg00=5m`030019mdWg0099m`030019mdWg
00=9m`040019mdWgBOL50002BOL00`00BOM9m`03BOL00`00BOM9m`03BOL00`00BQM:5`03BQL00`00
BQM:5`03BQL00`00CQM>5`04CQL00`00CQM>5`040004CQL00`00CQI>5P04CQH00`00CQI>5P03CQH0
0`00CQI>5P03CQH01000CQI>5ThF0P0000=>5P00CQH014hF00<004hFCQH014hF00<0058FDQH00e8F
00<0058FDQH00P0000=B5P00DQH01E8F00<0058FDQH0158F00<0058fDSH00e8f0P001E8f00<0058f
DSH0158f00<005HfESH00UHf00<005Hf00001UHf00<005HfESH015Hf00@005HfESH000=F=P03001F
=UHf00AF=P03001F=UHf009F=P03001F=P0000IF=P03001F=UHf00AF=P8000IJEP03001JEUYF00AJ
EP8000IJEP03001JEUYF00AJEP8000IJEP03001JEUYF00=JEP8000MJEP05001NEUiFGUH00003GUH0
0`00GUINEP05GUH00`00GWINMP05GWH00`00GWINMP02GWH01000GWINMP001eif00<005ifGWH01Eif
00D005ifGWINMP0000=NMP03001NMUif00=NMP03001RMP0000MRMP03001RMV9f00ERMP04001RUV:F
0005HYH01@00HYIRUV:F00000f:F00<006:FHYH00V:F00@006:FHYH000IRUP03001RUP0000IRUP03
001VUP0000MVUP03001VUVJF00EVUP03001V]fJg00IV]`03001V]fJg00EV]`03001V]`0000EV]`03
001V]`0000EV]`04001V]fJg0002I[L00`00I[L00003I[L01000J]MZe`001F[G00<006[G00001V[G
00<006[GJ]L016[G00<006[G000016[G00D006[GJ]MZe`00009Ze`03001Zef[G00AZe`03001Zmf[g
00AZm`03001Zm`0000=Zm`03001Zmf[g009Zm`03001Zm`0000EZn003001^m`0000=_6003001_5flG
009_5`03001^mfkg00E^m`03001Zn00000=Vn@03001[6F/I009[6@8000EFo@03001FoEKm00=Fo@<0
00EFo@03001FoEKm00=Fo@<000IFo@03001oo`000;Uoo`00f7oo0P002goo00<007oo00000P000eKm
00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0`001UKm00<005Km
00000P000UKm00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P00
0eKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0`001EKm00<005KmE_d00eKm0`001EKm00<0
059iDWT00U9i00<004hgCSL00dhg00<003FG=IL00SFG00<0047h@OP00T7h00D003gG?MLme`0000E1
m`030015mdGg0095m`030011md7g0091m`030015mdGg00=5m`030015mdGg0095m`030015mdGg00=5
m`030015mdGg0095m`030015mdGg0095m`030015mdGg00=5m`030019mdWg00=9m`030019mdWg00H0
0099m`030019mdWg0099m`030019mdWg00A9m`030019mdWg0099m`03001:5dXG00A:5`03001:5dXG
009:5`03001>5dhG00=>5`@0009>5`03001>5dhG00A>5`03001>5ThF00=>5P03001>5ThF00=>5P03
001>5ThF00A>5P<000=>5P03001>5ThF00=>5P03001>5ThF00A>5P03001B5U8F00AB5P8000=B5P03
001B5U8F00AB5P03001B5U8F00AB5P04001B=U8fDSH200000e8F001B=P04DSH00`00DSIB=P04DSH0
0`00ESIF=P020002ESH00`00ESIF=P04ESH00`00ESIF=P05ESH20004ESH00`00ESIF=P04ESH01@00
ESIF=UHf00000UHf00<005HfESH01EHf00<005HfESH00UHf00<005Xf00001eYF00<005YFFUH00UYF
00<005YF00001eYF00<005YFFUH00UYF00<005YF00001eYF00D005YFFUIJEP00009JEP03001JEUYF
00AJEP04001NEUiF0004GUH00`00GUINEP04GUH20007GWH01@00GWINMUif00000eif00<005ifGWH0
1Eif00<005ifGWH01Eif00@005ifGWH000ENMP05001NMUifGWH00002HWH00`00HWIRMP05HWH00`00
HWIRMP06HWH20006HYH01000HYIRUP001F:F00@006:FHYH000ARUP03001RUV:F009RUP04001RUV:F
0005HYH01000IYIVUP001VJF00<006JF00001FJF00<006Jf00001VJg00<006Jg00001FJg00@006Jg
I[L000AV]`04001V]fJg0004I[L00`00I[MV]`02I[L01000I[L0000016Jg00<006[G00001f[G00<0
06[GJ]L016[G00<006[G000016[G00@006[GJ]L000AZe`03001Zef[G009Ze`8000MZe`03001Zmf[g
00=Zm`05001Zmf[gJ_L00002J_L00`00J_MZm`03J_L00`00J_QZn003J_P01000K_M^m`000VlH00<0
06lGKaL00flG00<006kgK_L016kg00@006[hJ_P0009Vn@03001[6F/I00=[6@03001FoEKm00AFo@03
001FoEKm00<00003E_d005Km00IFo@03001Fo@000080009Fo@03001FoEKm00AFo@800003Ool007oo
0;Moo`00eGoo0`003Goo0`001UKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P00
0UKm00<005KmE_d015Km00<005Km00000P000eKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm
0P001UKm00<005KmE_d00eKm0`001UKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km0000
0P000UKm00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d00eKm00<0059iDWT00e9i00<0
04hgCSL00Thg00<003FG=IL00SFG00<0047h@OP00T7h00<003gG?ML00SgG00<0047g@OL00d7g00<0
04GgAOL00TGg00<0047g@OL00T7g00<004GgAOL00TGg00<004GgAOL00TGg00<004GgAOL00dGg00<0
04GgAOL00TGg00<004GgAOL00TGg00<004GgAOL014Gg00<004WgBOL01@000dWg00<004WgBOL00TWg
00<004WgBOL00dWg00<004WgBOL00dWg00<004WgBOL00dWg00<004XGBQL00dXG00<004XGBQL00dXG
00<004hG00000P0000=>5`00CQL014hG00<004hGCQL00dhG00<004hFCQH014hF00<004hFCQH00ThF
00<004hFCQH00dhF0P001ThF00<004hFCQH00ThF00<004hFCQH014hF00<0058FDQH00e8F0P001E8F
00<0058FDQH0158F00<0058FDQH0158F0`000e8F00<0058fDSH0158f00<0058fDSH0158f0P001EHf
00<005HfESH015Hf00<005HfESH00eHf0P001EHf00<005HfESH015Hf00@005HfESH000AF=P03001F
=UHf00AF=P05001F=UHfESH00002FSH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH0
1EYF00D005YFFUIJEP00009JEP03001JEUYF00EJEP04001JEUYF0003FUH00`00FUIJEP05FUH20006
GUH00`00GUINEP02GUH00`00GUH00007GWH01000GWINMP0015if00<005ifGWH015if00<005if0000
1eif0P001Uif00@005ifGWH000ARMP03001RMV9f00=RMP03001RMP0000MRMP03001RUV:F00ERUP03
001RUP0000IRUP04001RUV:F0004HYH01@00HYIRUV:F00000f:F00<006:FHYH00V:F00D006JFIYIV
UP0000EVUP04001VUVJF0004IYH01000I[IV]P001FJg00@006JgI[L000AV]`03001V]fJg009V]`04
001V]fJg0004I[L01000I[MV]`001FJg00@006Jg000000EV]`03001Zef[G00IZe`03001Zef[G00=Z
e`04001Zef[G0004J]L01@00J]MZef[G00000V[G00<006[GJ]L00f[G00<006[GJ]L01F[G00<006[g
00000f[g00<006[gJ_L00V[g00<006[g00001V[g00<006[hJ_P00V[h00L006kgK_M^m`00KaP00005
KaL00`00K_L00004K_L01`00J_QZn6[h001Vn@0000E[6@03001_>00000EFo@<000EFo@03001FoEKm
00AFo@8000IFo@03001FoEKm00<00005E_d007ooOol0002gOol00=9oo`<000eoo`<000=Fo@03001F
oEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@<000IFo@03001Fo@000080
009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@00008000=Fo@03
001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm
00=Fo@03001BNE9i009BN@03001>=dhg009>=`03000eUcFG008eU`030011n47h0091n003000mecgG
008me`030011md7g00=1m`030015mdGg0095m`030011md7g0091m`030015mdGg0095m`030015mdGg
00=5m`030015mdGg0095m`030015mdGg00=5m`030015mdGg0095m`030015mdGg00H00095m`030019
mdWg00=9m`030019mdWg00=9m`030019mdWg0099m`030019mdWg00=9m`030019mdWg00=9m`03001:
5dXG00=:5`03001:5dXG009:5`<000A>5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5ThF00A>
5P03001>5ThF00=>5P03001>5P0000800003CQH004hF00E>5P03001>5ThF00=>5P03001>5ThF00=>
5P04001B5U8FDQH200000e8F001B5P04DQH00`00DQIB5P04DQH00`00DQIB5P03DQH20006DQH00`00
DSIB=P03DSH00`00DSIB=P03DSH20006ESH00`00ESIF=P04ESH00`00ESIF=P02ESH00`00ESH00006
ESH00`00ESIF=P04ESH20005ESH00`00ESIF=P04ESH01000ESIF=P0015Xf00<005YFFUH015YF00@0
05YFFUH000AJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUH00005FUH0
0`00FUIJEP04FUH00`00GUINEP05GUH01@00GUINEUiF00000eiF00<005ifGWH01Eif0P001Uif00<0
05ifGWH00Uif00@005ifGWH000MNMP03001NMUif00ENMP04001NMUif0004HWH00`00HWIRMP02HWH0
1000HWIRMP001f9f00<006:FHYH01V:F00<006:FHYH01F:F00<006:F00001V:F00@006:FHYH000AR
UP05001RUV:FHYH00004IYH01@00IYIVUVJF000016JF00@006JFIYH000AV]P05001V]fJgI[L00004
I[L01@00I[MV]fJg000016Jg00@006JgI[L000AV]`03001V]`0000IV]`03001V]`0000IV]`03001Z
ef[G00EZe`03001Ze`0000=Ze`03001Zef[G009Ze`04001Zef[G0004J]L00`00J]L00006J]L00`00
J]MZe`04J]L01000J_MZm`000V[g00<006[gJ_L016[g00<006[gJ_L016[g00<006kg00000f[h00<0
06kgK_L00Vkg00<006lGKaL00flG00D006kgK_M^m`00009^m`03001Zn6[h00=Zn003001[6F/I00=[
6@06001_>6lhKcP005Km0`0000=Fo@00E_d01UKm00<005KmE_d00`0000=Fo@00E_d01EKm0`001EKm
00<007oo0000]goo003@Ool2000>Ool30006E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00
E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020003E_d00`00E_eFo@03E_d20006E_d00`00
E_eFo@03E_d20006E_d00`00E_eFo@03E_d30006E_d00`00E_d000020002E_d00`00E_eFo@04E_d0
0`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_eF
o@02E_d00`00DWUBN@02DWT00`00CSM>=`03CSL00`00=ILeU`02=IL00`00@OQ1n002@OP01@00?MLm
ecgG00001D7g00<004GgAOL00TGg00<0047g@OL00T7g00<004GgAOL00dGg00<004GgAOL00TGg00<0
04GgAOL00dGg00<004GgAOL02P000dGg00<004GgAOL00TGg00<004WgBOL014Wg00<004WgBOL00TWg
00<004WgBOL00TWg00<004WgBOL014Wg00<004WgBOL00TWg00<004XGBQL014XG100000=:5`00CQL0
1DhG00<004hGCQL00ThG00<004hGCQL014hG00<004hFCQH00dhF00<004hFCQH00ThF0`0014hF00<0
04hFCQH014hF00<004hFCQH00dhF00<004hFCQH014hF0`000e8F00<0058FDQH00e8F00<0058FDQH0
158F00@0058FDQIB5P800003DQH0058F00EB5P03001B=U8f00=B=P03001B=U8f009B=P03001B=P00
00IF=P03001F=UHf00AF=P03001F=UHf0080009F=P03001F=UHf00AF=P03001F=UHf00=F=P8000IF
=P03001F=UHf00EF=P8000EJ=P03001JEUYF00EJEP8000EJEP03001JEUYF00EJEP8000EJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP8000MNEP04001NEUiF0004GUH00`00GWINMP05
GWH00`00GWINMP05GWH01@00GWINMUif00000eif00<005ifGWH015if0P0025if0P001F9f00D0069f
HWIRMP0000=RMP03001RMV9f00ARMP03001RMP0000MRUP03001RUV:F00IRUP03001RUV:F00ERUP03
001RUP0000ERUP04001RUV:F0005IYH01000IYIVUP001FJF00@006JFIYH000AV]P04001V]fJg0005
I[L01000I[MV]`001FJg00<006Jg00001VJg00<006JgI[L01VJg0P001FJg00<006[G00001F[G00@0
06[GJ]L000=Ze`03001Zef[G009Ze`04001Zef[G0005J]L00`00J]MZe`04J]L00`00J]L00004J]L0
1`00J_MZmf[g001Zm`0000MZm`03001Zmf[g00=Zm`04001^mfkg0002J_P00`00K_M^m`03K_L00`00
KaM_5`03KaL01`00K_M^mfkg001^m`0000IZn003001[6F/I009[6@03001_>6lh00=_>003001FoEKm
00=Fo@03001FoEKm00AFo@<000EFo@03001FoEKm00<00003E_d005Km00EFo@04001oogoo002fOol0
0<eoo`<000eoo`<000=Fo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm
00=Fo@8000MFo@03001Fo@0000800003E_d005Km00IFo@03001Fo@0000800003E_d005Km00IFo@03
001Fo@00008000=Fo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=F
o@8000IFo@03001FoEKm00=Fo@H000=BNAD00003?ML0047g00A1m`030015mdGg0095m`030011md7g
0091m`030015mdGg01000095m`030015mdGg0095m`030015mdGg00=5m`030015mdGg00=5m`030019
mdWg00=9m`030019mdWg0099m`030019mdWg00=9m`030019mdWg00=9m`030019mdWg00=9m`03001:
5dXG00@000A:5`03001>5dhG00A>5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5ThF00A>5P@0
0003CQH004hF00E>5P03001>5ThF00A>5P03001>5ThF009>5P03001>5ThF00=>5P8000IB5P03001B
5U8F00=B5P03001B5U8F00AB5P<000=B5P03001B5U8F00AB5P03001B=U8f00=B=P03001B=U8f0080
009B=P03001F=UHf00EF=P03001F=UHf00AF=P8000EF=P03001F=UHf00AF=P07001F=UHfESH005Hf
00001eHf00<005HfESH00eHf0P001UXf00<005YFFUH015YF0P001UYF00<005YFFUH015YF0P001UYF
00<005YFFUH015YF0P001UYF00<005YFFUH00UYF00@005YFFUH000MNEP8000ENEP03001NMUif00AN
MP8000MNMP04001NMUif0005GWH00`00GWINMP02GWH01000GWINMP001eif00<0069fHWH01F9f00@0
069fHWH000ARMP03001RMV9f009RMP04001RMV9f0006HYH00`00HYH00007HYH00`00HYIRUP06HYH0
0`00HYIRUP04HYH00`00HYH00006IYH00`00IYH00006IYH00`00IYH00005I[H00`00I[L00006I[L0
0`00I[L00007I[L00`00I[MV]`05I[L00`00I[MV]`06I[L20004I[L01000J]MZe`0016[G00D006[G
J]MZe`00009Ze`03001Zef[G00=Ze`03001Ze`0000IZe`03001Zef[G00=Ze`04001Zef[G0004J]L0
0`00J_MZm`02J_L00`00J_MZm`05J_L00`00J_L00003J_L01`00K_M^mfkg001Zn00000E^m`03001^
m`0000=_5`03001^mfkg00=^m`03001Zn6[h00AZn003001_600000=[6@03001_>6lh00=_>003001F
oEKm00AFo@03001FoEKm00<00003E_d005Km00EFo@<000EFo@03001FoEKm00=Fo@80009oo`03001o
ogoo0;=oo`00bgoo0P003Woo0P001eKm00<005Km00000P0000=Fo@00E_d01UKm00<005Km00000P00
00=Fo@00E_d01UKm00<005Km00000P000UKm00<005KmE_d015Km0P001EKm00<005KmE_d015Km0P00
1EKm00<005KmE_d015Km0P001eKm00<005Km00000P0000=Fo@00E_d01UKm00<005Km00000P0000=F
o@00E_d01UKm00<005Km00000P0000=Fo@00E_d01UKm00<005Km00000P0000=BN@00>KP00SVh1000
0THH00<004GhAOP00TGh00<003gG?ML00SgG00<0047G@ML00T7G00@0047G@MM1ea@00091m`030015
mdGg00=5m`030015mdGg0095m`030015mdGg0095m`030015mdGg00=5m`030015mdGg00=5m`030015
mdGg0095m`030019mdWg00=9m`030019mdWg00=9m`030019mdWg0099m`030019mdWg00=9m`030019
mdWg0099m`@000=9m`03001:5dXG00=:5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5dhG00=>
5`03001>5ThF00=>5P8000A>5P03001>5ThF00A>5P03001>5ThF00A>5P03001>5ThF00=>5P03001>
5P0000800003CQH0058F00EB5P03001B5U8F00=B5P03001B5U8F00=B5P8000IB5P03001B5U8F00AB
5P03001B=U8f00=B=P8000EB=P03001F=UHf00AF=P03001F=UHf00=F=P8000IF=P03001F=UHf00AF
=P04001F=UHf0003ESH00`00ESIF=P04ESH00`00ESIF=P02ESH00`00ESH00007FSH00`00FUIJEP02
FUH00`00FUH00007FUH00`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP02FUH00`00FUH00007
FUH01000FUIJEP000eYF00<005iFGUH01EiF00<005iFGUH01EiF00<005ifGWH00Uif00@005ifGWH0
00MNMP8000INMP05001NMUifGWH00003GWH00`00GWINMP05GWH00`00HWIRMP05HWH00`00HWH00005
HWH01@00HWIRMV9f00000f9f00<006:FHYH00f:F00@006:FHYH000IRUP03001RUP0000MRUP03001R
UV:F00ERUP03001VUVJF00IVUP03001VUVJF00IVUP03001V]VJf00EV]P03001V]fJg00IV]`03001V
]fJg00IV]`03001V]fJg00AV]`03001V]`0000IV]`03001V]`0000AV]`05001Zef[GJ]L00003J]L0
0`00J]MZe`02J]L20007J]L00`00J]MZe`04J]L00`00J]L00004J]L01@00J]MZef[G00000V[G00<0
06[gJ_L00f[g00<006[gJ_L016[g00@006[gJ_L0009Zm`03001^mfkg00=^m`03001^mfkg00=^m`05
001^mfkgK_L00002KaL00`00K_M^m`03K_L00`00J_QZn003J_P01`00KaQ_66lH001[6@0000E_>003
001_>00000EFo@<000EFo@03001FoEKm00<00003E_d005Km00EFo@03001FoEKm00<00005E_d007oo
Ool0002eOol00<Qoo`<000eoo`<0009Fo@03001FoEKm00AFo@8000EFo@03001FoEKm00AFo@8000EF
o@03001FoEKm00AFo@8000IFo@03001FoEKm00<00003E_d005Km00EFo@03001FoEKm00<00003E_d0
05Km00EFo@03001FoEKm00<0009Fo@03001FoEKm00AFo@8000EFo@03001FoEKm00AFo@8000EFo@03
001FoEKm00AFo@8000EFo@03001FoEKm00AFo@8000EBN@05000i^3Vh>KP00005AQP00`00AOQ5n002
AOP00`00?MLme`02?ML01@00@MM1ed7G0000147G00<0047g@OL00d7g00<0047g@OL00T7g00<0047g
@OL00T7g00<0047g@OL00T7g00<004GgAOL014Gg00<004GgAOL00TGg00<004GgAOL00TGg00<004Gg
AOL00TGg00<004GgAOL00dGg00<004GgAOL00TGg00<004WgBOL014Wg00<004WgBOL00TWg00<004Wg
BOL00TWg00<004WgBOL014Wg100000=9m`00BOL014Wg00<004XGBQL00dXG00<004hGCQL014hG00<0
04hGCQL00dhG00<004hGCQL00dhG00<004hF00000P0000=>5P00CQH014hF00<004hFCQH00dhF00<0
04hFCQH014hF00<004hFCQH00ThF0`0014hF00<0058FDQH0158F00<0058FDQH00e8F00@0058FDQIB
5P800003DQH0058F00EB5P03001B5U8F00AB5P03001B=U8f009B=P8000IB=P03001F=UHf00AF=P03
001F=UHf009F=P03001F=P0000IF=P03001F=UHf00AF=P03001F=P0000AF=P03001F=UHf00AF=P05
001F=UHfESH00002ESH00`00FSIJ=P05FSH01@00FUIJEUYF00000UYF00<005YFFUH01EYF00D005YF
FUIJEP00009JEP03001JEUYF00EJEP05001JEUYFFUH00003FUH00`00FUIJEP04FUH00`00FUH00004
FUH00`00GUINEP04GUH20007GUH01@00GWINMUif00000eif00<005ifGWH01Eif00<005ifGWH01Eif
00@005ifGWH000ANMP03001NMUif00ANMP03001NMP0000MRMP03001RMV9f00ARMP04001RMV9f0005
HWH01@00HYIRUV:F00000f:F00<006:FHYH00f:F00@006:FHYH000IRUP03001RUP0000IRUP03001V
UVJF00IVUP03001VUVJF00IVUP03001V]VJf00EV]P03001V]fJg00IV]`03001V]fJg00EV]`03001V
]`0000AV]`04001V]fJg0005I[L01000I[MV]`000fJg00<006[GJ]L00V[G00@006[GJ]L000EZe`03
001Zef[G00IZe`03001Zef[G00=Ze`04001Zef[G0003J]L00`00J]MZe`02J]L00`00J]L00005J_L0
0`00J_L00004J_L01`00J_MZmf[g001Zm`0000I^m`03001^mfkg00=^m`07001^mfkgK_L006lG0000
1Fkg00<006lH00000f[h00<006lHKaP00flH00<006lhKcP00flh00@006lhKcP0009Fo@<00003E_d0
05Km00EFo@<000EFo@03001FoEKm00=Fo@<000EFo@04001oogoo002dOol00<Ioo`8000ioo`8000IF
o@03001FoEKm00<00003E_d005Km00EFo@03001FoEKm00<00003E_d005Km00EFo@03001FoEKm00<0
009Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm00=Fo@<000EFo@03001FoEKm00=Fo@<000IFo@03
001FoEKm00<00003E_d005Km00EFo@03001FoEKm00<00003E_d005Km00EFo@03001FoEKm00<00003
E_d005Km00EFo@03001FoEKm00<00003E_d0059i00ABN@03000i^3Vh008i^003001664HH00966003
0015n4Gh0095n003000mecgG008me`030011ed7G0091e`030011ed7G0091e`030011md7g00=1m`03
0011md7g0091m`030011md7g0091m`030011md7g0091m`030015mdGg00=5m`030015mdGg0095m`03
0015mdGg0095m`030015mdGg00=5m`030015mdGg0095m`030015mdGg00=5m`030019mdWg00=9m`03
0019mdWg0099m`030019mdWg00=9m`030019mdWg00@000A9m`030019mdWg00A9m`03001:5dXG009:
5`03001>5dhG00A>5`03001>5dhG00=>5`03001>5dhG009>5`<000A>5P03001>5ThF00=>5P03001>
5ThF00A>5P03001>5ThF00=>5P03001>5ThF00800003CQH004hF00E>5P03001B5U8F00AB5P03001B
5U8F00=B5P<000=B5P03001B5U8F00AB5P03001B5U8F00AB5P03001B=U8f00800003DSH0058f00EB
=P03001F=UHf00AF=P03001F=UHf0080009F=P03001F=UHf00EF=P03001F=UHf00=F=P8000EF=P03
001F=UHf00AF=P04001F=UHf0004ESH00`00FSIJ=P04FSH01000FUIJEP0015YF00<005YFFUH015YF
00@005YFFUH000AJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00GUINEP02GUH00`00GUH00007GUH01000GWINMP0015if00<005ifGWH015if0P0025if0P00
1Uif00<005ifGWH00Uif00@005ifGWH000MRMP03001RMV9f00ERMP8000IRMP04001RUV:F0005HYH0
1@00HYIRUV:F00000f:F00<006:FHYH00f:F00@006:FHYH000ERUP03001RUP0000IVUP03001VUP00
00IVUP03001VUP0000EV]P03001V]P0000IV]`03001V]P0000EV]`04001V]fJg0004I[L01@00I[MV
]fJg00000fJg00@006JgI[MV]`80009V]`03001Zef[G009Ze`03001Ze`0000IZe`03001Zef[G00EZ
e`03001Ze`0000AZe`05001Zef[GJ]L00002J]L00`00J]MZe`03J]L00`00J_MZm`03J_L01000J_MZ
m`0016[g00<006[gJ_L00V[g00<006kgK_L016kg00<006kg00000fkg00<006kgK_L00fkg00<006kg
K_L00fkg00D006lHKaQ_6000009Zn003001_66lH00=_6003001_>6lh009_>003001_>6lh009_>080
00EFo@03001FoEKm00<00003E_d005Km00EFo@03001FoEKm00<00003E_d005Km00IFo@04001oogoo
002cOol00<=oo`<000eoo`<0009Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm00=Fo@<000EFo@03
001FoEKm00=Fo@<000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03
001FoEKm00AFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm00=Fo@<000EF
o@03001FoEKm00=Fo@<000EFo@03001FoEKm00=Fo@<000EFo@03001BNE9i009BN@03000i^3Vh008i
^003001664HH009660030015n4Gh0095n003000mecgG008me`030011ed7G0091e`030011ed7G0091
e`030011md7g00=1m`030011md7g0091m`030011md7g0091m`030011md7g0091m`030015mdGg00=5
m`030015mdGg0095m`030015mdGg0095m`030015mdGg00=5m`030015mdGg00=5m`030015mdGg0095
m`030019mdWg00=9m`030019mdWg00=9m`030019mdWg00D000=9m`030019mdWg00=9m`030019mdWg
00=9m`03001:5dXG00=:5`03001>5dhG00=>5`03001>5dhG00=>5`03001>5`0000800003CQH004hF
00E>5P03001>5ThF009>5P03001>5ThF00A>5P03001>5ThF00A>5P8000=>5P03001>5ThF00A>5P03
001B5U8F00AB5P03001B5U8F009B5P8000IB5P03001B5U8F00AB5P03001B5U8F00AB5P8000AB=P03
001B=U8f00AB=P03001F=UHf00AF=P8000EF=P03001F=UHf00AF=P03001F=UHf009F=P03001F=P00
00IF=P03001F=UHf00AF=P8000EF=P03001J=UXf00EJ=P8000EJEP03001JEUYF00EJEP8000EJEP03
001JEUYF00EJEP8000EJEP03001JEUYF00AJEP8000IJEP05001NEUiFGUH00003GUH00`00GUINEP05
GUH20006GWH00`00GWINMP02GWH01000GWINMP001eif00<005ifGWH01Eif00D005ifGWINMP0000=N
MP03001RMV9f00ARMP03001RMP0000IRMP03001RMV9f00ERMP03001RUP0000IRUP05001RUV:FHYH0
0004HYH01@00HYIRUV:F00000f:F00<006:FHYH00V:F00@006:FHYH000EVUP04001VUVJF0005IYH0
1000IYIVUP0016Jf00@006JfI[H000EV]`04001V]VJf0004I[L00`00I[MV]`02I[L01000I[MV]`00
16Jg00@006JgI[L000AV]`800003I[L006[G00EZe`03001Zef[G00AZe`03001Ze`0000EZe`04001Z
ef[G0003J]L00`00J]MZe`02J]L00`00J]L00006J]L00`00J_MZm`03J_L01@00J_MZmf[g00000V[g
00<006[gJ_L00f[g00<006kgK_L00fkg00D006kgK_M^m`00009^m`03001^mfkg00=^m`03001^mfkg
00=^m`07001_66lHKaP006[h00001FlH00<006lH00000Vlh00<006lhKcP00flh0P001EKm0`001EKm
00<005KmE_d00eKm0`001EKm00<005KmE_d015Km0P0000=oo`00Ool0/Woo0031Ool2000=Ool30006
E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00
E_d000020003E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d3
0006E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@04E_d0
0`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020003E_d00`00E_eFo@02E_d00`00DWUB
N@03DWT01@00>KPi^3Vh00001DHH00<004GhAOP00TGh00<003gG?ML00SgG00D0047G@MM1e`0000E1
e`030011md7g0091m`030011md7g0091m`030011md7g0091m`030011md7g0091m`030015mdGg00A5
m`030015mdGg0095m`030015mdGg0095m`030015mdGg0095m`030015mdGg00=5m`030015mdGg0095
m`030019mdWg00A9m`030019mdWg00D00099m`030019mdWg00=9m`030019mdWg00=9m`030019mdWg
00=9m`03001:5dXG00=:5`03001>5dhG00=>5`03001>5dhG00=>5`8000A>5P03001>5ThF00A>5P03
001>5ThF00=>5P03001>5ThF00=>5P03001>5ThF00=>5P8000E>5P03001>5ThF00=>5P03001B5U8F
00AB5P03001B5U8F00800003DQH0058F00EB5P03001B5U8F00AB5P03001B5U8F00=B5P8000EB=P03
001B=U8f00AB=P03001F=UHf00=F=P8000IF=P03001F=UHf00AF=P03001F=UHf0080009F=P03001F
=UHf00AF=P03001F=UHf00=F=P8000IF=P03001J=UXf00AJ=P8000IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF00AJEP8000MJEP03001JEUYF009JEP03001JEP0000IJEP04001NEUiF0004
GUH00`00GUINEP05GUH00`00GWINMP05GWH01@00GWINMUif00000eif00<005ifGWH01Eif00<005if
GWH01Eif00@005ifGWH000ENMP03001RMV9f009RMP04001RMV9f0006HWH00`00HWIRMP06HWH00`00
HYIRUP05HYH01000HYIRUP001F:F00D006:FHYIRUP0000ARUP04001RUV:F0003HYH00`00IYIVUP02
IYH01@00IYIVUVJF000016JF00D006JFIYIVUP0000AV]P05001V]VJfI[H00003I[L00`00I[IV]P02
I[H01@00I[MV]fJg000016Jg00@006JgI[L000AV]`03001V]`0000EV]`03001V]`0000MZe`03001Z
ef[G00=Ze`04001Zef[G0004J]L00`00J]MZe`02J]L01000J]MZe`001F[G00<006[GJ]L016[G00<0
06[g00000f[g00<006[gJ_L00V[g00<006[g00001F[g00<006kg00000fkg00<006kgK_L00Vkg00<0
06kg00001Fkg00<006lG00000fkg00<006lHKaP00flH00<006lHKaP00flH00H006lHKaP006lh0005
KcP01@00LcQc>000E_d00`0000=Fo@00E_d01UKm00<005Km00000P0000=Fo@00E_d01UKm00<005Km
E_d00`0000EFo@00Oomoo`000;9oo`00_Woo0`0037oo0`000eKm00<005KmE_d00eKm0P001UKm00<0
05KmE_d00eKm0P001UKm00<005KmE_d00eKm0`001UKm00<005Km00000P000UKm00<005KmE_d015Km
00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000eKm00<005KmE_d00eKm0P001UKm
00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0`001UKm00<005Km
E_d00UKm00<0059iDWT00U9i00<003Vh>KP00SVh00<004HHAQP00THH00<004GhAOP00TGh00<003gG
?ML00SgG00<0047G@ML00T7G00<0047G@ML00T7G00<0047g@OL00d7g00<0047g@OL00T7g00<0047g
@OL00T7g00<0047g@OL00T7g00<004GgAOL00dGg00<004GgAOL00TGg00<004GgAOL00TGg00<004Gg
AOL00dGg00<004GgAOL00TGg00<004GgAOL00dGg00<004WgBOL01P000TWg00<004WgBOL00dWg00<0
04WgBOL00dWg00<004WgBOL00TWg00<004WgBOL014Wg00<004XGBQL00TXG00<004hGCQL014hG00<0
04hG00000P0000=>5P00CQH014hF00<004hFCQH00dhF00<004hFCQH00dhF00<004hFCQH014hF00<0
04hF00000P0000=>5P00CQH014hF00<004hFCQH014hF00<0058FDQH0158F0P00158F00<0058FDQH0
0e8F00<0058FDQH0158F00<0058FDQH00U8F00<0058F00001E8f00<0058fDSH0158f00<005HfESH0
0UHf00<005Hf00001UHf00<005HfESH01EHf0P001EHf00<005HfESH015Hf00L005HfESIF=P00ESH0
0007ESH00`00FSIJ=P02FSH00`00FSH00007FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP02FUH0
0`00FUH00007FUH01@00FUIJEUYF00000eYF00<005YFFUH015YF0P001EiF00<005iFGUH015iF0P00
1eif00@005ifGWH000ANMP03001NMUif00ANMP03001NMP0000MNMP8000INMP05001RMV9fHWH00003
HWH00`00HWIRMP03HWH00`00HWH00007HWH00`00HYIRUP06HYH20006HYH01000HYIRUP001F:F00@0
06:FHYH000ARUP05001VUVJFIYH00004IYH01@00IYIVUVJF000016JF00@006JfI[H000AV]P04001V
]fJg0005I[H01000I[MV]`001FJg00<006Jg00001VJg00<006JgI[L016Jg00<006Jg00001V[G00<0
06[G000016[G00D006[GJ]MZe`00009Ze`03001Zef[G00=Ze`03001Ze`0000IZe`03001Zef[G00=Z
e`05001Zmf[gJ_L00002J_L00`00J_MZm`03J_L00`00J_MZm`03J_L01@00K_M^mfkg00000Vkg00<0
06kgK_L00fkg00<006kgK_L00fkg00D006lGKaM_5`00009^m`03001_66lH00=_6003001_66lH009_
6003001_66lH009_6003001_>6lh00=_>003001c>7<h009c>003001FoEKm00=Fo@03001FoEKm00AF
o@8000EFo@03001FoEKm00AFo@<000EFo@04001oogoo002aOol00;]oo`<000eoo`<000IFo@03001F
o@000080009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080
00=Fo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@<000IFo@03
001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@00
0080009Fo@03001FoEKm00AFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@H000ABN@03000i^3Vh
008i^003001664HH009660030015n4Gh0095n003000mecgG008me`030011ed7G0091e`030011ed7G
0091e`030011md7g00=1m`030011md7g0091m`030011md7g0091m`030011md7g0091m`030015mdGg
00=5m`030015mdGg0095m`030015mdGg0095m`030015mdGg00=5m`030015mdGg00=5m`030015mdGg
00D000=5m`030019mdWg0099m`030019mdWg00=9m`030019mdWg00=9m`030019mdWg00=9m`030019
mdWg00=9m`03001:5dXG00=:5`03001>5dhG00D000A>5P03001>5ThF00=>5P03001>5ThF00A>5P03
001>5ThF009>5P03001>5ThF00=>5P<000A>5P03001>5ThF00=>5P03001>5ThF00A>5P03001B5U8F
00=B5P8000EB5P03001B5U8F00AB5P03001B5U8F00=B5P03001B5U8F0080009B5P03001B=U8f00AB
=P03001B=U8f00=B=P03001F=UHf0080009F=P03001F=UHf00EF=P03001F=UHf00=F=P8000IF=P03
001F=UHf00AF=P04001F=UHf0003ESH00`00ESIF=P04ESH01@00FSIJ=UXf00000UXf00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001eYF00D005YFFUIJEP00009JEP03001JEUYF00EJEP04001J
EUYF0004FUH00`00FUIJEP04FUH00`00GUINEP05GUH00`00GUINEP02GUH01000GUINEP001eif0P00
1Uif00<005ifGWH00Uif00@005ifGWH000MNMP03001NMUif00ENMP04001RMV9f0005HWH01@00HWIR
MV9f00000V9f00<0069fHWH0169f00<006:F00001f:F00<006:FHYH01V:F0P001V:F00<006:F0000
1F:F00@006JFIYH000EVUP04001VUVJF0005IYH01000I[IV]P0016Jf00<006Jg00001VJf00<006Jg
00001fJg00<006JgI[L01FJg00<006JgI[L016Jg0`001F[G00@006[GJ]L000=Ze`03001Zef[G009Z
e`03001Ze`0000MZe`03001Zef[G00AZe`03001Ze`0000=Ze`03001Zmf[g009Zm`03001Zm`0000IZ
m`03001Zmf[g00=Zm`07001^mfkgK_L006kg00001Vkg00<006kgK_L00fkg00L006lGKaM_5`00K_L0
0005KaP00`00KaP00002KaP00`00KaQ_6003KaP00`00KcQ_>002KcP00`00LcQc>003LcP00`00E_eF
o@04E_d00`00E_eFo@0300000eKm001Fo@05E_d00`00E_eFo@0300000eKm001Fo@05E_d01000Oomo
o`00/Goo002iOol2000=Ool30003E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20006E_d0
0`00E_eFo@03E_d30006E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d0
0`00E_eFo@04E_d00`00E_d000020003E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20006
E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20007E_d00`00E_d0000200000eKm000ef@02
=MT;0005AQP00`00AOQ5n002AOP00`00?MLme`02?ML01@00@MM1ed7G00001D7G00<0047g@OL00T7g
00<0047g@OL00T7g00<0047g@OL00T7g00<0047g@OL00T7g00<004GgAOL014Gg00<004GgAOL00TGg
00<004GgAOL00TGg00<004GgAOL02`000TGg00<004GgAOL00dGg00<004WgBOL00dWg00<004WgBOL0
0TWg00<004WgBOL00dWg00<004WgBOL00dWg00<004WgBOL00dWg00<004XGBQL00TXG10000dWg00<0
04hFCQH014hF00<004hFCQH00ThF00<004hFCQH014hF00<004hFCQH00dhF00<004hF00000P0000=>
5P00CQH01DhF00<004hFCQH00dhF00<004hFCQH00dhF00@0058FDQIB5P800003DQH0058F00AB5P03
001B5U8F00AB5P03001B5U8F00AB5P8000EB5P03001B=U8f00=B=P03001B=U8f00AB=P8000EF=P03
001F=UHf00AF=P03001F=UHf009F=P03001F=P0000IF=P03001F=UHf00AF=P03001F=P0000AF=P03
001F=UHf00AF=P04001J=UXf0004FSH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF00<005YFFUH0
15YF00@005YFFUH000AJEP03001JEUYF00EJEP8000EJEP03001JEUYF00AJEP03001NEUiF00ENEP05
001NEUiFGUH00003GUH00`00GWINMP05GWH00`00GWINMP05GWH01@00GWINMUif00000eif00<005if
GWH015if0P0025if0P001V9f00@0069fHWH000ARMP03001RMV9f009RMP04001RUV:F0007HYH00`00
HYIRUP06HYH00`00HYIRUP06HYH00`00HYIRUP04HYH00`00IYH00006IYH00`00IYH00006IYH00`00
I[H00006I[H00`00I[IV]P06I[H00`00I[MV]`06I[L00`00I[MV]`04I[L00`00I[L00005I[L01000
J]MZe`000f[G00<006[GJ]L00V[G00@006[GJ]L000EZe`03001Zef[G00IZe`03001Zef[G00=Ze`05
001Zef[GJ]L00002J]L00`00J_MZm`03J_L00`00J_MZm`04J_L00`00J_L00003J_L00`00K_M^m`03
K_L00`00K_M^m`04K_L00`00K_L00003K_L00`00KaM_5`03KaL00`00KaQ_6003KaP01P00KaQ_6000
KaP000E_6003001_>00000=_>003001c>7<h009c>003001c>00000EFo@<000EFo@03001FoEKm00=F
o@<000EFo@03001FoEKm00=Fo@80009oo`03001oogoo0:ioo`00]Woo0`003Goo0`001UKm00<005Km
00000P000UKm00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P00
0eKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0`001UKm00<0
05Km00000P000UKm00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d015Km00<005Km0000
0P0000=Fo@00E_d01UKm00<005Km00000P000UKm00<005KmE_d015Km0P001EKm00D003GI=MTef@00
00A1n004000mn3gh?OPD00000d7G0011e`03@ML00`00@OM1m`03@OL00`00@OM1m`02@OL00`00@OM1
m`02@OL00`00@OM1m`02@OL00`00AOM5m`0@0003AOL00`00AOM5m`02AOL00`00AOM5m`02AOL00`00
AOM5m`04AOL00`00BOM9m`02BOL00`00BOM9m`03BOL00`00BOM9m`03BOL00`00BOM9m`02BOL00`00
BOM9m`04BOL400000dWg0019m`04BOL00`00CQI>5P04CQH00`00CQI>5P03CQH00`00CQI>5P03CQH0
0`00CQI>5P02CQH30004CQH00`00CQI>5P04CQH00`00CQI>5P03CQH00`00CQI>5P04CQH30003DQH0
0`00DQIB5P04DQH00`00DQIB5P03DQH00`00DQIB5P03DQH20006DQH00`00DSIB=P04DSH00`00DSIB
=P02DSH20006ESH00`00ESIF=P04ESH01@00ESIF=UHf00000UHf00<005HfESH01EHf00<005HfESH0
0eHf0P001EHf00<005HfESH01EHf0P001EXf00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF
00EJEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP03001NEP0000INEP04
001NEUiF0004GUH00`00GWINMP04GWH20007GWH01000GWINMP001Eif00<005ifGWH00Uif00@005if
GWH000MNMP03001RMV9f00ERMP04001RMV9f0004HWH01@00HWIRMV9f00000f:F00<006:FHYH016:F
00<006:F00001f:F00<006:FHYH01V:F00<006:FHYH01F:F00<006JFIYH01VJF00<006JFIYH01VJF
00<006JfI[H01FJf00<006JfI[H01VJf00<006JgI[L01FJg0P001FJg00@006JgI[L000AV]`80009Z
e`05001Zef[GJ]L00004J]L00`00J]L00006J]L00`00J]MZe`05J]L00`00J]L00003J]L00`00J]MZ
e`02J]L00`00J]L00006J_L00`00J_MZm`03J_L01@00J_MZmf[g00000V[g00<006kgK_L00fkg00<0
06kgK_L00fkg00D006kgK_M^m`00009^m`03001_5flG00=_5`03001_66lH009_6003001_66lH009_
6003001_66lH00=_6007001_>6lhKcP006lh000017<h00@007<hLcP0009Fo@<00003E_d005Km00EF
o@03001FoEKm00<00003E_d005Km00EFo@03001FoEKm00<00005E_d007ooOol0002`Ool00;Aoo`80
00eoo`<000=Fo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@<0
00IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm00AFo@03
001Fo@00008000=Fo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=F
o@8000EFo@03001FoEKm00AFo@8000IFo@03001FoEKm00<00003E_d005Km00AFo@03000efCGI008e
f@030011n47h0091n005000mn3gh?OP00004@OP00`00@OQ1n002@OP00`00@MM1e`02@ML01000@MM1
ed7G7P000dGg00<004GgAOL00TGg00<004GgAOL00TGg00<004GgAOL00dGg00<004GgAOL00dGg00<0
04GgAOL00TGg00<004GgAOL00dGg00<004WgBOL00TWg00<004WgBOL00dWg00<004WgBOL00dWg00<0
04WgBOL00dWg00<004WgBOL010001DWg00<004WgBOL00dWg00<004hFCQH00dhF00<004hFCQH00dhF
00<004hFCQH00dhF00<004hFCQH00P0000=>5P00CQH01DhF00<004hFCQH00dhF00<004hFCQH00dhF
00<004hFCQH00dhF0P001U8F00<0058FDQH00e8F00<0058FDQH00e8F00@0058FDQIB5P800003DQH0
058F00EB5P03001B=U8f00AB=P03001B=U8f00800003DSH005Hf00EF=P03001F=UHf00AF=P04001F
=UHf0004ESH00`00ESIF=P04ESH00`00ESIF=P02ESH00`00ESH00006ESH00`00ESIF=P04ESH00`00
FSIJ=P04FSH00`00FUIJEP05FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP04
FUH20007FUH01@00FUIJEUYF00000UiF00<005iFGUH01EiF0P001UiF00<005ifGWH00Uif00@005if
GWH000MNMP8000INMP05001NMUifGWH00003GWH00`00GWINMP05GWH00`00HWIRMP06HWH20006HWH0
1000HWIRMP0016:F00<006:FHYH00V:F00@006:FHYH000IRUP03001RUP0000IRUP03001RUP0000IR
UP03001VUVJF00IVUP03001VUVJF00IVUP03001V]VJf00AV]P03001V]P0000IV]P03001V]P0000EV
]`04001V]fJg0003I[L00`00I[MV]`02I[L01000I[MV]fJg0P000V[G00@006[GJ]L000IZe`03001Z
ef[G00AZe`03001Ze`0000EZe`04001Zef[G0002J]L00`00J]MZe`04J]L00`00J_MZm`04J_L00`00
J_L00004J_L01`00J_MZmf[g001Zm`0000E^m`03001^m`0000=^m`03001^mfkg009^m`03001^m`00
00E_5`03001_5`00009_6003001_66lH00=_6003001_66lH00=_6003001_>6lh009_>003001c>7<h
009c>003001c>7<h009c>08000EFo@03001FoEKm00=Fo@<000EFo@03001FoEKm00=Fo@<000EFo@04
001oogoo002_Ool00;5oo`<000eoo`<000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001F
o@000080009Fo@03001FoEKm00AFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@8000IFo@03001F
oEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000MFo@03001Fo@0000800003E_d005Km00IFo@03001F
o@0000800003E_d005Km00IFo@03001Fo@000080009Fo@03001FoEKm00=Fo@03001FoEKm00<0009F
o@03001FoEKm00=Fo@<000EFo@03001FoEKm009Fo@03000efCGI008ef@030011n47h0091n003000m
n3gh008mn0030011n47h0091n0030011n47h0091n0030011ed7G0091e`050011ed7G@ML00005@ML0
0`00@OM1m`02@OL00`00@OM1m`02@OL00`00@OM1m`02@OL00`00@OM1m`02@OL00`00AOM5m`03AOL0
0`00AOM5m`02AOL00`00AOM5m`03AOL00`00AOM5m`03AOL00`00AOM5m`02AOL00`00AOM5m`02AOL0
0`00AOM5m`03AOL00`00BOM9m`03BOL00`00BOM9m`03BOL00`00BOM9m`02BOL00`00BOM9m`02BOL4
0003BOL00`00BOM9m`03BOL00`00BOM9m`03BOL00`00CQI>5P04CQH00`00CQI>5P02CQH00`00CQI>
5P04CQH20003CQH00`00CQI>5P04CQH00`00CQI>5P04CQH00`00CQI>5P02CQH01000CQI>5ThF0P00
00=>5P00DQH01E8F00<0058FDQH00e8F00<0058FDQH0158F0`000e8F00<0058FDQH01E8F00<0058f
DSH00e8f00<0058f00000e8f00<005HfESH01EHf00<005HfESH015Hf0P001EHf00<005HfESH015Hf
00D005HfESIF=P00009F=P03001F=UHf00AF=P03001F=UHf00=F=P8000MJ=P03001JEUYF00=JEP80
00MJEP03001JEUYF00=JEP8000MJEP03001JEUYF009JEP03001JEP0000MJEP04001JEUYF0003GUH0
0`00GUINEP05GUH00`00GUINEP05GUH01@00GWINMUif00000eif00<005ifGWH01Eif00<005ifGWH0
1Eif00@005ifGWH000ANMP03001NMUif00ANMP03001RMP0000MRMP03001RMV9f00ERMP03001RMP00
00ERUP05001RUV:FHYH00003HYH00`00HYIRUP03HYH01000HYIRUP001F:F00@006:FHYH000ERUP03
001VUP0000IVUP03001VUP0000IVUP03001V]P0000AV]P04001V]VJf0005I[H01000I[IV]P0016Jg
00D006JgI[MV]`0000=V]`03001V]fJg009V]`06001V]fJg001Ze`000f[G0P001f[G00<006[GJ]L0
0f[G00@006[GJ]L000AZe`07001Zef[GJ]L006[G00001f[G00<006[gJ_L00f[g00@006[gJ_L000=Z
m`03001Zmf[g00=Zm`03001^mfkg00=^m`05001^mfkgK_L00002K_L00`00K_M^m`03K_L00`00KaM_
5`03KaL01P00KaM_5`00KaP000E_6003001_600000=_6003001_>6lh00=_>003001c>7<h009c>003
001c>7<h009c>003001FoEKm00AFo@03001FoEKm00<0009Fo@03001FoEKm00=Fo@03001FoEKm00<0
009Fo@03001FoEKm00=Fo@80009oo`03001oogoo0:aoo`00[goo0P003Goo0`000eKm00<005KmE_d0
0eKm0P001UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0`001UKm00<005Km00000P000UKm
00<005KmE_d015Km00<005Km00000P0000=Fo@00E_d01UKm00<005Km00000P000UKm00<005KmE_d0
15Km0P001EKm00<005KmE_d015Km0P001EKm00<005KmE_d015Km0P001UKm00@005KmE_eFo@@000IF
o@03001Fo@000080009Fo@03001FoEKm00AFo@03001FoEKm009Fo@05000efCGI=MT00004@OP00`00
?OPmn002?OP00`00@OQ1n002@OP00`00@OQ1n002@OP00`00@MM1e`02@ML00`00@MM1e`02@ML00`00
@MM1e`03@ML00`00@OM1m`02@OL00`00@OM1m`02@OL00`00@OM1m`02@OL00`00@OM1m`02@OL00`00
AOM5m`03AOL00`00AOM5m`02AOL00`00AOM5m`02AOL00`00AOM5m`03AOL00`00AOM5m`02AOL00`00
AOM5m`02AOL00`00AOM5m`04AOL00`00BOM9m`02BOL00`00BOM9m`03BOL00`00BOM9m`03BOL40000
0dWg0019m`04BOL00`00BOM9m`03BOL00`00BOM9m`03BOL00`00CQI>5P04CQH00`00CQI>5P02CQH0
0`00CQI>5P03CQH20005CQH00`00CQI>5P03CQH00`00CQI>5P04CQH00`00CQI>5P03CQH30003CQH0
0`00DQIB5P04DQH00`00DQIB5P04DQH00`00DQIB5P02DQH20006DQH00`00DQIB5P04DQH00`00DSIB
=P03DSH20005DSH00`00ESIF=P04ESH00`00ESIF=P03ESH20006ESH00`00ESIF=P04ESH01000ESIF
=P0015Hf00<005HfESH015Hf00L005HfESIF=P00ESH00007FSH00`00FUIJEP02FUH00`00FSH00007
FUH00`00FUIJEP02FUH00`00FUH00007FUH01@00FUIJEUYF00000eYF00<005YFFUH01EYF0P001EiF
00<005iFGUH015iF00<005iFGUH01EiF00@005ifGWH000ANMP03001NMUif00ANMP8000QNMP8000IN
MP03001NMUif009NMP04001RMV9f0007HWH00`00HWIRMP06HWH00`00HYIRUP04HYH01000HYIRUP00
1F:F00D006:FHYIRUP0000=RUP03001RUV:F009RUP05001RUV:FHYH00004HYH01000IYIVUP001FJF
00@006JFIYH000EVUP04001V]VJf0004I[H01000I[IV]P0016Jf00<006JfI[H00VJf00D006JgI[MV
]`0000=V]`04001V]fJg0005I[L00`00I[L00003J]L01000J]MZe`001f[G00<006[G000016[G00D0
06[GJ]MZe`00009Ze`03001Zef[G00=Ze`03001Zef[G00EZe`03001Zm`0000=Zm`03001Zmf[g009Z
m`04001Zmf[g0005J_L00`00K_M^m`03K_L01`00K_M^mfkg001^m`0000I^m`03001_5flG009_5`03
001_5flG009_5`03001_66lH00=_6005001_66lHKaP00002KaP00`00KcQ_>002KcP00`00KcP00002
LcP00`00LcQc>002LcP00`00LcP00005E_d30006E_d01000E_eFoEKm10001UKm00<005Km00000P00
00EFo@00Oomoo`000:ioo`00[7oo100037oo0`001UKm00<005Km00000P000UKm00<005KmE_d015Km
00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000eKm00<005KmE_d00eKm0P001UKm
00<005KmE_d00eKm0P001EKm00<005KmE_d015Km0P001UKm00<005KmE_d00`0000=Fo@00E_d01EKm
00<005KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d00`000UKm00<005KmE_d00eKm100015Km00<0
05KmE_d00eKm0P001UKm00<005KmE_d00eKm0`000UKm00<003GI=MT00SGI00<0047h@OP00T7h00D0
03gh?OPmn00000A1n0030011n47h0091n0030011ed7G0091e`030011ed7G0091e`030011ed7G00=1
e`030011md7g0091m`030011md7g0091m`030011md7g0091m`030011md7g0091m`030015mdGg00=5
m`030015mdGg0095m`030015mdGg0095m`030015mdGg00=5m`030015mdGg00=5m`030015mdGg0095
m`030015mdGg00=5m`030019mdWg0099m`030019mdWg00=9m`040019mdWgBOL30005BOL00`00BOM9
m`03BOL00`00BOM9m`03BOL00`00BOM9m`03BOL00`00CQI>5P03CQH00`00CQI>5P03CQH00`00CQH0
000200000dhF001>5P04CQH00`00CQI>5P04CQH00`00CQI>5P03CQH00`00CQI>5P02CQH20006CQH0
0`00DQIB5P04DQH00`00DQIB5P03DQH00`00DQIB5P0200000e8F001B5P05DQH00`00DQIB5P04DQH0
0`00DSIB=P02DSH00`00DQH00005DSH00`00ESIF=P04ESH00`00ESIF=P02ESH00`00ESH00007ESH0
0`00ESIF=P04ESH20005ESH00`00ESIF=P04ESH01000ESIF=P000eHf00<005XfFSH015Xf00D005YF
FUIJEP00009J=P03001JEUYF00EJEP05001JEUYFFUH00003FUH00`00FUIJEP04FUH01000FUIJEP00
15YF00<005YFFUH01EYF00<005iFGUH015iF00<005iFGUH00eiF00<005iF00001eiF0P001Uif00<0
05ifGWH00Uif00@005ifGWH000MNMP03001NMUif00ENMP05001NMUifGWH00003HWH00`00HWIRMP04
HWH00`00HWH00007HWH00`00HYIRUP05HYH20006HYH01000HYIRUP001F:F00D006:FHYIRUP0000AR
UP04001RUV:F0004IYH01@00IYIVUVJF000016JF00D006JFIYIVUP0000AV]P04001V]VJf0004I[H0
1@00I[IV]VJf000016Jf00@006JgI[L000EV]`8000MV]`03001Zef[G009Ze`04001Zef[G0006J]L0
1000J]MZe`000f[G00<006[GJ]L00V[G00<006[G00001V[G00<006[GJ]L016[G00@006[gJ_L000=Z
m`03001Zmf[g009Zm`03001Zm`0000EZm`03001^m`0000=^m`03001^mfkg00=^m`03001^mfkg00A^
m`03001_5`00009_5`03001_5flG00=_5`03001_66lH00=_6007001_66lHKaP006lH000016lh00H0
06lhKcP007<h0004LcP01000LcQc>0000UKm0`000UKm00<005KmE_d015Km10000eKm00<005KmE_d0
15Km0P001EKm00@007ooOol00:eoo`00ZWoo0P0017oo00<007ooOol01Woo0`000eKm00<005KmE_d0
0eKm0P001UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0`001UKm00<005Km00000P0000=F
o@00E_d01UKm00<005Km00000P0000=Fo@00E_d01EKm00<005KmE_d00`000UKm00<005KmE_d00eKm
0`001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d00eKm0`001UKm00<005Km00000P000UKm00<0
05KmE_d015Km00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P0000=BF000<IL00`00
13GI00<0047h@OP00T7h00<003gh?OP00Sgh00<0047h@OP00T7h00<0047h@OP00T7h00<0047G@ML0
0T7G00D0047G@MM1e`0000E1e`030011md7g0091m`030011md7g0091m`030011md7g0091m`030011
md7g0091m`030015mdGg00=5m`030015mdGg0095m`030015mdGg00=5m`030015mdGg00=5m`030015
mdGg0095m`030015mdGg0095m`030015mdGg00=5m`030019mdWg00=9m`030019mdWg00H00099m`03
0019mdWg00=9m`030019mdWg00=9m`030019mdWg00=9m`030019mdWg00=9m`03001>5ThF00A>5P03
001>5ThF00@000A>5P03001>5ThF00=>5P03001>5ThF00A>5P03001>5ThF00A>5P@00003CQH004hF
00E>5P03001B5U8F00AB5P03001B5U8F00=B5P03001B5P0000=B5P03001B5U8F00AB5P03001B5U8F
00AB5P03001B=U8f0080009B5P03001B=U8f00=B=P03001F=UHf00AF=P03001F=UHf0080009F=P03
001F=UHf00EF=P03001F=UHf00=F=P8000IF=P03001F=UHf00AF=P03001F=P0000AF=P03001J=UXf
00AJ=P04001JEUYF0004FSH00`00FUIJEP04FUH01000FUIJEP0015YF00<005YFFUH01EYF0P001EYF
00<005YFFUH015YF0P001eiF00D005iFGUINEP00009NEP03001NEUiF00ENEP03001NMUif00ENMP05
001NMUifGWH00003GWH00`00GWINMP05GWH00`00GWINMP05GWH01000GWINMP001F9f00<0069fHWH0
0V9f00@0069fHWH000IRMP03001RMP0000IRUP03001RUV:F00ERUP03001RUP0000IRUP04001RUV:F
0005HYH01000HYIRUP0016JF00@006JFIYH000EVUP04001VUVJF0005I[H01000I[IV]P0016Jf00@0
06JfI[H000EV]P03001V]`0000IV]`03001V]fJg00IV]`03001Zef[G009Ze`05001Ze`00J]L00004
J]L00`00J]MZe`02J]L01000J]MZe`001F[G00<006[GJ]L016[G00<006[G000016[G00D006[gJ_MZ
m`00009Zm`03001Zmf[g00AZm`03001Zmf[g00=Zm`05001^mfkgK_L00002K_L00`00K_M^m`03K_L0
0`00K_M^m`03K_L01P00KaM_5`00KaL000E_5`03001_600000=_6003001_66lH00=_6003001_>6lh
009_>003001_>6lh009_>003001c>7<h00=c>004001c>7<hLcP20006E_d00`00E_eFo@0300000eKm
001Fo@05E_d00`00E_eFo@0300000eKm001Fo@05E_d01000Oomoo`00[7oo002WOol30007Ool00`00
Oomoo`03Ool30006E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00
E_eFo@04E_d00`00E_d000020003E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@04E_d20005E_d0
0`00E_eFo@03E_d30006E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d0
0`00E_eFo@04E_d00`00E_d000020003E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20006
E_d00`00E_eFo@03E_d20005DUP01000<ILaUc6G1@00147h00<003gh?OP00Sgh00<0047h@OP00T7h
00<0047h@OP00T7h00<0047G@ML00T7G00<0047G@ML00T7G00<0047G@ML00d7G00<0047g@OL00T7g
00<0047g@OL00T7g00<0047g@OL00T7g00<0047g@OL00T7g00<004GgAOL00dGg00<004GgAOL00TGg
00<004GgAOL00TGg00<004GgAOL00dGg00<004GgAOL00TGg00<004GgAOL00TGg00<004GgAOL014Gg
00<004WgBOL01@000dWg00<004WgBOL00TWg00<004WgBOL00dWg00<004WgBOL00dWg00<004WgBOL0
0dWg00<004WgBOL00dWg00<004hFCQH00dhF10000ThF00<004hFCQH014hF00<004hFCQH00dhF00<0
04hFCQH00dhF00<004hFCQH00dhF0P0014hF00<004hFCQH014hF00<0058FDQH0158F00<0058FDQH0
0e8F0P001E8F00<0058FDQH0158F00<0058FDQH0158F0P001E8F00<0058fDSH00e8f00<005HfESH0
15Hf0P001EHf00<005HfESH015Hf00<005HfESH00UHf00<005Hf00001eHf00<005HfESH00eHf0P00
1EHf00<005XfFSH01EXf0P001EXf00<005YFFUH01EYF0P001EYF00<005YFFUH015YF0P001eYF00<0
05YFFUH00UYF00<005YF00001eiF00@005iFGUH000=NEP03001NEUiF00ENEP03001NMUif00ENMP04
001NMUif0004GWH00`00GWINMP04GWH20008GWH20006HWH01@00HWIRMV9f00000f9f00<0069fHWH0
0f9f00@0069fHWH000IRUP03001RUV:F00IRUP03001RUV:F00ERUP03001RUP0000IRUP03001RUP00
00EVUP03001VUP0000IVUP03001VUP0000IV]P03001V]P0000EV]P03001V]P0000MV]P03001V]fJg
00EV]`03001V]fJg00EV]`03001Z]`0000=Ze`80009Ze`03001Zef[G009Ze`03001Zef[G009Ze`03
001Ze`0000IZe`03001Zef[G00=Ze`04001Zef[G0004J]L00`00J_MZm`02J_L20007J_L00`00J_MZ
m`02J_L00`00K_M^m`02K_L00`00K_L00005K_L00`00K_L00003K_L00`00KaM_5`02KaL00`00KaM_
5`03KaL01@00KaQ_66lH00000VlH00<006lHKaP00flH00<006lhKcP00Vlh00<006lhKcP00Vlh00<0
07<hLcP00W<h00<007<hLcP00W<h0P001UKm0`001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d0
0eKm0P0000=oo`00Ool0Zgoo002TOol3000;Ool00`00Ool000020003E_d00`00E_eFo@03E_d20006
E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20007E_d00`00E_d0000200000eKm001Fo@05
E_d00`00E_eFo@0300000eKm001Fo@05E_d00`00E_d000020003E_d00`00E_eFo@03E_d20006E_d0
0`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d30006E_d00`00E_d000020002E_d00`00E_eFo@04
E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d0000200000eKm001BF004DUP01@00<ILa
Uc6G00000cVh1@0000=1n000?OP00Sgh00<0047h@OP00T7h00<0047h@OP00T7h00<0047G@ML00T7G
00<0047G@ML00T7G00<0047G@ML00d7G00<0047g@OL00T7g00<0047g@OL00T7g00<0047g@OL00T7g
00<0047g@OL00T7g00<004GgAOL00dGg00<004GgAOL00TGg00<004GgAOL00TGg00<004GgAOL00dGg
00<004GgAOL00dGg00<004GgAOL00TGg00<004GgAOL01P000TWg00<004WgBOL00dWg00<004WgBOL0
0dWg00<004WgBOL00dWg00<004WgBOL00dWg00<004WgBOL00dWg00<004WgBOL00dWg00<004hF0000
0P0000==mP00CQH00dhF00<004hFCQH014hF00<004hFCQH00dhF00<004hFCQH00dhF00@004hFCQI>
5P800003CQH004hF00A>5P03001>5ThF00A>5P03001B5U8F00=B5P04001B5U8FDQH200000e8F001B
5P04DQH00`00DQIB5P04DQH00`00DQIB5P03DQH20006DQH00`00DSIB=P03DSH00`00ESIF=P03ESH2
0006ESH00`00ESIF=P04ESH00`00ESIF=P020002ESH00`00ESIF=P05ESH00`00ESIF=P02ESH00`00
ESH00006ESH00`00FSIJ=P03FSH20006FSH00`00FUIJEP04FUH20007FUH00`00FUIJEP02FUH00`00
FUH00007FUH01@00FUIJEUYF00000eYF00<005iFGUH015iF00<005iF00001EiF00<005iFGUH00eiF
00<005iF00001eif0P001Uif00<005ifGWH00Uif00@005ifGWH000MNMP03001RMV9f00ERMP04001R
MV9f0005HWH01@00HWIRMV9f00000f9f00<006:FHYH00f:F00<006:F00001f:F00<006:FHYH01V:F
00<006:FHYH01V:F00<006JFIYH01FJF00<006JFIYH01VJF00<006JfI[H01VJf00<006JfI[H01FJf
00<006JfI[H01VJf00<006JgI[L016Jg00<006Jg00001FJg00@006ZgJ[L000=Ze`8000=Ze`04001Z
ef[G0006J]L00`00J]MZe`04J]L00`00J]L00004J]L01@00J]MZef[G00000V[G00<006[gJ_L00f[g
00<006[gJ_L01F[g00<006kg00000f[g00<006kgK_L00fkg00<006kgK_L00fkg00@006kgK_L0009^
m`03001_5flG00=_5`03001_5flG00=_5`07001_66lHKaP006lH00001FlH00<006lH00000Vlh00<0
06lhKcP00Vlh00<007<h00000g<h00D007<hLcQc>000009c>003001FoEKm00<00003E_d005Km00EF
o@03001FoEKm00<00003E_d005Km00EFo@03001FoEKm00<00005E_d007ooOol0002[Ool00:9oo`80
00ioo`<000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm
00AFo@03001Fo@000080009Fo@03001FoEKm00AFo@8000EFo@03001FoEKm00=Fo@<000EFo@03001F
oEKm00=Fo@<000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03001F
oEKm00AFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03
001FoEKm00=Fo@8000EFo@03001BF59H009BF003000aUc6G008aU`05000i^3Vh>KP00003?MP:0000
0d7h0011n003@OP00`00@MM1e`02@ML01@00@MM1ed7G00001D7G00<0047g@OL00T7g00<0047g@OL0
0T7g00<0047g@OL00T7g00<0047g@OL00T7g00<004GgAOL00dGg00<004GgAOL00TGg00<004GgAOL0
0dGg00<004GgAOL00dGg00<004GgAOL02P000dGg00<004WgBOL00TWg00<004WgBOL014Wg00<004Wg
BOL00TWg00<004WgBOL00dWg00<004WgBOL00dWg00<004WgBOL00dWg00<004WgBOL00TWg0`0014gf
00<004hFCQH00dhF00<004hFCQH00dhF00<004hFCQH00dhF00<004hFCQH014hF0`000dhF00<004hF
CQH00dhF00<004hFCQH014hF00<0058FDQH0158F0`000e8F00<0058FDQH00e8F00<0058FDQH0158F
00@0058FDQIB5P800003DQH0058F00EB5P03001B=U8f00=B=P04001F=UHfESH200000eHf001F=P05
ESH00`00ESIF=P05ESH20005ESH00`00ESIF=P04ESH01@00ESIF=UHf00000UHf00<005HfESH015Hf
00<005XfFSH00UXf00<005Xf00001eXf00<005YFFUH00UYF00<005YF00001eYF00D005YFFUIJEP00
009JEP03001JEUYF00EJEP04001JEUYF0004FUH00`00GUINEP05GUH00`00GUINEP04GUH00`00GUIN
EP02GUH01000GUINEP001eif00<005ifGWH01Eif00D005ifGWINMP0000=NMP03001NMUif00ENMP03
001RMV9f00IRMP8000IRMP05001RMV9fHWH00004HWH01@00HYIRUV:F00000V:F00<006:FHYH016:F
00<006:F00001f:F00<006:FHYH01V:F00<006JFIYH01FJF00<006JFIYH01VJF00<006JfI[H01VJf
00<006JfI[H01FJf00<006JfI[H01FJf00<006Jf000016Jg00@006JgI[L000AV]`03001Z]fZg009Z
]`04001Zef[G0004J]L00`00J]L00007J]L00`00J]MZe`03J]L01000J]MZe`000f[G00<006[GJ]L0
0V[G00<006[G00001V[g00<006[gJ_L016[g00@006kgK_L0009Zm`03001^mfkg00A^m`03001^mfkg
009^m`07001^mfkgK_L006kg00001FlG00<006lG00000flG00<006lHKaP00flH00<006lHKaP00flH
00H006lHKaP006lh0004KcP01`00LcQc>7<h001c>00000=c>003001c>7<h009c>08000EFo@03001F
oEKm00=Fo@<000EFo@03001FoEKm00=Fo@<000EFo@04001oogoo002ZOol009moo`<000eoo`<000=F
o@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03001F
oEKm00<00003E_d005Km00EFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@00008000=F
o@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@<000IFo@03001F
o@0000800003E_d005Km00IFo@03001Fo@0000800003E_d005Km00IFo@03001Fo@000080009Fo@03
001FoEKm009Fo@03001BF59H00=BF005000aUc6G<IL00004>KP01@00?MPmf3gH000013gH00@003gh
?OPmn0l00003@ML0047G00A1e`030011md7g0091m`030011md7g0091m`030011md7g0091m`030011
md7g0091m`030015mdGg00=5m`030015mdGg0095m`030015mdGg00/00095m`030015mdGg0095m`03
0015mdGg00=5m`030019mdWg00=9m`030019mdWg00=9m`030019mdWg0099m`030019mdWg00=9m`03
0019mdWg00=9m`030019mdWg00=9m`030019m`0000800003BOH004gf00E=mP03001>5ThF009>5P03
001>5ThF00A>5P03001>5ThF009>5P03001>5ThF00=>5P8000I>5P03001>5ThF009>5P03001>5ThF
00A>5P03001B5U8F00=B5P8000IB5P03001B5U8F00=B5P03001B5U8F00AB5P<000=B5P03001B5U8F
00EB5P03001B=U8f00=B=P<000=F=P03001F=UHf00EF=P03001F=UHf00=F=P8000IF=P03001F=UHf
00AF=P04001F=UHf0004ESH00`00ESIF=P03ESH01@00FSIJ=UXf00000UXf00<005XfFSH01EXf00D0
05YFFUIJEP00009JEP03001JEUYF00EJEP04001JEUYF0004FUH00`00FUIJEP05FUH20005FUH00`00
GUINEP04GUH20007GUH01000GUINEP000eiF00<005ifGWH01Eif00<005ifGWH01Eif00@005ifGWH0
00ANMP03001NMUif00ANMP03001NMP0000MRMP03001RMV9f00ERMP04001RMV9f0005HWH01000HYIR
UP000f:F00<006:FHYH00f:F00@006:FHYH000IRUP03001RUP0000IRUP03001VUP0000EVUP03001V
UP0000IVUP03001VUP0000IV]P03001V]P0000EV]P03001V]P0000EV]P04001V]VJf0004I[L01@00
I[MV]fJg00000fJg00<006ZgJ[L00VZg00@006[GJ]L000EZe`03001Zef[G00EZe`03001Ze`0000AZ
e`05001Zef[GJ]L00002J]L00`00J]MZe`03J]L00`00J_MZm`04J_L00`00J_L00004J_L01`00K_M^
mfkg001Zm`0000I^m`03001^m`0000=^m`03001^mfkg009^m`03001_5flG00=_5`05001_5flGKaL0
0002KaL00`00KaQ_6003KaP00`00KaQ_6002KaP00`00KaQ_6002KaP00`00KcQ_>003KcP00`00LcQc
>002LcP00`00LcQc>002LcP00`00LcQc>002LcP00`00E_eFo@04E_d00`00E_eFo@0300000eKm001F
o@05E_d00`00E_eFo@0300000eKm001Fo@05E_d01000Oomoo`00ZWoo002MOol2000=Ool40006E_d0
0`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d0000200000eKm001Fo@06E_d00`00E_d00002
0002E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d30006E_d0
0`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d0
00020003E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@04E_d20005E_d00`00E_eFo@04E_d20006
E_d00`00E_eFo@02E_d00`00DUQBF002DUP01@00<ILaUc6G000013Vh00<003gH?MP00SgH00<003gH
?MP00SgH00D003gh?OPmn00000A1n0030011ed7G0091e`040011ed7G@MLY0002AOL00`00AOM5m`03
AOL00`00AOM5m`02AOL00`00AOM5m`02AOL00`00AOM5m`04AOL00`00BOM9m`02BOL00`00BOM9m`03
BOL00`00BOM9m`03BOL00`00BOM9m`03BOL00`00BOM9m`03BOL00`00BOM9m`040004BOH00`00COI=
mP04COH00`00CQI>5P02CQH00`00CQI>5P04CQH00`00CQI>5P03CQH00`00CQH0000200000dhF001>
5P05CQH00`00CQI>5P03CQH00`00CQI>5P03CQH01000DQIB5U8F0P0000=B5P00DQH01E8F00<0058F
DQH00e8F00<0058FDQH00e8F0P001U8F00<0058FDQH0158F00<0058fDSH00U8f0P001UHf00<005Hf
ESH015Hf00<005HfESH00UHf00<005Hf00001UHf00<005HfESH01EHf0P001EHf00<005HfESH00eHf
00@005XfFSH000AJ=P03001J=UXf00AJ=P04001JEUYF0004FUH00`00FUIJEP05FUH20005FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00GUINEP02GUH00`00GUH00007GUH01000GUINEP0015iF00<0
05ifGWH00eif00<005if00001eif0P001Uif00<005ifGWH00Uif00@005ifGWH000MRMP03001RMV9f
00IRMP8000IRMP04001RUV:F0004HYH01@00HYIRUV:F00000f:F00<006:FHYH00f:F00@006:FHYH0
00ERUP04001VUVJF0004IYH01000IYIVUP001FJF00@006JFIYH000EV]P04001V]VJf0004I[H01000
I[IV]P0016Jf00<006JfI[H00VJf00@006JgI[L000AV]`04001V]fJg0005J[L01000J]L000001F[G
00<006[GJ]L016[G00@006[GJ]L000=Ze`03001Zef[G009Ze`03001Ze`0000IZe`03001Zmf[g00=Z
m`05001Zmf[gJ_L00002J_L00`00K_M^m`03K_L00`00K_M^m`04K_L01000K_M^m`000Vkg00<006kg
K_L00fkg00<006lGKaL00flG00L006lGKaM_5`00KaL00005KaP00`00KaP00003KaP00`00KaQ_6002
KaP00`00KcQ_>002KcP00`00LcQc>003LcP01@00LcQc>7<h000017<h00<007<h00001EKm0`001EKm
00<005KmE_d00eKm0`001EKm00@005KmE_eFo@@0009oo`03001oogoo0:Moo`00VWoo0`002goo1000
15Km00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001EKm00<005KmE_d015Km0P001UKm00<0
05Km00000P000UKm00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d015Km00<005Km0000
0P000eKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001eKm
00<005Km00000P0000=Fo@00E_d01EKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d00`00
0UKm00<005KmE_d00eKm0`000UKm00<0059HDUP00U9H00<0036G<IL00S6G00D003Vh>KPi^00000@m
f003000mf3gH008mf003000mn3gh008mn0030011n47h0091n0030011ed7G0091e`050011ed7G@ML0
0005@ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00@OM1m`02@OL00`00@OM1m`02@OL00`00@OM1
m`03@OL00`00AOM5m`02AOL00`00AOM5m`02AOL00`00AOM5m`03AOL00`00AOM5m`03AOL00`00AOM5
m`02AOL00`00AOM5m`03AOL00`00BOM9m`02BOL00`00BOM9m`04BOL00`00BOM9m`02BOL00`00BOM9
m`03BOL00`00BOM9m`02BOL40003BOH00`00BOI9mP03BOH00`00COI=mP03COH00`00CQI>5P03CQH0
0`00CQI>5P03CQH00`00CQI>5P02CQH30004CQH00`00CQI>5P04CQH00`00CQI>5P03CQH00`00CQI>
5P04CQH30003DQH00`00DQIB5P04DQH00`00DQIB5P03DQH00`00DQIB5P02DQH00`00DQH00006DQH0
0`00DQIB5P04DQH01`00DSIB=U8f001B=P0000IF=P03001F=UHf00AF=P03001F=UHf0080009F=P03
001F=UHf00EF=P03001F=UHf00=F=P8000IF=P03001F=UHf00AF=P8000EJ=P03001J=UXf00EJ=P80
00EJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00AJEP8000MJEP05001NEUiFGUH00003
GUH00`00GUINEP04GUH00`00GUH00005GUH00`00GWINMP02GWH01000GWINMP001eif00<005ifGWH0
1Eif00D005ifGWINMP0000=NMP03001RMV9f00ARMP03001RMP0000MRMP03001RMV9f00IRMP8000ER
UP04001RUV:F0005HYH01@00HYIRUV:F00000f:F00<006:FHYH00V:F00D006JFIYIVUP0000AVUP04
001VUVJF0004IYH01@00IYIVUVJF000016Jf00D006JfI[IV]P0000AV]P05001V]VJfI[H00003I[H0
0`00I[IV]P02I[H01000I[MV]`0016Jg00<006Jg00001fZg0`0016[G00<006[G000016[G00<006[G
J]L00V[G00@006[GJ]L000EZe`03001Zef[G00AZe`03001Ze`0000AZm`07001Zmf[gJ_L006[g0000
1Vkg00<006kgK_L00fkg00L006kgK_M^m`00K_L00005K_L00`00K_L00003KaL00`00KaM_5`03KaL0
0`00KaQ_6003KaP01`00KaQ_66lH001_600000A_6003001_>00000=_>003001c>7<h009c>003001c
>000009c>005001c>7<hLcP00002LcP00`00E_eFo@0300000eKm001Fo@05E_d00`00E_eFo@030002
E_d00`00E_eFo@03E_d40004E_d01000Oomoo`00Z7oo002HOol2000;Ool30002E_d00`00E_eFo@04
E_d00`00E_d0000200000eKm001Fo@06E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_eFo@03
0002E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d30006E_d0
0`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d0
00020002E_d00`00E_eFo@04E_d20005E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@03E_d30006
E_d00`00E_d0000200000e9i000e]`030005DUP01@00<ILaUc6G000013Vh00D003gH?MPmf00000@m
f003000mn3gh008mn0030011n47h0091n0030011ed7G0091e`030011ed7G0091e`030011ed7G00=1
e`030011ed7G0091e`050011ed7G@ML00004@OL00`00@OM1m`02@OL00`00@OM1m`03@OL00`00AOM5
m`02AOL00`00AOM5m`03AOL00`00AOM5m`03AOL00`00AOM5m`02AOL00`00AOM5m`02AOL00`00AOM5
m`03AOL00`00BOM9m`03BOL00`00BOM9m`03BOL00`00BOM9m`02BOL00`00BOM9m`03BOL00`00BOL0
000200000dWg0019mP04BOH00`00BOI9mP03BOH00`00COI=mP04COH00`00CQI>5P02CQH00`00CQI>
5P04CQH400000dhF001>5P05CQH00`00CQI>5P04CQH00`00CQI>5P02CQH00`00CQI>5P03CQH20006
DQH00`00DQIB5P04DQH00`00DQIB5P02DQH00`00DQIB5P020002DQH00`00DQIB5P04DQH00`00DQIB
5P04DQH01000DSIB=P000e8f00<005HfESH00eHf00<005HfESH01EHf0P001EHf00<005HfESH015Hf
00<005HfESH00UHf00<005Hf00001eHf00<005HfESH00eHf00<005XfFSH015Xf00<005XfFSH015Xf
0P001UYF00<005YFFUH015YF0P001eYF00<005YFFUH00UYF00<005YF00001eYF00@005iFGUH000AN
EP03001NEUiF00ENEP03001NEUiF00ENEP04001NMUif0003GWH00`00GWINMP05GWH00`00GWINMP05
GWH01000GWINMP001Eif00<0069fHWH00V9f00@0069fHWH000MRMP03001RMV9f00IRMP03001RUV:F
00ARUP03001RUP0000IRUP04001RUV:F0005HYH01@00HYIRUV:F000016JF00@006JFIYH000AVUP05
001VUVJFIYH00004IYH01@00I[IV]VJf000016Jf00@006JfI[H000AV]P04001V]VJf0005I[H00`00
I[L00006I[L00`00J[MZ]`04J[L300000f[G001Ze`02J]L01000J]MZe`0016[G00<006[GJ]L00V[G
00<006[G00001V[G00<006[GJ]L00f[G00@006[GJ]L000=Zm`03001Zmf[g00=Zm`03001^mfkg00A^
m`03001^m`0000A^m`03001^mfkg009^m`03001^mfkg00=^m`05001^mfkgK_L00002KaL00`00KaM_
5`03KaL00`00KaQ_6003KaP00`00KaQ_6002KaP00`00KaQ_6002KaP01`00KcQ_>6lh001_>00000Ac
>006001c>7<h001c>00017<h00@007<hLcQc>08000EFo@03001FoEKm00=Fo@<000IFo@03001Fo@00
00800003E_d005Km00IFo@03001oo`000:Qoo`00UGoo0`002goo0P001UKm00<005KmE_d00eKm0P00
1EKm00<005KmE_d015Km0P001EKm00<005KmE_d00eKm0`001UKm00<005Km00000P000UKm00<005Km
E_d015Km00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000eKm00<005KmE_d00eKm
0P001UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00`0000=Fo@00
E_d01EKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000eKm00<005KmE_d00eKm
0P001E9i00@003Fg=KLe]`X000@i^003000mf3gH008mf003000mf3gH008mf005000mn3gh?OP00004
@OP00`00@MM1e`02@ML00`00@MM1e`02@ML00`00@MM1e`03@ML00`00@MM1e`02@ML00`00@MM1e`02
@ML00`00@OM1m`02@OL00`00@OM1m`02@OL00`00@OM1m`03@OL00`00AOM5m`02AOL00`00AOM5m`02
AOL00`00AOM5m`03AOL00`00AOM5m`02AOL00`00AOM5m`02AOL00`00AOM5m`04AOL00`00BOM9m`02
BOL00`00BOM9m`03BOL00`00BOM9m`03BOL00`00BOM9m`040004BOL00`00BOI9mP04BOH00`00BOI9
mP02BOH00`00COI=mP04COH00`00CQI>5P02CQH00`00CQI>5P03CQH20005CQH00`00CQI>5P03CQH0
0`00CQI>5P04CQH00`00CQI>5P02CQH01000CQI>5ThF0P0000=>5P00DQH01E8F00<0058FDQH0158F
00<0058FDQH00e8F0P001E8F00<0058FDQH0158F00<0058FDQH0158F0P00158f00<005HfESH015Hf
00<005HfESH00eHf0P001UHf00<005HfESH015Hf00<005HfESH00P000UHf00<005HfESH01EHf00<0
05HfESH00UHf0P001eXf00<005XfFSH00UXf00<005Xf00001eYF00<005YFFUH00UYF00<005YF0000
1eYF00D005YFFUIJEP0000=JEP03001JEUYF00EJEP8000ENEP03001NEUiF00ANEP8000MNEP04001N
MUif0004GWH00`00GWINMP03GWH20008GWH20006GWH01@00HWIRMV9f00000f9f00<0069fHWH0169f
00<0069f00001f9f00<006:FHYH01F:F00<006:FHYH01F:F00<006:F00001V:F00@006:FHYH000EV
UP04001VUVJF0004IYH01000IYIVUP001FJF00@006JfI[H000EV]P04001V]VJf0004I[H00`00I[H0
0007I[H00`00I[MV]`05I[L01000J[MZ]fZg0`0000IZ]`00J]L006[G0002J]L01@00J]MZef[G0000
0V[G00<006[GJ]L016[G00<006[GJ]L016[G00<006[G000016[G00D006[GJ]MZe`00009Zm`03001Z
mf[g00=Zm`03001^mfkg00=^m`05001^mfkgK_L00002K_L00`00K_M^m`03K_L00`00K_M^m`03K_L0
1`00K_M^mfkg001_5`0000E_5`03001_5`0000=_6003001_66lH00=_6005001_66lHKaP00005KcP0
0`00LcQc>002LcP00`00LcQc>002LcP00`00LcQc>002LcP00`00LcQc>002LcP00`00E_eFo@05E_d0
0`00E_d000020002E_d00`00E_eFo@04E_d20005E_d00`00E_eFo@04E_d200000goo001oo`2VOol0
09=oo`8000]oo`<0009Fo@03001FoEKm00AFo@03001Fo@0000800003E_d005Km00EFo@03001FoEKm
00<0009Fo@03001FoEKm00=Fo@03001Fo@00008000=Fo@03001FoEKm00=Fo@8000IFo@03001FoEKm
00=Fo@8000IFo@03001FoEKm00=Fo@<000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001F
o@0000800003E_d005Km00IFo@03001Fo@000080009Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm
00=Fo@8000IFo@03001FoEKm00=Fo@<000IFo@03001Fo@0000800003E_d0059i00ABN@05000e]cFg
=KL00004?OP01000>MPif3WH0`000SVh00<003gH?MP00SgH00<003gH?MP00SgH00<003gh?OP00Sgh
00<0047h@OP00T7h00<0047G@ML00T7G00D0047G@MM1e`0000E1e`030011ed7G0091e`030011ed7G
0091e`030011md7g0091m`030011md7g0091m`030011md7g00=1m`030015mdGg0095m`030015mdGg
0095m`030015mdGg00=5m`030015mdGg00=5m`030015mdGg0095m`030015mdGg00=5m`030019mdWg
0099m`030019mdWg00A9m`030019mdWg00D000=9m`030019mdWg00=9m`030019mTWf00=9mP030019
mTWf00=9mP03001=mTgf00==mP03001>5ThF00=>5P03001>5P0000800003CQH004hF00A>5P03001>
5ThF00=>5P03001>5ThF00A>5P03001>5ThF00=>5P<000=>5P03001B5U8F00AB5P03001B5U8F00AB
5P03001B5U8F009B5P8000IB5P03001B5U8F00AB5P03001B5U8F00=B5P8000EB=P03001F=UHf00AF
=P03001F=UHf009F=P03001F=P0000IF=P03001F=UHf00EF=P8000EF=P03001F=UHf00AF=P05001F
=UHfESH00002ESH00`00FSIJ=P04FSH01@00FSIJ=UXf00000UXf00<005YFFUH01EYF00D005YFFUIJ
EP0000=JEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00GUINEP05GUH00`00
GUINEP02GUH01000GUINEP001UiF00<005if00001Eif00<005ifGWH00Uif00@005ifGWH000MNMP03
001NMUif00ENMP04001RMV9f0005HWH00`00HWIRMP02HWH01000HWIRMP001V9f00<0069f00001V:F
00<006:FHYH01V:F00<006:FHYH01F:F00<006:F00001VJF00<006JF00001FJF00<006JF00001VJF
00<006Jf00001VJf00<006Jf00001VJf00<006JfI[H01VJf00<006JgI[L016Jg00<006Zg00000P00
0fZg00@006[GJ]L0009Ze`8000AZe`03001Ze`0000MZe`03001Zef[G00=Ze`04001Zef[G0003J]L0
0`00J]MZe`02J]L00`00J_L00005J_L00`00K_L00004K_L01`00K_M^mfkg001^m`0000E^m`03001^
m`0000=^m`03001^mfkg00=^m`03001_5flG00=_5`05001_5flGKaL00002KaP00`00KaQ_6002KaP0
0`00KaP00002KaP00`00KcQ_>003KcP00`00LcQc>002LcP00`00LcQc>002LcP20003LcP01`00LcQc
>7<h001c>00000IFo@8000IFo@03001FoEKm00<00003E_d005Km00EFo@03001FoEKm00<00005E_d0
07ooOol0002VOol0091oo`<000]oo`8000IFo@03001FoEKm00=Fo@8000EFo@03001FoEKm00=Fo@<0
00IFo@04001FoEKmE_d40006E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002
E_d00`00E_eFo@04E_d00`00E_d000020003E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d2
0005E_d00`00E_eFo@04E_d20006E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d00002
0002E_d00`00E_eFo@04E_d00`00E_d000020003E_d00`00E_eFo@03E_d20005E_d00`00DWUBN@02
DWT00`00=KLe]`02=KL00`00?OPmn002?OP01P00>MPif3WH000if0@000<mf003000mf3gH008mf003
000mn3gh008mn0030011n47h0091n0030011ed7G0091e`030011ed7G0091e`030011ed7G00=1e`03
0011ed7G0091e`050011ed7G@ML00004@OL00`00@OM1m`02@OL00`00@OM1m`03@OL00`00AOM5m`02
AOL00`00AOM5m`03AOL00`00AOM5m`03AOL00`00AOM5m`02AOL00`00AOM5m`02AOL00`00AOM5m`03
AOL00`00BOM9m`03BOL00`00BOM9m`060002BOL00`00BOM9m`03BOL00`00BOM9m`03BOL00`00BOI9
mP03BOH00`00BOI9mP03BOH00`00COI=mP03COH00`00CQI>5P02CQH30004CQH00`00CQI>5P03CQH0
0`00CQI>5P04CQH00`00CQI>5P03CQH00`00CQI>5P02CQH20006CQH00`00DQIB5P04DQH00`00DQIB
5P03DQH00`00DQIB5P0200000e8F001B5P05DQH00`00DQIB5P04DQH00`00DQIB5P02DQH00`00DQH0
0006DSH00`00ESIF=P03ESH00`00ESIF=P020002ESH00`00ESIF=P05ESH00`00ESIF=P03ESH20006
ESH00`00ESIF=P04ESH01000ESIF=P000eHf00<005XfFSH015Xf00@005XfFSH000AJ=P03001JEUYF
00AJEP04001JEUYF0004FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP04FUH20007GUH01@00GUIN
EUiF00000eiF00<005iFGUH01EiF00<005ifGWH01Eif00@005ifGWH000=NMP03001NMUif00ENMP03
001NMUif00INMP8000IRMP05001RMV9fHWH00003HWH00`00HWIRMP03HWH01000HWIRMP001F:F00<0
06:F00001f:F00<006:FHYH01V:F00<006JFIYH01VJF00<006JFIYH01FJF00<006JFIYH01VJF00<0
06JfI[H01VJf00<006JfI[H01FJf00<006JfI[H01FJf00<006Jf000016Jg100016Zg00<006[GJ]L0
0V[G00@006[GJ]L000EZe`03001Zef[G00EZe`03001Ze`0000=Ze`03001Zef[G009Ze`04001Zef[G
0005J]L00`00J_MZm`03J_L01000K_M^m`000fkg00<006kgK_L00fkg00<006kgK_L00fkg00D006kg
K_M^m`00009^m`03001^mfkg00=^m`03001_5flG00=_5`07001_5flGKaL006lH000016lH00H006lH
KaP006lH0005KcP00`00LcP00002LcP00`00LcQc>002LcP01P00LcQc>000LcP000=c>005001c>7<h
LcP00002E_d300000eKm001Fo@05E_d30005E_d00`00E_eFo@03E_d30005E_d00`00Ool0002VOol0
08eoo`<000]oo`<0009Fo@03001FoEKm00AFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@00
008000=Fo@03001FoEKm00=Fo@@000AFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@<000EF
o@03001FoEKm00=Fo@<000IFo@03001Fo@0000800003E_d005Km00IFo@03001Fo@0000800003E_d0
05Km00EFo@03001FoEKm00<0009Fo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03
001FoEKm00=Fo@<000IFo@03001Fo@0000800003E_d005Km00AFo@03001BNE9i00=BN@05000e]cFg
=KL00004?OP00`00>MPif002>MP01000>MPif3WH2@0000<mf000?OP00Sgh00<0047h@OP00T7h00<0
047G@ML00T7G00<0047G@ML00T7G00<0047G@ML00d7G00<0047G@ML00T7G00<0047G@ML00T7G00<0
047g@OL00T7g00<0047g@OL00T7g00<0047g@OL00d7g00<004GgAOL00TGg00<004GgAOL00TGg00<0
04GgAOL00dGg00<004GgAOL00TGg00<004GgAOL00TGg00<004GgAOL014Gg00<004WgBOL01@000dWg
00<004WgBOL00TWg00<004WgBOL014Wg00<004WgBOL00TWg00<004WfBOH014Wf00<004WfBOH00TWf
00<004gfCOH014gf100000==mP00CQH01DhF00<004hFCQH00dhF00<004hFCQH00dhF00<004hFCQH0
14hF100000=>5P00CQH01DhF00<0058FDQH0158F00<0058FDQH0158F0P000e8F00<0058FDQH01E8F
00<0058FDQH00e8F00<0058FDQH00P000U8F00<0058fDSH0158f00<005HfESH015Hf0P001EHf00<0
05HfESH015Hf00<005HfESH00UHf00<005Hf00001UHf00<005HfESH01EHf0P0015Hf00<005XfFSH0
1EXf0P001EXf00<005YFFUH01EYF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005iF00001eiF00@005iFGUH000ANEP03001NEUiF00ANEP8000MNMP04001NMUif0003GWH0
0`00GWINMP04GWH00`00GWH00007GWH00`00HWIRMP05HWH01000HWIRMP001F9f00D0069fHWIRMP00
00=RMP03001RUV:F009RUP04001RUV:F0006HYH00`00HYH00007HYH00`00IYIVUP06IYH00`00IYIV
UP05IYH00`00IYIVUP06IYH00`00I[IV]P06I[H00`00I[IV]P04I[H00`00I[H00005I[H01@00I[IV
]P00I[L010000fZg00D006ZgJ[MZ]`0000AZe`04001Ze`000005J]L00`00J]MZe`04J]L01000J]MZ
e`000f[G00<006[GJ]L00V[G00<006[G00001V[G00<006[gJ_L00f[g00D006kgK_M^m`00009^m`03
001^mfkg00=^m`03001^mfkg00=^m`07001^mfkgK_L006kg00001Fkg00<006lG00000flG00<006lG
KaL00flG00<006lHKaP00VlH00<006lHKaP00VlH00<006lhKcP00flh00H007<hLcP007<h0004LcP0
0`00LcQc>002LcP00`00LcQc>002LcP00`00LcQc>002LcP20005E_d00`00E_eFo@0300000eKm001F
o@05E_d00`00E_eFo@0300000eKm001Fo@05E_d01000Oomoo`00YGoo002;Ool2000<Ool20006E_d0
0`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d30006E_d00`00E_d000020002E_d00`00E_eFo@04
E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020003E_d00`00E_eFo@03E_d00`00
E_d000020003E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@04E_d20005E_d00`00E_eFo@03E_d3
0006E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@04E_d0
0`00E_d000020003E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d00`00DWUBN@02DWT01@00
=KLe]cFg000013gh00<003WH>MP00SWH00D003WH>MPif00000@mf004000mf3gH?MP500000cgh0011
n003@OP00`00@MM1e`02@ML01@00@MM1ed7G00001D7G00<0047G@ML00T7G00<0047G@ML00T7G00<0
047g@OL00T7g00<0047g@OL00T7g00<0047g@OL00d7g00<004GgAOL00TGg00<004GgAOL00TGg00<0
04GgAOL00dGg00<004GgAOL00dGg00<004GgAOL00TGg00<004GgAOL01P000TWg00<004WgBOL00dWg
00<004WgBOL00dWg00<004WgBOL00dWg00<004WgBOL00dWg00<004WfBOH00dWf00<004WfBOH00TWf
00<004gfCOH00dgf0P0014gf00<004hFCQH014hF00<004hFCQH00dhF00<004hFCQH00dhF00<004hF
CQH00dhF0P001DhF00<004hFCQH00dhF00<0058FDQH0158F00<0058FDQH00e8F0P001E8F00<0058F
DQH0158F00<0058FDQH0158F0P001E8F00<0058fDSH00e8f00<005HfESH00eHf0P001UHf00<005Hf
ESH015Hf00D005HfESIF=P00009F=P03001F=UHf00EF=P03001F=UHf00=F=P8000IF=P03001J=UXf
00AJ=P03001J=UXf00AJ=P03001JEUYF00AJEP8000MJEP03001JEUYF00=JEP8000MJEP05001JEUYF
FUH00003GUH00`00GUINEP05GUH20006GUH00`00GUINEP02GUH00`00GUH00007GWH00`00GWH00005
GWH00`00GWINMP02GWH01000GWINMP001eif00<0069fHWH01V9f0P001V9f00@0069fHWH000ERMP05
001RUV:FHYH00003HYH00`00HYIRUP02HYH01000HYIRUP001V:F00<006:F00001VJF00<006JF0000
1FJF00<006JF00001VJF00<006Jf00001VJf00<006Jf000016Jf00@006JfI[H000AV]P03001V]VJf
00<0009V]`03001Z]fZg009Z]`04001Z]fZg0006J]L01000J]MZe`000f[G00<006[G00001F[G00@0
06[GJ]L0009Ze`03001Zef[G00AZe`03001Zef[G00AZe`03001Zm`0000=Zm`03001^mfkg009^m`03
001^m`0000E^m`03001^m`0000=^m`03001^mfkg00=^m`03001^mfkg00=^m`05001_5flGKaL00002
KaL00`00KaM_5`03KaL00`00KaQ_6002KaP00`00KaQ_6002KaP00`00KcQ_>002KcP00`00LcQc>002
LcP00`00LcQc>002LcP00`00LcQc>003LcP01@00LcQc>7<h00001G<h00<005KmE_d015Km0`001EKm
00<005KmE_d00eKm0`001EKm00<005KmE_d00eKm0P000Woo00<007ooOol0XWoo0028Ool3000;Ool3
0002E_d00`00E_eFo@04E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d000020003E_d00`00
E_eFo@03E_d20006E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d30006E_d01000E_eFoEKm
10001UKm00<005Km00000P0000=Fo@00E_d01EKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005Km
00000P000eKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P00
1eKm00<005Km00000P0000=Fo@00E_d01EKm00<005KmE_d00UKm00<0059iDWT00U9i00<003Fg=KL0
0SFg00<003gh?OP00Sgh00D003WH>MPif00000@if003000mf3gH008mf005000mf3gH?MP00003?MP?
00000d7G0011e`04@ML00`00@MM1e`02@ML01@00@MM1ed7G0000147g00<0047g@OL00T7g00<0047g
@OL00d7g00<004GgAOL00TGg00<004GgAOL00dGg00<004GgAOL00dGg00<004GgAOL02P000dGg00<0
04WgBOL00TWg00<004WgBOL014Wg00<004WgBOL00TWg00<004WgBOL00dWg00<004WgBOL00dWg00<0
04WfBOH00dWf00<004WfBOH00dWf00<004gf00000P0000==mP00COH014gf00<004hFCQH00dhF00<0
04hFCQH00dhF00<004hFCQH014hF00<004hF00000P0000=>5P00CQH014hF00<004hFCQH014hF00<0
058FDQH00e8F00@0058FDQIB5P800003DQH0058F00AB5P03001B5U8F00AB5P03001B5U8F00=B5P80
00IB5P03001B=U8f00AB=P07001F=UHfESH005Hf00001UHf00<005HfESH015Hf00@005HfESH000AF
=P03001F=UHf00AF=P03001F=UHf009F=P03001F=P0000IF=P03001J=UXf00=J=P8000MJ=P03001J
EUYF009JEP03001JEP0000MJEP03001JEUYF009JEP03001JEP0000MJEP04001JEUYF0004GUH00`00
GUINEP05GUH00`00GUINEP05GUH01@00GUINEUiF00000eiF00<005ifGWH01Eif00<005ifGWH015if
00D005ifGWINMP0000=NMP03001NMUif00ANMP03001RMP0000MRMP03001RMV9f00ERMP03001RMP00
00IRMP04001RUV:F0004HYH00`00HYIRUP02HYH01000HYIRUP001F:F00@006:FHYH000EVUP04001V
UVJF0004IYH01000IYIVUP001FJF00@006JfI[H000EV]P04001V]VJf0004I[H01@00I[IV]VJf0000
0fJf0`000VJf00@006JgI[L000AZ]`03001Z]`0000MZe`07001Zef[GJ]L006[G00000V[G00<006[G
J]L00V[G00<006[GJ]L00V[G0P001f[G00<006[GJ]L00f[G00D006[gJ_MZm`00009Zm`03001^mfkg
00=^m`03001^mfkg00=^m`05001^mfkgK_L00002K_L00`00K_M^m`03K_L00`00K_M^m`03K_L01`00
KaM_5flG001_5`0000E_5`03001_6000009_6003001_66lH009_6003001_600000=_>003001c>7<h
009c>08000=c>003001c>7<h009c>003001c>000009c>003001c>7<h009c>003001c>000009Fo@<0
0003E_d005Km00EFo@03001FoEKm00<00003E_d005Km00EFo@03001FoEKm00<00004E_d007ooOol2
002SOol008Ioo`8000aoo`8000IFo@03001FoEKm00=Fo@8000EFo@03001FoEKm00=Fo@<000IFo@03
001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@00
008000=Fo@03001FoEKm00=Fo@@000AFo@03001FoEKm00=Fo@8000EFo@03001FoEKm00=Fo@<000EF
o@03001FoEKm00=Fo@<000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009F
o@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm00AFo@8000EFo@03001FoEKm00=Fo@H0
00EBN@05000e]cFg=KL00004?OP00`00>MPif002>MP01@00>MPif3WH000013gH00<003gH?MP00SgH
00D003gH?MPmf00000@mf003000mecgG008me`04000mecgG?ML@00000d7G0011m`03@OL00`00@OM1
m`02@OL00`00@OM1m`03@OL00`00AOM5m`02AOL00`00AOM5m`0;0002AOL00`00AOM5m`02AOL00`00
AOM5m`03AOL00`00BOM9m`03BOL00`00BOM9m`03BOL00`00BOM9m`02BOL00`00BOM9m`04BOL00`00
BOM9m`02BOL00`00BOI9mP04BOH00`00BOI9mP040004COH00`00COI=mP03COH00`00CQI>5P04CQH0
0`00CQI>5P03CQH00`00CQI>5P02CQH30004CQH00`00CQI>5P03CQH00`00CQI>5P04CQH00`00DQIB
5P04DQH30003DQH00`00DQIB5P03DQH00`00DQIB5P04DQH01000DQIB5U8F0P0000=B5P00DQH01E8F
00<0058fDSH0158f00@005HfESH000=F=P03001F=UHf00AF=P03001F=UHf00AF=P8000EF=P03001F
=UHf00AF=P03001F=UHf0080009F=P03001F=UHf00EF=P05001J=UXfFSH00002FSH00`00FSIJ=P04
FSH01@00FUIJEUYF00000UYF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF00EJEP80
00ENEP03001NEUiF00ANEP8000MNEP04001NEUiF0004GUH00`00GWINMP05GWH00`00GWINMP04GWH0
1000GWINMP001Eif00<005ifGWH00Uif00@0069fHWH000MRMP03001RMV9f00IRMP03001RMV9f00ER
MP04001RUV:F0004HYH01@00HYIRUV:F000016:F00D006:FHYIRUP0000=RUP03001VUVJF009VUP05
001VUVJFIYH00004IYH01000IYIVUP0016JF00<006JfI[H00VJf00D006JfI[IV]P0000AV]P04001V
]VJf0004I[H01000I[H000001FJf00<006Jg00001VZg00<006[GJ]L01F[G00<006[G00000V[G00<0
06[G00000f[G00@006[GJ]L000EZe`03001Zef[G00EZe`03001Ze`0000AZe`07001Zmf[gJ_L006[g
00001Vkg00<006kgK_L00fkg00L006kgK_M^m`00K_L00005K_L00`00K_L00003K_L00`00KaM_5`03
KaL00`00KaM_5`03KaL01P00KaQ_6000KaP000A_6007001_66lHKaP006lh000017<h00H007<hLcP0
07<h0004LcP01P00LcQc>000LcP000Ac>004001c>7<hLcP20005E_d00`00E_eFo@03E_d30005E_d0
0`00E_eFo@03E_d30005E_d200000goo001oo`2ROol008=oo`<000]oo`<0009Fo@03001FoEKm00AF
o@03001Fo@0000800003E_d005Km00EFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@8000IFo@03
001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@<000IFo@03001Fo@0000800003E_d005Km00IFo@03
001Fo@0000800003E_d005Km00EFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@03001Fo@000080
00=Fo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03
001FoEKm00<00003E_d005Km00EFo@03001Fo@0000800003E_d003GI008ef@/000@mn003000if3WH
008if005000if3WH>MP00004?MP00`00?MPmf002?MP00`00?MPmf002?MP00`00?MPmf002?MP01@00
?MLmecgG000013gG00<0047G@ML00d7G00<0047G@ML00T7G00@0047G@MM1eaT00095m`030015mdGg
00=5m`030015mdGg0095m`030015mdGg0095m`030015mdGg00A5m`030019mdWg0099m`030019mdWg
00=9m`030019mdWg00=9m`030019mdWg00=9m`030019mdWg0099m`030019mTWf00=9mP@00099mP03
001=mTgf00A=mP03001=mTgf009=mP03001>5ThF00A>5P03001>5ThF00=>5P03001>5ThF00800003
CQH004hF00E>5P03001>5ThF00=>5P03001>5ThF00=>5P03001B5U8F00=B5P8000IB5P03001B5U8F
00=B5P03001B5U8F00AB5P<000=B5P03001B5U8F00EB5P03001B=U8f00=B=P03001F=P0000AF=P03
001F=UHf00AF=P03001F=UHf00=F=P8000IF=P03001F=UHf00EF=P8000EF=P03001F=UHf00AF=P04
001J=UXf0003FSH00`00FSIJ=P04FSH01000FUIJEP0015YF00<005YFFUH015YF00@005YFFUH000AJ
EP03001JEUYF00EJEP03001NEUiF00ENEP03001NEUiF009NEP03001NEP0000QNEP8000ENEP03001N
MUif00ANMP03001NMP0000INMP8000INMP05001NMUifGWH00003HWH00`00HWIRMP04HWH00`00HWH0
0007HWH00`00HWIRMP06HWH20006HYH01000HYIRUP0016:F00@006:FHYH000ERUP05001VUVJFIYH0
0004IYH01000IYIVUP0016JF00D006JFIYIVUP0000AV]P04001V]VJf0005I[H01000I[IV]P000fJf
10001fJf00<006ZgJ[L01FZg00<006[GJ]L016[G00@006[GJ]L000=Ze`03001Zef[G009Ze`04001Z
ef[G0005J]L00`00J]MZe`04J]L01000J]MZe`000f[G00<006[gJ_L00f[g00<006kgK_L016kg00<0
06kg00000fkg00<006kgK_L00fkg00<006kgK_L00fkg00D006kgK_M^m`00009^m`03001_5flG00=_
5`03001_5flG009_5`03001_66lH009_6003001_66lH00=_6003001_66lH009_6003001c>7<h009c
>003001c>7<h009c>003001c>7<h009c>003001c>7<h009c>003001c>7<h00=c>005001c>7<hLcP0
0006E_d00`00E_eFo@0300000eKm001Fo@05E_d00`00E_eFo@030002E_d00`00E_eFo@03E_d20002
Ool00`00Oomoo`2POol0089oo`8000]oo`8000IFo@03001FoEKm00=Fo@8000EFo@03001FoEKm00=F
o@<000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm00AF
o@03001Fo@00008000=Fo@03001FoEKm00=Fo@8000EFo@03001FoEKm00AFo@8000EFo@03001FoEKm
00=Fo@<000IFo@04001FoEKmE_d40006E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d0
000200000eKm001Fo@06E_d00`00E_d000020002E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@03
E_d20005E_d01@00=MTefCGI0000147i00@003WH>MPif0D00003?OP003WH008if003000if3WH008i
f003000mf3gH008mf005000mf3gH?MP00004?MP00`00?MPmf002?MP00`00?MLme`02?ML00`00?MLm
e`02?ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00@MM1
e`02@ML00`00@OM1m`03@OL00`00AOM5m`02AOL00`00AOM5m`02AOL00`00AOM5m`03AOL00`00AOM5
m`03AOL00`00AOM5m`02AOL00`00AOM5m`03AOL00`00BOM9m`02BOL00`00BOM9m`04BOL00`00BOM9
m`02BOL00`00BOM9m`03BOL00`00BOM9m`03BOL00`00BOH0000200000dWf0019mP03BOH00`00COI=
mP04COH00`00COI=mP03COH00`00CQI>5P03CQH00`00CQI>5P03CQH00`00CQH00003CQH00`00CQI>
5P04CQH00`00CQI>5P03CQH00`00CQI>5P03CQH01000DQIB5U8F0P0000=B5P00DQH01E8F00<0058F
DQH00e8F00<0058FDQH00e8F0P001U8F00<0058FDQH0158F00<0058fDSH00e8f0P001EHf00<005Hf
ESH015Hf00<005HfESH00UHf00<005Hf00001eHf00<005HfESH00eHf0P001UHf00<005HfESH015Hf
00<005Xf000015Xf00<005XfFSH01EXf0P001EYF00<005YFFUH01EYF0P001EYF00<005YFFUH015YF
0P001eiF00D005iFGUINEP0000=NEP03001NEUiF00ENEP03001NEUiF00ENEP03001NMUif009NMP04
001NMUif0006GWH00`00GWINMP05GWH01000GWINMP001F9f00<0069fHWH00V9f00@0069fHWH000IR
MP03001RMP0000MRMP03001RUV:F00ERUP03001RUP0000ERUP03001RUP0000IRUP04001VUVJF0005
IYH01000IYIVUP0016JF00@006JFIYH000EV]P03001V]P0000IV]P04001V]P00I[H30002I[H00`00
I[IV]P06I[H00`00J[MZ]`04J[L00`00J[L00004J]L00`00J]MZe`02J]L00`00J]MZe`020003J]L0
0`00J]L00005J]L00`00J]L00004J]L00`00J]MZe`02J]L01000J]MZe`001F[g00<006kgK_L00fkg
00D006kgK_M^m`00009^m`03001^mfkg00=^m`03001^mfkg00=^m`07001^mfkgK_L006kg00001FlG
00<006lG00000VlG00<006lHKaP00flH00<006lHKaP00VlH00<006lHKaP00flH00D007<hLcQc>000
00Ec>003001c>7<h009c>003001c>7<h009c>003001c>7<h009c>007001c>7<hLcP007<h00001EKm
0`001EKm00<005KmE_d00eKm0`001UKm00<005Km00000P0000EFo@00Oomoo`000:9oo`00PWoo00<0
07oo00001goo0`000UKm00<005KmE_d015Km00<005Km00000P0000=Fo@00E_d01EKm00<005Km0000
0P000eKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0`001UKm
00<005Km00000P0000=Fo@00E_d01EKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005Km00000P00
0eKm00<005KmE_d00eKm100015Km00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001EKm00<0
05KmE_d015Km0P001UKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000UKm00<0
05KmE_d00UKm00<003GI=MT00SGI00<0047i@OT00T7i00D003WH>MPif00000<if0D00003>MP003WH
008if003000mf3gH008mf003000mf3gH008mf005000mf3gH?MP00004?MP00`00?MLme`02?ML00`00
?MLme`02?ML00`00@MM1e`03@ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00
@MM1e`02@ML00`00@OM1m`03@OL00`00AOM5m`02AOL00`00AOM5m`02AOL00`00AOM5m`03AOL00`00
AOM5m`02AOL00`00AOM5m`02AOL00`00AOM5m`03AOL00`00BOM9m`03BOL00`00BOM9m`03BOL00`00
BOM9m`02BOL00`00BOM9m`04BOL00`00BOM9m`040004BOH00`00BOI9mP03BOH00`00COI=mP03COH0
0`00COI=mP03COH00`00CQI>5P03CQH00`00CQI>5P03CQH20005CQH00`00CQI>5P03CQH00`00CQI>
5P04CQH00`00CQI>5P03CQH30003DQH00`00DQIB5P04DQH00`00DQIB5P03DQH00`00DQIB5P02DQH0
0`00DQH00006DQH00`00DQIB5P04DQH00`00DSIB=P02DSH00`00DSH00006ESH00`00ESIF=P03ESH0
0`00ESIF=P020002ESH00`00ESIF=P05ESH00`00ESIF=P02ESH00`00ESH00006ESH00`00ESIF=P04
ESH20006FSH00`00FSIJ=P04FSH00`00FUIJEP04FUH00`00FUIJEP04FUH20007FUH00`00FUIJEP02
FUH00`00FUH00007GUH01000GUINEP0015iF00<005iFGUH01EiF00<005iFGUH01EiF00D005ifGWIN
MP0000=NMP03001NMUif00ANMP03001NMUif00INMP8000IRMP05001RMV9fHWH00003HWH00`00HWIR
MP03HWH01000HWIRMP001f9f00<006:FHYH01V:F00<006:FHYH01F:F00<006:FHYH01F:F00<006JF
00001VJF00<006JF00001FJF00<006JF00001fJf00<006JfI[H01VJf0`001FJf00<006JfI[H01FJf
00<006Zf000016Zg00@006ZgJ[L000AZe`03001Zef[G009Ze`03001Ze`00009Ze`05001Zef[GJ]L0
0006J]L00`00J]L00004J]L00`00J]MZe`02J]L00`00J]L00005J_L00`00K_L00004K_L01`00K_M^
mfkg001^m`0000E^m`03001^m`0000=^m`03001^mfkg00=^m`03001_5flG00=_5`06001_5flG001_
5`001FlH00<006lH00000flH00<006lHKaP00VlH00<007<h00000W<h00<007<hLcP00W<h00<007<h
00000W<h00<007<hLcP00W<h00<007<h00000g<h00@007<hLcP000=c>003001Fo@0000800003E_d0
05Km00IFo@03001Fo@000080009Fo@03001FoEKm00AFo@8000EFo@04001oogoo002QOol0089oo`04
001oogoo0004Ool20006E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d30006E_d00`00E_d0
00020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020003
E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@03E_d30006E_d00`00
E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d00002
0002E_d00`00E_eFo@03E_d00`00E_eFo@030002E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03
E_d20006E_d00`00E_eFo@02E_d01@00=MTefCGI0000147i00<003WH>MP00SWH00D003WH>MPif000
00<if0H000@mf003000mf3gH008mf003000mf3gH008mf003000mf3gH008mf005000mecgG?ML00005
?ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00@MM1e`02
@ML00`00@OM1m`03@OL00`00AOM5m`02AOL00`00AOM5m`02AOL00`00AOM5m`03AOL00`00AOM5m`02
AOL00`00AOM5m`02AOL00`00AOM5m`04AOL00`00BOM9m`02BOL00`00BOM9m`03BOL00`00BOM9m`03
BOL00`00BOM9m`060002BOH00`00BOI9mP04BOH00`00BOI9mP02BOH00`00COI=mP04COH00`00COI=
mP02COH00`00CQI>5P04CQH00`00CQH0000200000dhF001>5P04CQH00`00CQI>5P04CQH00`00CQI>
5P03CQH00`00CQI>5P02CQH20006DQH00`00DQIB5P04DQH00`00DQIB5P02DQH00`00DQIB5P020002
DQH00`00DQIB5P04DQH00`00DQIB5P04DQH00`00DSIB=P020002DSH00`00ESIF=P04ESH00`00ESIF
=P04ESH20005ESH00`00ESIF=P04ESH01@00ESIF=UHf00000UHf00<005HfESH01EHf00<005HfESH0
0UHf00<005Xf00001UXf00<005XfFSH015Xf00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
1eYF00D005YFFUIJEP0000=JEP03001NEUiF00ENEP8000ENEP03001NEUiF00ANEP8000MNEP04001N
MUif0005GWH00`00GWINMP02GWH00`00GWH00007GWH00`00HWIRMP05HWH01000HWIRMP001F9f00D0
069fHWIRMP0000=RMP03001RMV9f00ARMP03001RUP0000MRUP03001RUV:F00ERUP03001RUV:F00IR
UP03001VUVJF00IVUP03001VUVJF00EVUP03001V]VJf00IV]P03001V]VJf00=V]P@000IV]P03001V
]P0000EV]P04001Z]VZf0004J[L01@00J[MZ]fZg00000V[G00<006[GJ]L016[G00D006[GJ]MZe`00
00=Ze`03001Zef[G00=Ze`05001Zef[GJ]L00002J]L00`00J]MZe`04J]L00`00J_MZm`03J_L01000
K_M^m`000fkg00<006kgK_L00fkg00<006kgK_L00fkg00D006kgK_M^m`00009^m`03001^mfkg00=^
m`03001_5flG009_5`03001_5flG009_5`03001_66lH00=_6007001_66lHKaP006lH000016lH00H0
07<hLcP007<h0004LcP01P00LcQc>000LcP000Ac>007001c>7<hLcP007<h00000g<h00<007<hLcP0
0W<h00<005KmE_d00eKm00<005KmE_d015Km0P001UKm00<005KmE_d00`0000=Fo@00E_d01EKm00<0
07oo0000XGoo0022Ool01000Oomoogoo10000UKm00<005KmE_d015Km00<005Km00000P0000=Fo@00
E_d01EKm00<005Km00000P000eKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001UKm00<0
05KmE_d00eKm0`001UKm00<005Km00000P0000=Fo@00E_d01EKm00<005Km00000P000UKm00<005Km
E_d015Km00<005Km00000P000eKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001UKm00<0
05KmE_d00eKm0P001UKm00@005KmE_eFo@@000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03
001Fo@000080009Fo@03001FoEKm00AFo@03001FoEKm009Fo@04000efCGI0004@OT00`00>MPif002
>MP00`00>MPif002>MP01@00>MPif3WH00000cWH1@0000<mf000?MP00SgH00<003gH?MP00SgH00<0
03gH?MP00SgH00<003gG?ML00SgG00<003gG?ML00SgG00<0047G@ML00T7G00<0047G@ML00T7G00<0
047G@ML00T7G00<0047G@ML00T7G00<0047G@ML00T7G00<0047g@OL00d7g00<004GgAOL00TGg00<0
04GgAOL00TGg00<004GgAOL00dGg00<004GgAOL00dGg00<004GgAOL00TGg00<004GgAOL00dGg00<0
04WgBOL00TWg00<004WgBOL014Wg00<004WgBOL01@000dWf00<004WfBOH00TWf00<004WfBOH014Wf
00<004WfBOH00TWf00<004gfCOH014gf00<004gfCOH00Tgf00<004hFCQH00dhF0`0014hF00<004hF
CQH00dhF00<004hFCQH014hF00<004hFCQH00dhF00<004hF00000P0000=>5P00DQH01E8F00<0058F
DQH0158F00<0058FDQH00e8F0P001E8F00<0058FDQH0158F00<0058FDQH0158F0P001E8f00<005Hf
ESH00eHf00<005HfESH00eHf0P001UHf00<005HfESH015Hf00@005HfESH000AF=P03001F=UHf00AF
=P05001F=UHfESH00002FSH00`00FSIJ=P04FSH00`00FSIJ=P03FSH00`00FSH00006FUH01@00FUIJ
EUYF00000UYF00<005YFFUH01EYF00@005YFFUH000AJEP03001NEUiF00ENEP03001NEUiF00ENEP03
001NEUiF009NEP04001NEUiF0007GUH20006GWH01@00GWINMUif00000Uif00<005ifGWH01Eif00<0
069fHWH01V9f0P001V9f00D0069fHWIRMP0000ARMP03001RMV9f009RMP04001RUV:F0006HYH00`00
HYH00005HYH00`00HYH00007HYH00`00IYIVUP06IYH00`00IYIVUP05IYH00`00I[IV]P05I[H01000
I[H006Jf0`000VJf00<006Jf000016Jf00@006JfI[H000AV]P03001Z]VZf009Z]P04001Z]fZg0004
J[L00`00J]L00007J]L00`00J]MZe`02J]L01@00J]L006[G00000f[G00<006[GJ]L00V[G00<006[G
00001f[G00<006[gJ_L00f[g00D006kgK_M^m`00009^m`03001^mfkg00=^m`03001^mfkg009^m`03
001^mfkg009^m`03001^m`0000E^m`03001_5`0000=_5`03001_5flG009_5`03001_66lH00=_6003
001_66lH009_6003001_66lH009_6003001c>7<h009c>003001c>7<h00=c>005001c>7<hLcP00005
LcP00`00LcQc>002LcP01@00LcQc>7<h00001G<h00<005KmE_d015Km00<005KmE_d00`0000=Fo@00
E_d01EKm0`001EKm00<005KmE_d00eKm0P0000=oo`00Ool0Wgoo0021Ool00`00Oomoo`030006E_d0
0`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d30006E_d00`00E_d000020002E_d00`00E_eFo@04
E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020003E_d00`00E_eFo@03E_d20005
E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d30006E_d00`00E_d000020002E_d00`00E_eF
o@04E_d00`00E_d0000200000eKm001Fo@06E_d00`00E_d000020002E_d00`00E_eFo@03E_d40004
E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@03E_d60003=MT00`00
@OU1n@02@OT01@00>MPif3WH000013WH00<003WH>MP00SWH00D003WH>MPif00000<if0D00003?MP0
03gH008mf003000mf3gH008mf003000mecgG008me`03000mecgG008me`030011ed7G00=1e`030011
ed7G0091e`030011ed7G0091e`030011ed7G0091e`030011ed7G0091e`030011md7g00=1m`030015
mdGg0095m`030015mdGg0095m`030015mdGg00=5m`030015mdGg0095m`030015mdGg0095m`030015
mdGg00=5m`030019mdWg00=9m`030019mdWg00H00099m`030019mTWf00=9mP030019mTWf00=9mP03
0019mTWf00=9mP030019mTWf00=9mP03001=mTgf00==mP03001=mTgf00==mP03001>5P0000800003
COH004hF00E>5P03001>5ThF00=>5P03001>5ThF00=>5P03001>5ThF00=>5P8000A>5P03001B5U8F
00AB5P03001B5U8F00AB5P03001B5U8F009B5P8000IB5P03001B5U8F00AB5P03001B5U8F00=B5P80
00IB=P03001F=UHf00AF=P07001F=UHfESH005Hf00001UHf00<005HfESH01EHf0P001EHf00<005Hf
ESH015Hf00@005HfESH000AJ=P03001J=UXf00AJ=P05001J=UXfFSH00002FSH00`00FUIJEP04FUH0
1000FUIJEP0015YF00<005YFFUH01EYF0P001EYF00<005iFGUH015iF0P001eiF00D005iFGUINEP00
00=NEP03001NEUiF00ENEP03001NMUif00ENMP04001NMUif0004GWH00`00GWINMP03GWH00`00GWH0
0007HWH00`00HWIRMP05HWH01000HWIRMP001F9f00D0069fHWIRMP0000=RUP03001RUV:F00=RUP04
001RUV:F0004HYH01000HYIRUP001V:F00<006JF00001VJF00<006JF00001FJF00<006JF00001FJf
00<006Jf00000P0016Jf00@006JfI[H000AV]P05001V]VJfI[H00003I[H00`00J[IZ]P02J[H01000
J[MZ]`001FZg00<006[GJ]L01F[G00<006[G000016[G00@006[GJ]L000=Ze`03001Zef[G00=Ze`03
001Zef[G00EZe`03001Zm`0000=Zm`03001^mfkg009^m`03001^m`0000E^m`03001^m`0000=^m`03
001^mfkg00=^m`03001^mfkg00=^m`04001_5flG0002KaL00`00KaM_5`02KaL00`00KaL00003KaP0
0`00KaQ_6003KaP00`00KaQ_6002KaP00`00LcQc>002LcP00`00LcQc>002LcP00`00LcQc>002LcP0
0`00LcQc>002LcP00`00LcQc>003LcP01@00LcQc>7<h000017<h00<007<h00001EKm0`001EKm00<0
05KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d00`0000EFo@00Oomoo`0009moo`00PGoo10000UKm
00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d00eKm00<005Km00000P000eKm00<005Km
E_d00eKm0P001UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001eKm00<005Km00000P00
00=Fo@00E_d01EKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000eKm00<005Km
E_d00eKm0P001UKm00<005KmE_d00eKm0P001EKm00<005KmE_d015Km0P001UKm00<005Km00000P00
0UKm00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000eKm00<0
05KmE_d00eKm00<005Km00000P0000=Fo@00<KP00S6h0`0000<ef@00@OT00d7i00<003WH>MP00SWH
00D003WH>MPif00000@if003000if3WH008if005000if3WH>MP00003?MP:00000cgH000me`02?ML0
0`00?MLme`03?ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00@MM1e`02@ML0
0`00@MM1e`02@ML00`00@OM1m`03@OL00`00AOM5m`02AOL00`00AOM5m`02AOL00`00AOM5m`03AOL0
0`00AOM5m`02AOL00`00AOM5m`02AOL00`00AOM5m`04AOL00`00BOM9m`050003BOL00`00BOM9m`02
BOL00`00BOI9mP04BOH00`00BOI9mP02BOH00`00BOI9mP04BOH00`00BOI9mP02BOH00`00COI=mP03
COH00`00COI=mP02COH30004COH00`00CQI>5P04CQH00`00CQI>5P03CQH00`00CQI>5P03CQH01000
CQI>5ThF0P0000=>5P00CQH014hF00<0058FDQH0158F00<0058FDQH00e8F00<0058FDQH00P0000=B
5P00DQH01E8F00<0058FDQH0158F00<0058FDQH00U8F00<0058F00001U8f00<005HfESH015Hf00@0
05HfESH0009F=P03001F=UHf00EF=P03001F=UHf00=F=P8000IF=P03001F=UHf00EF=P8000EJ=P03
001J=UXf00AJ=P04001J=UXf0003FSH00`00FUIJEP05FUH20005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00GUINEP02GUH00`00GUH00007GUH01000GUINEP0015iF00<005iFGUH015iF0P0025if
0P001Eif00<005ifGWH00Uif00@005ifGWH000MRMP03001RMV9f00IRMP8000IRMP04001RMV9f0005
HYH01@00HYIRUV:F00000f:F00<006:FHYH00V:F00@006:FHYH000ERUP04001VUVJF0005IYH01000
IYIVUP0016JF00@006JFIYH000AV]P<00003I[H006Jf00=V]P03001V]VJf009V]P04001V]VJf0004
I[H01000I[IV]P001FZf00<006Zg00001VZg00<006[GJ]L016[G00@006[GJ]L000AZe`80009Ze`03
001Ze`0000IZe`03001Zef[G00AZe`04001Zmf[g0002J_L00`00K_M^m`04K_L00`00K_M^m`03K_L0
1000K_M^m`000Vkg00<006kgK_L016kg00<006kgK_L00Vkg00L006lGKaM_5`00KaL00004KaL01@00
KaM_5flG00000VlH00<006lHKaP00VlH00<006lH00000VlH00<007<hLcP00W<h00<007<h00000g<h
00L007<hLcQc>000LcP00003LcP00`00LcQc>002LcP01@00LcP007<h000017<h00@007<hLcP0009F
o@<00003E_d005Km00EFo@<000EFo@03001FoEKm00=Fo@<000EFo@03001oo`0009moo`00PGoo00<0
05KmE_d015Km00<005KmE_d00eKm0P001UKm00@005KmE_eFo@@000IFo@03001Fo@000080009Fo@03
001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm
00AFo@8000EFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@<000IFo@03001Fo@000080009F
o@03001FoEKm00AFo@03001Fo@0000800003E_d005Km00EFo@03001FoEKm00<0009Fo@03001FoEKm
00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000MFo@04001FoEKmE_d30005
E_d01P00<KPa^36h000ef08000A1n@03000if3WH008if003000if3WH008if005000if3WH>MP00004
>MP00`00>MPif002>MP01@00?MPmf3gH000013gH00@003gG?MLme`D00003?ML003gG00<me`030011
ed7G0091e`030011ed7G0091e`030011ed7G0091e`030011ed7G0091e`030011ed7G0091e`030011
md7g00=1m`030015mdGg0095m`030015mdGg0095m`030015mdGg00=5m`030015mdGg00=5m`030015
mdGg0095m`030015mdGg00H00095m`030019mdWg00=9m`030019mdWg00=9m`030019mTWf00=9mP03
0019mTWf0099mP030019mTWf00A9mP030019mTWf0099mP03001=mTgf00A=mP@00003COH004gf00E=
mP03001>5ThF00=>5P03001>5ThF00=>5P03001>5ThF00A>5P<000=>5P03001>5ThF00=>5P03001B
5U8F00AB5P03001B5U8F00AB5P8000AB5P03001B5U8F00AB5P03001B5U8F00=B5P03001B5U8F0080
009B5P03001B=U8f00EB=P03001F=UHf00=F=P03001F=P0000AF=P03001F=UHf00AF=P03001F=UHf
009F=P03001F=P0000MF=P03001F=UHf00=F=P8000IJ=P03001J=UXf00AJ=P03001J=P0000EJ=P03
001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00AJEP8000MJEP05001NEUiFGUH00003GUH00`00
GUINEP05GUH20006GUH00`00GUINEP02GUH01000GUINEP001eif00<005ifGWH015if00D005ifGWIN
MP0000=NMP03001RMV9f00ARMP03001RMP0000MRMP03001RMV9f00IRMP8000IRUP04001RUV:F0005
HYH01000HYIRUP0016:F00D006:FHYIRUP0000=VUP03001VUVJF009VUP05001VUVJFIYH00004IYH0
1000IYIVUVJF1@0016Jf00D006JfI[IV]P0000AV]P04001V]VJf0004I[H00`00I[H00007J[H00`00
J[MZ]`04J[L00`00J]L00005J]L01@00J]MZef[G00000V[G00<006[G00000V[G00<006[G00001F[G
00<006[G000016[G00D006[gJ_MZm`00009Zm`03001^mfkg00A^m`03001^mfkg009^m`07001^mfkg
K_L006kg00001Vkg00<006kg00000fkg00<006lGKaL00VlG00<006lGKaL00flG00L006lGKaM_5`00
KaP00004KaP01P00KaQ_6000KaP000Ac>007001c>7<hLcP007<h00000g<h00L007<hLcQc>000LcP0
0004LcP01@00LcQc>7<h000017<h00<007<hLcP00W<h0P001EKm00<005KmE_d00`0000=Fo@00E_d0
1EKm00<005KmE_d00`0000=Fo@00E_d01EKm00@007ooOol009ioo`00PGoo0P001UKm00<005Km0000
0P000UKm00<005KmE_d00eKm100015Km00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0`001EKm
00<005KmE_d00eKm0P001UKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005Km00000P000UKm00<0
05KmE_d015Km00<005Km00000P000eKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001EKm
00<005KmE_d00eKm0`001UKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000UKm
00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d015Km10000eKm00<005KmE_d00UKm00<0
036h<KP00S6h00<003GH=MP0100000=1n@00>MP00SWH00<003WH>MP00SWH00<003WH>MP00SWH00D0
03WH>MPif00000@if003000mf3gH008mf003000mf3gH008mf005000mecgG?ML00003?ML;00000d7G
0011e`03@ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00@OM1m`03@OL00`00
AOM5m`02AOL00`00AOM5m`02AOL00`00AOM5m`03AOL00`00AOM5m`0:0003AOL00`00AOM5m`02AOL0
0`00BOM9m`04BOL00`00BOM9m`02BOL00`00BOI9mP03BOH00`00BOI9mP03BOH00`00BOI9mP03BOH0
0`00BOI9mP03BOH00`00COI=mP040004COH00`00COI=mP04COH00`00CQI>5P04CQH00`00CQI>5P02
CQH00`00CQI>5P03CQH20006CQH00`00CQI>5P02CQH00`00DQIB5P04DQH00`00DQIB5P03DQH20005
DQH00`00DQIB5P04DQH00`00DQIB5P04DQH20005DQH00`00DSIB=P04DSH00`00ESIF=P03ESH20005
ESH00`00ESIF=P04ESH00`00ESIF=P020002ESH00`00ESIF=P05ESH00`00ESIF=P02ESH00`00ESH0
0007FSH00`00FSIJ=P03FSH20006FSH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00007FUH01000GUINEP0015iF00<005iFGUH01EiF00<005iFGUH01EiF00D005iFGUINEP00
00=NEP03001NMUif00ENMP03001NMUif00ENMP04001NMUif0004GWH00`00HWIRMP02HWH01000HWIR
MP001f9f00<0069fHWH01V9f00<006:FHYH01F:F00<006:F00001V:F00@006:FHYH000ARUP05001R
UV:FHYH00004IYH01@00IYIVUVJF000016JF00@006JFIYH000=VUP80009V]P03001V]VJf00=V]P04
001V]VJf0005I[H00`00I[H00006I[H00`00J[IZ]P06J[H00`00J[MZ]`03J[L01000J]MZe`0016[G
00<006[GJ]L00V[G00@006[GJ]L0009Ze`04001Zef[G0006J]L00`00J]L00004J]L00`00J_MZm`02
J_L20006K_L00`00K_L00003K_L00`00K_M^m`02K_L00`00K_M^m`04K_L01000K_M^m`000Vkg00<0
06lGKaL00flG00<006lGKaL00VlG00<006lGKaL00flG00<006lHKaP00VlH00<006lHKaP00VlH00<0
07<hLcP00g<h00<007<hLcP00W<h00<007<hLcP00W<h00<007<hLcP00W<h00<007<hLcP00W<h00<0
07<hLcP00W<h00<007<hLcP00W<h00<007<hLcP00W<h00<005KmE_d015Km0`001EKm00<005KmE_d0
0eKm0`001EKm00<005KmE_d00eKm0P000Woo00<007ooOol0Vgoo0021Ool00`00Ool00005E_d20006
E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00
E_d000020003E_d00`00E_eFo@03E_d00`00E_d000020002E_d00`00E_eFo@03E_d30005E_d00`00
E_eFo@03E_d30005E_d00`00E_eFo@03E_d30006E_d00`00E_d000020002E_d00`00E_eFo@04E_d0
0`00E_d0000200000eKm001Fo@05E_d00`00E_d000020003E_d00`00E_eFo@03E_d20006E_d00`00
E_eFo@03E_d20006E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@0300000eKm001Fo@05E_d00`00
E_eFo@02E_d01@00<KPa^36h00000SGH00@003WH>MPif0D00003>MP003WH008if003000if3WH008i
f003000if3WH008if005000if3WH>MP00004?MP00`00?MPmf002?MP00`00?MLme`02?ML01@00?MLm
ecgG00001CgG00@003gG?MLmebh00095m`030015mdGg0095m`030015mdGg00=5m`030015mdGg00=5
m`030019mdWg00=9m`030019mdWg0099m`030019mTWf00A9mP030019mTWf0099mP030019mTWf00=9
mP030019mTWf0099mP@000=9mP03001=mTgf00==mP03001=mTgf00==mP03001>5ThF00A>5P03001>
5ThF00=>5P03001>5P0000800003CQH004hF00E>5P03001>5ThF00=>5P03001B5U8F00=B5P04001B
5U8FDQH200000e8F001B5P04DQH00`00DQIB5P04DQH00`00DQIB5P03DQH20006DQH00`00DSIB=P04
DSH00`00ESIF=P02ESH00`00ESH00005ESH00`00ESIF=P05ESH20005ESH00`00ESIF=P04ESH01@00
ESIF=UHf00000UHf00<005XfFSH01EXf00<005XfFSH00UXf00<005Xf00001UXf00<005YFFUH00eYF
00<005YF00001UYF00D005YFFUIJEP0000=JEP03001JEUYF00EJEP8000ENEP03001NEUiF00ANEP80
00MNEP04001NEUiF0004GUH00`00GWINMP04GWH20007GWH00`00GWH00005GWH01@00HWIRMV9f0000
0f9f00<0069fHWH0169f00<0069f00001f9f00<006:FHYH01V:F00<006:FHYH01F:F00<006:F0000
1F:F00@006:FHYH000EVUP04001VUVJF0005IYH00`00IYIVUP04000016JF001V]P001VJf00<006Jf
00001fJf00<006JfI[H01FJf00<006ZfJ[H01FZf00<006Zf000016Zg00D006[GJ]MZe`00009Ze`03
001Zef[G00=Ze`03001Ze`0000AZe`03001Ze`0000EZe`05001Zef[GJ]L00002J]L00`00J_MZm`03
J_L00`00K_M^m`04K_L01000K_M^m`000Vkg00<006kgK_L00fkg00<006kgK_L00fkg00L006kgK_M^
m`00K_L00005KaL00`00KaL00003KaL00`00KaM_5`03KaL00`00KaQ_6002KaP00`00KaQ_6002KaP0
0`00LcQc>002LcP00`00LcQc>003LcP01@00LcQc>7<h00001G<h00D007<hLcQc>00000Ac>003001c
>000009c>003001c>7<h009c>003001c>000009Fo@<00003E_d005Km00EFo@03001FoEKm00<0009F
o@03001FoEKm00=Fo@03001FoEKm00<00005E_d007ooOol0002MOol0085oo`05001oogoo001Fo@03
0002E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d30006E_d0
1000E_eFoEKm0`001UKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000eKm00<0
05KmE_d00eKm00<005Km00000P000eKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001EKm
00<005KmE_d00eKm0`001UKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000UKm
00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d00eKm0`001EKm00<005KmE_d00eKm0`00
0UKm00D0036h<KPa^00000<ef005000if3WH>MP00003>MP500000cWH000if002>MP00`00>MPif002
>MP00`00>MPif002>MP01@00?MPmf3gH000013gH00<003gG?ML00SgG00<003gG?ML00SgG00<003gG
?ML00cgG00D003gG?MLme`0000A1e`030011ed7G0091e`030011ed7G0091e`030011ed7G0091e`03
0011ed7G00=1e`030011ed7G0091e`030015mdGg0095m`030015mdGg00=5m`030015mdGg0095m`03
0015mdGg0095m`030015mdGg00A5m`030015mdGg0095m`030019mdWg00=9m`030019mdWg00=9m`03
0019mTWf00=9mP030019mTWf0099mP030019mTWf00A9mP@00003BOH004Wf00A9mP03001=mTgf00==
mP03001=mTgf00A=mP03001>5ThF00=>5P03001>5ThF009>5P<000A>5P03001>5ThF00A>5P03001>
5ThF00=>5P03001B5U8F00AB5P<000=B5P03001B5U8F00AB5P03001B5U8F00=B5P04001B5U8FDQH2
00000e8F001B5P05DQH00`00DSIB=P04DSH00`00ESIF=P020002ESH00`00ESIF=P04ESH00`00ESIF
=P03ESH20006ESH00`00ESIF=P04ESH01000ESIF=P0015Hf00<005XfFSH015Xf00D005XfFSIJ=P00
009J=P03001J=UXf00EJ=P05001JEUYFFUH00002FUH00`00FUIJEP04FUH01000FUIJEP0015YF00<0
05YFFUH01EYF00<005iFGUH01EiF00<005iFGUH00UiF00<005iF000025iF0P001UiF00<005ifGWH0
0Uif00@005ifGWH000MNMP03001NMUif00ANMP04001RMV9f0005HWH00`00HWIRMP02HWH01000HWIR
MP001V9f00<0069f00001f:F00<006:FHYH01V:F00<006:FHYH01F:F0P001VJF00<006JF00001VJF
10001FJF00<006JfI[H01VJf00<006JfI[H01VJf00<006JfI[H016Jf00<006Jf00001FZf00@006Zf
J[H000=Z]`03001Zef[G009Ze`04001Zef[G0006J]L00`00J]MZe`03J]L200000f[G001Ze`02J]L0
0`00J]MZe`02J]L00`00J]L00006J_L00`00K_M^m`03K_L01`00K_M^mfkg001^m`0000E^m`03001^
m`0000A^m`03001^mfkg009^m`03001_5flG00=_5`07001_5flGKaL006lG00001FlG00<006lG0000
0VlH00<006lHKaP00VlH00<007<h00000g<h00<007<hLcP00W<h00<007<h00000W<h00<007<hLcP0
0W<h00D007<h001c>00000Ac>006001c>7<h001c>00017<h00@007<hLcQc>08000EFo@03001FoEKm
00=Fo@<000IFo@04001FoEKmE_d40005E_d01000Oomoo`00W7oo001XOol4000DOol00`00Oomoo`02
Ool00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00
E_eFo@04E_d00`00E_d000020003E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d20006E_d0
0`00E_eFo@03E_d30006E_d01000E_eFoEKm10001UKm00<005Km00000P0000=Fo@00E_d01UKm00<0
05Km00000P0000=Fo@00E_d01EKm00<005Km00000P000eKm00<005KmE_d00eKm0P001UKm00<005Km
E_d00eKm0P001UKm00<005KmE_d00eKm0P001UKm00<005Km00000P000UKm00<005KmE_d015Km00<0
05Km00000P0000=BF@00;GL00`00136h00@003GH=MP000@if005000if3WH>MP00003>MP500000cWH
000if002>MP00`00>MPif002>MP00`00?MPmf002?MP00`00?MPmf002?MP01@00?MLmecgG000013gG
00<003gG?ML00cgG00<003gG?ML00SgG00<0047G@ML00T7G00D0047G@MM1e`0000A1e`030011ed7G
00=1e`030011ed7G0091e`030011ed7G0091e`030015mdGg0095m`030015mdGg00=5m`030015mdGg
00=5m`030015mdGg0095m`030015mdGg00=5m`030015mdGg0095m`030019mdWg00A9m`030019mdWg
0099m`030019mTWf00=9mP030019mTWf00=9mP030019mTWf00@000A9mP030019mTWf00A9mP03001=
mTgf009=mP03001=mTgf00A=mP03001>5ThF00=>5P03001>5ThF00800003CQH004hF00E>5P03001>
5ThF00A>5P03001>5ThF009>5P03001B5U8F00=B5P8000IB5P03001B5U8F00=B5P03001B5U8F00AB
5P<000=B5P03001B5U8F00EB5P03001B=U8f00AB=P8000EF=P03001F=UHf00=F=P03001F=UHf009F
=P03001F=P0000IF=P03001F=UHf00EF=P8000EF=P03001J=UXf00AJ=P04001J=UXf0004FSH00`00
FSIJ=P04FSH01000FUIJEP000eYF00<005YFFUH01EYF0P001EYF00<005YFFUH015YF0P001eiF00D0
05iFGUINEP0000=NEP03001NEUiF00ENEP03001NEUiF00ENEP05001NMUifGWH00003GWH00`00GWIN
MP05GWH00`00GWINMP05GWH20006HWH01@00HWIRMV9f00000f9f00<0069fHWH00f9f00@0069fHWH0
00IRUP03001RUP0000MRUP03001RUV:F00ERUP03001VUVJF00IVUP03001VUVJF00=VUP@000MVUP03
001V]VJf00IV]P03001V]VJf00EV]P03001V]P0000AV]P04001V]VJf0004J[H00`00J[IZ]P02J[H0
1000J[MZ]`0016[G00<006[G00001f[G00<006[GJ]L00f[G0P0000=Ze`00J]L00V[G00<006[GJ]L0
0f[G00<006[gJ_L016[g00<006kg000016kg00<006kgK_L00Vkg00<006kgK_L00fkg00D006kgK_M^
m`00009^m`03001^mfkg00=^m`03001_5flG00=_5`03001_5flG009_5`03001_5flG00=_5`06001_
5flG001_600016lH00L007<hLcQc>000LcP00004LcP01P00LcQc>000LcP000Ac>005001c>7<hLcP0
0005LcP01@00LcQc>7<h000017<h00<007<hLcP00W<h00<005KmE_d01EKm00<005Km00000P000UKm
00<005KmE_d015Km10000eKm00<005KmE_d00eKm0P000Woo00<007ooOol0VGoo001VOol8000BOol0
0`00Oomoo`03Ool00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d3
0006E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00
E_d000020003E_d00`00E_eFo@03E_d40004E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@04E_d2
0005E_d00`00E_eFo@03E_d30006E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d00002
00000eKm001Fo@06E_d00`00E_d000020002E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d2
0005DUT01000;GL]Mbeg0P000S6h00D003GH=MPef00000<if003000if3WH008if005000if3WH>MP0
0003>MP500000cWH000if002>MP00`00?MPmf002?MP00`00?MPmf002?MP00`00?MLme`02?ML01@00
?MLmecgG00001CgG00<003gG?ML00SgG00<0047G@ML00T7G00<0047G@ML00T7G00<0047G@ML00T7G
00<0047G@ML00T7G00<0047G@ML00d7G00<0047G@ML00T7G00<004GgAOL00TGg00<004GgAOL00dGg
00<004GgAOL00TGg00<004GgAOL00TGg00<004GgAOL00dGg00<004GgAOL00dGg00<004WgBOL00dWg
00<004WgBOL00TWg00<004WfBOH00dWf00<004WfBOH00TWf10000dWf00<004WfBOH00dWf00<004Wf
BOH00dWf00<004gfCOH00dgf00<004gfCOH00dgf00<004hFCQH014hF0P000dhF00<004hFCQH014hF
00<004hFCQH014hF00<004hFCQH00ThF00@0058FDQIB5P800003DQH0058F00EB5P03001B5U8F00=B
5P03001B5U8F00=B5P8000IB5P03001B5U8F00AB5P03001B=U8f00=B=P8000IF=P03001F=UHf00=F
=P05001F=UHfESH00002ESH00`00ESIF=P05ESH00`00ESIF=P03ESH20006ESH00`00FSIJ=P05FSH2
0005FSH00`00FSIJ=P04FSH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00007GUH01000GUINEP0015iF00<005iFGUH01EiF00<005iFGUH01EiF00@005if
GWH000ANMP03001NMUif00ANMP03001NMP0000INMP03001RMV9f00ERMP04001RMV9f0005HWH01@00
HWIRMV9f00000f9f00<006:FHYH00f:F00@006:FHYH000IRUP03001RUP0000IRUP03001VUVJF00IV
UP03001VUVJF00<000=VUP03001VUVJF00AVUP03001V]P0000IV]P03001V]P0000EV]P04001V]VJf
0004I[H01@00I[IV]VJf00000fZf00<006ZfJ[H00VZf00<006Zg00001V[G00<006[GJ]L01F[G00<0
06[G00000f[G00P006[GJ]L006[G001Ze`001V[G00<006[gJ_L00f[g00D006kgK_M^m`00009^m`03
001^mfkg00=^m`03001^mfkg00=^m`07001^mfkgK_L006kg00001Fkg00<006lG00000flG00<006lG
KaL00flG00<006lGKaL00flG00D006lGKaM_5`0000E_6003001c>7<h009c>003001c>7<h009c>003
001c>7<h009c>003001c>7<h00=c>005001c>7<hLcP00004LcP00`00LcQc>002LcP20003LcP01`00
LcQc>7<h001c>00000IFo@8000IFo@03001FoEKm00<00003E_d005Km00EFo@03001Fo@0000800005
E_d007ooOol0002KOol006Ioo`8000Aoo`80019oo`03001oogoo00Aoo`03001Fo@000080009Fo@03
001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@00008000=Fo@03001FoEKm
00=Fo@8000EFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@<000IFo@03001Fo@000080009F
o@03001FoEKm00AFo@03001Fo@0000800003E_d005Km00EFo@03001FoEKm00<0009Fo@03001FoEKm
00=Fo@03001Fo@00008000=Fo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000EFo@03001F
oEKm00AFo@8000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@0000800003E_d0059I
00ABF@06000]Mbeg;GL0036h0`000cGH00D003WH>MPif00000@if003000if3WH008if005000if3WH
>MP00003>MP500000cWH000mf002?MP00`00?MPmf002?MP00`00?MLme`02?ML00`00?MLme`02?ML0
0`00?MLme`03?ML01@00?MLmecgG0000147G00<0047G@ML00T7G00<0047G@ML00T7G00<0047G@ML0
0T7G00<0047G@ML00d7G00<0047G@ML00T7G00<004GgAOL00TGg00<004GgAOL00dGg00<004GgAOL0
0TGg00<004GgAOL00TGg00<004GgAOL014Gg00<004GgAOL00TGg00<004WgBOL00dWg00<004WgBOL0
0TWg00<004WfBOH014Wf100000=9mP00BOH014Wf00<004WfBOH00dWf00<004WfBOH00dWf00<004gf
COH00dgf00<004gfCOH00dgf00<004hFCQH00dhF0P001DhF00<004hFCQH00dhF00<004hFCQH014hF
00<004hFCQH00dhF0`000e8F00<0058FDQH0158F00<0058FDQH0158F00L0058FDQIB5P00DQH00006
DQH00`00DQIB5P04DQH00`00DSIB=P02DSH00`00EQH00006ESH00`00ESIF=P03ESH01000ESIF=P00
15Hf00<005HfESH015Hf00<005HfESH00UHf00<005Hf00001eHf00<005XfFSH00eXf0P001UXf00<0
05XfFSH015Xf0P001UYF00<005YFFUH015YF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001N
EUiF00ENEP8000ENEP03001NEUiF00ANEP8000QNEP8000INMP03001NMUif009NMP04001NMUif0006
GWH00`00HWIRMP06HWH20006HWH01@00HWIRMV9f0000169f00D006:FHYIRUP0000=RUP03001RUV:F
00=RUP04001RUV:F0005HYH00`00IYH00006IYH40005IYH00`00IYH00005IYH00`00I[H00005I[H0
1000I[IV]P0016Jf00<006JfI[H00VJf00@006JfI[H000AV]P04001Z]VZf0006J[H00`00J]MZe`05
J]L00`00J]MZe`04J]L01000J]MZe`000f[G00@006[GJ]MZe`800003J]L006[G00AZe`03001Ze`00
00AZm`07001^mfkgK_L006kg00001Fkg00<006kg00000fkg00<006kgK_L00fkg00<006kgK_L00fkg
00D006lGKaM_5`00009_5`03001_5flG009_5`03001_5`0000=_5`03001_5flG009_5`03001_66lH
009_6003001c>7<h00=c>003001c>7<h009c>003001c>7<h009c>003001c>7<h009c>007001c>7<h
LcP007<h00000g<h00D007<hLcQc>000009c>003001c>00000=c>005001c>7<hLcP00002E_d30000
0eKm001Fo@05E_d30005E_d00`00E_eFo@03E_d20005E_d01000Oomoo`00VWoo001UOol20006Ool2
000AOol00`00Oomoo`05Ool00`00E_eFo@04E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d3
0006E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00
E_d000020003E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d3
0006E_d01000E_eFoEKm10001UKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P00
0UKm00<005KmE_d00eKm00<005KmE_d00`000UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm
0P001EKm00<0059IDUT00U9I00<002eg;GL00Reg00@0036h<KPa^080008ef005000if3WH>MP00003
>MP00`00>MPif002>MP00`00>MPif002>MP01@00>MPif3WH00000cWH1@0000<mf000?MP00cgH00D0
03gG?MLme`0000@me`03000mecgG00<me`03000mecgG008me`030011ed7G0091e`050011ed7G@ML0
0004@ML00`00@MM1e`03@ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00AOM5m`02AOL00`00AOM5
m`03AOL00`00AOM5m`03AOL00`00AOM5m`02AOL00`00AOM5m`03AOL00`00AOM5m`02AOL00`00BOM9
m`03BOL00`00BOM9m`03BOL00`00BOI9mP040004BOH00`00BOI9mP04BOH00`00BOI9mP02BOH00`00
BOI9mP04BOH00`00COI=mP02COH00`00COI=mP04COH00`00CQH0000200000dgf001>5P04CQH00`00
CQI>5P04CQH00`00CQI>5P03CQH00`00CQI>5P02CQH20006DQH00`00DQIB5P04DQH00`00DQIB5P03
DQH01000DQIB5P000U8F00<0058FDQH0158F00<0058FDQH0158F00<0058fDSH00P000UHF00<005Hf
ESH01EHf00<005HfESH00eHf0P001EHf00<005HfESH015Hf00D005HfESIF=P00009F=P03001F=UHf
00EF=P03001J=UXf009J=P03001J=P0000MJ=P03001J=UXf009J=P03001J=P0000IJEP03001JEUYF
00=JEP03001JEP0000IJEP04001JEUYF0004FUH00`00GUINEP05GUH00`00GUINEP05GUH00`00GUIN
EP02GUH01000GUINEP001eiF00<005ifGWH01Eif00D005ifGWINMP0000=NMP03001NMUif00=NMP03
001RMP0000MRMP03001RMV9f00ERMP04001RMV9f0005HWH01@00HYIRUV:F000016:F00D006:FHYIR
UP0000=RUP03001RUV:F009RUP04001VUVJF0004IYH300000fJF001VUP04IYH01000IYIVUP0016JF
00@006JfI[H000AV]P03001V]VJf009V]P05001V]VJfI[H00004I[H01000I[IV]P0016Jf00<006Zf
00001fZf00<006[GJ]L016[G00<006[G000016[G00D006[GJ]MZe`00009Ze`03001Zef[G009Ze`03
001Ze`0000EZe`04001Zef[G0003J_L00`00K_M^m`03K_L00`00K_M^m`03K_L01@00K_M^mfkg0000
0Vkg00<006kgK_L00fkg00<006kgK_L00fkg00L006lGKaM_5`00KaL00004KaL01@00KaM_5flG0000
0VlG00L006lGKaM_5`00KaL00003KaP00`00LcQc>002LcP00`00LcP00002LcP00`00LcQc>002LcP0
0`00LcP00003LcP01000LcQc>0000g<h00<007<h00000g<h00<007<hLcP00W<h00<007<hLcP00W<h
00<007<hLcP00W<h0P001EKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d00`0000=Fo@00
E_d01EKm00@007ooOol009Uoo`00IGoo0P001Woo0P004Goo00<007ooOol01Woo00<005KmE_d015Km
00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000eKm00<005KmE_d00eKm0P001EKm
00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0`001UKm00<005Km00000P000UKm00<005KmE_d0
15Km00<005Km00000P0000=Fo@00E_d01EKm00<005Km00000P000eKm00<005KmE_d00eKm100015Km
00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001UKm00@005KmE_eFo@@000IFo@03001Fo@00
0080009Fo@03001FoEKm00AFo@03001Fo@0000800003E_d005Km00AFo@03001BFE9I00=BF@05000]
Mbeg;GL00003<KP00`00=KP000020003>MP00`00>MPif002>MP01@00>MPif3WH000013WH00<003WH
>MP00SWH00D003WH>MPif00000<mf0X00003?ML003gG008me`03000mecgG00<me`03000mecgG008m
e`030011ed7G0091e`030011ed7G0091e`030011ed7G0091e`030011ed7G0091e`030011ed7G00=1
e`030011ed7G0091e`030015mdGg0095m`030015mdGg00=5m`030015mdGg0095m`030015mdGg0095
m`030015mdGg00=5m`030015mdGg0095m`030019mdWg00A9m`030019mdWg00D000=9mP030019mTWf
00=9mP030019mTWf00=9mP030019mTWf00=9mP030019mTWf00=9mP03001=mTgf009=mP03001=mTgf
00==mP<000A=mP03001>5ThF00=>5P03001>5ThF00A>5P03001>5ThF00A>5P@00003CQH0058F00EB
5P03001B5U8F00AB5P03001B5U8F00=B5P03001B5P0000AB5P03001B5U8F00AB5P03001B5U8F00AB
5P8000EF5P03001F=UHf00AF=P03001F=UHf009F=P8000IF=P03001F=UHf00AF=P04001F=UHf0004
ESH00`00ESIF=P04ESH01@00FSIJ=UXf00000UXf00<005XfFSH01EXf00D005XfFSIJ=P00009J=P03
001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP05FUH20005FUH00`00GUINEP04GUH20007
GUH01@00GUINEUiF00000eiF00<005iFGUH01EiF00<005ifGWH01Eif00@005ifGWH000ENMP05001N
MUifGWH00002HWH00`00HWIRMP05HWH00`00HWIRMP06HWH20006HWH01000HYIRUP001F:F00D006:F
HYIRUP0000ARUP04001RUV:F0003IYH00`00IYH000030003IYH00`00IYIVUP02IYH01@00IYIVUVJF
00000fJF00<006JfI[H00VJf00D006JfI[IV]P0000AV]P04001V]VJf0005I[H00`00I[H00006I[H0
0`00J[IZ]P05J[H00`00J[H00004J]L01000J]MZe`0016[G00<006[GJ]L00V[G0P001V[G0P001F[G
00D006[GJ]MZe`00009Zm`03001^mfkg00=^m`03001^mfkg00=^m`07001^mfkgK_L006kg00001Fkg
00<006kg00000fkg00<006lGKaL00flG00<006lGKaL00flG00L006lGKaM_5`00KaL00003KaL01`00
KaM_5flG001_600000Ac>006001c>7<h001c>00017<h00L007<hLcQc>000LcP00003LcP00`00LcQc
>002LcP01@00LcQc>7<h00001G<h00D007<hLcQc>00000Ec>003001FoEKm00AFo@<000EFo@03001F
oEKm00=Fo@<000EFo@03001FoEKm00=Fo@800003Ool007oo09Qoo`00I7oo0P0027oo0P0047oo1000
1Woo00<005KmE_d00eKm0`001EKm00<005KmE_d00eKm0`001UKm00<005Km00000P0000=Fo@00E_d0
1EKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000eKm00<005KmE_d00eKm0P00
1UKm00<005KmE_d00eKm0P001EKm00<005KmE_d00eKm0`001UKm00<005Km00000P000UKm00<005Km
E_d015Km00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d00eKm
100015Km00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001EKm00<005KmE_d00eKm00<0059I
DUT00U9I00D002eg;GL]M`0000@a^004000e^3Fh=KP40004>MP00`00>MPif002>MP01@00>MPif3WH
000013WH00<003WH>MP00SWH00D003gH?MPmf00000@me`04000mecgG?ML500000cgG000me`04?ML0
1@00?MLmecgG0000147G00<0047G@ML00T7G00<0047G@ML00T7G00<0047G@ML00d7G00<0047G@ML0
0T7G00<0047G@ML00T7G00<004GgAOL00TGg00<004GgAOL00dGg00<004GgAOL00TGg00<004GgAOL0
0TGg00<004GgAOL014Gg00<004GgAOL00TGg00<004WgBOL01P000TWf00<004WfBOH00dWf00<004Wf
BOH00dWf00<004WfBOH00dWf00<004WfBOH00dWf00<004WfBOH00dWf00<004gfCOH00dgf00<004gf
00000P0000==mP00COH01Dgf00<004hFCQH00dhF00<004hFCQH00dhF00<004hFCQH00dhF0P0014hF
00<0058FDQH0158F00<0058FDQH0158F00<0058FDQH00e8F0P001E8F00<0058FDQH0158F00<0058F
DQH00e8F0P001UHF00<005HfESH015Hf00L005HfESIF=P00ESH00007ESH00`00ESIF=P04ESH20005
ESH00`00ESIF=P04ESH01000FSIJ=P0015Xf00<005XfFSH015Xf00@005XfFSH000AJ=P03001JEUYF
00AJEP04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00GUINEP02GUH00`00GUH0
0007GUH01000GUINEP0015iF00<005iFGUH015iF0P0025if0P001Uif00@005ifGWH000ARMP03001R
MV9f00=RMP03001RMP0000MRMP03001RMV9f00IRMP8000IRUP04001RUV:F0005HYH01000HYIRUP00
0fJF0P000fJF00<006JFIYH00VJF00D006JFIYIVUP0000AVUP04001VUVJF0004I[H01000I[IV]P00
1FJf00<006Jf00001fJf00<006JfI[H01FJf00<006ZfJ[H016Zf00@006ZfJ[H000AZe`05001Zef[G
J]L00002J]L00`00J]MZe`03J]L00`00J]MZe`05J]L30003J]L00`00J]MZe`02J]L00`00J_L00005
K_L00`00K_L00003K_L00`00K_M^m`03K_L00`00K_M^m`03K_L01@00K_M^mfkg00000Vkg00<006lG
KaL00flG00<006lGKaL00VlG00<006lGKaL00flG00<006lGKaL00VlG00<006lGKaL00VlG00<007<h
LcP00g<h00D007<hLcQc>00000Ec>003001c>7<h009c>005001c>7<hLcP00005LcP01@00LcQc>7<h
000017<h00<007<h00000W<h00<007<hLcP00W<h00<007<h00000UKm0`0000=Fo@00E_d01EKm00<0
05KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d00`0000EFo@00Oomoo`0009Qoo`00I7oo0P0027oo
0P003goo0P002Woo00<005Km00000P000eKm00<005KmE_d00eKm00<005Km00000P000eKm00<005Km
E_d00eKm0P001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d00eKm0`001UKm00<005Km00000P00
0UKm00<005KmE_d015Km00<005Km00000P0000=Fo@00E_d01EKm00<005Km00000P000eKm00<005Km
E_d00eKm0P001UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001UKm00<005Km00000P00
0UKm00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000UKm00<0
05KmE_d00eKm00<005KmE_d00UKm00<0059IDUT00U9I00<002eg;GL00Reg00D0036h<KPa^00000<e
^003000ef3GH00H000@if003000if3WH008if005000if3WH>MP00004>MP00`00?MPmf002?MP00`00
?MLme`02?ML01@00?MLmecgG00000cgG2`0000<me`00@ML00d7G00D0047G@MM1e`0000A1e`030011
ed7G00=1e`030011ed7G0091e`030011ed7G0091e`030015mdGg0095m`030015mdGg00=5m`030015
mdGg0095m`030015mdGg00=5m`030015mdGg00/000=9mP030019mTWf0099mP030019mTWf00A9mP03
0019mTWf0099mP030019mTWf00A9mP030019mTWf0099mP030019mTWf00=9mP03001=mTgf009=mP<0
00A=mP03001=mTgf00A=mP03001>5ThF00=>5P03001>5ThF00=>5P04001>5ThFCQH200000dhF001>
5P04CQH00`00DQIB5P04DQH00`00DQIB5P03DQH01000DQIB5U8F0P0000=B5P00DQH0158F00<0058F
DQH0158F00<0058FDQH00U8F00<0058F00001UHF00<005HfESH015Hf00@005HfESH000=F=P03001F
=UHf00AF=P03001F=UHf00=F=P8000IF=P03001F=UHf00EF=P8000EJ=P03001J=UXf00EJ=P8000EJ
=P03001JEUYF00AJEP03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP05001NEUiFGUH0
0003GUH00`00GUINEP05GUH20006GUH00`00GUINEP02GUH01000GWINMP001eif00<005ifGWH01Eif
00@005ifGWH000ARMP03001RMV9f009RMP04001RMV9f0007HWH00`00HWIRMP06HWH00`00HYIRUP06
HYH20006HYH01000HYH006JF0`0000EVUP00IYIVUP0000EVUP04001VUVJF0005IYH00`00IYH00005
I[H00`00I[H00007I[H00`00I[IV]P06I[H00`00I[IV]P04I[H00`00J[H00005J[H01@00J[IZ]VZf
00000V[G00<006[GJ]L00V[G00<006[G00001V[G00<006[GJ]L016[G00<006[GJ]L00P000V[G00<0
06[GJ]L00f[G00<006kgK_L00fkg00D006kgK_M^m`00009^m`03001^mfkg00=^m`03001^mfkg00=^
m`07001^mfkgK_L006kg00001FlG00<006lG00000flG00<006lGKaL00flG00D006lGKaM_5`0000E_
5`03001c>7<h009c>003001c>7<h009c>003001c>7<h009c>003001c>7<h00=c>005001c>7<hLcP0
0004LcP01@00LcP007<h000017<h00H007<hLcP007<h0004LcP01000LcQc>7<h0P001EKm00<005Km
E_d00eKm0`001EKm00<005KmE_d00eKm0`001EKm00@007ooOol009Moo`00I7oo0P0027oo0P003goo
00<007ooOol02Woo0P001UKm00@005KmE_eFo@@000IFo@03001Fo@0000800003E_d005Km00EFo@03
001Fo@00008000=Fo@03001FoEKm00=Fo@03001Fo@00008000=Fo@03001FoEKm00=Fo@8000IFo@03
001FoEKm00=Fo@8000EFo@03001FoEKm00=Fo@<000IFo@03001Fo@000080009Fo@03001FoEKm00AF
o@03001Fo@0000800003E_d005Km00IFo@03001Fo@000080009Fo@03001FoEKm00=Fo@8000IFo@03
001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@04001FoEKmE_d70005DUT01@00;GL]Mbeg
00000c6h00<003Fh=KP00SFh00@003GH=MP000<if0H000@if003000if3WH008if005000if3WH>MP0
0004?MP00`00?MLme`02?ML00`00?MLme`02?ML01@00?MLmecgG00001CgG00@003gG?MLme`X00003
@ML0047G00=1e`030011ed7G0091e`030011ed7G00=1e`030011ed7G0091e`030015mdGg0095m`03
0015mdGg00=5m`030015mdGg0095m`030015mdGg00D000=5m`030015mdGg0095m`030019mTWf00=9
mP030019mTWf00=9mP030019mTWf00=9mP030019mTWf00=9mP030019mTWf00=9mP030019mTWf0099
mP030019mTWf00A9mP@00003COH004gf00E=mP03001=mTgf00==mP03001>5ThF00=>5P03001>5ThF
00A>5P<000=>5P03001>5ThF00=>5P03001B5U8F00AB5P03001B5U8F00AB5P<000=B5P03001B5U8F
00AB5P03001B5U8F00=B5P03001B5U8F0080009B5P03001F5UHF00EF5P03001F=UHf00AF=P8000AF
=P03001F=UHf00AF=P03001F=UHf009F=P03001F=P0000MF=P03001F=UHf00=F=P8000IJ=P03001J
=UXf00EJ=P03001J=UXf00AJ=P03001JEUYF00AJEP8000IJEP03001JEUYF00=JEP03001JEP0000IJ
EP04001NEUiF0004GUH00`00GUINEP05GUH00`00GUINEP05GUH01@00GUINEUiF00000eif00<005if
GWH01Eif00<005ifGWH01Uif0P001F9f00D0069fHWIRMP0000ARMP03001RMV9f00=RMP03001RMP00
00MRMP03001RUV:F00IRUP03001RUV:F00IRUP<000AVUP03001VUP0000IVUP03001VUP0000IVUP03
001VUP0000IV]P03001V]VJf00IV]P03001V]VJf00EV]P03001V]P0000AV]P04001Z]VZf0004J[H0
0`00J[IZ]P02J[H01000J]MZe`001F[G00<006[GJ]L016[G00<006[G000016[G00@006[GJ]MZe`80
0003J]L006[G00EZe`03001^mfkg00=^m`07001^mfkgK_L006kg00001Fkg00<006kg00000fkg00<0
06kgK_L00fkg00<006lGKaL00flG00L006lGKaM_5`00KaL00005KaL00`00KaL00002KaL00`00KaM_
5`02KaL00`00LaL00003LcP01`00LcQc>7<h001c>00000=c>003001c>7<h009c>005001c>000LcP0
0004LcP01@00LcQc>7<h00001G<h00D007<hLcQc>00000Ac>003001c>7<h009c>003001FoEKm00AF
o@03001FoEKm00<00003E_d005Km00EFo@03001FoEKm00<00003E_d005Km00EFo@800003Ool007oo
09Ioo`00I7oo0P0027oo0P003goo00<007ooOol037oo00<005KmE_d00eKm100015Km00<005KmE_d0
0eKm0P001EKm00<005KmE_d00eKm0`001UKm00@005KmE_eFo@@000IFo@03001Fo@000080009Fo@03
001FoEKm00AFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@00008000=Fo@03001FoEKm00=F
o@8000IFo@03001FoEKm00=Fo@8000EFo@03001FoEKm00AFo@8000IFo@03001Fo@000080009Fo@03
001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm
00=Fo@@0009Fo@04000efCGI=MT80002;GL00`00<KPa^002<KP01@00=KPe^3Fh00000cGH00D003WH
>MPif00000<if0H000@if003000if3WH008if005000mf3gH?MP00004?ML00`00?MLme`02?ML00`00
?MLme`02?ML00`00?MLme`02?ML00`00?MLme`02?ML00`00?MLme`02?ML01000@MM1ed7G:@000TGg
00<004GgAOL00dGg00<004GgAOL00TGg00<004WfBOH014Wf00<004WfBOH00TWf00<004WfBOH00dWf
00<004WfBOH00dWf00<004WfBOH00dWf00<004WfBOH00dWf00<004WfBOH0100014gf00<004gfCOH0
14gf00<004gfCOH014gf00<004hFCQH00ThF00<004hFCQH00dhF0P001ThF00<004hFCQH00ThF00<0
058FDQH0158F00<0058FDQH00e8F0P001U8F00<0058FDQH00e8F00<0058FDQH0158F0P001E8F00<0
05HFEQH015HF00<005HfESH00eHf0P001EHf00<005HfESH015Hf00<005HfESH00P000UHf00<005Hf
ESH01EHf00<005HfESH00UHf00<005Hf00001eXf00<005XfFSH00eXf0P001eXf00<005YFFUH00UYF
00<005YF00001eYF00D005YFFUIJEP00009JEP03001JEUYF00EJEP8000ENEP03001NEUiF00ANEP80
00MNEP04001NEUiF0004GWH00`00GWINMP04GWH20008GWH00`00HWIRMP05HWH01000HWIRMP00169f
00<0069fHWH00V9f00@0069fHWH000IRMP03001RMP0000MRUP03001RUV:F00=RUP@000MVUP03001V
UVJF00IVUP03001VUVJF00IVUP03001V]VJf00EV]P03001V]VJf00EV]P03001V]P0000EV]P04001V
]VJf0004I[H01@00J[IZ]VZf00000VZf00<006ZfJ[H00fZf00<006[G00001V[G00<006[GJ]L00f[G
00@006[GJ]L000AZe`03001Zef[G009Ze`8000IZe`03001^m`0000=^m`03001^mfkg00=^m`03001^
mfkg00A^m`04001^mfkg0002K_L00`00K_M^m`03K_L00`00KaM_5`03KaL00`00KaM_5`02KaL00`00
KaM_5`03KaL01P00KaM_5`00KaL000A_5`07001c5g<GLaL007<h00000g<h00L007<hLcQc>000LcP0
0004LcP01@00LcQc>7<h00001G<h00D007<hLcQc>00000Ac>003001c>7<h009c>08000=c>007001c
>7<hLcP007=H00001EKm0`001EKm00@005KmE_eFo@D000EFo@03001FoEKm00<00005E_d007ooOol0
002FOol006Aoo`8000Qoo`8000moo`03001oogoo00eoo`03001Fo@000080009Fo@03001FoEKm00AF
o@03001Fo@0000800003E_d005Km00EFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@@000AFo@03
001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000EFo@03001FoEKm00=Fo@<000IFo@03001Fo@00
0080009Fo@03001FoEKm00AFo@03001Fo@0000800003E_d005Km00EFo@03001FoEKm00<0009Fo@03
001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03001Fo@00
0080009Fo@03001FoEKm009Fo@05000efCGI=MT00004?OT00`00=KP000030003<KP01@00=KPe^3Fh
00000cGH00<003WH>MP00SWH00D003WH>MPif00000<if0<0008if003000if3WH008if003000mf3gH
008mf003000mecgG008me`05000mecgG?ML00004?ML00`00?MLme`03?ML00`00?MLme`02?ML01@00
?MLmecgG0000147G00<0047G@ML00T7G00<0047G@ML00d7G00<0047G@ML00T7G00<0047G@ML00T7G
00<0047G@ML00T7G00<004GGAML00dGG00<004GgAOL00TGg00<004GgAOL00TGg00<004GgAOL014Gg
00<004GgAOL00TGg00<004WfBOH00dWf00<004WfBOH00TWf00<004WfBOH014Wf00<004WfBOH00TWf
00<004WfBOH00dWf00<004WfBOH00TWf10000dWf00<004gfCOH00dgf00<004gfCOH00dgf00<004gf
COH014gf00<004hFCQH00dhF00<004hF00000P0000=>5P00CQH01DhF00<004hFCQH00dhF00<0058F
DQH00e8F00@0058FDQIB5P800003DQH0058F00EB5P03001B5U8F00=B5P03001B5U8F00=B5P8000IB
5P03001F5UHF00AF5P03001F=UHf009F=P03001F=P0000IF=P03001F=UHf00AF=P8000EF=P03001F
=UHf00AF=P05001F=UHfESH00002ESH00`00FSIJ=P05FSH00`00FSIJ=P02FSH00`00FSH00007FSH0
1@00FUIJEUYF00000UYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEUYF00EJEP03001NEUiF
00ENEP03001NEUiF009NEP03001NEP0000QNEP8000INMP03001NMUif009NMP04001NMUif0007GWH0
0`00HWIRMP05HWH00`00HWH00005HWH01@00HWIRMV9f00000f9f00<0069fHWH00f9f00@0069fHWH0
00IRUP04001RUP00HYH30002HYH00`00HYH00006IYH00`00IYIVUP06IYH00`00IYIVUP06IYH00`00
I[IV]P04I[H00`00I[H00005I[H01000I[IV]P0016Jf00<006JfI[H00VJf00@006JfI[H000AZ]P04
001Z]VZf0006J[H00`00J]MZe`04J]L00`00J]H00004J]L01@00J]MZef[G00000V[G00<006[GJ]L0
16[G00<006[GJ]L00f[G00D006kgK_M^m`00009^m`03001^mfkg00=^m`03001^mfkg00=^m`07001^
mfkgK_L006kg00001Fkg00<006lG00000flG00<006lGKaL00flG00<006lGKaL00VlG00<006lGKaL0
0VlG00<006lGKaL00flG00<007<GLaL00W<G00<007<hLcP00W<h00<007<hLcP00W<h00<007<hLcP0
0W<h00<007<hLcP00W<h00<007<hLcP00W<h00L007<hLcQc>000LcP00003LcP01@00LcQc>7<h0000
0W<h00<007<h00000g<h00H007=HLeQcF000E_d30002E_d00`00E_eFo@03E_d40004E_d00`00E_eF
o@03E_d30005E_d01000Oomoo`00UGoo001TOol20008Ool2000?Ool00`00Oomoo`0>Ool00`00E_eF
o@04E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d30006E_d00`00E_d000020002E_d00`00
E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@03
E_d00`00E_d000020003E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20005E_d00`00E_eF
o@03E_d30006E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d0000200000eKm001Fo@06
E_d00`00E_d000020002E_d00`00E_eFo@03E_d20006E_d01@00E_eFoEKm000013GI00<003gi?OT0
0Sgi00@003Fh=KPe^0D000@e^005000ef3GH=MP00003>MP00`00>MPif002>MP01P00>MPif3WH000i
f0@000<if003000mf3gH008mf003000mecgG008me`03000mecgG008me`05000mecgG?ML00005?ML0
0`00?MLme`02?ML00`00?MLme`02?ML00`00@MM1e`02@ML01@00@MM1ed7G00001D7G00<0047G@ML0
0T7G00<0047G@ML00T7G00<0047G@ML00T7G00<004GGAML00dGG00<004GgAOL00TGg00<004GgAOL0
0dGg00<004GgAOL00dGg00<004GgAOL00TGg00<004WfBOH00dWf00<004WfBOH00dWf00<004WfBOH0
0dWf00<004WfBOH00TWf00<004WfBOH014Wf100000=9mP00BOH014Wf00<004gfCOH00dgf00<004gf
COH014gf00<004gfCOH00dgf00<004hFCQH00ThF0`0014hF00<004hFCQH014hF00<004hFCQH00dhF
00<0058FDQH0158F0`000e8F00<0058FDQH0158F00<0058FDQH00e8F00@0058FDQIB5P800003DQH0
058F00EB5P03001F5UHF00AF5P03001F=UHf0080009F=P03001F=UHf00AF=P03001F=UHf00AF=P03
001F=UHf00AF=P03001F=UHf00AF=P04001F=UHf0004ESH00`00FSIJ=P04FSH01@00FSIJ=UXf0000
0eXf00<005XfFSH015Xf00@005YFFUH000AJEP03001JEUYF00AJEP03001JEP0000EJEP03001JEUYF
00AJEP03001NEUiF00ENEP05001NEUiFGUH00003GUH00`00GUINEP05GUH00`00GWINMP05GWH01@00
GWINMUif00000eif00<005ifGWH015if0P00269f00<0069fHWH01F9f00@0069fHWH000ARMP05001R
MV9fHWH00003HWH00`00HYIRUP03HYH00`00HYH000020004HYH01000HYIRUP001FJF00<006JF0000
1VJF00<006JF00001VJF00<006JF000016Jf00@006JfI[H000EV]P05001V]VJfI[H00003I[H00`00
I[IV]P02I[H01000I[IV]P0016Zf00<006Zf00001fZf00<006[GJ]L00f[G00@006[FJ]H000=Ze`03
001Zef[G009Ze`03001Ze`0000IZe`<000=Ze`03001^mfkg009^m`03001^m`0000E^m`03001^m`00
00=^m`03001^mfkg00=^m`03001^mfkg00=^m`05001_5flGKaL00002KaL00`00KaM_5`02KaL00`00
KaL00003KaL00`00KaM_5`02KaL00`00KaM_5`02KaL00`00LaMc5`03LaL01@00LcQc>7<h00001G<h
00<007<hLcP00W<h00L007<hLcQc>000LcP00003LcP01000LcQc>0000g<h00<007<h00000g<h00<0
07<hLcP00W<h00<007<hLcP00W<h00<007=HLeP00W=H00<005KmE_d015Km00<005Km00000P0000=F
o@00E_d01UKm00<005Km00000P0000=Fo@00E_d01EKm00@007ooOol009Eoo`00I7oo0P0027oo0P00
3goo00<007ooOol03goo00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d00eKm00<005Km
00000P000eKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P00
1UKm00@005KmE_eFo@@000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009F
o@03001FoEKm00=Fo@03001Fo@00008000=Fo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@80
00EFo@03001FoEKm00AFo@8000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@05001FoEKmE_d0
0003=MT00`00?OTmn@02?OT01@00=KPe^3Fh00000cFh0`000SFh00D003GH=MPef00000<if003000i
f3WH008if003000if3WH008if004000if3WH>MP400000cWH000mf002?MP00`00?MLme`02?ML00`00
?MLme`02?ML00`00?MLme`02?ML00`00?MLme`02?ML00`00?MLme`02?ML00`00?MLme`02?ML00`00
@MM1e`02@ML00`00@MM1e`02@ML00`00@MM1e`03@ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00
@MM1e`02@ML00`00AMM5e`03AML00`00AOM5m`02AOL00`00AOM5m`02AOL00`00AOM5m`03AOL00`00
AOM5m`02AOL00`00BOI9mP04BOH00`00BOI9mP02BOH00`00BOI9mP03BOH00`00BOI9mP03BOH00`00
BOI9mP040004BOH00`00BOI9mP04BOH00`00COI=mP02COH00`00COI=mP04COH00`00COI=mP03COH0
0`00CQI>5P0200000dhF001>5P05CQH00`00CQI>5P03CQH00`00CQI>5P03CQH00`00DQIB5P03DQH2
0006DQH00`00DQIB5P04DQH00`00DQIB5P03DQH30003DQH00`00DQIB5P05DQH00`00EQIF5P04EQH2
0005ESH00`00ESIF=P03ESH00`00ESIF=P03ESH20006ESH00`00ESIF=P05ESH20005ESH00`00FSIJ
=P04FSH01000FSIJ=P0015Xf00<005XfFSH01EXf0P001EYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00eYF0P001eiF00@005iFGUH000ANEP03001NEUiF00ENEP03001NMUif00ENMP04001N
MUif0004GWH00`00GWINMP03GWH01000GWINMP001f9f00<0069fHWH01F9f00<0069f00001F9f00D0
069fHWIRMP0000ARMP04001RUV:FHYH300000f:F001RUP03HYH01@00HYIRUV:F000016JF00@006JF
IYH000EVUP04001VUVJF0005IYH01000IYIVUP0016Jf00D006JfI[IV]P0000=V]P03001V]VJf009V
]P04001V]VJf0005I[H00`00I[H00006J[H00`00J[IZ]P05J[H00`00J]H00004J]L01@00J]IZeV[F
00000V[G00<006[GJ]L00f[G00<006[GJ]L016[G00@006[GJ]L000=Ze`03001^mfkg00=^m`03001^
mfkg00=^m`04001^mfkg0003K_L00`00K_M^m`03K_L00`00K_M^m`02K_L00`00KaM_5`02KaL00`00
KaL00004KaL01000KaM_5`000VlG00<006lGKaL00VlG00<007<G00000flG00<007<GLaL00W<G00<0
07<g00000W<h00<007<hLcP00W<h00<007<h00000W<h00D007<hLcQc>00000=c>003001c>00000=c
>003001c>7<h009c>005001c>7<hLcP00005LcP01@00LcQc>7<h00001G=H00<005KmE_d015Km0P00
1EKm00<005KmE_d015Km0P001EKm00<005KmE_d00eKm0P000Woo00<007ooOol0TWoo001TOol20008
Ool2000?Ool00`00Oomoo`0@Ool00`00E_eFo@03E_d20006E_d00`00E_eFo@02E_d30006E_d00`00
E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d00002
0002E_d00`00E_eFo@03E_d40004E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20006E_d0
1000E_eFoEKm10001UKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000UKm00<0
05KmE_d00eKm00<005KmE_d00`000UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0`000UKm
00D003GI=MTef@0000<mn@03000e^3Fh008e^006000e^3Fh=KP003Fh0`0013GH00D003WH>MPif000
00<if003000if3WH008if005000if3WH>MP00003>MP500000cgH000me`03?ML01@00?MLmecgG0000
13gG00<003gG?ML00cgG00<003gG?ML00SgG00D003gG?MLme`0000A1e`030011ed7G0091e`030011
ed7G00=1e`030011ed7G0091e`030011ed7G0091e`030011ed7G0091e`030015edGG00=5e`030015
mdGg0095m`030015mdGg0095m`030015mdGg00A5m`030015mdGg0095m`030019mTWf00=9mP030019
mTWf0099mP030019mTWf00A9mP030019mTWf00D000=9mP030019mTWf00=9mP030019mTWf00=9mP03
001=mTgf00==mP03001=mTgf00==mP03001=mTgf00A=mP8000=>5P03001>5ThF00A>5P03001>5ThF
00A>5P03001>5ThF009>5P04001B5U8FDQH200000e8F001B5P05DQH00`00DQIB5P04DQH00`00DQIB
5P02DQH20006DQH00`00DQIB5P04DQH00`00EQIF5P03EQH20006ESH00`00ESIF=P04ESH01`00ESIF
=UHf001F=P0000MF=P03001F=UHf00=F=P8000IF=P03001J=UXf00EJ=P8000EJ=P03001J=UXf00EJ
=P03001JEUYF00AJEP03001JEUYF00AJEP8000IJEP03001JEUYF009JEP04001NEUiF0007GUH20005
GUH00`00GUINEP04GUH20008GWH20006GWH01@00GWINMUif00000eif00<0069fHWH0169f0P00269f
00<0069fHWH0169f00@0069fHWH000ERMPD000ARUP05001RUV:FHYH00004HYH01@00IYIVUVJF0000
0fJF00<006JFIYH00VJF00@006JFIYH000AVUP03001VUVJF009VUP04001V]VJf0005I[H01000I[IV
]P0016Jf00<006Jf00001fJf00<006ZfJ[H01FZf00<006ZfJ[H016Zf00@006[FJ]H000=Ze`03001Z
eV[F009ZeP03001Ze`0000IZe`03001Zef[G00AZe`03001Zef[G00800003J]L006kg00E^m`03001^
mfkg00=^m`07001^mfkgK_L006kg00001Fkg00<006kg00000fkg00<006lGKaL00flG00<006lGKaL0
0flG00H006lGKaL006lG0004KaL01`00LaMc5g<G001_5`0000Ac5`06001c=g<g001c>00017<h00H0
07<hLcP007<h0004LcP00`00LcQc>002LcP01@00LcQc>7<h00001G<h00D007<hLcQc>00000Ac>003
001cF000009c>003001cF7=H009cF003001cF000009Fo@<00003E_d005Km00EFo@03001FoEKm00<0
0003E_d005Km00EFo@03001Fo@000080009Fo@04001oogoo002COol006Eoo`8000Ioo`8000moo`03
001oogoo019oo`03001Fo@000080009Fo@03001FoEKm00AFo@04001Fo@000003E_d00`00E_eFo@03
E_d20006E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20006E_d00`00E_d000020002E_d0
0`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eF
o@03E_d40004E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20006E_d01000E_eFoEKm1000
1UKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P0000=Fo@00<KT00`000cGI00<0
03gi?OT00Sgi00D003Fh=KPe^00000@e^004000e^3Fh=KP50003>MP00`00>MPif002>MP01@00>MPi
f3WH000013WH00D003WH>MPif00000<if0X00003?ML003gG008me`03000mecgG00<me`03000mecgG
008me`03000mecgG008me`030011ed7G0091e`050011ed7G@ML00005@ML00`00@MM1e`02@ML00`00
@MM1e`02@ML00`00@MM1e`02@ML00`00AMM5e`03AML00`00AOM5m`02AOL00`00AOM5m`03AOL00`00
AOM5m`03AOL00`00AOM5m`02AOL00`00BOI9mP03BOH00`00BOI9mP03BOH00`00BOI9mP060002BOH0
0`00BOI9mP03BOH00`00BOI9mP03BOH00`00BOI9mP03BOH00`00COI=mP03COH00`00COI=mP03COH0
0`00COI=mP03COH20005CQH00`00CQI>5P03CQH00`00CQI>5P04CQH00`00CQI>5P03CQH30003DQH0
0`00DQIB5P04DQH00`00DQIB5P04DQH01`00DQIB5U8F001B5P0000IB5P03001B5U8F00AB5P03001F
5UHF009F5P03001F5P0000IF=P03001F=UHf00AF=P04001F=UHf0003ESH00`00ESIF=P04ESH00`00
ESIF=P02ESH00`00ESH00007ESH00`00FSIJ=P03FSH20007FSH00`00FSIJ=P03FSH20007FUH00`00
FUIJEP02FUH00`00FUH00007FUH01000FUIJEP000eiF00<005iFGUH01EiF00<005iFGUH01EiF00<0
05iFGUH00UiF00@005iFGUH000MNMP03001NMUif00ENMP05001NMUifGWH00003GWH00`00HWIRMP03
HWH01000HWIRMP001f9f00<0069fHWH01F9f0P00169f0`000V:F00<006:FHYH00f:F00@006:FHYH0
00ERUP04001VUVJF0004IYH01@00IYIVUVJF000016JF00D006JFIYIVUP0000AVUP04001V]VJf0005
I[H00`00I[H00006I[H00`00I[IV]P06I[H00`00J[IZ]P04J[H00`00J[H00004J[H00`00J]IZeP02
J]H01000J]MZe`001F[F00<006[GJ]L016[G00<006[G000016[G00<006[GJ]L00V[G0P001Vkg00<0
06kg00000fkg00<006kgK_L00Vkg00<006kg000016kg00@006kgK_L0009^m`03001_5flG00A_5`03
001_5flG009_5`03001_5flG009_5`03001_5flG00=_5`03001c5g<G009c5`03001c5g<G009c5`03
001c=g<g009c=`03001c>7<h00=c>005001c>7<hLcP00004LcP00`00LcQc>003LcP01@00LcQc>7<h
000017<h00D007<h001c>00000Ac>006001cF7=H001c>00017=H00@007=HLeQcF08000EFo@03001F
oEKm00=Fo@<000EFo@03001FoEKm00=Fo@8000IFo@03001oo`0009=oo`00IGoo0P001Woo0P003goo
00<007ooOol04goo0P001EKm00<005KmE_d00eKm0P001UKm00<005Km00000P000UKm00<005KmE_d0
15Km00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d00eKm0P00
1UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001UKm00<005Km00000P000UKm00<005Km
E_d015Km00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d00eKm
100015Km00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001EKm00@0036i<KTa^@@000@mn@05
000e^3Fh=KP00004=KP01@00=KPe^3Fh00000cFh0`0000<if000>MP00cWH00<003WH>MP00SWH00D0
03WH>MPif00000@if005000if3WH>MP00004?ML01000?MLmecgG1@0000<me`00?ML00cgG00<003gG
?ML00SgG00<003gG?ML00SgG00<0047G@ML00T7G00<0047G@ML00T7G00<0047G@ML00d7G00<0047G
@ML00T7G00<0047G@ML00T7G00<0047G@ML00T7G00<004GGAML00dGG00<004GgAOL00TGg00<004Gg
AOL00TGg00<004GgAOL00dGg00<004GgAOL00TGg00<004WfBOH014Wf00<004WfBOH01@000dWf00<0
04WfBOH00TWf00<004WfBOH014Wf00<004WfBOH00TWf00<004WfBOH014Wf00<004gfCOH00Tgf00<0
04gfCOH014gf00<004gf00000P0000==mP00CQH014hF00<004hFCQH014hF00<004hFCQH00dhF00<0
04hFCQH00ThF0P001U8F00<0058FDQH0158F00<0058FDQH00e8F00@0058FDQH000=B5P03001B5U8F
00=B5P03001B5U8F00AB5P03001F5UHF0080009F5P03001F=UHf00EF=P03001F=UHf00=F=P03001F
=P0000AF=P03001F=UHf00AF=P05001F=UHfESH00002ESH00`00ESIF=P05ESH00`00FSIJ=P02FSH0
0`00FSH00007FSH00`00FSIJ=P02FSH00`00FSH00007FUH01@00FUIJEUYF00000eYF00<005YFFUH0
15YF00@005YFFUH000=NEP03001NEUiF00ENEP03001NEUiF00ENEP05001NEUiFGUH00003GUH00`00
GWINMP05GWH00`00GWINMP05GWH01000GWINMP001Eif00D0069fHWIRMP0000=RMP03001RMV9f00AR
MP03001RMP0000IRMP04001RMV9fHWH20003HWH20006HYH00`00HYH00006HYH01000IYIVUP001FJF
00@006JFIYH000AVUP04001VUVJF0005IYH00`00I[H00007I[H00`00I[IV]P05I[H00`00I[IV]P05
I[H00`00J[H00004J[H01000J[IZ]P0016Zf00<006[FJ]H00V[F00<006[G00001V[F00<006[GJ]L0
0f[G00@006[GJ]L000=Ze`03001Zef[G00=Ze`8000E^m`04001^mfkg0002K_L00`00K_M^m`04K_L0
0`00K_M^m`03K_L01P00K_M^m`00K_L000I_5`03001_5`00009_5`03001_5flG00=_5`03001_5flG
009_5`03001c5g<G00=c5`03001c5g<G009c5`03001c=g<g009c=`03001c>7<h009c>003001c>7<h
009c>08000=c>003001c>7<h009c>005001c>000LcP00004LcP01@00LcQc>7<h000017<h00<007=H
LeP00W=H00<007=HLeP00W=H00<007=HLeP00W=H00<005KmE_d015Km00<005KmE_d00`0000=Fo@00
E_d01EKm00<005KmE_d00`0000=Fo@00E_d01EKm0P0000=oo`00Ool0TGoo001VOol20004Ool2000@
Ool00`00Oomoo`02000COol00`00E_eFo@03E_d00`00E_d000020002E_d00`00E_eFo@03E_d20006
E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@03E_d20006E_d00`00E_d000020002E_d00`00E_eF
o@04E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@03E_d2
0006E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20006E_d00`00E_d000020002E_d00`00
E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@02
E_d01@00<KTa^C6i00000S7I1P0013Fh00D003Fh=KPe^00000@e^006000e^3Fh=KP003Fh0`000cWH
00<003WH>MP00SWH00D003WH>MPif00000@if003000if3WH008if005000mecgG?ML00004?ML01000
?MLmecgG1@000SgG00<003gG?ML00SgG00D003gG?MLme`0000A1e`030011ed7G0091e`030011ed7G
00=1e`030011ed7G0091e`030011ed7G0091e`030011ed7G0091e`030015edGG00=5e`030015mdGg
0095m`030015mdGg0095m`030015mdGg00=5m`030015mdGg00=5m`030019mTWf00H00099mP030019
mTWf00=9mP030019mTWf00=9mP030019mTWf00=9mP030019mTWf00=9mP030019mTWf00=9mP03001=
mTgf009=mP03001=mTgf00==mP<000A=mP03001>5ThF00=>5P03001>5ThF00A>5P03001>5ThF00=>
5P03001>5ThF00800003CQH0058F00EB5P03001B5U8F00AB5P03001B5U8F00AB5P8000AB5P03001B
5U8F00AB5P03001B5U8F00AB5P8000EF5P03001F=UHf00AF=P03001F=UHf00=F=P8000EF=P03001F
=UHf00AF=P04001F=UHf0004ESH00`00ESIF=P04ESH01@00FSIJ=UXf00000UXf00<005XfFSH01EXf
00D005XfFSIJ=P0000=J=P03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUH0
0005GUH00`00GUINEP03GUH20007GUH01000GUINEP0015iF00<005ifGWH015if0P0025if0P001Uif
00D0069fHWIRMP0000=RMP03001RMV9f00=RMP04001RMV9f0006HWH40005HWH00`00HYIRUP06HYH0
0`00HYIRUP06HYH20006IYH00`00IYH00005IYH00`00IYH00007IYH00`00I[IV]P06I[H00`00I[IV
]P04I[H00`00I[H00005I[H01000J[IZ]P0016Zf00D006ZfJ[IZ]P00009Z]P03001ZeV[F00AZeP03
001ZeV[F00AZeP03001ZeP0000AZe`05001Zef[GJ]L00002J]L00`00J]MZe`03J]L00`00K_L00004
K_L01000K_M^m`000Vkg00<006kgK_L016kg00<006kgK_L00Vkg00<006kgK_L00Vkg00<006lGKaL0
16lG00@006lGKaL0009_5`03001_5flG009_5`03001_5`0000=_5`03001c5g<G009c5`03001c5`00
009c5`03001c=g<g009c=`03001c>00000=c>005001c>7<hLcP00002LcP00`00LcP00004LcP01@00
LcQc>7<h000017<h00<007<hLcP00W<h00<007<hLcP00W<h00<007=HLeP00W=H00D007=HLeQcF000
00AcF003001cF@0000EFo@<000EFo@03001FoEKm00=Fo@<000EFo@03001FoEKm00<00004E_d007oo
002BOol006Ioo`P0011oo`<001Ioo`04001FoEKmE_d30006E_d00`00E_d000020002E_d00`00E_eF
o@04E_d00`00E_d000020003E_d00`00E_eFo@03E_d00`00E_d000020002E_d00`00E_eFo@03E_d2
0006E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@03E_d20006E_d00`00E_d000020002E_d00`00
E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@03
E_d20006E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@02E_d01@00
<KTa^C6i00000S7I00@003GH=MPef0<0008e^003000e^3Fh008e^005000e^3Fh=KP00004=KP00`00
=KPe^00400000cWH000if002>MP00`00>MPif002>MP01@00>MPif3WH000013WH00<003gG?ML00SgG
00D003gG?MLme`0000@me`04000mecgG?ML;00000cgG0011e`03@ML01@00@MM1ed7G00001D7G00<0
047G@ML00T7G00<0047G@ML00T7G00<0047G@ML00T7G00<004GGAML00dGG00<004GgAOL00TGg00<0
04GgAOL00dGg00<004GgAOL00dGg00<004GgAOL01@000dGf00<004WfBOH00TWf00<004WfBOH014Wf
00<004WfBOH00TWf00<004WfBOH00dWf00<004WfBOH00dWf00<004WfBOH00dWf00<004gfCOH00dgf
00<004gf00000P0000==mP00COH01Dgf00<004hFCQH00ThF00<004hFCQH014hF00<004hFCQH014hF
0P0014hF00<0058FDQH00e8F00<0058FDQH0158F00<0058FDQH00e8F0P001E8F00<0058FDQH0158F
00<0058FDQH00e8F0P001UHF00<005HfESH015Hf00<005HfESH00UHf00<005Hf00001EHf00<005Hf
ESH01EHf0P001EHf00<005HfESH015Hf00@005XfFSH000AJ=P03001J=UXf00AJ=P04001J=UXf0004
FSH00`00FUIJEP05FUH20005FUH00`00FUIJEP05FUH00`00GUINEP04GUH00`00GUINEP02GUH01000
GUINEP001eiF0P001UiF00<005ifGWH00Uif00@005ifGWH000MNMP03001NMUif00ENMP04001RMV9f
0005HWH01@00HWIRMV9f00000f9f00<0069fHWH00V9f10001f9f00<006:FHYH01V:F00<006:FHYH0
1V:F00<006JFIYH01VJF00<006JFIYH01FJF00<006JFIYH01VJF00<006JfI[H01FJf00<006Jf0000
1FJf00<006Jf00001FJf00D006ZfJ[IZ]P00009Z]P03001Z]VZf009Z]P03001Z]P0000MZeP03001Z
eV[F00=ZeP04001ZeV[F0003J]L00`00J]MZe`02J]L00`00J]L00005J]L01@00K_L006kg00000Vkg
00<006kgK_L00Vkg0P001Vkg00<006kg00000Vkg00<006kgK_L00fkg00<006lGKaL00flG00L006lG
KaM_5`00KaL00004KaL01`00KaM_5flG001_5`0000Ac5`06001c5g<G001c5`0017<g00L007<hLcQc
>000LcP00003LcP00`00LcQc>002LcP00`00LcQc>002LcP00`00LcQc>002LcP00`00LcQc>002LcP0
1`00LcQc>7<h001cF000009c>003001cF7=H009cF005001cF000LeP00004LeP01000LeUcF@000UKm
0`0000=Fo@00E_d01EKm00<005KmE_d00`0000=Fo@00E_d01EKm0`001EKm00<007oo0000TGoo001X
Ool4000AOol2000IOol30003E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d30006E_d01000
E_eFoEKm0`001UKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000eKm00<005Km
E_d00eKm00<005Km00000P000UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0`001EKm00<0
05KmE_d00eKm0P001UKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000UKm00<0
05KmE_d015Km00<005Km00000P000UKm00<005KmE_d00eKm0`000UKm00D0036i<KTa^@0000<af@06
000ef3GH=MP003Fh0`0013Fh00D003Fh=KPe^00000@e^004000e^3Fh0003>KP500000cWH000if002
>MP00`00>MPif002>MP01@00>MPif3WH000013gG00<003gG?ML00SgG00<003gG?ML00SgG00<003gG
?ML00SgG00<003gG?ML00SgG00@003gG?MLme`X00003@ML0047G00A1e`030011ed7G0091e`030011
ed7G0091e`030011ed7G0091e`030015edGG00=5e`030015mdGg0095m`030015mdGg00/00095mP03
0015mTGf00=5mP030019mTWf00=9mP030019mTWf00=9mP030019mTWf0099mP030019mTWf00A9mP03
0019mTWf0099mP030019mTWf00A9mP03001=mTgf00@000A=mP03001=mTgf00A=mP03001>5ThF00=>
5P03001>5ThF00=>5P03001>5ThF00=>5P8000E>5P03001B5U8F00AB5P03001B5U8F00=B5P04001B
5U8FDQH200000e8F001B5P05DQH00`00DQIB5P03DQH00`00DQIB5P02DQH00`00DQH00006EQH00`00
ESIF=P04ESH00`00ESIF=P020002ESH00`00ESIF=P04ESH00`00ESIF=P03ESH20006ESH00`00ESIF
=P05ESH20005FSH00`00FSIJ=P05FSH20005FSH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH20006GUH01@00GUINEUiF00000eiF00<005iFGUH01EiF00<005iFGUH01EiF00D005ifGWIN
MP0000=NMP03001NMUif00ENMP03001NMUif00INMP8000IRMP05001RMV9fHWH00004HWH50002HWH0
0`00HWIRMP04HWH00`00HYH00006HYH00`00HYH00007HYH00`00IYIVUP06IYH00`00IYIVUP05IYH0
0`00IYIVUP05IYH00`00I[H00005I[H01000I[IV]P0016Jf00@006JfI[H000AV]P03001Z]VZf009Z
]P04001Z]VZf0005J[H00`00J]IZeP05J]H20005J]H01@00J]IZeV[F00000V[G00<006[GJ]L00f[G
00<006[GJ]L016[G00<006kg00000Vkg0P001Fkg00<006kgK_L016kg00@006kgK_L0009^m`03001^
mfkg009^m`03001^m`0000A_5`03001_5flG009_5`03001_5flG00=_5`03001_5flG009_5`03001c
5g<G009c5`03001c5g<G009c5`03001c=g<g00=c=`03001c>7<h009c>003001c>7<h009c>003001c
>7<h009c>003001c>7<h009c>007001c>7<hLcP007<h00000W<h00D007<hLcQc>000009cF003001c
>00000AcF005001cF7=HLeP00004LeP00`00LeUcF@02LeT20005E_d01000E_eFoEKm1@001EKm00<0
05KmE_d00`0000=Fo@00E_d01EKm00@007ooOol0091oo`00OWoo00<007ooOol05goo00<005KmE_d0
15Km00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000eKm00<005KmE_d00eKm1000
0eKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0`001UKm00@005KmE_eFo@<000IFo@03001F
o@000080009Fo@03001FoEKm00AFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@03001Fo@000080
009Fo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@03
001Fo@0000800003E_d002fh00<000@a^@04000afC7I0004=MP01000=KPe^3Fh0P000SFh00<003Fh
=KP00SFh00D003Fh=KPe^00000<e^005000i^3Vh>KP00003>KP60004>MP00`00>MPif002>MP01@00
?MLmecgG000013gG00<003gG?ML00SgG00<003gG?ML00cgG00D003gG?MLme`0000@me`030011ed7G
0091e`040011ed7G@MLT0002AML00`00AOM5m`03AOL00`00AOI5mP02AOH00`00AOI5mP04AOH00`00
BOI9mP02BOH00`00BOI9mP03BOH00`00BOI9mP03BOH00`00BOI9mP03BOH00`00BOI9mP02BOH00`00
BOI9mP03BOH40002COH00`00COI=mP04COH00`00COI=mP03COH00`00CQI>5P03CQH00`00CQI>5P04
CQH00`00CQH0000200000dhF001>5P04CQH00`00DQIB5P04DQH00`00DQIB5P04DQH30003DQH00`00
DQIB5P04DQH00`00DQIB5P03DQH00`00DQIB5P020002DQH00`00EQIF5P05EQH00`00ESIF=P04ESH2
0005ESH00`00ESIF=P03ESH00`00ESIF=P02ESH00`00ESH00007ESH00`00ESIF=P03ESH20006FSH0
0`00FSIJ=P04FSH20007FSH00`00FUIJEP03FUH20007FUH00`00FUIJEP02FUH00`00FUH00006GUH0
1000GUINEP0015iF00<005iFGUH015iF0P001eiF00@005ifGWH000ANMP03001NMUif00ANMP03001N
MP0000MNMP03001RMV9f00ERMP04001RMV9f0003HWH30002HWH01@00HWIRMV9f00001F9f00@006:F
HYH000ERUP04001RUV:F0006HYH00`00IYH00006IYH00`00IYH00005IYH00`00IYH00005IYH01000
I[IV]P001FJf00@006JfI[H000=V]P03001V]VJf009V]P04001V]VJf0005J[H00`00J[H00006J[H0
0`00J]IZeP04J]H01000J]IZeP000f[F00<006[FJ]H00V[F00<006[G00001V[G00<006[GJ]L00f[G
00H006kgK_M^m`00K_L20005K_L00`00K_M^m`03K_L01`00K_M^mfkg001^m`0000E^m`04001^mfkg
0002KaL00`00KaM_5`03KaL00`00KaM_5`02KaL00`00KaM_5`03KaL00`00LaMc5`02LaL00`00LaMc
5`02LaL00`00LcMc=`02LcL00`00LcQc>003LcP01@00LcQc>7<h000017<h00<007<h00000W<h00D0
07<hLcQc>000009c>003001c>00000Ac>005001cF7=HLeP00004LeP00`00LeQcF002LeP20003LeP0
0`00LeUcF@02LeT20005E_d40003E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@03E_d200000goo
001oo`2?Ool007eoo`03001oogoo01Uoo`03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@<000IF
o@03001Fo@0000800003E_d005Km00EFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@00
008000=Fo@03001FoEKm00=Fo@@000=Fo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@<000IF
o@04001FoEKmE_d30006E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d0000200000eKm
001Fo@06E_d00`00E_d000020002E_d00`00E_eFo@03E_d20005E_d01000;KP]^2fh0P000S6i00@0
037I<MT000@ef006000e^3Fh=KP003Fh10000cFh00<003Fh=KP00SFh00@003Fh=KP000@i^005000i
^3Vh>KP00003>KP60004>MP00`00?MLme`02?ML01@00?MLmecgG00001CgG00<003gG?ML00SgG00<0
03gG?ML00SgG00D003gG?MLme`0000A1e`030011ed7G0091e`030011ed7G00=1e`030011ed7G0091
e`030011ed7G0091e`030011ed7G0091e`030015edGG00=5e`030015edGG0095e`030015edGG0095
e`030015mdGg00=5m`030015mTGf00=5mP030015mTGf00=5mP030019mTWf0099mP030019mTWf00A9
mP030019mTWf0099mP030019mTWf00=9mP030019mTWf00=9mP030019mP0000800003BOH004gf00A=
mP03001=mTgf00==mP03001=mTgf00A=mP03001>5ThF009>5P03001>5ThF00=>5P<000A>5P03001>
5ThF00A>5P03001B5U8F00=B5P03001B5U8F00=B5P8000IB5P03001B5U8F00=B5P03001B5U8F00AB
5P8000EB5P03001F5UHF00AF5P03001F=UHf00=F=P8000IF=P03001F=UHf00=F=P05001F=UHfESH0
0002ESH00`00ESIF=P05ESH00`00ESIF=P02ESH00`00ESH00007FSH00`00FSIJ=P02FSH00`00FSH0
0007FSH00`00FUIJEP02FUH00`00FUH00007FUH01@00FUIJEUYF00000eYF00<005iFGUH015iF0P00
1UiF00<005iFGUH00UiF00<005iF000025iF0P001Uif00<005ifGWH00Uif00@005ifGWH000MNMP03
001RMV9f00IRMP800004HWH000000002HWH01000HWIRMP00169f00D0069fHWIRMP0000=RUP03001R
UV:F009RUP05001RUV:FHYH00005HYH01000IYIVUP001FJF00@006JFIYH000AVUP04001VUVJF0005
IYH01000I[IV]P0016Jf00<006JfI[H00VJf00@006JfI[H000AV]P04001V]VJf0006J[H00`00J[IZ
]P04J[H00`00J]H00005J]H01000J]IZeP000V[F00<006[FJ]H016[F00<006[GJ]L016[G00<006[G
00000f[G00<006kgK_L00Vkg00@006kg000000A^m`03001^m`0000A^m`03001^mfkg009^m`03001^
mfkg00=^m`07001^mfkgK_L006lG00001FlG00<006lG00000flG00<006lGKaL00VlG00<007<G0000
0W<G00<007<GLaL00W<G00<007<g00000g<g00<007<hLcP00W<h00<007<h00000W<h00D007<hLcQc
>000009c>003001c>00000Ac>005001c>7<hLcP00004LcP00`00LeQcF002LeP20003LeP01@00LeQc
F7=H00000W=H00<007=H000017=I00D007=jLgX005Km00<00003E_d005Km00EFo@03001FoEKm00<0
0003E_d005Km00EFo@03001FoEKm00<00005E_d007ooOol0002?Ool007eoo`03001oogoo01Yoo`03
001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@8000EFo@03
001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@<000IFo@03001Fo@0000800003E_d005Km00EFo@03
001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@@000=Fo@03
001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000EFo@03001FoEKm00AFo@8000IFo@03001Fo@00
0080009Fo@03001FoEKm009Fo@06000]^2fh;KP002fh0`000c7I00D003GH=MPef00000@e^004000e
^3Fh=KP50004=KP01000=KPe^00013Vh00<003Vh>KP00SVh00D003Vh>KPi^00000<if0<0008if003
000mecgG008me`03000mecgG008me`03000mecgG008me`03000mecgG008me`03000mecgG008me`03
000mecgG008me`030011ed7G0091e`050011ed7G@ML00005@ML00`00@MM1e`02@ML00`00@MM1e`02
@ML00`00@MM1e`02@ML00`00AMM5e`03AML00`00AMM5e`02AML00`00AMM5e`03AML00`00AOM5m`03
AOL00`00AOI5mP02AOH00`00AOI5mP03AOH00`00BOI9mP03BOH00`00BOI9mP03BOH00`00BOI9mP02
BOH00`00BOI9mP03BOH00`00BOI9mP02BOH30004BOH00`00COI=mP03COH00`00COI=mP03COH00`00
COI=mP04COH00`00CQI>5P02CQH01000CQI>5ThF0P0000=>5P00CQH01DhF00<004hFCQH00dhF00<0
058FDQH00e8F00@0058FDQIB5P800003DQH0058F00EB5P03001B5U8F00AB5P03001B5U8F009B5P80
00IB5P03001F5UHF00AF5P03001F=UHf009F=P03001F=P0000IF=P03001F=UHf00=F=P04001F=UHf
0004ESH00`00ESIF=P04ESH01@00ESIF=UHf00000UHf00<005XfFSH01EXf00D005XfFSIJ=P00009J
=P03001J=UXf00EJ=P05001JEUYFFUH00003FUH00`00FUIJEP04FUH01000FUIJEP0015YF00<005iF
GUH015iF00<005iFGUH01EiF00D005iFGUINEP0000=NEP03001NEUiF00ENEP03001NMUif00ENMP05
001NMUifGWH00003GWH00`00GWINMP04GWH00`00HWH00007HWH30006HWH20005HWH01000HWIRMP00
1F:F00D006:FHYIRUP0000ARUP05001RUV:FHYH00003IYH00`00IYIVUP02IYH01@00IYIVUVJF0000
16JF00@006JFIYH000AVUP03001V]VJf009V]P04001V]VJf0005I[H00`00I[H00005I[H00`00I[H0
0007J[H00`00J[IZ]P04J[H00`00J]H00004J]H01@00J]IZeV[F00000V[F00<006[FJ]H016[F00<0
06[GJ]L00f[G00@006[GJ]L000=Ze`03001^mfkg00=^m`04001^mfkg0002K_L01@00K_M^mfkg0000
0Vkg00<006kgK_L00fkg00<006kgK_L00Vkg00<006kgK_L00fkg00<006lGKaL00flG00L006lGKaM_
5`00KaL00004KaL01P00LaMc5`00LaL000Ac5`07001c=g<gLcL007<g000017<h00H007<hLcP007<h
0004LcP01@00LcQc>7<h000017<h00<007<hLcP00W<h0P000g<h00D007=HLeQcF000009cF003001c
F00000=cF003001cF7=H009cF003001cFG=I009cF@04001cNW=jLgX20005E_d00`00E_eFo@03E_d3
0005E_d00`00E_eFo@03E_d30005E_d01000Oomoo`00SWoo001mOol00`00Oomoo`0KOol20005E_d0
0`00E_eFo@03E_d30006E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d000020002E_d00`00
E_eFo@04E_d00`00E_d000020003E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d20006E_d0
0`00E_eFo@03E_d30006E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d000020002E_d00`00
E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@03E_d00`00E_eFo@030002E_d00`00E_eFo@03
E_d20006E_d01@00E_eFoEKm000012fh00@002fh;KP]^0800003<MT003GH00<ef005000e^3Fh=KP0
0003=KP01000=KPe^3Fh0`000SFh00D003Fh=KPe^00000<i^003000i^3Vh008i^003000i^3Vh008i
^006000if3WH>MP003WG10000cgG00<003gG?ML00SgG00<003gG?ML00SgG00<003gG?ML00cgG00D0
03gG?MLme`0000@me`030011ed7G0091e`030011ed7G0091e`030011ed7G00=1e`030011ed7G0091
e`030011ed7G0091e`030011ed7G0091e`030015edGG00=5e`030015edGG0095e`030015edGG0095
e`030015mdGg00=5m`030015mTGf0095mP030015mTGf00A5mP030019mTWf0099mP030019mTWf00=9
mP030019mTWf0099mP030019mTWf00A9mP@00003BOH004Wf00E9mP03001=mTgf009=mP03001=mTgf
00A=mP03001=mTgf00==mP03001>5ThF00=>5P<000=>5P03001>5ThF00A>5P03001>5ThF00=>5P03
001B5U8F00AB5P<000=B5P03001B5U8F00AB5P03001B5U8F00AB5P07001B5U8FDQH0058F00001U8F
00<005HFEQH015HF00<005HfESH00P000UHf00<005HfESH01EHf00<005HfESH00eHf0P001EHf00<0
05HfESH015Hf00@005HfESH000AF=P03001J=UXf00AJ=P04001J=UXf0004FSH00`00FSIJ=P04FSH0
1000FUIJEP0015YF00<005YFFUH01EYF0P001EYF00<005iFGUH015iF00<005iFGUH01EiF00@005iF
GUH000ANEP03001NEUiF00ENEP03001NMUif00ENMP04001NMUif0005GWH00`00GWINMP02GWH01000
HWIRMP00169f1000269f00<0069fHWH0169f00<0069f00001V:F00@006:FHYH000ERUP05001RUV:F
HYH00004IYH01@00IYIVUVJF000016JF00@006JFIYH000AVUP04001VUVJF0005I[H01000I[IV]P00
1FJf00<006Jf00001VJf00<006ZfJ[H01FZf00<006Zf000016Zf00D006[FJ]IZeP00009ZeP03001Z
eV[F00=ZeP8000IZeP03001Ze`0000AZe`07001Zef[GJ]L006[G00001Vkg00@006kgK_L0009^m`07
001^mfkgK_L006kg00001Fkg00<006kg00000fkg00<006kgK_L00fkg00<006lGKaL00flG00<006lG
KaL00VlG00<006lGKaL00VlG00<007<GLaL00W<G00<007<GLaL00g<G00<007<gLcL00W<g00<007<h
LcP00W<h00<007<hLcP00W<h00<007<hLcP00W<h00<007<hLcP00W<h0P000g<h00D007<hLcQc>000
009cF003001c>00000=cF003001cF7=H009cF005001cF7=HLeP00005LeP01@00LeUcFG=I00000g=j
00<006_k00001UKm00<005Km00000P0000=Fo@00E_d01UKm00<005Km00000P000UKm00<005KmE_d0
0eKm0P0000=oo`00Ool0SGoo001mOol00`00Oomoo`0MOol00`00E_eFo@03E_d00`00E_d000020003
E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@03E_d30006E_d00`00
E_d0000200000eKm001Fo@05E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020003
E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20006E_d01000
E_eFoEKm10001UKm00<005Km00000P000UKm00<005KmE_d015Km00D005KmE_eFo@0000<]^006000]
^2fh;KP0036h0P0013GH00D003Fh=KPe^00000@e^006000e^3Fh=KP003Fh10000SFh00<003Vh>KP0
0SVh00D003Vh>KPi^00000@i^003000if3WH008if004000iecWG>ML400000cgG000me`02?ML00`00
?MLme`03?ML00`00?MLme`02?ML00`00?MLme`02?ML01@00?MLmecgG0000147G00<0047G@ML00T7G
00<0047G@ML00d7G00<0047G@ML00T7G00<0047G@ML00T7G00<0047G@ML00T7G00<004GGAML00dGG
00<004GGAML00TGG00<004GGAML00TGG00<004GgAOL00dGg00<004GfAOH00dGf00<004GfAOH00dGf
00<004WfBOH00TWf00<004WfBOH00dWf00<004WfBOH00dWf00<004WfBOH0100014Wf00<004WfBOH0
14Wf00<004gfCOH00dgf00<004gfCOH00dgf00<004gfCOH00dgf00<004hFCQH00ThF0P001ThF00<0
04hFCQH00dhF00<004hFCQH014hF00<0058FDQH00U8F0P001U8F00<0058FDQH0158F00<0058FDQH0
0e8F00@0058FDQH0009B5P03001B5U8F00EB5P03001F5UHF00AF5P8000EF=P03001F=UHf00AF=P03
001F=UHf009F=P8000IF=P03001F=UHf00EF=P8000EF=P03001J=UXf00EJ=P8000EJ=P03001J=UXf
00EJ=P8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001NEUiF009NEP03001NEP0000MNEP80
00ENEP03001NEUiF00ANEP8000QNMP8000INMP05001NMUifGWH00003HWH00`00HWIRMP020002HWH0
0`00HWH00007HWH00`00HWIRMP05HWH00`00HYIRUP05HYH00`00HYH00006HYH01000HYIRUP001FJF
00@006JFIYH000EVUP04001VUVJF0004IYH01000IYIVUP001FJf00<006Jf00001fJf00<006JfI[H0
1FJf00<006ZfJ[H016Zf00@006ZfJ[H000=Z]P03001ZeV[F009ZeP04001ZeV[F0005J]H00`00J]IZ
eP04J]H01000J]MZe`000f[G00<006[GJ]L00V[G00<006[G00001Fkg00<006kg00000Vkg0P001Fkg
00<006kgK_L00fkg00L006kgK_M^m`00K_L00005K_L00`00KaL00003KaL00`00KaM_5`03KaL00`00
KaM_5`02KaL00`00LaMc5`02LaL00`00LaMc5`02LaL00`00LcMc=`03LcL00`00LcQc>002LcP00`00
LcQc>002LcP20003LcP01@00LcQc>7<h00000W<h00<007<h00000g<h00<007=HLeP00W=H00D007=H
LeQcF00000EcF005001cF7=HLeP00004LeP01@00LgT007=I00000g=j00D006_kJo][n`0000EFo@80
00EFo@03001FoEKm00AFo@8000IFo@03001Fo@0000800005E_d007ooOol0002=Ool007eoo`03001o
ogoo01ioo`04001FoEKmE_d40006E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d000020003
E_d00`00E_eFo@03E_d00`00E_d000020003E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d3
0005E_d00`00E_eFo@03E_d30006E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d000020002
E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@03E_d40004E_d00`00E_eFo@03E_d2
0006E_d00`00E_eFo@03E_d300000eKm000]^002;KP00`00;KP]^002;KP00`00<KPa^0020002=MP0
0`00=KPe^002=KP01@00=KPe^3Fh000013Fh00@003Fh=KPe^0@000@i^003000i^3Vh008i^005000i
^3Vh>KP00004>MP01@00>MLiecWG00000cWG1@0000<me`00?ML00cgG00<003gG?ML00SgG00<003gG
?ML00SgG00<003gG?ML00SgG00<0047G@ML00T7G00D0047G@MM1e`0000E1e`030011ed7G0091e`03
0011ed7G0091e`030011ed7G0091e`030015edGG00=5e`030015edGG0095e`030015edGG00=5e`03
0015mdGg00=5m`030015mTGf0095mP030015mTGf00=5mP030019mTWf0099mP030019mTWf00A9mP03
0019mTWf00D000=9mP030019mTWf00=9mP030019mTWf00=9mP03001=mTgf00==mP03001=mTgf00==
mP03001=mTgf00A=mP@00003COH004hF00E>5P03001>5ThF00A>5P03001>5ThF00=>5P03001B5U8F
00800003DQH0058F00EB5P03001B5U8F00AB5P03001B5U8F00AB5P8000AB5P03001B5U8F00AB5P03
001F5UHF00=F5P8000IF=P03001F=UHf00AF=P07001F=UHfESH005Hf00001eHf00<005HfESH00eHf
0P001UHf00<005XfFSH01EXf00<005XfFSH015Xf00<005XfFSH01EXf00<005YFFUH01EYF00<005YF
FUH00eYF0P001eYF00D005iFGUINEP00009NEP03001NEUiF00ENEP03001NEUiF00ENEP03001NEUiF
009NEP04001NEUiF0007GWH00`00GWINMP05GWH01000GWINMP00169f0`000f9f00@0069fHWH000IR
MP03001RMP0000IRMP03001RUV:F00IRUP03001RUV:F00IRUP8000IVUP03001VUP0000IVUP03001V
UP0000EVUP03001VUP0000MV]P03001V]VJf00IV]P03001V]VJf00AV]P03001Z]P0000EZ]P05001Z
]VZfJ[H00002J[H00`00J]IZeP02J]H00`00J]H00006J]H00`00J]IZeP04J]H01@00J]MZef[G0000
0V[G00<006[GJ]L00f[G00<006kgK_L00fkg00D006kgK_M^m`00009^m`03001^mfkg00=^m`03001^
mfkg00=^m`07001^mfkgK_L006kg00001Fkg00@006lGKaL0009_5`03001_5flG009_5`03001_5`00
009_5`03001c5g<G009c5`03001c5`0000=c5`03001c=g<g009c=`03001c=`00009c>003001c>7<h
009c>006001c>7<h001c>0000g<h00<007<hLcP00W<h00<007<hLcP00W<h00<007=HLeP00W=H00D0
07=HLeQcF00000AcF005001cF000LeP00004LeP01@00LgUcNG=i00000g=j00<006_kJo/00V_k00<0
05KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d00`0000=Fo@00E_d01EKm0P001EKm1000S7oo001m
Ool00`00Oomoo`0OOol30004E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d30006E_d01000
E_eFoEKm10001UKm00<005Km00000P0000=Fo@00E_d01EKm00<005Km00000P000eKm00<005KmE_d0
0eKm00<005Km00000P000eKm00<005KmE_d00eKm0P001EKm00<005KmE_d00eKm0`001EKm00<005Km
E_d00eKm0P001UKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000UKm00<005Km
E_d015Km00<005Km00000P0000=Fo@00;IP00P0012fh00D002fh;KP]^000008a^003000a^00000<0
00<e^005000e^3Fh=KP00004=KP01@00=KPe^3Fh00000SFh1P0013Vh00<003Vh>KP00SVh00D003WH
>MPif00000@ie`05000iecWG>ML00003?ML;00000cgG000me`02?ML00`00?MLme`02?ML00`00@MM1
e`02@ML00`00@MM1e`02@ML00`00@MM1e`03@ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00@MM1
e`02@ML00`00AMM5e`03AML00`00AMM5e`02AML00`00AMM5e`02AML00`00AOM5m`03AOL00`00AOI5
mP02AOH00`00AOI5mP03AOH00`00BOI9mP03BOH00`00BOI9mP060002BOH00`00BOI9mP03BOH00`00
BOI9mP03BOH00`00BOI9mP03BOH00`00COI=mP03COH00`00COI=mP03COH00`00COI=mP03COH20004
COH00`00CQI>5P04CQH00`00CQI>5P04CQH00`00CQI>5P03CQH00`00DQH00003DQH00`00DQIB5P04
DQH00`00DQIB5P04DQH00`00DQIB5P03DQH20005DQH00`00DQIB5P04DQH00`00EQIF5P02EQH00`00
EQH00006ESH00`00ESIF=P04ESH01000ESIF=P000eHf00<005HfESH015Hf00<005HfESH00UHf00<0
05Hf00001eHf00<005XfFSH00eXf0P001eXf00<005XfFSH00eXf0P001eYF00<005YFFUH00UYF00<0
05YF00001eYF00@005iFGUH000=NEP03001NEUiF00ENEP03001NEUiF00ENEP05001NEUiFGUH00003
GUH00`00GWINMP05GWH00`00GWINMP06GWH20002HWH300000f9f001RMP02HWH01@00HWIRMV9f0000
1F9f00@0069fHWH000ERMP03001RMP0000MRUP03001RUV:F00IRUP03001VUVJF00IVUP03001VUVJF
00IVUP03001VUVJF00EVUP03001V]VJf00IV]P03001V]VJf00EV]P03001V]P0000AV]P04001Z]VZf
0004J[H00`00J[IZ]P02J[H00`00J[H00006J]H00`00J]IZeP04J]H00`00J]H00004J]H00`00J]MZ
e`02J]L00`00J]L00006J]L00`00K_M^m`03K_L02@00K_M^mfkg001^m`00K_L00003K_L00`00K_L0
0003K_L00`00K_M^m`03K_L00`00K_M^m`03K_L01`00KaM_5flG001_5`0000A_5`06001_5flG001_
5`001G<G00H007<GLaL007<G0004LcL01P00LcMc=`00LcP000Ac>003001c>7<h009c>003001c>7<h
009c>003001c>7<h009c>005001c>7<hLcP00004LeP01@00LeP007=H000017=H00D007=HLeQcF000
00AcF003001cNG=i009cN@800003LgX006_k00A[n`<000EFo@04001FoEKmE_d50005E_d00`00E_eF
o@0300000eKm001Fo@05E_d00`00Ool0002<Ool007aoo`03001oogoo025oo`03001FoEKm00AFo@03
001Fo@0000800003E_d005Km00EFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@@000AFo@03001F
oEKm00=Fo@8000EFo@03001FoEKm00=Fo@<000IFo@04001FoEKmE_d40006E_d00`00E_d000020000
0eKm001Fo@05E_d00`00E_d000020003E_d00`00E_eFo@03E_d00`00E_d000020002E_d00`00E_eF
o@03E_d20006E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20005E_d00`00;IP]V0020002
;KP01@00;KP]^2fh00000c6h00@0036h<KPa^0D000@e^005000e^3Fh=KP00004=KP01000=KPe^000
0cFh0`000SVh00<003Vh>KP00SVh00<003WH>MP00SWH00D003WG>MLie`0000@ie`05000mecgG?ML0
0005?ML01000?MLmecgG1@0000<me`00?ML00SgG00<0047G@ML00T7G00<0047G@ML00T7G00<0047G
@ML00d7G00<0047G@ML00T7G00<0047G@ML00T7G00<0047G@ML00T7G00<004GGAML00dGG00<004GG
AML00TGG00<004GGAML00TGG00<004GgAOL00dGg00<004GfAOH00TGf00<004GfAOH014Gf00<004Wf
BOH01@000dWf00<004WfBOH00TWf00<004WfBOH014Wf00<004WfBOH00TWf00<004WfBOH014Wf00<0
04gfCOH00dgf00<004gfCOH00dgf00<004gf00000P0000==mP00COH014gf00<004hFCQH014hF00<0
04hFCQH00dhF00<004hFCQH00dhF0P001E8F00<0058FDQH0158F00<0058FDQH00e8F00@0058FDQIB
5P800003DQH0058F00AB5P03001B5U8F00AB5P03001F5UHF0080009F5P03001F=UHf00AF=P03001F
=UHf00EF=P8000AF=P03001F=UHf00AF=P05001F=UHfESH00002ESH00`00ESIF=P05ESH00`00FSIJ
=P02FSH00`00FSH00007FSH00`00FSIJ=P02FSH00`00FSH00007FUH01@00FUIJEUYF00000eYF00<0
05YFFUH01EYF0P001EiF00<005iFGUH00eiF00<005iF00001UiF00@005iFGUH000ANEP03001NMUif
00ANMP03001NMP0000MNMP@000ARMP04001RMV9f0005HWH01@00HWIRMV9f00000f9f00<0069fHWH0
0V9f00@0069fHWH000IRUP03001RUP0000MRUP03001VUVJF00IVUP03001VUVJF00IVUP03001VUVJF
00EVUP03001V]VJf00EV]P03001V]P0000EV]P04001V]VJf0004I[H01@00J[IZ]VZf00000VZf00<0
06ZfJ[H00fZf00<006Zf00001V[F00<006[FJ]H00f[F00@006[FJ]H000=ZeP03001Zef[G00AZe`03
001Zef[G00AZe`03001^e`0000=^m`03001^mfkg00=^m`04001^mfkg0003K_L01000K_M^m`000Vkg
00<006kgK_L00fkg00<006kgK_L00Vkg00<006lGKaL00flG00<006lGKaL00flG00D006lGKaM_5`00
00Ec5`03001c5g<G009c5`03001c=g<g00=c=`05001c=g<gLcL00005LcP00`00LcQc>002LcP01@00
LcQc>7<h000017<h00<007<h00000W<h00D007=HLeQcF00000=cF003001cF7=H009cF003001cF7=H
009cF08000=cF005001cNG=iLgT00002LgT20002Jo/300000eKm001Fo@05E_d40003E_d00`00E_eF
o@04E_d30005E_d00`00E_eFo@03E_d200000goo001oo`2:Ool007aoo`03001oo`000080021oo`03
001FoEKm00=Fo@<000AFo@03001FoEKm00=Fo@<000IFo@03001Fo@000080009Fo@03001FoEKm00AF
o@03001Fo@0000800003E_d005Km00EFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@@000AFo@03
001FoEKm00=Fo@8000EFo@03001FoEKm00=Fo@<000IFo@04001FoEKmE_d30006E_d00`00E_d00002
0002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d0
0`00E_eFo@02E_d01@00;IP]V000;KP00`0012fh00@0036h<KP000<a^004000a^36h<KP30002=KP0
0`00=KPe^002=KP01@00=KPe^3Fh00000cFh00H003Fh=KPe^000=KP40003>KP00`00>MPif002>MP0
1@00>MLiecWG000013WG00<003gG?ML00SgG00<003gG?ML00SgG00<003gG?ML00SgG00@003gG?MLm
e`D00003?ML0047G00=1e`050011ed7G@ML00005@ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00
@MM1e`02@ML00`00AMM5e`03AML00`00AMM5e`02AML00`00AMM5e`02AML00`00AOM5m`04AOL00`00
AOI5mP02AOH00`00AOI5mP060002BOH00`00BOI9mP03BOH00`00BOI9mP03BOH00`00BOI9mP03BOH0
0`00BOI9mP03BOH00`00BOI9mP03BOH00`00COI=mP03COH00`00COI=mP02COH30004COH00`00COI=
mP03COH00`00CQI>5P04CQH00`00CQI>5P03CQH01000CQI>5ThF0P0000=>5P00DQH0158F00<0058F
DQH0158F00<0058FDQH0158F0`000e8F00<0058FDQH0158F00<0058FDQH0158F0P001EHF00<005Hf
ESH015Hf00<005HfESH00eHf0P001EHf00<005HfESH015Hf00@005HfESH000AF=P03001F=UHf00AF
=P05001J=UXfFSH00003FSH00`00FSIJ=P04FSH01@00FSIJ=UXf00000eXf00<005YFFUH015YF00@0
05YFFUH000AJEP03001JEUYF00EJEP03001NEUiF00ANEP03001NEUiF009NEP04001NEUiF0007GUH2
0006GUH00`00GWINMP02GWH01000GWINMP001Eif0`00269f0P001V9f00D0069fHWIRMP0000ARMP05
001RMV9fHWH00003HWH00`00HYIRUP02HYH01000HYIRUP001V:F00<006JF00001VJF00<006JF0000
1VJF00<006JF00001FJF00<006JF00001FJf00@006JfI[H000AV]P03001V]VJf009V]P04001V]VJf
0004J[H01000J[IZ]P001VZf00<006[FJ]H016[F00<006[F000016[F00D006[FJ]IZeP00009ZeP03
001Zef[G00AZe`03001Zef[G00=Ze`05001^efkGK]L00002K_L00`00K_M^m`03K_L01`00K_M^mfkg
001^m`0000=^m`03001^m`0000E^m`03001^m`0000=^m`03001_5flG00=_5`03001_5flG009_5`03
001_5flG009_5`03001c5g<G009c5`03001c5g<G00=c5`03001c=g<g009c=`03001c=g<g009c=`03
001c>7<h009c>003001c>7<h009c>003001c>000009c>005001c>7<hLcP00002LcP00`00LcP00004
LeP01000LeQcF7=H0P000g=H00D007=HLeQcF000009cF003001cF00000=cN@06001cNG=iLgT007NI
0P001EKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005Km
E_d00`0000EFo@00Oomoo`0008Yoo`00O7oo0P0097oo00<005Km00000P000eKm00<005KmE_d00UKm
00<005Km00000P000eKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001EKm00<005KmE_d0
0eKm0`001UKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P0000=Fo@00E_d01EKm
00<005Km00000P000eKm00<005KmE_d00eKm10000eKm00<005KmE_d00eKm0P001UKm00<005KmE_d0
0eKm0P001UKm00@005KmE_eFo@@000IFo@03001FoEKm009Fo@04000]V2fH0003;KP20002;KP01@00
<KPa^36h00000c6h00H0036h<KPa^000<KP30004=KP01@00=KPe^3Fh00000cFh00<003Fh=KP00SFh
00@003Fh=KPe^0@00003>KP003WH008if003000iecWG008ie`05000iecWG>ML00004?ML00`00?MLm
e`03?ML01@00?MLmecgG000013gG00@003gG?MLme`X00003@ML0047G00A1e`030011ed7G0091e`05
0011ed7G@ML00004@ML00`00AMM5e`04AML00`00AMM5e`02AML00`00AMM5e`02AML00`00AOM5m`0;
0003AOH00`00BOI9mP02BOH00`00BOI9mP04BOH00`00BOI9mP02BOH00`00BOI9mP03BOH00`00BOI9
mP03BOH00`00BOI9mP03BOH00`00COI=mP03COH00`00COH0000200000dgf001=mP05COH00`00COI=
mP02COH00`00CQI>5P04CQH00`00CQI>5P04CQH30003CQH00`00DQIB5P03DQH00`00DQIB5P04DQH0
0`00DQIB5P03DQH20006DQH00`00DQIB5P03DQH00`00DQIB5P03DQH20006EQH00`00ESIF=P04ESH0
0`00ESIF=P02ESH00`00ESH00006ESH00`00ESIF=P04ESH20005ESH00`00ESIF=P04ESH01000FSIJ
=P0015Xf00<005XfFSH015Xf00@005XfFSH000AJ=P03001JEUYF00EJEP8000EJEP03001JEUYF00AJ
EP8000MNEP04001NEUiF0003GUH00`00GUINEP05GUH00`00GUINEP05GUH01@00GWINMUif00000eif
00<005ifGWH00`0000=NMP000000269f00<0069fHWH01F9f00@0069fHWH000ERMP04001RMV9f0004
HWH00`00HYIRUP02HYH01000HYIRUP001F:F00@006JFIYH000EVUP04001VUVJF0005IYH01000IYIV
UP0016JF00@006JFIYH000AV]P03001V]VJf009V]P05001V]VJfI[H00004I[H01000I[IV]P0016Zf
00<006Zf00001fZf00<006[FJ]H00f[F00@006[FJ]H000=ZeP03001ZeV[F009ZeP03001ZeP0000IZ
e`03001Ze`0000AZe`07001^efkGK]L006kg00001Fkg00<006kg00000fkg00<006kgK_L00fkg00<0
06kgK_L00fkg00L006kgK_M^m`00K_L00005KaL00`00KaL00003KaL01`00KaM_5flG001c5`0000=c
5`03001c5g<G009c5`03001c=`0000=c=`07001c=g<gLcL007<g00000g<h00D007<hLcQc>000009c
>003001c>00000Ac>005001c>7<hLcP00004LeP01@00LeQcF7=H00000W=H00<007=H00000g=H00<0
07=HLeP00W=H00D007=iLgUcN@0000=cN@03001gVGNI008000EFo@<000EFo@03001FoEKm00=Fo@<0
00EFo@03001FoEKm00=Fo@<000EFo@03001oo`0008Yoo`00O7oo00<007ooOol097oo0P001UKm00<0
05KmE_d010001UKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P0000=Fo@00E_d0
1EKm00<005Km00000P000eKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001EKm00<005Km
E_d00eKm0`001UKm00<005Km00000P0000=Fo@00E_d01EKm00<005Km00000P000UKm00<005KmE_d0
15Km00<005Km00000P000UKm00<005KmE_d00eKm100015Km00<005KmE_d00eKm0`000UKm00@002fH
;IP000<]^003000]^000008000<a^005000a^36h<KP00004<KP01000<KPa^36h1@0013Fh00D003Fh
=KPe^00000<e^005000e^3Fh=KP00003>KP500000cWH000ie`02>ML00`00>MLie`02>ML01@00?MLm
ecgG00001CgG00<003gG?ML00SgG00D003gG?MLme`0000@me`03000mecgG008me`040011ed7G@ML@
00000d7G0011e`03@ML00`00AMM5e`0@0003AMH00`00AOI5mP02AOH00`00AOI5mP03AOH00`00BOI9
mP03BOH00`00BOI9mP03BOH00`00BOI9mP02BOH00`00BOI9mP04BOH00`00BOI9mP02BOH00`00BOI9
mP03BOH00`00COI=mP03COH20004COH00`00COI=mP04COH00`00COI=mP03COH00`00CQI>5P03CQH0
0`00CQI>5P03CQH20006CQH00`00DQIB5P02DQH00`00DQIB5P04DQH01000DQIB5U8F0P0000=B5P00
DQH01E8F00<0058FDQH00e8F00<0058FDQH00U8F00<0058F00001UHF00<005HfESH015Hf00D005Hf
ESIF=P00009F=P03001F=UHf00AF=P03001F=UHf00AF=P03001F=UHf00AF=P03001F=UHf00EF=P80
00EJ=P03001J=UXf00EJ=P8000EJ=P03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000MNEP04001NEUiF0004GUH00`00GUINEP04GUH00`00GUINEP05GUH01000GWINMP0015if
0`000eif00@005ifGWH000MRMP03001RMV9f00IRMP8000IRMP04001RMV9f0004HWH01@00HYIRUV:F
000016:F00D006:FHYIRUP0000=VUP03001VUVJF009VUP05001VUVJFIYH00004IYH01@00IYIVUVJF
000016JF00D006JFIYIVUP0000=V]P03001V]VJf009V]P04001V]VJf0005I[H00`00I[H00006J[H0
0`00J[IZ]P05J[H20005J]H01@00J]IZeV[F00000V[F00<006[FJ]H00f[F00<006[GJ]L016[G00@0
06[GJ]L000=Ze`03001^efkG00=^e`03001^mfkg00A^m`03001^m`0000=^m`8000A^m`03001^mfkg
00=^m`07001^mfkgK_L006kg000016lG00L006lGKaM_5`00KaL00004KaL01P00LaMc5`00LaL000Ec
5`06001c=g<g001c=`000g<g00L007<gLcMc=`00LcP00003LcP00`00LcQc>002LcP00`00LcQc>002
LcP00`00LcQc>002LcP20003LeP01000LeQcF00017=H00<007=HLeP00W=H00<007=HLeP00W=H00D0
07=iLgUcN@00009cN@04001gVGNI0002MeL00`00E_d0000200000eKm001Fo@05E_d00`00E_eFo@03
00000eKm001Fo@05E_d00`00E_eFo@0300000eKm001Fo@05E_d200000goo001oo`28Ool007aoo`03
001oogoo02Ioo`03001FoEKm00=Fo@<000AFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@80
00EFo@03001FoEKm00=Fo@<000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080
0003E_d005Km00EFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@8000EFo@03001FoEKm00=Fo@80
00IFo@03001FoEKm00=Fo@8000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080
0003E_d002fH00<000<]V005000]^2fh;KP00003;KP20002<KP01@00<KPa^36h00000c6h00D0036h
<KPa^00000<e^0<0008e^005000e^3Fh=KP00003=KP00`00=KPe^002=KP01@00>KPi^3Vh00000cVg
0`000SWG00<003WG>ML00SWG00<003gG?ML00SgG00<003gG?ML00SgG00<003gG?ML00SgG00<003gG
?ML00SgG00<003gG?ML00SgG00D003gG?MLme`0000A1e`030011ed7G00=1e`030011ed7G0091e`04
0011ed7G@ML90003@ML00`00AMM5e`02AML00`00AMI5eP02AMH00`00AMI5eP03AMH00`00AOI5mP02
AOH00`00AOI5mP04AOH00`00BOI9mP02BOH00`00BOI9mP03BOH00`00BOI9mP03BOH00`00BOI9mP03
BOH00`00BOI9mP02BOH00`00BOI9mP04BOH00`00COH0000200000dgf001=mP04COH00`00COI=mP03
COH00`00COI=mP03COH00`00CQI>5P04CQH00`00CQH0000200000dhF001>5P05CQH00`00DQIB5P03
DQH00`00DQIB5P04DQH30003DQH00`00DQIB5P04DQH00`00DQIB5P03DQH00`00DQIB5P020002DQH0
0`00EQIF5P04EQH00`00ESIF=P04ESH01000ESIF=P0015Hf00<005HfESH00eHf00<005HfESH00eHf
0P001eHf00<005HfESH00eHf0P001eXf00<005XfFSH00eXf0P001eXf00<005YFFUH00eYF0P001eYF
00D005YFFUIJEP0000=JEP03001NEUiF00ANEP03001NEP0000ENEP03001NEUiF00=NEP03001NEP00
00MNEP80009NMP<00003GWH005if009NMP05001NMUifGWH00006HWH20008HWH00`00HWIRMP06HWH2
0006HWH01000HYIRUP0016:F00D006:FHYIRUP0000AVUP05001VUVJFIYH00004IYH01@00IYIVUVJF
000016JF00@006JFIYH000AVUP04001V]VJf0005I[H00`00I[H00007I[H00`00J[IZ]P05J[H00`00
J[IZ]P04J[H01000J[IZ]P000f[F00<006[FJ]H00V[F00<006[F00001V[F00<006[GJ]L016[G00D0
06[GJ]MZe`00009Ze`03001^efkG00=^e`03001^mfkg00=^m`09001^mfkgK_L006kg001^m`0000=^
m`03001^m`0000=^m`03001^mfkg00=^m`03001_5flG00=_5`03001_5flG009_5`03001_5flG009_
5`07001c5g<GLaL007<G000017<G00<007<gLcL00W<g00<007<gLcL00W<g00<007<gLcL00W<g00<0
07<hLcP00W<h00<007<hLcP00W<h0P000g<h00D007<hLcQc>000009cF003001cF00000=cF003001c
F7=H009cF005001cF7=HLeP00004LeP01@00LgP007=i00000W=i00@007NIMiT000AgE`03001FoEKm
00=Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm00=Fo@<000EFo@03001FoEKm00<00005E_d007oo
Ool00028Ool007aoo`03001oogoo02Moo`03001Fo@0000800003E_d005Km00EFo@03001Fo@000080
009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm00=Fo@03001Fo@00008000=Fo@03
001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000EFo@03001FoEKm00=Fo@<000IFo@03001Fo@00
00800003E_d005Km00EFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03
001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000EFo@04000]V2fH;IP200000bfH000]^002;KP0
1P00;KP]^2fh000a^0<000<a^005000a^36h<KP00004<KP01P00=KPe^3Fh000e^0<000<e^003000e
^3Fh008e^005000e^3Fh=KP00004>KP01P00>KLi]cVg000i]`@000<ie`03000mecgG008me`03000m
ecgG00<me`05000mecgG?ML00004?ML00`00?MLme`02?ML00`00?MLme`02?ML01@00@MM1ed7G0000
1D7G00<0047G@ML00T7G00<0047G@ML00T7G00<0047G@ML00T7G00<0047G@ML00d7G00<004GGAML0
0TGG00<004GFAMH00TGF00<004GFAMH014GF00<004GfAOH00TGf00<004GfAOH00dGf00<004WfBOH0
0TWf00<004WfBOH014Wf00<004WfBOH00TWf00<004WfBOH00dWf00<004WfBOH00dWf00<004WfBOH0
1@0014gf00<004gfCOH00dgf00<004gfCOH014gf00<004gfCOH00Tgf00<004hFCQH00dhF0`0014hF
00<004hFCQH014hF00<0058FDQH00e8F00<0058FDQH00e8F0P001U8F00<0058FDQH0158F00<0058F
DQH00e8F0P001E8F00<005HFEQH015HF00<005HfESH015Hf0P001EHf00<005HfESH015Hf00D005Hf
ESIF=P00009F=P03001F=UHf00AF=P03001F=UHf009F=P03001J=P0000MJ=P03001J=UXf009J=P03
001J=P0000MJ=P03001JEUYF009JEP03001JEP0000MJEP04001JEUYF0004FUH00`00GUINEP05GUH0
0`00GUINEP04GUH00`00GUINEP02GUH01000GUINEP001eiF100015if00@005ifGWH000ANMP03001R
MV9f00=RMP04001RMV9f0007HWH00`00HWIRMP06HWH00`00HWIRMP05HWH00`00HYH00005HYH01000
HYIRUP001FJF00@006JFIYH000EVUP04001VUVJF0005IYH01000IYIVUP0016JF00<006Jf00001fJf
00<006JfI[H01VJf00<006ZfJ[H016Zf00<006Zf00001FZf00@006ZfJ[H0009ZeP03001ZeV[F00AZ
eP03001ZeV[F00AZeP03001ZeP0000AZe`03001Zef[G009Ze`03001Ze`0000E^e`03001^m`0000=^
m`03001^mfkg009^m`03001^m`00009^m`04001^mfkg0002K_L01000K_M^m`001Fkg00<006lGKaL0
0VlG00<006lGKaL00flG00D006lGKaM_5`0000Ec5`03001c5g<G009c5`03001c=g<g00=c=`05001c
=g<gLcL00005LcL01@00LcQc>7<h000017<h00H007<hLcP007<h0003LcP00`00LeQcF002LeP01@00
LeQcF7=H000017=H00<007=H00000W=H00D007=HLeQcF00000=cN005001cNG=iLgT00002MiT00`00
MeMgE`02MeL00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@03E_d00`00E_eFo@030000
0eKm001Fo@05E_d30005E_d00`00Ool00028Ool007]oo`03001oogoo02Uoo`03001FoEKm00=Fo@03
001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@04001FoEKmE_d40006E_d00`00E_d00002
0002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@03E_d00`00E_d000020003E_d0
0`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@03E_d20006E_d00`00E_d0
00020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@02E_d01P00;IP]V2fH000]
V08000<]^003000]^2fh008]^004000a^36h<KP40004<KP01@00<KPa^36h000013Fh00@003Fh=KPe
^080008e^005000e^3Fh=KP00003=KP00`00>KPi^002>KP00`00>KLi]`02>KL01000>KLi]cVg1000
00<ie`00?ML00SgG00<003gG?ML00cgG00<003gG?ML00SgG00D003gG?MLme`0000@me`03000mecgG
008me`030011ed7G0091e`030011ed7G00=1e`030011ed7G0091e`050011ed7G@ML00004@ML00`00
@MM1e`04@ML00`00AMM5e`02AML00`00AMI5eP02AMH00`00AMI5eP03AMH00`00AOI5mP02AOH00`00
AOI5mP03AOH00`00BOI9mP03BOH00`00BOI9mP03BOH00`00BOI9mP02BOH00`00BOI9mP03BOH00`00
BOI9mP02BOH40003BOH00`00COI=mP04COH00`00COI=mP02COH00`00COI=mP04COH00`00COI=mP02
COH01000CQI>5ThF0P0000==mP00CQH01DhF00<004hFCQH00dhF00<0058FDQH00e8F00<0058FDQH0
0U8F00<0058F00001U8F00<0058FDQH0158F00<0058FDQH00U8F0P001U8F00<005HFEQH015HF00<0
05HfESH00eHf0P001UHf00<005HfESH015Hf00@005HfESH000=F=P03001F=UHf00AF=P05001F=UHf
ESH00002FSH00`00FSIJ=P05FSH01@00FSIJ=UXf00000UXf00<005XfFSH01EXf00D005YFFUIJEP00
00=JEP03001JEUYF00EJEP8000EJEP03001NEUiF00ENEP03001NEUiF00ENEP04001NEUiF0003GUH0
0`00GUINEP04GUH20008GWH20006GWH01@00HWIRMV9f00000f9f00<0069fHWH0169f00<0069f0000
1f9f00<0069fHWH01V9f00<006:FHYH01F:F0P001VJF00<006JF00001VJF00<006JF00001VJF00<0
06JF00001VJF00<006JfI[H01VJf00<006JfI[H01FJf0P001FZf00@006ZfJ[H000AZ]P05001Z]VZf
J[H00002J]H00`00J]IZeP04J]H00`00J]IZeP04J]H00`00J]H00003J]L00`00J]MZe`04J]L00`00
K]M^e`03K]L01000K_M^m`000fkg00<006kgK_L00fkg00<006kgK_L00Vkg0P000fkg00<006kg0000
1Fkg00<006lG00000flG00<006lGKaL00VlG00<006lG00000VlG00<007<GLaL00g<G00<007<GLaL0
0W<G00<007<gLcL00W<g00<007<g00000W<g00<007<gLcL00W<g00D007<g001c>00000Ac>003001c
>7<h009c>005001c>7<hLcP00005LeP01@00LeQcF7=H00000g=H00H007=HLeP007=H0003LeP00`00
LgQcN002LgP200001G=i001gVGNI000017MG00<007=H00001EKm0P001UKm00@005KmE_eFo@@000EF
o@03001FoEKm00<00003E_d005Km00EFo@04001oogoo0027Ool007]oo`03001oogoo02Uoo`03001F
oEKm00AFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm00=F
o@@000AFo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IFo@04001FoEKmE_d40006E_d0
0`00E_d0000200000eKm001Fo@05E_d00`00E_d000020003E_d00`00E_eFo@03E_d00`00E_d00002
0002E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d30005E_d01@00E_eFoEKm000012fH00<0
02fH;IP00P000Rfh00D002fh;KP]^00000<a^003000a^36h00<0008a^005000a^36h<KP00004=KP0
1P00=KPe^3Fh000e^0<000<e^003000e^3Fh008e^005000i^3Vh>KP00004>KL01@00>KLi]cVg0000
0cVg1@0000<me`00?ML00cgG00<003gG?ML00SgG00<003gG?ML00SgG00<003gG?ML00SgG00D003gG
?MLme`0000A1e`030011ed7G00=1e`030011ed7G0091e`030011ed7G0091e`030011ed7G0091e`03
0011ed7G00=1e`030015edGG0095e`030015eTGF0095eP030015eTGF00=5eP030015mTGf0095mP03
0015mTGf00A5mP030019mTWf0099mP030019mTWf00=9mP030019mTWf0099mP030019mTWf00A9mP@0
0003BOH004Wf00A9mP03001=mTgf00A=mP03001=mTgf00==mP03001=mTgf00==mP03001=mTgf00==
mP<000==mP03001>5ThF00A>5P03001>5ThF00A>5P03001B5U8F009B5P03001B5U8F0080009B5P03
001B5U8F00AB5P03001B5U8F00AB5P07001B5U8FDQH0058F00001U8F00<005HFEQH015HF00<005Hf
ESH00UHf00<005HF00001eHf00<005HfESH00eHf00<005Hf000015Hf00<005HfESH015Hf00@005Hf
ESH000AJ=P03001J=UXf00AJ=P04001J=UXf0004FSH00`00FSIJ=P04FSH01000FUIJEP0015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005iFGUH00eiF0P001eiF00@005iFGUH000ANEP03001NEUiF
00@00003GUH005if00INMP03001NMUif00ENMP05001RMV9fHWH00003HWH00`00HWIRMP03HWH01000
HWIRMP001V9f00<0069f00001f9f00<006:FHYH01F:F00<006JFIYH01VJF00<006JFIYH01VJF00<0
06JFIYH01VJF00<006JFIYH01FJF00<006JfI[H01FJf00<006Jf00001FJf00@006ZfJ[H000=Z]P03
001Z]VZf009Z]P04001Z]VZf0005J[H20006J]H00`00J]H00004J]H01@00J]IZeV[F00000V[G00<0
06[GJ]L016[G00<006kGK]L00fkG00L006kgK_M^m`00K_L00006K_L00`00K_M^m`02K_L00`00K_M^
m`03K_L00`00K_M^m`03K_L01`00KaM_5flG001_5`0000A_5`06001_5flG001_5`001G<G00<007<G
00000W<G00<007<gLcL00W<g00H007<gLcL007<g0004LcL01@00LcMc=g<g00001G<h00<007<hLcP0
0W<h00D007<hLcQc>00000AcF005001cF000LeP00003LeP00`00LeQcF002LeP01@00LeQcF7=H0000
17=h00@007=iLgT000=gV@05001gEgMGMeL00002LeP00`00E_eFo@0300000eKm001Fo@05E_d40003
E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@03E_d20002Ool00`00Oomoo`24Ool007]oo`03001o
ogoo02Yoo`03001FoEKm00=Fo@<000EFo@03001FoEKm00=Fo@<000EFo@03001Fo@000080009Fo@03
001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm
00=Fo@@000AFo@03001FoEKm00=Fo@8000EFo@03001FoEKm00=Fo@<000IFo@04001FoEKmE_d30006
E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020003E_d00`00E_eFo@03E_d01@00
E_eFoEKm00000bfH00D002fH;IP002fH00<000<]^003000a^36h008a^005000a^36h000a^0030004
<KP01@00=KPe^3Fh000013Fh00@003Fh=KPe^0<00003=KP003Fh008e^003000i^3Vh008i^005000i
]cVg>KL00004>KL01@00>KLi]cVg00000cVg1@000SgG00D003gG?MLme`0000@me`03000mecgG008m
e`03000mecgG008me`050011ed7G@ML00005@ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00@MM1
e`02@ML00`00@MM1e`03@ML00`00AMM5e`02AML00`00AMI5eP02AMH00`00AMI5eP04AMH00`00AOI5
mP02AOH00`00AOI5mP03AOH00`00BOI9mP02BOH00`00BOI9mP03BOH00`00BOI9mP03BOH00`00BOI9
mP040004BOH00`00BOI9mP04BOH00`00COI=mP03COH00`00COI=mP03COH00`00COI=mP03COH00`00
COI=mP02COH20006COH00`00CQI>5P03CQH00`00CQI>5P04CQH00`00DQIB5P03DQH20005DQH00`00
DQIB5P03DQH00`00DQIB5P04DQH01000DQIB5P000e8F00<0058FDQH00e8F00<005HFEQH015HF00<0
05HfESH00P000UHF00<005HfESH01EHf00<005HfESH00eHf0P001UHf00<005HfESH015Hf0P001EXf
00<005XfFSH01EXf0P001EXf00<005XfFSH01EXf0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005iFGUH00UiF00@005iFGUH000INEP03001NEP0000ENEP<0009NEP04001NEUiF0007GWH00`00
GWINMP05GWH01000HWIRMP001F9f00D0069fHWIRMP0000=RMP03001RMV9f00=RMP04001RMV9f0006
HWH00`00HWH00006HYH00`00IYIVUP06IYH00`00IYIVUP06IYH00`00IYIVUP06IYH00`00IYIVUP04
IYH00`00I[H00005I[H01000I[IV]P001FJf00@006ZfJ[H000=Z]P03001Z]VZf009Z]P04001Z]VZf
0005J[H00`00J]IZeP04J]H01000J]IZeP000f[F00<006[FJ]H00V[F00<006[G00001V[G00<006kG
00000fkG00<006kgK_L00Vkg00<006kg00001Fkg00<006kg00000fkg0P0016kg00<006kgK_L00Vkg
00<006lGKaL00flG00<006lGKaL00flG00H006lGKaL006lG0004LaL01`00LaMc5g<G001c5`0000Ac
=`05001c=g<gLcL00005LcL01@00LcMc=g<g000017<h00<007<hLcP00W<h00D007=H001c>00000Ac
F005001cF7=HLeP00004LeP00`00LeQcF002LeP200000g=H001cN003LgP01000LgUcNG=i0P0000=g
V@00MeL00gMG00@007=HLeQcF08000EFo@03001FoEKm00<00003E_d005Km00EFo@03001Fo@000080
0003E_d005Km00EFo@03001FoEKm00<00005E_d007ooOol00026Ool007]oo`03001oogoo02]oo`03
001Fo@00008000=Fo@03001FoEKm00=Fo@03001Fo@00008000=Fo@03001FoEKm009Fo@8000IFo@03
001FoEKm00=Fo@<000EFo@03001FoEKm00=Fo@8000IFo@03001Fo@000080009Fo@03001FoEKm00AF
o@03001Fo@0000800003E_d005Km00EFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@@000=Fo@03
001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000MFo@04001FoEKmE_d400000eKm000]V002;IP0
1@00;IP]V2fH00000RfH00<002fh;KP00Rfh00D0036h<KPa^00000<a^004000a^36h<KP20002<KP0
0`00=KPe^002=KP01@00=KPe^3Fh00000cFh00<003Fh=KP00`000SFh00<003Vh>KP00SVh00<003Vg
>KL00SVg00D003Vg>KLi]`0000@i]`05000i]cVg>KL00003?KL600000cgG000me`02?ML00`00?MLm
e`02?ML00`00?MLme`02?ML00`00@MM1e`02@ML00`00@MM1e`03@ML00`00@MM1e`02@ML01@00@MM1
ed7G0000147G00<0047G@ML0147G00<004GGAML00TGG00<004GFAMH00TGF00<004GFAMH00dGF00<0
04GfAOH00TGf00<004GfAOH00dGf00<004WfBOH00TWf00<004WfBOH014Wf00<004WfBOH01@000dWf
00<004WfBOH00dWf00<004WfBOH00dWf00<004gfCOH014gf00<004gfCOH00Tgf00<004gfCOH014gf
100000==mP00COH01Dgf00<004hFCQH014hF00<004hFCQH00dhF00<0058FDQH00U8F0P001U8F00<0
058FDQH0158F00<0058FDQH0158F0P00158F00<0058FDQH0158F00<005HFEQH015HF0P001EHF00<0
05HfESH015Hf00<005HfESH00UHf00<005Hf00001UHf00<005HfESH015Hf00<005XfFSH015Xf00<0
05XfFSH01EXf00<005XfFSH015Xf00<005XfFSH01EXf00<005YFFUH01EYF00<005YFFUH00eYF0P00
1eYF00D005iFGUINEP0000=NEP03001NEUiF00ENEP04001NEUiFGUH300001EiF001NEUiF00000eiF
00<005ifGWH015if0P0025if0P001V9f00D0069fHWIRMP0000ARMP05001RMV9fHWH00003HWH00`00
HWIRMP03HWH01000HWIRMP001F:F00<006:F00001VJF00<006JF00001VJF00<006JF00001VJF00<0
06JF00001FJF00<006Jf00001FJf00@006JfI[H000AV]P05001Z]VZfJ[H00002J[H00`00J[IZ]P03
J[H00`00J[H00006J[H00`00J]IZeP04J]H01@00J]IZeV[F00000V[F00<006[FJ]H00f[F00<006[G
J]L016[G00@006kGK]L0009^e`03001^mfkg00A^m`03001^mfkg00=^m`07001^mfkgK_L006kg0000
0Vkg00H006kgK_L006kg0003K_L00`00KaM_5`03KaL00`00KaM_5`02KaL00`00KaM_5`02KaL00`00
LaMc5`03LaL00`00LaMc5`02LaL00`00LcMc=`02LcL00`00LcMc=`02LcL00`00LcMc=`02LcL01`00
LcMc=g<g001c>00000=c>005001c>7<hLcP00003LeP00`00LeQcF002LeP00`00LeQcF002LeP01@00
LeQcF7=H000017=H00@007=HLeP000AcN005001cNG=iLgT00002MgT00`00MeMgE`02MeL00`00LeQc
F002LeP00`00E_eFo@04E_d30005E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d30005E_d0
1000Oomoo`00QGoo001kOol00`00Oomoo`0/Ool20006E_d01000E_eFoEKm10001UKm00@005Km0000
009Fo@03001FoEKm00AFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@03001Fo@000080009Fo@03
001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000EFo@03001FoEKm00=Fo@<000IFo@03001Fo@00
00800003E_d005Km00EFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03
001FoEKm00AFo@@0009Fo@04000YV0000004;IP01000;IP]V0000bfH0P000Rfh00D0036h<KPa^000
00<a^006000a^36h<KP0036h0`0013Fh00D003Fh=KPe^00000@e^005000e^3Fh000e^0040003>KP0
0`00>KLi]`02>KL01@00>KLi]cVg000013Vg00<003Vg>KL00SVg00<003fg?KL00Sfg00@003gG?MLm
e`D00003?ML003gG00<me`05000mecgG?ML00004@ML00`00@MM1e`03@ML00`00@MM1e`02@ML00`00
@MM1e`02@ML00`00@MM1e`02@ML00`00@MM1e`03@ML00`00AMM5e`02AML00`00AMI5eP02AMH00`00
AMI5eP03AMH00`00AOI5mP02AOH00`00AOI5mP03AOH00`00BOI9mP03BOH00`00BOI9mP060002BOH0
0`00BOI9mP03BOH00`00BOI9mP03BOH00`00BOI9mP03BOH00`00COI=mP04COH00`00COI=mP02COH0
0`00COI=mP03COH20005COH00`00COI=mP03COH00`00CQI>5P04CQH00`00CQI>5P03CQH00`00DQIB
5P0200000e8F001B5P05DQH00`00DQIB5P04DQH00`00DQIB5P03DQH20005DQH00`00DQIB5P04DQH0
0`00EQIF5P03EQH20006EQH00`00ESIF=P04ESH00`00ESIF=P020002ESH00`00ESIF=P04ESH00`00
ESIF=P03ESH20007FSH00`00FSIJ=P03FSH20007FSH00`00FSIJ=P03FSH20007FUH00`00FUIJEP02
FUH01000FUIJEP001UYF00@005iFGUH000ANEP03001NEUiF00ENEP@000ANEP04001NEUiF0004GUH0
0`00GWINMP02GWH01000GWINMP001eif00<0069fHWH01F9f00@0069fHWH000ERMP05001RMV9fHWH0
0004HWH01@00HWIRMV9f00000f9f00<006:FHYH00V:F00@006:FHYH000EVUP04001VUVJF0005IYH0
1000IYIVUP001FJF00@006JFIYH000AVUP04001V]VJf0004I[H00`00I[IV]P02I[H01000I[IV]P00
1FZf0P001fZf00<006ZfJ[H016Zf00<006[F000016[F00<006[FJ]H00V[F00<006[F00001V[F00<0
06[GJ]L016[G00@006kGK]L0009^e`03001^mfkg00A^m`03001^mfkg009^m`03001^mfkg009^m`03
001^m`0000=^m`80009^m`04001^mfkg0005KaL00`00KaL00002KaL00`00KaM_5`03KaL00`00LaMc
5`02LaL00`00LaMc5`03LaL01@00LcMc=g<g000017<g00<007<g00000g<g00D007<gLcMc=`00009c
>003001c>00000=c>003001cF7=H009cF003001cF7=H009cF009001cF7=HLeP007=H001cF00000Ac
F004001cF7=HLeP20003LgP01000LgUcN@000gMi0P000gMG00L007=HLeQcF000LgT00002E_d30000
0eKm001Fo@05E_d00`00E_eFo@0300000eKm001Fo@05E_d00`00E_d000020002E_d00`00E_eFo@03
E_d20002Ool00`00Oomoo`22Ool007]oo`04001oo`00000]Ool00`00E_eFo@03E_d40004E_d00`00
E_eFo@03E_d20005E_d00`00E_eFo@03E_d30006E_d01000E_eFoEKm0`001UKm00<005Km00000P00
0UKm00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d00eKm00<005Km00000P000eKm00<0
05KmE_d00eKm0P001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d00eKm0P001UKm00<005KmE_d0
0`0000=Fo@00E_d015Km00<002VH:IP00P000RfH00D002fH;IP]V000008]V003000]^000008000@a
^004000a^36h0004<KP01000<KPa^36h0P000SFh00<003Fh=KP00SFh00D003Fh=KPe^00000<e^004
000e^3Fh=KP400000cVh000i]`02>KL00`00>KLi]`02>KL01@00>KLi]cVg000013Vg00<003fg?KL0
0cfg00D003gG?MLme`0000<me`X00003?ML0047G0091e`030011ed7G00=1e`030011ed7G0091e`03
0011ed7G0091e`030011ed7G0091e`030011ed7G00=1e`030015edGG0095e`030015eTGF0095eP03
0015eTGF00=5eP030015mTGf0095mP030015mTGf00A5mP030019mTWf00D000=9mP030019mTWf0099
mP030019mTWf00A9mP030019mTWf0099mP030019mTWf00A9mP03001=mTgf00==mP03001=mTgf00==
mP03001=mP0000800003COH004gf00A=mP03001=mTgf00==mP03001>5ThF00A>5P03001>5ThF00A>
5P8000=B5P03001B5U8F00AB5P03001B5U8F00AB5P03001B5U8F009B5P03001B5P0000IB5P03001B
5U8F00=B5P03001F5UHF009F5P03001F5P0000IF5P03001F=UHf00EF=P8000EF=P03001F=UHf00AF
=P05001F=UHfESH00002ESH00`00FSIJ=P04FSH00`00FSIJ=P02FSH00`00FSH00007FSH00`00FSIJ
=P02FSH00`00FSH00007FUH01@00FUIJEUYF00000eYF00<005YFFUH01EYF0P001UiF00<005iFGUH0
0UiF0`001eiF00<005iF00001EiF00<005ifGWH00Uif00@005ifGWH000MNMP03001RMV9f00IRMP80
00IRMP04001RMV9f0005HWH01@00HWIRMV9f0000169f00D006:FHYIRUP00009RUP03001VUVJF00=V
UP04001VUVJF0005IYH01000IYIVUP0016JF00D006JFIYIVUP0000=VUP03001V]VJf009V]P04001V
]VJf0005I[H01000I[IV]P001FZf00<006ZfJ[H01VZf00<006ZfJ[H00fZf00@006[FJ]H000=ZeP03
001ZeV[F00=ZeP03001ZeP0000EZeP03001ZeP0000AZe`03001^efkG009^e`8000I^m`03001^m`00
00=^m`03001^mfkg00=^m`03001^mfkg009^m`80009^m`03001^m`0000E_5`04001_5flG0002KaL0
0`00KaM_5`02KaL00`00LaL00003LaL00`00LaMc5`02LaL00`00LcL00002LcL00`00LcMc=`02LcL0
1P00LcMc=`00LcL000=c=`03001c>7<h009c>003001c>7<h009c>007001cF7=HLeP007=H00000W=H
00D007=HLeQcF00000=cF003001cF7=H009cF005001cF7=HLeP00002LgP00`00LgP00003LgT01000
MgUgN@000WMh00<007MG00000g=H00@007=iLgUcN@8000EFo@03001FoEKm00=Fo@<000EFo@04001F
oEKmE_d40006E_d00`00E_d0000200001EKm001oogoo0000Q7oo001kOol2000`Ool00`00E_d00002
0002E_d00`00E_eFo@04E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d000020003E_d00`00
E_eFo@03E_d40003E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20006E_d01000E_eFoEKm
10001UKm00<005Km00000P0000=Fo@00E_d01EKm00<005Km00000P000eKm00<005KmE_d00eKm00<0
05Km00000P000UKm00<005KmE_d00eKm0`001EKm00<005KmE_d00UKm00D002VH:IP002VH00<000<]
V005000]V2fH;IP00003;KP20002<KP01@00<KPa^36h00000c6h00H0036h<KPa^000<KP40003=KP0
1@00=KPe^3Fh00000cFh00D003Fh=KPe^00000<e^0D00003>KL003Vg008i]`03000i]cVg008i]`05
000i]cVg>KL00005?KL00`00?MLme`02?ML01@00?MLmecgG000013gG00@003gG?MLme`D00003@ML0
047G00A1e`050011ed7G@ML00004@ML00`00@MM1e`02@ML00`00@MM1e`03@ML00`00AMM5e`02AML0
0`00AMI5eP02AMH00`00AMI5eP04AMH00`00AOI5mP02AOH00`00AOI5mP060002AOH00`00BOI9mP03
BOH00`00BOI9mP03BOH00`00BOI9mP03BOH00`00BOI9mP02BOH00`00BOI9mP04BOH00`00COI=mP03
COH00`00COI=mP02COH30004COH00`00COI=mP03COH00`00COI=mP04COH00`00CQI>5P03CQH00`00
CQI>5P03CQH20005DQH00`00DQIB5P04DQH00`00DQIB5P03DQH00`00DQIB5P020002DQH00`00DQIB
5P04DQH00`00DQIB5P03DQH00`00EQIF5P020002EQH00`00EQIF5P05EQH00`00ESIF=P03ESH20006
ESH00`00ESIF=P04ESH01000ESIF=P000eHf00<005XfFSH015Xf00D005XfFSIJ=P0000=J=P03001J
=UXf00AJ=P05001J=UXfFSH00003FSH00`00FUIJEP04FUH01000FUIJEP0015YF00<005YFFUH01EYF
00<005iFGUH01EiF00<005iF00000`000UiF00<005iFGUH01EiF00<005iFGUH01EiF00@005ifGWH0
00=NMP03001NMUif00ANMP03001RMP0000MRMP03001RMV9f00IRMP8000IRMP04001RMV9f0005HWH0
1000HYIRUP0016:F00D006JFIYIVUP0000AVUP05001VUVJFIYH00004IYH01@00IYIVUVJF000016JF
00@006JFIYH000AV]P04001V]VJf0005I[H00`00I[H00006J[H00`00J[IZ]P05J[H00`00J[H00004
J[H01@00J]IZeV[F00000V[F00<006[FJ]H016[F00<006[FJ]H016[F00<006[F00000f[G00<006kG
K]L00fkG00<006kgK_L016kg00@006kgK_L0009^m`03001^mfkg00A^m`03001^mfkg009^m`8000=^
m`03001_5flG00A_5`06001_5flG001_5`0016lG00L007<GLaMc5`00LaL00004LaL01P00LcMc=`00
LcL000Ac=`03001c=g<g009c=`05001c=g<gLcL00005LcP01@00LcQc>7<h000017=H00D007=H001c
F00000AcF004001cF7=HLeP20003LeP01000LeQcF00017=h00D007=iLgUcN@00009gN@03001gN7Mh
009gN005001cF7=HLeP00004LgT00`00E_eFo@04E_d00`00E_eFo@0300000eKm001Fo@05E_d40003
E_d00`00E_eFo@04E_d20005E_d01000Oomoo`00Pgoo001jOol00`00Oomoo`0aOol00`00E_eFo@04
E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d30006E_d00`00E_d0000200000eKm001Fo@05
E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@03E_d40004
E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d30006E_d01000E_eFoEKm0`001UKm00<005Km
00000P000UKm00<005KmE_d015Km00<005KmE_d00UKm00@002VH:IP000<YV080008]V004000]V2fH
0003;KP00`00;KP000020003<KP01@00<KPa^36h0000136h00@0036h<KPa^0D000@e^004000e^3Fh
0004=KP01@00=KPe^3Fh00000cVg0`000SVg00<003Vg>KL00SVg00<003Vg>KL00SVg00<003fg?KL0
0Sfg00<003gG?ML00SgG00<003gG?ML00SgG00D003gG?MLme`0000@me`04000mecgG?ML;00000d7G
0011e`03@ML00`00@MM1e`02@ML00`00@MM1e`03@ML00`00AMM5e`02AML00`00AMI5eP02AMH00`00
AMI5eP0;0003AOH00`00AOI5mP02AOH00`00BOI9mP04BOH00`00BOI9mP02BOH00`00BOI9mP03BOH0
0`00BOI9mP03BOH00`00BOI9mP03BOH00`00COI=mP04COH400000dgf001=mP05COH00`00COI=mP03
COH00`00COI=mP03COH00`00CQI>5P04CQH00`00CQH0000200000dhF001B5P04DQH00`00DQIB5P04
DQH00`00DQIB5P04DQH20005DQH00`00DQIB5P03DQH00`00DQIB5P04DQH20005EQH00`00EQIF5P04
EQH00`00ESIF=P02ESH00`00ESH00006ESH00`00ESIF=P04ESH00`00ESH00004ESH00`00FSIJ=P04
FSH01000FSIJ=P0015Xf00<005XfFSH015Xf00@005XfFSH000AJ=P03001JEUYF00EJEP8000IJEP03
001JEUYF00=JEP8000INEP<0009NEP05001NEUiFGUH00007GUH00`00GUINEP05GUH01000GWINMP00
15if00<005ifGWH00Uif00@0069fHWH000MRMP03001RMV9f00IRMP03001RMV9f00IRMP8000IRMP04
001RUV:F0004HYH01000IYIVUP001FJF00@006JFIYH000EVUP04001VUVJF0005IYH00`00IYH00005
I[H00`00I[H00007I[H00`00J[IZ]P04J[H00`00J[H00005J[H01000J[IZ]P000fZf00<006[FJ]H0
0V[F00<006[F00001f[F00<006[FJ]H00f[F00D006[FJ]IZeP00009Ze`03001^efkG00=^e`03001^
mfkg00A^m`06001^mfkg001^m`001Vkg00<006kg00000Vkg00@006kgK_L0009^m`03001_5flG00=_
5`03001_5flG009_5`03001_5flG00=_5`03001c5g<G009c5`03001c5g<G009c5`03001c=g<g009c
=`03001c=g<g009c=`03001c=g<g00=c=`05001c=g<gLcL00004LcP01@00LcP007<h000017=H00D0
07=HLeQcF00000AcF005001cF7=HLeP00002LeP00`00LeP00003LeP00`00LgQcN002LgP01@00LgUc
NG=i00000WMi00<007MhMgP00WMh00D007=HLeQcF00000=cN@03001cVP0000EFo@<000EFo@03001F
oEKm00<00003E_d005Km00EFo@03001FoEKm00<00003E_d005Km00EFo@03001oo`0008=oo`00NWoo
00<007ooOol0<Woo00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d00eKm00<005Km0000
0P000eKm00<005KmE_d00eKm0P001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d00eKm0P001UKm
00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P0000=Fo@00E_d01EKm00<005Km0000
0P000eKm00<005KmE_d00eKm10000eKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0`000UKm
00@002VH:IP000<YV003000]V000008000<]V005000]^2fh;KP00003;KP40004<KP01@00<KPa^36h
00000c6h00@0036h<KPa^0<0008e^005000e^3Fh=KP00003=KP00`00=KPe^002=KP01P00>KLi]cVg
000i]`@000<i]`03000i]cVg008i]`03000m]cfg00<m]`05000mecgG?ML00004?ML00`00?MLme`02
?ML01@00?MLmecgG000013gG00<0047G@ML00d7G00@0047G@MM1eah000=5eP030015eTGF0095eP03
0015mTGf00=5mP030015mTGf00=5mP030019mTWf00=9mP030019mTWf0099mP030019mTWf00A9mP03
0019mTWf0099mP030019mTWf00=9mP03001=mTgf00==mP8000A=mP03001=mTgf00A=mP03001=mTgf
00==mP03001=mTgf00==mP03001>5ThF00=>5P<000A>5P03001B5U8F00=B5P03001B5U8F00AB5P03
001B5U8F00=B5P8000IB5P03001B5U8F00AB5P03001B5U8F009B5P8000IF5P03001F5UHF00AF5P05
001F=UHfESH00002ESH00`00ESIF=P05ESH00`00ESIF=P03ESH20006ESH00`00FSIJ=P04FSH20005
FSH00`00FSIJ=P05FSH20005FSH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
GUH00004GUH200001EiF001NEUiF000015iF00<005iFGUH015iF0P001eiF00<005if00001Eif00D0
05ifGWINMP0000=RMP03001RMV9f00ARMP03001RMP0000MRMP03001RMV9f00IRMP03001RMV9f00IR
MP8000ERUP04001VUVJF0005IYH01000IYIVUP001FJF00<006JF00001VJF00<006JF00001VJf00<0
06JfI[H01VJf00<006ZfJ[H016Zf00<006Zf000016Zf00<006ZfJ[H00VZf00@006ZfJ[H000EZeP03
001ZeV[F00EZeP03001ZeP0000=ZeP03001ZeV[F009ZeP03001Ze`0000E^e`03001^m`0000A^m`03
001^mfkg009^m`03001^mfkg00A^m`04001^mfkg0002K_L02000K_M^m`00K_L006lG0003KaL00`00
KaM_5`03KaL00`00KaM_5`02KaL00`00LaMc5`03LaL00`00LaMc5`02LaL00`00LcMc=`02LcL00`00
LcMc=`02LcL00`00LcMc=`02LcL01@00LcL007<g000017<h00D007<hLcQc>00000AcF003001cF7=H
009cF08000=cF004001cF7=H0004LeP01@00LeQcF7=H000017=h00D007Mh001cN@00009gN@03001g
N7Mh009gN005001gN000LeP00003LgT01P00LiYcVW>J001Fo@<0009Fo@03001FoEKm00=Fo@<000EF
o@03001FoEKm00=Fo@<000EFo@03001FoEKm00=Fo@800003Ool007oo085oo`00NWoo00<007ooOol0
<goo00<005KmE_d00eKm0P001UKm00@005KmE_eFo@@000IFo@03001Fo@0000800003E_d005Km00EF
o@03001Fo@00008000=Fo@03001FoEKm00=Fo@03001Fo@000080009Fo@03001FoEKm00=Fo@8000IF
o@03001FoEKm00=Fo@8000EFo@03001FoEKm00=Fo@<000IFo@03001Fo@0000800003E_d005Km00EF
o@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@0000800003E_d002VH00<000<YV005000Y
V2VH:IP00003;IP200000bfH000]^002;KP01@00;KP]^2fh00000S6h0`000S6h00D0036h<KPa^000
00@a^006000a^36h<KP003Fh0`000cFh00D003Fh=KPe^00000@e^005000i]cVg>KL00004>KL40000
0cVg000i]`02>KL00`00?KLm]`03?KL00`00?MLme`02?ML01@00?MLmecgG000013gG00<003gG?ML0
0SgG00D003gG?MLme`0000E1e`030011ed7G0091e`030011ed7G0091e`030011ed7G0091e`030011
ed7G00=1e`030015eTGF0095eP030015eTGF0095eP030015eTGF00=5eP030015eTGF0095eP030015
mTGf00A5mP030015mTGf0095mP030019mTWf00=9mP030019mTWf00=9mP030019mTWf00=9mP030019
mTWf0099mP030019mTWf00A9mP03001=mP0000800003BOH004gf00A=mP03001=mTgf00==mP03001=
mTgf00==mP03001=mTgf00==mP04001>5ThFCQH200000dgf001>5P05CQH00`00DQIB5P03DQH00`00
DQIB5P03DQH01000DQIB5U8F0P0000=B5P00DQH01E8F00<0058FDQH0158F00L0058FDQIB5P00DQH0
0006EQH00`00EQIF5P04EQH01000ESIF=P0015Hf00<005HfESH015Hf00<005HfESH00UHf00<005Hf
00001UHf00<005XfFSH015Xf00<005XfFSH015Xf00<005XfFSH01EXf00<005XfFSH01EXf00<005YF
FUH00eYF0P001eYF00D005YFFUIJEP0000=NEP@000ANEP8000INEP03001NEUiF009NEP04001NEUiF
0007GUH00`00GWINMP04GWH01000GWINMP001F9f00<0069fHWH00V9f00@0069fHWH000IRMP03001R
MP0000MRMP03001RMV9f00IRMP03001RUV:F00ERUP8000MVUP8000MVUP03001VUVJF00IVUP03001V
]VJf00EV]P03001V]VJf00EV]P03001V]P0000AZ]P05001Z]VZfJ[H00003J[H00`00J[IZ]P02J[H0
0`00J[H00006J]H00`00J]IZeP04J]H01000J]IZeP000f[F00<006[FJ]H00f[F00<006kGK]L016kG
00<006kg00000fkg00<006kgK_L00fkg00<006kgK_L016kg00H006kgK_L006kg0004K_L20002KaL0
1000KaM_5`0016lG00<007<G00000flG00<007<GLaL00W<G00<007<G00000W<G00<007<gLcL00W<g
00<007<g00000W<g00<007<gLcL00W<g00H007<gLcL007<g0004LcP01@00LcQc>7<h000017=H00D0
07=HLeQcF000009cF003001cF00000=cF003001cF7=H009cF005001cF7=HLeP00003LgP01@00MgQg
N7Mh00000gMi00D007MhMgQgN00000=gN005001cNG=iLgT00004LiX20006E_d00`00E_d000020000
0eKm001Fo@05E_d00`00E_eFo@0300000eKm001Fo@05E_d00`00E_eFo@0300001EKm001oogoo0000
PGoo001jOol00`00Oomoo`0dOol00`00E_d000020002E_d00`00E_eFo@03E_d40004E_d00`00E_eF
o@03E_d20005E_d00`00E_eFo@03E_d30006E_d01000E_eFoEKm0`001UKm00<005Km00000P000UKm
00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d00eKm00<005Km00000P000eKm00<005Km
E_d00eKm0P001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d00eKm0P001EKm00@002VH:IPYV080
0003:IP002VH008YV006000]V2fH;IP002fH0P0012fh00D002fh;KP]^000008a^003000a^0000080
00@a^005000a^36h<KP00004<KP01000=KPe^3Fh0P0000<e^000=KP00cFh00D003Fh=KPe^00000@i
]`05000i]cVg>KL00003>KL500000cVg000m]`03?KL00`00?MLme`02?ML00`00?MLme`02?ML01@00
?MLmecgG000013gG00<003gG?ML00SgG00<0047G@ML00d7G00D0047G@MM1e`0000A1e`030011ed7G
0091e`030011ed7G00=1e`030015eTGF0095eP030015eTGF00=5eP030015eTGF00=5eP030015eTGF
0095eP030015mTGf00=5mP030015mTGf0095mP030019mTWf00A9mP030019mTWf0099mP030019mTWf
00=9mP030019mTWf0099mP030019mTWf00=9mP<000A9mP03001=mTgf00==mP03001=mTgf00==mP03
001=mTgf00A=mP03001=mTgf00==mP<000==mP03001>5ThF00A>5P03001B5U8F00=B5P03001B5U8F
00AB5P<000=B5P03001B5U8F00AB5P03001B5U8F00AB5P04001B5U8F0002DQH00`00EQIF5P05EQH0
0`00EQIF5P04EQH20005ESH00`00ESIF=P04ESH01@00ESIF=UHf00000UHf00<005HfESH015Hf00<0
05XfFSH00eXf0P001eXf00<005XfFSH00eXf0P001eXf00<005YFFUH00UYF00<005YE00001eYF00@0
05YFFUH0009NEP<000MNEP03001NEUiF00ENEP05001NEUiFGUH00003GUH00`00GUINEP05GUH00`00
GWINMP05GWH20006HWH01@00HWIRMV9f00000f9f00<0069fHWH00f9f00@0069fHWH000IRMP03001R
MP0000MRMP03001RUV:F00ERUP03001VUVJF00IVUP03001VUVJF00IVUP03001VUVJF00IVUP03001V
]VJf00AV]P03001V]P0000EV]P04001V]VJf0003J[H00`00J[IZ]P02J[H01000J[IZ]P001VZf00<0
06[FJ]H016[F00<006[F00001F[F00L006[FJ]IZeP00J]H00006J]H00`00K]M^e`03K]L01@00K_M^
mfkg00000Vkg00<006kgK_L00Vkg00<006kg000016kg00<006kgK_L00Vkg00<006kgK_L00fkg0P00
0VlG00<006lG00001FlG00H007<GLaL006lG0004LaL01P00LaMc5`00LaL000Ac=`07001c=g<gLcL0
07<g00000g<g00<007<gLcL00W<g00<007<hLcP00W<h00L007<hLcQc>000LeP00002LeP01@00LeQc
F7=H000017=H00D007=HLeQcF00000AcF005001cF000LeP00004LgP01000MgQgN7Mh0P0000=gN@00
MgP00WMh00<007MhMgP00WMh0P0000=cN@00LiX00g>J00<006_k00001UKm0P001EKm00<005KmE_d0
0eKm0`001EKm00@005KmE_eFo@D000EFo@03001oo`00085oo`00NWoo00<007ooOol0=Goo00<005Km
E_d015Km00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P0000=Fo@00E_d01EKm00<0
05Km00000P000eKm00<005KmE_d00eKm10000eKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm
0P001UKm00@005KmE_eFo@@000IFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@00008000=F
o@03001FoEKm00=Fo@03001Fo@000080009Fo@03001FoEKm009Fo@06000YV2VH:IP002VH0P0012VH
00D002fH;IP]V000008]V080008]^005000]^2fh;KP00003<KP01000<KPa^36h0P000S6h00D0036h
<KPa^00000@a^006000e^3Fh=KP003Fh0`000cFh00<003Fh=KP00SFh00D003Vg>KLi]`0000@i]`05
000i]cVg>KL00003>KL50002?KL01@00?MLmecgG000013gG00<003gG?ML00SgG00D003gG?MLme`00
00@me`030011ed7G00=1e`030011ed7G0091e`030011ed7G0091e`030011ed7G0091e`030011ed7G
00=1e`030015eTGF0095eP030015eTGF0095eP030015eTGF00=5eP030015eTGF0095eP030015mTGf
00=5mP030015mTGf00=5mP030019mTWf00=9mP030019mTWf0099mP030019mTWf00=9mP030019mTWf
00=9mP030019mP0000800003BOH004Wf00E9mP03001=mTgf009=mP03001=mTgf00A=mP03001=mTgf
00==mP03001=mTgf009=mP8000I=mP03001>5ThF00=>5P03001B5U8F00=B5P03001B5U8F00=B5P80
00IB5P03001B5U8F00AB5P03001B5U8F00AB5P8000AB5P03001F5UHF00AF5P03001F5UHF00=F5P80
00IF=P03001F=UHf00AF=P04001F=UHf0004ESH00`00ESIF=P04ESH01@00FSIJ=UXf00000UXf00<0
05XfFSH015Xf00<005XfFSH00UXf00<005Xe00001eXf00D005YFFUIJEP0000=JE@03001JEUYF00EJ
EPD0009NEP03001NEUiF00ANEP8000MNEP04001NEUiF0004GUH00`00GUINEP04GUH20007GWH00`00
HWIRMP05HWH01000HWIRMP001F9f00D0069fHWIRMP0000=RMP03001RMV9f00=RMP04001RMV9f0006
HWH00`00HYH00006HYH00`00IYIVUP06IYH00`00IYIVUP05IYH00`00IYH00006IYH00`00IYH00005
I[H00`00I[H00004I[H00`00I[IV]P02I[H01000J[IZ]P0016Zf00<006Zf00001fZf00<006[FJ]H0
16[F00<006[F000016[F00<006[FJ]H00V[F00<006[F00001F[F00<006kF00000fkG00<006kgK_L0
0Vkg00<006kg00001Fkg00<006kg00000fkg00<006kgK_L00fkg00<006kgK_L00Vkg00@006lGKaL0
009_5`03001_5flG00=_5`03001c5g<G009c5`03001c5g<G00=c5`05001c5g<GLaL00005LcL00`00
LcMc=`02LcL00`00LcMc=`02LcL00`00LcMc=`02LcL20003LcP01000LcQc>0000g=H00<007=H0000
0g=H00<007=HLeP00W=H00D007=HLeQcF00000=cF005001cF7=HLeP00004LgP01@00MgQgN7Mh0000
0WMh0P000gMh00D007MhMgQgN000009gN@04001cVW>JLiX20003Jo/00`00E_eFo@0300000eKm001F
o@05E_d00`00E_d000020002E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@04E_d200000goo001o
o`1oOol007Yoo`03001oogoo03Ioo`03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000EFo@03
001FoEKm00=Fo@<000IFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@000080009Fo@03001F
oEKm00AFo@03001Fo@000080009Fo@03001FoEKm00=Fo@@000AFo@03001FoEKm00=Fo@8000EFo@03
001FoEKm00=Fo@<000IFo@04001FoEKmE_d30006E_d00`00E_eFo@02E_d01@00:IPYV2VH00000RVH
0P000RVH00D002fH;IP]V000008]V003000]V000008000@]^004000a^36h0003<KP00`00<KP00002
0004<KP01@00<KPa^36h000013Fh00<003Fh=KP01@0013Fh00D003Vg>KLi]`0000@i]`03000i]cVg
008i]`05000i]cVg>KL00003>KL600000cgG000me`02?ML00`00?MLme`02?ML00`00?MLme`02?ML0
1@00?MLmecgG00001D7G00<0047G@ML00T7G00<0047G@ML00T7G00<0047G@ML00T7G00<0047G@ML0
0d7G00<004GFAMH00TGF00<004GFAMH00TGF00<004GFAMH00dGF00<004GFAMH00TGF00<004GfAOH0
14Gf00<004GfAOH00TGf00<004WfBOH00dWf00<004WfBOH00TWf00<004WfBOH014Wf00<004WfBOH0
100014Wf00<004WfBOH014Wf00<004gfCOH00Tgf00<004gfCOH014gf00<004gfCOH00dgf00<004gf
00000P0000==mP00COH01Dgf00<004hFCQH014hF00<0058FDQH00U8F00@0058FDQIB5P800003DQH0
058F00EB5P03001B5U8F00AB5P03001B5U8F00=B5P8000EB5P03001F5UHF00AF5P03001F5UHF009F
5P03001F5P0000IF=P03001F=UHf00EF=P8000EF=P03001F=UHf00AF=P04001J=UXf0003FSH00`00
FSIJ=P04FSH01@00FSIJ=UXf00000eXe00<005XfFSH015Xf00@005YFFUH000AJE@03001JEUYF00AJ
EP<000INEP03001NEUiF009NEP03001NE@0000QNEP8000INEP03001NEUiF009NEP04001NEUiF0006
GWH00`00HWIRMP06HWH20006HWH01@00HWIRMV9f0000169f00D0069fHWIRMP0000=RMP03001RMV9f
00=RMP04001RUV:F0005HYH00`00IYH00006IYH00`00IYH00005IYH01000IYIVUP001FJF00@006JF
IYH000AV]P05001V]VJfI[H00003I[H00`00I[IV]P02I[H00`00J[H00006J[H00`00J[IZ]P05J[H0
0`00J[H00004J]H01@00J]IZeV[F00000V[F00<006[FJ]H016[F00<006[FJ]H016[F00<006kF0000
0fkG00<006kgK_L00fkg00<006kgK_L00fkg00D006kgK_M^m`00009^m`03001^mfkg009^m`03001^
m`0000=^m`04001_5flG0002KaL00`00KaM_5`02KaL00`00LaMc5`03LaL00`00LaMc5`02LaL00`00
LaMc5`02LaL00`00LcMc=`02LcL00`00LcMc=`03LcL01@00LcMc=g<g000017<g00H007<gLcL007<h
0003LcP00`00LeQcF002LeP01@00LeQcF7=H000017=H00D007=H001cF00000AcF004001cF7=HLeP2
0003LgP01000MgQgN0000gMh00D007Mh001gN00000=gN004001gNGMiMgT200000g>J001[n`04Jo/3
0005E_d00`00E_eFo@03E_d20006E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_eFo@030000
1EKm001oogoo0000Ogoo001iOol00`00Oomoo`0hOol00`00E_d000020002E_d00`00E_eFo@04E_d0
0`00E_d000020002E_d00`00E_eFo@03E_d00`00E_d000020003E_d00`00E_eFo@03E_d20005E_d0
0`00E_eFo@03E_d30005E_d00`00E_eFo@03E_d20006E_d00`00E_d000020002E_d00`00E_eFo@04
E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d000020003E_d00`00E_eFo@03E_d40003E_d0
0`00E_eFo@03E_d30002E_d01@00:IPYV2VH00000RVH00<002VH00000P000bfH00D002fH;IP]V000
00<]V080008]^004000a^36h0004<KP01000<KPa^36h0P000S6h00<0036h<KP00S6h00D003Fh=KPe
^000008e^004000e^3Fh=KP30002=KP00`00>KLi]`02>KL01@00>KLi]cVg000013Vg00D003Vg>KLi
]`0000Di]`04000m]cfg?KL500000cgG000me`02?ML00`00?MLme`02?ML00`00?MLme`02?ML00`00
@MM1e`03@ML01@00@MM1ed7G0000147G00<0047G@ML00T7G00<0047G@ML00d7G00<004GFAMH00TGF
00<004GFAMH00dGF00<004GFAMH00dGF00<004GFAMH00TGF00<004GfAOH00dGf00<004GfAOH00TGf
00<004WfBOH00dWf00<004WfBOH00dWf00<004WfBOH01P000TWf00<004WfBOH014Wf00<004WfBOH0
0dWf00<004gfCOH00dgf00<004gfCOH00dgf00<004gfCOH00dgf0P0014gf00<004gfCOH014gf00<0
04hFCQH014hF00<0058FDQH00e8F0`000e8F00<0058FDQH0158F00<0058FDQH0158F00<0058FDQH0
0U8F00<0058F00001E8F00<005HFEQH015HF00<005HFEQH00P000UHF00<005HfESH01EHf00<005Hf
ESH00eHf0P001UHf00<005HfESH015Hf00<005Xf000015Xf00<005XfFSH015Xf00@005XfFSH000AJ
=@03001J=UXf00EJ=P8000EJE@04001JEUYFFUH300000eYF001NEP06GUH01@00GUINEUiF00000eiE
00<005iFGUH01EiF00<005iFGUH01EiF00D005iFGUINEP0000=NEP03001NMUif00=NMP03001NMP00
00MRMP03001RMV9f00ERMP04001RMV9f0005HWH01@00HWIRMV9f0000169f00D0069fHWIRMP0000=R
UP03001RUV:F009RUP04001VUVJF0005IYH01000IYIVUP001FJF00@006JFIYH000AVUP05001VUVJF
IYH00003I[H00`00I[IV]P02I[H01000I[IV]P001FJf00<006Zf00001VZf00<006ZfJ[H016Zf00@0
06ZfJ[H000=ZeP03001ZeV[F009ZeP04001ZeV[F0006J]H00`00J]IZeP03J]H01`00K]I^eVkF001^
e`0000I^m`03001^mfkg009^m`03001^mfkg009^m`03001^m`0000E^m`06001^mfkg001^m`0016lG
0P0000=_5`00KaL00VlG00<007<GLaL00W<G00<007<G00000W<G00<007<GLaL00W<G00<007<g0000
0g<g00<007<gLcL00W<g00D007<g001c=`0000Ac=`03001c=g<g009c=`05001c>7<hLcP00005LeP0
1@00LeQcF7=H00000g=H00D007=HLeQcF00000AcF005001cF7=HLeP00002MgP00`00LgP00002MgP0
1@00MgQgN7Mh00000gMh00D007MhMgQgN00000=gN@03001gVGNI0080009[n`<00003E_d005Km00EF
o@03001FoEKm00<00003E_d005Km00EFo@8000EFo@03001FoEKm00=Fo@<000EFo@03001oo`0007mo
o`00NGoo00<007ooOol0>Goo00<005KmE_d015Km00<005KmE_d00eKm0`001EKm00@005KmE_eFo@@0
00IFo@03001Fo@000080009Fo@03001FoEKm00=Fo@03001Fo@00008000=Fo@03001FoEKm00=Fo@03
001Fo@000080009Fo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000EFo@03001FoEKm00=F
o@<000IFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@0000800003E_d002VI00<000@YV004
000YV2VH0003:IP20002;IP01000;IP]V0000bfH00<002fH00000P000c6h00D0036h<KPa^00000<a
^003000a^000008000@a^005000e^3Fh=KP00003=KP01P00=KPe^3Fh000e]`@000<i]`03000i]cVg
008i]`05000i]cVg>KL00004>KL00`00>KLi]`02>KL00`00?KLm]`02?KL01000?KLm]cfg1@0000<m
e`00?ML00SgG00<003gG?ML00SgG00<0047G@ML00d7G00<0047G@ML00T7G00<0047G@ML00T7G00<0
047G@ML00T7G00<0047G@ML00d7G00<004GFAMH00TGF00<004GFAMH00TGF00<004GFAMH00dGF00<0
04GFAMH00TGF00<004GfAOH00dGf00<004GfAOH00TGf00<004WfBOH014Wf00<004WfBOH01@000dWf
00<004WfBOH00TWf00<004WfBOH014Wf00<004WfBOH00dWf00<004gfCOH00dgf00<004gfCOH00dgf
00@004gfCOI=mP800003COH004gf00A=mP03001=mTgf00==mP03001>5ThF00A>5P03001B5U8F009B
5P8000IB5P03001B5U8F00AB5P03001B5U8F00=B5P03001B5U8F0080009B5P03001B5U8F00=B5P03
001F5UHF00EF5P8000EF5P03001F=UHf00AF=P03001F=UHf009F=P03001F=P0000IF=P03001F=UHf
00EF=P03001J=UXf00AJ=P03001J=UXf00AJ=P8000EJ=@03001J=UXf00EJ=P03001JEEYE00EJE@<0
00=JEP8000MNEP04001NEUiF0004GUD00`00GUINEP05GUH00`00GUINEP05GUH01000GUINEP0015iF
00<005ifGWH00Uif00@005ifGWH000MRMP03001RMV9f00IRMP8000IRMP04001RMV9f0005HWH01@00
HWIRMV9f000016:F00D006:FHYIRUP0000=VUP03001VUVJF009VUP04001VUVJF0004IYH00`00IYIV
UP02IYH01@00IYIVUVJF000016JF00@006JfI[H000AV]P03001V]P0000MV]P03001Z]VZf00AZ]P03
001Z]P0000EZ]P05001Z]VZfJ[H00002J]H00`00J]IZeP02J]H00`00J]H00006J]H00`00J]H00003
J]H00`00K]I^eP02K]H00`00K]L00005K_L00`00K_L00003K_L00`00K_M^m`03K_L00`00K_M^m`03
K_L01`00K_M^mfkg001^m`0000E_5`06001_5flG001_5`001G<G00<007<G00000W<G00<007<GLaL0
0W<G00H007<gLcL007<g0004LcL01@00LcMc=g<g00001G<g00<007<gLcL00W<g00D007<hLcQc>000
00AcF005001cF000LeP00004LeP01000LeQcF7=H0P000g=H00@007=HLeP000AgN005001gN7MhMgP0
0002MgP00`00MgQgN002MgP01@00MgQgN7Mh00000WMi00H007NIMiUgV@00MkT20005E_d01000E_eF
oEKm1@001EKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005Km00000P0000=Fo@00E_d01EKm00@0
07ooOol007ioo`00NGoo00<007ooOol00Woo0P00=Woo00<005KmE_d015Km00<005Km00000P000eKm
00<005KmE_d00UKm100015Km00<005KmE_d00eKm0P001UKm00<005KmE_d00UKm0`001UKm00@005Km
E_eFo@@000EFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm
00=Fo@03001Fo@00008000=Fo@03001FoEKm00=Fo@8000EFo@03001FoEKm00=Fo@<000AFo@04000Y
VBVI:IT20002:IP01000:IPYV0000bVH00<002VH00000P000RfH00<002fH;IP00RfH00@002fH;IP]
V0800003<KP0036h008a^003000a^36h008a^004000a^36h<KP20002<KP00`00=KPe^002=KP01000
=KPe^00013Fh00@003Fg=KLe]`80008i]`03000i]cVg008i]`03000i]cVg008i]`05000i]cVg>KL0
0005>KL01@00?KLm]cfg000013fg00@003fg?KLm]`D00003?ML003gG008me`030011ed7G00=1e`03
0011ed7G0091e`030011ed7G0091e`030011ed7G0091e`030011ed7G00=1e`030015eTGF0095eP03
0015eTGF00=5eP030015eTGF0095eP030015eTGF0095eP030015mTGf00=5mP030015mTGf00=5mP03
0019mTWf00H00099mP030019mTWf00=9mP030019mTWf00=9mP030019mTWf00=9mP030019mTWf00A9
mP03001=mTgf009=mP03001=mTgf00A=mP<000==mP03001=mTgf00==mP03001=mTgf00A=mP03001>
5ThF00=>5P03001B5U8F00800003DQH0058F00EB5P03001B5U8F00AB5P03001B5U8F00AB5P8000EB
5P03001B5U8F00=B5P03001F5UHF00=F5P8000IF5P03001F=UHf00AF=P05001F=UHfESH00002ESH0
0`00ESIF=P05ESH00`00ESIF=P03ESH20006FSH00`00FSIJ=P04FSH00`00FSEJ=@05FSD00`00FSIJ
=P03FSH20004FUD40004FUH01000FUEJE@001eiF0P001EiE00<005iFGUH015iF0P0025iF0P001UiF
00D005ifGWINMP00009NMP03001RMV9f00ARMP03001RMP0000MRMP03001RMV9f00IRMP8000IRMP04
001RMV9f0005HYH01000HYIRUP0016JF00D006JFIYIVUP0000AVUP04001VUVJF0005IYH01000IYIV
UP001FJF00<006Jf00001VJf00<006JfI[H01VJf00<006ZfJ[H016Zf00<006Zf000016Zf00<006Zf
J[H00VZf00<006[F00001V[F00<006[FJ]H016[F00@006[FJ]H000=ZeP03001^eVkF00=^eP03001^
mfkg00A^m`06001^mfkg001^m`001Vkg00<006kgK_L00Vkg00<006kgK_L00fkg00<006lGKaL00flG
00L006lG001_5`00KaL00004LaL01P00LaMc5`00LaL000Ac5`03001c=g<g009c=`03001c=g<g00=c
=`05001c=g<gLcL00004LcL00`00LcMc=`02LcL01@00LcL007<h000017=H00D007=HLeQcF00000Ac
F005001cF7=HLeP00002MeP00`00LeP00002LeP00`00MgQgN003MgP200001GMh001gN7Mh000017Mh
00D007Mh001gN000009gN@05001gVGNIMiT00002MkT20005E_d40003E_d00`00E_eFo@04E_d30005
E_d00`00E_eFo@03E_d20005E_d01000E_eFoEKm10000Woo00<007ooOol0Ngoo001iOol00`00Ool0
0002000iOol00`00E_eFo@03E_d30006E_d01000E_d000000UKm00<005KmE_d015Km00<005Km0000
0P000UKm00<005KmE_d015Km00@005Km000000=Fo@03001FoEKm00=Fo@@000AFo@03001FoEKm009F
o@8000IFo@03001FoEKm00=Fo@8000IFo@04001FoEKmE_d40006E_d00`00E_d0000200000eKm001F
o@05E_d00`00E_d000020003E_d01@00E_eFoEKm00000bVI00<002VH00000P000RVH00<002VH:IP0
0RVH00@002VH:IP000<]V005000]V2fH;IP00003;IP01000;IP00000136h00D0036h<KPa^00000<a
^003000a^00000<000<e^005000e^3Fh=KP00003=KP01P00=KLe]cFg000e]`@000<i]`03000i]cVg
008i]`05000i]cVg>KL00005>KL00`00?KLm]`02?KL01@00?KLm]cfg000013fg00@003gG?MLme`D0
0003?ML0047G00A1e`050011ed7G@ML00004@ML00`00@MM1e`02@ML00`00@MM1e`03@ML00`00AMI5
eP02AMH00`00AMI5eP03AMH00`00AMI5eP02AMH00`00AMI5eP02AMH00`00AOI5mP04AOH00`00AOI5
mP050003BOH00`00BOI9mP02BOH00`00BOI9mP04BOH00`00BOI9mP02BOH00`00BOI9mP04BOH00`00
BOI9mP03BOH00`00COI=mP02COH00`00COI=mP03COH20006COH00`00COI=mP02COH00`00COI=mP04
COH00`00CQI>5P04CQH20003DQH00`00DQIB5P04DQH00`00DQIB5P04DQH00`00DQIB5P03DQH20006
DQH00`00DQIB5P03DQH00`00EQIF5P02EQH00`00EQH00006EQH00`00ESIF=P04ESH01000ESIF=P00
15Hf00<005HfESH015Hf00<005HfESH00UHf00<005He00001UXf00<005XfFSH00eXf0P001eXe00<0
05XfFSH00UXf00@005Xe001JE@<000=JE@05001JEUYFFUH00003FUD00`00GUINEP05GUH00`00GUEN
E@05GUD00`00GUINEP02GUH01000GUENE@001eiF00<005iFGUH01EiF00@005ifGWH000ANMP03001R
MV9f009RMP04001RMV9f0007HWH00`00HWIRMP06HWH00`00HWIRMP06HWH20006HYH01000HYIRUP00
1FJF00@006JFIYH000AVUP04001VUVJF0005IYH00`00IYH00006IYH00`00I[H00006I[H00`00I[IV
]P05I[H00`00J[H00004J[H01@00J[IZ]VZf00000VZf00<006ZfJ[H00fZf00<006[F00001V[F00<0
06[FJ]H016[F00L006[FJ]IZeP00J]H00006K]H00`00K_M^m`03K_L01`00K_M^mfkg001^m`0000E^
m`03001^m`0000=^m`03001^mfkg00=^m`03001_5flG009_5`04001_5flG0002KaL00`00LaMc5`02
LaL00`00LaMc5`02LaL00`00LaMc5`02LaL00`00LcMc=`03LcL00`00LcMc=`02LcL01`00LcMc=g<g
001c=`0000=c=`05001c=g<gLcL00003LcL00`00LeQcF003LeP01000LeQcF7=H0P000g=H00@007=H
LeP000AgF005001cF7=HLeP00004MgP01000MgQgN0000gMh00D007MhMgQgN00000=gN005001gNGMi
MgT00002MiT01000MkUg^@000WMh00<005Km00000P0000=Fo@00E_d01EKm00<005KmE_d00`0000=F
o@00E_d01EKm00<005KmE_d00`0000=Fo@00E_d015Km10000eKm00@007ooOol007eoo`00NGoo0P00
?Goo00<005Km00000P000eKm00<005KmE_d00eKm0P001EKm00<005KmE_d00eKm0`001EKm00<005Km
E_d00eKm0P001UKm00<005Km00000P000UKm00<005KmE_d015Km00@005Km0000009Fo@03001FoEKm
00AFo@03001Fo@000080009Fo@03001FoEKm00=Fo@@000AFo@03001FoEKm00=Fo@8000EFo@03001F
oEKm00=Fo@<000IFo@05001FoEKmE_d00003:IT01000:IPYV2VH0P0000<YV000:IP00RVH00@002VH
:IPYV0800003;IP002fH008]V003000]V2fH008]V003000]V2fH0080008a^005000a^36h<KP00004
<KP01000<KPa^36h0P000SFh00D003Fh=KPe^00000<e^003000e]cFg008e]`04000e]cFg=KL40000
0cVg000i]`02>KL00`00>KLi]`02>KL00`00>KLi]`02>KL00`00?KLm]`02?KL00`00?KLm]`02?KL0
1@00?KLm]cfg000013gG00@003gG?MLme`/00003@ML0047G00=1e`030011ed7G0091e`030011ed7G
0091e`030015eTGF0095eP030015eTGF00=5eP030015eTGF00=5eP030015eTGF0095eP030015mTGf
00H00095eP030019mTWf00=9mP030019mTWf00=9mP030019mTWf00=9mP030019mTWf0099mP030019
mTWf00A9mP030019mTWf00=9mP03001=mTgf00==mP03001=mP0000800003COH004gf00E=mP03001=
mTgf009=mP03001=mTgf00A=mP03001>5ThF00=>5P8000EB5P03001B5U8F00=B5P03001B5U8F00AB
5P04001B5U8FDQH200000e8F001B5P05DQH00`00DQIB5P03DQH01@00EQIF5UHF00000UHF00<005HF
EQH015HF00<005HfESH01EHf0P001EHf00<005HfESH015Hf00D005HfESIF=P0000=F=@03001J=UXf
00AJ=P05001J=UXfFSH00002FSD00`00FSEJ=@04FSD01@00FSIJ=UXf00000UXe0P001UYE00@005YF
FUH000AJE@03001NEUiF00ENEP03001NEEiE00ENE@05001NEUiFGUH00003GUD00`00GUINEP05GUH0
0`00GUINEP05GUH01000GWINMP0015if00<0069fHWH00V9f00@0069fHWH000IRMP03001RMP0000MR
MP03001RMV9f00IRMP03001RUV:F00IRUP8000IVUP03001VUP0000EVUP03001VUP0000MVUP03001V
UVJF00IVUP03001V]VJf00AV]P03001V]P0000EV]P04001Z]VZf0003J[H00`00J[IZ]P02J[H01000
J[IZ]P001VZf00<006[FJ]H016[F00<006[F000016[F00<006[FJ]H00V[F00<006[F00001FkF00<0
06kF00000fkg00<006kgK_L00fkg00<006kgK_L016kg00H006kgK_L006kg0005K_L00`00K_L00003
KaL01`00KaM_5flG001_5`0000Ac5`03001c5g<G009c5`03001c5g<G009c5`03001c=g<g009c=`03
001c=`0000=c=`05001c=g<gLcL00002LcL00`00LcL00003LcL00`00LcMc=`02LcL00`00LeQcF002
LeP01@00LeQcF7=H00000W=H00<007=H00000g=H00<007MHMeP00WMH0P0000=cF000MgP00gMh00@0
07MhMgQgN0800003MgP007Mh009gN003001gN7Mh009gN0800005MgT007NIMiT00002MkT00`00MgQg
N002MgP00`00E_eFo@03E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@03E_d30005E_d00`00E_d0
000200000eKm001Fo@05E_d01000Oomoo`00O7oo001iOol00`00Oomoo`0mOol20006E_d00`00E_d0
000200000eKm001Fo@05E_d00`00E_d000020003E_d00`00E_eFo@03E_d00`00E_d000020002E_d0
0`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d30005E_d00`00E_d0
00020002E_d00`00E_eFo@04E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d000020003E_d0
0`00E_eFo@03E_d300000eKm000YV@02:IT01P00:IPYV2VH000YV08000<YV006000YV2VH:IP002VH
0P0012fH00D002fH;IP]V000008]V003000]V000008000@a^005000a^36h<KP00003<KP00`00<KP0
00030002=KP00`00=KPe^002=KP01@00=KLe]cFg00000cFg00@003Vg>KLi]`D00003>KL003Vg008i
]`03000i]cVg00<i]`05000m]cfg?KL00004?KL00`00?KLm]`02?KL01@00?MLmecgG000013gG00<0
03gG?ML00cgG00@0047G@MM1e`l00091e`030015eTGF0095eP030015eTGF010000=5eP030015eTGF
0095eP030019mTWf00A9mP030019mTWf0099mP030019mTWf00=9mP030019mTWf00=9mP030019mTWf
00=9mP030019mTWf00=9mP03001=mTgf009=mP<000A=mP03001=mTgf00A=mP03001=mTgf00==mP03
001=mTgf00==mP04001>5ThFCQH200000dhF001B5P04DQH00`00DQIB5P04DQH00`00DQIB5P04DQH3
0003DQH00`00DQIB5P04DQH00`00DQIB5P03DQH01000EQIF5P0015HF00<005HFEQH015HF00<005Hf
ESH00eHf0P001UHf00<005HfESH015Hf00@005HfESH000AF=@03001J=UXf00AJ=P04001J=UXf0003
FSD00`00FSEJ=@04FSD00`00FSIJ=P0400000eXe001JE@06FUD20006FUD00`00GUINEP03GUH20007
GUD01000GUINEP0015iE00<005iFGUH015iF0P0025iF0P001Uif00@0069fHWH000ARMP03001RMV9f
009RMP04001RMV9f0006HWH20008HWH00`00HYIRUP06HYH00`00IYIVUP06IYH00`00IYIVUP05IYH0
0`00IYIVUP06IYH00`00IYIVUP06IYH00`00I[IV]P04I[H00`00I[H00005I[H01@00J[IZ]VZf0000
0VZf00<006ZfJ[H00VZf00<006Zf00001fZf00<006[FJ]H016[F00<006[F00000f[F00<006[FJ]H0
16[F00<006kFK]H00fkF00@006kFK]H000=^m`03001^mfkg00=^m`03001^mfkg00=^m`07001^mfkg
K_L006kg00001Fkg00H006kgK_L006lG0005KaL00`00LaL00002LaL00`00LaMc5`02LaL00`00LaL0
0002LaL00`00LcMc=`03LcL01P00LcMc=`00LcL000=c=`03001c=g<g009c=`03001c=g<g009c=`07
001c=g<gLcL007=H00000g=H00@007=HLeP000AcF005001cF7=HLeP00004MeP01000MeQgF00017Mh
00D007MhMgQgN000009gN003001gN7Mh009gN005001gN7MhMgP00002MgT01@00MiUgVGNI00000WNi
00<007MhMgP00WMh00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d00eKm00<005KmE_d0
0`0000=Fo@00E_d01EKm0P001EKm00<005KmE_d00eKm0P000Woo00<007ooOol0NGoo001hOol00`00
Oomoo`10Ool00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d30006E_d01000E_eFoEKm0`001UKm
00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d00eKm00<005Km
00000P000eKm00<005KmE_d00UKm0P001UKm00<005KmE_d00eKm0P001EKm00<005KmE_d00eKm0`00
1UKm00<005Km00000P0000=Fo@00;KT00P000bVI00<002VH:IP00RVH00<002VH000012VH00D002VH
:IPYV000008YV080008]V005000]V2fH;IP00003;IP00`00;IP]V0020003<KP01@00<KPa^36h0000
136h00@0036h<KPa^080008e^005000e^3Fh=KP00003=KL00`00=KLe]`02=KL01@00>KLi]cVg0000
0cVg0`000SVg00<003Vg>KL00cVg00<003fg?KL00Sfg00D003fg?KLm]`0000@m]`03000mecgG008m
e`05000mecgG?ML00005?ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00@MM1e`02@ML01000@MI1
eT7F2P000dGF00<004GFAMH00TGF00<004GFAMH00TGF00<004GFAMH00dGF00<004GFAMH00dGF00<0
04WfBOH00dWf00<004WfBOH00TWf00<004WfBOH014Wf00<004WfBOH00TWf00<004WfBOH00dWf00<0
04WfBOH014Wf100000==mP00COH01Dgf00<004gfCOH00dgf00<004gfCOH00dgf00<004gfCOH014gf
0`000dhF00<0058FDQH00e8F00<0058FDQH0158F00<0058FDQH00e8F0P001U8F00<0058FDQH0158F
00<0058FDQH00e8F0P001EHF00<005HFEQH015HF00<005HfESH00UHf00<005He00001UHf00<005Hf
ESH01EHf0P001EHe00<005XfFSH015Xf00<005Xf000015Xe00<005XeFSD01EXe0`0015Xe00<005YE
FUD01EYE00<005YEFUD01EYE00<005iFGUH00UiF00@005iEGUD000MNE@8000INE@03001NEUiF009N
EP04001NEEiE0007GUH00`00GWINMP05GWH01000HWIRMP00169f00<0069fHWH00V9f00@0069fHWH0
00ERMP04001RMV9f0006HWH00`00HWH00007HYH00`00IYIVUP06IYH00`00IYIVUP05IYH00`00IYIV
UP05IYH00`00IYH00006IYH00`00I[H00004I[H01000I[IV]P0016Jf00<006ZfJ[H00VZf00<006Zf
00001VZf00<006ZfJ[H01FZf00<006[F000016[F00D006[FJ]IZeP00009ZeP03001ZeV[F00AZeP03
001^eVkF00=^eP07001^eVkFK]H006kg00001Fkg00<006kg00000fkg00<006kgK_L00fkg00<006kg
K_L00fkg00L006kgK_M^m`00KaL00004KaL20002LaL00`00LaL00003LaL01`00LaMc5g<G001c5`00
00Ac=`03001c=g<g009c=`05001c=g<gLcL00005LcL01@00LcMc=g<g000017<g00H007=HLeP007=H
0003LeP00`00LeQcF002LeP01@00LeQcF7=H00000gMH00D007MHMeQgF00000=gN005001gN7MhMgP0
0003MgP01@00MgQgN7Mh00000gMh00@007MiMgUgN@800005MiT007NiMkT00004MgP00`00MiT00005
E_d20006E_d01000E_eFoEKm10001EKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005Km00000P00
0UKm00<007oo0000Ngoo001hOol00`00Oomoo`11Ool00`00E_d0000200000eKm001Fo@05E_d00`00
E_d000020003E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@03E_d2
0006E_d01000E_eFoEKm10001UKm00@005Km0000009Fo@03001FoEKm00AFo@03001Fo@000080009F
o@03001FoEKm00=Fo@03001Fo@00008000=Fo@03001FoEKm00=Fo@8000EFo@03000]^Bfi0080008Y
V@05000YV2VH:IP00002:IP20002:IP01@00:IPYV2VH00000RVH00<002fH00000P0012fH00@002fH
;IP000<]V080008a^003000a^36h008a^005000a^36h<KP00003<KP00`00=KP000020003=KP00`00
=KLe]`02=KL01@00=KLe]cFg000013Vg00H003Vg>KLi]`00>KL40004>KL00`00?KLm]`02?KL00`00
?KLm]`02?KL01@00?KLm]cfg000013gG00<003gG?ML00SgG00<003gG?ML00cgG00D0047G@MM1e`00
00A1e`030011ed7G0091e`030011eT7F00=1eP030011eT7F0091eP030015eTGF00=5eP030015eTGF
0095eP030015eTGF0095eP030015eTGF00A5eP030015eTGF0095eP030019mTWf00=9mP030019mTWf
0099mP030019mTWf00A9mP030019mTWf0099mP030019mTWf00A9mP030019mTWf00@000A=mP03001=
mTgf00A=mP03001=mTgf00A=mP03001=mTgf009=mP03001=mTgf00==mP8000I>5P03001B5U8F009B
5P03001B5U8F00AB5P03001B5U8F009B5P03001B5P0000IB5P03001B5U8F00AB5P03001B5U8F009B
5P8000IF5P03001F5UHF00AF5P05001F=UHfESH00002ESD00`00ESIF=P05ESH00`00ESIF=P03ESH2
0006ESD00`00FSIJ=P05FSH00`00FSEJ=@04FSD01000FSEJ=EXe10001eXe00<005YEFUD00eYE0P00
1eYE00D005iFGUINEP0000=NE@03001NEEiE00ENE@03001NEEiE00ENE@05001NEUiFGUH00003GUD0
0`00GUINEP05GUH00`00GWINMP05GWH00`00HWH00006HWH01000HWIRMP00169f00D0069fHWIRMP00
00=RMP03001RMV9f00=RMP04001RMV9f0006HYH00`00HYH00006IYH00`00IYH00005IYH00`00IYH0
0005IYH01000IYIVUP001FJF00@006JfI[H000=V]P03001V]VJf009V]P04001V]VJf0005J[H00`00
J[H00006J[H00`00J[IZ]P04J[H01000J]IZeP000f[F00<006[FJ]H00V[F00<006[F00001V[F00<0
06kF00000fkF00<006kFK]H00VkF00<006kg00001Fkg00<006kg00000fkg00<006kgK_L00fkg00<0
06kgK_L00Vkg00<006kgK_L00fkg00<006lGKaL00VlG00@007<GLaL0009c5`03001c5g<G009c5`03
001c5g<G009c5`03001c=g<g009c=`03001c=g<g00=c=`05001c=g<gLcL00004LcL01@00LcL007<g
000017<g00<007=HLeP00W=H00D007=HLeQcF00000AcF005001gF000LeP00003MeP02@00MeQgF7MH
001gN000MgP00004MgP02000MgQgN000MgP007Mh0003MgP01@00MgUgNGMi00000WNI00D007NiMkUg
^@0000=gN004001gVGNI0002E_d300000eKm001Fo@05E_d40003E_d00`00E_eFo@03E_d30005E_d0
0`00E_eFo@03E_d20006E_d00`00Ool0001jOol001Qoo`@000ioo`<000moo`@000Uoo``000Uoo`H0
01Aoo`03001oogoo049oo`03001FoEKm00=Fo@03001FoEKm00=Fo@<000IFo@03001Fo@0000800003
E_d005Km00EFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm
00=Fo@@000AFo@03001FoEKm00=Fo@8000EFo@03001FoEKm00=Fo@8000IFo@04001FoEKmE_d40006
E_d00`00E_d0000200000eKm001Fo@04E_d01@00;KT]^@00:IT00`000bVH00D002VH:IP002VH00<0
00@YV004000YV2VH0003;IP20002;IP01@00;IP]V2fH00000RfH00<0036H00000`000c6h00D0036h
<KPa^00000@a^004000e^3Fh=KP300000cFh000e]`02=KL01@00=KLe]cFg000013Vg00D003Vg>KLi
]`0000@i]`@0008i]`05000m]cfg?KL00004?KL00`00?KLm]`02?KL01@00?MLmecgG000013gG00<0
03gG?ML00cgG00<0047G@ML00T7G00<0047G@ML00T7G00<0047G@ML00T7G00<0047F@MH00T7F00<0
047F@MH00T7F00<004GFAMH014GF00<004GFAMH00TGF00<004GFAMH00TGF00<004GFAMH00dGF00<0
04GFAMH00TGF00<004WfBOH00dWf00<004WfBOH00dWf00<004WfBOH00dWf00<004WfBOH00TWf00<0
04WfBOH00dWf10000dWf00<004gfCOH00dgf00<004gfCOH00dgf00<004gfCOH014gf00<004gfCOH0
0Tgf00@004gfCOI=mP800003COH004hF00E>5P03001B5U8F00=B5P03001B5U8F00=B5P03001B5U8F
0080009B5P03001B5U8F00AB5P03001B5U8F00AB5P07001B5U8FDQH0058F00001UHF00<005HFEQH0
15HF00@005HfESH000AF=@03001F=UHf00AF=P03001F=UHf009F=P03001F=@0000MF=@03001J=UXf
00=J=P8000IJ=@@000=J=@03001J=EXe00EJ=@03001JEEYE009JE@03001JE@0000MJE@04001NEUiF
0004GUD00`00GUENE@05GUD00`00GUENE@05GUD01000GUINEP0015iE00<005iFGUH015iF0P0025if
00<0069fHWH01F9f00@0069fHWH000ARMP05001RMV9fHWH00003HWH00`00HWIRMP03HWH01000HWIR
MP001F:F00@006:FHYH000EVUP04001VUVJF0005IYH00`00IYH00005IYH01000IYIVUP0016JF00<0
06JfI[H00VJf00@006JfI[H000AV]P04001V]VJf0006J[H00`00J[IZ]P04J[H00`00J[H00005J[H0
1@00J]IZeV[F00000V[F00<006[FJ]H00f[F00<006[FJ]H016[F00@006kFK]H0009^eP03001^eVkF
00A^eP03001^mfkg00=^m`07001^mfkgK_L006kg00001Fkg00<006kg00000fkg00<006kgK_L00fkg
00<006lGKaL00VlG00L007<GLaMc5`00LaL00003LaL00`00LaMc5`03LaL00`00LcMc=`02LcL00`00
LcMc=`02LcL01@00LcL007<g000017<g00D007<gLcMc=`0000Ac=`03001cF7=H00=cF005001cF7=H
LeP00003LeP01@00MeQgF7MH000017MH00@007MHMeP000=gN003001gN7Mh009gN004001gN7Mh0003
MgP20003MgP01000MgUgN@000gNI0P0000=g^@00MgP00WMh00<007NIMiT00WNI0P001EKm00<005Km
E_d00`0000=Fo@00E_d01EKm00<005Km00000P0000=Fo@00E_d01EKm00<005KmE_d00`0000=Fo@00
E_d01EKm0P0000=oo`00Ool0N7oo000FOol8000;Ool5000<Ool80007Ool<0007Ool:000BOol00`00
Oomoo`13Ool00`00E_eFo@03E_d00`00E_d000020003E_d00`00E_eFo@03E_d20005E_d00`00E_eF
o@03E_d30005E_d00`00E_eFo@03E_d20006E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00
E_d0000200000eKm001Fo@05E_d00`00E_d000020002E_d00`00E_eFo@03E_d40004E_d00`00E_eF
o@03E_d20005E_d00`00E_eFo@03E_d01000;KT]^@000RVI00<002VH:IP00RVH00@002VH:IP000<Y
V080008YV004000YV2VH0003;IP00`00;IP000020003;IP01@00;IP]V2fH00000c6H0P000S6h00<0
036h<KP00S6h00D0036h<KPa^00000<e^003000e]cFg00<0008e]`03000e]cFg008e]`05000i]cVg
>KL00004>KL01@00>KLi]cVg00000cVg1P0000<m]`00?KL00Sfg00<003fg?KL00Sfg00<003gG?ML0
0SgG00D003gG?MLme`0000Dme`030011ed7G0091e`030011ed7G0091e`030011ed7G0091e`030011
eT7F00=1eP030011eT7F0091eP030015eTGF00=5eP030015eTGF0095eP030015eTGF0095eP030015
eTGF00=5eP030015eTGF00=5eP030019mTWf00=9mP030019mTWf0099mP030019mTWf00=9mP030019
mTWf00=9mP030019mP0000800003BOH004Wf00A9mP03001=mTgf00==mP03001=mTgf00A=mP03001=
mTgf00==mP03001=mTgf00==mP<000==mP03001>5ThF00A>5P03001B5U8F00=B5P03001B5U8F00AB
5P8000EB5P03001B5U8F00AB5P03001B5U8F00=B5P04001B5U8F0003DQH00`00EQIF5P04EQH00`00
EQIF5P04EQH20005ESD00`00ESIF=P04ESH01@00ESIF=UHf00000UHe00<005HeESD01EHe00<005Xf
FSH00UXf00<005Xe000015Xe0`001EXe00<005Xe00001UXe00D005YEFUEJE@0000=JE@03001JEEYE
00EJE@8000INE@03001NEEiE00=NE@8000QNE@8000INE@03001NEUiF009NEP04001NMEie0007GWH0
0`00HWIRMP05HWH00`00HWH00005HWH01000HWIRMP001F9f00D0069fHWIRMP0000ARMP05001RUV:F
HYH00003HYH00`00IYIVUP03IYH01000IYIVUP0016JF00@006JFIYH000AVUP03001VUVJF009VUP05
001VUVJFIYH00004I[H00`00I[H00005I[H00`00I[H00007J[H00`00J[IZ]P04J[H00`00J[H00004
J[H00`00J]IZeP02J]H00`00J]H00006J]H00`00J]IZeP04J]H01000K]I^eP000VkF00<006kFK]H0
16kF00<006kgK_L00Vkg00<006kgK_L00Vkg00<006kg00001Fkg00H006kgK_L006kg0005K_L00`00
KaL00002KaL00`00LaMc5`03LaL00`00LaL00002LaL00`00LaMc5`02LaL00`00LaL00002LcL00`00
LcMc=`02LcL01P00LcMc=`00LcL000Ac=`05001c=g<gLcL00004LcL00`00LeQcF002LeP01@00LeP0
07=H00000g=H00<007MHMeP00WMH00D007MHMeQgF00000=gF004001gN7MhMgP20003MgP01000MgQg
N0000gMh00D007Mh001gN000009gN@05001gVGNIMiT00002MiT20003MgP01000MiUgVGNI0P001UKm
0`001EKm00<005KmE_d00eKm0P001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d00`0000AFo@00
Ool007Uoo`005Woo0P0017oo0P002goo1@0037oo0P0017oo0P0027oo0`001Woo0P001goo0`001Goo
0`004Goo00<007ooOol0A7oo00@005KmE_eFo@@000IFo@03001Fo@0000800003E_d005Km00EFo@03
001Fo@00008000=Fo@03001FoEKm00=Fo@03001Fo@000080009Fo@03001FoEKm00=Fo@8000IFo@03
001FoEKm00=Fo@8000EFo@03001FoEKm00=Fo@8000IFo@03001Fo@000080009Fo@03001FoEKm00AF
o@03001Fo@0000800003E_d005Km00EFo@03001FoEKm009Fo@04000]^Bfi0003:IT20002:IP01000
:IPYV0000bVH00<002VH00000P000RVH00<002fH;IP00RfH00@002fH;IP]V0800003;IP002fH008]
V006000aV36H<IP0036H10000c6h00D0036h<KPa^00000@e^005000e]cFg000e]`040003=KL00`00
>KLi]`02>KL01@00>KLi]cVg000013Vg00<003Vg>KL00SVg00@003Vg>KLi]`D00003?KL003fg008m
]`03000mecgG008me`03000mecgG008me`03000mecgG00<me`050011ed7G@ML00004@ML00`00@MM1
e`02@ML00`00@MI1eP03@MH00`00@MI1eP02@MH00`00AMI5eP03AMH00`00AMI5eP02AMH00`00AMI5
eP02AMH00`00AMI5eP04AMH00`00AMI5eP02AMH00`00BOI9mP03BOH00`00BOI9mP02BOH00`00BOI9
mP04BOH00`00BOI9mP040004BOH00`00BOI9mP04BOH00`00COI=mP02COH00`00COI=mP04COH00`00
COI=mP03COH00`00COI=mP02COH20006COH00`00CQI>5P03CQH00`00DQIB5P03DQH00`00DQIB5P03
DQH20006DQH00`00DQIB5P04DQH00`00DQIB5P04DQH20004DQH00`00EQIF5P04EQH00`00EQIF5P03
EQH20006ESD00`00ESIF=P04ESH01000ESIF=P0015He00<005HeESD015He00D005XfFSIJ=P0000=J
=@@000=J=@05001J=EXeFSD00002FSD00`00FSEJ=@04FSD01000FUEJE@0015YE00<005YEFUD01EYE
00<005iEGUD01EiE00<005iEGUD00UiE00@005iEGUD000MNE@03001NEEiE00ENE@05001NEUiFGUH0
0003GWD00`00GWINMP04GWH20008HWH00`00HWIRMP05HWH20006HWH01000HWIRMP001F9f00D006:F
HYIRUP0000ARUP05001VUVJFIYH00004IYH01000IYIVUP0016JF00@006JFIYH000EVUP04001VUVJF
0005I[H00`00I[H00006I[H00`00J[IZ]P05J[H00`00J[H00004J[H01@00J[IZ]VZf00000VZf00<0
06[FJ]H00f[F00<006[F00001F[F00<006[F000016[F00<006kFK]H00VkF0P001VkF00<006kf0000
0fkg00<006kgK_L00fkg00<006kgK_L00fkg00L006kgK_M^m`00K_L00004K_L01P00KaM_5`00KaL0
00Ec5`800004LaL007<G0004LaL01`00LaMc5g<G001c=`0000Ac=`05001c=g<gLcL00004LcL01`00
LcMc=g<g001c=`00009c=`03001cF7=H009cF005001cF7=HLeP00004LeP02@00MeQgF7MH001gF000
MeP00003MeP01@00MgQgN7Mh00000WMh00<007Mh00000WMh00D007MhMgQgN00000=gN005001gNGMi
MgT00002MiT02@00MiUgVGNI001gV@00MgP00003MiT01000JoY[nP000UKm0`0000=Fo@00E_d01EKm
00<005KmE_d00`0000=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d01EKm0`001EKm00<007oo
0000N7oo000EOol20006Ool2000:Ool5000;Ool20006Ool20008Ool3000GOol2000AOol00`00Oomo
o`15Ool30004E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d30006E_d01000E_eFoEKm0`00
1UKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d00eKm00<0
05Km00000P000UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00eKm0P001EKm00<005KmE_d00eKm
1P000bfi00D002VI:IT002VI00<000<YV005000YV2VH:IP00003:IP200000bVH000]V002;IP01P00
;IP]V2fH000]V0<0008]V003000aV36H008aV004000aV36H<IP50004<KP01@00=KPe^3Fh00000cFg
00@003Fg=KLe]`80008e]`03000i]cVg008i]`05000i]cVg>KL00004>KL00`00>KLi]`02>KL00`00
>KLi]`02>KL01000?KLm]cfg1@0000<m]`00?ML00SgG00<003gG?ML00SgG00<003gG?ML00cgG00<0
047G@ML00T7G00<0047G@ML00T7G00<0047G@ML00T7G00<0047F@MH00T7F00<0047F@MH00T7F00<0
04GFAMH014GF00<004GFAMH00TGF00<004GFAMH00TGF00<004GFAMH00dGF00<004GFAMH00TGF00<0
04WfBOH00dWf00<004WfBOH00TWf00<004WfBOH00dWf10000TWf00<004WfBOH014Wf00<004WfBOH0
0dWf00<004gfCOH00dgf00<004gfCOH00dgf00<004gfCOH014gf100000==mP00COH01Dgf00<004hF
CQH014hF00<0058FDQH00U8F00@0058FDQIB5P800003DQH0058F00EB5P03001B5U8F00AB5P03001B
5U8F00=B5P8000EB5P03001F5UHF00AF5P03001F5UHF009F5P03001F5@0000IF=@03001F=UHf00EF
=P8000EF=@03001F=EHe00AF=@04001J=UXf0002FSD30006FSD01000FSEJ=@000eXe00<005XeFSD0
1EXe0P001EYE00<005YEFUD01EYE00<005iEGUD01EiE00D005iEGUENE@0000=NE@03001NEEiE00EN
E@03001NEEiE00ENE@04001NEUiF0004GWD00`00GWINMP03GWH01000HWERM@001f9f00<0069fHWH0
1F9f00<0069fHWH01F9f00@0069fHWH000ERMP04001RUV:F0005HYH01000IYIVUP001FJF00@006JF
IYH000AVUP04001VUVJF0005IYH00`00IYH00007I[H00`00I[IV]P05I[H00`00J[IZ]P04J[H01000
J[IZ]P000fZf00<006ZfJ[H00VZf00@006ZfJ[H000IZeP03001ZeV[F00AZeP03001ZeP0000=ZeP03
001^eVkF00=^eP03001^eVkF00A^eP07001^mVkfK_H006kg00001Vkg00<006kgK_L00Vkg00<006kg
K_L00fkg00<006kgK_L00fkg00D006lGKaM_5`0000Ic5`05001c5`00LaL00005LaL00`00LaMc5`02
LaL00`00LcMc=`02LcL00`00LcMc=`02LcL20003LcL01@00LcMc=g<g00000W<g00<007<g00000g=H
00<007=HLeP00W=H00D007=HLeQcF00000=gF004001gF7MHMeP20003MeP01000MgQgN00017Mh00D0
07MhMgQgN000009gN003001gN7Mh009gN0800005MgT007NIMiT00003MiT01@00MiUgVGNI00000gNI
00@006_jJoY[nP<000EFo@03001FoEKm00=Fo@<000EFo@04001FoEKmE_d40005E_d00`00E_eFo@03
00000eKm001Fo@05E_d01000Oomoo`00Mgoo000EOol20006Ool2000;Ool3000<Ool20006Ool20009
Ool3000GOol2000?Ool00`00Oomoo`17Ool00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eF
o@03E_d00`00E_d000020003E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d30005E_d00`00
E_eFo@03E_d20006E_d01000E_eFoEKm10001EKm00<005Km00000P000UKm00<005KmE_d015Km00<0
05Km00000P000UKm00<005KmE_d00eKm00<005Km00000P0000=Fo@00;KT00Rfi0`0000<]^@00:IT0
0RVI00@002VI:ITYV@800003:IP002VH008YV006000YV2VH:IP002VH0P000bfH00<002fH;IP00RfH
00@002fH;IP000<]V005000aV36H<IP00003<IP01000<IPaV36H0`000S6h00D003Fh=KPe^00000<e
]`06000e]cFg=KL003Fg10000cVg00<003Vg>KL00SVg00D003Vg>KLi]`0000Di]`05000i]cVg>KL0
0004?KL01000?KLm]cfg1@0000<me`00?ML00SgG00<003gG?ML00cgG00<0047G@ML00T7G00<0047G
@ML00T7G00<0047G@ML00T7G00<0047F@MH00d7F00<0047F@MH00T7F00<004GFAMH00dGF00<004GF
AMH00TGF00<004GFAMH00TGF00<004GFAMH00dGF00<004GFAMH00TGF00<004WfBOH00dWf00<004Wf
BOH00dWf00<004Wf00000P0000=9mP00BOH00dWf00<004WfBOH014Wf00<004WfBOH00dWf00<004gf
COH00dgf00<004gfCOH00dgf00<004gfCOH00dgf0P0014gf00<004gfCOH014gf00<004hFCQH014hF
00<0058FDQH00e8F0`000e8F00<0058FDQH0158F00<0058FDQH0158F00@0058FDQIB5P800003DQH0
058F00EB5P03001F5UHF00=F5P03001F5UHF0080009F5@03001F=EHe00EF=@03001F=UHf00=F=P80
00IF=@03001F=EHe00EF=@800003FSD00000009J=@03001J=EXe00AJ=@03001J=@0000EJ=@03001J
=EXe00AJ=@03001JEEYE00EJE@03001JEEYE00=JE@8000MNE@04001NEEiE0004GUD00`00GUENE@04
GUD20008GUD20006GWD01@00GWINMUif00000f9e00<0069fHWH0169f0P001f9f00<0069fHWH01V9f
0P001f9f0P001V:F00@006JFIYH000EVUP03001VUP0000EVUP03001VUP0000MVUP03001V]VJf00IV
]P03001V]VJf00AV]P03001Z]P0000EZ]P05001Z]VZfJ[H00002J[H00`00J[IZ]P02J[H00`00J[H0
0007J]H00`00J]IZeP03J]H01@00J]IZeV[F00000V[F00<006kFK]H00fkF00<006kFK]H016kF00L0
06kfK_I^mP00K_L00005K_L00`00K_L00003K_L00`00K_M^m`03K_L00`00K_M^m`02K_L00`00KaM_
5`02KaL00`00LaMc5`03LaL01000LaMc5g<G0P0017<G00<007<GLaL00g<G00D007<gLcMc=`0000Ac
=`06001c=g<g001c=`000g<g00<007<gLcL00W<g00<007=HLeP00W=H00T007=HLeQcF000MeP007=H
000017MH00T007MHMeQgF000MgP007MH00000gMh00<007MhMgP00WMh0P0000EgN000MgQgN00000Ag
N004001gV7NH0003MiT01000MiUgV@0017NI0P0000=gV@00JoX00`000UKm00<005KmE_d00eKm00<0
05KmE_d00`0000=Fo@00E_d01EKm10000eKm00<005KmE_d00eKm0`001EKm00<005KmE_d00eKm0P00
00=oo`00Ool0MWoo000DOol20008Ool2000HOol20008Ool20009Ool3000FOol2000?Ool00`00Oomo
o`020016Ool00`00E_eFo@03E_d30005E_d01000E_eFoEKm10001UKm00<005Km00000P0000=Fo@00
E_d01EKm00<005Km00000P000eKm00<005KmE_d00eKm00<005Km00000P000UKm00<005KmE_d00eKm
100015Km00<005KmE_d00UKm0`001EKm00<005KmE_d00eKm0P001UKm00@005KmE_eFo@@000AFo@06
000]^Bfi;KT002Vi0`000RVI00H002VI:ITYV@00:IP20003:IP00`00:IPYV002:IP00`00:IP00004
;IP01@00;IP]V2fH00000bfH0P0000<]V000<IP00S6H00<0036H<IP00S6H00H0036H<IPaV000<KP3
0004=KP01000=KLe]`0013Fg00@003Fg=KLe]`@00003>KL003Vg008i]`03000i]cVg008i]`03000i
]cVg008i]`03000i]cVg008i]`05000m]cfg?KL00004?KL01000?KLm]cfg1@0000<me`00?ML00cgG
00<0047G@ML00T7G00<0047G@ML00T7G00<0047G@ML00T7G00<0047F@MH00d7F00<0047F@MH00T7F
00<004GFAMH00dGF00<004GFAMH00TGF00<004GFAMH00TGF00<004GFAMH00dGF00<004GFAMH00dGF
00<004WfBOH00dWf00<004WfBOH0100014Wf00<004WfBOH00dWf00<004WfBOH00dWf00<004WfBOH0
14Wf00<004gfCOH00Tgf00<004gfCOH014gf00<004gf00000P0000==mP00COH014gf00<004gfCOH0
0dgf00<004hFCQH014hF00<0058FDQH00U8F0P001U8F00<0058FDQH0158F00<0058FDQH0158F0`00
0e8F00<0058FDQH0158F00<005HFEQH015HF0P001EHE00<005HeESD015He00<005HfESH00UHf00<0
05He00001eHe00<005HeESD00eHe100015Xe00<005XeFSD01EXe00<005XeFSD015Xe00<005XeFSD0
15Xe00<005YEFUD01EYE00<005YEFUD00UYE00@005iEGUD000MNE@8000INE@03001NEEiE009NE@04
001NEEiE0007GUD00`00GWENM@05GWD01@00GWINMUif00000f9e00<0069fHWH00f9f00@0069fHWH0
00ERMP03001RMP0000MRMP03001RMV9f00IRMP03001RUV:F00IRUP8000MVUP8000IVUP03001VUVJF
00IVUP03001V]VJf00EV]P03001V]P0000EV]P03001Z]P0000AZ]P03001Z]VZf009Z]P03001Z]P00
00IZ]P03001ZeV[F00EZeP03001ZeP0000=ZeP03001ZeV[F009ZeP03001ZeP0000E^eP03001^eP00
00A^eP03001^mVkf00=^mP03001^mfkg00=^m`07001^mfkgK_L006kg00001Fkg00<006kg00000Vkg
00<006lGKaL00VlG00<007<G00000g<G00<007<GLaL00W<G0`000g<G00<007<GLaL00W<G00<007<g
00000W<g00D007<gLcMc=`0000Ac=`05001c=g<gLcL00005LcL01@00LeQcF7=H00000g=H00D007MH
MeQgF00000AgF005001gF7MHMeP00003MgP01@00MgQgN7Mh000017Mh00@007MhMgP000=gN005001g
N7MhMgP00003MiP200001GNI001gVGNI000017NI00<007NIMiT00`001UKm00@005KmE_eFo@@000EF
o@03001FoEKm00<00003E_d005Km00EFo@03001Fo@000080009Fo@03001FoEKm00=Fo@03001FoEKm
00<00003E_d007oo00<007Eoo`0057oo0P0027oo0P0067oo0P0027oo0P002Woo0`005Goo0P003goo
0`00BGoo00<005Km00000P000eKm00<005KmE_d00UKm100015Km00<005KmE_d00eKm0P001EKm00<0
05KmE_d00eKm0`001UKm00@005KmE_eFo@<000IFo@03001Fo@000080009Fo@03001FoEKm00AFo@04
001Fo@000003E_d00`00E_eFo@03E_d00`00E_d000020002E_d00`00E_eFo@03E_d40004E_d01@00
E_eFoEKm000012fi00@002Vi:KT000<YV@05000YVBVI:IT00002:IP20002:IP01@00:IPYV2VH0000
0RVH0P000RfH00D002fH;IP]V00000<]V004000]V0000004<IP01@00<IPaV36H0000136H00@0036h
<KPa^080008e^005000e]cFg=KL00003=KL01@00=KLe]cFg00000cFg0`000SVg00<003Vg>KL00SVg
00<003Vg>KL00SVg00<003Vg>KL00SVg00<003fg?KL00Sfg00D003fg?KLm]`0000@m]`04000m]cfg
?KL50002?ML00`00@MM1e`02@ML01@00@MM1ed7G0000147G00<0047F@MH00d7F00<0047F@MH00T7F
00<004GFAMH00dGF00<004GFAMH00TGF00<004GFAMH00TGF00<004GFAMH014GF00<004GFAMH02`00
0TWf00<004WfBOH014Wf00<004WfBOH00TWf00<004WfBOH00dWf00<004WfBOH014Wf00<004gfCOH0
0Tgf00<004gfCOH00dgf0`0014gf00<004gfCOH00dgf00<004gfCOH014gf00<004hFCQH00dhF00<0
058FDQH00P0000=B5P00DQH01E8F00<0058FDQH0158F00<0058FDQH00e8F0P001U8F00<0058FDQH0
0e8F00<005HFEQH00eHF0P001UHE00<005HeESD015He00D005HfESIF=P00009F=@03001F=EHe00EF
=@04001F=EHeESD40007FSD00`00FSEJ=@03FSD20006FSD00`00FSEJ=@03FSD00`00FSD00006FUD0
1@00FUEJEEYE00000eiE00<005iEGUD01EiE00<005iEGUD01EiE00D005iEGUENE@0000=NE@03001N
EEiE00ENE@03001NMEie00ENM@04001NMUif0005HWD01@00HWIRMV9f00000f9f00<0069fHWH00f9f
00<0069f00001f9f00<0069fHWH01V9f00<006:FHYH01V:F00<006JFIYH01VJF00<006JFIYH01FJF
00<006JFIYH01FJF00<006JF00001FJf00@006JfI[H000AV]P05001Z]VZfJ[H00002J[H00`00J[IZ
]P03J[H00`00J[H00006J[H00`00J]IZeP04J]H01000J]IZeP000f[F00<006[FJ]H00f[F00<006kF
K]H016kF00<006kF00000fkF00<006kfK_H016kf00<006kgK_L00fkg00L006kgK_M^m`00K_L00004
K_L01000K_M^m`000Vkg00<006lGKaL00VlG00@007<GLaL0009c5`03001c5g<G009c5`800004LaL0
07<G0004LaL01P00LcMc=`00LcL000Ac=`03001c=g<g009c=`05001c=g<gLcL00004LcL01@00LeL0
07=H000017=H00@007MHMeQgF08000=gF004001gF7MH0004MgP01@00MgQgN7Mh00000gMh00@007Mh
MgQgN0800003MgP007Mh009gN005001gV7NHMiP00002MiT01@00MiUgVGNI00000gNI00L007NIMiUg
V@00MkT00006E_d40003E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@03E_d20006E_d01000E_eF
oEKm10001EKm00@007ooOol007Eoo`0057oo0P0027oo0P0067oo0P0027oo0P002goo0`0057oo0P00
3goo00<007ooOol0BWoo0P001UKm00@005Km0000009Fo@03001FoEKm00AFo@03001Fo@0000800003
E_d005Km00EFo@03001Fo@00008000=Fo@03001FoEKm00=Fo@@000=Fo@03001FoEKm00=Fo@8000IF
o@03001FoEKm00=Fo@8000IFo@04001FoEKmE_d30006E_d00`00E_d000020002E_d00`00E_eFo@04
E_d01@00E_eFoEKm00000bfi00@002Vi:KTY^@800003:IT002VI008YV@05000YV2VH000YV0030003
:IP01@00:IPYV000:IP00`0012fH00D002fH;IP]V000008]V080008aV005000aV36H<IP00004<IP0
1P00<KPa^36h000a^0<000<e]`05000e]cFg=KL00004=KL01P00=KLe]cFg000i]`@000<i]`03000i
]cVg00<i]`05000i]cVg>KL00004?KL00`00?KLm]`02?KL01@00?KLm]cfg000013fg00@003gG?MLm
e`/00003@ML0047G00=1e`030011eT7F00=1eP030011eT7F0091eP030015eTGF00=5eP030015eTGF
0095eP030015eTGF0095eP030015eTGF00H00095eP030019eTWF00=9eP030019mTWf0099mP030019
mTWf00A9mP030019mTWf0099mP030019mTWf00A9mP030019mTWf00=9mP03001=mTgf00==mP03001=
mP0000800003COH004gf00E=mP03001=mTgf009=mP03001=mTgf00A=mP03001>5ThF00A>5P8000AB
5P03001B5U8F00=B5P03001B5U8F00AB5P03001B5U8F009B5P03001B5P0000IB5P03001B5U8F00AB
5P07001F5UHFEQH005HE00001UHE00<005HeESD015He00@005HfESH000AF=@03001F=EHe00AF=@D0
009F=@03001J=EXe00EJ=@03001J=EXe009J=@03001J=@0000MJ=@05001J=EXeFSD00002FSD00`00
FUEJE@04FUD01000FUEJE@0015iE00<005iEGUD01EiE00<005iEGUD01EiE00D005iEGUENE@0000=N
E@03001NEEiE00ANE@8000QNM@8000IRM@05001RMV9fHWH00003HWH00`00HWIRMP02HWH01000HWIR
MP001V9f00<0069f00001V9f00<0069f00001f:F00<006JFIYH01VJF00<006JFIYH016JF00<006JF
00001FJF00@006JFIYH000EV]P04001V]VJf0003I[H00`00J[IZ]P02J[H01000J[IZ]P001VZf00<0
06ZfJ[H016Zf00<006Zf00001F[F00L006[FJ]IZeP00J]H00006J]H00`00K]I^eP03K]H01@00K]I^
eVkF00000VkF00<006kfK_H00fkf00<006kf00000fkg00<006kgK_L00fkg00<006kgK_L00fkg00H0
06kgK_L006kg0004KaL01`00LaMc5g<G001c5`0000Ac5`06001c5g<G001c5`001G<G00D007<gLcMc
=`0000Ac=`03001c=g<g009c=`05001c=`00LcL00004LcL01@00LeMcEg=G000017=H00D007MHMeQg
F000009gF003001gF00000=gF009001gN7MhMgP007Mh001gN00000=gN005001gN7MhMgP00002MgP0
1@00MgQgN7Mh00000gNH00@007NIMiUgV@800003MiT007NI009gV@09001gVGNIMiT007Ni001gN000
009Fo@<00003E_d005Km00EFo@03001Fo@0000800003E_d005Km00EFo@03001FoEKm00<00003E_d0
05Km00EFo@@0009Fo@03001FoEKm00AFo@800003Ool007oo07Aoo`0057oo0P0027oo0P0067oo0P00
27oo0P0037oo0`004goo0P003goo00<007ooOol0C7oo00<005KmE_d00eKm0P001EKm00<005KmE_d0
0eKm0`0015Km00<005KmE_d00eKm0`001UKm00<005Km00000P0000=Fo@00E_d01EKm00<005Km0000
0P000UKm00<005KmE_d015Km00<005Km00000P000UKm00<005KmE_d00eKm10000eKm00<005KmE_d0
0eKm0P001UKm00<005KmE_d00eKm1@0012fi00D002Vi:KT002VI008000@YV@04000YV2VH0002:IP0
0`00:IPYV002:IP01000:IPYV0000bVH0P000RfH00D002fH;IP]V000008]V003000]V000008000@a
V005000aV36H<IP00004<KP01000<KPa^36h0P0000<e]`00=KL00cFg00D003Fg=KLe]`0000<e]`03
000i]cVg008i]`@00003>KL003Vg00<i]`03000i]cVg008i]`05000m]cfg?KL00004?KL00`00?KLm
]`02?KL01@00?KLm]cfg00001CgG00<0047G@ML00T7G00@0047G@MM1eb@000=5eP030015eTGF0095
eP030019eTWF00=9eP030019mTWf00=9mP030019mTWf00=9mP030019mTWf0099mP030019mTWf00A9
mP030019mTWf00=9mP03001=mTgf009=mP<000A=mP03001=mTgf00A=mP03001=mTgf00==mP03001=
mTgf00==mP03001>5ThF00=>5P8000EB5P03001B5U8F00=B5P03001B5U8F00AB5P03001B5U8F0080
009B5P03001B5U8F00AB5P03001B5U8F00AB5P04001F5UHF0002EQD00`00EQEF5@05EQD00`00ESEF
=@04ESD20005ESD00`00ESEF=@02ESD30002ESD00`00ESEF=@02ESD00`00FSEJ=@04FSD01@00FSEJ
=EXe00000eXe00<005XeFSD015Xe00@005XeFSD000=J=@03001JEEYE00EJE@8000INE@03001NEEiE
00=NE@8000MNE@04001NEEiE0005GUD00`00GUENE@02GUD01000GUENE@001eie00<0069eHWD01F9e
00@0069fHWH000ERMP04001RMV9f0004HWH00`00HWIRMP02HWH01000HWIRMP001F9f00@0069fHWH0
00IRUP03001VUP0000IVUP03001VUP0000EVUP03001VUP0000EVUP04001VUVJF0004I[H00`00I[IV
]P02I[H01000I[IV]P0016Zf00<006Zf00001fZf00<006ZfJ[H016Zf00<006Zf000016[F00<006[F
J]H00V[F00<006[F00001F[F00<006kF00000fkF00<006kFK]H00VkF00<006kF00001Fkf00@006kf
K_H0009^m`03001^mfkg00A^m`03001^mfkg009^m`03001^mfkg009^m`03001_5flG009_5`03001c
5g<G00=c5`03001c5g<G009c5`03001c5g<G009c5`8000Ac5`03001c=g<g009c=`8000=c=`05001c
=g<gLcL00002LcL00`00LcL00004LcL01000LeMcEg=G0P000g=H00@007MHMeP000AgF005001gF7MH
MeP00003MgP01@00MgQgN7Mh00000gMh00D007MhMgQgN00000=gN0800003MgP007NH00=gV004001g
VGNI0002MiT01@00MiUgVGNI00000gNI00<007Ni00000gMh0P001EKm00<005KmE_d00eKm0P001EKm
00<005KmE_d00eKm0`001EKm00<005KmE_d00`0000=Fo@00E_d015Km00<005KmE_d00`0000EFo@00
Oomoo`0007Aoo`0057oo0P0027oo0P0067oo0P0027oo0P003Goo0`004Goo0P0047oo00<007ooOol0
CGoo00<005Km00000P0000=Fo@00E_d01EKm00<005Km00000P000eKm00<005KmE_d00UKm00<005Km
00000P000eKm00<005KmE_d00eKm0P001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d00eKm0P00
1UKm00<005Km00000P0000=Fo@00E_d01EKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km
00000P000UKm00<001Xm00000P000Rfi00D002Vi:KTY^@00008YV@80008YV@04000YV2VH0003:IP2
0002:IP01000:IPYV0000bVH00<002fH00000P000bfH00D002fH;IP]V00000<]V080008aV003000a
V36H008aV005000a^36h<KP00003<KP00`00<KL000020003=KL01@00=KLe]cFg000013Fg00D003Vg
>KLi]`0000<i]`@0008i]`03000i]cVg008i]`03000m]cfg008m]`05000m]cfg?KL00004?KL00`00
?KLm]`02?KL00`00?MLme`02?ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00@MI1eP02@MH00`00
@MI1eP03@MH00`00@MI1eP02@MH00`00AMI5eP03AMH00`00AMI5eP02AMH00`00AMI5eP02AMH00`00
AMI5eP03AMH00`00AMI5eP03AMH00`00BMI9eP03BMH00`00BOI9mP02BOH00`00BOI9mP03BOH00`00
BOI9mP03BOH00`00BOI9mP03BOH00`00BOI9mP04BOH400000dgf001=mP05COH00`00COI=mP03COH0
0`00COI=mP03COH00`00COI=mP03COH01000CQI>5ThF0P0000==mP00DQH0158F00<0058FDQH0158F
00<0058FDQH0158F0P001E8F00<0058FDQH0158F00<0058FDQH00e8F00<005HF000015HE00<005HE
EQD015HE00<005HeESD00eHe0P001UHe00<005He00000P000eHe0P001EHe00<005XeFSD015Xe00@0
05XeFSD000AJ=@03001J=EXe00AJ=@03001J=@0000EJ=@03001JEEYE00AJE@03001NEEiE00ENE@03
001NEEiE009NE@04001NEEiE0007GUD20006GUD01@00GUENEEiE00000eiE00<005ieGWD01Eie00<0
069eHWD01V9e0P001V9f00@0069fHWH000ARMP03001RMV9f009RMP04001RMV9f0005HWH01000HWIR
MP001F:F00@006JFIYH000EVUP04001VUVJF0004IYH01000IYIVUP0016JF00<006JFIYH00VJF00@0
06JfI[H000EV]P03001V]P0000IZ]P03001Z]VZf00EZ]P03001Z]P0000AZ]P05001Z]VZfJ[H00002
J]H00`00J]IZeP04J]H00`00J]IZeP04J]H00`00K]H00003K]H00`00K]I^eP03K]H00`00K_I^mP04
K_H01000K_I^mP000Vkg00<006kgK_L00fkg00<006kg00000Vkg00<006kgK_L00fkg00<006lGKaL0
0VlG00<007<GLaL00g<G00<007<GLaL00W<G00<007<GLaL00W<G00<007<G00000W<G00<007<gLcL0
0W<g00H007<gLcL007<g0004LcL01@00LcMc=g<g000017<g00D007=GLeMcE`00009gF003001cF000
00=gF003001gF7MH009gF005001gF7MHMeP00003MgP01000MgQgN7Mh0P0000=gN000MgP00gMh00@0
07MhMgP0009gN003001gV7NH009gV004001gVGNI0003MiT200000gNI001gV@02MiT01000MkUg^@00
0gMh00<005KmE_d015Km00<005KmE_d00`0000=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d0
1EKm0`001EKm00<005KmE_d00UKm0`001EKm00<007oo0000M7oo000DOol20008Ool2000HOol20008
Ool2000>Ool20009Ool20005Ool3000?Ool00`00Oomoo`1?Ool00`00E_eFo@03E_d00`00E_eFo@03
E_d30006E_d00`00E_eFo@040006E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d000020003
E_d00`00E_eFo@03E_d00`00E_d000020002E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d3
0005E_d00`00E_eFo@03E_d20006E_d010006Sd002Fj0`000bVi00D002VI:IT002VI00<0008YV006
000YV2VH:IP002VH0`000bVH00D002VH:IPYV00000<]V080008]V004000]V2fH0003;IP00`00;IP0
00020004<IP01@00<KPa^36h0000136h00<0036g<KL00P000SFg00<003Fg=KL00SFg00D003Fg=KLe
]`0000@i]`05000i]cVg>KL00002>KL40003>KL00`00?KLm]`02?KL00`00?KLm]`02?KL01@00?KLm
]cfg000013fg00<003gG?ML00cgG00<0047G@ML00T7G00D0047G@MM1e`0000A1eP030011eT7F00=1
eP030011eT7F0091eP030015eTGF00=5eP030015eTGF0095eP030015eTGF0095eP030015eTGF00A5
eP030015eTGF0095eP030019eTWF00=9eP030019mTWf0099mP030019mTWf00A9mP030019mTWf0099
mP030019mTWf00=9mP030019mTWf00=9mP8000A=mP03001=mTgf00A=mP03001=mTgf00==mP03001=
mTgf00==mP03001=mTgf00A=mP<000==mP03001B5U8F00AB5P03001B5U8F00=B5P03001B5U8F00=B
5P8000IB5P03001B5U8F00AB5P03001B5U8F00=B5P8000EF5@03001F5EHE00AF5@03001F=EHe009F
=@03001F5@0000EF=@<000EF=@8000IF=@03001J=EXe00EJ=@8000EJ=@03001J=EXe00EJ=@03001J
=EXe00AJ=@03001JEEYE00AJE@03001NEEiE00ENE@05001NEEiEGUD00003GUD00`00GUENE@05GUD0
0`00GUENE@05GUD01@00GUENEEiE00000eiE00<005ieGWD015ie0P00269e00<0069fHWH01F9f00<0
069f00001V9f00@0069fHWH000ARMP05001RMV9fHWH00004HWH01@00HYIRUV:F00000fJF00<006JF
IYH00VJF00D006JFIYIVUP0000=VUP03001VUVJF009VUP04001VUVJF0005IYH01000I[IV]P001FJf
00<006Jf00001VZf00<006ZfJ[H016Zf00@006ZfJ[H000=Z]P03001Z]VZf009Z]P04001ZeV[F0006
J]H00`00J]IZeP03J]H01`00K]I^eVkF001^eP0000I^eP03001^mVkf00=^mP03001^mVkf009^mP80
00E^m`04001^mfkg0002K_L00`00K_M^m`02K_L00`00KaL00002KaL00`00LaMc5`03LaL00`00LaL0
0002LaL00`00LaMc5`03LaL30002LaL01@00LcMc=g<g000017<g00<007<gLcL00W<g00<007<gLcL0
0W<g0P000g<g00@007=GLeL000AgF005001gF7MHMeP00004MeP01@00MeP007MH00000gMh00D007Mh
MgQgN000009gN003001gN7Mh009gN004001gN7Mh0003MgP20003MiP00`00MiT00003MiT00`00MiUg
V@020003MiT00`00MkT00003MgP00`00MiT00005E_d30005E_d01000E_eFoEKm10001EKm00<005Km
E_d00`0000=Fo@00E_d01EKm00<005Km00000P000UKm00<005KmE_d00eKm00@007ooOol007=oo`00
57oo0P0027oo0P0067oo0P0027oo0P003goo0P0027oo2@0047oo00<007ooOol0Cgoo00<005KmE_d0
15Km00<005Km00000P000eKm00<005KmE_d00eKm0`0015Km00<005KmE_d00eKm0P001EKm00<005Km
E_d00eKm0`001UKm00@005KmE_eFo@<000IFo@03001Fo@000080009Fo@03001FoEKm00=Fo@03001F
o@00008000=Fo@03001FoEKm00=Fo@03001Fo@000080009Fo@03001FoEKm00=Fo@@000<U^P80008Y
^@04000YVBVI0003:IT200000bVH000YV002:IP01000:IPYV2VH0P0000<YV000:IP00RVH00H002fH
;IP]V000;IP30002;IP00`00;IP]V002;IP01000;IP]V2fH0P000S6H00<0036h<KP00S6h00D0036h
<KPa^000008a]`03000e]`0000<000<e]`05000e]cFg=KL00004>KL01@00>KLi]cVg00001CVg1000
00<i]`00?KL00Sfg00<003fg?KL00Sfg00<003fg?KL00Sfg00D003fg?KLm]`0000Dme`030011ed7G
0091e`030011ed7G0091e`030011eT7F0091eP030011eT7F00=1eP030011eT7F0091eP030015eTGF
00=5eP030015eTGF0095eP030015eTGF0095eP030015eTGF00=5eP030015eTGF0095eP030019eTWF
00=9eP030019mTWf00=9mP030019mTWf00=9mP030019mTWf0099mP030019mTWf00A9mP030019mP00
00800003BOH004gf00A=mP03001=mTgf00==mP03001=mTgf00A=mP03001=mTgf009=mP03001=mTgf
00==mP8000I=mP03001B5U8F00=B5P03001B5U8F00=B5P03001B5U8F009B5P03001B5P0000IB5P03
001B5U8F00AB5P03001B5U8F009B5P03001B5@0000EF5@03001F5EHE00AF5@03001F=EHe0080009F
5@03001F=EHe00<0009F=@03001F=EHe009F=@03001F=@0000MF=@03001J=EXe00=J=@8000MJ=@03
001J=EXe00=J=@8000IJ=@03001JEEYE00=JE@8000MNE@04001NEEiE0004GUD00`00GUENE@05GUD0
0`00GUENE@05GUD01000GUENE@001EiE00<005ieGWD00Uie00@005ieGWD000MRM@03001RMV9f00IR
MP8000IRMP04001RMV9f0004HWH01000HWIRMP001F9f00D006:FHYIRUP0000AVUP05001VUVJFIYH0
0004IYH01000IYIVUP0016JF00@006JFIYH000EVUP03001V]P0000MV]P03001Z]VZf00AZ]P03001Z
]P0000EZ]P05001Z]VZfJ[H00002J[H00`00J[IZ]P02J[H00`00J]H00006J]H00`00J]H00003J]H0
0`00K]I^eP02K]H00`00K]H00005K]H00`00K_H00003K_H00`00K_I^mP03K_H00`00K_M^m`04K_L0
1P00K_M^m`00K_L000E^m`06001_5flG001_5`001G<G00H007<GLaL007<G0004LaL01P00LaMc5`00
LaL000Ac=`03001c=g<g009c=`05001c=g<gLcL00004LcL01P00LcMc=`00LcL000=cE`03001gF7MH
009gF005001gF7MHMeP00003MeP01000MeQgF7MH0P000gMh00@007MhMgP000=gN08000=gN004001g
N7Mh0002MgP01P00MiQgV000MiP0009gV@04001gVGNI0003MiT01@00MiT007NI00000WNi00@007Mh
MgP0009gV@03001FoEKm00<00003E_d005Km00EFo@@000=Fo@03001FoEKm00=Fo@<000EFo@03001F
oEKm00=Fo@8000IFo@04001FoEKmE_d30002Ool00`00Oomoo`1`Ool001Aoo`8000Qoo`8001Qoo`80
00Qoo`8000moo`8000Qoo`800003Ool0000000<0015oo`03001oogoo051oo`03001FoEKm00=Fo@<0
00IFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@000080009Fo@03001FoEKm00=Fo@03001F
o@00008000=Fo@03001FoEKm00=Fo@@000=Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm009Fo@<0
00IFo@04001FoEKmE_d30006E_d00`00E_d0000200000eKm000E=`0200029KX00`009IT000020002
:IT01P00:ITYVBVI000UV08000<YV006000YV2VH:IP002VH0P000bVH00<002fH;IP00RfH00@002fH
;IP000<]V005000]V2fH;IP00003;IP00`00<IP000030003<KP01@00<KPa^36h00000c6g00@003Fg
=KLe]`80008e]`03000e]cFg008e]`05000i]cVg>KL00004>KL00`00>KLi]`02>KL01000>KLi]cVg
1@0000<m]`00?KL00Sfg00<003fg?KL00Sfg00<003fg?KL00Sfg00<003gG?ML00SgG00<0047G@ML0
0T7G00<0047G@ML00T7G00<0047F@MH00T7F00<0047F@MH00d7F00<0047F@MH00T7F00<004GFAMH0
0dGF00<004GFAMH00TGF00<004GFAMH00TGF00<004GFAMH00dGF00<004GFAMH00TGF00<004WFBMH0
14WF00<004WfBOH00TWf00<004WfBOH00dWf00<004WfBOH00TWf00<004WfBOH00dWf0`0014Wf00<0
04gfCOH00dgf00<004gfCOH00dgf00<004gfCOH014gf00<004gfCOH00dgf00<004gf00000P0000==
mP00COH01Dgf00<0058FDQH00e8F00<0058FDQH00e8F00<0058FDQH00P000U8F00<0058FDQH0158F
00<0058FDQH0158F00<0058FDQH00P000U8E00<005HEEQD00eHE00<005HEEQD01EHE0P0015HE0`00
1EHe00D005HeESEF=@00009F=@03001F=EHe00EF=@03001J=EXe009J=@03001J=@0000MJ=@03001J
=EXe009J=@03001J=@0000MJ=@05001JEEYEFUD00002FUD00`00GUENE@05GUD20006GUD00`00GUEN
E@03GUD20008GUD20006GUD01@00GWENMEie00000eie00<0069eHWD0169e0P00269f00<0069fHWH0
1F9f00<0069f00001F9f00@0069fHWH000ERMP04001RUV:F0005IYH01000IYIVUP001FJF00<006JF
00001FJF00<006JF00001fJF00<006JfI[H01VJf00<006ZfJ[H016Zf00<006Zf000016Zf00<006Zf
J[H00VZf00<006Zf00001VZf00<006[FJ]H016[F00@006[FJ]H000=ZeP03001^eVkF00=^eP03001^
eVkF00A^eP04001^mVkf0002K_H00`00K_I^mP03K_H00`00K_M^m`03K_L00`00K_M^m`02K_L00`00
K_M^m`03K_L00`00KaM_5`02KaL00`00LaMc5`03LaL00`00LaMc5`02LaL00`00LaMc5`02LaL00`00
LaMc5`02LaL00`00LcMc=`02LcL00`00LcMc=`02LcL00`00LcL00002LcL01@00LcMc=g<g000017<g
00D007=GLeMcE`0000AgF005001gF000MeP00004MeP02@00MeQgF7MH001gN000MgP00003MgP01000
MgQgN0000WMh00<007Mh00000WMh00@007MhMgP000AgV0800005MiT007NIMiT00003MiT01000MiUg
VGNI0P0000Eg^@00MgQgN00000AgV@8000EFo@03001FoEKm00<00003E_d005Km00EFo@03001Fo@00
0080009Fo@03001FoEKm00=Fo@03001FoEKm00<00003E_d005Km00EFo@@0009Fo@04001oogoo001b
Ool001Eoo`8000Ioo`8001Yoo`8000Ioo`8000Moo`8000Moo`8000Qoo`8001Moo`03001oogoo055o
o`03001Fo@00008000=Fo@03001FoEKm00=Fo@8000EFo@03001FoEKm00=Fo@<000EFo@04001FoEKm
E_d40006E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d000020003E_d00`00E_eFo@03E_d0
1000E_d000000eKm00<005KmE_d00eKm10000eKm00<005KmE_d00eKm0`0015Km00<001Dg00000bFj
00@002FI9IT000<YV@07000YVBVI:IT002FH000012VH00D002VH:IPYV000008YV080008YV005000]
V2fH;IP00003;IP200000bfH000]V002;IP00`00;IP]V002;IP01000<IPaV36H0P000S6h00<0036h
<KP00S6h00@0036g<KL000<e]`03000e]`0000<000<e]`03000i]cVg008i]`05000i]cVg>KL00005
>KL01@00>KLi]cVg00000cVg1@0000<m]`00?KL00Sfg00<003fg?KL00Sfg00<003gG?ML00cgG00<0
047G@ML00T7G00D0047G@MM1e`0000A1eP030011eT7F00=1eP030011eT7F0091eP030015eTGF00=5
eP030015eTGF0095eP030015eTGF0095eP030015eTGF00A5eP030015eTGF0095eP030019eTWF00=9
eP030019mTWf0099mP030019mTWf00=9mP030019mTWf00=9mP030019mP0000800003BOH004Wf00E9
mP03001=mTgf009=mP03001=mTgf00A=mP03001=mTgf00==mP03001=mTgf009=mP<000A=mP03001=
mTgf00A=mP03001B5U8F00AB5P03001B5U8F00=B5P8000EB5P03001B5U8F00AB5P03001B5U8F00AB
5P8000EB5@03001F5EHE00=F5@03001F5EHE00=F5@8000=F5@800003EQD005He00EF=@04001F=EHe
0004ESD00`00ESEF=@04ESD01@00FSEJ=EXe00000UXe00<005XeFSD01EXe00D005XeFSEJ=@0000=J
=@03001J=EXe00AJ=@04001JEEYE0003FUD00`00GUENE@05GUD00`00GUENE@05GUD00`00GUENE@02
GUD01000GUENE@001eiE00<005iEGUD01EiE00@005ieGWD000ANM@03001RMF9e00=RM@04001RMF9e
0007HWH00`00HWIRMP06HWH00`00HWIRMP05HWH20007HWH20006IYH00`00IYH00006IYH00`00IYH0
0006IYH00`00IYIVUP06IYH00`00I[IV]P05I[H00`00J[H00004J[H01@00J[IZ]VZf00000VZf00<0
06ZfJ[H00fZf00<006Zf00001VZf00<006[FJ]H016[F00L006[FJ]IZeP00J]H00006K]H00`00K]I^
eP03K]H01`00K_I^mVkf001^mP0000E^mP03001^mP0000=^m`03001^mfkg00=^m`03001^mfkg009^
m`03001_5flG00=_5`03001c5g<G009c5`03001c5g<G00=c5`03001c5g<G009c5`03001c5g<G009c
5`8000=c=`03001c=g<g009c=`05001c=`00LcL00004LcL00`00LcMc=`02LcL01@00LeMcEg=G0000
0gMH00D007MHMeQgF00000AgF005001gF7MHMeP00003MgP01@00MgQgN7Mh00000WMh00<007MhMgP0
0WMh00D007MhMgQgN000009gN003001gV7NH009gV003001gV00000=gV@04001gVGNI0004MiT00`00
MkT00003MgP01`00MiUgVGNI001[nP0000EFo@<000EFo@03001FoEKm00=Fo@8000IFo@04001FoEKm
E_d40005E_d00`00E_eFo@0300000eKm001Fo@04E_d01000Oomoo`00LGoo000EOol20006Ool2000J
Ool20006Ool20007Ool30006Ool20008Ool2000GOol00`00Oomoo`1BOol20006E_d00`00E_d00002
00000eKm001Fo@05E_d00`00E_d000020003E_d00`00E_eFo@02E_d40004E_d00`00E_eFo@03E_d2
0005E_d00`00E_eFo@03E_d30006E_d01000E_eFoEKm0`001UKm00<005Km00000P0000=Fo@00E_d0
1EKm00<005Km00000P000eKm00D005KmE_eFo@00008E=`04000U^RFj00039IT200000bVI000YV@02
:IT00`009IPUV0020002:IP01@00:IPYV2VH00000RVH00<002VH00000P000bfH00H002fH;IP]V000
;IP20004;IP01@00;IP]V2fH00000c6H00<0036H00000`000c6h00D0036g<KLa]`0000<e]`04000e
]cFg=KL20002=KL00`00>KLi]`02>KL01@00>KLi]cVg00001CVg00D003Vg>KLi]`0000@i]`04000m
]cfg?KL500000cfg000m]`02?KL00`00?MLme`03?ML00`00@MM1e`02@ML00`00@MM1e`02@ML00`00
@MI1eP02@MH00`00@MI1eP03@MH00`00@MI1eP02@MH00`00AMI5eP03AMH00`00AMI5eP02AMH00`00
AMI5eP02AMH00`00AMI5eP03AMH00`00AMI5eP02AMH00`00BMI9eP03BMH00`00BOI9mP02BOH00`00
BOI9mP04BOH00`00BOI9mP040004BOH00`00BOI9mP04BOH00`00COI=mP02COH00`00COI=mP04COH0
0`00COI=mP03COH00`00COI=mP0200000dgf001=mP05COH00`00COI=mP03COH00`00DQIB5P04DQH0
0`00DQIB5P02DQH20006DQH00`00DQIB5P04DQH00`00DQIB5P03DQH20006DQD00`00EQEF5@03EQD0
0`00EQEF5@02EQD00`00EQD000030003EQD00`00ESEF=@05ESD20005ESD00`00ESEF=@04ESD01000
FSEJ=@0015Xe00<005XeFSD015Xe00@005XeFSD000AJ=@03001J=EXe00AJ=@03001JE@0000AJE@03
001NEEiE00ENE@03001NEEiE00ENE@05001NEEiEGUD00003GUD00`00GUENE@05GUD00`00GUENE@06
GUD20006GWD01@00HWERMF9e00000f9e00<0069fHWH0169f00<0069e00001f9f00<0069fHWH01F9f
00<0069fHWH01V9f00<006JFIYH01VJF00<006JFIYH01VJF00<006JFIYH01FJF00<006JFIYH01FJF
00<006Jf00001FJf00@006ZfJ[H000=Z]P03001Z]VZf009Z]P04001Z]VZf0006J[H00`00J[IZ]P04
J[H00`00J]H00004J]H00`00J]IZeP02J]H00`00J]H00005K]H00`00K]H00003K]H00`00K_I^mP03
K_H00`00K_I^mP04K_H01000K_I^mP000Vkg00<006kgK_L00Vkg00<006kg00000fkg00<006lGKaL0
0VlG00<007<G00000g<G00<007<GLaL00W<G00<007<G00000W<G00<007<GLaL00W<G00H007<g0000
07<g0004LcL01@00LcMc=g<g000017<g00<007<gLcL00W<g00D007MG001cE`0000AgF004001gF7MH
MeP20003MeP01000MeQgF00017Mh00D007MhMgQgN000009gN003001gN7Mh009gN0800005MgP007Mh
MgP00004MiP00`00MiQgV00200001GNI001gVGNI000017NI00<007NiMkT00P0000=gN000MiT00WNI
00H006_jJoY[nP00E_d300000eKm001Fo@05E_d00`00E_eFo@0300000eKm001Fo@05E_d40002E_d0
0`00E_eFo@04E_d30005E_d00`00E_eFo@02E_d20002Ool00`00Oomoo`1^Ool001Ioo`8000Aoo`80
01aoo`8000Aoo`8000Qoo`@000Aoo`8000Uoo`8001Moo`03001oogoo05Aoo`03001FoEKm00=Fo@80
00EFo@03001FoEKm00=Fo@<000IFo@04001Fo@000002E_d00`00E_eFo@04E_d00`00E_d000020000
0eKm001Fo@05E_d00`00E_d000020003E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d20005
E_d00`00E_eFo@03E_d30006E_d01000E_eFo@000aDg0P0000HU^P009ITUV@009IT20004:IT01000
9IP002FH0`000bVH00D002VH:IPYV000008YV003000]V2fH008]V005000]V2fH;IP00002;IP20002
;IP01@00;IP]V2fH0000136H00@0036H<IPaV080008a^005000a]c6g<KL00003=KL01P00=KLe]cFg
000e]`@000<i]`03000i]cVg008i]`03000i]cVg008i]`03000i]cVg008i]`05000i]cVg>KL00004
?KL01000?KLm]cfg1@0000<m]`00?ML00cgG00<0047G@ML00T7G00<0047G@ML00T7G00<0047F@MH0
0T7F00<0047F@MH00d7F00<0047F@MH00T7F00<004GFAMH00dGF00<004GFAMH00TGF00<004GFAMH0
0TGF00<004GFAMH00dGF00<004GFAMH00TGF00<004WFBMH00dWF00<004WfBOH00dWf00<004WfBOH0
1P000TWf00<004WfBOH014Wf00<004WfBOH00dWf00<004gfCOH00dgf00<004gfCOH00dgf00<004gf
COH014gf0P000dgf00<004gfCOH014gf00<004gfCOH014gf00<0058FDQH00e8F00<0058FDQH00P00
00=B5P00DQH01E8F00<0058FDQH0158F00<0058FDQH00U8F00<0058E00001U8E00<005HEEQD00eHE
00@005HEEQEF5@@000MF5@03001F=EHe00=F=@8000IF=@03001F=EHe00EF=@8000EJ=@03001J=EXe
00EJ=@8000EJ=@03001J=EXe00EJ=@03001JEEYE00AJE@03001NEEiE00=NE@8000MNE@04001NEEiE
0004GUD00`00GUENE@04GUD20008GUD00`00GWENM@05GWD01@00HWERMF9e00000f9e00<0069fHWH0
0f9f00@0069eHWD000IRMP03001RM@0000IRMP03001RMV9f00IRMP03001VUVJF00IVUP03001VUVJF
00IVUP03001VUVJF00AVUP03001VUP0000IVUP03001V]P0000EV]P05001Z]VZfJ[H00002J[H00`00
J[IZ]P02J[H00`00J[H00007J[H00`00J[IZ]P04J[H00`00J]H00003J]H00`00J]IZeP04J]H00`00
K]I^eP04K]H00`00K]H00003K]H00`00K_I^mP03K_H00`00K_I^mP03K_H01`00K_I^mVkf001^m`00
00E^m`06001^mfkg001^m`001FlG00H007<GLaL007<G0005LaL01P00LaMc5`00LaL000=c5`04001c
=g<gLcL20004LcL00`00LcMc=`02LcL20003LcL01@00LcMc=g<g00000gMG00<007MHMeP00WMH00D0
07MHMeQgF000009gF003001gF00000=gF009001gN7MhMgP007Mh001gN000009gN003001gN7Mh009g
N004001gN7Mh0003MgP01@00MiQgV7NH00000WNH00@007NIMiT000=gV@05001gVGNIMiT00002MkT0
1000MiUgV@000gNI00<006_jJoX00V_j0P001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d00`00
00=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d01EKm00<005Km00000P000UKm00<007oo0000
L7oo000FOol8000LOol80009Ool8000:Ool:000?Ool01000Ool00000E7oo00<005Km00000P000UKm
00<005KmE_d00eKm00<005Km00000P000eKm00<005KmE_d00eKm0P001EKm00<005KmE_d00eKm0P00
1EKm00<005KmE_d00eKm0`001UKm00<005Km00000P0000=Fo@00E_d01EKm00<005Km00000P0000=F
o@00E_d01EKm00<005Km00000P000eKm00<005KmE_d00eKm0`0000IFo@005CLE=`007GT200039IT0
0`009ITUV@020002:IT010009IPUV0000bFH0P000RVH00@002VH:IP000<YV080008]V005000]V2fH
;IP00002;IP00`00;IP000020004;IP01@00<IPaV36H00000c6H00<0036G00000`000S6g00D003Fg
=KLe]`0000@e]`04000e]cFg=KL400000cVg000i]`02>KL00`00>KLi]`03>KL01@00>KLi]cVg0000
13Vg00D003fg?KLm]`0000@m]`04000m]cfg?KL50002?ML01@00@MM1ed7G0000147G00<0047F@MH0
0T7F00<0047F@MH00d7F00<0047F@MH00T7F00<004GFAMH00dGF00<004GFAMH00TGF00<004GFAMH0
0TGF00<004GFAMH00dGF00<004GFAMH00TGF00<004WFBMH014WF00<004WfBOH01@000dWf00<004Wf
BOH00TWf00<004WfBOH014Wf00<004WfBOH00dWf00<004gfCOH00dgf00<004gfCOH00dgf00<004gf
COH00dgf0P001Dgf00<004gfCOH00dgf00<004gfCOH014gf00<0058FDQH0158F0P000e8F00<0058F
DQH0158F00<0058FDQH0158F00<0058FDQH00P000U8E00<0058EDQD0158E00<005HEEQD00eHE00<0
05HE00000P000eHE00<005HEEQD015HE00<005HeESD00UHe00<005He00001UHe00<005HeESD01EHe
00<005XeFSD015Xe00<005XeFSD01EXe00<005XeFSD01EXe00<005XeFSD00eXe0P001UYE00<005iE
GUD00UiE00@005iEGUD000MNE@8000INE@03001NEEiE009NE@04001NEEiE0007GUD00`00GWENM@05
GWD01000HWERM@001F9e00D0069fHWIRMP0000=RM@03001RMV9f00=RMP04001RMF9e0005HWH00`00
HWH00006HWH00`00IYH00006IYH00`00IYH00006IYH00`00IYH00005IYH00`00IYH00005IYH01000
I[IV]P0016Jf00<006ZfJ[H00VZf00<006Zf00001VZf00<006ZfJ[H01FZf00<006Zf000016Zf00D0
06[FJ]IZeP00009ZeP03001ZeV[F00AZeP03001^eVkF00=^eP07001^eVkFK]H006kF00001Fkf00<0
06kf00000fkf00<006kfK_H00fkf00<006kgK_L00fkg00L006kgK_M^m`00K_L00004KaL01`00LaMc
5g<G001c5`0000Ac5`03001c5g<G009c5`03001c5g<G009c5`03001c=g<g009c=`03001c=g<g009c
=`05001c=g<gLcL00002LcL00`00LcL00004LcL01000MeMgEgMG0P000gMH00@007MHMeP000AgF005
001gF7MHMeP00003MgP01@00MgQgN7Mh00000gMh00D007MhMgQgN00000=gN0800003MgP007NH009g
V004001gV7NH0003MiT200000gNI001gV@02MiT01000MkUg^@000gNI0P0000AgV@00JoY[nP<00003
E_d005Km00AFo@03001FoEKm00<00003E_d005Km00EFo@<000EFo@03001FoEKm009Fo@<000EFo@03
001FoEKm00=Fo@8000IFo@03001oo`0006moo`0067oo100087oo10003Goo1@002goo2P003Woo0`00
Egoo00<005KmE_d015Km00@005KmE_eFo@@000IFo@03001Fo@0000800003E_d005Km00EFo@03001F
o@000080009Fo@03001FoEKm00=Fo@03001Fo@00008000=Fo@03001FoEKm00=Fo@8000EFo@03001F
oEKm00=Fo@8000EFo@03001FoEKm00=Fo@<000IFo@03001Fo@0000800003E_d002FI008000<E=`03
000MN@0000<UV@05000UVBFI000UV@0300029IP01P009IPUV2FH000YV0<0008YV006000YV2VH:IP0
02VH0`000bfH00D002fH;IP]V00000<]V080008]V005000aV36H<IP00004<IP01000<ILaUc6G0P00
0S6g00D003Fg=KLe]`0000<e]`05000e]cFg=KL00003=KL30002>KL00`00>KLi]`03>KL01@00>KLi
]cVg000013Vg00<003fg?KL00Sfg00D003fg?KLm]`0000@m]`04000m]cfg?KL600000d7G0011e`03
@ML01@00@MI1eT7F00001D7F00<0047F@MH00T7F00<004GFAMH00dGF00<004GFAMH00TGF00<004GF
AMH00TGF00<004GFAMH014GF00<004GFAMH00TGF00<004WFBMH01P000TWF00<004WfBOH00dWf00<0
04WfBOH00dWf00<004WfBOH00dWf00<004WfBOH014Wf00<004gfCOH00Tgf00<004gfCOH014gf00<0
04gf00000P0000==mP00COH014gf00<004gfCOH00dgf00<004gfCOH014gf00<0058FDQH00e8F0P00
1E8F00<0058FDQH0158F00<0058FDQH0158F0P001E8E00<0058EDQD0158E00@005HEEQEF5@@000EF
5@03001F5EHE00AF5@05001F=EHeESD00002ESD00`00ESEF=@05ESD00`00ESEF=@03ESD20007FSD0
0`00FSEJ=@03FSD20007FSD00`00FSEJ=@02FSD00`00FSD00006FUD01@00GUENEEiE00000eiE00<0
05iEGUD01EiE00<005iEGUD01EiE00D005iEGUENE@0000=NE@03001NEEiE00ANE@8000QNM@8000IR
M@05001RMV9fHWH00004HWD01@00HWIRMV9f00000f9e00<0069fHWH00V9f00@0069fHWH000IRMP03
001VUP0000EVUP04001VUVJF0005IYH01000IYIVUP0016JF00D006JFIYIVUP0000=VUP03001V]VJf
009V]P04001V]VJf0005J[H00`00J[H00006J[H00`00J[IZ]P04J[H01000J[IZ]P000fZf00<006[F
J]H00V[F00<006[F00001V[F00<006kF00000fkF00<006kFK]H00VkF00<006kF00001Fkf00<006kf
00000fkf00<006kfK_H00fkf00<006kgK_L00Vkg00<006kgK_L00fkg00<006lGKaL00VlG00<007<G
LaL00g<G00<007<GLaL00W<G00<007<GLaL00g<G00D007<GLaMc5`0000Ac=`<0009c=`03001c=g<g
009c=`05001c=g<gLcL00004LcL01@00MeMgEgMG00000WMG00<007MH00000gMH00<007MHMeP00WMH
00D007MHMeQgF000009gN003001gN7Mh009gN0800003MgP007Mh009gN005001gN7MhMgP00002MiP2
0003MiP01000MiQgV0000WNI00<007NIMiT00P000gNI00<007Ni00000gNI00<007NiMkT010001EKm
00@005KmE_eFo@@000EFo@03001FoEKm00<00003E_d005Km00EFo@03001Fo@000080009Fo@03001F
oEKm00=Fo@03001FoEKm00<00003E_d005Km00EFo@800003Ool007oo06eoo`00MGoo00<007ooOol0
F7oo00<005KmE_d00eKm100015Km00<005KmE_d00eKm0P001EKm00<005KmE_d00eKm0`001EKm00@0
05KmE_eFo@@000IFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@000080009Fo@03001FoEKm
00=Fo@03001Fo@00008000=Fo@03001FoEKm00=Fo@8000EFo@03000UV@0000<E=`03000MNAei0080
008UV@04000UVBFI00039IT200000bFH000UV0029IP01000:IPYV0000bVH00D002VH:IPYV00000<Y
V080008]V004000]V2fH0003;IP00`00;IP000020004<IP01@00<IPaV36H00000c6G00<0036G0000
0P000cFg00D003Fg=KLe]`0000@e]`06000e]cFg=KL003Fg100013Vg00<003Vg>KL00SVg00D003Vg
>KLi]`0000@m]`03000m]cfg008m]`05000m]cfg?KL00005?KL01000?KHm]Sff2P0000=1eP00@MH0
147F00<0047F@MH00T7F00<004GFAMH00dGF00<004GFAMH00TGF00<004GFAMH00TGF00<004GFAMH0
2`000dGF00<004WFBMH00TWF00<004WfBOH014Wf00<004WfBOH00TWf00<004WfBOH00dWf00<004Wf
BOH014Wf00<004gfCOH00Tgf00<004gfCOH00dgf0`0014gf00<004gfCOH00dgf00<004gfCOH014gf
00<004gfCOH00dgf00@0058FDQIB5P800003DQH0058F00AB5P03001B5U8F00AB5P03001B5U8F00=B
5P8000IB5@03001B5E8E00AB5@@00003EQD0000000IF5@03001F5EHE00AF5@04001F=EHe0004ESD0
0`00ESEF=@04ESD00`00ESEF=@02ESD00`00FSD00007FSD00`00FSEJ=@02FSD00`00FSD00007FSD0
1@00FSEJ=EXe00000eXe00<005YEFUD00eYE00@005iEGUD000ANE@03001NEEiE00ENE@03001NEEiE
00ENE@04001NEEiE0004GUD00`00GUENE@03GUD01000GUENE@001eie00<0069eHWD01F9e00@0069f
HWH000ERM@05001RMV9fHWH00004HWD01@00HWIRMV9f00000f9f00<0069fHWH00V9f00@006JFIYH0
00EVUP04001VUVJF0005IYH01000IYIVUP000fJF00<006JFIYH00VJF00D006JFIYIVUP0000AV]P04
001V]VJf0006J[H00`00J[IZ]P04J[H00`00J[H00005J[H01@00J[IZ]VZf00000VZf00<006[FJ]H0
0f[F00<006[FJ]H016[F00@006kFK]H000=^eP03001^eVkF00=^eP03001^mVkf00=^mP07001^mVkf
K_H006kf00001Fkf00<006kf00000fkg00<006kgK_L00fkg00<006lGKaL00VlG00<007<GLaL00g<G
00<007<GLaL00W<G00<007<GLaL00W<G00<007<G00000W<G00<007<gLcL00W<g00H007<g000007<g
0003LcL00`00LcMc=`02LcL01@00LcMc=g<g000017MG00D007MGMeMgE`0000=gF003001gF7MH009g
F005001gF000MeP00003MgP01@00MgQgN7Mh00000WMh0P000gMh00@007MhMgP000=gV005001gV000
MiP00002MiP01000MiUgV@000gNI00D007NI001gV@00009g^@04001gVGNI0003MkT00`00MmT00006
E_d40003E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@03E_d20006E_d01000E_eFoEKm10001EKm
00<005KmE_d00`0000AFo@00Ool006ioo`00MGoo00<007ooOol0FGoo00<005Km00000P000UKm00<0
05KmE_d015Km00<005Km00000P000UKm00<005KmE_d00eKm00<005Km00000P000eKm00<005KmE_d0
0UKm100015Km00<005KmE_d00eKm0P001EKm00<005KmE_d00eKm0`001EKm00@005KmE_eFo@@000IF
o@03001Fo@0000800003E_d005Km00AFo@03000UVBFI0080008E=`04000MN@008IT300029IT01P00
9ITUVBFI000UV0<0008UV004000YV2VH:IP200000bVH000YV002:IP01P00:IPYV2VH000YV0<0008]
V003000]V2fH008]V004000]V2fH;IP20002<IP01@00<IPaV36H0000136G00@0036G<ILaU`800003
=KL003Fg00<e]`05000e]cFg=KL00003=KL00`00=KLe]`02=KL40002>KL01@00>KLi]cVg000013Vg
00D003fg?KLm]`0000@m]`03000m]cfg008m]`03000m]cfg008m]`03000m]Sff008m]P030011eT7F
0091eP040011eT7F@MHO0003AMH00`00AMI5eP02AMH00`00AMI5eP03AMH00`00BMI9eP03BMH00`00
BOI9mP03BOH00`00BOI9mP02BOH00`00BOI9mP04BOH00`00BOI9mP03BOH00`00COI=mP03COH00`00
COH0000200000dgf001=mP05COH00`00COI=mP02COH00`00COI=mP04COH00`00COI=mP04COH30003
DQH00`00DQIB5P03DQH00`00DQIB5P04DQH00`00DQIB5P02DQH00`00DQD00006DQD00`00DQEB5@02
DQD30003EQD00`00EQD00006EQD00`00EQEF5@05EQD20005ESD00`00ESEF=@04ESD01@00ESEF=EHe
00000eXe00<005XeFSD015Xe00D005XeFSEJ=@0000=J=@03001J=EXe00AJ=@04001J=EXe0004FSD0
0`00FUEJE@04FUD20006GUD00`00GUENE@03GUD20008GUD20006GUD01@00GUENEEiE00000eiE00<0
05ieGWD01Eie00<0069eHWD01V9e0P001V9e00@0069fHWH000ERM@04001RMV9f0004HWH01@00HWIR
MV9f000016JF00D006JFIYIVUP0000AVUP05001VUVJFIYH00004IYH01000IYIVUP001FJF00<006JF
00001FJf00<006Jf00001fZf00<006ZfJ[H016Zf00<006Zf000016Zf00<006ZfJ[H00VZf00<006Zf
00001V[F00<006[FJ]H016[F00L006kFK]I^eP00K]H00006K]H00`00K_I^mP03K_H01`00K_I^mVkf
001^mP0000E^mP06001^mVkf001^m`001Fkg00<007<G00000VlG00<007<GLaL00g<G00<007<G0000
0W<G00<007<GLaL00W<G00H007<GLaL007<G0004LcL01000LcMc=g<g0P000g<g00<007<gLcL00W<g
00<007<g00000W<g00D007MGMeMgE`0000AgE`05001gF7MHMeP00003MeP01@00MeQgF7MH00000gMh
00D007MhMgQgN00000=gN005001gN000MgP00003MgP01000MiQgV0000gNH00D007NHMiQgV000009g
V@04001gVGNI0003MiT200001GNi001gVGNI00000gNi00D007OI001g^000009Fo@<00003E_d005Km
00EFo@03001Fo@000080009Fo@03001FoEKm00=Fo@03001FoEKm00<00003E_d005Km00EFo@@0009F
o@03001FoEKm00AFo@<000EFo@03001oo`0006eoo`00MGoo00<007ooOol0FWoo00<005KmE_d015Km
00<005KmE_d00eKm0P001UKm00@005KmE_eFo@@000IFo@04001Fo@000002E_d00`00E_eFo@04E_d0
0`00E_d000020002E_d00`00E_eFo@03E_d00`00E_d000020003E_d00`00E_eFo@02E_d40004E_d0
0`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d010009IT001eh0`000Qei00@0026I8ITQV@800003
9IT002FI008UV@04000UV2FH00039IP01@00:IPYV000:IP00P000bVH00<002VH:IP00RVH00@002VH
:IP000<]V005000]V2fH;IP00003;IP00`00;IP000020004<IP01@00<ILaUc6G00000c6G00<0036G
00000P000cFg00D003Fg=KLe]`0000@e]`05000e]cFg=KL00003>KL40002>KL00`00>KLi]`02>KL0
0`00?KLm]`02?KL01@00?KLm]cfg000013fg00<003fg?KL00cfg00D003ff?KHm]P0000A1eP030011
eT7F0091eP030011eT7F00=1eP030011eT7F0091eP030011eT7F00=1eP030015eTGF0095eP030015
eTGF0095eP030015eTGF00=5eP030015eTGF0095eP030015eTGF00A5eP030019eTWF0099eP030019
mTWf00=9mP030019mTWf00=9mP030019mTWf00=9mP030019mTWf00=9mP03001=mTgf009=mP<000A=
mP03001=mTgf00A=mP03001=mTgf00==mP03001=mTgf00==mP03001=mTgf00==mP8000IB5P03001B
5U8F009B5P03001B5U8F00AB5P03001B5U8F0080009B5@03001B5E8E00AB5@03001B5@000080009B
5@04001F5EHE0003EQD00`00EQEF5@04EQD00`00EQEF5@03EQD20006ESD00`00ESEF=@04ESD01000
ESEF=@0015Xe00<005XeFSD015Xe00@005XeFSD000AJ=@03001J=EXe00EJ=@8000EJ=@03001JEEYE
00AJE@03001NEEiE00ENE@03001NEEiE009NE@04001NEEiE0007GUD00`00GUENE@05GUD01@00GUEN
EEiE00000eiE00<005ieGWD015ie0P00269e00<0069eHWD01V9e0P001V9e00@0069fHWH000ARMP05
001RMV9fHWH00004IYH01000IYIVUP001FJF00@006JFIYH000EVUP03001VUP0000IVUP03001VUP00
00IV]P03001Z]VZf00EZ]P03001Z]P0000AZ]P05001Z]VZfJ[H00002J[H00`00J[IZ]P03J[H00`00
J[H00005J]H00`00J]H00004J]H00`00K]I^eP02K]H00`00K]H00005K]H00`00K]H00003K_H00`00
K_I^mP03K_H00`00K_I^mP03K_H01`00K_I^mVkf001^m`0000E^m`06001c5g<G001_5`001G<G00H0
07<GLaL007<G0004LaL01@00LaMc5g<G000017<g00<007<gLcL00W<g0P000g<g00<007<gLcL00W<g
00D007<g001c=`0000=gE`03001gEgMG009gE`05001gE`00MeP00004MeP01000MeQgF7MH0P0000=g
N000MgP00gMh00@007MhMgP000=gN005001gN7MhMgP00002MiP00`00MiQgV002MiP200001GNH001g
VGNI00000WNI00<007NIMiT00WNI00<007Ni00000gNI00H007NiMkT007OI0003MkP20005E_d00`00
E_eFo@03E_d20006E_d01000E_eFoEKm10001EKm00<005KmE_d00`0000=Fo@00E_d015Km00<005Km
E_d00`0000=Fo@00E_d01EKm00@007ooOol006aoo`00MGoo00<007ooOol0Fgoo00<005KmE_d015Km
00<005Km00000P000UKm00<005KmE_d00eKm100015Km00<005KmE_d00eKm0P001EKm00<005KmE_d0
0eKm0P001UKm00@005KmE_eFo@@000IFo@04001Fo@000002E_d00`00E_eFo@04E_d00`00E_d00002
0002E_d00`00E_eFo@03E_d00`00E_eFo@02E_d010009ITUV@000Qeh00@001ei7GT000<QV@04000Q
V@0000039IT010009IPUV2FH0P0000<UV000:IP00RVH00<002VH:IP00P000RVH00D002VH:IPYV000
00<YV0800003;IP002fH008]V003000]V2fH008]V003000]V2fH008000<aV005000aUc6G<IL00004
<IL00`00<ILaU`020002=KL00`00=KLe]`02=KL01@00=KLe]cFg00000cFg00<003Vg>KL00cVg00<0
03Vg00000`000cVg00<003fg?KL00Sfg00<003fg?KL00Sfg00D003fg?KLm]`0000Dm]`03000m]Sff
008m]P030011eT7F0091eP050011eT7F@MH00005@MH00`00@MI1eP02@MH00`00@MI1eP03@MH00`00
AMI5eP02AMH00`00AMI5eP02AMH00`00AMI5eP04AMH00`00AMI5eP02AMH00`00AMI5eP03AMH00`00
BMI9eP02BMH00`00BOI9mP03BOH00`00BOI9mP03BOH00`00BOI9mP03BOH00`00BOI9mP04BOH40000
0dgf001=mP05COH00`00COI=mP03COH00`00COI=mP03COH00`00COI=mP03COH01000COI=mTgf0P00
00==mP00DQH01E8F00<0058FDQH00e8F00<0058FDQH0158F0P001E8E00<0058EDQD00e8E0P001U8E
0P0015HE00<005HEEQD015HE00<005HEEQD00UHE00<005HE00001UHe00<005HeESD01EHe0P001EXe
00<005XeFSD01EXe0P001EXe00<005XeFSD01EXe00<005XeFSD01EXe00<005YEFUD00eYE00<005iE
GUD01EiE00D005iEGUENE@0000=NE@03001NEEiE00ENE@03001NEEiE00ENE@04001NEEiE0005GUD0
0`00GWENM@02GWD01000HWERM@001f9e00<0069eHWD01V9e00<0069eHWD01V9e0P001V9f00<0069f
00001FJF00@006JFIYH000EVUP04001VUVJF0005IYH00`00IYH00007IYH00`00I[IV]P05I[H00`00
J[IZ]P04J[H01000J[IZ]P0016Zf00D006ZfJ[IZ]P00009Z]P03001Z]VZf00AZ]P03001ZeV[F00AZ
eP03001ZeP0000AZeP03001^eVkF00=^eP03001^eVkF00=^eP04001^eVkF0003K_H00`00K_I^mP03
K_H00`00K_I^mP02K_H00`00K_I^mP03K_H00`00K_M^m`03K_L00`00LaMc5`02LaL00`00LaMc5`03
LaL00`00LaMc5`02LaL00`00LaMc5`02LaL00`00LaMc5`02LaL00`00LcMc=`02LcL00`00LcMc=`02
LcL300000g<g001c=`03LcL01@00LcMc=g<g000017MG00D007MGMeMgE`0000=gE`03001gF7MH009g
F005001gF7MHMeP00002MgP00`00MgQgN002MgP01000MgQgN00017Mh00D007MhMgQgN000009gV005
001gV7NHMiP00002MiP01`00MiUgVGNI001gV@0000AgV@03001g^GNi00800007MiT007NiMkT007OI
000017Nh00<005KmE_d015Km00<005KmE_d00`0000=Fo@00E_d01EKm10000UKm00<005KmE_d015Km
0`001EKm00<005KmE_d00UKm0`001EKm00@005KmE_eFo@@00003Ool007oo06]oo`00MGoo00<007oo
Ool0G7oo00<005KmE_d00eKm0P001UKm00<005Km00000P000UKm00<005KmE_d015Km00<005Km0000
0P000UKm00<005KmE_d00eKm00<005Km00000P000UKm00<005KmE_d00eKm100015Km00<005KmE_d0
0eKm0P001EKm00<005KmE_d00eKm0P001UKm00@005KmE_eFo@L0008UV@04000MN1eh7GP200000aei
000QV@028IT00`008IT000039IT01P009IPUV2FH000UV08000<YV005000YV2VH000YV0030003:IP0
1P00:IPYV2VH000]V08000@]V005000]V2fH;IP00003;IP20002<IP00`00<ILaU`02<IL01@00<ILa
Uc6G00000S6G00<003FG00000`000cFg00D003Fg=KLe]`0000@e]`03000i]cVg008i]`03000i]cVg
008i]`@00003>KL003fg008m]`03000m]cfg008m]`03000m]cfg008m]`03000m]cfg008m]`03000m
]Sff008m]P030011eT7F0091eP030011eT7F0091eP030011eT7F00=1eP030011eT7F0091eP030011
eT7F00=1eP030015eTGF0095eP030015eTGF0095eP030015eTGF00=5eP030015eTGF0095eP030015
eTGF00=5eP030019eTWF0099eP030019mTWf00A9mP030019mTWf0099mP030019mTWf00=9mP030019
mTWf00=9mP8000A=mP03001=mTgf00A=mP03001=mTgf00==mP03001=mTgf00==mP03001=mTgf00A=
mP<000==mP03001B5U8F00AB5P03001B5U8F00=B5P03001B5U8F00=B5P8000IB5@03001B5E8E00<0
0003DQD0058E00AB5@8000EF5@03001F5EHE00AF5@05001F5EHEEQD00002EQD00`00ESEF=@05ESD0
0`00ESEF=@03ESD20006FSD00`00FSEJ=@05FSD00`00FSEJ=@04FSD00`00FSEJ=@05FSD00`00FSEJ
=@05FSD00`00FUEJE@02FUD00`00FUD00006GUD01000GUENE@0015iE00<005iEGUD015iE0P0025iE
0P001UiE00D005ieGWENM@0000=RM@03001RMF9e00ARM@8000QRM@03001RMF9e00IRM@03001RMV9f
00ERMP03001RMP0000IVUP8000MVUP8000MVUP03001VUVJF00IVUP03001V]VJf00AV]P03001V]P00
00EZ]P04001Z]VZf0003J[H00`00J[IZ]P02J[H00`00J[H00007J[H00`00J]IZeP03J]H01@00J]IZ
eV[F00000V[F00<006kFK]H016kF00<006kFK]H00fkF00L006kFK]I^eP00K_H00005K_H00`00K_H0
0003K_H00`00K_I^mP03K_H00`00K_M^m`02K_L00`00LaMc5`03LaL00`00LaMc5`02LaL00`00LaMc
5`03LaL01@00LaMc5g<G000017<G00<007<g00000W<g00<007<gLcL00W<g00H007<gLcL007<g0003
LcL00`00LcMc=`02LcL20002MeL00`00MeMgE`02MeL01000MeMgEgMG0P000gMH00@007MHMeP000=g
N08000=gN004001gN7Mh0003MgP01@00MgP007Mh00000WNH00D007NHMiQgV00000=gV0800005MiT0
07NIMiT00003MiT01000MkUg^@000WNi0P0000Eg^@00MmUgf@0000=g^003001Wn@0000EFo@<000EF
o@03001FoEKm00<00003E_d005Km00AFo@03001FoEKm00<00003E_d005Km00EFo@03001Fo@000080
009Fo@03001FoEKm00=Fo@@000=Fo@04001oogoo000LOol:000;Ool4000>Ool4000TOol007Aoo`03
001oogoo05ioo`03001Fo@000080009Fo@03001FoEKm00=Fo@8000IFo@03001FoEKm00=Fo@8000IF
o@04001FoEKmE_d30006E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d0
0`00E_eFo@03E_d00`00E_d000020002E_d00`00E_eFo@03E_d40002E_d01000:KTY^BVi0`0000HU
V@007GPMN0007GT200038IT00`008ITQV@0200029IT01@009IPUV2FH00000RFH0P000RVH00@002VH
:IP0008YV003000YV2VH008YV005000YV2VH:IP00002;IP20002;IP01@00;IP]V2fH00000bfH00<0
036H00000`000c6G00D0036G<ILaU`0000<aU`04000eUcFG=IL20002=KL00`00=KLe]`02=KL01@00
=KLe]cFg00001CVg00D003Vg>KLi]`0000<i]`D00003?KL003fg008m]`03000m]cfg008m]`03000m
]cfg00<m]`05000m]Sff?KH00004@MH00`00@MI1eP02@MH00`00@MI1eP03@MH00`00@MI1eP02@MH0
0`00@MI1eP03@MH00`00AMI5eP02AMH00`00AMI5eP02AMH00`00AMI5eP03AMH00`00AMI5eP02AMH0
0`00AMI5eP03AMH00`00BMI9eP03BMH00`00BOI9mP03BOH00`00BOI9mP02BOH00`00BOI9mP04BOH0
0`00BOH0000200000dWf001=mP04COH00`00COI=mP03COH00`00COI=mP04COH00`00COI=mP02COH0
0`00COI=mP03COH20006COH00`00DQIB5P03DQH00`00DQIB5P03DQH00`00DQIB5P02DQH00`00DQD0
0006DQD30004DQD00`00DQEB5@02DQD00`00DQD00006EQD00`00EQEF5@03EQD01000EQEF5@0015HE
00<005HeESD015He00<005HeESD00UHe00<005He00001eXe00<005XeFSD00eXe0P001eXe00<005Xe
FSD00eXe0P001eXe00D005YEFUEJE@00009JE@03001NEEiE00ENE@8000INE@03001NEEiE009NE@04
001NEEiE0007GUD00`00GUENE@05GUD01@00GWENMEie00000f9e00<0069eHWD00f9e00@0069eHWD0
00IRM@8000QRM@03001RMV9f00IRMP03001VUVJF00EVUP03001VUVJF00IVUP03001VUVJF00IVUP03
001VUVJF00EVUP03001VUP0000EV]P03001V]P0000AZ]P03001Z]VZf009Z]P04001Z]VZf0005J[H0
0`00J[IZ]P05J[H00`00J]H00004J]H01`00J]IZeV[F001ZeP0000I^eP03001^eP0000=^eP03001^
eVkF009^eP03001^mP0000E^mP06001^mVkf001^mP001Fkf00<006kf00000fkg00<007<GLaL00W<G
00<007<G00000g<G00<007<GLaL00W<G00<007<G00000W<G00<007<GLaL00W<G00H007<gLcL007<g
0004LcL01@00LcMc=g<g000017<g00D007<gLcMc=`00009gE`03001gE`0000=gE`05001gEgMGMeL0
0002MeP00`00MeP00003MeP01000MgQgN0000WMh00<007Mh00000WMh00D007MhMgQgN00000=gN005
001gV7NHMiP00002MiP01@00MiQgV7NH00000WNH0P0000=gV@00MiT00WNI00@007NiMkT000=g^@06
001g^@00001gf@000gNh00H006OiIoUWn@00E_d300000eKm001Fo@05E_d30005E_d00`00E_eFo@02
E_d30005E_d01000E_eFoEKm10001UKm00<005Km00000P0000=Fo@00E_d01EKm00@007ooOol001]o
o`X000Uoo`P000Yoo`P0029oo`00M7oo00<007ooOol0Ggoo0P001EKm00<005Km00000P000UKm00<0
05KmE_d015Km00<005Km00000P000UKm00<005KmE_d00eKm10000eKm00<005KmE_d00eKm0P001UKm
00<005KmE_d00eKm0P001UKm00@005KmE_eFo@<000IFo@03001Fo@000080009Fo@03001FoEKm009F
o@06000Y^BVi:KT002FI0P000aeh00<001ei0000126I00@0026I000QV@<000<UV005000UV2FH000U
V0030002:IP01000:IPYV2VH0P000RVH00D002VH:IPYV000008]V003000]V000008000@]V005000]
V2fH;IP00003<IP20002<IL00`00<ILaU`02<IL01000<ILaU`000cFG00<003FG00000`000cFg00D0
03Fg=KLe]`0000Di]`05000i]cVg>KL00004>KL01000>KLi]cVg0`000Sfg00<003fg?KL00Sfg00<0
03fg?KL00cfg00<003ff?KH00Sff00<0047F@MH00T7F00D0047F@MI1eP0000E1eP030011eT7F0091
eP030011eT7F00=1eP030015eTGF0095eP030015eTGF0095eP030015eTGF00=5eP030015eTGF00=5
eP030015eTGF00=5eP030019eTWF0099eP030019mTWf00=9mP030019mTWf00=9mP030019mTWf00D0
00A9mP03001=mTgf00==mP03001=mTgf00==mP03001=mTgf00A=mP03001=mTgf009=mP04001=mTgf
COH200000dgf001=mP05COH00`00DQIB5P04DQH00`00DQIB5P02DQH00`00DQIB5P020002DQD01000
DQEB5E8E10001U8E00D0058EDQEB5@00009B5@03001F5EHE00AF5@03001F5EHE00AF5@8000EF5@03
001F=EHe00AF=@05001F=EHeESD00002ESD00`00FSEJ=@05FSD00`00FSEJ=@02FSD00`00FSD00007
FSD00`00FSEJ=@02FSD01000FSEJ=@001UXe00@005YEFUD000=JE@03001NEEiE00ENE@03001NEEiE
00ENE@05001NEEiEGUD00003GUD00`00GUENE@05GUD00`00GUENE@05GUD01000GWENM@001F9e00D0
069eHWERM@0000=RM@03001RMF9e00=RM@04001RMF9e0006HWD20008HWH00`00IYIVUP05IYH00`00
IYIVUP06IYH00`00IYIVUP05IYH00`00IYH00005IYH01000IYIVUP0016Jf00@006JfI[H000AZ]P03
001Z]VZf009Z]P03001Z]P0000IZ]P03001Z]VZf00AZ]P04001ZeV[F0003J]H00`00J]IZeP02J]H0
0`00J]H00005K]H01000K]I^eP000VkF00<006kFK]H016kF00<006kfK_H00fkf00L006kfK_I^mP00
K_H00005K_H01P00K_I^mP00K_L000Ac5`07001c5g<GLaL007<G000017<G00H007<GLaL007<G0004
LaL00`00LcMc=`02LcL00`00LcMc=`02LcL00`00LcMc=`02LcL20002LcL01@00LcMc=g<g000017MG
00D007MGMeMgE`0000AgE`05001gF7MHMeP00003MeP01000MgQgN00017Mh00D007MhMgQgN00000=g
N004001gN7MhMgP200000gNH001gV002MiP01000MiQgV0000gNH00<007NH00000gNI00@007NiMkT0
00=g^@06001g^GNi001g^@000gNh00<006OiIoT010001EKm00<005KmE_d00`0000=Fo@00E_d01EKm
00<005Km00000P000UKm00<005KmE_d00eKm10000eKm00<005KmE_d015Km0P001EKm00<005KmE_d0
0eKm0P0000=oo`00Ool07Woo0P003Goo0P0017oo0P002Woo0P0017oo0P008Woo001dOol00`00Oomo
o`1QOol00`00E_eFo@02E_d30005E_d00`00E_eFo@03E_d20006E_d00`00E_d000020002E_d00`00
E_eFo@03E_d00`00E_d000020002E_d00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@03
E_d40003E_d00`00E_eFo@03E_d20006E_d01@00E_eFoEKm000012Vi00<002FI00000aeh00<001ei
7GT00P000R6I00@0026I8IT0008QV@03000UV2FH008UV004000UV2FH00029IP01@00:IPYV2VH0000
0RVH00<002VH00000P000bVH00D002fH;IP]V00000<]V080008]V005000]V2fH;IP00003<IP00`00
<IL000030003<IL01000<ILaU`0013FG00@003FG=ILeU`80008e]`03000e]cFg008e]`03000i]cVg
008i]`03000i]cVg008i]`05000i]cVg>KL00004>KL00`00?KL000030003?KL00`00?KLm]`03?KL0
0`00?KHm]P02?KH00`00@MI1eP02@MH00`00@MI1eP02@MH00`00@MI1eP03@MH00`00@MI1eP02@MH0
0`00@MI1eP02@MH00`00AMI5eP02AMH00`00AMI5eP03AMH00`00AMI5eP03AMH00`00AMI5eP02AMH0
0`00AMI5eP03AMH00`00BMI9eP02BMH00`00BOI9mP03BOH00`00BOI9mP02BOH40003BOH00`00BOI9
mP04BOH00`00COI=mP02COH00`00COI=mP04COH00`00COI=mP03COH00`00COI=mP03COH30003COH0
0`00COI=mP04COH00`00DQIB5P04DQH00`00DQIB5P03DQH20005DQD30004DQD00`00DQEB5@03DQD0
1000DQEB5@00158E00<005HEEQD00eHE00<005HEEQD015HE00<005HEEQD015HE00<005HeESD015He
00@005HeESD000AF=@03001J=EXe00AJ=@05001J=EXeFSD00003FSD00`00FSEJ=@04FSD01@00FSEJ
=EXe00000eXe00<005XeFSD01EXe0P001EYE00<005iEGUD015iE00<005iEGUD01EiE00D005iEGUEN
E@0000=NE@03001NEEiE00ANE@8000QNE@8000IRM@05001RMF9eHWD00003HWD00`00HWERM@03HWD0
1000HWERM@001F9e00@0069eHWD000IRMP03001RM@0000EVUP03001VUP0000IVUP03001VUP0000EV
UP04001VUVJF0005IYH01000IYIVUP000fJf00<006JfI[H00VJf00@006ZfJ[H000EZ]P03001Z]P00
00EZ]P03001Z]P0000EZ]P05001ZeV[FJ]H00002J]H00`00J]IZeP03J]H00`00K]I^eP04K]H01000
K]I^eP000VkF00<006kFK]H016kF00<006kfK_H00Vkf00<006kfK_H00fkf00<006kfK_H00fkf00L0
06kfK_I^mP00K_L00004LaL01`00LaMc5g<G001c5`0000Ac5`05001c5g<GLaL00004LaL00`00LcMc
=`03LcL01@00LcMc=g<g000017<g00H007<g000007<g0003LcL00`00MeMgE`02MeL01@00MeMgEgMG
00000gMG00<007MHMeP00WMH00D007MHMeQgF000009gN003001gN7Mh009gN0800003MgP007Mh009g
N005001gN7MhMgP00002MiP01@00MiQgV7NH00000WNH00D007NHMiQgV000009gV0800003MiT007Ni
009g^@04001g^GNi0002MkT00`00MkUg^@0200000gNh000000020003E_d00`00E_eFo@03E_d30005
E_d00`00E_eFo@03E_d20006E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_eFo@0300000eKm
001Fo@04E_d00`00E_eFo@0300001EKm001oogoo00007Woo0P0037oo0P001Woo0P0027oo0P001Woo
0P008Goo001dOol00`00Oomoo`1ROol01000E_d000000eKm00<005KmE_d00eKm00<005Km00000P00
0UKm00<005KmE_d00eKm0P001UKm00<005KmE_d00UKm0`001EKm00<005KmE_d00eKm0P001UKm00<0
05Km00000P0000=Fo@00E_d01EKm00<005Km00000P000UKm00<005KmE_d015Km00D005KmE_eFo@00
00<Y^@03000UVBFI0080008MN004000MN@008GT300028IT010008ITQVB6I0P000RFH00@002FH9IP0
00<UV0800003:IP002VH008YV004000YV2VH:IP20002:IP01000;IP]V0000bfH00<002fH00000P00
0bfH00<0036H<IP00S6H00@0036G<ILaU`80008aU`05000aUc6G<IL00003=IL01P00=ILeUcFG000e
]`@000<e]`03000i]cVg00<i]`05000i]cVg>KL00004>KL01@00>KLi]cVg000013fg100000<m]`00
?KL00cfg00<003ff?KH00Sff00<0047F@MH00T7F00<0047F@MH00T7F00<0047F@MH00d7F00<0047F
@MH00T7F00<0047F@MH00d7F00<004GFAMH00TGF00<004GFAMH00TGF00<004GFAMH00dGF00<004GF
AMH00TGF00<004GFAMH00dGF00<004WFBMH00TWF00<004WfBOH014Wf100000=9mP00BOH014Wf00<0
04WfBOH014Wf00<004gfCOH00Tgf00<004gfCOH014gf00<004gfCOH00dgf00<004gfCOH00Tgf0P00
1Tgf00<004gfCOH00dgf00<0058FDQH0158F00<0058FDQH00U8F0P000e8E10001U8E00<0058EDQD0
158E0P001E8E00<005HEEQD015HE00<005HEEQD00UHE0P001UHE00<005HeESD01EHe0P001EHe00<0
05XeFSD015Xe00@005XeFSD000AJ=@03001J=EXe00AJ=@04001J=EXe0004FSD00`00FSEJ=@05FSD0
0`00FUEJE@04FUD00`00GUENE@03GUD00`00GUD00006GUD01000GUENE@001EiE00<005iEGUD00UiE
00@005iEGUD000MNE@03001RMF9e00ERM@04001RMF9e0005HWD01@00HWERMF9e00000f9e00<0069e
HWD00f9e00@0069eHWD000ERMP04001RMF9e0005IYH00`00IYH00005IYH01000IYIVUP001FJF00@0
06JFIYH000AVUP03001VUVJF009VUP04001V]VJf0004I[H00`00J[H00007J[H00`00J[IZ]P04J[H0
0`00J[H00004J[H00`00J]IZeP02J]H00`00J]H00006J]H00`00K]I^eP03K]H00`00K]I^eP02K]H2
0006K]H00`00K_H00003K_H00`00K_I^mP03K_H00`00K_I^mP02K_H00`00K_I^mP03K_H00`00LaMc
5`02LaL00`00LaMc5`03LaL00`00LaMc5`02LaL00`00LaMc5`02LaL00`00LaMc5`02LaL00`00LcMc
=`02LcL00`00LcL00002LcL00`00LcMc=`02LcL00`00LcMc=`020003LcL00`00MeMgE`02MeL01@00
MeL007MG00000gMG00<007MHMeP00WMH00D007MH001gF000009gN003001gN7Mh009gN003001gN7Mh
008000=gN004001gN7Mh0003MiP200000gNH001gV002MiP01000MiQgV0000WNH00<007NiMkT00`00
00Eg^@00MkUg^@00009g^@04001g^GNi0002MkT00`00MmT00006E_d00`00E_d000020002E_d00`00
E_eFo@03E_d00`00E_eFo@0300000eKm001Fo@05E_d20005E_d00`00E_eFo@03E_d30005E_d00`00
E_eFo@02E_d30005E_d01000Oomoo`007Goo0P0037oo0P001Woo0P0027oo0P001Woo0P008Goo001d
Ool00`00Ool00002001QOol00`00E_eFo@04E_d01000E_eFoEKm0`001UKm00<005Km00000P000UKm
00<005KmE_d015Km00@005Km000000=Fo@03001FoEKm00=Fo@03001Fo@000080009Fo@03001FoEKm
00=Fo@8000EFo@03001FoEKm00=Fo@<000EFo@03001FoEKm00=Fo@D000@Y^@04000UV@008GT30002
7GT010008GTQNB5i0P0000HQV@008ITQV@009GP300029IP01P009IPUV2FH000UN0<0008YV006000Y
V2VH:IP002VH0`000RfH00<002fH;IP00RfH00<002fH;IP00P000bfH00D0036H<IPaV00000<aU`03
000aU`0000<0008aU`05000eUcFG=IL00004=IL01000=KLe]cFg0P000SFg00<003Vg>KL00cVg00D0
03Vg>KLi]`0000@i]`03000i]cVg008i]`05000m]cfg?KL00003?KL50002?KL01@00?KHm]Sff0000
147F00<0047F@MH00T7F00<0047F@MH00d7F00<0047F@MH00T7F00<0047F@MH00d7F00<004GFAMH0
0TGF00<004GFAMH00TGF00<004GFAMH00dGF00<004GFAMH00TGF00<004GFAMH00dGF00<004WFBMH0
0dWF00<004WfBOH0100014Wf00<004WfBOH014Wf00<004WfBOH00dWf00<004gfCOH00dgf00<004gf
COH00dgf00<004gfCOH014gf100000==mP00COH01Dgf00<004gfCOH014gf00<0058FDQH00e8F00<0
058FDQH00P0000=B5@0000000P000e8E00<0058EDQD0158E00<0058EDQD00e8E0P001U8E00<005HE
EQD015HE00D005HEEQEF5@00009F5@03001F5EHE00AF5@03001F=EHe00=F=@8000IF=@03001J=EXe
00EJ=@8000EJ=@03001J=EXe00EJ=@8000EJ=@03001J=EXe00EJ=@03001JEEYE00AJE@03001NEEiE
009NE@04001NEEiE0007GUD20006GUD01@00GUENEEiE00000eiE00<005iEGUD01EiE00<0069eHWD0
1V9e0P001V9e00@0069eHWD000ERM@05001RMF9eHWD00003HWD00`00HWIRMP03HWH01000HWERM@00
16JF00@006JFIYH000EVUP04001VUVJF0004IYH00`00IYIVUP02IYH01000IYIVUP001FJF00<006Jf
00001FJf00<006Zf00001fZf00<006ZfJ[H00fZf00D006ZfJ[IZ]P00009Z]P03001ZeV[F00=ZeP03
001ZeP0000EZeP03001^eP0000A^eP03001^eVkF009^eP03001^eVkF00A^eP07001^mVkfK_H006kf
00001Fkf00<006kf00000fkf00<006kfK_H00fkf00<007<GLaL00W<G00<007<GLaL00g<G00D007<G
LaMc5`0000Ac5`03001c5`00009c5`03001c=g<g009c=`06001c=g<g001c=`0017<g00<007<gLcL0
0W<g00D007<gLcMc=`0000AgE`04001gEgMG0004MeL01@00MeQgF7MH00000gMH00D007MhMgQgN000
00=gN009001gN7MhMgP007Mh001gN000009gN005001gV7NHMiP00002MiP300001GNH001gV7NH0000
0WNH00D007NiMkUg^@00009g^@07001g^GNiMkT007Ni00000WNi00@007NiMkUg^@800003MiP005Km
00AFo@8000IFo@04001FoEKmE_d40005E_d00`00E_eFo@0300000eKm001Fo@04E_d00`00E_eFo@03
00000eKm001Fo@05E_d00`00E_d000020002E_d00`00E_eFo@03E_d200000goo001oo`0LOol2000;
Ool20008Ool20006Ool20008Ool2000POol007=oo`<006Eoo`03001FoEKm00=Fo@@000=Fo@03001F
oEKm00=Fo@<000EFo@03001FoEKm00=Fo@8000IFo@04001FoEKmE_d30006E_d00`00E_d000020002
E_d00`00E_eFo@03E_d00`00E_d000020003E_d00`00E_eFo@03E_d00`00E_d000020002E_d00`00
7Sd000020002:KT010009ITUV@000R5i00@001ei7GT000<QN@04000QN@0000038IT010009GPUN2Eh
0P0000<UV0009IP00RFH00@002Eh9GP000<YV005000YV2VH:IP00002:IP01@00;IP]V2fH00000bfH
00@002fH;IP]V080008]V005000aV36H<IP00004<IL01000<ILaUc6G0P0000<aU`00=IL00cFG00D0
03FG=ILeU`0000<e]`03000e]`0000<000@i]`03000i]cVg008i]`05000i]cVg>KL00004>KL01@00
?KLm]cfg000013fg00@003ff?KHm]PH00003?KH0047F00=1eP050011eT7F@MH00005@MH00`00@MI1
eP02@MH00`00@MI1eP03@MH00`00AMI5eP02AMH00`00AMI5eP02AMH00`00AMI5eP03AMH00`00AMI5
eP03AMH00`00AMI5eP03AMH00`00BMI9eP050003BMH00`00BOI9mP03BOH00`00BOI9mP03BOH00`00
BOI9mP03BOH00`00COI=mP03COH00`00COI=mP03COH00`00COI=mP03COH20004COH00`00COI=mP04
COH00`00COI=mP04COH00`00DQIB5P04DQH20000158E000000001U8E00<0058EDQD0158E00<0058E
DQD00U8E00<0058E00001U8E00<005HEEQD015HE00@005HEEQD000=F5@03001F5EHE00AF5@03001F
=EHe009F=@03001F=@0000IF=@03001J=EXe00EJ=@03001J=EXe00AJ=@03001J=EXe00EJ=@03001J
=EXe00EJ=@03001J=EXe00=J=@8000MJE@04001NEEiE0003GUD00`00GUENE@05GUD00`00GUENE@05
GUD01@00GUENEEiE00000eiE00<005iEGUD015iE0P00269e00<0069eHWD01F9e00@0069eHWD000ER
M@04001RMF9e0005HWD01@00HWIRMV9f0000169e00@006JFIYH000AVUP05001VUVJFIYH00004IYH0
1000IYIVUP001FJF00@006JFIYH000EVUP03001V]P0000IV]P03001Z]VZf00EZ]P03001Z]P0000AZ
]P05001Z]VZfJ[H00002J[H00`00J]IZeP04J]H00`00J]IZeP04J]H00`00K]H00003K]H00`00K]I^
eP03K]H00`00K]I^eP04K]H01`00K_I^mVkf001^mP0000A^mP07001^mVkfK_H006kf00001Fkf00<0
07;g00000W<G00<007<GLaL00g<G00<007<G00000W<G00<007<GLaL00W<G00H007<GLaL007<G0004
LcL01@00LcMc=g<g000017<g00<007<gLcL00W<g0`0000=c=`00MeL00gMG00@007MGMeMgE`80009g
E`03001gF7MH009gF004001gF7MHMeP200000gMh001gN003MgP01000MgQgN0000gMh00D007MhMgQg
N000009gV005001gV7NHMiP00002MiP01@00MiQgV7NH00000WNH00@007NiMkT000=g^@800007MkT0
07NiMkT007Ni00000gNi0P000WNH00<005KmE_d00`0000=Fo@00E_d01EKm10000eKm00<005KmE_d0
0eKm0`001EKm00<005KmE_d00UKm0`001EKm00@005KmE_eFo@@000IFo@03001Fo@0000800005E_d0
07ooOol0000LOol2000;Ool20008Ool20006Ool20008Ool2000POol007=oo`03001oogoo06Ioo`03
001Fo@000080009Fo@03001FoEKm00=Fo@03001Fo@00008000=Fo@03001FoEKm00=Fo@03001Fo@00
0080009Fo@03001FoEKm00=Fo@@000=Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm009Fo@<000IF
o@04001FoEKmE_d30006E_d010007Sd0026j0`000RFI00@0025i8GTQN@8000037GT0025i008QN@03
000QN@0000<QV@06000UN2Eh9GP002Eh0P000bFH00@002Eh9GPUN0800003:IP002VH008YV004000Y
V2VH:IP200000bfH000]V002;IP01P00;IP]V2fH000]V0<000@aV005000aUc6G<IL00003<IL00`00
<IL000020003=IL01@00=ILeUcFG000013Fg00@003Fg=KLe]`@0008i]`05000i]cVg>KL00004>KL0
1@00>KLi]cVg000013fg00D003fg?KLm]`0000Dm]P04000m]Sff?KH:00000d7F0011eP04@MH00`00
@MI1eP02@MH00`00@MI1eP02@MH00`00AMI5eP02AMH00`00AMI5eP03AMH00`00AMI5eP03AMH00`00
AMI5eP0;0002BMH00`00BMI9eP03BMH00`00BOI9mP03BOH00`00BOI9mP03BOH00`00BOI9mP04BOH0
0`00COI=mP02COH00`00COI=mP04COH00`00COH0000200000dgf001=mP04COH00`00COI=mP03COH0
0`00COI=mP04COH00`00DQIB5P03DQH40003DQD00`00DQEB5@04DQD00`00DQEB5@03DQD00`00DQEB
5@020002DQD00`00DQEB5@05DQD00`00EQEF5@04EQD20004EQD00`00EQEF5@04EQD01@00ESEF=EHe
00000UHe00<005HeESD01EHe00<005XeFSD00eXe0P001eXe00<005XeFSD00eXe0P001eXe00<005Xe
FSD00UXe00@005XeFSD000IJE@04001NEEiE0004GUD00`00GUENE@04GUD00`00GUENE@05GUD01000
GUENE@001EiE00<005iEGUD00UiE00@005iEGUD000MRM@03001RMF9e00IRM@8000IRM@04001RMF9e
0005HWD01000HWIRMP001F9e00@006JFIYH000AVUP04001VUVJF0005IYH01000IYIVUP001FJF00<0
06JF00001fJF00<006JfI[H01FJf00<006ZfJ[H016Zf00@006ZfJ[H000=Z]P03001Z]VZf009Z]P03
001Z]P0000MZeP03001ZeV[F00=ZeP07001^eVkFK]H006kF00001FkF00<006kF000016kF00<006kf
K_H00fkf00<006kfK_H00fkf00L006kfK_I^mP00K_H00004K_H01P00L_Mbm`00LaL000Ec5`06001c
5g<G001c5`0017<G00<007<GLaL00W<G00<007<gLcL00W<g00<007<gLcL00W<g00<007<gLcL00W<g
00D007<gLcMc=`00009g=`8000AgE`05001gEgMGMeL00002MeL00`00MeL00003MeP01@00MeQgF7MH
00000WMh00<007MhMgP00WMh00@007MhMgP000AgN0800005MgP007NHMiP00003MiP01000MiQgV7NH
0P0000EgV000MiQgV000009g^@05001g^GNiMkT00002MkT200001GNi001g^GNi00000WNi00<007OI
00000gNH0P001EKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005Km00000P0000=Fo@00E_d01EKm
00<005Km00000P000UKm00<005KmE_d00eKm10000eKm00<005KmE_d015Km0P001EKm00@007ooOol0
01]oo`8000]oo`8000Qoo`8000Ioo`8000Qoo`80021oo`00Lgoo00<007ooOol0Igoo0P001EKm00<0
05KmE_d00UKm0`001UKm00@005KmE_eFo@<000IFo@03001Fo@0000800003E_d005Km00EFo@03001F
o@00008000=Fo@03001FoEKm00=Fo@04001Fo@000003E_d00`00E_eFo@03E_d40003E_d00`00E_eF
o@03E_d400038KX200001RFI000QNB5i000MN@8000<QN@03000QNB5i0080008QV@07000UN2Eh9GP0
02Eh00000bFH00H002Eh9GPUN0009GP20003:IP01P00:IPYV2VH000YV08000@]V005000]V2fH;IP0
0003;IP20002<IP01@00<ILaUc6G0000136G00<0036G<IL00P000SFG00<003FG=IL00SFG00D003Fg
=KLe]`0000<e]`04000e]cFg=KL40002>KL00`00>KLi]`02>KL00`00>KLi]`02>KL01@00?KLm]cfg
000013fg00<003ff?KH00Sff00<003ff?KH00Sff00<003ff?KH00Sff00@0046f@KI1]Q000091eP03
0015eTGF0095eP030015eTGF00/00095eP030015eTGF00=5eP030019eTWF0099eP030019eTWF00A9
eP030019mTWf0099mP030019mTWf00=9mP030019mTWf00A9mP03001=mTgf009=mP03001=mTgf00==
mP<000A=mP03001=mTgf00==mP03001=mTgf00A=mP03001=mTgf00==mP04001B5U8FDQH40005DQD0
0`00DQEB5@04DQD00`00DQEB5@04DQD20005DQD00`00DQEB5@04DQD00`00EQEF5@03EQD20006EQD0
0`00EQEF5@03EQD01000ESEF=@0015He00<005HeESD015He00<005XeFSD00UXe00<005Xe00001eXe
00<005XeFSD00UXe00<005Xe00001eXe00D005XeFSEJ=@0000=J=@03001JEEYE00AJE@03001NE@00
00ENE@03001NEEiE00=NE@03001NE@0000MNE@8000INE@05001NEEiEGUD00003GUD00`00HWERM@04
HWD20008HWD00`00HWERM@06HWD20006HWD01000HWIRMP001F9e00<006JF00001FJF00@006JFIYH0
00EVUP03001VUP0000MVUP03001VUVJF00IVUP03001V]VJf00AV]P03001Z]P0000EZ]P05001Z]VZf
J[H00002J[H00`00J[IZ]P03J[H00`00J]IZeP05J]H00`00J]H00003J]H00`00K]I^eP02K]H00`00
K]H00005K]H00`00K]H00003K]H00`00K_I^mP04K_H00`00K_I^mP02K_H00`00K_I^mP03K_H00`00
K_I^mP03K_H01P00L_Mbm`00LaL000Ec5`05001c5g<GLaL00005LaL00`00LaMc5`02LaL01@00LcMc
=g<g000017<g00<007<g00000W<g00<007<gLcL00W<g00D007LgMcMg=`0000AgE`05001gEgMGMeL0
0003MeL01@00MeQgF7MH00000gMH00@007MhMgQgN08000=gN004001gN7Mh0003MgP01000MgQgN000
0gNH00@007NHMiP000=gV004001gV7NH0003MiP00`00MkT00003MkT01P00MkUg^GNi001g^@800007
MkT007NiMkT007OI000017NH0P001EKm0`001EKm00<005KmE_d00eKm0P001EKm00@005KmE_eFo@@0
00IFo@03001Fo@0000800003E_d005Km00EFo@03001FoEKm00<00003E_d005Km00AFo@04001oogoo
000KOol2000;Ool20008Ool20006Ool20008Ool2000POol007=oo`03001oogoo06Uoo`03001FoEKm
00=Fo@04001Fo@000003E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d30004E_d00`00E_eF
o@03E_d30006E_d01000E_eFoEKm0`001UKm00<005Km00000P0000=Fo@00E_d01EKm00<005Km0000
0P0000=Fo@004CP00P000R6j00@0026I000000<QN@03000MNAei0080008QN@04000QN@008GP30003
9GP00`009GPUN00200029IP01@009GPUN2Eh00000REh0P000RVH00D002VH:IPYV000008YV080008]
V005000]V2fH;IP00003;IP00`00;IL000020004<IL01@00<ILaUc6G00000S6G00<0036G00000`00
0cFG00D003Fg=KLe]`0000@e]`03000e]cFg008e]`03000i]`0000<000<i]`03000i]cVg008i]`05
000m]cfg?KL00004?KL00`00?KHm]P03?KH01@00?KHm]Sff000013ff00<0046f@KH00T6f00<0047F
@MH00d7F00<0047F@MH00T7F00@0047F@MI1ePX00095eP030015eTGF00=5eP030015eTGF0095eP03
0015eTGF00=5eP030019eTWF00=9eP030019eTWF00=9eP030019mTWf0099mP030019mTWf00A9mP03
0019mTWf00=9mP03001=mTgf00==mP03001=mP0000800003COH004gf00E=mP03001=mTgf009=mP03
001=mTgf00A=mP03001=mTgf00A=mP@0009Am@03001B5E8E00=B5@03001B5E8E00AB5@03001B5E8E
00=B5@8000IB5@03001B5E8E00AB5@03001F5EHE009F5@03001F5@0000IF5@03001F5EHE00AF5@80
00EF=@03001F=EHe00AF=@05001J=EXeFSD00003FSD00`00FSEJ=@04FSD01@00FSEJ=EXe00000eXe
00<005XeFSD015Xe00@005XeFSD000AJ=@03001JEEYE00EJE@03001NEEiE00ANE@03001NEEiE009N
E@04001NEEiE0007GUD00`00GUENE@05GUD01@00GUENEEiE00000eiE00<0069eHWD00f9e00@0069e
HWD000MRM@03001RMF9e00IRM@03001RMF9e00IRM@8000MRM@8000IVUP8000MVUP03001VUVJF00IV
UP03001VUVJF00EVUP03001V]P0000EV]P03001Z]P0000AZ]P03001Z]VZf009Z]P03001Z]P0000IZ
]P03001ZeV[F00AZeP04001ZeV[F0003J]H00`00K]I^eP03K]H00`00K]I^eP03K]H01@00K]I^eVkF
00000VkF00<006kfK_H00fkf00<006kf00000fkf00<006kfK_H00fkf00<006kfK_H00Vkf00<007;g
L_L00W;g00<007<GLaL00g<G00<007<GLaL00W<G00<007<GLaL00W<G00<007<GLaL00W<G00<007<g
00000W<g00<007<gLcL00W<g00H007<gLcL007<g0003LcL01000McMg=gLg0`000WMG00D007MGMeMg
E`0000AgE`05001gF7MHMeP00003MeP01000MgQgN0000WMh00<007Mh00000WMh00D007MhMgQgN000
00=gN0800005MiP007NHMiP00003MiP01000MiQgV7NH0P0000EgV000MkUg^@00009g^@05001g^GNi
MkT00002MkT01P00MkT00000MkT0009gf@05001gV7NHMiP00002MiT00`00E_d0000200000eKm001F
o@05E_d00`00E_eFo@0300000eKm001Fo@04E_d40003E_d00`00E_eFo@04E_d20005E_d00`00E_eF
o@03E_d30005E_d01000E_eFoEKm0`000Woo00<007ooOol067oo0P002goo0P0027oo0P001Woo0P00
27oo0P0087oo001cOol00`00Oomoo`1ZOol01000E_eFoEKm0`001UKm00<005Km00000P0000=Fo@00
E_d01EKm00<005Km00000P000eKm00<005KmE_d00UKm00<005Km00000P000eKm00<005KmE_d00eKm
10000eKm00<005KmE_d00eKm0P001EKm00<005KmE_d00eKm0`0015Km00@0014h4CP0008Q^P03000Q
V@0000<QN@05000MNAei000MN@0300028GT010008GPQN0000bEh00D002Eh9GP002Eh00<000<UN005
000UN2Eh000UN0030003:IP01@00:IPYV000:IP00`000bfH00<002fH;IP00RfH00<002fG;IL00P00
0c6G00D0036G<ILaU`00008aU`03000aUc6G008aU`80008eU`03000e]cFg008e]`05000e]cFg=KL0
0004=KL00`00>KLi]`02>KL400000cVg000i]`02>KL00`00?KLm]`02?KL01@00?KLm]cfg00001Cff
00<003ff?KH00Sff00<003ff?KH00Sff00D0046f@KI1]P0000E1eP030011eT7F0091eP030011eT7F
00=1eP030015eTGF0095eP030015eTGF0095eP030015eTGF00=5eP030015eTGF00=5eP030015eTGF
00=5eP030019eTWF0099eP030019eTWF00=9eP030019mTWf00=9mP030019mTWf00=9mP030019mTWf
00=9mP03001=mTgf009=mP<000A=mP03001=mTgf00A=mP03001=mTgf009=mP03001=mTgf00A=mP03
001=mTgf009=mP<000IAm@03001B5E8E009B5@03001B5E8E00AB5@04001B5E8EDQD200000e8E001B
5@05DQD00`00DQEB5@04DQD01@00EQEF5EHE00000UHE00<005HEEQD015HE00<005HEEQD015HE00<0
05HeESD015He00<005HeESD015He00@005XeFSD000AJ=@03001J=EXe00AJ=@04001J=EXe0004FSD0
0`00FSEJ=@05FSD20005FSD00`00FUEJE@05FUD00`00GUENE@05GUD01000GUENE@000eiE00<005iE
GUD01EiE00<005iEGUD01EiE00@005iEGUD000ENE@05001RMF9eHWD00003HWD00`00HWERM@04HWD0
0`00HWD00007HWD00`00HWERM@06HWD00`00HWERM@06HWD00`00IYIVUP05IYH00`00IYIVUP06IYH0
0`00IYIVUP05IYH00`00IYH00005IYH01000I[IV]P0016Jf00D006ZfJ[IZ]P00009Z]P03001Z]VZf
00=Z]P03001Z]P0000EZ]P03001Z]P0000EZeP07001ZeV[FJ]H006[F00001VkF00<006kFK]H00fkF
00L006kFK]I^eP00K]H00005K_H01000K_I^mP000Vkf00<006kfK_H00fkf00<006kf00000Vkf00<0
07;gL_L00g;g00<007<GLaL00W<G00<007<GLaL00W<G00<007<G00000g<G00<007<GLaL00W<G00D0
07<g001c=`0000Ac=`03001c=g<g009c=`05001c=g<gLcL00004McL01P00MeL00000MeL0009gE`03
001gEgMG009gE`05001gE`00MeP00003MeP01@00MgQgN7Mh00000gMh00D007MhMgQgN000009gN005
001gN7MhMgP00002MiP01@00MiQgV7NH00000gNH00@007NHMiP0009gV0800003MkT007Ni009g^@04
001g^GNi0002MkT01@00MkUg^@00MkT00P0000=gf@00MiP00WNH00@007NIMiUgV@8000EFo@04001F
oEKmE_d50005E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_eFo@0300000eKm001Fo@04E_d0
0`00E_eFo@0300000eKm001Fo@05E_d40003E_d00`00Ool0000JOol2000;Ool20008Ool20006Ool2
0008Ool2000POol007=oo`03001oogoo06]oo`<000=Fo@03001FoEKm00=Fo@8000EFo@03001FoEKm
00=Fo@<000IFo@03001FoEKm00@000IFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@000080
009Fo@03001FoEKm00=Fo@03001Fo@00008000=Fo@05001FoEKmE_d000034CP300028IT200028GT0
10007GTMN@000Qei00@0025i8GT000<QN080008UN004000UN2Eh00029GP00`009GPUN0029GP01000
9GPUN0000REh00D002VH:IPYV00000<YV003000YV2VH008000<]V005000]V2fH;IP00003;IL20002
<IL00`00<ILaU`02<IL01000<ILaU`000c6G00<003FG00000`000cFg00D003Fg=KLe]`0000De]`05
000i]cVg>KL00003>KL30002>KL00`00?KLm]`02?KL00`00?KLm]`02?KL00`00?KHm]P02?KH00`00
?KHm]P02?KH00`00?KHm]P02?KH00`00@KI1]P02@KH00`00@MI1eP03@MH00`00@MI1eP02@MH00`00
@MI1eP02@MH00`00AMI5eP02AMH00`00AMI5eP03AMH00`00AMI5eP03AMH00`00AMI5eP02AMH00`00
AMI5eP03AMH00`00BMI9eP02BMH00`00BMI9eP03BMH00`00BOI9mP03BOH00`00BOI9mP03BOH00`00
BOI9mP04BOH400000dgf001=mP05COH00`00COI=mP03COH00`00COI=mP03COH00`00COI=mP03COH0
0`00COH0000300000dge001Am@05DOD00`00DQEB5@03DQD00`00DQEB5@04DQD30003DQD00`00DQEB
5@04DQD00`00DQEB5@04DQD01000EQEF5@0015HE00<005HEEQD015HE00<005HEEQD00UHE0P001UHe
00<005HeESD01EHe0P001EXe00<005XeFSD01EXe0P001EXe00<005XeFSD01EXe00<005XeFSD01EXe
00<005YEFUD00eYE0P001eiE00@005iEGUD000ANE@03001NEEiE00=NE@03001NE@0000MNE@8000IN
E@05001RMF9eHWD00003HWD00`00HWERM@03HWD01000HWERM@001V9e00<0069e00001f9e00<0069e
HWD01V9e00<006JFIYH01FJF00<006JFIYH01FJF00<006JF00001FJF00@006JFIYH000EVUP04001V
]VJf0003I[H00`00J[IZ]P02J[H01000J[IZ]P001VZf00<006ZfJ[H016Zf00<006Zf000016[F00<0
06[FJ]H00V[F00<006[F00001FkF00<006kF00000fkF00<006kFK]H00fkF00<006kfK_H016kf00H0
06kfK_H006kf0005K_H01000K_I^mP000Vkf00<007;gL_L00W;g00<007<G00000g<G00<007<GLaL0
0W<G00H007<GLaL007<G0004LaL01@00LcMc=g<g000017<g00<007<gLcL00g<g00D007<gLcMc=`00
00=g=`04001gEgMGMeL20003MeL01@00MeMgEgMG00000gMG0P000gMH00@007MhMgP000AgN0800003
MgP007Mh009gN004001gN7Mh0003MiP200000gNH001gV002MiP01000MiQgV0000gNH00<007Nh0000
0gNi00@007NiMkT0009g^@04001g^GNi0002MkT00`00MkT00003MiP01`00MiUgVGNI001[n`0000EF
o@@000=Fo@03001FoEKm00AFo@8000EFo@03001FoEKm00=Fo@<000EFo@04001FoEKmE_d40005E_d0
0`00E_eFo@0300000eKm001Fo@05E_d00`00Ool0000IOol2000;Ool20008Ool20006Ool20008Ool2
000POol007=oo`03001oogoo06]oo`03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm00=F
o@03001Fo@00008000=Fo@03001FoEKm00=Fo@<000AFo@03001FoEKm00=Fo@8000EFo@03001FoEKm
00=Fo@8000IFo@04001FoEKmE_d40006E_d01@00E_eFoEKm00000Q4h00L001Ui0000026I000MN@03
00027GT010007GTMNAei0P0000HQN@008GPQN0008GP300029GP010009GPUN2Eh0P000REh00@002Eh
9GP000<UN080008YV004000YV2VH0003:IP20002;IP01@00;IP]V2fH00000bfG00<002fG00000`00
0c6G00@0036G<IL000<aU`03000eUcFG008eU`80008e]`03000e]cFg008e]`03000e]cFg008e]`05
000i]cVg>KL00004>KL00`00>KL000030003?KL00`00?KLm]`02?KL00`00?KHm]P03?KH01@00?KHm
]Sff000013ff00<0046f@KH00T6f00<0047F@MH00d7F00<0047F@MH00T7F00<0047F@MH00T7F00<0
04GFAMH00dGF00<004GFAMH00TGF00<004GFAMH00dGF00<004GFAMH00TGF00<004GFAMH00dGF00<0
04WFBMH00TWF00<004WFBMH014WF00<004WfBOH00TWf00<004WfBOH00dWf00<004WfBOH00dWf0P00
14gf00<004gfCOH014gf00<004gfCOH00dgf00<004gfCOH00dgf00<004gfCOH00Tgf1@000dge00<0
057eDOD0157e00<0058EDQD00e8E00<0058EDQD00e8E0P001U8E00<0058EDQD0158E00<0058EDQD0
158E0P001EHE00<005HEEQD015HE00L005HEEQEF5@00EQD00007ESD00`00ESEF=@03ESD20006FSD0
0`00FSEJ=@05FSD00`00FSEJ=@05FSD00`00FSEJ=@03FSD20007FSD00`00FUEJE@02FUD01000GUEN
E@001UiE00<005iE00001EiE00<005iEGUD00UiE00@005iEGUD000MNE@03001NEEiE00ENE@04001R
MF9e0005HWD01@00HWERMF9e00000f9e00<0069eHWD00f9e00@0069eHWD000IRM@03001RM@0000IR
M@03001VU@0000EVUP03001VU@0000IVUP03001VUP0000EVUP04001VUVJF0004IYH00`00I[IV]P02
I[H01000I[IV]P0016Zf00<006Zf00001fZf00<006ZfJ[H00fZf00D006ZfJ[IZ]P00009ZeP03001Z
eV[F00AZeP03001^eVkF00A^eP03001^eP0000=^eP03001^eVkF00=^eP03001^mVkf00=^mP03001^
mVkf009^mP8000E^mP06001^mVkf001^mP001G;g00H007<GLaL007<G0004LaL01`00LaMc5g<G001c
5`0000Ac5`05001c=g<gLcL00004LcL00`00LcMc=`02LcL01@00LcL007<g00000gLg00<007MGMeL0
0gMG00@007MGMeL000AgE`09001gEgMGMeL007MG001gF000009gN003001gN7Mh009gN004001gN7Mh
0003MgP01@00MgQgN7Mh00000WNH00<007NHMiP00P000gNH00@007NHMiP0009gV003001g^7Nh0080
0003MkT007Ni009g^@03001g^@00009g^@04001g^GNi0002MkT200000gNH001gV@02MiT01P00Jo][
nf_k001Fo@<00003E_d005Km00EFo@03001FoEKm00<00003E_d005Km00EFo@03001Fo@0000800003
E_d005Km00EFo@@000=Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm00=Fo@800003Ool007oo01Mo
o`8000]oo`8000Qoo`8000Ioo`8000Qoo`80021oo`00LWoo00<007ooOol0KGoo00<005KmE_d00eKm
0`001EKm00@005KmE_eFo@@000IFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@000080009F
o@03001FoEKm00=Fo@03001Fo@000080009Fo@03001FoEKm00=Fo@@000AFo@03001FoEKm00=Fo@<0
0003E_d0014h008A>003000IN@00008QV@04000MNAei7GT200001Qei000MNAei000MN@<0008QN004
000QN25h00039GP01@009GPUN0009GP00`000REh00H002Eh9GPUN000:GP30002:IP01P00:IPYV2VH
000]V0<000@]V005000]UbfG;IL00003;IL20002<IL01000<ILaU`00136G00H003FG=ILeU`00=IL4
0003=KL00`00=KLe]`02=KL00`00>KLi]`02>KL01@00>KLi]cVg000013Vg100000<m]`00?KL00Sfg
00<003ff?KH00cff00<003ff?KH00Sff00<003ff?KH00Sff00D0046f@KI1]P0000E1eP030011eT7F
0091eP030011eT7F00=1eP030015eTGF0095eP030015eTGF0095eP030015eTGF00=5eP030015eTGF
0095eP030015eTGF00=5eP030019eTWF00=9eP030019eTWF00=9eP030019mTWf0099mP030019mTWf
00A9mP030019mP0000800003BOH004gf00A=mP03001=mTgf00==mP03001=mTgf00A=mP03001=mTgf
009=mP03001=mP0000800003COH0000000I=m@03001AmE7e00=Am@03001B5E8E00=B5@03001B5E8E
009B5@03001B5@0000IB5@03001B5E8E00AB5@03001B5E8E00=B5@8000IF5@03001F5EHE00AF5@04
001F5EHE0003EQD00`00ESEF=@04ESD00`00ESEF=@02ESD00`00ESD00007FSD00`00FSEJ=@03FSD2
0007FSD00`00FSEJ=@02FSD00`00FSD00007FSD01@00FUEJEEYE00000eiE00<005iEGUD01EiE00<0
05iEGUD01EiE00@005iEGUD000=NE@03001NEEiE00ENE@03001NEEiE00INE@8000IRM@05001RMF9e
HWD00004HWD01@00HWERMF9e00000f9e00<0069eHWD00f9e00@0069eHWD000ERM@04001VUFJE0005
IYH00`00IYD00005IYH01000IYIVUP0016JF00<006JFIYH00VJF00D006JFIYIVUP0000AV]P03001V
]P0000IZ]P03001Z]VZf00EZ]P03001Z]P0000AZ]P05001Z]VZfJ[H00002J]H00`00J]IZeP04J]H0
0`00K]I^eP03K]H01`00K]I^eVkF001^eP0000E^eP03001^mP0000A^mP03001^mVkf009^mP03001^
mVkf00=^mP03001^mVkf009^mP03001bmg;g00=bm`03001c5g<G009c5`03001c5g<G00=c5`03001c
5g<G009c5`03001c5g<G009c5`07001c=g<gLcL007<g00000W<g00<007<gLcL00g<g00@007<gLcL0
00Ag=`03001gEgMG009gE`<00003MeL007MG009gE`05001gEgMGMeL00003MeL01@00MgQgN7Mh0000
0gMh00@007MhMgQgN0800003MgP007Mh009gN004001gV7NH0003MiP01@00MiP007NH00000WNH00@0
07NHMiP0009g^003001g^7Nh00<00007MkT007NiMkT007Ni00000WNi00@007NiMkT0009g^@05001g
VGNIMiT00004Jo/20005E_d00`00E_eFo@03E_d30005E_d01000E_eFoEKm10001EKm00<005KmE_d0
0`0000=Fo@00E_d01EKm00<005Km00000P0000=Fo@00E_d01EKm00<005KmE_d00`0000AFo@00Ool0
01Qoo`8000aoo`8000Ioo`8000Qoo`8000Ioo`80025oo`00LWoo00<007ooOol0KWoo00<005Km0000
0P000eKm00<005KmE_d00UKm100015Km00<005KmE_d00eKm0P001EKm00<005KmE_d00eKm0P001UKm
00@005KmE_eFo@@000EFo@03001Fo@000080009Fo@03001FoEKm00AFo@03001Fo@000080009Fo@<0
00<A>003000INAUi00<000<MN@04000MN@0000037GT010007GTMN@000R5h00@0025h8GPQN0800003
9GP002Eh008UN004000UN2Eh9GP200000bEh000UN0029GP01000:GPYN0000bVH00D002VH:IPYV000
00<]V080008]V005000]UbfG;IL00003;IL00`00<IL000030002<IL01@00<ILaUc6G00000cFG00<0
03FG=IL00SFG0P000SFg00<003Fg=KL00cFg00D003Vg>KLi]`0000@i]`05000i]cVg>KL00003>KL5
00000cfg000m]P03?KH00`00?KHm]P02?KH00`00?KHm]P02?KH00`00@KI1]P02@KH00`00@MI1eP03
@MH01@00@MI1eT7F00001D7F00<004GFAMH00TGF00<004GFAMH00TGF00<004GFAMH00dGF00<004GF
AMH00dGF00<004GFAMH00dGF00<004WFBMH00TWF00<004WFBMH00dWF00<004WfBOH00dWf00<004Wf
BOH01@0014Wf00<004gfCOH00dgf00<004gfCOH00dgf00<004gfCOH014gf00@004gfCOI=mP<0009=
mP800003COD004ge00E=m@03001AmE7e00AAm@03001B5E8E009B5@03001B5E8E0080009B5@03001B
5E8E00AB5@03001B5E8E00AB5@03001B5E8E009B5@03001F5@0000IF5@03001F5EHE00EF5@8000AF
5@03001F=EHe00AF=@05001F=EHeESD00002ESD00`00FSEJ=@05FSD00`00FSEJ=@02FSD00`00FSD0
0007FSD01@00FSEJ=EXe00000eXe00<005XeFSD015Xe00@005YEFUD000ANE@03001NEEiE00ENE@03
001NEEiE00ENE@04001NEEiE0004GUD00`00GUENE@03GUD00`00GUD00007GUD00`00HWERM@05HWD0
1000HWERM@001F9e00D0069eHWERM@0000ARM@05001RMF9eHWD00003HWD00`00HWERM@03HWD01000
IYEVU@0016JF00D006JEIYEVU@0000AVUP05001VUVJFIYH00003IYH00`00IYIVUP02IYH01000IYIV
UP001FJf00<006Jf00001VZf00<006ZfJ[H016Zf00@006ZfJ[H000=Z]P03001Z]VZf009Z]P03001Z
eP0000IZeP03001^eP0000A^eP07001^eVkFK]H006kF00001FkF00<006kf00000fkf00<006kfK_H0
0fkf00<006kfK_H00fkf00<006kfK_H00Vkf00<007;gL_L00W;g00<007<GLaL00g<G00<007<GLaL0
0W<G00<007<GLaL00g<G00<007<GLaL00W<G00D007<gLcMc=`00009c=`03001c=`0000Ac=`04001c
=g<gLcL20002McL00`00MeMgE`02MeL00`00MeMgE`030003MeL01000MeMgE`0017MG00@007MhMgP0
00AgN004001gN7Mh0002MgP20003MgP01000MiQgV0000WNH00D007NHMiQgV00000=gV003001gV000
009g^005001g^7NhMkP00002MkP200001gNi001g^GNi001g^@00009g^@04001g^GNiMkT2000017NI
001[nf_k0`0000=Fo@00E_d01EKm00<005Km00000P0000=Fo@00E_d01EKm10000eKm00<005KmE_d0
0eKm0`001EKm00<005KmE_d00eKm0P001EKm00@005KmE_eFo@D000EFo@03001oo`0001Moo`8000ao
o`8000Ioo`8000Qoo`8000Ioo`80025oo`00LWoo00<007ooOol0Kgoo0P001UKm00@005Km0000009F
o@03001FoEKm00AFo@03001Fo@000080009Fo@03001FoEKm00=Fo@03001Fo@000080009Fo@03001F
oEKm00=Fo@@000AFo@03001FoEKm009Fo@<000EFo@03001FoEKm00=Fo@8000IFo@04000Ao0000002
4CP010006GT001Ui0P000aei00<001ei00000aei00@001ei7GTMN@8000068GP0025h8GP0025h0P00
0bEh00H002Eh9GPUN0009GP200039GP01000:GPYN2Uh0P0000<YV000:IP00RVH00H002fH;IP]V000
;IP30003;IL00`00;IL]U`02;IL01000<ILaUc6G0P0000<aU`00<IL00S6G00<003FG=IL00SFG00H0
03FG=ILeU`00=IL40004=KL01@00>KLi]cVg000013Vg00D003Vg>KLi]`0000@i]`04000m]Sff?KH5
0002?KH01@00?KHm]Sff000013ff00<0046f@KH00T6f00<0047F@MH00d7F00<0047F@MH00T7F00<0
047F@MH00T7F00<004GFAMH00dGF00<004GFAMH00TGF00<004GFAMH00dGF00<004GFAMH00TGF00<0
04GFAMH00dGF00<004WFBMH00TWF00<004WFBMH00dWF00<004WfBOH00TWf10000dWf00<004WfBOH0
14Wf00<004gfCOH00Tgf00<004gfCOH014gf00<004gfCOH00dgf10000Tgf0`000dge00<004geCOD0
14ge00<0057eDOD0157e00<0058EDQD00e8E0P001E8E00<0058EDQD00e8E00<0058EDQD0158E00<0
058EDQD00P000UHE00<005HEEQD01EHE00<005HEEQD00eHE0P001EHE00<005HeESD015He00@005He
ESD000AF=@03001J=EXe00AJ=@05001J=EXeFSD00003FSD00`00FSEJ=@04FSD01000FSEJ=@0015Xe
00<005XeFSD01EXe0P001UiE00<005iEGUD00eiE0P001eiE00<005iE00001EiE00<005iEGUD00UiE
00@005iEGUD000MNE@03001RMF9e00IRM@8000IRM@04001RMF9e0005HWD01@00HWERMF9e0000169e
00D0069eHWERM@0000AVU@04001VUVJF0004IYD01@00IYIVUVJF000016JF00@006JFIYH000EVUP03
001VUP0000MV]P03001Z]VZf00AZ]P03001Z]P0000EZ]P05001Z]VZfJ[H00002J[H00`00J[IZ]P03
J[H00`00J]IZeP04J]H01000K]I^eP000fkF00<006kFK]H00fkF00<006kFK]H00fkF00L006kfK_I^
mP00K_H00005K_H00`00K_H00003K_H00`00K_I^mP02K_H00`00L_H00003L_L00`00LaMc5`02LaL0
0`00LaL00003LaL00`00LaMc5`02LaL00`00LaL00002LaL01@00LcMc=g<g000017<g00<007<gLcL0
0W<g00D007<gLcMc=`00009g=`03001g=`0000AgE`09001gEgMGMeL007MG001gE`0000=gE`09001g
EgMGMeL007Mh001gN00000=gN004001gN7Mh0003MgP01@00MiP007Mh00000WNH00@007NHMiP000Ag
V0800005MiP007NHMiP00002MkP01000MkQg^0000gNh00H007Ni000007Ni0002MkT00`00MkT00003
MkT00`00MkUg^@040005E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@0300000eKm001Fo@05E_d0
0`00E_d000020002E_d00`00E_eFo@03E_d00`00E_eFo@0300000eKm001Fo@04E_d40003E_d00`00
E_eFo@04E_d200000goo001oo`0AOol300000goo0000000=Ool20004Ool2000:Ool20004Ool2000R
Ool0079oo`03001oo`00008006moo`03001FoEKm00=Fo@8000EFo@03001FoEKm00=Fo@8000IFo@04
001FoEKmE_d30006E_d00`00E_d000020002E_d00`00E_eFo@04E_d01000E_d000000eKm00<005Km
E_d00eKm00<005Km00000P000UKm00<005KmE_d00eKm0`0000@EN@000000008IN@03000IN@0000<M
N@03000MNAei0080008MN@05000MNAei000QN00200038GP00`008GPQN00200029GP01`009GPUN2Eh
000UN00000<UN006000YN2Uh:GP002Uh0P000bVH00<002fH;IP00RfH00<002fH;IP00P000bfG00D0
02fG;IL]U`0000<aU`04000aU`000004<IL01@00=ILeUcFG00000cFG00<003FG=IL00SFG0`000SFg
00<003Vg>KL00SVg00D003Vg>KLi]`0000@i]`05000i]cVg>KL00004?KH01000?KHm]Sff1P0000<m
]P00?KH00Sff00<0046f@KH00T6f00<0047F@MH00d7F00<0047F@MH00T7F00<0047F@MH00T7F00<0
04GFAMH00dGF00<004GFAMH00TGF00<004GFAMH00dGF00<004GFAMH00TGF00<004GFAMH00dGF00<0
04WFBMH00TWF00<004WFBMH014WF100000=9eP00BOH014Wf00<004WfBOH014Wf00<004gfCOH00Tgf
00<004gfCOH014gf00<004gfCOH00Tgf0P0014gf0P001Tge00<004geCOD00dge00<0057eDOD0157e
00<0058EDQD00U8E0P001U8E00<0058EDQD0158E00<0058EDQD0158E0P001EHE00<005HEEQD015HE
00<005HEEQD00UHE00<005HE00001EHE00<005HeESD01EHe0P001EHe00<005XeFSD015Xe00@005Xe
FSD000AJ=@03001J=EXe00EJ=@8000EJ=@03001J=EXe00EJ=@03001NEEiE00ENE@03001NEEiE009N
E@04001NEEiE0007GUD00`00GUENE@04GUD00`00GUENE@02GUD01000GUENE@001UiE00<0069E0000
1f9e00<0069eHWD01V9e0P001V9e00@0069eHWD000ERM@04001RMF9e0005IYD01000IYIVUP0016JE
00D006JFIYIVUP0000AVUP03001VUP0000MVUP8000MV]P03001Z]VZf00AZ]P03001Z]P0000AZ]P03
001Z]VZf009Z]P03001Z]P0000IZ]P03001ZeV[F00AZeP05001^eVkFK]H00002K]H00`00K]I^eP03
K]H00`00K]I^eP03K]H01`00K_I^mVkf001^mP0000E^mP06001^mVkf001^mP001Fkf00H007;fL_H0
07;g0005LaL01P00LaMc5`00LaL000Ec5`06001c5g<G001c5`000g<g00<007<gLcL00W<g00<007<g
LcL00W<g00D007<gLcMc=`0000=g=`03001gEgMG009gE`09001gEgMGMeL007MG001gE`0000=gE`03
001gEgMG009gE`03001gN7Mh008000=gN004001gN7Mh0002MgP01@00MiQgV7NH00000gNH00@007NH
MiP000=gV003001gV7NH00800005MiP007NhMkP00002MkP01@00MkQg^7Nh00000WNi00H007Ni0000
07Ni0002MkT01000MkUg^@000gNi00@007?J000000EFo@03001FoEKm00<00003E_d005Km00AFo@<0
00EFo@03001FoEKm00=Fo@8000IFo@04001FoEKmE_d40005E_d00`00E_d0000200000eKm001Fo@05
E_d00`00E_eFo@0300000eKm00000002000AOol6000=Ool8000:Ool8000ROol0079oo`8007=oo`03
001Fo@0000800003E_d005Km00EFo@03001Fo@000080009Fo@03001FoEKm00=Fo@@000=Fo@03001F
oEKm00=Fo@<000EFo@03001FoEKm00=Fo@8000IFo@04001FoEKmE_d30006E_d00`00E_d000020000
15Km000000000QEi00@001Ui6GT0008IN@80008MN@04000MN@007GT300037GT00`008GP000038GP0
1@008GPQN0008GP00`000bEh00<002Eh9GP00P000REh00D002Uh:GPYN000008YN080008YV005000]
V2fH;IP00003;IP20002;IL01@00;IL]UbfG0000136G00@0036G000000<aU`05000eUcFG=IL00004
=IL01@00=ILeUcFG00000SFG10000cVg00<003Vg>KL00SVg00D003Vg>KLi]`0000@i]`05000m]Sff
?KH00005?KH01000?KHm]Sff1@0000<m]P00@KH00T6f00<0047F@MH00d7F00<0047F@MH00T7F00<0
047F@MH00T7F00<004GFAMH00dGF00<004GFAMH00TGF00<004GFAMH00dGF00<004GFAMH00TGF00<0
04GFAMH00dGF00<004WFBMH00dWF00<004WFBMH0100014WF00<004WfBOH014Wf00<004WfBOH00dWf
00<004gfCOH00dgf00<004gfCOH00dgf00<004gf00000P000Tgf100000==m@00COD01Dge00<004ge
COD014ge00<0057eDOD00e7e00<0058EDQD00P0000=B5@00DQD01E8E00<0058EDQD0158E00<0058E
DQD00e8E0P001UHE00<005HEEQD015HE00D005HEEQEF5@00009F5@03001F5EHE00AF5@03001F=EHe
00AF=@03001F=EHe00AF=@03001J=EXe00EJ=@8000EJ=@03001J=EXe00EJ=@03001J=EXe00AJ=@03
001J=EXe00EJ=@03001NEEiE00ENE@05001NEEiEGUD00003GUD00`00GUENE@05GUD00`00GUENE@05
GUD01000GUENE@0015iE00<005iEGUD00UiE00@0069EHUD000MRM@03001RMF9e00IRM@03001RMF9e
00IRM@8000IRM@04001RMF9e0005IYD00`00IYH00006IYD00`00IYH00006IYH20007IYH00`00I[IV
]P05I[H00`00J[H00004J[H01000J[IZ]P0016Zf00<006ZfJ[H00VZf00<006Zf00001FZf00<006[F
000016[F00<006kFK]H00VkF00<006kF00001FkF00<006kF00000fkF00<006kfK_H00fkf00<006kf
K_H00fkf00L006kfK_I^mP00K_H00004K_H01`00L_IbmW;f001bm`0000Ac5`07001c5g<GLaL007<G
000017<G00<007<GLaL00W<G00D007<gLcMc=`0000Ac=`03001c=`00009c=`05001c=g<gLcL00004
McL20003MeL01000MeMgE`000WMG00<007MG00000gMG00D007MGMeMgE`0000=gN005001gN000MgP0
0002MgP01000MgQgN00017NH0P0000EgV000MiQgV00000=gV007001gV7NHMiP007Nh00000gNh00<0
07Nh00000gNh00@007NiMkT0009g^@06001g^@00001g^@000WNi00L007NiMkUg^@00LmX00002MkT0
1000E_eFoEKm10001EKm00<005Km00000P0000=Fo@00E_d01EKm00<005KmE_d00`0000=Fo@00E_d0
1EKm10000UKm00<005KmE_d015Km0P001EKm00<005KmE_d00eKm0`001EKm00<007oo000057oo0`00
3goo10003Woo100097oo001bOol00`00Oomoo`1cOol00`00E_eFo@03E_d00`00E_eFo@03E_d20006
E_d00`00E_d000020002E_d00`00E_eFo@03E_d00`00E_d000020003E_d00`00E_eFo@03E_d00`00
E_d000020002E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d20005E_d300025GT200001AUi
000IN@006GT00`000Qei00@001ei7GT000<MN@03000QN25h0080008QN004000QN25h00028GP01@00
9GPUN2Eh00000REh00<002Eh00000P000bUh00D002Uh:GP002Uh00<000<]V006000]V2fH;IP002fG
0`0012fG00D0036G<ILaU`00008aU`80008aU`03000eUcFG008eU`05000eUcFG=IL00003=IL00`00
=ILeU`03=IL20002>KL00`00>KLi]`02>KL01@00>KLi]cVg000013Vg00<003ff?KH00Sff00<003ff
?KH00Sff00<003ff?KH00Sff00@003ff?KHm]PD00003@KH0047F00A1eP050011eT7F@MH00005@MH0
0`00AMI5eP02AMH00`00AMI5eP02AMH00`00AMI5eP03AMH00`00AMI5eP03AMH00`00AMI5eP03AMH0
0`00BMI9eP050003BMH00`00BMI9eP03BMH00`00BOI9mP03BOH00`00BOI9mP03BOH00`00COI=mP03
COH00`00COI=mP02COH30004COH20004COD00`00COE=m@04COD00`00COE=m@04COD00`00DOEAm@04
DOD20003DQD00`00DQEB5@04DQD00`00DQEB5@04DQD00`00DQEB5@02DQD00`00DQD00006EQD00`00
EQEF5@04EQD01000EQEF5@0015HE00<005HEEQD00eHE00<005HeESD00eHe0P001UHe00<005XeFSD0
1EXe00<005XeFSD015Xe00<005XeFSD01EXe00<005XeFSD01EXe00<005XeFSD00eXe0P001eiE00@0
05iEGUD000ANE@03001NEEiE00ANE@8000MNE@04001NEEiE0004GUD00`00GUENE@02GUD01000HUER
E@001V9e0P00269e00<0069eHWD01V9e00<0069eHWD01V9e0P001fJE0P001VJE00<006JF00001VJF
00<006JFIYH01VJF00<006JfI[H016Jf00@006ZfJ[H000AZ]P05001Z]VZfJ[H00002J[H00`00J[IZ
]P04J[H00`00J[IZ]P04J[H00`00J]H00004J]H00`00K]I^eP02K]H00`00K]H00005K]H00`00K]H0
0003K]H00`00K_I^mP03K_H00`00K_I^mP02K_H00`00K_I^mP03K_H00`00K_I^mP03K_H00`00L_Ib
mP02L_H00`00LaMc5`03LaL00`00LaMc5`02LaL00`00LaMc5`02LaL00`00LaMc5`03LaL01@00LcMc
=g<g000017<g00H007<gLcL007<g0002LcL00`00McMg=`02McL01P00MeMgE`00MeL000=gE`09001g
EgMGMeL007MG001gE`0000=gE`05001gN7MhMgP00003MgP01@00MgQgN7Mh00000WMh00D007NHMiQg
V000009gV005001gV7NHMiP00002MiP01@00MiQgV7NH00000WNh0P0000Eg^000MkQg^000009g^004
001g^GNi0002MkT01P00MkUg^@00MkT000=g^@06001g^GNi001cfP000gNi10000UKm00<005KmE_d0
15Km0P001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d00`0000=Fo@00E_d015Km00<005KmE_d0
0`0000=Fo@00E_d01EKm00<005Km00000P0000=Fo@00E_d01EKm0P0000=oo`00Ool0GWoo001bOol0
0`00Oomoo`1dOol00`00E_eFo@03E_d00`00E_d000020002E_d00`00E_eFo@03E_d20006E_d00`00
E_eFo@02E_d30006E_d01000E_eFoEKm0`001UKm00<005Km00000P0000=Fo@00E_d01EKm00<005Km
00000P000UKm00<005KmE_d00UKm00<000dG00000QEi00@001Ei0000008IN@04000INAUi00027GT0
10007GTMNAei0P000Qei00@0025h000QN0<0008QN004000QN25h8GP200029GP010009GPUN0000REh
00D002Uh:GPYN00000<YN004000YN2Uh0004;IP01@00;IP]V2fH00000bfG0P000RfG00D0036G<ILa
U`00008aU`03000aU`0000<000<eU`05000eUcFG=IL00004=IL00`00=ILeU`02=IL00`00=IL00003
0003>KL00`00>KLi]`02>KL01@00>KLi]cVg000013ff00<003ff?KH00cff00D003ff?KHm]P0000@m
]P04000m]Sff?KH;00000d7F0011eP03@MH00`00AMI5eP03AMH00`00AMI5eP02AMH00`00AMI5eP03
AMH00`00AMI5eP0;0002BMH00`00BMI9eP03BMH00`00BMI9eP03BMH00`00BOI9mP03BOH00`00BOI9
mP04BOH00`00COI=mP02COH00`00COH0000200000dgf001=mP02COH200000dge001=m@04COD00`00
COE=m@03COD00`00COE=m@04COD00`00DOEAm@03DOD20005DQD00`00DQEB5@04DQD00`00DQEB5@03
DQD00`00DQEB5@020002DQD00`00EQEF5@04EQD00`00EQEF5@05EQD20005EQD00`00EQEF5@03EQD0
0`00ESEF=@02ESD00`00ESD00007ESD00`00FSEJ=@03FSD20007FSD00`00FSEJ=@03FSD20007FSD0
0`00FSEJ=@02FSD01000FSEJ=@001eiE0P001UiE00<005iEGUD00UiE00@005iEGUD000INE@03001N
E@0000INE@04001NEEiE0004HUD00`00HWERM@02HWD01000HWERM@001V9e0P00269e00<0069eHWD0
1V9e00<006JEIYD01VJE00<006JEIYD01VJE00<006JFIYH01FJF00<006JFIYH01FJF00<006JF0000
1FJf00@006ZfJ[H000=Z]P03001Z]VZf009Z]P03001Z]P0000MZ]P03001Z]VZf00=Z]P05001ZeV[F
J]H00002J]H00`00K]I^eP04K]H00`00K]I^eP03K]H01`00K]I^eVkF001^eP0000E^mP03001^mP00
00=^mP03001^mVkf00=^mP03001^mVkf009^mP03001bmW;f00=bmP03001c5g<G009c5`03001c5g<G
00=c5`03001c5g<G009c5`03001c5g<G009c5`05001c=`00LcL00004LcL00`00LcMc=`02LcL01@00
LcMc=g<g000017Lg00D007MGMeMgE`0000=gE`09001gEgMGMeL007MG001gE`0000AgE`04001gN7Mh
0004MgP200001GMh001gN7Mh00000gNH00@007NHMiQgV0800003MiP007NH009gV004001gV7NH0002
MkP00`00MkQg^00200000gNh001g^002MkP00`00MkT00002MkT01000MkUg^@000WNi0P0000Mg^@00
MkUg^@00LmX00003MkT00`00Jo/00005E_d00`00E_eFo@0300000eKm001Fo@05E_d00`00E_d00002
00000eKm001Fo@05E_d30005E_d00`00E_eFo@02E_d30005E_d01000E_eFoEKm10001EKm00<005Km
E_d00`0000AFo@00Ool005moo`00LGoo00<007ooOol0MWoo00@005KmE_eFo@@000EFo@03001Fo@00
0080009Fo@03001FoEKm00AFo@04001Fo@000003E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03
E_d20005E_d00`00E_eFo@03E_d30005E_d01@00E_eFoEKm00000PdG0P0000@EN@005GTEN@800004
6GT001Ui6GT200001Qei000MNAei000MN0<0008QN004000QN25h00028GP01P008GPQN25h000QN0<0
008UN004000UN2Eh9GP20002:GP01000:GPYN0000bUh0P000RfH00D002fH;IP]V00000<]U`03000]
U`00008000@aU`04000aUc6G0003<IL20002=IL00`00=ILeU`02=IL01@00=ILeUcFG000013FG00<0
03FG=IL00SFG0P000SVg00<003Vg>KL00SVg00<003Vg>KL00SVg00D003ff?KHm]P0000Dm]P03000m
]Sff008m]P05000m]Sff?KH00004?KH00`00@KI1]P03@KH01000@KI1]T6f6P000TGF00<004GFAMH0
0dGF00<004WFBMH00TWF00<004WFBMH014WF00<004WFBMH00TWF00<004WfBOH00dWf00<004WfBOH0
14Wf00@004gfCOI=mP<000E=mP<000==m@03001=mDge00==m@03001=mDge00A=m@03001=mDge00==
m@03001AmE7e009Am@03001Am@0000EB5@03001B5E8E00AB5@03001B5E8E00AB5@8000EB5@03001F
5EHE00AF5@03001F5EHE00=F5@8000IF5@03001F5EHE00=F5@05001F=EHeESD00003ESD00`00ESEF
=@04ESD00`00FSEJ=@02FSD00`00FSD00007FSD00`00FSEJ=@02FSD01000FSEJ=@001UXe00D005Xe
FSEJ=@0000=J=@03001NEEiE00ENE@03001NEEiE00ENE@05001NEEiEGUD00003GUD00`00GUENE@05
GUD00`00GUENE@05GUD01000GUENE@00169E00<0069eHWD00V9e00@0069eHWD000ERM@04001RMF9e
0006HWD20008HWD00`00IYEVU@06IYD00`00IYEVU@06IYD00`00IYIVUP04IYH00`00IYD00005IYH0
1000IYIVUP0016Jf00<006ZfJ[H00VZf00@006ZfJ[H000AZ]P03001Z]P0000IZ]P03001Z]P0000AZ
]P07001ZeV[FJ]H006[F00001fkF00<006kFK]H00fkF00L006kFK]I^eP00K]H00005K_H01P00K_I^
mP00K_H000E^mP03001^mP0000=^mP03001bmW;f009bmP03001c5P0000=c5`03001c5g<G009c5`03
001c5`00009c5`03001c5g<G009c5`06001c=g<g001c=`000g<g00<007<gLcL00g<g00@007<gLcL0
00Ag=`03001gEgMG009gE`05001gEgMGMeL00003MeL01000MeL007MG0P000WMG00D007MhMgQgN000
00=gN004001gN7Mh0003MgP01@00MiQgV7NH00000WNH00@007NHMiP000=gV004001gV7NH0002MkP0
1P00MkQg^7Nh001g^0<00007MkP007NiMkT007Ni00000WNi00@007NiMkT0009g^@800005MkT007?J
LmX00002MkT01@00Jo][nf_k000015Km0`001EKm00@005KmE_eFo@@000EFo@03001FoEKm00<00003
E_d005Km00EFo@03001Fo@0000800003E_d005Km00EFo@@000=Fo@03001FoEKm00=Fo@<000EFo@03
001oo`0005ioo`00LGoo00<007ooOol0Mgoo0`0015Km00<005KmE_d00UKm0`001EKm00<005KmE_d0
0eKm0P001UKm00<005Km00000P0000=Fo@00E_d01EKm00<005Km00000P000UKm00<005KmE_d00eKm
00<005Km00000P000eKm00<005KmE_d00UKm0`000UKm00@000dG000AF080008EN@04000IN@000002
6GT00`006GT0000200027GT010007GPMN0000R5h00@0025h8GPQN08000038GP0025h008QN004000Q
N25h00029GP01P009GPUN2Eh000UN0<0008YN006000YN2Uh:GP002Uh0`000bfH00<002fG;IL00RfG
00<002fG;IL00P000c6G00@0036G<IL000<aU`03000aU`0000<000<eU`05000eUcFG=IL00005=IL0
1P00=ILeUcFG000i]`@000<i]`03000i]cVg008i]`03000m]Sff008m]P03000m]Sff008m]P03000m
]Sff008m]P03000m]Sff008m]P05000m]Sff?KH00005@KH00`00@KI1]P02@KH00`00@MI1eP02@MH0
0`00@MI1eP03@MH00`00AMI5eP02AMH00`00AMI5eP03AMH00`00AMI5eP02AMH00`00AMI5eP03AMH0
0`00BMI9eP03BMH00`00BMI9eP03BMH00`00BMI9eP03BMH00`00BOI9mP03BOH00`00BOI9mP03BOH4
00000dgf001=mP04COH20006COD00`00COE=m@02COD00`00COE=m@04COD00`00COE=m@03COD00`00
DOEAm@020002DOD00`00DQEB5@03DQD00`00DQEB5@04DQD00`00DQEB5@03DQD20006DQD00`00EQEF
5@04EQD00`00EQEF5@02EQD00`00EQD00006EQD00`00EQEF5@03EQD01000ESEF=@0015He00<005He
ESD015He00D005XeFSEJ=@0000=J=@03001J=EXe00AJ=@05001J=EXeFSD00003FSD00`00FSEJ=@04
FSD01000FSEJ=@0015Xe00<005iEGUD01EiE00<005iEGUD01EiE00D005iEGUENE@0000=NE@03001N
EEiE00ENE@03001NEEiE00ENE@03001NE@0000IRE@04001RMF9e0003HWD00`00HWERM@03HWD01000
HWERM@001F9e00@0069eHWD000IRM@03001RM@0000IVU@03001VU@0000IVU@03001VU@0000EVUP03
001VU@0000EVUP04001VUVJF0004I[H00`00J[IZ]P02J[H00`00J[H00006J[H00`00J[IZ]P04J[H0
1000J[IZ]P000fZf00<006[FJ]H00V[F00<006[F00001VkF00<006kF00000fkF00<006kFK]H00fkF
00<006kfK_H00fkf00L006kfK_I^mP00K_H00005K_H01P00K_I^mP00K_H000EbmP06001c5W<F001c
5`001G<G00H007<GLaL007<G0004LaL01@00LcMc=g<g000017<g00<007<gLcL00W<g00D007Lg001c
=`0000=g=`03001gEgMG009gE`05001gE`00MeL00003MeL01@00MeMgEgMG00000WMg00<007MG0000
0WMh00D007MhMgQgN00000=gN0800003MgP007NH009gV004001gV7NH0003MiP200000gNH001gV002
MiP01000MkQg^0000WNh00@007NhMkP0009g^0800007MkT007NiMkT007Ni00000WNi00H007NiMkUg
^@00MmT200001G?J001g^GNi000016_k00<005Km00000P000UKm00<005KmE_d00eKm10000eKm00<0
05KmE_d00eKm0`001EKm00<005KmE_d00eKm0P001EKm00<005KmE_d00`0000=Fo@00E_d01EKm00<0
05Km00000P0000=Fo@00E_d01EKm00@007ooOol005eoo`00LGoo00<007ooOol0N7oo00<005KmE_d0
15Km00@005Km000000=Fo@03001FoEKm00=Fo@03001Fo@000080009Fo@03001FoEKm00=Fo@8000EF
o@03001FoEKm00=Fo@<000EFo@04001FoEKmE_d40006E_d01`00E_d00000E_d002Fi00<0008=5`04
000AF00000025GT010006GTIN@000QUi00@001Ui6GT0008MN@04000MN1eh7GP200001R5h000QN25h
000QN08000<QN004000QN25h8GP200000bEh000UN0029GP010009GPUN0000bUh00D002Uh:GPYN000
008YN08000<]V005000]UbfG;IL00003;IL20002<IL01000<ILaU`00136G00@0036G<ILaU`80008e
U`03000eUcFG008eU`03000eUcFG008eU`05000eUcFG=IL00004>KL400000cVg000i]`02>KL00`00
?KHm]P02?KH00`00?KHm]P03?KH01@00?KHm]Sff000013ff00<003ff?KH00Sff00<0046f@KH00d6f
00D0046f@KI1]P0000A1eP030011eT7F00=1eP030015eTGF0095eP030015eTGF00=5eP030015eTGF
00=5eP030015eTGF00=5eP030019eTWF0099eP030019eTWF00=9eP030019eTWF00=9eP030019mTWf
00=9mP040019mTWfBOH30005COH00`00COH0000200000dge001=m@05COD00`00COE=m@02COD00`00
COE=m@04COD00`00COE=m@04COD20005DOD00`00DQEB5@03DQD00`00DQEB5@03DQD00`00DQEB5@02
DQD00`00DQD00006DQD00`00EQEF5@04EQD01@00EQEF5EHE00000UHE00<005HEEQD01EHE00<005HE
EQD00eHE0P001EHe00<005HeESD015He00@005XeFSD000AJ=@03001J=EXe00AJ=@04001J=EXe0004
FSD00`00FSEJ=@05FSD20006FSD00`00GUENE@03GUD20007GUD01000GUENE@001EiE00<005iEGUD0
0eiE0P0025iE00<0069EHUD01F9E00@0069eHWD000ARM@05001RMF9eHWD00003HWD00`00HWERM@03
HWD01000HWERM@001F9e00@0069eHWD000EVU@04001VUFJE0005IYD01000IYEVU@0016JF00@006JE
IYD000AVUP03001VUVJF009VUP04001V]VJf0005J[H00`00J[H00006J[H00`00J[IZ]P04J[H01@00
J[IZ]VZf00000VZf00<006[FJ]H00f[F00<006kFK]H016kF00@006kFK]H000=^eP03001^eVkF00=^
eP03001^mVkf00=^mP03001^mVkf009^mP03001^mVkf00=^mP07001^mVkfK_H006kf000017;f00L0
07<FLaIc5P00LaL00004LaL00`00LaMc5`02LaL00`00LaMc5`02LaL00`00LcMc=`02LcL20002LcL0
0`00LcMc=`02LcL01@00McMg=gLg000017Lg00D007MGMeMgE`0000=gE`05001gEgMGMeL00004MeL2
0002MgL01@00MgQgN7Mh00000WMh00D007MhMgQgN000009gN08000=gV004001gV7NH0002MiP00`00
MiQgV00300001GNH001g^7Nh00000WNh00@007NhMkP000=g^006001g^000001g^@000WNi00<007Ni
00000gNi00D007OIMmT007OI00800003MkT006_k009[n`@000IFo@03001Fo@0000800003E_d005Km
00EFo@03001Fo@000080009Fo@03001FoEKm00=Fo@03001FoEKm00<00003E_d005Km00AFo@<000EF
o@03001FoEKm00=Fo@8000EFo@04001FoEKmE_d400000goo001oo`1LOol0075oo`03001oogoo07Uo
o`03001FoEKm00=Fo@8000IFo@04001FoEKmE_d30006E_d00`00E_d0000200000eKm001Fo@05E_d0
0`00E_d000020003E_d00`00E_eFo@02E_d40004E_d00`00E_eFo@03E_d20004E_d010009KTU^@00
0PdG00@0015H4EP0008EN@04000INAUi6GT300036GT200001Qei000MN1eh000MN08000<QN003000Q
N00000<QN006000QN25h8GP0025h0P000bEh00@002Eh9GPUN0800003:GP002Uh008YN004000YN2Uh
:GP20002;IP01@00;IL]UbfG00000bfG00<002fG00000`000S6G00D0036G<ILaU`0000<aU`03000e
U`0000<000<eU`03000eUcFG008eU`03000eUcFG008eU`05000i]cVg>KL00003>KL30002>KL00`00
?KHm]P02?KH00`00?KHm]P03?KH00`00?KHm]P02?KH01@00?KHm]Sff000013ff00<0046f@KH00d6f
00<0046f@KH00T6f00<0047F@MH00T7F00<0047F@MH00d7F00<004GFAMH00TGF00<004GFAMH00dGF
00<004GFAMH00TGF00<004GFAMH00dGF00<004WFBMH00TWF00<004WFBMH00dWF00<004WFBMH00dWF
00<004WfBOH00dWf10000TWf00<004gfCOH00Tgf0`0014ge00<004geCOD014ge00<004geCOD00dge
00<004geCOD00dge00<004geCOD00dge0P001U7e00<0058EDQD00e8E00<0058EDQD00e8E00<0058E
DQD00P000U8E00<0058EDQD0158E00<005HEEQD015HE00@005HEEQD000AF5@03001F5EHE00AF5@03
001F5EHE00=F5@03001F=EHe00AF=@03001F=EHe00EF=@8000EJ=@03001J=EXe00EJ=@8000EJ=@03
001J=EXe00EJ=@03001J=EXe00EJ=@03001NEEiE009NE@04001NEEiE0007GUD20006GUD00`00GUEN
E@02GUD01000GUENE@001eiE00<0069EHUD01F9E00<0069e00001F9e00@0069eHWD000ERM@05001R
MF9eHWD00003HWD00`00HWERM@03HWD01000HWERM@001FJE00@006JEIYD000EVU@04001VUFJE0003
IYH00`00IYEVU@02IYD01000IYIVUP001FJF00<006Jf00001fZf00<006ZfJ[H016Zf00<006Zf0000
16Zf00<006ZfJ[H00VZf00<006Zf00001V[F00<006kFK]H016kF00L006kFK]I^eP00K]H00005K]H0
0`00K]H00003K_H00`00K_I^mP03K_H00`00K_I^mP03K_H00`00K_I^mP02K_H00`00L_IbmP03L_H0
0`00LaIc5P02LaH00`00LaMc5`02LaL00`00LaMc5`03LaL01@00LaMc5g<G000017<g00H007<gLcL0
07<g0004LcL01000McMg=gLg0P000WLg00<007MGMeL00WMG00D007MGMeMgE`0000=gE`05001gEgMG
MeL00002MgL01P00MgL00000MgP000=gN005001gN7MhMgP00002MgP01@00MiP007NH00000WNH00@0
07NHMiP000=gV004001gV7NH0003MkP00`00MkP00002MkP01@00MkQg^7Nh00000WNh00H007Nh0000
07Ni0002MkT01000MkUg^@000WOI00D007OIMmT007OI00D000=Fo@03001FoEKm00AFo@8000EFo@03
001FoEKm00=Fo@8000IFo@04001FoEKmE_d40005E_d00`00E_d0000200000eKm001Fo@05E_d00`00
E_eFo@0300000eKm001Fo@04E_d40003E_d01000Oomoo`00G7oo001aOol00`00Oomoo`1jOol00`00
E_d000020002E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d30004E_d00`00E_eFo@03E_d3
0006E_d01000E_d000000UKm00<005KmE_d015Km00<005Km00000P000UKm00D005KmE_eFo@0000<U
^@8000043AL0015H4EP200001QEi000INAUi000IN@80008IN@04000IN@0000037GP00`007GP00003
8GP00`008GPQN00200028GP01`008GPQN25h000QN00000<UN006000UN2Eh9GP002Eh0P000bUh00H0
02Uh:GPYN000:GL30004;IL01@00;IL]UbfG00000bfG0P0000<aU`00<IL00S6G00D0036G<ILaU`00
00@eU`80008eU`03000eUcFG00<eU`05000eUcFG=IL00003>KL00`00>KLi]`02>KL00`00>KH00003
0003?KH00`00?KHm]P03?KH00`00?KHm]P02?KH00`00?KHm]P02?KH01@00?KHm]Sff00001D6f00<0
046f@KH00T6f00<0047F@MH00T7F00<0047F@MH00d7F00<004GFAMH00TGF00<004GFAMH00dGF00<0
04GFAMH00TGF00<004GFAMH00dGF00<004WFBMH00TWF00<004WFBMH014WF00<004WFBMH00dWF00<0
04WfBOH00`001TWf100000=9mP00COD01Dge00<004geCOD00dge00<004geCOD00dge00<004geCOD0
0dge00@004geCOE=m@800003COD0057e00EAm@03001B5E8E00=B5@03001B5E8E00AB5@8000EB5@03
001B5E8E00AB5@03001F5EHE00AF5@8000EF5@03001F5EHE00AF5@03001F5EHE009F5@8000MF=@03
001F=EHe00AF=@03001J=EXe00AJ=@03001J=EXe00EJ=@03001J=EXe00EJ=@03001J=EXe00=J=@80
00MJ=@05001NEEiEGUD00003GUD00`00GUENE@05GUD00`00GUENE@05GUD01@00GUENEEiE00000eiE
00<005iEGUD015iE0P00269E00<0069eHWD0169e00@0069eHWD000ERM@04001RMF9e0005HWD01@00
HWERMF9e0000169e00D006JEIYEVU@0000AVU@05001VUFJEIYD00004IYD01000IYIVUP0016JE00@0
06JFIYH000EVUP03001V]P0000MZ]P03001Z]VZf00AZ]P03001Z]P0000AZ]P03001Z]VZf009Z]P03
001Z]P0000EZeP03001ZeP0000A^eP03001^eVkF009^eP03001^eP0000A^eP04001^eVkF0003K_H0
0`00K_I^mP02K_H00`00K_H00003K_H00`00K_I^mP03K_H00`00L_IbmP02L_H00`00LaIc5P03LaH0
0`00LaMc5`02LaL00`00LaMc5`02LaL00`00LaL00002LaL00`00LcMc=`02LcL01@00LcMc=g<g0000
17<g00D007LgMcMg=`00009g=`03001g=`0000=gE`09001gEgMGMeL007MG001gE`0000=gE`04001g
MgMgMgL20002MgL01@00MgQgN7Mh00000gMh00@007MhMgP000=gV005001gV7NHMiP00002MiP01000
MiQgV0000gNH0P0000Mg^000MkQg^000MkP00003MkP01000MkQg^0000WNh00H007OI000007Ni0002
MkT01000MmUgf@000WOI00H007OIMmT006oi0006E_d00`00E_eFo@0300000eKm001Fo@04E_d00`00
E_eFo@0300000eKm001Fo@05E_d40002E_d00`00E_eFo@04E_d20005E_d00`00E_eFo@03E_d30005
E_d00`00E_d0000200000eKm001Fo@05E_d01000Oomoo`00Fgoo001aOol00`00Oomoo`02Ool2001g
Ool00`00E_eFo@04E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d000020003E_d00`00E_eF
o@02E_d00`00E_d000020003E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d20006E_d01@00
E_eFoEKm00000RFi00@001UI0000008AF004000EF@0000036GT00`006GT000036GT00`006GT00003
7GP00`007GPMN00200028GP010008GP0025h0`000b5h00<0025h8GP00P000REh00H002Eh9GPUN000
9GP20003:GP01@00:GPYN2Uh00000RUg0P000bfG00D002fG;IL]U`0000<]U`04000aU`000004<IL0
1@00<ILaUc6G00000cFG00<003FG00000`0013FG00D003FG=ILeU`0000@i]`05000i]cVg>KL00004
>KH400000cff000m]P03?KH00`00?KHm]P02?KH00`00?KHm]P02?KH00`00?KHm]P02?KH00`00@KI1
]P02@KH00`00@KI1]P02@KH00`00@MI1eP02@MH00`00@MI1eP03@MH00`00AMI5eP02AMH00`00AMI5
eP03AMH00`00AMI5eP02AMH00`00AMI5eP03AMH00`00BMI9eP03BMH00`00BMI9eP03BMH00`00BMI9
eP03BMH30003BOH00`00BOI9mP040004BOH00`00COE=m@04COD00`00COE=m@04COD00`00COE=m@02
COD00`00COE=m@04COD30003COD00`00DOEAm@04DOD00`00DQEB5@04DQD00`00DQEB5@02DQD20006
DQD00`00DQEB5@04DQD00`00EQEF5@03EQD20006EQD00`00EQEF5@04EQD01@00EQEF5EHE00000UHE
00<005HeESD015He00<005HeESD00eHe0P001eXe00<005XeFSD00eXe0P001eXe00<005XeFSD00UXe
00<005Xe00001eXe00@005iEGUD000ANE@03001NEEiE00ENE@03001NEEiE00ENE@04001NEEiE0004
GUD00`00GUENE@03GUD01000GUENE@001f9E00<0069eHWD01F9e0P001V9e00@0069eHWD000ERM@04
001RMF9e0005HWD01000IYEVU@001FJE00@006JEIYD000EVU@03001VUP0000EVU@03001VUP0000MV
UP03001Z]VZf00EZ]P03001Z]P0000AZ]P05001Z]VZfJ[H00002J[H00`00J[IZ]P04J[H00`00J]IZ
eP04J]H00`00J]H00003K]H00`00K]I^eP04K]H00`00K]I^eP03K]H01`00K]I^eVkF001^mP0000E^
mP03001^mP0000=^mP03001^mVkf009^mP03001bmP0000=bmP03001c5W<F009c5P03001c5P00009c
5`03001c5g<G009c5`06001c5g<G001c5`0017<g00<007<gLcL00W<g00D007<gLcMc=`0000Ag=`05
001g=gLgMcL00003MeL00`00MeMgE`02MeL01000MeMgE`0017MG00@007MgMgMgM`80009gM`800003
MgP007Mh009gN005001gN7MhMgP00003MiP200001GNH001gV7NH00000WNH00D007NHMiQgV000009g
^0800005MkP007NhMkP00002MkP01000MkQg^0000WNh00H007OIMmT007OI0003MkT00`00MmT00002
MmT02000MmUgf@00KoT006?g0005E_d30005E_d01000E_eFoEKm10001EKm00<005KmE_d00`0000=F
o@00E_d015Km00<005KmE_d00`0000=Fo@00E_d01EKm00<005Km00000P0000=Fo@00E_d01EKm0P00
1EKm00<005KmE_d00eKm0P0000=oo`00Ool0FWoo001`Ool00`00Oomoo`03001jOol00`00E_eFo@03
E_d30004E_d00`00E_eFo@03E_d30006E_d00`00E_eFo@040006E_d00`00E_d000020002E_d00`00
E_eFo@03E_d00`00E_d000020002E_d00`00E_eFo@03E_d30002E_d01P009KTU^@006ET000<AF003
000EF@0000<IN@03000INAUi008000046GT001Ui6GT200027GP010007GP001eh0`000R5h00@0025h
8GP000<QN005000QN25h000UN00300039GP00`009GPUN0020002:GP01@00:GPYN2Uh00000bUg0P00
0RfG00D002fG;IL]U`0000@]U`04000aU`000003<IL01@00<ILaUc6G00000cFG00<003FG=IL00SFG
0`000SFG00<003FG=IL00SFG00D003Vg>KLi]`0000@i]`05000i]SVf>KH00003>KH50002?KH01@00
?KHm]Sff000013ff00<003ff?KH00Sff00<0046f@KH00d6f00<0046f@KH00T6f00D0047F@MI1eP00
00E1eP030015eTGF0095eP030015eTGF00=5eP030015eTGF00=5eP030015eTGF00=5eP030019eTWF
0099eP030019eTWF00=9eP040019eTWFBMH30004BOH40003BOH00`00BOI9mP03BOH00`00COE=m@03
COD00`00COE=m@04COD00`00COE=m@02COD00`00COE=m@03COD20006COD00`00DOEAm@04DOD00`00
DQEB5@03DQD01`00DQEB5E8E001B5@0000IB5@03001B5E8E00AB5@03001F5EHE009F5@03001F5@00
00IF5@03001F5EHE00AF5@04001F5EHE0003EQD00`00ESEF=@04ESD00`00ESEF=@02ESD00`00ESD0
0007FSD00`00FSEJ=@02FSD00`00FSD00007FSD01@00FSEJ=EXe00000eXe00<005XeFSD01EXe0P00
1UiE00<005iEGUD00eiE0P0025iE0P001UiE00D005iEGUENE@0000=NE@03001REF9E00ARE@8000MR
M@03001RMF9e00IRM@8000IRM@04001RMF9e0005HWD01000IYEVU@001FJE00@006JEIYD000EVU@03
001VUP0000IVU@03001VUVJF00IVUP03001Z]VZf00AZ]P04001Z]VZf0003J[H00`00J[IZ]P02J[H0
0`00J[H00007J[H00`00J]IZeP03J]H01@00J]IZeV[F00000VkF00<006kFK]H016kF00<006kFK]H0
0VkF00<006kFK]H00VkF00<006kf000016kf00L006kfK_I^mP00K_H00005K_H01P00L_IbmP00L_H0
00Ec5P06001c5W<F001c5`0017<G00D007<GLaMc5`0000Ac=`03001c=g<g009c=`03001c=`00009c
=`05001g=gLgMcL00004McL01@00MeMgEgMG00000gMG00@007MGMeMgE`80009gE`05001gMgMgMgL0
0002MgL20002MgL00`00MgQgN002MgP01000MgQgN0000gNH00@007NHMiP000=gV003001gV00000=g
V006001g^7NhMkP007Nh0P0000Eg^000MkQg^00000=g^003001g^000009gf@03001gfGOI00800004
MkT007OI0002MmT01P00MmUgf@00KoT000=Sm`03001Fo@0000800003E_d005Km00EFo@@000=Fo@03
001FoEKm00=Fo@<000EFo@03001FoEKm009Fo@<000EFo@04001FoEKmE_d40005E_d00`00E_eFo@03
00000eKm001Fo@05E_d00`00E_d0000200001EKm001oogoo0000FWoo001`Ool3001nOol00`00E_d0
00020003E_d00`00E_eFo@02E_d00`00E_d000020003E_d00`00E_eFo@03E_d30004E_d00`00E_eF
o@03E_d20006E_d01000E_eFoEKm0`001UKm00<005Km00000P0000=Fo@007Sd00`000RFi00<001UI
6ET00P0000@AF0005ETEF@80008IN@04000IN@006ET300000aUi000IN00300027GP010007GPMN000
0R5h00@0025h8GPQN080008QN004000QN25h00029GP01@009GPUN2Eh00000REh00<002Uh00000P00
0bUh00H002Ug:GLYM`00;GL40003;IL01@00;IL]UbfG00000S6G0P000S6G00D0036G<ILaU`0000@e
U`05000eUcFG=IL00002=IL40003=IL01@00>KLi]cVg000013Vg00D003Vf>KHi]P0000@i]P04000m
]Sff?KH600000cff000m]P02?KH00`00?KHm]P02?KH00`00@KI1]P03@KH00`00@KI1]P02@KH00`00
@MI1eP02@MH00`00@MI1eP03@MH00`00AMI5eP02AMH00`00AMI5eP03AMH00`00AMI5eP02AMH00`00
AMI5eP03AMH00`00BMI9eP02BMH00`00BMI9eP03BMH40003BMH400000dWF0019mP04BOH00`00BOI9
mP03BOH00`00COE=m@03COD00`00COE=m@04COD00`00COE=m@03COD00`00COD0000200000dge001=
m@05COD00`00DOEAm@04DOD00`00DQEB5@03DQD01000DQEB5@000U8E00<0058EDQD0158E00<0058E
DQD0158E00<005HEEQD00P000UHE00<005HEEQD01EHE00<005HEEQD015HE0P0015HE00<005HeESD0
15He00D005HeESEF=@0000=F=@03001J=EXe00AJ=@05001J=EXeFSD00003FSD00`00FSEJ=@04FSD0
1000FSEJ=@0015Xe00<005XeFSD01EXe00<005iEGUD01EiE00<005iEGUD00UiE00@005iEGUD000MN
E@03001NEEiE00ENE@05001NEEiEGUD00003GUD00`00HUERE@03HUD01000HWERM@001V9e00<0069e
HWD01V9e00<0069eHWD01V9e0P001f9e0P001fJE0P001fJE00<006JEIYD01FJE00<006JFIYH01FJF
00<006Zf00001FZf00D006ZfJ[IZ]P00009Z]P03001Z]VZf009Z]P03001Z]P0000IZ]P03001Z]P00
00AZeP07001ZeV[FJ]H006kF00001VkF00<006kF00000fkF00<006kFK]H00fkF00<006kfK_H00fkf
00L006kfK_I^mP00K_H00004K_H01`00L_IbmW;f001bmP0000Ac5P03001c5W<F009c5P03001c5g<G
009c5`03001c5g<G009c5`03001c=g<g009c=`03001c=g<g009c=`05001c=`00LcL00003McL00`00
McMg=`02McL01@00MeL007MG00000gMG00D007MGMeMgE`00009gE`03001gE`0000=gM`05001gMgMg
MgL00002MgL20002MgP01000MgQgN0000gNH00@007NHMiQgV0800005MiP007NHMiP00003MiP01000
MkQg^0000WNh00H007Nh000007Nh0003MkP01P00MkQg^000MmT0009gf@03001gfGOI00@00007MmT0
07OIMmT006oi00000V?g10001EKm00<005KmE_d00`0000=Fo@00E_d01EKm00<005Km00000P0000=F
o@00E_d01EKm00<005Km00000P000UKm00<005KmE_d00eKm10000eKm00<005KmE_d00eKm0`001EKm
00@005KmE_eFo@@000EFo@04001oogoo001IOol0071oo`03001oogoo07moo`8000IFo@03001FoEKm
00@000IFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@000080009Fo@03001FoEKm00=Fo@@0
00=Fo@03001FoEKm00=Fo@8000EFo@04000N?Ahm7Sd200001BFi000IF@005ET00`0000<EF@005ET0
0`000QUi00@001UI6ET0008IN@04000IN1Uh00027GP010007GPMN1eh0P0000HQN0008GPQN0008GP3
00028GP010009GPUN2Eh0P000REh00@002Eh9GP0008YN08000<YN005000YMbUg:GL00003;GL20002
;IL01@00;IL]UbfG00000S6G00<0036G00000`000c6G00D003FG=ILeU`0000<eU`03000eUcFG00<e
U`80008eU`03000i]cVg008i]`05000i]cVg>KL00004>KH01@00>KHi]SVf00001Cff00@003ff?KHm
]PD00003?KH003ff008m]P030011]T6f00=1]P030011]T6f0091]P030011eT7F0091eP030011eT7F
00=1eP030015eTGF0095eP030015eTGF00=5eP030015eTGF0095eP030015eTGF00=5eP030019eTWF
0099eP040019eTWFBMH40002BMH40004BMH00`00BOI9mP04BOH00`00BOI9mP02BOH00`00COE=m@04
COD00`00COE=m@03COD00`00COE=m@02COD30004COD00`00COE=m@04COD00`00DOEAm@04DOD00`00
DQEB5@04DQD20004DQD00`00DQEB5@04DQD00`00DQEB5@04DQD20005EQD00`00EQEF5@04EQD00`00
EQEF5@03EQD20006EQD00`00ESEF=@03ESD01000ESEF=@0015He00<005XeFSD015Xe00@005XeFSD0
00AJ=@03001J=EXe00EJ=@8000EJ=@03001J=EXe00EJ=@03001NEEiE00ENE@05001NEEiEGUD00003
GUD00`00GUENE@05GUD00`00GUENE@05GUD01000GUENE@001EiE00<0069EHUD00V9E00@0069eHWD0
00ERM@03001RM@0000MRM@03001RMF9e00IRM@03001RMF9e00IRM@03001VUFJE00IVU@03001VUFJE
00IVU@03001VUFJE00AVU@03001VU@0000EVUP04001Z]VZf0004J[H00`00J[IZ]P02J[H00`00J[H0
0006J[H00`00J[IZ]P04J[H01000J[IZ]P000f[F00<006[FJ]H00f[F00<006kFK]H016kF00@006kF
K]H0009^eP03001^eVkF00A^eP03001^mVkf009^mP03001^mVkf00=^mP03001^mVkf00=^mP03001b
mW;f009bmP03001c5W<F009c5P03001c5W<F00=c5P05001c5g<GLaL00004LaL00`00LcL00002LcL0
0`00LcMc=`02LcL01@00LcMc=g<g000017Lg00<007LgMcL00WLg00@007MGMeL000AgE`05001gEgMG
MeL00003MeL01@00MgMgMgMg00000gMg0P0000MgM`00MgQgN000MgP00002MgP01000MiQgV0000gNH
00<007NHMiP00P0000=gV000MiP00WNH00@007NhMkP0009g^005001g^7Nh001g^0020003MkP00`00
MkP00002MmT00`00MmT00003MmT01000MmT007OI0P0000=gf@00KoT010000eKm00<005KmE_d00eKm
0`001EKm00<005KmE_d00eKm0P001EKm00@005KmE_eFo@@000IFo@03001Fo@0000800003E_d005Km
00EFo@03001Fo@0000800003E_d005Km00EFo@@000=Fo@03001FoEKm00=Fo@800003Ool007oo05Qo
o`00L7oo00<007ooOol0PGoo00<005KmE_d00eKm0`0015Km00<005KmE_d00eKm0P001EKm00<005Km
E_d00eKm0P001UKm00<005Km00000P0000=Fo@00E_d01EKm00<005Km00000P000UKm00<005KmE_d0
0eKm00D001hm7Sd001fj0080008IF@04000EFAEI00025ET010005ETEF@000QUi00L001UI6ETIF@00
6GT000036GP200001Qeh000MN1eh000MN08000<QN004000QN25h00028GP01P009GPUN2Eh000UN0<0
008UN004000YN2Uh:GP20002:GP01@00:GLYMbUg00000beg00<002eg00000P0012fG00@0036G<IL0
00<aU`80008aU`05000eUcFG=IL00004=IL00`00=ILeU`02=IL00`00=IL000030003>KL00`00>KLi
]`02>KL01@00>KHi]SVf000013Vf00<003ff?KH00Sff00<003ff?KH00Sff00@003ff?KHm]PD00003
?KH0046f00=1]P030011]T6f0091]P030011eT7F0091eP030011eT7F00=1eP030015eTGF0095eP03
0015eTGF00=5eP030015eTGF0095eP030015eTGF00=5eP030019eTWF00=9ePT000=9eP030019eTWF
00=9eP030019mTWf00=9mP030019mTWf0099mP03001=mDge00A=m@03001=mDge00==m@03001=mDge
00800003COD004ge00E=m@03001=mDge00==m@03001AmE7e00AAm@03001B5E8E00=B5@8000EB5@03
001B5E8E00AB5@03001B5E8E00=B5@8000IF5@03001F5EHE00AF5@03001F5EHE009F5@03001F5@00
00IF5@03001F=EHe00AF=@8000EF=@03001J=EXe00EJ=@8000EJ=@03001J=EXe00EJ=@03001J=EXe
00EJ=@03001J=EXe00=J=@8000MNE@04001NEEiE0004GUD00`00GUENE@04GUD20008GUD20006GUD0
1@00HUEREF9E00000f9e00<0069eHWD00f9e00<0069e00001V9e00<0069e00001f9e00<0069eHWD0
1V9e00<006JEIYD01VJE00<006JEIYD01FJE00<006JE00001FJE00<006JE00001FJF00D006ZfJ[IZ
]P00009Z]P03001Z]VZf00=Z]P03001Z]P0000IZ]P03001Z]VZf00AZ]P05001Z]VZfJ[H00002J]H0
0`00J]IZeP03J]H00`00K]I^eP04K]H01P00K]I^eP00K]H000I^eP03001^mP0000=^mP03001^mVkf
00=^mP03001^mVkf009^mP03001bmW;f00=bmP03001c5W<F009c5P03001c5W<F009c5P03001c5P00
009c5`03001c5g<G009c5`06001c=g<g001c=`0017<g00@007<gLcMc=`80009g=`03001g=gLg009g
=`04001gEgMGMeL20002MeL01@00MeMgEgMG000017MG0P0000=gM`00MgL00WMg00<007MgMgL00P00
0gMh00@007MhMgP000=gV004001gV7NH0003MiP01000MiP000000gNH00<007Nh00000WNh00@007Nh
MkP0009g^005001g^000MkP00002MkP01@00MmT007OI00000gOI00<007OI00000WOI00<007Oi0000
0P0000=gn000E_d01EKm00<005Km00000P000UKm00<005KmE_d00eKm00<005KmE_d00`0000=Fo@00
E_d015Km10000eKm00<005KmE_d015Km0P001EKm00<005KmE_d00eKm0P001EKm00<005KmE_d00`00
00=Fo@00E_d01EKm00<005Km00000P0000EFo@00Oomoo`0005Qoo`00L7oo00<007ooOol0PWoo00<0
05Km00000P0000=Fo@00E_d01EKm00<005Km00000P000UKm00<005KmE_d00eKm00<005Km00000P00
0UKm00<005KmE_d00eKm0`0015Km00<005KmE_d00eKm0`001EKm00@005KmE_eFo@@000047Sd001fj
7KX2000011UI000EFAEI0`000aEI0P0000@IN@006ETIF@8000066GT001Uh6GP001eH0P000aeh00<0
01eh00000b5h00@0025h8GPQN08000038GP002Eh008UN004000UN2Eh00039GP01@00:GPYN000:GL0
0`000bUg00<002eg;GL00Reg00<002eg;GL00P000bfG00@0036G<IL000<aU`03000aU`00008000@e
U`05000eUcFG=IL00004=IL00`00=ILeU`02=IL20002>KL00`00>KLi]`02>KL01@00>KHi]SVf0000
13Vf00<003ff?KH00Sff00<003ff?KH00Sff00<003ff?KH00Sff00@003ff?KHm]PD00091]P030011
]T6f0091]P050011eT7F@MH00005@MH00`00AMI5eP02AMH00`00AMI5eP03AMH00`00AMI5eP03AMH0
0`00AMI5eP03AMH00`00BMH000050003BMH00`00BMI9eP03BMH00`00BMI9eP03BMH00`00BOI9mP03
BOH00`00BOI9mP03BOH00`00COE=m@03COD00`00COE=m@04COD20003COD00`00COE=m@04COD00`00
COE=m@04COD00`00DOEAm@03DOD01000DQEB5E8E0P0000=Am@00DQD0158E00<0058EDQD0158E00<0
058EDQD00U8E00<0058E00001UHE00<005HEEQD015HE00D005HEEQEF5@00009F5@03001F5EHE00AF
5@03001F=EHe00AF=@03001F=EHe00AF=@03001J=EXe00EJ=@03001J=EXe00AJ=@03001J=EXe00EJ
=@03001J=EXe00EJ=@03001J=EXe009J=@04001J=EXe0007GUD20006GUD00`00GUENE@02GUD01000
GUENE@001eiE00<005iEGUD01EiE00@0069EHUD000ERM@05001RMF9eHWD00002HWD00`00HWERM@04
HWD00`00HWD00006HWD00`00HWD00006HWD00`00IWD00006IYD00`00IYD00005IYD01000IYEVU@00
16JE00@006JEIYD000AVUP03001Z]VZf009Z]P04001Z]VZf0006J[H00`00J[IZ]P04J[H00`00J[H0
0004J[H00`00J[IZ]P02J[H00`00J]H00005J]H00`00K]H00004K]H00`00K]I^eP02K]H20005K]H0
1`00K_I^mVkf001^mP0000E^mP03001^mP0000=^mP03001bmW;f009bmP03001c5P00009c5P03001c
5W<F009c5P06001c5W<F001c5`0017<G00<007<gLcL00W<g00<007<gLcL00W<g00D007<gLcMc=`00
009g=`03001g=`0000=g=`05001gEgMGMeL00002MeL00`00MeL00002MeL00`00MeMgE`02MeL01000
MgMgM`0017Mg00<007MgMgL00P000gMh0P0000EgN000MiQgV00000=gV004001gV7NH0002MiP01@00
NiP007NH00000WNh00H007NhMkP007Nh0002MkP01000MkQg^7Nh0P0000Mg^000MmUgf@00MmT00002
MmT00`00MmT00002MmT01@00MoUgn@00LoT00P0000=k^000E_d015Km0P001UKm00@005KmE_eFo@@0
00EFo@03001Fo@0000800003E_d005Km00EFo@03001FoEKm00<00003E_d005Km00AFo@03001FoEKm
00<00003E_d005Km00AFo@<000EFo@03001FoEKm00=Fo@8000EFo@04001oogoo001GOol0071oo`03
001oogoo08=oo`03001FoEKm00=Fo@03001FoEKm00=Fo@8000IFo@04001FoEKmE_d30006E_d00`00
E_d000020003E_d00`00E_eFo@02E_d00`00E_d000020003E_d00`00E_eFo@02E_d40002E_d00`00
4EP0000200000afj000EN@0200025ET010005ET000000QEI00@001EI000000<IF@<000<IN003000M
F00000<MN003000MN1eh0080008QN005000QN25h000QN00200039GP010009GPUN2Eh0P0000<UN000
:GP00RUh00@002Ug:GLYM`80008YM`05000]Mbeg;GL00003;GL20002;IL01000<ILaU`000c6G00@0
036G<ILaU`8000<eU`05000eUcFG=IL00005=IL01P00=ILeUcFG000eU`@000<i]`03000i]SVf008i
]P05000i]SVf>KH00005?KH00`00?KHm]P02?KH01@00?KHm]Sff000013ff00@0046f@KI1]P/00003
@MH0047F00A1eP030015eTGF0095eP030015eTGF00=5eP030015eTGF00/00095eP030019eTWF00=9
eP030019eTWF00A9eP030019eTWF0099eP030019mTWf00=9mP030019mTWf00=9mP03001=mDge00==
m@03001=mDge00==m@8000E=m@03001=mDge00==m@03001=mDge00A=m@03001AmE7e00AAm@<000=A
m@03001B5E8E00=B5@03001B5E8E00AB5@05001B5E8EDQD00002DQD00`00EQEF5@04EQD00`00EQEF
5@04EQD01000EQEF5@0015HE00<005HEEQD015HE00<005HeESD00UHe0P001eHe00<005XeFSD00eXe
0P001eXe00<005XeFSD00eXe0P001eXe00D005XeFSEJ=@0000=J=@03001NEEiE00ENE@03001NEEiE
00ENE@05001NEEiEGUD00003GUD00`00GUENE@05GUD00`00GUENE@05GUD01000HUERE@001F9e00@0
069eHWD000ARM@03001RMF9e009RM@04001RMF9e0006HWD00`00HWD00005HWD01000IWEVM@001FJE
00@006JEIYD000EVU@04001VUFJE0004IYD01@00IYEVUFJE00000VJF00<006ZfJ[H00fZf00<006Zf
00001fZf00<006ZfJ[H016Zf00<006Zf000016Zf00<006ZfJ[H00VZf00<006[F00001F[F00<006kF
000016kF00<006kFK]H00VkF00<006kFK]H016kF00L006kfK_I^mP00K_H00004K_H01`00K_I^mVkf
001^mP0000AbmP07001c5W<FLaH007<F000017<F00D007<FLaIc5P0000Ec5`03001c=g<g009c=`03
001c=g<g009c=`05001c=g<gLcL00003McL00`00McMg=`02McL01@00MeMgEgMG00000gMG00D007MG
MeMgE`0000AgE`03001gMgMg0080009gM`06001gMgMg001gN0000WMh00<007MhMgP00P0000=gV000
MiP00WNH00@007NHMiP0009gV004001kV7^HNiP200001GNh001g^7Nh00000WNh00<007Nh000017Nh
00P007OH000007OI001gf@000WOI00<007OI00000WOI00D007OiMoT007?i0080009k^003001FoEKm
00<00003E_d005Km00EFo@@0009Fo@03001FoEKm00AFo@8000EFo@03001FoEKm00=Fo@<000EFo@04
001FoEKmE_d40005E_d00`00E_d000020002E_d00`00E_eFo@03E_d00`00E_eFo@0300000eKm001F
o@04E_d200000goo001oo`1FOol0025oo`@000ioo`<000moo`@000aoo`H001Aoo`03001oogoo08Eo
o`03001FoEKm00=Fo@03001Fo@000080009Fo@03001FoEKm00=Fo@@000=Fo@03001FoEKm00=Fo@<0
00IFo@03001FoEKm00@000IFo@04001Fo@000002E_d00`00E_eFo@02E_d010004EPAF0000Qfj00@0
01Ei5GT0008EF@03000EF@0000<EF@03000EF@0000<IF@03000IF00000<IN003000MF1eH0080008M
N004000MN0007GP300038GP00`008GP000039GP01P009GPUN2Eh000UN0<0008YN006000YMbUg:GL0
02Ug0`000beg00H002eg;GL]M`00;GL40002<IL01@00<ILaUc6G00000c6G0P000SFG00<003FG=IL0
0SFG00<003FG=IL00SFG00D003FG=ILeU`0000@eU`80008i]`03000i]SVf008i]P03000i]SVf008i
]P03000m]Sff008m]P03000m]Sff008m]P03000m]Sff008m]P05000m]Sff?KH00005@KH00`00@KI1
]P02@KH01000@KI1]T6f5@000TGF00<004GF00000P0000=5eP00AMH00dGF00<004WFBMH014WF00<0
04WFBMH00dWF00<004WFBMH00TWF00<004WfBOH014Wf00<004WfBOH00TWf00<004geCOD014ge00<0
04ge00000P0000==m@00COD014ge00<004geCOD00dge00<004geCOD014ge00<0057eDOD00e7e0P00
1U7e00<0058EDQD00e8E00<0058EDQD00e8E00@0058EDQD000AB5@03001F5EHE00AF5@03001F5EHE
00AF5@8000EF5@03001F5EHE00AF5@05001F=EHeESD00002ESD00`00ESEF=@04ESD00`00FSEJ=@02
FSD00`00FSD00007FSD00`00FSEJ=@02FSD01000FSEJ=@001UXe00@005XeFSD000AJ=@03001NEEiE
00ENE@03001NEEiE00ENE@05001NEEiEGUD00003GUD00`00GUENE@04GUD20008GUD20006HWD01000
HWERM@00169e00D0069eHWERM@0000ARM@03001RMF9e009RM@04001RMF9e0005HWD01000IWEVM@00
1FJE00@006JEIYD000AVU@03001VUFJE009VU@04001VUFJE0004IYD01000IYIVUP001VZf00<006Zf
J[H01FZf00<006Zf000016Zf00D006ZfJ[IZ]P00009Z]P03001Z]VZf00AZ]P03001ZeV[F00=ZeP05
001^eVkFK]H00002K]H00`00K]I^eP03K]H00`00K]I^eP03K]H00`00K_I^mP03K_H00`00K_I^mP03
K_H01`00K_I^mVkf001^mP0000AbmP03001c5W<F009c5P03001c5W<F009c5P03001c5W<F009c5P03
001c5g<G009c5`03001c=g<g009c=`03001c=`00009c=`05001c=g<gLcL00004McL20002McL01@00
MeMgEgMG000017MG00@007MGMeL000AgE`04001gMgMg0002MgL00`00MgL00002MgL00`00MgQgN002
0003MgP01000MiP000000gNH00H007NHMiP007NH0004NiP00`00NkP00003MkP00`00MkP00002MkP0
1@00MkQg^7Nh00000WOH00<007OH00000`0000Mgf@00MmUgf@00MmT00002MoT01@00LoT007Oh0000
0g^h0P001EKm00<005KmE_d00`0000=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d01EKm00<0
05Km00000P0000=Fo@00E_d01EKm10000UKm00<005KmE_d015Km0P001UKm00@005KmE_eFo@@000EF
o@03001Fo@0000800005E_d007ooOol0001FOol001moo`P000]oo`D000aoo`P000Qoo`X0019oo`03
001oogoo08Ioo`04001FoEKmE_d30006E_d00`00E_d000020003E_d00`00E_eFo@02E_d00`00E_d0
00020003E_d00`00E_eFo@03E_d30004E_d00`00E_eFo@03E_d20005E_d01@00E_eFoEKm00000a5H
0`000aEi0`000QEI0P0000@EF@005ETEF@80008IF@04000IF00000026GP010007EP001eH0`000Qeh
00@001eh7GP000<QN003000QN25h0080008UN005000UN2Eh9GP000029GP01000:GPYN00012Ug00@0
02Ug:GL000@]M`05000]Mbeg;GL00003;GL200000c6G000aU`02<IL01P00<ILaUc6G000aU`@000<e
U`03000eUcFG008eU`03000eUcFG008eU`06000eUcFG=IL003VG10000cVf00<003Vf>KH00SVf00<0
03ff?KH00Sff00<003ff?KH00Sff00<003ff?KH00Sff00<003ff?KH00Sff00<0046f@KH00T6f00<0
046f@KH00T6f00<0046f@KH00T6f00<0047F@MH00d7F00<004GFAMH00TGF00<004GFAMH00dGF00<0
04GFAMH00TGF0P0014GF00<004GFAMH00dGF00<004WFBMH00dWF00<004WFBMH00dWF00<004WFBMH0
0dWF00<004WfBOH00dWf00<004WfBOH00TWf00<004geCOD00dge0`0014ge00<004geCOD00dge00<0
04geCOD014ge00<004geCOD00dge00@0057eDOEAm@800003DOD0057e00EAm@03001B5E8E00=B5@03
001B5E8E00AB5@8000EB5@03001F5EHE00AF5@03001F5EHE00=F5@8000IF5@03001F5EHE00AF5@04
001F=EHe0003ESD00`00ESEF=@04ESD01@00FSEJ=EXe00000eXe00<005XeFSD015Xe00D005XeFSEJ
=@0000=J=@03001J=EXe00EJ=@8000EJ=@03001NEEiE00ANE@8000MNE@04001NEEiE0005GUD00`00
GUENE@02GUD01000GUENE@001eiE00<0069eHWD01F9e00<0069e00001V9e00@0069eHWD000ARM@05
001RMF9eHWD00004HWD01@00HWERMF9e000016Ie00D006JEIYEVU@0000AVU@05001VUFJEIYD00004
IYD01000IYEVU@0016JE00<006JF00001fZf00<006ZfJ[H016Zf00@006ZfJ[H000AZ]P07001Z]VZf
J[H006Zf00001fZf00<006[FJ]H00f[F00L006kFK]I^eP00K]H00005K]H00`00K]H00004K]H00`00
K_I^mP03K_H00`00K_I^mP02K_H00`00K_I^mP03K_H00`00L_IbmP02L_H00`00LaIc5P03LaH00`00
LaIc5P02LaH01`00LaIc5W<F001c5`0000=c5`03001c=g<g009c=`06001c=g<g001c=`000W<g00<0
07LgMcL00WLg00H007LgMcL007Lg0002MeL00`00MeMgE`02MeL01@00MeL007MG00000gMG00D007Mg
MgMgM`0000=gM`04001gMgMg0004MgP01000MgQgN0000WNH00D007NH001gV000009gV004001gV7NH
0003NiP00`00NkQk^00200001gNh001g^7Nh001g^00000=g^004001gf7OH0002MmP01000MmP007OI
0P0000]gf@00MmUgf@00MoT007?i001gn00000=k^003001Wn@0000EFo@<000EFo@03001FoEKm009F
o@<000EFo@04001FoEKmE_d40005E_d00`00E_eFo@0300000eKm001Fo@04E_d00`00E_eFo@030000
0eKm001Fo@05E_d40002E_d00`00E_eFo@04E_d20005E_d00`00Ool0001FOol001moo`8000Aoo`80
00]oo`D000aoo`8000Aoo`8000Qoo`<000Eoo`<0015oo`03001oogoo08Moo`<000=Fo@03001FoEKm
00=Fo@<000IFo@03001FoEKm00@000IFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@000080
009Fo@03001FoEKm00=Fo@05001FoEKmE_d000024EP010005GT000000QEi00L001EI000001EI000E
F@0300000aEI000EF@0300000aUH000IF00300027EP010007EPMF0000Qeh00@001eh7GPMN080008Q
N004000QN0008GP300039GP010009GPUN2Eh0P0000<YN000:GL00RUg00@002Ug:GLYM`80008]M`05
000]Mbeg;GL00003;GL01000;GL000000c6G00<0036G<IL00S6G00@0036G<ILaU`80008eU`03000e
UcFG00<eU`05000eUcFG=IL00003=IL00`00>ILiU`02>IL400000cVf000i]P02>KH00`00?KHm]P02
?KH00`00?KHm]P03?KH01@00?KHm]Sff000013ff00<0046f@KH00d6f00<0046f@KH00T6f00D0046f
@KI1]P0000E1eP030015eTGF0095eP030015eTGF00=5eP030015eP0000800003AMH004GF00A5eP03
0015eTGF0095eP030019eTWF00=9eP030019eTWF00=9eP030019eTWF00=9eP030019mTWf00=9mP03
0019mTWf00=9mP03001=m@0000800003COD004ge00E=m@03001=mDge00==m@03001=mDge00==m@03
001=mDge00A=m@<000=Am@03001AmE7e00AAm@03001B5E8E00=B5@03001B5E8E00=B5@8000IB5@03
001F5EHE00AF5@03001F5EHE009F5@03001F5@0000IF5@03001F5EHE00EF5@8000AF=@03001F=EHe
00AF=@04001J=EXe0004FSD00`00FSEJ=@04FSD01000FSEJ=@0015Xe00<005XeFSD01EXe00<005Xe
FSD01EXe00<005iEGUD00UiE00@005iEGUD000MNE@8000INE@05001NEEiEGUD00003GUD00`00GUEN
E@05GUD00`00HWERM@06HWD20006HWD00`00HWD00006HWD01000HWERM@00169e00@0069eHWD000EV
M@04001VUFJE0005IYD01000IYEVU@001FJE00<006JE00001VJE00<006ZfJ[H01FZf00<006Zf0000
1FZf00@006ZfJ[H000=Z]P03001Z]VZf009Z]P03001Z]P0000IZ]P03001ZeP0000=ZeP03001^eVkF
009^eP03001^eP0000E^eP03001^eP0000=^eP03001^mVkf00=^mP03001^mP00009^mP03001^mVkf
00A^mP03001bmW;f009bmP03001c5W<F009c5P03001c5P00009c5P03001c5W<F009c5P06001c5g<G
001c5`0017<g00<007<gLcL00W<g00D007<gLcMc=`0000Ag=`05001g=gLgMcL00003MeL00`00MeMg
E`02MeL01000MeMgE`0017MG00@007MgMgL000AgM`800003MgL007Mh009gN004001gN0000002MiP0
1@00MiQgV7NH00000gNH00<007NH00000g^H00@007^hNkP0009k^0800005MkP007NhMkP00002MkP0
1000MmQgf0000WOH00<007OH00000WOI00P007OI000007OI001gn@000W?i00<007Oh00000W^h00H0
06OiIoUWn@00E_d300000eKm001Fo@05E_d00`00E_d000020002E_d00`00E_eFo@03E_d40003E_d0
0`00E_eFo@03E_d30005E_d01000E_eFoEKm10001EKm00<005KmE_d00`0000=Fo@00E_d015Km00<0
05KmE_d00`0000=Fo@00E_d015Km00@007ooOol005Eoo`007Woo0P001Woo0P002Woo1@002goo0P00
1Woo0P0047oo0P004Goo00<007ooOol0RGoo00<005KmE_d00UKm00<005Km00000P000eKm00<005Km
E_d00eKm0`0015Km00<005KmE_d00eKm0P001EKm00<005KmE_d00eKm0P001UKm00@005KmE_eFo@H0
00<AF003000EN@0000<EN@03000EF@00008EF@04000EFAEI00025ET010005ETEF@000QUH00@001UH
6EP0008MF004000MF1eH7EP200001Qeh000MN1eh000MF0<0008QN004000QN25h00039GP01P009GPU
N2Eh000UN08000<YM`06000YMbUg:GL002Ug0`000beg00D002eg;GL]M`00008]M`8000<aU`05000a
Uc6G<IL00003<IL00`00<IL000030004=IL01@00=ILeUcFG000013FG00D003VG>ILiU`0000<iUP<0
008i]P03000m]Sff008m]P03000m]Sff00<m]P03000m]Sff008m]P05000m]Sff?KH00005@KH00`00
@KI1]P02@KH00`00@KI1]P02@KH00`00@MI1eP03@MH00`00AMI5eP02AMH01000AMI5eTGF0`0014GF
00<004GFAMH00dGF00<004GFAMH00TGF00<004WFBMH00dWF00<004WFBMH014WF00<004WFBMH00TWF
00<004WfBOH00dWf00<004WfBOH00TWf0`0014ge00<004geCOD014ge00<004geCOD00dge00<004ge
COD00dge00<004geCOD00dge0P001U7e00<0057eDOD00e7e00<0058EDQD00e8E00<0058EDQD00U8E
00<0058E00001U8E00<005HEEQD015HE00D005HEEQEF5@00009F5@03001F5EHE00EF5@03001F5EHE
00=F5@8000IF=@03001F=EHe00AF=@8000EJ=@03001J=EXe00EJ=@8000EJ=@03001J=EXe00EJ=@03
001J=EXe00EJ=@05001NEEiEGUD00003GUD00`00GUENE@05GUD00`00GUENE@05GUD01@00GUENEEiE
00000eiE00<005iEGUD015iE0P00269e00<0069eHWD01F9e00<0069e00001V9e00<0069e00001F9e
00@0069eHWD000EVM@04001VUFJE0005IYD00`00IYD00007IYD20006IYD00`00J[IZ]P04J[H01000
J[IZ]P0016Zf00<006ZfJ[H00VZf00@006ZfJ[H000EZ]P03001Z]VZf00AZ]P04001ZeV[F0003J]H0
0`00K]I^eP03K]H00`00K]I^eP03K]H01`00K]I^eVkF001^eP0000E^mP04001^mVkf0002K_H00`00
K_I^mP03K_H00`00L_H00002L_H00`00LaIc5P02LaH01P00LaIc5P00LaH000Ac5P07001c5g<GLaL0
07<G00000g<g00<007<gLcL00g<g00@007<gLcL000Ag=`03001g=gLg009g=`04001gEgMG0004MeL0
1000MeMgEgMG0P000WMG00@007MgMgL000AgM`03001gMgMg008000=gN004001gN0000002MiP01000
MiQgV7NH0P0000EgV000MiQgV00000=kV003001k^00000=k^006001k^000001g^0000gNh00<007OH
00000WOH00<007OH00000WOI00D007OIMmT007OI00@00004LoT007Oh0002NkP00`00IoUWn@02IoT2
0005E_d01000E_eFoEKm10001UKm00<005Km00000P0000=Fo@00E_d01EKm00<005Km00000P0000=F
o@00E_d01EKm10000eKm00<005KmE_d00eKm0`001EKm00<005KmE_d00UKm0`001EKm00@005KmE_eF
o@<0009oo`03001oogoo059oo`007Woo0P001Woo0P002goo0`0037oo0P001Woo0P004Goo0P0047oo
00<007ooOol0RWoo00<005KmE_d010001UKm00<005Km00000P0000=Fo@00E_d01EKm00<005Km0000
0P000UKm00<005KmE_d00eKm00<005Km00000P000UKm00<005KmE_d00eKm10000eKm00<001hm0000
0P0000@AF0005GTEN@8000045GT001EI5ET300035ET300035ET300036EP200001QeH000MF1eH000M
F08000<MN004000MF1eH00028GP010008GPQN25h0P000REh00L002Eh9GPUN0009GP00004:GL01@00
:GLYMbUg00000RUg0P000beg00D002eg;GL]M`00008]M`80008aU`05000aUc6G<IL00003<IL00`00
<ILaU`02<IL30002=IL00`00=ILeU`02=IL01@00=ILeUcFG00000cVG00<003VF>IH00SVF00<003Vf
00000`0013ff00<003ff?KH00Sff00<003ff?KH00Sff00<003ff?KH00Sff00<0046f@KH00T6f00<0
046f@KH00T6f00<0046f@KH00T6f00<0047F@MH00d7F00<004GFAMH00TGF10000TGF00<004GFAMH0
0TGF00<004GFAMH00dGF00<004GFAMH00TGF00<004WFBMH014WF00<004WFBMH00dWF00<004WFBMH0
0TWF00<004WfBOH014Wf100000=9m@00COD01Dge00<004geCOD00dge00<004geCOD00dge00<004ge
COD00dge00@004geCOE=m@800003COD0057e00EAm@03001AmE7e00AAm@03001B5E8E009B5@03001B
5E8E0080009B5@03001B5E8E00EB5@03001F5EHE00=F5@04001F5EHE0004EQD00`00EQEF5@04EQD0
0`00EQEF5@02EQD00`00EQD00006ESD00`00ESEF=@04ESD00`00FSEJ=@04FSD00`00FSEJ=@05FSD0
0`00FSEJ=@05FSD00`00FSEJ=@03FSD20007FSD01@00GUENEEiE00000eiE00<005iEGUD01EiE00<0
05iEGUD01EiE00@005iEGUD000ENE@03001NEEiE009NE@04001REF9E0007HWD00`00HWERM@06HWD0
0`00HWERM@05HWD00`00HWD00006HWD20007IWD20007IYD20007IYD00`00IYEVU@04IYD00`00IYD0
0005J[H01000J[IZ]P0016Zf00<006ZfJ[H00VZf00<006Zf00001VZf00<006ZfJ[H016Zf00L006[F
J]IZeP00J]H00006K]H00`00K]I^eP03K]H01`00K]I^eVkF001^eP0000E^mP06001^mVkf001^mP00
1Fkf00H007;fL_H007;f0005LaH01P00LaIc5P00LaH000Ac5P03001c5g<G009c5`03001c=g<g009c
=`03001c=g<g009c=`05001g=`00LcL00004McL02@00McMg=gLg001gE`00MeL00003MeL01@00MeMg
EgMG00000WMG00<007MG00000WMg00D007MgMgMgM`0000=gM`05001gM`00MgP00002MgP200000gNH
001gV002MiP00`00NiQkV00200000gNH001kV002NiP01000NkQk^0000W^h00D007^hNkP007Nh00<0
0009MkP007OHMmP007OH001gf000009gf@04001gfGOI0002MmT01000MoT007Oi100000Ak^000IoUW
n@<00003E_d005Km00AFo@@000=Fo@03001FoEKm00AFo@8000EFo@04001FoEKmE_d40005E_d00`00
E_eFo@0300000eKm001Fo@05E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d0000200000eKm
001Fo@05E_d40003E_d00`00Ool0001DOol001eoo`8000Qoo`8001Qoo`8000Qoo`80011oo`80011o
o`04001oo`00002:Ool20004E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d20006E_d01000
E_eFoEKm0`001UKm00<005Km00000P0000=Fo@00E_d01EKm00@001hm000=NP<000035GT0015I00<0
00035ET0015I0080008EF@04000EF@0000025ET010005EP000000QUH00@001UH000000<MF003000M
F00000<MN007000MF1eH7EP0025h00000b5h00<0025h00000P000bEh00<002Eh9GP00P000RUg00D0
02Ug:GLYM`0000<YM`80008]M`05000]Mbeg;GL00002;GL00`00;IL000020004<IL01@00<ILaUc6G
00000c6G00<003FG=IL010000cFG00D003FG=ILeU`0000@iU`05000iUSVF>IH00004>KH400000cff
000m]P03?KH00`00?KHm]P02?KH00`00?KHm]P02?KH00`00@KI1]P03@KH01@00@KI1]T6f0000146f
00<0047F@MH00d7F00<004GFAMH00`001DGF00<004GFAMH00TGF00<004GFAMH00dGF00<004GFAMH0
0dGF00<004WFBMH00dWF00<004WFBMH00dWF00<004WFBMH00TWF00<004WfBOH00dWf0P0014We00<0
04geCOD014ge00<004geCOD00dge00<004geCOD014ge00<004geCOD00dge0`000dge00<0057eDOD0
157e00<0057eDOD0157e00<0058EDQD00e8E0P001E8E00<0058EDQD0158E00<005HEEQD015HE0P00
1EHE00<005HEEQD015HE00D005HEEQEF5@00009F5@03001F=EHe00AF=@03001F=EHe00AF=@03001J
=EXe00EJ=@03001J=EXe00=J=@8000MJ=@03001J=EXe009J=@04001J=EXe0006FSD01000GUENE@00
15iE00<005iEGUD015iE0P0025iE0P001UiE00D005iEGUENE@0000=RE@03001RMF9e00ARM@8000QR
M@03001RMF9e00IRM@03001RMF9e00ERM@03001VMFIe00IVM@03001VUFJE00IVU@03001VUFJE00IV
U@03001VUFJE00AVU@03001VU@0000AZ]P03001Z]VZf009Z]P04001Z]VZf0005J[H00`00J[H00005
J[H00`00J[H00004J[H00`00J]IZeP02J]H00`00J]H00005K]H00`00K]H00003K]H00`00K]I^eP03
K]H00`00K_I^mP03K_H00`00K_I^mP02K_H00`00K_I^mP04K_H01P00L_IbmP00L_H000Ac5P03001c
5W<F009c5P03001c5W<F009c5P03001c5g<G00=c5`80009c=`03001c=g<g009c=`05001g=gLgMcL0
0004McL01@00McMg=gLg00000gMG00<007MGMeL00WMG00D007MGMeMgE`0000=gE`04001gMgMg0004
MgL01000MgMgM`000gMg00L007MhMgQgN000MiP00003MiP01P00NiQkV7^H001kV08000=kV003001k
^000009k^004001k^7^h0002MkP00`00MkQg^00200002GOH001gf7OH001gf000MmT00002MmT01P00
MmUgf@00MoT0009gn@04001gn@00MmT40005E_d00`00E_d000020002E_d00`00E_eFo@03E_d00`00
E_eFo@0300000eKm001Fo@04E_d40003E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@03E_d20005
E_d01000E_eFoEKm10001EKm00<005KmE_d00`0000=Fo@00E_d01EKm00<007oo0000Dgoo000MOol2
0008Ool2000HOol20008Ool2000@Ool2000?Ool3002<Ool00`00E_eFo@04E_d00`00E_d000020002
E_d00`00E_eFo@03E_d00`00E_d000020002E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d3
0004E_d00`00E_eFo@03E_d400023GX010005GTEN@000Q5I00H001EI5ET0015I00035ET00`005ET0
00035ET00`005EP000036EP00`006EP000037EP00`007EPMF00200000aeh000MF0027EP200000b5h
000QN0028GP010008GPQN0000bEh00D002Eh9GP002Eg00<000<YM`06000YMbUg:GL002Ug0`000beg
00D002eg;GL]M`00008]U`8000<aU`05000aUc6G<IL00003<IL00`00=ILeU`03=IL20002=IL00`00
=ILeU`02=IL01@00>ILiUcVG000013VF00D003Vf>KHi]P0000<i]PD0008m]P05000m]Sff?KH00004
?KH00`00@KI1]P03@KH00`00@KI1]P02@KH00`00@KI1]P02@KH00`00@MI1eP02@MH30002AMH00`00
AMI5eP03AMH00`00AMI5eP03AMH00`00AMI5eP03AMH00`00AMI5eP02AMH00`00BMI9eP03BMH00`00
BMI9eP03BMH00`00BMI9eP03BMH00`00BOH0000200000dWE0019m@04BOD00`00COE=m@03COD00`00
COE=m@04COD00`00COE=m@03COD00`00COE=m@02COD20006COD00`00DOEAm@03DOD00`00DOEAm@04
DOD00`00DQEB5@02DQD20006DQD00`00DQEB5@04DQD00`00EQEF5@03EQD20006EQD00`00EQEF5@04
EQD01000EQEF5@0015HE00<005HeESD015He00<005HeESD00UHe00<005Xe00001UXe00<005XeFSD0
0UXe00<005Xe00001eXe00D005XeFSEJ=@0000=J=@03001J=EXe00EJ=@8000INE@03001NEEiE009N
E@04001NEEiE0007GUD00`00GUENE@05GUD01@00GUENEEiE00000f9E00<0069eHWD00f9e00@0069e
HWD000IRM@8000QRM@03001RMF9e00ERM@03001VMFIe00IVM@03001VUFJE00IVU@03001VUFJE00EV
U@03001VU@0000AVU@04001VUFJE0004J[H00`00J[IZ]P02J[H00`00J[H00007J[H00`00J[IZ]P04
J[H00`00J[H00004J[H00`00J]IZeP03J]H00`00K]I^eP04K]H00`00K]H00003K]H00`00K]I^eP03
K]H00`00K_I^mP03K_H00`00K_I^mP02K_H00`00K_I^mP03K_H00`00L_IbmP02L_H00`00LaIc5P03
LaH00`00LaIc5P02LaH00`00LaIc5P02LaH00`00LaMc5`02LaL01P00LaMc5`00LcL000Ac=`05001g
=gLgMcL00004McL01@00McMg=gLg00000gMG0P000WMG00D007MGMeMgE`0000AgE`800003MgL007Mg
009gM`05001gMgMgMgL00003MgL2000017Mh001gV7NH0P000WNH00@007^HNiP0009kV005001k^000
NiP00002NkP00`00NkP00002NkP01000MkQg^0000gNh00P007OH000007OH001gf0000WOI00<007OI
00000WOI00<007Oi00000WOi00<007Oi00000WOI00<007?i00001UKm0P001UKm00@005KmE_eFo@@0
00EFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@000080009Fo@03001FoEKm00=Fo@03001F
oEKm00<00003E_d005Km00AFo@@000=Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm00=Fo@800003
Ool007oo055oo`007Goo0P0027oo0P0067oo0P0027oo0P0047oo0P003goo00<007ooOol0SGoo00<0
05KmE_d00eKm0P001UKm00@005KmE_eFo@<000IFo@03001Fo@0000800003E_d005Km00EFo@03001F
o@00008000=Fo@03001FoEKm009Fo@03001Fo@00008000=Fo@80008=NP<000<AF@<0008AF@800004
5ET001EI5ET2000011EI000EF1EH0P0000@IF0006EPIF080008MF007000MF0007EP001eh00000aeH
0`000b5h00@0025h8GPQN080008UN004000UN2Eh00029GL20003:GL01@00:GLYMbUg00000RUg0P00
0beg00@002eg;GL000<]U`80008aU`05000aUc6G<IL00004<IL00`00=ILeU`02=IL00`00=IL00003
0003=IL01@00>ILiUcVG000013VF00D003Vf>KHi]P0000@i]P04000m]Sff?KH600000cff000m]P02
?KH00`00@KI1]P03@KH00`00@KI1]P02@KH00`00@KI1]P02@KH00`00@MH0000200000d7F0015eP03
AMH00`00AMI5eP03AMH00`00AMI5eP02AMH00`00AMI5eP03AMH00`00AMI5eP02AMH00`00BMI9eP03
BMH00`00BMI9eP04BMH00`00BMI9eP040004BMD00`00BOE9m@03BOD00`00COE=m@03COD00`00COE=
m@04COD00`00COE=m@03COD00`00COE=m@0200000dge001=m@05COD00`00DOEAm@04DOD00`00DOEA
m@03DOD00`00DQEB5@0200000e8E001B5@05DQD00`00DQEB5@04DQD00`00EQEF5@02EQD00`00EQD0
0006EQD00`00EQEF5@05EQD20005EQD00`00ESEF=@04ESD01@00ESEF=EHe00000UXe00<005XeFSD0
15Xe00D005XeFSEJ=@0000=J=@03001J=EXe00AJ=@04001J=EXe0004FSD00`00FSEJ=@05FSD00`00
GUENE@05GUD01@00GUENEEiE00000eiE00<005iEGUD01EiE00<005iEGUD01EiE00@005iEGUD000ER
E@05001RMF9eHWD00003HWD00`00HWERM@03HWD01000HWERM@001V9e0P001V9e0P001fIe00<006JE
00001VJE00<006JE00001FJE00@006JEIYD000AVU@05001VUFJEIYD00002J[H00`00J[IZ]P03J[H0
0`00J[H00007J[H00`00J[IZ]P03J[H01@00J[IZ]VZf00000VZf00<006[FJ]H016[F00<006kFK]H0
0fkF00L006kFK]I^eP00K]H00005K]H00`00K_H00003K_H00`00K_I^mP02K_H00`00K_H00004K_H0
0`00L_IbmP02L_H00`00LaIc5P02LaH00`00LaIc5P02LaH00`00LaH00002LaH00`00LaMc5`03LaL0
1@00LaMc5g<G000017<g00L007LgMcMg=`00McL00002McL01@00McMg=gLg00000gMG00H007MGMeL0
07MG0002MeL00`00MeMgE`02MeL00`00MgMgM`020003MgL01000MgMgM`000gMg00@007MgMgL0009g
V005001gV000MiP00002NiP01000NiQkV0000g^h0P0000Mk^000NkQk^000NkP00002MkP01@00MkQg
^7Nh00000WOH00<007OH00000`0000Ugf@00MmUgf@00MmT007Oi00000WOi00<007Oi00000WOI00D0
07?i001g^@00009Fo@<00003E_d005Km00EFo@@0009Fo@03001FoEKm00AFo@8000EFo@03001FoEKm
00=Fo@8000IFo@04001FoEKmE_d40005E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d00002
0002E_d00`00E_eFo@03E_d00`00E_eFo@03000015Km001oo`00DWoo000MOol20008Ool2000HOol2
0008Ool2000@Ool2000?Ool00`00Oomoo`2>Ool00`00E_d000020002E_d00`00E_eFo@03E_d40003
E_d00`00E_eFo@03E_d30004E_d00`00E_eFo@03E_d30006E_d00`00E_eFo@040006E_d200000`ej
000=F@0200024ET01`004ET000004ET0015I00<0000?5ET001EH000EF@005EP001EH000IF0006EP0
01UH00<0008MF004000MF00000037EP00`008EP000038GP01P008GPQN25h000QN0<0008UN004000U
MbEg9GL20002:GL01@00:GLYMbUg00000bUg0P000Reg00@002eg;GL000<]U`03000aU`0000<000<a
U`05000aUc6G<IL00004=IL00`00=ILeU`02=IL20002=IL00`00>ILiU`02>IL01@00>IHiUSVF0000
13Vf00D003Vf>KHi]P0000Dm]P04000m]Sff?KH500000cff0011]P03@KH00`00@KI1]P02@KH01000
@KI1]T6f0`00147F00<004GFAMH00TGF00<004GFAMH00dGF00<004GFAMH00TGF00<004GFAMH00dGF
00<004GFAMH00TGF00<004WFBMH014WF00<004WFBMH01P000TWE00<004WEBMD014WE00<004WeBOD0
0TWe00<004geCOD014ge00<004geCOD00dge00<004geCOD014ge0P000dge00<004geCOD014ge00<0
057eDOD0157e00<0057eDOD0157e0P000e8E00<0058EDQD0158E00<0058EDQD0158E00<005HEEQD0
0P000UHE00<005HEEQD01EHE00<005HEEQD015HE00<005HEEQD015HE00<005HeESD015He00@005He
ESD000=J=@03001J=EXe00AJ=@04001J=EXe0004FSD00`00FSEJ=@05FSD20005FSD00`00FSEJ=@05
FSD00`00GUENE@05GUD01@00GUENEEiE00000eiE00<005iEGUD015iE0P0025iE0P001V9E00D0069e
HWERM@0000=RM@03001RMF9e00=RM@04001RMF9e0005HWD01000HWERM@001F9e00<006Ie00001FIe
00@006JEIYD000EVU@04001VUFJE0005IYD01000IYEVU@000fJE00<006JEIYD00VJE00<006Zf0000
1fZf00<006ZfJ[H01FZf00<006Zf000016Zf00L006ZfJ[IZ]P00J[H00006J]H00`00K]H00004K]H0
1`00K]I^eVkF001^eP0000E^eP06001^mVkf001^mP001Fkf00<006kf00000fkf00<007;fL_H00W;f
00<007<F00000W<F00<007<FLaH00g<F00H007<FLaH007<F0004LaL00`00LaMc5`02LaL01@00LcMc
=g<g000017Lg00H007LgMcL007Lg0003McL01@00MeMgEgMG00000gMG00D007MGMeMgE`0000AgE`08
001gMgMg001gM`00MgL0009gM`05001gMgMgMgL00003MgL2000017NH001gV7NH0P000W^H00<007^H
000017^h00H007^h000007^h0002NkP00`00MkP00003MkP01000MmQgf0000WOH00@007OH001gf080
0004MmT007OI0002MoT01@00MoT007Oi00000WOI00<007?i00000gNi0P001EKm00<005KmE_d00`00
00=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d01EKm
10000UKm00<005KmE_d015Km0P001EKm00<005KmE_d00eKm0P001UKm00@005KmE_eFo@@000EFo@03
001oo`00055oo`007Goo0P0027oo0P0067oo0P0027oo0P003goo0P0047oo00<007ooOol0Sgoo0P00
1EKm00<005Km00000P000UKm00<005KmE_d00eKm00<005Km00000P000eKm00<005KmE_d00UKm00<0
05Km00000P000eKm00<005KmE_d00eKm0`0015Km00<005KmE_d00eKm1@0000<=F@004ET00Q5I00<0
015I00000Q5I00@0015I4ET0008EF@04000EF00000025EP010005EP000000QUH00@001UH6EP0008M
F004000MF1eH00037EP00`008EPQF00200028GP01@008GPQN25h00000R5h00@002Eh9GP000<UM`03
000YM`00008000<YM`06000YMbUg:GL002eg0`000beg00D002fG;IL]U`0000<aU`80008aU`05000a
Uc6G<IL00005=IL01P00=ILeUcFG000eU`@000<iU`03000iUSVF008iUP05000i]SVf>KH00004>KH0
0`00?KHm]P02?KH00`00?KHm]P02?KH01000?KHm]Sff1@000T6f00@0046f@KI1]P@00003@KH0047F
00A1eP030015eTGF0095eP030015eTGF00=5eP030015eTGF0095eP030015eTGF00=5eP030015eTGF
00=5eP030019eTWF00H000=9eP030019eDWE0099e@030019eDWE00A9e@030019mDWe0099m@03001=
mDge00A=m@03001=mDge00==m@03001=mDge00==m@8000E=m@03001=mDge00==m@03001AmE7e00AA
m@03001AmE7e00=Am@8000EB5@03001B5E8E00AB5@03001B5E8E00AB5@8000EF5@03001F5EHE00AF
5@03001F5EHE00=F5@8000IF5@03001F=EHe00EF=@8000EJ=@03001J=EXe00AJ=@8000EJ=@03001J
=EXe00EJ=@03001J=EXe00EJ=@03001J=EXe00=J=@8000MNE@04001NEEiE0005GUD00`00GUENE@02
GUD01000GUENE@001eiE00<0069EHUD01F9E00@0069eHWD000ERM@05001RMF9eHWD00003HWD00`00
HWERM@03HWD01000HWERM@00169e00@006IeIWD000EVM@04001VUFJE0005IYD01000IYEVU@0016JE
00<006JEIYD00VJE00@006JEIYD000AVU@03001Z]P0000MZ]P03001Z]VZf00AZ]P04001Z]VZf0003
J[H00`00J[IZ]P02J[H00`00J[H00006J]H00`00K]H00003K]H00`00K]I^eP03K]H00`00K]I^eP03
K]H01`00K_I^mVkf001^mP0000A^mP07001^mVkfK_H006kf00001G;f00H007<FLaH007<F0004LaH0
0`00LaIc5P02LaH00`00LaMc5`02LaL00`00LaMc5`02LaL00`00LcL00002LcL01@00McMg=gLg0000
17Lg00D007LgMcMg=`0000=gE`03001gEgMG009gE`04001gEgMG0004MeL01000MgMgM`000gMg00D0
07MgMgMgM`0000=gM`04001gMgMg0002NiP300001GNH000007^H00000W^H00D007^hNkQk^000009k
^006001k^000001k^0000WNh00@007NhMkP0009gf006001gf7OH001gf0000WOH00<007OH00000`00
00Agn@00MoT0009gn@05001gf@00LoT00003MkT00`00Jo/00005E_d30005E_d00`00E_eFo@02E_d3
0005E_d01000E_eFoEKm10001EKm00<005KmE_d00`0000=Fo@00E_d015Km00<005KmE_d00`0000=F
o@00E_d015Km00<005KmE_d00`0000=Fo@00E_d01EKm10000UKm00<005KmE_d015Km0P0000=oo`00
Ool0Cgoo000MOol20008Ool2000HOol20008Ool20007Ool20005Ool3000@Ool00`00Oomoo`2AOol0
0`00E_eFo@02E_d30005E_d00`00E_eFo@02E_d30006E_d00`00E_eFo@040006E_d00`00E_d00002
00000eKm001Fo@05E_d00`00E_d00002000015Km0000004i0P0000D=F@00000AF@00008AF@800007
4ET0015I4ET001EI00000QEH00@001EH5EP0008EF004000IF1UH00036EP2000011eH000MF1eH0P00
0QeH00@0025H000QF0<000<QN004000QN25h8GP200000bEh000UM`029GL00`00:GLYM`020003:GL0
1@00:GLYMbUg00000Reg0P000Reg00D002fG;IL]U`0000<aU`03000aU`00008000@aU`03000eUcFG
008eU`05000eUcFG=IL00004=IL20002>IL00`00>IHiUP02>IH01@00>KHi]SVf000013Vf00<003ff
?KH00cff00D003ff?KHm]P0000@m]P04000m]Sff?KH80004@KH00`00@MI1eP02@MH00`00AMI5eP02
AMH00`00AMI5eP03AMH00`00AMI5eP03AMH00`00AMI5eP03AMH00`00AMI5eP050003BMH00`00BMI9
eP03BMH00`00BME9e@03BMD00`00BME9e@03BMD00`00BOE9m@03BOD00`00COE=m@03COD00`00COE=
m@03COD01000COE=mDge0P0000==m@00COD014ge00<004geCOD014ge00<0057eDOD00e7e00<0057e
DOD00U7e00<0057e00001E8E00<0058EDQD0158E00<0058EDQD00e8E0P001UHE00<005HEEQD015HE
00<005HEEQD00UHE00<005HE00001eHE00<005HeESD015He00<005XeFSD015Xe00<005XeFSD015Xe
00<005XeFSD015Xe00<005XeFSD01EXe00<005XeFSD01EXe00<005XeFSD00UXe00@005heGSD000MN
E@8000INE@05001NEEiEGUD00003GUD00`00GUENE@05GUD00`00HUERE@06HUD20006HWD01000HWER
M@001F9e00D0069eHWERM@0000=RM@03001RMF9e009RM@04001VMFIe0004IWD00`00IYEVU@02IYD0
1@00IYEVUFJE000016JE00@006JEIYD000EVU@03001VU@0000IVU@03001Z]VZf00EZ]P03001Z]@00
00EZ]P05001Z]VZfJ[H00002J[H00`00J[IZ]P03J[H00`00J]IZeP04J]H01@00K]I^eVkF00000VkF
00<006kFK]H00fkF00<006kFK]H00fkF00<006kfK_H00Vkf00<006kfK_H00fkf00L006kfK_I^mP00
K_H00004L_H00`00LaIc5P02LaH00`00LaIc5P03LaH00`00LaIc5P02LaH00`00LaMc5`02LaL01@00
LaMc5g<G00000W<g00<007<g000017Lg00<007LgMcL00WLg00@007LgMcL000AgE`09001gEgMGMeL0
07MG001gE`0000=gE`05001gMgMgMgL00003MgL01000MgMgM`000gMg00@007MgMgL000=kV00:001k
V7^H001kV000NiP007^H0003NkP01000NkQk^0000W^h00H007^h000007Nh0002MkP01000MmQgf000
0WOH00<007OH00000WOH00L007OHMmP007OH001gn@0400001WOi001gf@00LoT000=g^@06001[nf_k
Jo/005Km0`0000=Fo@00E_d01EKm00<005Km00000P0000=Fo@00E_d01EKm10000eKm00<005KmE_d0
0eKm0`001EKm00<005KmE_d00UKm0`001EKm00@005KmE_eFo@@000EFo@03001FoEKm00<00003E_d0
05Km00AFo@03001FoEKm00<00004E_d007oo001@Ool001eoo`8000Qoo`8001Qoo`8000Qoo`8000Mo
o`T0015oo`03001oogoo099oo`04001Fo@000003E_d00`00E_eFo@03E_d01000E_d000000eKm00<0
05KmE_d00eKm0`0015Km00<005KmE_d00eKm0P001EKm00<005KmE_d00eKm0P001EKm0P0000D1>@00
3ET000eI00<000034ET0015I0080008AF@8000045ET001EH5EP2000011EH000EF1EH0P0000HIF000
6EPIF0006EP200027EP00`007EP0000200028EP010008EPQF0000b5h00H0025h8GPQN0009GL20003
9GL01000:GLYMbUg0P000RUg00D002Ug:GLYM`0000<]M`800003;GL002fG008]U`05000aUc6G<IL0
0003<IL20003<IL00`00=ILeU`02=IL00`00=ILeU`02=IL01P00=ILeUcFG000eUP@000<iUP03000i
]SVf008i]P05000i]SVf>KH00005?KH00`00?KHm]P02?KH01@00?KHm]Sff00001Cff0`0000=1]P00
000020000T7F00<004GFAMH00TGF00<004GFAMH00dGF00<004GFAMH02`000TGF00<004WFBMH00dWF
00<004WFBMH014WF00<004WEBMD00TWE00<004WEBMD00dWE00<004WeBOD00dWe00<004geCOD00dge
00<004geCOD014ge0`000dge00<004geCOD00dge00<004geCOD014ge00<0057eDOD00e7e00<0057e
DOD00P000U7e00<0058EDQD00e8E00<0058EDQD0158E00<0058EDQD00U8E00<0058E00001UHE00<0
05HEEQD015HE00D005HEEQEF5@0000=F5@03001F5EHE00AF5@03001F=EHe00=F=@8000IJ=@03001J
=EXe00AJ=@03001J=EXe00EJ=@03001J=EXe00=J=@8000MJ=@05001J=EXeFSD00003GSD00`00GUEN
E@05GUD00`00GUENE@05GUD01@00GUENEEiE00000eiE00<005iEGUD015iE0P00269E00<0069eHWD0
1F9e00@0069eHWD000ERM@04001RMF9e0005HWD01000HWERM@0016Ie00D006IeIWEVM@0000AVU@04
001VUFJE0005IYD01000IYEVU@001FJE00<006JE00001VJE00<006ZfJ[H01FZf00<006Ze000016Zf
00<006ZfJ[H00VZf00<006Zf00001VZf00<006[FJ]H016[F00L006kFK]I^eP00K]H00005K]H00`00
K]H00003K]H00`00K_I^mP03K_H00`00K_I^mP02K_H00`00K_I^mP03K_H00`00L_IbmP03L_H00`00
LaIc5P02LaH00`00LaIc5P02LaH00`00LaIc5P02LaH00`00LaH00002LaL00`00LaMc5`02LaL01@00
LcMc=g<g000017Lg00<007LgMcL00WLg00D007Lg001g=`0000=gE`05001gEgMGMeL00003MeL00`00
MeMgE`02MeL01000MgMgM`000gMg00D007Mg001gM`00009gM`05001gMgMgMgL00002NiP01000NiQk
V7^H0P0000EkV000NiQkV000009k^004001k^7^h0002NkP01@00NkQk^000NkP00P0000=g^000MmP0
0WOH00<007OH00000WOH00<007OH00000WOH00<007OH00000WOi00@007Oi001gn@D000=g^@03001[
nf_k009[n`8000EFo@04001FoEKmE_d40005E_d00`00E_eFo@0300000eKm001Fo@05E_d00`00E_d0
000200000eKm001Fo@05E_d00`00E_d0000200000eKm001Fo@05E_d40003E_d00`00E_eFo@03E_d3
0005E_d00`00E_eFo@02E_d30005E_d00`00Ool0001?Ool001eoo`8000Qoo`8001Qoo`8000Qoo`80
00Moo`800003Ool0000000<0015oo`03001oogoo09Aoo`03001FoEKm00AFo@04001FoEKmE_d30006
E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d000020002E_d00`00E_eFo@03E_d00`00E_d0
00020002E_d00`00E_eFo@02E_d30000104i000000000PeI00@0015I4ET0008AF@03000AFA5I00<0
008EF004000EF00000025EP010005EP000000aUH00@001UH0000008MF004000MF1eH00028EP01000
8EPQF25H0P000R5h00L0025h8GPQN0009GL000039GL01P00:GLYMbUg000YM`<000<YM`06000]Mbeg
;GL002eg0`000bfG00D0036G<ILaU`0000<aU`80008aU`03000eUcFG008eU`03000eUcFG008eU`05
000eUcFG=IL00004=IH20002>IH00`00>KHi]P02>KH00`00>KHi]P02>KH00`00?KHm]P02?KH00`00
?KHm]P02?KH00`00?KHm]P02?KH00`00?KH000030004@KH00`00@KI1]P02@KH01000@KI1]T6f4000
0TGF00<004GFAMH00dGF00<004GFAMH00TGF00<004WFBMH014WF00<004WFBMH00dWF00<004WEBMD0
0TWE00<004WEBMD014WE00<004WeBOD00TWe00<004geCOD00dge00<004geCOD00dge0P001Tge00<0
04geCOD00Tge00<004geCOD014ge00<0057eDOD0157e0P001E7e00<0058EDQD00e8E00<0058EDQD0
0e8E00<0058EDQD00P000U8E00<005HEEQD015HE00<005HEEQD015HE00@005HEEQD000AF5@03001F
5EHE00AF5@03001F=EHe009F=@03001F5@0000MJ=@03001J=EXe009J=@8000MJ=@03001J=EXe009J
=@04001J=EXe0006FSD01000FSEJ=@0015he00<005iEGUD01EiE00<005iEGUD01EiE00@005iEGUD0
00ANE@03001NEEiE00=NE@04001NEEiE0007HUD00`00HWERM@06HWD20006HWD01000HWERM@001F9e
00@0069eHWD000AVM@04001VMFIe0005IYD01000IYEVU@001FJE00<006JE00001fJE00<006JEIYD0
16JE00<006Ze00001FZf00@006ZeJ[D000AZ]P03001Z]VZf009Z]P03001Z]P0000EZ]P03001ZeP00
00AZeP03001^eVkF009^eP03001^eP0000E^eP03001^eP0000=^eP03001^mVkf009^mP03001^mP00
00=^mP03001^mVkf00=^mP03001bmW;f009bmP03001c5W<F009c5P03001c5P0000=c5P03001c5W<F
009c5P06001c5W<F001c5`000g<G00<007<gLcL00W<g00<007LgMcL00WLg00D007LgMcMg=`0000=g
=`03001gEgMG009gE`05001gEgMGMeL00003MeL20002MeL01000MgMgM`000gMg00D007MgMgMgM`00
00=gM`04001gMgMg0002NiP01@00NiQkV7^H00000W^H10000g^h00H007^hNkP007^h0002NkP01@00
NkQk^000NmP00`0000Ugf000MmQgf000MmP007OH00000WOH00<007OH00000WOi00<007Oi00000WOi
00@007Oi001cn@800004MkT006_kJo/300000eKm001Fo@04E_d40003E_d00`00E_eFo@03E_d30005
E_d00`00E_eFo@03E_d20005E_d01000E_eFoEKm10001EKm00<005KmE_d00`0000=Fo@00E_d01EKm
00<005Km00000P0000=Fo@00E_d01EKm00<005Km00000P0000=Fo@00E_d01EKm0P0000=oo`00Ool0
CGoo000NOol20006Ool2000JOol20006Ool20008Ool2000GOol00`00Oomoo`2EOol00`00E_eFo@03
E_d40003E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d20006E_d01000E_eFoEKm0`001UKm
00<005KmE_d00UKm0P0000<1>@001CT00P000PeI0`000a5I00D0015I000AF00000<EF003000EF000
00<EF003000EF00000<IF004000IF1UH00027EP010007EPMF1eH0P0000HQF0008EPQF0008EP30003
8GP00`009GLUM`0200029GL01@00:GLYMbUg00000RUg0P000bUg00D002eg;GL]M`00008]M`80008]
U`05000aUc6G<IL00003<IL00`00<IL000030003=IL00`00=ILeU`02=IL00`00=ILeU`02=IL01P00
=IHeUSFF000iUP@000<i]P03000i]SVf008i]P03000m]Sff008m]P03000m]Sff008m]P04000m]Sff
?KH30004?KH01@00@KI1]T6f0000146f00<0046f@KH00d6f00<0046f@KH00T6f00<004GFAMH00dGF
00<004GFAMH00TGF00<004GFAMH00dGF00<004GFAMH00dGF00<004WFBMH00dWF00<004WFBMH00dWF
00<004WEBMD00TWE00<004WEBMD014WE00<004WeBOD00TWe00<004geCOD014ge00<004ge00000P00
00==m@00COD01Dge00<004geCOD00dge00<004geCOD00dge00<0057eDOD00e7e0P001U7e00<0058E
DQD00e8E00<0058EDQD0158E0P001E8E00<005HEEQD015HE00<005HEEQD015HE0P001EHE00<005HE
EQD015HE00D005HeESEF=@0000=F5@03001J=EXe00AJ=@05001J=EXeFSD00002FSD00`00FSEJ=@04
FSD01@00FSEJ=EXe00000eXe00<005XeFSD01EXe0P001Ehe00<005iEGUD015iE0P0025iE0P001UiE
00<005iEGUD00UiE00@005iEGUD000IRE@8000QRM@03001RMF9e00IRM@8000IRM@03001RM@0000EV
M@03001VM@0000MVU@8000MVU@03001VUFJE00IVU@03001VUFJE00AVU@03001Z]@0000EZ]P05001Z
]FZeJ[D00002J[H00`00J[IZ]P04J[H00`00J[IZ]P04J[H00`00J]H00003J]H00`00K]I^eP04K]H0
0`00K]I^eP03K]H01`00K]I^eVkF001^eP0000E^mP03001^mP0000=^mP03001^mVkf009^mP03001b
mP0000=bmP03001c5W<F009c5P06001c5W<F001c5P0017<F00<007<FLaH00W<F00<007<GLaL00W<G
00L007<gLcMc=`00McL00002McL00`00McMg=`02McL01000McMg=gLg0P000WMG00D007MGMeMgE`00
00=gE`06001gEgMG001gE`000WMg00D007MgMgMgM`0000=gM`800003MgL007Mg009gM`04001kV7^H
0002NiP01P00NiQkV7^H001kV080009k^004001k^7^h0002NkP00`00NkP00002NkP01000NmQkf000
0WOH0P0000]gf000MmQgf000MmP007OH001gf000009gn@03001gn@00009gn@05001gn@00LoT00002
LoT40005E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d000020002E_d00`00E_eFo@03E_d0
0`00E_eFo@0300000eKm001Fo@04E_d40003E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@03E_d2
0005E_d01000E_eFoEKm10001EKm00<005KmE_d00`0000AFo@00Ool004ioo`007Woo0P001Woo0P00
6Woo0P001Woo0P0027oo0P005goo00<007ooOol0UWoo00<005Km00000P0000=Fo@00E_d01EKm00<0
05Km00000P000UKm00<005KmE_d00eKm00<005Km00000P000UKm00<005KmE_d00eKm10000eKm00<0
05KmE_d00eKm0`000UKm00<0003F00000P0000H5>@003ET=F@003ET200024ET200000a5I000AF002
000011EH000EF1EH0P0000@EF0005EPEF080008IF003000IF1UH008000067EP001eH7EP001eH0P00
0b5H00@0025H8EP000<QN005000UMbEg000UM`030003:GL01000:GLYMbUg0P000RUg00D002eg;GL]
M`00008]M`03000]M`00008000<aU`03000aUc6G008aU`04000aUc6G<IL20003=IL00`00=ILeU`02
=IL01@00=ILeUcFG00000cFF00<003VF>IH00SVF0P000SVf00<003Vf>KH00SVf00<003ff?KH00cff
00@003ff?KHm]P@00003?KH003ff00@m]P030011]T6f0091]P030011]T6f0091]P030011]T6f0091
]P030011]T6f0091]P030015eTGF00=5eP030015eTGF00=5eP030015eTGF00=5eP030015eTGF0095
eP030019eTWF00=9eP030019eTWF00=9eP030019eDWE00=9e@030019eDWE00=9e@030019mDWe0099
m@03001=mDge00==m@<000A=m@03001=mDge00A=m@03001=mDge00==m@03001=mDge00==m@04001A
mE7eDOD200000e7e001Am@05DOD00`00DQEB5@03DQD00`00DQEB5@04DQD00`00DQEB5@04DQD00`00
EQEF5@04EQD00`00EQEF5@03EQD20006EQD00`00EQEF5@04EQD01000ESEF=@0015HE00<005XeFSD0
15Xe00@005XeFSD000=J=@03001J=EXe00AJ=@04001J=EXe0004FSD00`00FSEJ=@05FSD00`00GSEN
=@05GSD00`00GUENE@02GUD01000GUENE@001eiE00<005iEGUD01EiE00D005iEGUENE@0000=NE@03
001REF9E00=RE@04001REF9E0007HWD00`00HWERM@06HWD00`00HWERM@06HWD20006IWD20007IYD0
0`00IYEVU@06IYD00`00IYEVU@05IYD00`00IYD00004IYD01@00J[EZ]FZe00000fZf00<006ZeJ[D0
0VZe00<006Zf00001fZf00<006ZfJ[H00fZf00D006[FJ]IZeP00009ZeP03001^eVkF00A^eP03001^
eVkF00=^eP07001^eVkFK]H006kF000016kf00L006kfK_I^mP00K_H00005K_H01P00L_IbmP00L_H0
00Ac5P07001c5W<FLaH007<F000017<F00<007<FLaH00W<F00D007<GLaMc5`0000Ac=`06001g=gLg
001g=`000gLg00D007LgMcMg=`00009gE`03001gE`0000=gE`05001gEgMGMeL00003MeL01000MgMg
M`000gMg00D007MgMgMgM`00009kM`<00005MgL007^HNiP00003NiP01000NiQkV0000W^H0P0000=k
^000NkP00W^h00<007^h00000W^h00<007^h00000W_H00H007OHMmQgf000MmP2000017OH001gf000
0WOH00L007OH001gn@00MoT00002MoT01@00MoT007?i00000W?i00@006oi000000IFo@8000EFo@03
001FoEKm00=Fo@8000IFo@04001FoEKmE_d40005E_d00`00E_d0000200000eKm001Fo@05E_d00`00
E_d000020002E_d00`00E_eFo@03E_d00`00E_eFo@0300000eKm001Fo@04E_d40003E_d00`00E_eF
o@03E_d30005E_d00`00Ool0001=Ool001moo`8000Aoo`8001aoo`8000Aoo`8000Uoo`8001Moo`03
001oogoo09Moo`03001FoEKm00=Fo@03001FoEKm00=Fo@8000IFo@04001FoEKmE_d30006E_d00`00
E_d000020002E_d00`00E_eFo@03E_d00`00E_d000020002E_d400000`3F0001600200001`Di0000
00eI000=F@0000<AF@<000034EP0014h00<000035EP001EH00<000035EP001EH00<0008IF004000I
F00000037EP00`007EP000038EP010008EPQF25H0P000R5h00@002Eg9GL0008UM`05000YMbUg:GL0
0003:GL00`00:GL000020003;GL01000;GL]M`000beg0P000c6G00D0036G<ILaU`0000<aU`03000a
U`0000<000@eU`05000eUcFG=IL00004=IH01P00>IHiUSVF000iUP@000<i]P03000m]Sff00<m]P03
000m]P0000<000<m]P03000m]Sff00<m]P030011]T6f0091]P030011]T6f0091]P030011]T6f00=1
]P030011]T6f0091]P030015eTGF00=5eP030015eTGF0095eP030015eTGF00=5eP030015eTGF0095
eP030019eTWF00=9eP030019eTWF00A9eP030019eDWE0099e@030019eDWE00=9e@030019mDWe00=9
m@03001=m@0000800003COD004ge00E=m@03001=mDge00==m@03001=mDge00==m@03001=mDge00A=
m@<000=Am@03001AmE7e00AAm@03001B5E8E00AB5@03001B5E8E009B5@8000IB5@03001F5EHE00AF
5@03001F5EHE009F5@03001F5@0000MF5@03001F5EHE00AF5@8000EF5@03001J=EXe00EJ=@8000AJ
=@03001J=EXe00EJ=@8000EJ=@03001J=EXe00EJ=@03001N=Ehe00EN=@05001NEEiEGUD00003GUD0
0`00GUENE@05GUD00`00GUENE@05GUD01000GUENE@001EiE00<0069EHUD00V9E00@0069EHUD000IR
M@8000QRM@03001RMF9e00IRM@03001VMFIe00EVM@03001VUFJE00IVU@03001VUFJE00EVU@03001V
U@0000EVU@04001VUFJE0004IYD01@00J[EZ]FZe00000fZf00<006ZeJ[D00VZe00<006Zf00001VZf
00<006Zf000016Zf00L006[FJ]IZeP00J]H00006K]H00`00K]H00003K]H00`00K]I^eP03K]H00`00
K_I^mP03K_H01`00K_I^mVkf001^mP0000A^mP07001bmW;fL_H007;f000017<F00<007<FLaH00W<F
00<007<FLaH00W<F00<007<FLaH00W<F00D007<F001c5`0000Ac=`03001g=gLg009g=`05001g=gLg
McL00004McL01@00MeMgEgMG00000gMG00D007MGMeMgE`0000AgE`800005MgL007MgMgL00003MgL0
1@00NgMkMg]g00000W^G00D007^HNiQkV000009kV004001kV7^H0002NiP00`00NkQk^00300001g^h
001k^7^h001k^000009k^003001kf00000=gf005001gf7OH001gf004000017OH001gf0000WOi00T0
07Oi001gn@00MoT007?i00000W?i00<006oi00000VOh00<005KmE_d00`0000=Fo@00E_d01EKm00<0
05Km00000P0000=Fo@00E_d01EKm10000UKm00<005KmE_d015Km0P001EKm00<005KmE_d00eKm0P00
1UKm00@005KmE_eFo@@000EFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@0000800003E_d0
05Km00EFo@800003Ool007oo04]oo`007goo200077oo20002Goo2P003goo00<007ooOol00P00UWoo
00<005KmE_d00eKm00<005Km00000P000UKm00<005KmE_d00eKm10000eKm00<005KmE_d00eKm0`00
1EKm00@005KmE_eFo@@000EFo@03000=o0gl00<000050AP000Di0009>@0300001`eI0000015I000=
>000008AF004000A>14h00025EP010005EPEF0000QEH00@001EH5EP000<IF003000IF00000<MF003
000MF1eH008000038EP0025H008QF003000QF0000080008UM`04000UMbEg9GL20002:GL01@00:GLY
MbUg00000RUg0P000beg00@002eg;GL000<]M`80008aU`05000aUc6G<IL00003<IL00`00<ILaU`02
<IL20003=IL00`00=ILeU`02=IL01@00=IHeUSFF00000cVF00<003VF>IH00SVF100000<i]P00?KH0
0Sff0`000cff00<003ff?KH00Sff00<003ff?KH00Sff00<0046f@KH00T6f00<0046f@KH00T6f00<0
046f@KH00d6f00<0046f@KH00T6f00<004GFAMH00dGF00<004GFAMH00TGF00<004GFAMH00dGF00<0
04GFAMH00TGF00<004WFBMH014WF00<004WFBMH00dWF00<004WEBMD00TWE00<004WEBMD00dWE00<0
04WeBOD00TWe0`0014ge00<004geCOD014ge00<004geCOD014ge00<004geCOD00Tge00<004geCOD0
0dge0P001U7e00<0057eDOD0157e00<0058EDQD00e8E00L0058EDQEB5@00DQD00006DQD00`00EQEF
5@04EQD00`00EQEF5@020002EQD00`00EQEF5@05EQD00`00EQEF5@03EQD20006EQD00`00FSEJ=@05
FSD00`00FSEJ=@04FSD00`00FSEJ=@04FSD00`00FSEJ=@05FSD00`00FSEJ=@03FSD00`00FSD00006
GSD01@00GUENEEiE00000eiE00<005iEGUD015iE0P001eiE00@005iEGUD000ENE@05001REF9EHUD0
0003HUD00`00HWERM@03HWD01000HWERM@001V9e0P00269e00<006IeIWD01FIe00<006JEIYD01FJE
00<006JE00001FJE00@006JEIYD000EVU@04001VUFJE0003IYD00`00J[EZ]@03J[D00`00J[H00006
J[D00`00J[IZ]P04J[H01000J[IZ]P000fZf00<006[FJ]H00V[F00<006[F00001FkF00@006kFK]H0
00=^eP03001^eVkF00=^eP03001^mVkf009^mP03001^mVkf00=^mP03001^mVkf00=^mP03001bmW;f
009bmP03001c5W<F009c5P03001c5W<F00=c5P03001c5W<F009c5P05001c5W<FLaH00002LaH00`00
LaL00004LcL00`00McMg=`02McL01@00McMg=gLg00000gLg00<007MGMeL00WMG00@007MGMeL000=g
E`03001gEgMG009gE`04001gMgMg0003MgL01@00MgMgMgMg00000W]g00@007^GNiMkU`800005NiP0
07^HNiP00003NiP01000NiQkV0000W^h0P0000Ek^000001k^000009k^003001k^000009kf004001g
f7OH0002MmP01`00MmQgf000MmP007OH00@00008MoT007Oi001gn@00MoT0009cn@05001cn@00KoT0
0003IoP30005E_d01000E_eFoEKm10001EKm00<005KmE_d00`0000=Fo@00E_d015Km00<005KmE_d0
0`0000=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d01EKm10000UKm00<005KmE_d015Km0P00
1EKm00@005KmE_eFo@@000EFo@03001FoEKm00<00003E_d00000008004]oo`008Goo100087oo1000
2goo2P003goo0`00VGoo00@005KmE_eFo@@000EFo@03001Fo@00008000=Fo@03001FoEKm009Fo@03
001Fo@00008000=Fo@03001FoEKm009Fo@@000AFo@03001FoEKm009Fo@@000041CT000000AP30002
2CT010003ET000di0`0000D=>000000AF000008A>003000EF00000<EF003000EF00000<EF0800004
6EP001UH6EP200027EP01`007EP001eH000QF00000<QF004000QF25H00029GL02@009GLUMbEg000U
M`00:GL00003:GL01000:GLYMbUg0P000Reg00@002eg;GL000<]M`03000]M`00008000@aU`05000a
Uc6G<IL00003<IL01P00=IL00000=IL000@eU`05000eUSFF=IH00004>IH01@00>IHiUSVF00000cVF
1@0000<m]P00?KH00cff00<003ff?KH00Sff00<003ff?KH00cff00D0046f@KI1]P0000A1]P030011
]T6f00=1]P030011]T6f0091]P030015eTGF00=5eP030015eTGF0095eP030015eTGF00=5eP030015
eTGF00=5eP030019eTWF00=9eP030019eTWF00=9eP030019eDWE0099e@030019eDWE00A9e@@00003
BOD004ge00E=m@03001=mDge00==m@03001=mDge00A=m@03001=mDge009=m@04001=mDgeCOD20000
0dge001Am@05DOD00`00DOEAm@04DOD00`00DQEB5@03DQD01000DQEB5@000e8E00<0058EDQD0158E
00<005HEEQD015HE0P001EHE00<005HEEQD015HE00<005HEEQD00UHE00<005HE00001eHE00<005Xe
FSD015Xe00<005XeFSD015Xe00<005XeFSD015Xe00<005XeFSD01EXe00<005XeFSD00UXe00@005Xe
FSD000IN=@04001NEEiE0005GUD00`00GUENE@02GUD01000GUENE@001eiE0P001UiE00@0069EHUD0
00ERE@03001RMF9e009RM@04001RMF9e0005HWD01000HWERM@001V9e00<0069e00001FIe00<006Ie
00001VJE00<006JE00001FJE00@006JEIYD000AVU@03001VUFJE009VU@04001VUFJE0005J[D00`00
J[H00006J[D00`00J[IZ]P04J[H01@00J[IZ]VZf00000VZf00<006[FJ]H00f[F00<006kFK]H016kF
00L006kFK]I^eP00K]H00005K]H00`00K]H00003K_H00`00K_I^mP03K_H00`00K_I^mP02K_H00`00
L_IbmP03L_H00`00LaIc5P02LaH00`00LaIc5P02LaH00`00LaH00002LaH00`00LaIc5P02LaH01@00
LaIc5W<F000017<g00<007LgMcL00WLg00D007Lg001g=`0000=g=`03001gEgMG009gE`05001gE`00
MeL00003MeL01@00MeMgEgMG00000gMg0P0000=gM`00MgL00WMg00@007]gNgL000=kU`04001kUg^G
0003NiP01000NiQkV0000W^H00T007^hNkP007^h001k^000NkP00P0000Mk^000NkQk^000NmP00003
MmP00`00MmP00002MmP00`00MmP00002MmP01000MoP007Oh200000Mcn@00LoT006oi001Wn0030002
E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@02E_d30005E_d01000
E_eFoEKm10001EKm00<005KmE_d00`0000=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d015Km
10000eKm00<005KmE_d00eKm0`001EKm00<007oo0000Bgoo001]Ool00`00Oomoo`2JOol30004E_d0
0`00E_eFo@02E_d30006E_d00`00E_eFo@040006E_d01000E_d000000UKm00<005KmE_d015Km00L0
05Km000005Km0009600200001@Di000160001CP00P000PTi00<000eI00000Pdi00@000dh000=>080
008A>08000045EP001EH5EP2000031EH000EF1EH000EF0006EP001UH000IF0<0008MF004000MF000
00038EP01@008EPQF25H00000REg00H002Eg9GLUM`009GL20003:GL01P00:GLYMbUg000YM`<0008]
M`05000]Mbeg;GL00003;GL20003<IL01@00<ILaUc6G00000c6G00@003FG=ILeU`<000<eU`03000e
USFF008eUP05000iUSVF>IH00003>IH01000>IHiUSVF0P000Sff10000cff00<003ff?KH00Sff00<0
03ff?KH00cff00<0046f@KH00T6f00<0046f@KH00T6f00<0046f@KH00T6f00<0046f@KH00T6f00<0
04GFAMH00dGF00<004GFAMH00dGF00<004GFAMH00dGF00<004GFAMH00TGF00<004WFBMH00dWF00<0
04WFBMH00dWF00<004WEBMD00dWE00<004WEBMD0100014We00<004geCOD014ge00<004geCOD00dge
00<004geCOD014ge00<004geCOD00dge0`000dge00<0057eDOD0157e00<0057eDOD0157e00<0058E
DQD0158E0P00158E00<0058EDQD0158E00<005HEEQD00eHE0P001UHE00<005HEEQD015HE00D005HE
EQEF5@00009F5@03001F5EHE00EF5@03001J=EXe00=J=@8000IJ=@03001J=EXe00=J=@03001J=@00
00IJ=@05001J=EXeFSD00003FSD00`00GSEN=@05GSD20006GUD01@00GUENEEiE00000eiE00<005iE
GUD01EiE00<005iEGUD01EiE00@0069EHUD000ERE@05001RMF9eHWD00003HWD00`00HWERM@03HWD0
1000HWERM@001F9e00@0069eHWD000EVM@03001VM@0000EVU@04001VUFJE0004IYD00`00IYEVU@02
IYD01@00IYEVUFJE000016JE00<006JE00001fZe00<006ZeJ[D016Ze00<006Ze000016Zf00<006Zf
J[H00VZf00<006Zf00001V[F00<006kFK]H00fkF00<006kFK]H00VkF00<006kF000016kF00L006kF
K]I^eP00K_H00005K_H00`00K_H00003K_H00`00L_IbmP02L_H00`00L_H00002LaH00`00LaIc5P03
LaH01P00LaIc5P00LaH000=c5P03001c5W<F009c5P03001c=g<g009c=`03001g=gLg009g=`04001g
=gLg0004McL00`00MeMgE`02MeL00`00MeMgE`020002MeL00`00MeMgE`02MeL01000MgMgM`000WMg
0P000gMg00@007]gNgL000=kU`03001kUg^G00800003NiP007^H009kV003001kV000009k^005001k
^7^hNkP00002NkP01P00NkP00000NkP0009kf006001gf7OH001gf0000WOH00<007OH00000WOH00<0
07Oh00000WOh00P007Oh001gn000MoP007?i1`001UKm00<005Km00000P0000=Fo@00E_d01EKm00<0
05Km00000P0000=Fo@00E_d01EKm00<005Km00000P000UKm00<005KmE_d00eKm10000eKm00<005Km
E_d00eKm0`001EKm00@005KmE_eFo@@000EFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@00
00800003E_d005Km00EFo@04001oogoo001:Ool006aoo`03001oogoo09eoo`03001FoEKm00=Fo@04
001Fo@000003E_d00`00E_eFo@03E_d30004E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d2
0004E_d02P002AP000001CT0004H0005>0000PTi0`000`di00<000dh00000Pdh00<0014h4CP00`00
0aEH0`000aEH00@001EH0000008IF004000IF1UH00027EP010007EPMF0000b5H00@0025H8EPQF080
00039GL002Eg008UM`03000UMbEg008000<YM`05000YMbUg:GL00002:GL20002;GL01@00;GL]Mbeg
00000beg0P000S6G00D0036G<ILaU`0000@aU`03000eUcFG008eU`80008eU`03000eUSFF008eUP05
000iUSVF>IH00004>IH300000cVF000m]P04?KH400000cff000m]P02?KH00`00?KHm]P03?KH00`00
@KI1]P02@KH00`00@KI1]P02@KH00`00@KI1]P03@KH00`00@KI1]P02@KH00`00AMI5eP03AMH00`00
AMI5eP02AMH00`00AMI5eP03AMH00`00AMI5eP02AMH00`00BMI9eP03BMH00`00BMI9eP03BMH00`00
BME9e@02BMD40003BMD00`00BOE9m@03BOD00`00COE=m@03COD00`00COE=m@04COD00`00COE=m@03
COD00`00COE=m@02COD20006COD00`00DOEAm@03DOD00`00DOEAm@04DOD00`00DQEB5@03DQD20005
DQD00`00DQEB5@04DQD00`00EQEF5@02EQD00`00EQD00006EQD00`00EQEF5@04EQD01000EQEF5@00
15HE00<005HEEQD015HE00<005XeFSD00UXe00@005XeFSD000IJ=@05001J=EXeFSD00002FSD00`00
FSEJ=@04FSD01000FSEJ=@001EXe00<005heGSD015he00<005iEGUD01EiE00D005iEGUENE@0000=N
E@03001NEEiE00ENE@03001NEEiE00INE@8000IRE@04001RMF9e0005HWD01@00HWERMF9e00000f9e
00<0069eHWD00f9e00@0069eHWD000AVM@05001VMFIeIWD00004IYD01@00IYEVUFJE00000fJE00<0
06JEIYD00VJE00@006JEIYD000EVU@03001VU@0000MZ]@03001Z]FZe00AZ]@03001Z]@0000AZ]P03
001Z]VZf009Z]P03001Z]P0000EZeP03001^eP0000A^eP03001^eVkF00=^eP03001^eVkF00=^eP07
001^eVkFK]H006kf00001Fkf00H006kfK_H006kf0005L_H01P00L_IbmP00LaH000Ac5P03001c5W<F
009c5P03001c5W<F009c5P07001c5W<FLaH007Lf00000W<g00<007LgMcL00WLg00@007LgMcMg=`80
009g=`03001gEgMG009gE`09001gEgMGMeL007MG001gE`0000=gE`05001gMgMgMgL00002MgL01@00
NgL007Mg00000W]g00D007^GNiMkU`00009kU`03001kUg^G00<00005NiP007^HNiP00002NkP01@00
NkQk^000NkP00P000W^h00H007^h000007_H0003MmP01`00MmP007OH001gf000009gf003001gn000
009gn007001gn000MoP007Oh00000W?i00@007?i001_n0<000IFo@8000EFo@03001FoEKm00=Fo@80
00EFo@04001FoEKmE_d40006E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d0000200000eKm
001Fo@05E_d40002E_d00`00E_eFo@04E_d20005E_d00`00E_eFo@03E_d20005E_d01000E_eFoEKm
100000=oo`00Ool0BGoo001/Ool00`00Oomoo`2NOol01000E_eFoEKm0`001UKm00<005Km00000P00
00=Fo@00E_d01EKm00<005Km00000P000UKm00<005KmE_d00eKm00<005Km00000P000UKm00D005Km
E_eFo@00008960030005>@0000800085>0030009>@Ti00<0008=>@<000<=>0<000034CP001EH008E
F003000E>00000<EF004000EF1EH00026EP01`006EPIF1UH000MF00000<MF080008QF004000QF25H
8EP300039GL010009GLUMbEg0P000RUg00D002Ug:GLYM`0000<YM`800003;GL002eg008]M`06000]
Mbeg;GL0035g10000c6G00D0036G<ILaU`0000@eU`03000eUP0000<000<eUP03000iUSVF008iUPD0
00@iUP03000m]Sff008m]P04000m]Sff?KH500000cff000m]P03?KH00`00@KI1]P02@KH00`00@KI1
]P02@KH00`00@KI1]P03@KH00`00@KI1]P02@KH00`00AMI5eP03AMH00`00AMI5eP02AMH00`00AMI5
eP03AMH00`00AMI5eP02AMH00`00BMI9eP03BMH00`00BMI9eP04BMH400000dWE0019e@04BMD00`00
BOE9m@03BOD00`00COE=m@03COD00`00COE=m@04COD00`00COE=m@03COD00`00COE=m@0200000dge
001=m@05COD00`00DOEAm@04DOD00`00DOEAm@03DOD01000DQEB5E8E0P0000=Am@00DQD0158E00<0
058EDQD0158E00D005HEEQEF5@00009F5@03001F5EHE00AF5@03001F5EHE00EF5@8000EF5@03001F
5EHE00AF5@05001J=EXeFSD00003FSD00`00FSEJ=@04FSD01000FSEJ=@000eXe00<005XeFSD01EXe
0P001UXe00<005heGSD015he00<005iEGUD01EiE00@005iEGUD000ANE@03001NEEiE00ANE@8000QN
E@03001REF9E00ERE@04001RMF9e0005HWD01000HWERM@001F9e00D0069eHWERM@0000ARM@04001V
MFIe0004IWD01@00IYEVUFJE000016JE00@006JEIYD000EVU@03001VU@0000MVU@03001Z]FZe00EZ
]@03001Z]@0000AZ]@05001Z]FZeJ[D00002J[H00`00J[IZ]P04J[H00`00J]IZeP04J]H00`00K]H0
0003K]H00`00K]I^eP04K]H00`00K]I^eP02K]H00`00K]I^eP03K]H00`00K_I^mP03K_H01`00K_I^
mVkf001^mP0000AbmP03001bmW;f009bmP03001c5W<F00=c5P03001c5W<F009c5P05001c5W<FLaH0
0004LaH01P00McIg=P00LcL000Ag=`04001g=gLg0002McL00`00McL00003MeL01@00MeMgEgMG0000
0gMG00D007MGMeMgE`0000=gM`04001gMgMg0003NgL01@00NgMkMg]g00000W^G00D007^GNiMkU`00
009kU`04001kUg^G0002NiP01000NkQk^0000g^h00H007^h000007^h0002NkP00`00NmP000020000
17OH001gf0000WOH00L007OH001gf000MoP00002MoP01`00MoP007Oh001gn000009cn@04001cn@00
KoP20002HmD00`00E_eFo@0300000eKm001Fo@04E_d00`00E_eFo@0300000eKm001Fo@04E_d40003
E_d00`00E_eFo@04E_d20005E_d01000E_eFoEKm10001EKm00<005KmE_d00`0000=Fo@00E_d015Km
00<005KmE_d00`0000=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d015Km10000eKm00@007oo
Ool004Uoo`00K7oo00<007ooOol0Wgoo0`000eKm00<005KmE_d00eKm0P001EKm00<005KmE_d00eKm
0P001UKm00@005KmE_eFo@<000IFo@05001FoEKmE_d000022AP500021CP300000`Ti000=>@023CT3
00023CP01@003CP000004CP00P000QEH00@001Dh0000008EF003000EF1EH008000046EP001UH6EP2
00001QeH000MF1eH000MF0<000<QF004000QE`0000039GL01@009GLUM`009GL00`000bUg00H002Ug
:GLYM`00:GL20003;GL01@00;GL]Mbeg0000135g0P000S6G00D0036G<ILaU`0000@eU`03000eUSFF
008eUP80008eUP03000iUSVF00<000<iUP03000iUSVF008iUP03000m]Sff008m]P03000m]Sff008m
]P04000m]Sff?KH50002?KH01@00@KI1]T6f0000146f00<0046f@KH00d6f00<0046f@KH00T6f00<0
04GFAMH00dGF00<004GFAMH00TGF00<004GFAMH00dGF00<004GFAMH00TGF00<004WFBMH014WF00<0
04WFBMH0100014WE00<004WEBMD014WE00<004WeBOD00TWe00<004geCOD014ge00<004geCOD00dge
00<004geCOD014ge0P000dge00<004geCOD014ge00<0057eDOD0157e00<0057eDOD0157e0`000e7e
00<0058EDQD00e8E00<0058EDQD0158E00@005HEEQD000AF5@03001F5EHE00AF5@03001F5EHE00=F
5@8000IF5@03001F5EHE00AF5@04001J=EXe0004FSD00`00FSEJ=@04FSD01000FSEJ=@0015Xe00<0
05XeFSD015Xe00<005XeFSD01EXe00<005heGSD00ehe00<005he00001eiE0P001UiE00<005iEGUD0
0UiE00@005iEGUD000MNE@03001REF9E00IRE@8000IRM@04001RMF9e0005HWD01000HWERM@001F9e
00@006IeIWD000AVM@05001VUFJEIYD00004IYD00`00IYD00007IYD20007IYD00`00J[EZ]@05J[D0
0`00J[D00004J[D01`00J[EZ]FZe001Z]P0000MZ]P03001ZeV[F00=ZeP07001^eVkFK]H006kF0000
1VkF00<006kF00000fkF00<006kFK]H00fkF00<006kfK_H00fkf00<006kfK_H00Vkf00<007;fL_H0
0g;f00<007;fL_H00W;f00<007<FLaH00W<F00<007<FLaH00W<F00D007<F001c5P0000Ac5P03001g
=WLf009g=P03001g=gLg009g=`05001g=gLgMcL00003McL00`00MeMgE`02MeL01@00MeMgEgMG0000
0gMG00D007MGMeMgE`00009gM`05001gMgMgMgL00003NgL200000g]g001kU`02NiL01000NiMkU`00
0W^G00@007^GNiMkU`800005NiP007^hNkP00002NkP00`00NkQk^0030002NkP01000NmQkf0000W_H
100000Agf000MmP0009gf00;001gn000MoP007Oh001gn000MoP00002LoT01000LoT006oh0P000V?E
10001EKm00@005KmE_eFo@@000EFo@03001Fo@000080009Fo@03001FoEKm00=Fo@03001FoEKm00<0
0003E_d005Km00AFo@@000=Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm009Fo@<000EFo@04001F
oEKmE_d40005E_d00`00E_d0000200000eKm001Fo@05E_d01000Oomoo`00B7oo001/Ool00`00Oomo
o`2OOol00`00E_eFo@04E_d00`00E_d000020002E_d00`00E_eFo@03E_d00`00E_d000020002E_d0
0`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d500022AP00`001CP0000200021CP01@001CP00000
2CT00P0000@=>@003CP000<=>006000=>0004CP0014h0`0000<E>0005CP00`000QEH00@001UH0000
00<IF0<000<MF004000MF1eH00038EP00`008ELQE`0200029GL01@009GLUMbEg00000REg0P000bUg
00H002Ug:GLYM`00:GL20003;GL01@00;GL]Mbeg00000c5g00<0035g00000P00136G00<003FG=IL0
0SFG00H003FF=IHeUP00=IH50002>IH00`00>IHiUP02>IH01@00>IHiUSVF00001Cff00D003ff?KHm
]P0000@m]P04000m]Sff?KH600000d6f0011]P03@KH00`00@KI1]P02@KH00`00@KI1]P02@KH00`00
AMI5eP03AMH00`00AMI5eP02AMH00`00AMI5eP04AMH00`00AMI5eP02AMH00`00BMI9eP060003BMD0
0`00BME9e@03BMD00`00BME9e@03BMD00`00BOE9m@02BOD00`00COE=m@04COD00`00COE=m@03COD0
0`00COE=m@03COD20005COD00`00COE=m@03COD00`00DOEAm@04DOD00`00DOEAm@03DOD20006DOD0
0`00DQEB5@03DQD00`00DQEB5@04DQD20005EQD00`00EQEF5@04EQD00`00EQEF5@02EQD00`00EQD0
0006EQD00`00EQEF5@05EQD20005FSD00`00FSEJ=@05FSD20005FSD00`00FSEJ=@04FSD00`00FSEJ
=@06FSD01@00GSEN=Ehe00000Uhe00<005iEGUD01EiE00<005iEGUD01EiE00D005iEGUENE@0000=N
E@03001NEEiE00ANE@8000QRE@03001RMF9e00IRM@8000IRM@04001RMF9e0005HWD00`00IWD00006
IWD00`00IYD00006IYD20007IYD00`00IYEVU@05IYD00`00JYD00005J[D01000J[EZ]@000fZe00<0
06ZeJ[D00VZe00<006Zf00001VZf00<006Zf000016[F00L006kFK]I^eP00K]H00005K]H01000K]I^
eP000VkF00<006kFK]H00fkF00<006kf00000fkf00<006kfK_H00fkf00<007;fL_H00W;f00<007;f
L_H00W;f00<007<F00000g<F00D007<FLaIc5P00009c5P03001c5P0000Ac5P03001g=WLf009g=P03
001g=gLg009g=`04001g=gLg0004McL20002MeL01@00MeMgEgMG00000gMG00D007MG001gE`0000=g
M`04001gMgMg0003NgL00`00NgMkM`020002NiL01000NiMkU`000W^G00D007^GNiMkU`00009k^080
0003NkP007^h009k^003001k^000009k^003001k^000009kf008001kf7_HNmP007OH001gf0@00006
MmP007Oh001gn0000WOh00X007Oh001gn000LoT007?i001_n0D0009Fo@03001FoEKm00AFo@@000=F
o@03001FoEKm00=Fo@8000IFo@04001FoEKmE_d40005E_d00`00E_d0000200000eKm001Fo@05E_d0
0`00E_d0000200000eKm001Fo@05E_d00`00E_d0000200000eKm001Fo@05E_d40002E_d00`00E_eF
o@04E_d20005E_d00`00E_eFo@03E_d200000goo001oo`17Ool006aoo`03001oogoo0:1oo`03001F
oEKm00=Fo@8000IFo@04001FoEKmE_d30006E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d0
00020002E_d00`006Qd0000200001@TH0005>0000AP00P0000L5>0001CP000Ti0009>00300001@dh
000000dh00000Pdh0`000Q4h00@001Dh5CP0008E>007000EF1EH5EP001UH00000aUH00<001UH0000
0aeH00@001eH7EPMF080008QF004000QE`008EL300039GL010009GLUMbEg0P000RUg00D002Ug:GLY
M`00008YM`80008]M`05000]Mbeg;GL00003<GL01000<GLaMc5g0P000c6G00<003FG=IL00SFG00@0
03FF=IHeUP@00003=IH00000008iUP03000iUSVF008iUP03000iUSVF008iUP03000m]Sff008m]P03
000m]Sff008m]P05000m]Sff?KH00005?KH01000@KI1]T6f2P000T6f00<0046f@KH00T6f00<004GF
AMH00dGF00<004GFAMH00TGF00<004GFAMH02`000dWE00<004WEBMD00dWE00<004WEBMD00dWE00<0
04WEBMD00dWE00<004WeBOD00dWe00<004geCOD00dge00<004geCOD00dge00@004geCOE=m@800003
COD004ge00A=m@03001=mDge00A=m@03001AmE7e00=Am@03001AmE7e009Am@03001Am@0000IAm@03
001B5E8E00=B5@03001B5E8E00=B5@8000IF5@03001F5EHE00AF5@05001F5EHEEQD00002EQD00`00
EQEF5@05EQD00`00EQEF5@04EQD00`00FSEJ=@05FSD00`00FSEJ=@04FSD00`00FSEJ=@04FSD00`00
FSEJ=@03FSD20008FSD01000GSEN=@000ehe00<005iEGUD01EiE00<005iEGUD01EiE00D005iEGUEN
E@0000=NE@03001NEEiE00=NE@04001REF9E0007HUD00`00HWERM@06HWD00`00HWERM@06HWD20007
HWD20006IWD00`00IYD00006IYD00`00IYEVU@06IYD00`00IYEVU@05IYD00`00JYD00005J[D01@00
J[EZ]FZe00000VZe00<006ZeJ[D00fZe00<006ZfJ[H016Zf00@006ZfJ[H000=ZeP03001^eVkF00=^
eP03001^eVkF00A^eP06001^eVkF001^eP001VkF00<006kf00000fkf00<006kfK_H00Vkf00<007;f
00000g;f00<007;fL_H00W;f00H007<FLaH007<F0004LaH01@00LaIc5W<F000017<F00<007LfMcH0
0WLf00<007Lf00000WLg00D007LgMcMg=`0000=g=`06001gEgMG001gE`000WMG00<007MGMeL00WMG
00<007MGMeL00P000WMg00@007MgMgL000AkM`08001kMg]g001kU`00NiL0009kU`04001kUg^G0003
NiL01@00NkQk^000NkP00`0000Qk^000NkQk^000NkP007^h0P0000=kf000NmP00W_H00<007OH0000
0WOH00@007OH001gf0H0000;MoP007Oh001gn000LoT007?i001_n00200000g?h001Fo@04E_d00`00
E_eFo@0300000eKm001Fo@05E_d00`00E_d0000200000eKm001Fo@05E_d40002E_d00`00E_eFo@04
E_d20005E_d00`00E_eFo@03E_d20005E_d01000E_eFoEKm10001EKm00<005KmE_d00`0000=Fo@00
E_d015Km00<005KmE_d00`0000=Fo@00E_d01EKm00<005Km00000P0000EFo@00Oomoo`0004Moo`00
K7oo00<007ooOol0XGoo00<005Km00000P000UKm00<005KmE_d00eKm10000eKm00<005KmE_d00eKm
0P001EKm00<005KmE_d00eKm0P001UKm00@001XM0005FP<000041CP000000AP3000010Dh00000000
0PTh00@000dh000=>0<000033CP000dh0080008A>0<000<E>08000045EP001UH6EP2000011UH000I
F1UH0P000QeH00D001eH7EP001eG00<0008QE`03000QEb5G0080008UM`06000UMbEg9GL002Ug0`00
0bUg00D002Ug:GL002eg00<000<]M`03000aMc5g008aM`04000aMc5g<GL20002<IL00`00=ILeU`02
=IL00`00=IH000030003=IH00`00=IH000030003>IH00`00>IHiUP02>IH00`00?KHm]P02?KH00`00
?KHm]P02?KH00`00?KHm]P02?KH00`00?KHm]P02?KH00`00@KI1]P02@KH00`00@KI1]P02@KH01000
@KI1]T6f5@000dGF00<004GEAMD00TGE00<004WEBMD00dWE00<004WEBMD014WE00<004WEBMD00TWE
00<004WEBMD00dWE00<004WeBOD00dWe00<004geCOD00dge00<004geCOD014ge0`000dge00<004ge
COD00dge00<004geCOD014ge00<0057eDOD00e7e00<0057eDOD00P000U7e00<0057eDOD0157e00<0
058EDQD00e8E00<0058EDQD00U8E00<0058E00001UHE00<005HEEQD015HE00@005HEEQD000AF5@03
001F5EHE00AF5@03001F5EHE00=F5@8000MJ=@03001J=EXe00=J=@8000MJ=@05001J=EXeFSD00002
FSD00`00FSEJ=@05FSD01000GSEN=@0015he00<005iEGUD00eiE00<005iE00001UiE00@005iEGUD0
00ENE@03001NEEiE009NE@04001REF9E0006HUD20008HWD00`00HWERM@06HWD00`00HWERM@06HWD0
0`00IWEVM@06IWD00`00IYEVU@05IYD00`00IYEVU@05IYD00`00IYD00005IYD01000JYEZU@0016Ze
00<006ZeJ[D00VZe00<006Ze00001VZe00<006ZfJ[H016Zf00D006ZfJ[IZ]P00009ZeP03001^eVkF
00=^eP03001^eVkF00=^eP03001^eVkF009^eP8000E^eP07001^mVkfK_H006kf000016kf00L007;f
L_IbmP00L_H00004L_H01`00LaIc5W<F001c5P0000=c5P03001c5W<F009c5P03001c5W<F009c5P03
001g=WLf009g=P06001g=WLf001g=`000WLg00<007LgMcL00WLg00D007MGMeMgE`0000=gE`05001g
EgMGMeL00003MeL01@00MgL007Mg00000WMg00D007]gNgMkM`00009kM`05001kUg^GNiL00002NiL0
1000NiMkU`000g^G00@007^hNkP0009k^003001k^7^h00800006NkP007^hNkP007^h0`000g_H00<0
07OH00000WOH00<007OH00000WOH00H007Oh001gn000MoP;00001Foh000007OH000015Km0`001EKm
00@005KmE_eFo@@000EFo@03001FoEKm00<00003E_d005Km00AFo@03001FoEKm00<00003E_d005Km
00AFo@03001FoEKm00<00003E_d005Km00AFo@@000=Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm
009Fo@<000EFo@04001FoEKmE_d40005E_d00`00Ool00017Ool006]oo`03001oogoo0:=oo`8000EF
o@03001Fo@000080009Fo@03001FoEKm00=Fo@03001Fo@000080009Fo@03001FoEKm00=Fo@03001F
o@000080009Fo@03001FoEKm00=Fo@@00085FP030005>0000080008160040005>0001CP200022CP0
0`003CP000023CP01P003CP=>0003CP0008A>004000A>00000025CP03P005CP001EH000IF0006CP0
01UH000IF0007EP300037EP010007ELME`000R5G00@0025G8ELQE`80008UM`05000UMbEg9GL00002
:GL20003:GL01000:GLYM`000Reg0P000beg00D0035g<GLaM`0000<aM`03000aM`00008000<eU`<0
00<eUP05000eUSFF=IH00004=IH20002>IH00`00>IHiUP02>IH00`00?KHm]P03?KH01@00?KHm]Sff
000013ff00<003ff?KH00cff00D0046f@KI1]P0000A1]P030011]T6f00=1]P030011]T6f0091]P03
0015]TFf00=5]P030015eTGF0095eP030015eTGF00=5eP030015eDGE0095e@030019eDWE00A9e@03
0019eDWE00=9e@030019eDWE0099e@030019eDWE00A9e@030019mDWe0099m@03001=mDge00==m@03
001=mDge00==m@8000I=m@03001=mDge009=m@03001=mDge00A=m@03001AmE7e00AAm@8000EAm@03
001AmE7e00=Am@03001B5E8E00=B5@05001B5E8EDQD00002DQD00`00EQEF5@04EQD00`00EQEF5@05
EQD20005EQD00`00EQEF5@04EQD00`00EQEF5@02EQD00`00EQD00007FSD00`00FSEJ=@02FSD00`00
FSD00007FSD01000FSEJ=@000eXe00<005XeFSD01UXe0P001Ehe00<005iEGUD00UiE00@005iEGUD0
00MNE@8000INE@05001NEEiEGUD00003HUD00`00HUERE@03HUD01000HWERM@001V9e0P00269e00<0
069eHWD01V9e00<006IeIWD01VIe00<006JEIYD016JE00<006JE00001VJE00<006JE00001FJE00D0
06ZEJYEZU@00009Z]@03001Z]FZe00=Z]@03001Z]@0000EZ]@03001Z]@0000AZ]P03001Z]VZf009Z
]P03001ZeP0000E^eP03001^eP0000A^eP03001^eVkF009^eP03001^eVkF00A^eP07001^mVkfK_H0
06kf000016kf00L007;fL_IbmP00L_H00004L_H00`00LaIc5P02LaH00`00LaIc5P02LaH01`00LaIc
5W<F001c5P00009c5P03001g=WLf009g=P03001g=WLf009g=P05001g=gLgMcL00003McL00`00MeMg
E`02MeL01000MeMgE`0017MG00@007MGMeL000=gM`04001gMgMg0003NgL01@00NgMkMg]g00000g^G
0P0000EkU`00NiMkU`00009kU`04001k^7^h0002NkP01P00NkQk^7^h001k^0800004NkP007^hNkP3
0002NmP02000MmQgf000MmP007OH0002MmP01@00MoP007Oh00000WOh00X007Oh001cn000LoP007?h
001cn0<0009gf003001Fo@000080009Fo@03001FoEKm00=Fo@@000=Fo@03001FoEKm00=Fo@<000EF
o@03001FoEKm009Fo@<000EFo@04001FoEKmE_d40005E_d00`00E_d0000200000eKm001Fo@05E_d0
0`00E_d000020002E_d00`00E_eFo@03E_d00`00E_d000020002E_d00`00E_eFo@03E_d40003E_d0
0`00E_eFo@03E_d200000goo001oo`15Ool006]oo`03001oogoo0:Eoo`03001FoEKm009Fo@<000EF
o@04001FoEKmE_d40005E_d01000E_eFoEKm10001EKm00<005Km00000P000eKm0P000PEJ00<000Dh
00000P000P4H00D000Dh0005>0000089>0<000<=>003000=>000008=>005000A>14h000A>0020002
5CP010005CP000000QUH00@001Th0000008IF004000MF1eH00037EP01`007ELMEaeG000QE`0000<Q
E`03000UE`00008000<UM`04000YMbUg:GL20002:GL01000:GLYM`000beg0P000Reg00D0035g<GLa
M`0000<aM`04000aMc5g<GL40002=IL01@00=IHeUSFF000013FF00H003FF=IHeUP00>IH40003>IH0
0`00?KHm]P03?KH00`00?KHm]P02?KH01@00?KHm]Sff00001Cff00<0046f@KH00T6f00<0046f@KH0
0T6f00<0046f@KH00T6f00<0046f@KH00T6f00<004FfAKH00dFf00<004GFAMH00TGF00<004GFAMH0
14GF00<004GEAMD00TGE00<004WEBMD00dWE00<004WEBMD00dWE00<004WEBMD00dWE00<004WEBMD0
0dWE00<004WeBOD00TWe00<004geCOD014ge00<004ge00000P0000==m@00COD01Dge00<004geCOD0
0Tge00<004geCOD014ge00<0057eDOD00e7e0P001U7e00<0057eDOD0157e00<0058EDQD00U8E00@0
058EDQD000AB5@03001F5EHE00AF5@03001F5EHE00AF5@03001F5EHE00AF5@03001F5EHE00AF5@05
001F5EHEEQD00003EQD00`00FSEJ=@04FSD01@00FSEJ=EXe00000eXe00<005XeFSD015Xe00@005Xe
FSD000=J=@03001J=EXe00IJ=@03001N=Ehe00AN=@03001NEEiE009NE@04001NEEiE0007GUD00`00
GUENE@05GUD01000GUENE@001F9E00<0069EHUD00V9E00@0069eHWD000ERM@04001RMF9e0006HWD2
0007HWD20007IWD00`00IYD00005IYD00`00IYD00005IYD01000IYEVU@0016JE00<006ZEJYD00VZE
00@006ZeJ[D000IZ]@03001Z]FZe00AZ]@03001Z]@0000AZ]P03001Z]VZf009Z]P03001ZeP0000E^
eP03001^eP0000=^eP03001^eVkF00=^eP03001^eVkF00=^eP03001^mVkf00=^mP03001^mVkf009^
mP03001bmW;f00=bmP03001bmW;f009bmP03001c5W<F00=c5P05001c5W<FLaH00004LaH01P00LaIc
5P00LaH000Ag=P03001g=WLf009g=P04001g=gLg0004McL02@00MeMgEgMG001gE`00MeL00003MeL0
1@00MeMgEgMG00000gMg0P0000=gM`00NgL00W]g00@007]gNgL000=kU`03001kUg^G00800003NiL0
07^G009kU`06001k^7^h001k^0000g^h00D007^hNkP007^h00800003NkP007_H00800009NmP007OH
MmP007OH001gf000009gf005001gn000MoP00002MoP02P00MoP007?h001cn000LoP007?h0P0000Ac
n000MmQgf08000IFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@0000800003E_d005Km00EF
o@03001Fo@0000800003E_d005Km00EFo@@0009Fo@03001FoEKm00AFo@8000EFo@04001FoEKmE_d4
0006E_d01000E_eFoEKm0`001UKm00<005Km00000P0000=Fo@00E_d01EKm00<005Km00000P0000EF
o@00Oomoo`0004Eoo`00Jgoo00<007ooOol0YWoo00@005Km000000=Fo@03001FoEKm009Fo@@000AF
o@03001FoEKm009Fo@@000AFo@03001FoEKm009Fo@<000IFo@8000061EX00000000160000P4H0`00
0PDh0P0000@9>0000000008=>08000073CP000dh3CP0014h00000Q4h00@001Dh5CP0008E>004000I
F1UH00026CP010006EPIF0000aeH0P0000<MF0007EL00QeG0P0000<QE`008EL00R5G00@002EG9EL0
00<UM`06000YMbUg:GL002Ug0`000RUg00H002eg;GL]M`00;GL30004<GL01P00<GLaMc5g000aM`D0
008eU`03000eUSFF008eUP05000eUSFF=IH00003=IH00`00>IHiUP02>IH400000cVF000m]P03?KH0
0`00?KHm]P02?KH01@00?KHm]Sff00001Cff00<0046f@KH00T6f00<0046f@KH00T6f00<0046f@KH0
0d6f00<0046f@KH00T6f00<004FfAKH00dFf00<004GFAMH00TGF00<004GFAMH00dGF00<004GEAMD0
0TGE00<004WEBMD00dWE00<004WEBMD00dWE00<004WEBMD00dWE00<004WEBMD00dWE00<004WeBOD0
0TWe00<004geCOD00dge0`0014ge00<004geCOD014ge00<004geCOD00dge00<004geCOD00dge00@0
057eDOEAm@800003DOD0057e00EAm@03001AmE7e00AAm@03001B5E8E00=B5@8000EB5@03001F5EHE
00AF5@03001F5EHE00=F5@8000IF5@03001F5EHE00AF5@04001F5EHE0004EQD00`00FSEJ=@04FSD0
1000FSEJ=@0015Xe00<005XeFSD01EXe0P001EXe00<005XeFSD01EXe00<005heGSD01Ehe00@005iE
GUD000ANE@03001NEEiE00ANE@03001NEEiE00ENE@04001NEEiE0005HUD01@00HUEREF9E00000f9e
00<0069eHWD00f9e00@0069eHWD000ERM@04001RMF9e0005HWD01000IWEVM@001FIe00@006JEIYD0
00AVU@05001VUFJEIYD00004IYD01@00IYEVUFJE00000VJE00<006ZEJYD00fZE00<006Ze00001fZe
00<006ZeJ[D00fZe00D006ZeJ[EZ]@00009Z]P03001Z]VZf00AZ]P03001^eVkF00=^eP07001^eVkF
K]H006kF00001FkF00<006kF00000fkF00<006kfK_H016kf00<006kfK_H00Vkf00<007;fL_H00g;f
00D007;fL_IbmP0000Ec5P05001c5P00LaH00004LaH00`00LaIc5P02LaH00`00McIg=P02McH00`00
McIg=P02McH01@00McL007Lg00000gLg00D007MGMeMgE`0000=gE`03001gEgMG009gE`04001gEgMG
0003MgL00`00NgMkM`020002NgL01000NgMkM`000g^G00H007^GNiMkU`00NiL20002NiL01000NkQk
^0000W^h00@007^hNkP0009k^005001k^7^h001kf00400000g_H001gf002MmP02`00MmP007OH001g
f000MoP007Oh00000WOh00X007Oh001cn000LoP007?h001cn0800007LoP007OHMmP006_j00001UKm
0P001EKm00<005KmE_d00eKm0P001EKm00@005KmE_eFo@@000EFo@03001FoEKm00<00003E_d005Km
00AFo@03001FoEKm00<00003E_d005Km00AFo@@000=Fo@03001FoEKm00AFo@@0009Fo@03001FoEKm
00AFo@8000EFo@04001FoEKmE_d40005E_d00`00Ool00015Ool006]oo`03001oo`0000800:Eoo`03
001FoEKm00AFo@04001Fo@000002E_d00`00E_eFo@04E_d01000E_d000000eKm00<005KmE_d00eKm
00@005Km000000=Fo@03001FoEKm00=Fo@L000040AP000000AP300000`Dh0005600200000`Th000=
>0023CP300023CP20000114h000A>14h0P0000LE>0005CPE>0006EP000036CP200002AUH000MF1eH
000ME`007EP000037EL300038EL010009ELUEbEG0P000REg00D002Ug:GLYM`00008YM`80008YM`05
000]Mbeg;GL00002;GL20003<GL00`00<GLaM`030002<GL00`00<IHaUP040003=IH01@00=IHeUSFF
000013FF00D003VF>IHiUP0000<iUP@0008m]P03000m]Sff008m]P03000m]Sff008m]P03000m]Sff
008m]P030011]T6f0091]P030011]T6f0091]P030011]T6f00=1]P030011]T6f0091]P030015]TFf
00=5]P030015eTGF0095eP030015eTGF00=5eP030015eDGE0095e@030019eDWE00=9e@030019eDWE
00A9e@030019eDWE0099e@030019eDWE00=9e@030019mDWe00=9m@03001=m@0000800003COD004ge
00E=m@03001=mDge00==m@03001=mDge00==m@03001=mDge00A=m@<000=Am@03001AmE7e00AAm@03
001AmE7e00AAm@03001B5E8E009B5@8000IB5@03001F5EHE00AF5@03001F5EHE009F5@03001F5@00
00MF5@03001F5EHE00AF5@8000EF5@03001J=EXe00EJ=@8000EJ=@03001J=EXe00EJ=@03001J=EXe
00AJ=@03001J=EXe00AJ=@8000MN=@04001NEEiE0004GUD00`00GUENE@03GUD00`00GUD00007GUD2
0006HUD01000HUERE@001F9e00D0069eHWERM@0000=RM@03001RMF9e00=RM@04001RMF9e0005HWD0
1000IWEVM@001FIe00@006JEIYD000AVU@05001VUFJEIYD00003IYD00`00IYEVU@02IYD01000IYEV
U@001VZE0P001VZe00<006Ze000016Ze00L006ZeJ[EZ]@00J[H00007J[H00`00K]I^eP03K]H01`00
K]I^eVkF001^eP0000E^eP03001^eP0000=^eP03001^mVkf00=^mP03001^mP00009^mP03001bmW;f
00=bmP03001bmP00009bmP03001c5W<F009c5P06001c5W<F001c5P0017<F00<007<FLaH00W<F00<0
07LfMcH00WLf00D007LfMcIg=P0000=g=`03001g=gLg009g=`05001gEgMGMeL00003MeL20002MeL0
1000MeMgE`0017Mg00P007]gNgL007]g001kM`000W]g00D007^GNiMkU`00009kU`08001kUg^G001k
U`00NiL0009k^003001k^000009k^004001k^7^h0002NkP01`00NmQkf000NmP007_H00<00006MmP0
07OH001gf0000WOH01L007Oh001gn000MoP007Oh001cn000LoP007?h001cn000KoP007?h001gf000
00=[nP03001FoEKm00<00003E_d005Km00AFo@03001FoEKm00<00003E_d005Km00AFo@@000=Fo@03
001FoEKm00=Fo@<000EFo@04001FoEKmE_d40005E_d00`00E_d0000200000eKm001Fo@05E_d00`00
E_eFo@0300000eKm001Fo@04E_d00`00E_eFo@0300000eKm001Fo@04E_d40003E_d00`00E_eFo@03
E_d200000goo001oo`13Ool006]oo`800:Uoo`03001FoEKm00=Fo@8000EFo@03001FoEKm00=Fo@80
00IFo@04001FoEKmE_d30006E_d00`00E_d00002000015Km0000004H0`0000<160000AP010000PDh
00D000DH000000Th008000043CP000dh00033CP300024CP010004CP000000QDh0P0000HIF0006CPI
>0006CP200037EP010007EL000000aeG00<0025G00000b5G00T002EG9ELUE`009EL002Eg00000bUg
00@002Ug:GLYM`800003:GL002eg008]M`04000]Mbeg;GL20002<GL300000c5g000aM`02<GL00`00
<IHaUP03<IH20002=IH00`00=IHeUP02=IH01@00=IHeUSFF00000cVF00<003VF>IH00SVF00<003VF
>IH010000cff00<003ff?KH00Sff00<003ff?KH00cff00D0046f@KI1]P0000A1]P030011]T6f00=1
]P030011]T6f0091]P030015]TFf00=5]P030015eTGF0095eP030015eTGF00=5eP030015eDGE0095
e@030019eDWE00A9e@030019eDWE00=9e@030019eDWE0099e@030019eDWE00=9e@030019mDWe0099
m@<000A=m@03001=mDge00A=m@03001=mDge00A=m@03001=mDge009=m@03001=mDge00==m@8000IA
m@03001AmE7e00=Am@03001AmE7e00AAm@07001B5E8EDQD0058E00001U8E00<005HEEQD015HE00D0
05HEEQEF5@0000=F5@03001F5EHE00AF5@03001F5EHE00=F5@8000IF5@03001J=EXe00EJ=@03001J
=EXe00AJ=@03001J=EXe00EJ=@03001J=EXe00AJ=@03001J=EXe00=J=@04001N=Ehe0006GSD00`00
GUD00005GUD00`00GUENE@02GUD01000GUENE@001eiE00<0069EHUD01F9E00@0069EHUD000ERM@05
001RMF9eHWD00004HWD01@00HWERMF9e00000f9e00<0069eHWD00V9e00D006IeIWEVM@0000AVM@03
001VUFJE009VU@04001VUFJE0004IYD01@00IYEVUFJE000016JE00<006JE00001fZE00<006ZeJ[D0
1FZe00<006Ze00000fZe00<006ZeJ[D00VZe00<006Zf00001VZf00<006kF00000fkF00<006kFK]H0
0fkF00<006kFK]H00fkF00L006kFK]I^eP00K]H00005K_H01P00K_I^mP00K_H000EbmP06001bmW;f
001bmP001G<F00D007<FLaIc5P0000Ac5P03001c5W<F009c5P03001g=P00009g=P03001g=WLf009g
=P04001g=gLgMcL20002McL01@00MeMgEgMG00000gMG00H007MGMeL007MG0002MeL01@00MgMgMgMg
00000W]g00D007]gNgMkM`00009kM`05001kUg^GNiL00003NiL00`00NiL00003NiL200001G^h001k
^7^h00000W^h00H007^hNkP007^h0002NmP00`00NmP00002NmP00`00MmP00006000067OH001gn000
MoP007Oh001gn000LoP007?h001cn000LoP006oh001cn000MmP000=[nP@000EFo@04001FoEKmE_d4
0005E_d00`00E_d000020002E_d00`00E_eFo@03E_d00`00E_d000020002E_d00`00E_eFo@03E_d4
0003E_d00`00E_eFo@03E_d20005E_d00`00E_eFo@03E_d30005E_d01000E_eFoEKm10001EKm00<0
05Km00000P0000=Fo@00E_d01EKm00<005Km00000P0000EFo@00Oomoo`0004=oo`00Jgoo00<007oo
Ool0ZGoo00<005Km00000P000UKm00<005KmE_d00eKm00<005Km00000P000UKm00<005KmE_d00eKm
10000eKm00<005KmE_d00eKm0P0015Km0`0000<160000CT00`000P4H00/0004H000000Dh00056000
2CP000Th00<000073CP000003CP000dh00000a4h00<0014h00000aDh0`000aTh00@001Th0000008M
F004000MEaeG00037EL00`008ELQE`0200028EL01P009ELUEbEG000UE`8000<YM`06000YMbUg:GL0
02Ug0P000beg00@002eg;GL]M`H000<aM`05000aMc5g<GL00004<IH00`00=IH000030003=IH01@00
=IHeUSFF000013VF00D003VF>IHiUP0000DiUP@00003?KH003ff008m]P03000m]Sff00<m]P030011
]T6f0091]P030011]T6f0091]P030011]T6f0091]P030011]T6f0091]P030015]TFf00=5]P030015
eTGF0095eP030015eTGF00A5eP030015eDGE0095e@030019eDWE00=9e@030019eDWE00=9e@030019
eDWE0099e@030019eDWE00A9e@@00003BMD004ge00E=m@03001=mDge00==m@03001=mDge00A=m@03
001=mDge009=m@03001=mDge009=m@03001=m@0000IAm@03001AmE7e00AAm@03001AmE7e00=Am@04
001B5E8E0002DQD00`00DQEB5@05DQD00`00EQEF5@03EQD01000EQEF5@0015HE00<005HEEQD015HE
00<005HEEQD00UHE00<005HE00001eHE00<005XeFSD00eXe0P001eXe00<005XeFSD00eXe0P001eXe
00D005XeFSEJ=@0000=N=@03001N=Ehe00EN=@03001NEEiE00ENE@05001NEEiEGUD00002GUD00`00
GUENE@05GUD00`00HUERE@06HUD20006HWD01000HWERM@001F9e00D0069eHWERM@0000ARM@05001R
MF9eHWD00004IWD01@00IWEVMFIe000016JE00@006JEIYD000EVU@03001VU@0000IVU@8000MZU@03
001Z]FZe00AZ]@04001Z]FZe0003J[D00`00J[EZ]@03J[D00`00J[IZ]P05J[H00`00K]H00003K]H0
0`00K]I^eP03K]H00`00K]I^eP03K]H01`00K]I^eVkF001^eP0000E^mP06001^mVkf001^mP001G;f
00H007;fL_H007;f0004LaH00`00LaIc5P02LaH00`00LaIc5P02LaH00`00LaIc5P02LaH01P00McIg
=P00McH000=g=P05001g=gLgMcL00002McL00`00McL00003MeL01@00MeMgEgMG00000gMG00@007MG
MeL000=gM`05001kMg]gNgL00003NgL200001G]g001kUg^G00000g^G00@007^GNiL000=kU`06001k
]`00001k^0000W^h00@007^hNkP0009k^005001kf000NmP00002NmP02P00MmQgf7OH001gf000MmP0
07Oh6`000eKm00<005KmE_d00eKm10000eKm00<005KmE_d00eKm0P001UKm00@005KmE_eFo@<000IF
o@03001Fo@0000800003E_d005Km00EFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@000080
0003E_d005Km00EFo@@0009Fo@03001FoEKm00AFo@8000EFo@03001FoEKm00=Fo@8000EFo@03001o
o`0004=oo`00JWoo00<007ooOol0Zgoo00<005KmE_d015Km00@005KmE_eFo@<000IFo@03001Fo@00
0080009Fo@03001FoEKm00=Fo@03001Fo@000080009Fo@03001FoEKm009Fo@<000040AP000000AP2
00020AP200000`4H000000021AP00`002CP000022CP020003CP000dh000=>0003CP20000114h000A
>14h0P0000@E>0005CP000<I>004000I>1Th00027EP010007ELMEaeG0P000QeG00@0025G000QE`<0
00<UE`03000UEbEG008000<YM`06000YMbUg:GL002Ug0P000beg1@000beg0P000S5g00D0035g<GLa
M`0000@aUP03000eUSFF008eUP80008eUP03000eUSFF008eUP05000iUSVF>IH00004>IH00`00>IHi
UP02>IH01000?IHmUSfF0`000Sff00<003ff?KH00cff00<0046f@KH00T6f00<0046f@KH00T6f00<0
046f@KH00d6f00<0046f@KH00T6f00<004FfAKH00dFf00<004GFAMH00TGF00<004GFAMH00dGF00<0
04GEAMD00TGE00<004WEBMD00dWE00<004WEBMD00dWE00<004WEBMD00dWE00<004WEBMD0100014WE
00<004geCOD014ge00<004geCOD00dge00<004geCOD014ge00<004geCOD00Tge00<004geCOD00P00
0Tge00<0057eDOD0157e00<0057eDOD0157e00<0057eDOD0157e0P00158E00<0058EDQD0158E00<0
05HEEQD015HE0P001EHE00<005HEEQD015HE00D005HEEQEF5@00009F5@03001F5EHE00EF5@03001J
=EXe009J=@03001J=@0000MJ=@03001J=EXe009J=@04001J=EXe0006FSD01@00FSEJ=EXe00000ehe
00<005heGSD01Ehe00<005iEGUD01EiE00@005iEGUD000ANE@03001NEEiE00=NE@03001NE@0000MR
E@03001RMF9e00ERM@03001RM@0000IRM@04001RMF9e0005HWD01000HWERM@001FIe00@006IeIWD0
00EVU@03001VU@0000IVU@03001VU@0000IVU@03001ZUFZE00EZU@03001Z]@0000EZ]@05001Z]FZe
J[D00002J[D00`00J[EZ]@03J[D00`00J[IZ]P04J[H01@00K]I^eVkF00000VkF00<006kFK]H00VkF
00<006kF00000fkF00<006kFK]H00fkF00<006kfK_H00fkf00<006kfK_H00Vkf00<007;fL_H00g;f
00<007;fL_H00W;f00<007<FLaH00g<F00L007<FLaIc5P00LaH00002LaH00`00LaIc5P02LaH00`00
McIg=P02McH01@00McIg=WLf000017Lg00D007LgMcMg=`0000=gE`05001gEgMGMeL00004MeL20000
0gMG001gM`02MgL01000NgMkM`000g]g00@007]gNgL000=kU`04001kUg^G0002NiL01@00NiMkUg^G
00000W^g00H007^g000007^h0003NkP01@00NkP007_H00000W_H00<007_H00000gOH00D007OH001g
f000009gn00I001gn000MoP007Oh001cn000LoP007?h001cn000LoP007?h001cn000LoT006_i0000
1UKm00<005Km00000P0000=Fo@00E_d01EKm00<005Km00000P0000=Fo@00E_d01EKm10000UKm00<0
05KmE_d015Km0P001EKm00<005KmE_d00eKm0P001EKm00@005KmE_eFo@@000EFo@03001FoEKm00<0
0003E_d005Km00AFo@03001FoEKm00<00003E_d005Km00AFo@03001FoEKm00<00003E_d005Km00AF
o@800003Ool007oo045oo`00JWoo00<007ooOol0[7oo00<005KmE_d00eKm10000eKm00<005KmE_d0
0eKm0P001UKm00@005KmE_eFo@<000IFo@08001FoEKmE_d0003G000160<000816003000160000080
0081600300056000008000<9>004000=>0003CP200000`dh000=>00300001a4h000A>0005CP001Dh
0080008I>003000I>1Th008000097EP001eG7EL001eG000ME`00008QE`04000QEb5G00039EL01000
9ELUEbEG0P000RUg00D002Ug:GLYM`00008YM`D000<]M`06000]Mbeg;GL002eg0`000c5g00<0036F
<IH00c6F00H003FF=IHeUP00=IH30004=IH01@00>IHiUSVF000013VF00<003VF>IH00SVF00<003fF
?IH00SfF00<003ff00000`0013ff00<0046f@KH00T6f00<0046f@KH00T6f00<0046f@KH00d6f00<0
046f@KH00T6f00<004FfAKH00dFf00<004GFAMH00TGF00<004GFAMH00dGF00<004GEAMD00TGE00<0
04WEBMD00dWE00<004WEBMD00dWE00<004WEBMD00TWE10000dWE00<004WEBMD00dWE00<004geCOD0
0dge00<004geCOD014ge00<004geCOD00dge00<004geCOD00dge0P001Dge00<0057eDOD00e7e00<0
057eDOD0157e00<0057eDOD00e7e0P001E8E00<0058EDQD0158E00<005HEEQD00eHE0P001UHE00<0
05HEEQD015HE00@005HEEQD000AF5@03001F5EHE00AF5@05001J=EXeFSD00003FSD00`00FSEJ=@04
FSD01@00FSEJ=EXe00000eXe00<005XeFSD015Xe00@005XeFSD000AN=@03001N=Ehe00AN=@8000MN
E@04001NEEiE0004GUD00`00GUENE@02GUD01000GUENE@001f9E00<0069eHWD01V9e0P001V9e00<0
069e00001V9e00<0069e00001VIe00<006Ie00001fJE0P001fJE00<006JEIYD01FJE00<006ZEJYD0
16ZE00@006ZeJ[D000AZ]@03001Z]FZe009Z]@03001Z]@0000EZ]@03001Z]@0000EZ]P07001^eVkF
K]H006kF00001FkF00<006kF00000fkF00<006kFK]H00fkF00<006kfK_H00fkf00<006kfK_H00Vkf
00<007;fL_H00g;f00<007;fL_H00W;f00<007<FLaH00W<F00<007<FLaH00W<F00H007<FLaH007<F
0004LaH00`00McIg=P02McH01@00McIg=WLf00000gLg00<007LgMcL00WLg00@007MGMeL000AgE`05
001gEgMGMeL00002MeL20002MgL01@00NgMkMg]g00000g]g00<007]gNgL00P0000=kU`00NiL00W^G
00<007^G00000g^G00@007^gNkL0009k]`03001k]`0000800009NkP007^hNkP007_H001kf000009k
f005001gf7OH001gf0030002MoP06`00MoP007Oh001gn000LoP007?h001cn000LoP007?h001cn000
LoP007?i001[n@00IoP00005E_d20005E_d01000E_eFoEKm10001EKm00<005KmE_d00`0000=Fo@00
E_d015Km00<005KmE_d00`0000=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d015Km10000eKm
00<005KmE_d00eKm0`001EKm00@005KmE_eFo@@000EFo@04001FoEKmE_d40005E_d00`00E_d00002
00001EKm001oogoo0000@Goo001ZOol00`00Oomoo`2]Ool00`00E_d000020002E_d00`00E_eFo@03
E_d00`00E_d000020002E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d3000015Km0000e`3G
1@000P4H00<0004H00000P000P4H00<000DH00000P000PTh0`000Pdh00@000dh3CP0008=>005000A
>14h000A>00200000aDh000E>00300026CP010006CL000000aeG00@001eG0000008QE`04000QEb5G
8EL200029EL01@009ELUE`009EL00`000bUg00<002Ug00001@000beg00D002eg;GL]M`0000<]M`80
00<aM`03000aUS6F008aUP05000eUSFF=IH00003=IH20003=IH00`00>IHiUP02>IH01@00>IHiUSVF
00001CVF00D003fF?IHmUP0000@m]P@0008m]P050011]T6f@KH00004@KH00`00@KI1]P03@KH00`00
@KI1]P02@KH00`00AKI5]P03AKH00`00AMI5eP02AMH00`00AMI5eP03AMH00`00AME5e@02AMD00`00
BME9e@03BMD00`00BME9e@04BMD400000dWE0019e@04BMD00`00BME9e@03BMD00`00COE=m@03COD0
0`00COE=m@04COD00`00COE=m@03COD00`00COE=m@02COD20006COD00`00DOEAm@04DOD00`00DOEA
m@03DOD00`00DOEAm@02DOD00`00DOD00005DQD00`00DQEB5@04DQD00`00EQEF5@02EQD00`00EQD0
0006EQD00`00EQEF5@05EQD20005EQD00`00EQEF5@04EQD01000FSEJ=@0015Xe00<005XeFSD015Xe
00@005XeFSD000AJ=@03001J=EXe00EJ=@8000IN=@03001N=Ehe009N=@04001N=Ehe0007GUD20005
GUD00`00GUENE@02GUD01000GUENE@001V9E00<0069E00001f9e00<0069eHWD01V9e0P001f9e0P00
1fIe0P001fJE00<006JEIYD01VJE00<006JEIYD016JE00<006ZE00001FZE00@006ZeJ[D000=Z]@03
001Z]FZe00=Z]@03001Z]@0000EZ]@03001Z]@0000AZ]P03001^eVkF009^eP03001^eP0000A^eP05
001^eVkFK]H00002K]H00`00K]I^eP02K]H00`00K_H00003K_H00`00K_I^mP02K_H00`00L_H00003
L_H00`00L_IbmP02L_H00`00LaH00002LaH00`00LaIc5P02LaH00`00LaIc5P02LaH00`00LaIc5P02
LaH00`00McIg=P02McH01@00McH007Lf000017Lg00T007LgMcMg=`00MeL007MG00000gMG00D007MG
MeMgE`0000=gE`05001kM`00MgL00002NgL01@00NgMkMg]g00000W]g00<007^GNiL00P000W^G00@0
07^GNiL0009kU`04001k]g^g0002NkL01000NkMk]`000W^g0P0000Ak^000NmP0009kf003001kf000
009gf003001gf000009gf00K001gn000MoP007Oh001gn000LoP007?h001cn000LoP007?h001cn000
LoP007?i001[n@00009Wn003001FoEKm00<00003E_d005Km00AFo@@000=Fo@03001FoEKm00=Fo@<0
00EFo@03001FoEKm009Fo@<000EFo@04001FoEKmE_d40005E_d00`00E_d0000200000eKm001Fo@05
E_d00`00E_d0000200000eKm001Fo@05E_d40002E_d00`00E_eFo@04E_d40002E_d00`00E_eFo@04
E_d20005E_d00`00Ool00011Ool006Yoo`03001oogoo0:ioo`8000EFo@04001FoEKmE_d40005E_d0
0`00E_d0000200000eKm001Fo@05E_d00`00E_d000020002E_d400000`3G0000n00300020AP30000
104H0001604H0`0000<560002CP00PTh0`000Pdh0`000`dh00<0014h00000Q4h00@001Dh5CP0008E
>007000I>1Th6CP001Tg00000aeG00<001eG7EL00P0000<QE`008EL00R5G00D0025G000UE`0000<U
E`03000UEbEG00800006:GL00000000YM`000bUg0P000beg00D002eg;GL]M`0000<]M`80008aM`03
000aUS6F008aUP03000eUSFF008eUP04000eUSFF=IH20002=IH00`00>IHiUP02>IH01@00>IHiUSVF
00001CVF00<003fF?IH00SfF00D003ff?KHm]P0000<m]PH00003@KH0046f0091]P030011]T6f00=1
]P030011]T6f0091]P030015]TFf00=5]P030015eTGF0095eP030015eTGF00=5eP030015eDGE0095
e@030019eDWE00A9e@030019eDWE00@000A9e@030019eDWE00A9e@030019eDWE0099e@03001=mDge
00A=m@03001=mDge00==m@03001=mDge00A=m@@00003COD004ge00E=m@03001AmE7e00AAm@03001A
mE7e00=Am@03001AmE7e0080009Am@03001B5E8E00AB5@03001B5E8E00=B5@03001F5EHE0080009F
5@03001F5EHE00EF5@03001F5EHE00AF5@03001F5EHE00AF5@03001F5EHE00EF5@8000EJ=@03001J
=EXe00EJ=@8000EJ=@03001J=EXe00EJ=@03001N=Ehe00EN=@05001N=EheGSD00003GSD00`00GUEN
E@05GUD00`00GUENE@05GUD01000GUENE@0015iE00<0069EHUD00f9E00<0069E00001f9e00<0069e
HWD01V9e00<0069eHWD01V9e00<006IeIWD01VIe00<006JEIYD01VJE00<006JEIYD01FJE00<006JE
00001FJE00<006ZE000016ZE00<006ZeJ[D00VZe00@006ZeJ[D000IZ]@03001Z]FZe00=Z]@04001Z
]FZe0003J[H00`00K]I^eP04K]H00`00K]I^eP03K]H01`00K]I^eVkF001^eP0000E^eP06001^mVkf
001^mP001Fkf00H007;fL_H007;f0005L_H01P00LaIc5P00LaH000Ac5P03001c5W<F009c5P03001c
5W<F009c5P05001g=WLfMcH00003McH00`00McMg=`02McL00`00McMg=`02McL01000MeMgE`0017MG
00D007MGMeMgE`00009gE`05001kMg]gNgL00003NgL01@00NgMkMg]g00000W]g00X007^GNiL007^G
001kU`00NiL000=kU`06001k]g^g001k]`000W^g00H007^gNkMk]`00NkP400001G_H001kf7_H0000
0WOH01l007OH001gf000MoP007Oh001gn000MoP007?h001cn000LoP007?h001cn000LoP007?h001c
n@00JoT00002IoP40005E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d0000200000eKm001F
o@05E_d00`00E_d0000200000eKm001Fo@05E_d40002E_d00`00E_eFo@04E_d20005E_d01000E_eF
oEKm10001EKm00<005KmE_d00`0000=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d015Km00<0
05KmE_d00`0000=Fo@00E_d015Km0P0000=oo`00Ool0?goo001ZOol00`00Oomoo`2`Ool00`00E_eF
o@02E_d40004E_d00`00E_eFo@02E_d30004E_d00`00E_eFo@03E_d20006E_d02@005Qd000000=L0
003h0001600200001@4H000000000AP00P0000D16000000000DH008000042CP000TH00023CP01000
3AP000000Pdh0P0000LA>0004CPA>0005CP000035CP2000011Th000I=aTg0P0000<ME`007EL00QeG
0P0000<QE`008EL00R5G00@0025G000000<UE`04000UEbEG9EL20002:GL01000:GLYM`000bUg0P00
0Reg00D002eg;GL]M`0000<]M`03000aMP00008000DaUP05000eUSFF=IH00003=IH00`00=IH00003
0003>IH00`00>IHiUP02>IH00`00>IHiUP02>IH00`00?IHmUP02?IH01@00?KHm]Sff00001Cff00@0
03ff?KHm]PD00003@KH0046f00A1]P030011]T6f0091]P030015]TFf0095]P030015eTGF00=5eP03
0015eTGF00=5eP030015eDGE0095e@030019eDWE00H000=9e@030019eDWE00=9e@030019eDWE00=9
e@030019eDWE00=9e@03001=mDge00==m@03001=mDge00==m@03001=mDge00==m@8000A=m@03001=
mDge00A=m@03001AmE7e00AAm@03001AmE7e00AAm@8000EAm@03001B5E8E00=B5@03001B5E8E00AB
5@8000EF5@03001F5EHE00AF5@03001F5EHE00=F5@8000IF5@03001F5EHE00EF5@03001J=EXe00AJ
=@03001J=EXe00EJ=@03001J=EXe00EJ=@03001J=EXe00AJ=@03001N=Ehe00EN=@05001N=EheGSD0
0003GSD00`00GUENE@05GUD00`00GUENE@05GUD01000GUENE@0015iE00<0069EHUD00V9E00@0069E
HUD000IRM@8000QRM@03001RMF9e00IRM@03001VMFIe00IVM@03001VUFJE00EVU@03001VU@0000EV
U@04001VUFJE0004IYD01000JYEZU@0016ZE00<006ZeJ[D00VZe00<006Ze00001fZe00<006ZeJ[D0
0fZe00D006ZeJ[EZ]@00009Z]P03001^eVkF00A^eP03001^eVkF009^eP03001^eVkF009^eP03001^
eP0000A^eP07001^mVkfK_H006kf000016kf00L007;fL_IbmP00L_H00004L_H00`00LaIc5P02LaH0
0`00LaIc5P02LaH00`00LaIc5P02LaH00`00LaH00002LaH00`00McIg=P02McH01@00McIg=WLf0000
17Lg00D007LgMcMg=`0000=gE`80009gE`05001gEgMGMeL00003MeL01@00NgMkMg]g00000W]g00D0
07]gNgMkM`00009kM`04001kUg^G0003NiL200001G^G001kUg^G00000W^g00H007^gNkL007^g0003
NkL01`00NkQk^000NmP007_H00800007NmP007OHMmP007OH00000WOH00<007Oh00000P0000]gn000
MoP007?h001cn000LoP007?h00800007LoP007?h001cn@00JoT010000UKm00<005KmE_d015Km0P00
1EKm00@005KmE_eFo@@000EFo@04001FoEKmE_d40005E_d00`00E_eFo@0300000eKm001Fo@04E_d0
0`00E_eFo@0300000eKm001Fo@04E_d40003E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@02E_d3
0005E_d01000E_eFoEKm10001EKm00<005Km00000P0000EFo@00Oomoo`0003moo`00JWoo00<007oo
Ool0/Goo00@005Km0000009Fo@03001FoEKm00AFo@04001Fo@000003E_d00`00E_eFo@02E_d00`00
E_d000020002E_d00`00E_eFo@03E_d70000103h0000004H100000<160000AP00P0000D160001AP0
00DH00<000072AP000003CP000dH00000`dh0`000Q4h0P0000lE>0005CPE>0005CL001Th000I=`00
6CL001eG00000QeG00@001eG000000<QE`03000QEb5G0080008UE`D000049EL000000002:GL01P00
:GLYMbUg000]M`<000<]M`05000]Mbeg;GL00003<GH20004<IH01@00=IHeUSFF00000cFF00<003FF
=IH00SFF0P000SVF00<003VF>IH00SVF00<003VF>IH00SVF00<003fF?IH00SfF00<003ff?KH00Sff
00<003ff?KH00Sff00<003ff?KH00Sff00@0046f@KI1]Q000095]P030015eTGF010000=5e@030019
eDWE00=9e@030019eDWE00=9e@030019eDWE00=9e@030019eDWE00=9e@03001=mDge00==m@03001=
mDge00==m@04001=mDgeCOD200000dge001=m@04COD00`00COE=m@03COD00`00DOEAm@04DOD00`00
DOEAm@03DOD20006DOD00`00DQEB5@03DQD00`00DQEB5@04DQD00`00EQEF5@04EQD00`00EQEF5@04
EQD00`00EQEF5@02EQD00`00EQD00007EQD00`00EQEF5@04EQD00`00FSEJ=@05FSD00`00FSEJ=@04
FSD00`00FSEJ=@05FSD00`00FSEJ=@03FSD20007GSD01000GSEN=@0015he00<005iEGUD015iE0P00
1eiE00<005iE00001EiE00D0069EHUERE@0000ARE@03001RMF9e00=RM@03001RM@0000IRM@8000MR
M@8000MVM@03001VM@0000EVU@04001VUFJE0005IYD01000IYEVU@0016JE00D006ZEJYEZU@00009Z
U@03001Z]FZe00=Z]@03001Z]@0000IZ]@03001Z]@0000=Z]@03001Z]FZe009Z]@03001Z]P0000I^
eP03001^eP0000=^eP03001^eVkF00=^eP03001^eVkF00=^eP03001^mVkf009^mP03001^mVkf00=^
mP03001bmW;f009bmP03001bmW;f00=bmP03001c5W<F009c5P03001c5W<F009c5P03001c5W<F009c
5P06001c5W<F001c5P000gLf00L007LfMcIg=P00McH00002McL00`00McMg=`02McL01000MeMgE`00
0WMG00<007MG00000WMG00D007MGMeMgE`0000=kM`05001kM`00NgL00003NgL00`00NgL00003NiL0
1P00NiMkUg^G001kU`800003NiL007^g009k]`03001k]`00009k]`04001k]g^g0002NkP00`00NmP0
0002NmP00`00NmP0000600004GOH001gn000MoP007Oh001gn000LoP007?h001cn000LoP02P0000=W
n000E_d015Km00<005KmE_d00`0000=Fo@00E_d015Km10000eKm00<005KmE_d00eKm10000eKm00<0
05KmE_d00eKm0`001EKm00@005KmE_eFo@@000EFo@03001Fo@0000800003E_d005Km00EFo@03001F
o@0000800003E_d005Km00EFo@03001Fo@0000800003E_d005Km00EFo@@0009Fo@03001FoEKm00AF
o@8000EFo@03001oo`0003moo`00JGoo00<007ooOol0/goo00<005KmE_d00eKm00<005KmE_d00eKm
0P001UKm00<005KmE_d010001EKm00<005Km00000P000eKm0P0000<1>@000?P00`000P4H00H0004H
000160000AP20000104H000560000PDH00@000TH00096080008=608000043CP000dh00034CP30003
5CP010005CL000000QTg00@001Tg000000<ME`03000ME`0000<QE`04000QEb5G8EL500039EL00`00
9ELUE`0200000bUg000YM`02:GL01000;GL]Mbeg0P000beg00D002eg;GL]M`0000<aMP8000<aUP03
000eUSFF008eUP05000eUSFF=IH00003=IH00`00>IH000030003>IH00`00>IHiUP03>IH01@00?IHm
USfF000013ff00<003ff?KH00cff00D003ff?KHm]P0000A1]P030011]T6f00=1]P030011]T6f0091
]P040011]T6f@KH50002AKD00`00AME5e@03AMD00`00AME5e@02AMD00`00AME5e@03AMD00`00BME9
e@04BMD00`00BME9e@02BMD00`00BME9e@03BMD00`00BME9e@03BMD00`00COE=m@03COD00`00COE=
m@04COD30003COD00`00COE=m@03COD00`00COE=m@04COD00`00DOEAm@03DOD01000DOEAmE7e0P00
00=Am@00DOD01E7e00<0058EDQD0158E00<0058EDQD00U8E0P001UHE00<005HEEQD015HE00D005HE
EQEF5@0000=F5@03001F5EHE00AF5@03001F5EHE00=F5@8000MJ=@03001J=EXe00=J=@8000MJ=@03
001J=EXe009J=@04001J=EXe0007GSD20006GSD00`00GUENE@02GUD01000GUENE@001eiE00<005iE
GUD01EiE00@0069EHUD000ARE@03001RMF9e009RM@04001RMF9e0005HWD01000HWERM@001F9e00@0
069eHWD000EVM@04001VMFIe0005IYD01000IYEVU@0016JE00<006JEIYD00VJE00@006JEIYD000AZ
U@03001ZU@0000MZ]@03001Z]FZe00AZ]@04001Z]FZe0003J[D00`00J[EZ]@02J[D00`00J[H00005
K]H01000K]I^eP000fkF00<006kFK]H00fkF00<006kFK]H00VkF00<006kfK_H00fkf00<006kfK_H0
0Vkf00<007;fL_H00g;f00<007;fL_H00W;f00<007<FLaH00W<F00<007<F00000g<F00D007<FLaIc
5P0000Ac5P03001g=WLf009g=P05001g=WLfMcH00002McH00`00McL00003McL01@00MeMgEgMG0000
0gMG00D007MGMeMgE`0000=gE`04001kMg]g0003NgL20002NgL01000NgMkM`000W^G00D007^GNiMk
U`00009kU`03001kU`0000800007NkL007^gNkL007^g00000g^g00D007^h001kf000009kf004001k
f7_H0002MmP01000MmP007OH4@0000Mcn000KoP006oh001_n002000016Oh001Wm`000eKm10001EKm
00<005Km00000P0000=Fo@00E_d01EKm00<005Km00000P000UKm00<005KmE_d00eKm00<005Km0000
0P0000=Fo@00E_d01EKm10000UKm00<005KmE_d015Km0P001EKm00<005KmE_d00eKm0P001EKm00@0
05KmE_eFo@@000EFo@03001FoEKm00<00003E_d005Km00AFo@03001FoEKm00<00003E_d005Km00AF
o@04001oogoo000nOol006Uoo`03001oogoo0;Aoo`03001FoEKm00=Fo@03001Fo@000080009Fo@03
001FoEKm00=Fo@<000AFo@03001FoEKm009Fo@<000IFo@8000030CT0000000<0008160@000816003
00016000008000<56004000960002AP200001`dH000=60003CP000dh008000044CP0014h00035CP0
10005CLE=`000QTg00@001Tg6CL000<ME`03000MEaeG0080008QE`@000048EL002EG00039EL01@00
9ELUEbEG00000RUg00D002Ug:GLYM`0000<]M`80008]M`05000]Mbeg;GL00003<GH01P00<GH00000
<IH000@eUP05000eUSFF=IH00003=IH00`00>IHiUP02>IH20002>IH00`00>IHiUP03>IH00`00?IHm
UP02?IH01@00?KHm]Sff00001Cff00<003ff?KH00Sff00D0046f@KI1]P0000E1]P030011]T6f0091
]P030011]T6f00=1]P030015]DFe0095]@030015eDGE00=5e@030015eDGE0095e@030015eDGE00A5
e@030019eDWE00=9e@030019eDWE0099e@030019eDWE00A9e@030019eDWE00=9e@03001=mDge009=
m@03001=mDge00==m@8000I=m@03001=mDge009=m@03001=mDge00A=m@03001AmE7e00AAm@<000=A
m@03001AmE7e00AAm@03001B5E8E00AB5@07001B5E8EDQD0058E00001UHE00<005HEEQD015HE00@0
05HEEQD000AF5@03001F5EHE00AF5@03001F5EHE009F5@04001F5EHE0006FSD00`00FSEJ=@02FSD0
1000FSEJ=@001UXe00D005XeFSEJ=@0000=J=@03001N=Ehe00EN=@03001N=Ehe00EN=@05001NEEiE
GUD00003GUD00`00GUENE@05GUD00`00GUENE@05GUD00`00HUD00005HUD01@00HWERMF9e00000f9e
00<0069eHWD00f9e00@0069eHWD000ERM@04001RMF9e0005IWD01000IWEVM@0016JE00<006JEIYD0
0VJE00D006JEIYEVU@0000AVU@04001VUFJE0004JYD00`00JYD00007J[D00`00J[EZ]@04J[D01@00
J[EZ]FZe00000VZe00<006ZeJ[D00fZe00<006kFK]H016kF00L006kFK]I^eP00K]H00005K]H00`00
K]H00003K]H00`00K_I^mP02K_H00`00L_H00003K_H00`00L_IbmP02L_H00`00L_H00003L_H00`00
LaIc5P02LaH01P00LaIc5P00LaH000Ac5P03001c5W<F009c5P05001g=WLfMcH00003McH00`00McIg
=P02McH00`00McMg=`02McL01000MeMgE`0017MG0P0000=gE`00MeL00WMG00D007]gNgMkM`0000=k
M`07001kM`00NgL007]g00000W^G00D007^GNiMkU`00009kU`04001kUg^G0002NkL200001G^g001k
]g^g00000W^g00P007^hNkP007_H001kf0000W_H00H007OHMmP007OH0002MmP01P00MoP007Oh001g
n0<00007LoP007?h001cn000LoP00P0000E_n000KoP006oh00800004IoP006OgIoL40003E_d00`00
E_eFo@03E_d20005E_d00`00E_eFo@03E_d20006E_d01000E_eFoEKm0`001EKm00<005KmE_d00`00
00=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d015Km
10000eKm00<005KmE_d00eKm0`001EKm00@005KmE_eFo@@000EFo@04001FoEKmE_d30002Ool00`00
Oomoo`0kOol006Uoo`03001oo`0000800;=oo`04001FoEKmE_d30006E_d00`00E_d000020002E_d0
0`00E_eFo@03E_d01000E_d000000eKm00<005KmE_d00eKm100000@160000000008160D000816003
000160000080008560<000896005000=60dH000=600200001`dh000=60004CP0014h008000035CP0
01Dg008E=`03000I=`0000<I=`8000067EL001eG7EL001eG0`000b5G00@0025G000000<UE`04000U
EbEG9EL200000bUg000YM`02:GL01P00;GL]Mbeg000]M`<000<]M`05000aMS5f<GH00003<GH30003
=IH01@00=IHeUSFF000013FF00H003VF>IHiUP00>IH40004>IH00`00?IHmUP02?IH01@00?KHm]Sff
00001Cff00<003ff?KH00Sff00<0046f@KH00T6f00<0046f@KH00d6f00<0046f@KH00T6f00<0046f
@KH00T6f00<004FeAKD00dFe00<004GEAMD00dGE00<004GEAMD00TGE00<004GEAMD00dGE00<004WE
BMD00dWE00<004WEBMD00TWE00<004WEBMD014WE00<004WEBMD00dWE00<004geCOD00dge00<004ge
00000P0000==m@00COD01Dge00<004geCOD00Tge00<004geCOD014ge00<0057eDOD00e7e0P001U7e
00<0057eDOD0157e00<0058EDQD00e8E00@0058EDQD000=B5@03001F5EHE00AF5@03001F5EHE00AF
5@8000EF5@03001F5EHE00AF5@05001F5EHEEQD00003EQD00`00FSEJ=@04FSD01@00FSEJ=EXe0000
0eXe00<005XeFSD015Xe00@005XeFSD000AJ=@03001N=Ehe00EN=@03001N=Ehe00EN=@05001NEEiE
GUD00003GUD00`00GUENE@04GUD20007GUD00`00HUD00006HUD01000HWERM@00169e00D0069eHWER
M@0000=RM@03001RMF9e009RM@05001RMF9eHWD00004IWD00`00IWEVM@02IWD01@00IYEVUFJE0000
16JE00@006JEIYD000EVU@03001VU@0000IZU@03001Z]FZe00EZ]@03001Z]@0000AZ]@03001Z]FZe
009Z]@03001Z]@0000IZ]@03001^eVkF00=^eP03001^eVkF009^eP03001^eP0000E^eP03001^eP00
00=^eP03001^mVkf009^mP03001bmP0000=^mP03001bmW;f009bmP06001bmW;f001bmP0017<F00L0
07<FLaIc5P00LaH00003LaH00`00LaIc5P02LaH01@00McH007Lf000017Lf00<007LfMcH00WLf0P00
0WLg00D007MGMeMgE`0000=gE`04001gEgMG0004MeL01000NgMkM`000g]g00@007]gNgMkM`800005
NgL007^GNiL00003NiL01P00NiMkU`00NiL000=k]`06001k]`00001k]`000g^g00D007^h001kf000
009kf003001kf000009gf003001gf000009gf00@001gn000MoP007Oh001gn000LoP007?h001cn000
LoP200001Foh001_n000KoP00P0000=Wn00000000P0000=Fo@00E_d01EKm00<005Km00000P0000=F
o@00E_d01EKm00<005Km00000P0000=Fo@00E_d01EKm10000UKm00<005KmE_d00eKm0`001EKm00@0
05KmE_eFo@@000EFo@04001FoEKmE_d40005E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d0
000200000eKm001Fo@05E_d40002E_d00`00E_eFo@04E_d40002E_d01000Oomoo`00?Goo001YOol2
002gOol30003E_d00`00E_eFo@03E_d20006E_d01000E_eFoEKm0`001UKm00<005Km00000P0000=F
o@0000000P0000<160000AP00P0000<1600000000P000P4H0`0000<160001AP00PDH0`000PTH00<0
00dH00000PdH00D000dh3CP000dH008000064CP0014g000E>0000QDg0P0000PI=`006CLI=`006CL0
01eG100000<ME`0000000b5G00<0025G8EL00P000bEG00D002EG9EL002UG008000<YM`05000]Mbeg
;GL00003;GL20003;GL01@00<GHaMS5f0000135f0P000SFF00<003FF=IH00SFF00D003FF=IHeUP00
00<iUP03000iUSVF008iUP<0008iUP03000mUSfF008mUP03000m]Sff008m]P03000m]Sff008m]P03
000m]Sff008m]P030011]T6f0091]P030011]T6f00=1]P030011]T6f0091]P030011]T6f00=1]P03
0015]DFe0095]@030015eDGE00=5e@030015eDGE0095e@030015eDGE00=5e@030019eDWE00=9e@03
0019eDWE00=9e@030019eDWE00=9e@030019eDWE00=9e@03001=mDge009=m@<000A=m@03001=mDge
00A=m@03001=mDge00==m@03001=mDge00==m@03001AmE7e009Am@03001Am@0000IAm@03001AmE7e
00AAm@03001B5E8E00AB5@8000AB5@03001F5EHE00AF5@03001F5EHE00=F5@8000IF5@03001F5EHE
00AF5@04001F5EHE0004EQD00`00FSEJ=@04FSD01000FSEJ=@0015Xe00<005XeFSD01EXe0P001EXe
00<005heGSD015he0P001ehe00@005iEGUD000ANE@03001NEEiE00=NE@04001NEEiE0007GUD00`00
HUERE@05HUD00`00HWD00005HWD01000HWERM@001F9e00D0069eHWERM@0000ARM@05001VMFIeIWD0
0004IWD01000IYEVU@001FJE00<006JE00001fJE0P001VZE00<006ZeJ[D016Ze00@006ZeJ[D000AZ
]@03001Z]FZe009Z]@03001Z]@0000EZ]@03001^]@0000A^eP03001^eVkF00=^eP03001^eVkF00=^
eP07001^eVkFK]H006kF000016kf00L007;fL_IbmP00K_H00004L_H01`00L_IbmW;f001bmP0000Ac
5P03001c5W<F009c5P03001c5W<F009c5P03001c5W<F009c5P05001g=P00McH00003McH00`00McIg
=P02McH01P00McIg=P00McL0009gE`03001gEgMG009gE`03001gEgMG0080009gE`05001kMg]gNgL0
0003NgL01`00NgMkMg]g001kM`00009kU`05001kUg^GNiL00002NiL01000NiMkU`000W^g00D007^g
NkL007^g00<0000;NkL007^hNkP007_H001kf000NmP00002MmP05@00MmQgf000MmP007Oh001gn000
MoP007Oh001cn000LoP007?h001cn00200001Foh001_n000KoP00P0000=Wn00000001EKm00<005Km
E_d00eKm0P001EKm00@005KmE_eFo@@000EFo@03001FoEKm00<00003E_d005Km00AFo@03001Fo@00
0080009Fo@03001FoEKm00=Fo@@000=Fo@03001FoEKm00=Fo@@000=Fo@03001FoEKm00=Fo@8000EF
o@04001FoEKmE_d40005E_d00`00E_eFo@0300000eKm001Fo@04E_d00`00E_eFo@0300000eKm001F
o@04E_d01000Oomoo`00?7oo001YOol00`00Oomoo`2gOol00`00E_eFo@03E_d00`00E_d000020002
E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d20005E_d40000104H0000003h0P0000<0n000
0AP00P0000D160000000004H008000041AP000DH00022AP200001`dH000=60dH000=>000008=6005
000A>14h000A=`0200035CL300036CL400027EL00`007ELME`0200028EL010008ELQEb5G0P000REG
00H002EG9ELUE`00:EL20003:GL01@00;GL]Mbeg00000beg0P000Reg00D0035f<GHaMP0000@aMP03
000aMP0000<000<eUP05000eUSFF=IH00004>IH01@00>IHiUSVF00000SVF10000cfF00<003ff?KH0
0Sff00<003ff?KH00cff00D003ff?KHm]P0000A1]P030011]T6f00=1]P030011]T6f0091]P030011
]T6f00=1]P030015]DFe0095]@030015eDGE00=5e@030015eDGE0095e@030015eDGE00=5e@030019
eDWE00A9e@030019eDWE0099e@030019eDWE00=9e@030019eDWE00A9e@@00003CMD004ge00E=m@03
001=mDge00==m@03001=mDge00==m@03001=mDge00==m@03001AmE7e0080009Am@03001AmE7e00AA
m@03001AmE7e00AAm@03001B5E8E00=B5@8000EB5@03001F5EHE00AF5@03001F5EHE009F5@03001F
5@0000MF5@03001F5EHE00AF5@8000EF5@03001J=EXe00EJ=@8000EJ=@03001J=EXe00EJ=@03001J
=EXe00EJ=@03001N=Ehe009N=@04001N=Ehe0007GSD20006GUD00`00GUENE@02GUD01000GUENE@00
1eiE00<0069EHUD01F9E00<0069e00001F9e00@0069eHWD000ERM@04001RMF9e0005HWD01000IWEV
M@001FIe00<006JE00001fJE0P001fJE00<006ZEJYD016ZE00<006ZE00001FZe00D006ZeJ[EZ]@00
009Z]@03001Z]FZe00AZ]@03001Z]FZe00AZ]@03001^]@0000=^eP03001^eVkF00A^eP03001^eVkF
00=^eP07001^eVkFK]H006kF000016kf00L007;fL_IbmP00K_H00004L_H00`00L_IbmP02L_H00`00
LaIc5P02LaH00`00LaIc5P03LaH00`00LaIc5P02LaH01@00LaIc5W<F00000gLf00<007LfMcH00WLf
00<007LfMcH00WLf00D007LfMcIg=P0000=gE`05001gEgMGMeL00002MeL01P00NeMkE`00MeL0009k
M`05001kMg]gNgL00003NgL00`00NgMkM`0200000g^G001kU`02NiL00`00NiL00002NiL01`00NkMk
]g^g001k]`00009k]`03001k]g^g00800004NkP007_H0002NmP00`00NmP00002MmP05P00MmP007OH
001gn000MoP007Oh001gn000LoP007?h001cn000LoP007?h0P0000=_n000KoP0100000=Wm`00E_d0
15Km00<005KmE_d00`0000=Fo@00E_d015Km10000eKm00<005KmE_d00eKm0`001EKm00@005KmE_eF
o@<000IFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@0000800003E_d005Km00EFo@03001F
o@0000800003E_d005Km00AFo@@000=Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm009Fo@<000EF
o@04001FoEKmE_d30002Ool00`00Oomoo`0iOol006Uoo`03001oogoo0;Qoo`04001FoEKmE_d30006
E_d00`00E_d000020002E_d00`00E_eFo@03E_d00`00E_d000020002E_d00`00E_eFo@02E_d40000
1@4H0000n0000?P00P0000@0n0000000n0@000030AP0004H00<000041AP000002AP300023AP20000
1`dh000=60dH000A>000008A=`08000E=aDg5CL001Dg000I=`<0008I=`04000MEaeG00037EL20002
8EL01@008ELQE`009EL00`000bEG00<002UG:EL00P000RUg00D002eg;GL]M`0000<]M`03000]MP00
008000<aMP03000aMS5f008aMP03000aMS5f008aMP80008eUP03000eUSFF008eUP05000iUSVF>IH0
0003>IH00`00>IHiUP03>IH400000cfF000m]P02?KH00`00?KHm]P03?KH00`00?KHm]P02?KH01@00
@KI1]T6f00001D6f00<0046f@KH00T6f00<0046f@KH00d6f00<004FeAKD00TFe00<004GEAMD00dGE
00<004GEAMD00TGE00<004GEAMD014GE00<004WEBMD00dWE00<004WEBMD00TWE00<004WEBMD00dWE
00<004WEBMD00dWE0P0014gE00<004geCOD014ge00<004geCOD00dge00<004geCOD00dge00<004ge
COD014ge0P001E7e00<0057eDOD00e7e00<0057eDOD0157e00<0058EDQD00U8E00<0057e00001E8E
00<005HEEQD015HE00D005HEEQEF5@00009F5@03001F5EHE00EF5@03001F5EHE00=F5@8000IF5@03
001J=EXe00EJ=@03001J=EXe00EJ=@03001J=EXe00AJ=@03001J=EXe00EJ=@05001N=EheGSD00003
GSD00`00GSEN=@05GSD00`00GUENE@05GUD01@00GUENEEiE00000eiE00<005iEGUD015iE0P00269E
00<0069eHWD01F9e0P001V9e00<0069e00001V9e00<006Ie00001fIe0P001fJE00<006JEIYD01VJE
00<006ZEJYD016ZE00<006ZE000016Ze00<006ZeJ[D00VZe00<006Ze00001fZe00<006ZeJ[D00fZe
00L006jeK[E^]@00K]H00006K]H00`00K]H00003K]H00`00K]I^eP03K]H00`00K_I^mP02K_H00`00
L_IbmP03L_H00`00L_IbmP02L_H00`00L_IbmP03L_H00`00LaIc5P02LaH00`00LaIc5P02LaH00`00
LaH00002LaH00`00LaIc5P02LaH01@00McIg=WLf000017Lf00D007LfMcIg=P0000Ag=P04001gEgMG
0004MeL01000MeMgE`000g]G00@007]gNgL000=kM`05001kMg]gNgL00002NgL00`00NiMkU`030000
1g^G001kUg^G001kU`0000=k]`06001k]g^g001k]`000g^g00<007_G00000`0000Akf000NmP0009g
f00?001gf7OH001gf000MoP007Oh001gn000MoP007?h00800005LoP007?h001cn00600001f_g0000
06Og001Sm`0000=Fo@@000EFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@0000800003E_d0
05Km00EFo@@0009Fo@03001FoEKm00AFo@8000EFo@03001FoEKm00=Fo@8000EFo@04001FoEKmE_d4
0005E_d00`00E_d000020002E_d00`00E_eFo@03E_d00`00E_d000020002E_d00`00E_eFo@03E_d0
0`00E_d0000200000eKm001Fo@05E_d40002E_d01000Oomoo`00>goo001XOol00`00Oomoo`2jOol3
0003E_d00`00E_eFo@03E_d20006E_d01000E_eFoEKm0`001UKm00<005KmE_d00UKm0P0000T16000
0000003h0000n0000?P00`000P3h00<0004H00000P000P4H00@000DH0005608000032AP000dH008=
60<0008=608000044CP0014g4CL200000aDg000E=`0300000aTg000I=`026CL010007ELME`000QeG
00D0025G000QE`0000<QE`03000UEbEG0080008UE`05000YEbUG000YE`030003;GL01@00;GL]Mbeg
00000bef0P000c5f00<0035f<GH00S5f00H0035f<GHaMP00=GH30004=IH01@00>IHiUSVF000013VF
00<003VF>IH00SVF00@003VF>IHiUP<0008m]P03000m]Sff00<m]P03000m]Sff008m]P030011]T6f
0091]P030011]T6f00=1]P030011]T6f0091]P030011]T6f0091]P030015]DFe00=5]@030015eDGE
00=5e@030015eDGE0095e@030015eDGE00=5e@030019eDWE00=9e@030019eDWE0099e@030019eDWE
00A9e@030019e@0000800003BMD004gE00A=e@03001=mDge00==m@03001=mDge00A=m@03001=mDge
009=m@03001=mDge00==m@8000IAm@03001AmE7e00AAm@03001AmE7e00=Am@03001B5E8E0080009A
m@03001B5E8E00=B5@03001F5EHE00AF5@04001F5EHE0004EQD00`00EQEF5@04EQD00`00EQEF5@02
EQD00`00EQD00007EQD00`00FSEJ=@04FSD00`00FSEJ=@05FSD00`00FSEJ=@03FSD20007FSD01@00
GSEN=Ehe00000ehe00<005heGSD01Ehe00<005iEGUD01EiE00@005iEGUD000ANE@03001NEEiE00=N
E@04001REF9E0007HUD00`00HWERM@05HWD00`00HWERM@06HWD20007HWD20007IWD00`00IYEVU@06
IYD00`00IYEVU@05IYD00`00IYD00004JYD01000JYEZU@0016Ze00<006ZeJ[D00VZe00<006Ze0000
1VZe00<006Ze000016Ze00L006jeK[E^]@00K]H00006K]H00`00K]H00003K]H00`00K]I^eP03K]H0
0`00K_I^mP02K_H00`00L_IbmP03L_H00`00L_IbmP02L_H00`00L_IbmP02L_H00`00LaH00003LaH0
0`00LaIc5P02LaH01P00LaIc5P00LaH000=c5P07001g=WLfMcH007Lf00000WLf00<007LfMcH00WLf
00T007LfMcIg=P00MeH007MG00000gMG00@007MGMeL000AkE`800003NgL007]g009kM`05001kMg]g
NgL00002NgL01000NiMkU`000W^G00@007^GNiL0009kU`04001k]g^g0002NkL01000NkMk]`000W^g
00L007_GNmL007_G001ke`04000047OH001gf7OH001gf000MoP007Oh001gn000MoP007?h200000E_
m`00KoL006oh00<00004IoL006?gHoL40002E_d00`00E_eFo@04E_d20005E_d01000E_eFoEKm1000
1EKm00<005KmE_d00`0000=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d015Km00<005KmE_d0
0`0000=Fo@00E_d015Km10000eKm00<005KmE_d00eKm0P001UKm00@005KmE_eFo@<000IFo@04001F
oEKmE_d30005E_d00`00E_eFo@0300000eKm001Fo@04E_d01000Oomoo`00>Woo001XOol00`00Oomo
o`2lOol00`00E_eFo@02E_d00`00E_d000020002E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03
E_d30002E_d01@000=L000000?P00P0000<0n0000?P01@000P3h0P0000<0n00000000P4H00@000DH
0005608000072AP000003AP000dH00000`dH0`000Q4g00<0014g00000P0000HE=`005CL001Tg0002
6CL200000aeG000ME`027EL010008EL000000b5G00D002EG9ELUE`00008UE`05000YEbUG:EL00002
:EL20003;GL01@00;GL]Mbeg00000bef0P000S5f00<0035f<GH00S5f00D0035f<GHaMP0000<eMP80
00<eUP03000iUSVF008iUP05000iUSVF>IH00004>IH00`00>IHiUP02>IH00`00?IH000030004?KH0
0`00?KHm]P02?KH00`00@KI1]P02@KH00`00@KI1]P03@KH00`00@KI1]P02@KH00`00@KI1]P03@KH0
0`00AKE5]@02AKD00`00AME5e@03AMD00`00AME5e@02AMD00`00AME5e@03AMD00`00BME9e@03BMD0
0`00BME9e@02BMD00`00BME9e@03BMD30004BMD00`00CME=e@03CMD00`00COE=m@03COD00`00COE=
m@04COD00`00COE=m@02COD01000COE=mDge0P0000==m@00DOD01E7e00<0057eDOD0157e00<0057e
DOD0157e0P001E7e00<0058EDQD00e8E00<005HEEQD015HE0P001EHE00<005HEEQD015HE00D005HE
EQEF5@00009F5@03001F5EHE00EF5@03001J=EXe00=J=@8000MJ=@03001J=EXe009J=@04001J=EXe
0006FSD01000GSEN=@0015he00<005heGSD015he0P001eiE00@005iEGUD000ENE@03001NEEiE009N
E@04001REF9E0006HUD20007HWD00`00HWERM@06HWD00`00HWERM@06HWD00`00IWEVM@06IWD00`00
IYEVU@05IYD00`00IYD00005IYD01000IYEVU@0016ZE00D006ZEJYEZU@00009Z]@03001Z]FZe00AZ
]@03001Z]FZe00EZ]@03001Z]@0000=Z]@03001^]Fje00=^]@03001^eVkF00A^eP07001^eVkFK]H0
06kF00001FkF00<006kf00000fkf00<007;fL_H00W;f00<007;f00000g;f00<007;fL_H00W;f00H0
07<FLaH007<F0004LaH00`00LaIc5P02LaH01@00LaIc5W<F000017Lf00H007LfMcH007Lf0003McH0
1@00McIg=WLf00000gMF00<007MGMeL00WMG00@007MGMeL000=kE`03001kMg]g0080009kM`05001k
Mg]gNgL00002NgL01000NiMkU`000g^G0P0000AkU`00NiL000=k]`03001k]`00009k]`04001k]g^g
0002NmL00`00NmL00002NmL01000NmL007OG400000Mcm`00LoL007?g001_m`0200000fog001_n003
00000fOg0000000200000eKm001Fo@04E_d00`00E_eFo@0300000eKm001Fo@04E_d40003E_d00`00
E_eFo@03E_d30005E_d00`00E_eFo@02E_d30005E_d01000E_eFoEKm10001EKm00<005Km00000P00
00=Fo@00E_d01EKm00<005Km00000P0000=Fo@00E_d01EKm10000UKm00<005KmE_d015Km10000UKm
00<005KmE_d00eKm0`001EKm00@005KmE_eFo@<0009oo`03001oogoo03Moo`00J7oo00<007ooOol0
_Goo00<005KmE_d010001EKm00<005Km00000P000UKm00<005KmE_d00eKm00<005Km00000P000UKm
100000H0e`000?P0003h00020?P20000103h000000000P3h0`000P3h00<0004H00000P000PDH00P0
00TH000960003AP000dH0P0000D=60003AL0014g00<000034CL00000008E=`04000E=`0000036CL3
00037EL00`008ELQE`0200028EL010009ELUEbEG0P0000<UE`00:EL00RUG00@002UG:ELYE`80008]
M`05000]Mbeg;GL00003;GH00`00;GH000020004<GH00`00<GHaMP02<GH01000=GHeMSEf0P000SFF
00<003VF>IH00SVF00D003VF>IHiUP0000DiUP05000iUSVF>IH00004?IH40002?KH01@00?KHm]Sff
0000146f00<0046f@KH00d6f00<0046f@KH00T6f00<0046f@KH00d6f00<004FeAKD00TFe00<004GE
AMD00dGE00<004GEAMD00TGE00<004GEAMD00dGE00<004WEBMD00dWE00<004WEBMD00dWE00<004WE
00000P0000=9e@00BMD01DWE00<004gECMD00TgE00<004geCOD00dge00<004geCOD014ge00<004ge
COD00dge0`000dge00<0057eDOD0157e00<0057eDOD0157e00<0057eDOD00e7e0P001U7e00<0058E
DQD00e8E00<005HEEQD00eHE0P001UHE00<005HEEQD015HE00@005HEEQD000AF5@03001F5EHE00AF
5@03001J=EXe009J=@04001J=EXe0006FSD01@00FSEJ=EXe00000eXe00<005XeFSD01EXe0P001Uhe
00<005heGSD00Uhe00@005heGSD000MNE@8000INE@05001NEEiEGUD00003HUD00`00HUERE@03HUD0
1000HUERE@001F9e00<0069e00001f9e00<0069eHWD01V9e00<006IeIWD01FIe0P001fJE00<006JE
00001FJE00@006JEIYD000=ZU@03001ZUFZE009ZU@03001Z]@0000MZ]@03001Z]FZe00AZ]@05001Z
]FZeJ[D00002J[D00`00K[E^]@03K[D00`00K]I^eP04K]H01`00K]I^eVkF001^eP0000A^eP07001^
mVkfK_H006kf00001G;f00H007;fL_H007;f0004L_H01`00LaIc5W<F001c5P0000Ac5P03001c5W<F
009c5P05001c5W<FLaH00003McH00`00McIg=P02McH00`00McIg=P02McH01@00McIg=WLf00000gMF
0P000WMG00@007MGMeL000AkE`08001kMg]g001kM`00NgL0009kM`05001kMg]gNgL00002NiL01000
NiMkU`000W^G0P0000EkU`00NkMk]`00009k]`03001k]`00009k]`06001keg_G001ke`000W_G00<0
07_G00000WOG00l007OGMmL007Og001gm`00MoL007Og001cm`00LoL00P0000Ecm`00LoL006og0080
0003KoL006oh00<00003IoL0000000EFo@04001FoEKmE_d40005E_d00`00E_d000020002E_d00`00
E_eFo@03E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d0000200000eKm001Fo@05E_d40002
E_d00`00E_eFo@04E_d20005E_d01000E_eFoEKm10001EKm00<005KmE_d00`0000=Fo@00E_d015Km
00<005KmE_d00`0000=Fo@00E_d015Km00<005Km00000P0000=Fo@00E_d01EKm10000UKm00@007oo
Ool003Uoo`00J7oo00<007ooOol0_Woo0P0015Km00<005KmE_d00UKm0`001EKm00<005KmE_d00UKm
0`001EKm00<001Xm6Sd00`0000<0n0000?P01@0000<0n0000?P00P0000@0n00000000080n0030001
6000008000856004000960002AP200001@dH000=5`003AP0100000DA=`004CLA=`00008E=`04000E
=aDg00036CL010006CL000000QeG00@0025G8ELQE`80008QE`04000UEbEG9EL200001BEG000YEbUG
00000bUG00<002UG00000P000beg00D002ef;GH]MP0000<]MP8000<aMP03000aMS5f008aMP06000e
MSEf=GH003FF10000cVF00<003VF>IH00SVF00<003VF>IH00SVF00<003VF>IH00SVF00D003fF?IHm
UP0000<mUPH00003?KH0046f0091]P030011]T6f00=1]P030011]T6f0091]P030011]T6f00=1]P03
0015]DFe0095]@030015eDGE00=5e@030015eDGE0095e@030015eDGE00=5e@030019eDWE00A9e@03
0019eDWE00@000A9e@030019eDWE00A9e@03001=eDgE009=e@03001=mDge00A=m@03001=mDge00==
m@03001=mDge009=m@8000I=m@03001AmE7e00=Am@03001AmE7e00AAm@03001AmE7e009Am@03001A
m@0000IAm@03001B5E8E00=B5@03001F5EHE009F5@03001F5@0000IF5@03001F5EHE00EF5@8000EF
5@03001F5EHE00AF5@05001J=EXeFSD00003FSD00`00FSEJ=@04FSD01000FSEJ=@0015Xe00<005Xe
FSD01EXe00<005heGSD01Ehe00D005heGSEN=@0000=N=@03001NEEiE00ENE@03001NEEiE00ENE@04
001NEEiE0005HUD00`00HUERE@02HUD01000HUERE@001F9e00<0069e00001V9e00<0069e00001V9e
0P001fIe00<006JE00001FJE00@006JEIYD000AVU@03001VUFJE009VU@04001ZUFZE0004JYD00`00
J[D00006J[D00`00J[D00005J[D01`00J[EZ]FZe001Z]@0000E^]@03001^e@0000A^eP03001^eVkF
00=^eP03001^eVkF00=^eP07001^mVkfK_H006kf000017;f00L007;fL_IbmP00L_H00004L_H00`00
LaIc5P02LaH00`00LaIc5P02LaH00`00LaIc5P02LaH01@00MaH007<F000017Lf00<007LfMcH00WLf
0P000WLf00D007LfMcIg=P0000=gEP06001gEWMF001gE`000WMG00D007]GNeMkE`00009kM`05001k
Mg]gNgL00003NgL01000NgMkM`000W^G00D007^GNiMkU`00009kU`03001k]`0000800004NkL007^g
0002NkL01000NkMk]`000W_G00L007_G001ke`00NmL00002MmL03`00MmMge`00MoL007Og001gm`00
MoL007?g001cm`0200001G?g001cm`00KoL0100000=_n00000001@001EKm10000eKm00<005KmE_d0
0eKm0P001UKm00@005KmE_eFo@<000EFo@04001FoEKmE_d40005E_d00`00E_eFo@0300000eKm001F
o@04E_d00`00E_eFo@0300000eKm001Fo@04E_d40003E_d00`00E_eFo@03E_d30005E_d00`00E_eF
o@02E_d30005E_d01000E_eFoEKm0`001EKm00<005KmE_d00`0000=Fo@00E_d015Km00@007ooOol0
03Qoo`00J7oo00<007ooOol0_Woo00<005KmE_d015Km00@005Km000000=Fo@03001FoEKm00=Fo@04
001Fo@000003E_d00`00E_eFo@02E_d40000104i0000003h0P0000<0n00000000P0000@0n0000000
m`8000040?P0003h0?P30000103h000560DH0`000PTH00<000dH3AP0100000H=5`004AL0014g0002
4CL00`005CL000035CL2000011Tg000I=aTg0P000QeG00D0025G8EL0025G00<000<UE`04000UE`00
0003:EL01000:ELYE`000bUG0P000beg00D002ef;GH]MP0000<]MP80008aMP03000aMS5f008aMP05
000eMSEf=GH00004=IH20002>IH00`00>IHiUP02>IH00`00>IHiUP02>IH00`00>IHiUP02>IH01@00
?IHmUSfF00001CfF00@003ff?KHm]PD00003@KH0046f00=1]P030011]T6f0091]P030011]T6f00=1
]P030015]DFe0095]@030015eDGE00=5e@030015eDGE0095e@030015eDGE00A5e@030019eDWE00H0
0099e@030019eDWE00A9e@030019eDWE00=9e@03001=eDgE009=e@03001=mDge00A=m@03001=mDge
00==m@03001=mDge00800003COD004ge00E=m@03001AmE7e00AAm@03001AmE7e00=Am@03001AmE7e
0080009Am@03001AmE7e00AAm@03001B5E8E00=B5@05001F5EHEEQD00002EQD00`00EQEF5@05EQD0
0`00EQEF5@04EQD00`00EQEF5@04EQD00`00EQEF5@04EQD01000FSEJ=@0015Xe00<005XeFSD01EXe
0P001EXe00<005XeFSD01EXe00<005heGSD01Ehe00D005heGSEN=@0000=N=@03001NEEiE00ENE@03
001NEEiE00ENE@04001NEEiE0005HUD01@00HUEREF9E00000f9E00<0069eHWD00V9e00@0069eHWD0
00IRM@03001RM@0000IRM@03001VM@0000EVM@04001VUFJE0005IYD01@00IYEVUFJE00000fJE00<0
06JEIYD00VJE00@006ZEJYD000EZU@03001Z]FZe00EZ]@03001Z]@0000AZ]@03001Z]FZe009Z]@03
001Z]@0000E^]@03001^e@0000=^eP03001^eVkF00A^eP03001^eVkF009^eP03001^mVkf00=^mP03
001bmW;f00=bmP03001bmW;f009bmP03001bmW;f009bmP03001c5W<F00=c5P03001c5W<F009c5P05
001c5W<FLaH00002MaH00`00LaH00003McH00`00McIg=P02McH01P00McIg=P00McH000=g=P05001g
EWMFMeH00003MeH01000MeMgE`000g]G00D007]gNgMkM`0000=kM`800003NgL007]g009kM`03001k
U`0000=kU`04001kUg^G0002NkL00`00NkMk]`02000017^g001k]`000W^g00H007_GNmL007_G0002
NmL01@00NmL007OG00000WOG00`007Og001gm`00MoL007Og001cm`00LoL200001G?g001cm`00KoL0
0P0000=_m`00KoP00P0000AWm`000000009SmP03001Fo@0000800003E_d005Km00EFo@03001Fo@00
00800003E_d005Km00EFo@@0009Fo@03001FoEKm00=Fo@@000=Fo@03001FoEKm00=Fo@<000EFo@04
001FoEKmE_d40005E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d0000200000eKm001Fo@05
E_d00`00E_d0000200000eKm001Fo@05E_d40002E_d00`00E_eFo@03E_d30005E_d01000E_eFoEKm
0`0000Aoo`00000003Ioo`00J7oo00<007ooOol0_goo00<005KmE_d00eKm0P001UKm00@005KmE_eF
o@<000IFo@04001Fo@000003E_d200000`4i0000n00300002@3h000000000?P0003g0000m`020000
103h0000003h0`0000@0n000000560<000032AP000000080008=5`05000=5`dG000A5`0200024CL2
000031Dg000E=aDg000I=`006CL001Tg000M=`<000<QE`04000QEb5G00039EL00`009ELUE`020002
:EL01@00:ELYEbUG00000bUG0P000Reg00D002ef;GH]MP0000<]MP06000aMP00000aMP00135f00D0
03Ef=GHeMP0000<eUP03000eUP0000<000<iUP03000iUSVF00<iUP05000iUSVF>IH00004?IH00`00
?IHmUP02?IH00`00?KHm]P02?KH01000?KHm]Sff1@000T6f00<0046f@KH00T6f00<0046f@KH00d6f
00<004FeAKD00TFe00<004GEAMD00dGE00<004GEAMD00TGE00<004GEAMD01P000dWE00<004WEBMD0
0TWE00<004WEBMD014WE00<004WEBMD00dWE00<004gECMD00dgE00<004geCOD00dge00<004geCOD0
14ge0P000dge00<004geCOD014ge00<0057eDOD0157e00<0057eDOD0157e0P001E7e00<0057eDOD0
0e7e00<0058EDQD00e8E00@005HEEQD000AF5@03001F5EHE00AF5@03001F5EHE00=F5@8000IF5@03
001F5EHE00EF5@8000EJ=@03001J=EXe00EJ=@03001J=EXe00EJ=@03001J=EXe00=J=@8000MN=@04
001N=Ehe0004GSD00`00GUENE@04GUD20008GUD20006HUD01000HUERE@001F9E00D0069eHWERM@00
00=RM@03001RMF9e009RM@04001RMF9e0005HWD01000IWEVM@001FIe00@006JEIYD000AVU@03001V
UFJE009VU@04001VUFJE0005IYD00`00JYD00006JYD00`00J[EZ]@04J[D01000J[EZ]@000fZe00<0
06ZeJ[D016Ze00<006jeK[D00fje00D006kEK]E^e@00009^eP03001^eVkF00=^eP03001^eP0000=^
eP03001^mVkf00=^mP03001bmW;f009bmP03001bmW;f00=bmP03001bmW;f009bmP03001c5W<F009c
5P03001c5P00009c5P03001c5W<F009c5P05001g5WLFMaH00004McH00`00McIg=P02McH01@00McIg
=WLf00000gLf00D007MFMeIgEP0000AgEP800003MeL007]G009kE`04001kMg]g0003NgL00`00NgMk
M`020002NgL01000NiMkU`000W^G00L007^GNiMkU`00NkL00003NkL02000NkL00000NkL007^g0003
NmL02@00NmL007_G001ke`00MmL00002MmL04000MoL007Og001gm`00MoL007?g001cm`00LoL007?g
0P0000=_m`000000100000=[m`0000000P000f?f0P001EKm00@005KmE_eFo@@000EFo@03001FoEKm
00<00003E_d005Km00AFo@03001Fo@000080009Fo@03001FoEKm00=Fo@03001Fo@000080009Fo@03
001FoEKm00=Fo@@0009Fo@03001FoEKm00AFo@8000EFo@03001FoEKm00=Fo@8000EFo@04001FoEKm
E_d40005E_d00`00E_eFo@0300000eKm001Fo@04E_d00`00E_d000020002E_d00`00E_eFo@03E_d4
0002E_d4000gOol006Qoo`04001oogooOol3002lOol00`00E_d000020002E_d00`00E_eFo@03E_d4
0003E_d00`00E_eFo@03E_d20006E_d200000`4i0000000300000`3h0000n00300001`3g0000m`00
0?P0003g008000050?P0003h0000m`0500001@TH000000dH00000PdG00<000dG00000Q4G00@0014g
4CLA=`<000<E=`04000I=`0000026CL010007CLM=`000b5G00@0025G8ELQE`80008UE`04000UE`00
9EL30003:EL02@00:ELYEbUG000YMP00;GL00003;GH01@00;GH]MRef00000c5f0P00135f00D003Ef
=GHeMP0000<eUP03000eUSFF008eUP80008iUP03000iUSVF00<iUP05000iUSVF>IH00004?IH00`00
?IHmUP03?IH01@00?KHm]Sff000013ff00@0046f@KI1]R0000=5e@030019eDWE00=9e@030019eDWE
00=9e@030019eDWE00=9e@030019eDWE00=9e@03001=eDgE00==e@03001=mDge00==m@03001=mDge
00==m@8000E=m@03001=mDge00==m@03001AmE7e00AAm@03001AmE7e00=Am@8000IAm@03001AmE7e
00AAm@03001B5E8E00=B5@8000EF5@03001F5EHE00AF5@03001F5EHE009F5@03001F5@0000MF5@03
001F5EHE00AF5@03001J=EXe00EJ=@03001J=EXe00AJ=@03001J=EXe00EJ=@03001J=EXe009J=@04
001J=EXe0007GSD20006GSD00`00GUENE@02GUD01000GUENE@001eiE00<0069EHUD01F9E00@0069E
HUD000ERE@04001RMF9e0004HWD00`00HWERM@02HWD01@00HWERMF9e0000169e00@006IeIWD000AV
M@03001VUFJE009VU@04001VUFJE0005IYD00`00IYD00007IYD20005JYD00`00J[D00005J[D01@00
J[EZ]FZe00000VZe00<006ZeJ[D016Ze00<006jeK[D00fje00L006kEK]E^e@00K]H00006K]H00`00
K]H00002K]H00`00K_I^mP03K_H00`00L_H00003L_H00`00L_IbmP02L_H00`00L_H00003L_H00`00
LaIc5P02LaH01P00LaIc5P00LaH000=c5P03001g5WLF009g5P03001g=WLf009g=P05001g=WLfMcH0
0004McH01000McIg=P0017MF00D007MFMeIgEP00009gE`80009kE`05001kMg]gNgL00003NgL02P00
NgMkM`00NiL007]g001kU`000g^G00@007^GNiL0009k]`04001k]g^g0002NkL00`00NkL000040000
17_G001ke`000W_G00D007_G001ge`00009ge`0:001gm`00MoL007Og001gm`00LoL200000g?g001c
m`0400000fog001_m`0200000f_g0000000200001V?f00000000E_d000EFo@@000=Fo@03001FoEKm
00=Fo@<000EFo@03001FoEKm009Fo@8000IFo@04001FoEKmE_d30006E_d00`00E_d0000200000eKm
001Fo@04E_d00`00E_eFo@0300000eKm001Fo@04E_d00`00E_eFo@0300000eKm001Fo@04E_d40003
E_d00`00E_eFo@03E_d30005E_d01000E_eFoEKm0`001UKm00<005Km00000P0000=Fo@00E_d015Km
00@007ooOol003Ioo`00Igoo00<007oo00000P00`7oo00<005KmE_d015Km00<005Km00000P000UKm
00<005KmE_d00eKm00<005Km00000P000UKm00<005KmE_d00eKm100000@1600000000080n080000:
0?L000000?L0003g0000n0000?L200000`3h0000n004000010DG000000TH0`000PdG0P0000@=5`00
4ALA5`8000044CL001Dg00035CL010006CLI=`000QTg00@001dg7CLM=`8000038EL0025G008QE`05
000QE`009EL000029EL00`009ELUE`020002:EL01@00:ELYEbUG00000RUf0P0012ef00D002ef;GH]
MP0000<aMP8000<aMP05000eMSEf=GH00004=IH01P00=IHeUSFF000iUP@000@iUP03000iUSVF008i
UP05000mUSfF?IH00005?IH00`00?KHm]P02?KH01@00?KHm]Sff00001D6f00<0046e@KD00T6e00<0
046e@KD00d6e00<004FeAKD00TFe00<004FeAKD00dFe00<004GEAMD00TGE00<004GEAMD00dGE00<0
04WEBMD014WE00<004WEBMD00TWE00<004WEBMD00dWE00<004WEBMD014WE00<004gECMD00TgE00<0
04geCOD00dge00@004geCOE=m@800003COD004ge00A=m@03001=mDge00==m@03001AmE7e00AAm@03
001AmE7e009Am@03001Am@0000IAm@03001AmE7e00AAm@03001B5E8E00=B5@03001F5EHE00AF5@03
001F5EHE00AF5@05001F5EHEEQD00003EQD00`00EQEF5@04EQD00`00EQEF5@03EQD20007FSD00`00
FSEJ=@03FSD20007FSD01@00FSEJ=EXe00000eXe00<005heGSD01Ehe00<005heGSD01Ehe00D005iE
GUENE@0000=NE@03001NEEiE00ENE@03001REF9E00IRE@8000IRE@04001RMF9e0004HWD01@00HWER
MF9e0000169e00D0069eHWERM@0000AVM@04001VMFIe0005IYD01000IYEVU@001VJE0P001fJE00<0
06ZEJYD016ZE00<006Ze000016Ze00<006ZeJ[D00VZe00<006Ze00001VZe00<006je00000fje00<0
06kEK]D00VkE00<006kF00001FkF00H006kFK]H006kF0006K_H00`00L_H00003L_H00`00L_IbmP02
L_H01P00L_IbmP00L_H000Ac5P03001c5W<F009c5P03001c5W<F009c5P07001g5WLFMaH007Lf0000
0WLf00<007LfMcH00WLf00T007LfMcIg=P00McH007Lf00000gMF00<007MFMeH00WMF00P007MGMeL0
07]g001kE`000W]g00D007]gNgMkM`00009kM`04001kUg^GNiL200001G^G001kUg^G00000W^G00@0
07^gNkL000=k]`03001k]`00009k]`03001k]`00009ke`@00006NmL007_G001ge`000WOG00X007Og
001gm`00MoL007Og001cm`H00003KoL006og00800004KoL00000JoL60005E_d00`00E_d000020002
E_d00`00E_eFo@03E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d0000200000eKm001Fo@05
E_d40002E_d00`00E_eFo@04E_d20005E_d01000E_eFoEKm10001EKm00@005KmE_eFo@@000EFo@03
001Fo@0000800003E_d005Km00EFo@03001Fo@0000800003E_d005Km00EFo@@0009Fo@03001FoEKm
00AFo@8000EFo@03001FoEKm009Fo@800003Ool007oo03Eoo`00Igoo0P00a7oo00<005KmE_d00eKm
0P001UKm00@005KmE_eFo@<000IFo@03001Fo@000080009Fo@06000160000AP0003h1@0000@0m`00
0?L0m`@00080m`D00080m`0400055`001?L200000`TG000=5`023AL300024AL01P004AL0014g000E
=`8000035CL001Tg008I=`03000I=`0000<M=`05000M=`008EL000038EL010008EL000000REG00@0
02EG9ELUE`80008YE`05000YEbUG:EL00002:GH20003;GH01@00;GH]MRef00000c5f00H0035f0000
035f0004=GH01@00=IHeUSFF00000cFF00<003VF>IH00SVF0`000SVF00<003VF>IH00SVF00D003fF
?IHmUP0000DmUP03000m]Sff008m]P03000m]Sff008m]P030011]T6f0091]P030011]D6e0091]@03
0011]D6e00=1]@030015]DFe0095]@030015]DFe00=5]@030015eDGE0095e@030015eDGE00A5e@03
0019eDWE00=9e@030019eDWE0099e@030019eDWE00=9e@030019eDWE00A9e@03001=eDgE009=e@03
001=mDge00A=m@<000==m@03001=mDge00==m@03001=mDge00A=m@03001AmE7e00=Am@03001AmE7e
0080009Am@03001AmE7e00AAm@03001AmE7e00AAm@03001B5E8E009B5@8000IF5@03001F5EHE00AF
5@04001F5EHE0004EQD00`00EQEF5@04EQD00`00EQEF5@02EQD00`00FQD00007FSD00`00FSEJ=@02
FSD01000FSEJ=@001UXe00@005XeFSD000AJ=@03001N=Ehe00EN=@03001N=Ehe00EN=@05001NEEiE
GUD00003GUD00`00GUENE@04GUD20008HUD00`00HUERE@05HUD00`00HWD00006HWD01000HWERM@00
1F9e00@0069eHWD000AVM@04001VMFIe0005IYD00`00IYD00007IYD00`00IYEVU@06IYD00`00JYEZ
U@03JYD01000J[EZ]@000fZe00<006ZeJ[D00fZe00<006Ze00001VZe00<006je00000fje00<006kE
K]D00fkE00<006kFK]H016kF00@006kFK]I^eP8000E^mP07001bmW;fL_H007;f000017;f00L007;f
L_IbmP00L_H00004LaH00`00LaIc5P02LaH01@00LaIc5W<F000017LF00H007LfMcH007Lf0003McH0
1@00McIg=WLf00000gLf00<007MFMeH00WMF00D007MFMeIgEP00009gE`05001kMg]gNgL00003NgL0
1@00NgMkMg]g00000W]g00H007^GNiMkU`00NiL300001g^G001kUg^G001k]`0000=k]`03001k]`00
009k]`03001k]`0000=ke`04001ke`00NmLB00001G?g001cm`00LoL00P0000A_m`00001_m`800003
JoL0000000<00003HoH005Km00AFo@8000IFo@04001FoEKmE_d30005E_d01000E_eFoEKm10001EKm
00<005KmE_d00`0000=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d015Km10000eKm00<005Km
E_d00eKm10000UKm00<005KmE_d015Km0P001EKm00@005KmE_eFo@@000EFo@03001FoEKm00<00003
E_d005Km00AFo@03001FoEKm00<00003E_d005Km00AFo@03001Fo@0000800005E_d007ooOol0000e
Ool006Moo`03001oogoo0<Aoo`03001Fo@000080009Fo@03001FoEKm00=Fo@@000=Fo@03001FoEKm
00=Fo@8000IFo@04000160000AP200000`3g0000000200000`3g000000080000103h000000000P3g
00@000DG0004m`8000072AL000003AL000dG00000a4G00X0014G000001Dg000E5`005CL0008I=`80
00036CL001dg008M=`04000M=`0000038EL00`008ELQE`0200000bEG000UE`029EL01@009EL002UG
00000bUG00@002Uf:GHYMP80008]MP05000]MRef;GH00003<GH01000<GHaMS5f0`000cEf00D003FF
=IHeUP0000@eUP05000iUSVF>IH00002>IH40003>IH00`00?IHmUP02?IH00`00?IHmUP02?IH00`00
?KHm]P02?KH00`00?KHm]P02?KH00`00@KI1]P03@KH00`00@KE1]@02@KD00`00@KE1]@03@KD00`00
AKE5]@02AKD00`00AKE5]@03AKD00`00AME5e@02AMD00`00AME5e@03AMD00`00BME9e@03BMD00`00
BME9e@02BMD00`00BME9e@04BMD00`00BME9e@03BMD00`00CME=e@02CMD00`00COE=m@03COD20006
COD00`00COE=m@03COD00`00COE=m@03COD00`00DOEAm@04DOD20005DOD00`00DOEAm@03DOD00`00
DOEAm@04DOD01`00DQEB5E8E001B5@0000IF5@03001F5EHE00EF5@8000EF5@03001F5EHE00AF5@05
001F5EHEEQD00003FQD00`00FSEJ=@04FSD01@00FSEJ=EXe00000eXe00<005XeFSD01EXe0P001EXe
00<005heGSD015he0P001ehe00@005iEGUD000ANE@03001NEEiE00=NE@04001NEEiE0007HUD00`00
HUERE@06HUD20006HWD00`00HWD00006HWD00`00HWD00005IWD00`00IWD00007IYD20007IYD00`00
IYEVU@05IYD00`00JYD00004JYD01@00J[EZ]FZe00000VZe00<006ZeJ[D016Ze00<006ZeJ[D016Ze
00D006jeK[E^]@00009^]@03001^eFkE00=^e@03001^eVkF00=^eP03001^eVkF009^eP03001^mVkf
00A^mP07001bmW;fL_H007;f000017;f00<007;fL_H00W;f00<007<FLaH00W<F00<007<FLaH00W<F
00D007<F001c5P0000Ag5P03001g=WLf009g=P03001g=WLf009g=P05001g=WLfMcH00003McH20002
MeH00`00MeIgEP02MeH01000MeMgE`000g]g00@007]gNgL000=kM`04001kMg]g0003NiL01000NiMk
U`000W^G00@007^GNiL0009k]`04001k]g^g0002NkL00`00NkL00002NkL01P00NmMke`00NmL0009k
e`05001ke`00MmL00002MoL02P00MoL007Og001gm`00MoL007?g0P0000=cm`00LoL00P0000A_m`00
001_m`800004JoL00000IoH30002HoH00`00E_d0000200000eKm001Fo@05E_d40002E_d00`00E_eF
o@03E_d40003E_d00`00E_eFo@03E_d30005E_d01000E_eFoEKm10001EKm00<005Km00000P0000=F
o@00E_d01EKm00<005Km00000P0000=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d015Km1000
0eKm00<005KmE_d00eKm0`001EKm00@005KmE_eFo@@000EFo@04001FoEKmE_d30005E_d01000Oomo
o`00=7oo001WOol00`00Oomoo`35Ool20005E_d00`00E_d000020002E_d00`00E_eFo@03E_d00`00
E_d000020002E_d00`00E_eFo@03E_d200001P4H0000003g0000m`<000030?L0003G00D00080m`<0
00070?L0003g0?L000DG00000PCg00P000TG00095`003AL000dG0P0000DA5`004ALA5`00008E=`04
000E5`0000036CL300037CL010007CLM=`000b5G00D0025G8ELQE`00008UE`04000UEbEG00029EL2
0003:EL01P00:GHYMRUf000]MP<000@]MP05000aMS5f<GH00004<GH20002=GH00`00=IHeUP02=IH0
1@00=IHeUSFF00000cVF00<003VF>IH00cVF0P000SVF00<003fF?IH00SfF00<003fF?IH00cfF00D0
03ff?KHm]P0000@m]P030011]T6f00=1]P030011]D6e0091]@030011]D6e00=1]@030015]DFe0095
]@030015]DFe00=5]@030015eDGE0095e@030015eDGE00=5e@030019eDWE00=9e@030019eDWE00=9
e@030019eDWE00=9e@030019eDWE00=9e@03001=eDgE00==e@03001=m@0000800003COD004ge00E=
m@03001=mDge00==m@03001=mDge00==m@03001AmE7e00=Am@8000IAm@03001AmE7e00AAm@03001A
mE7e00=Am@04001B5E8E0003DQD00`00EQEF5@04EQD00`00EQEF5@04EQD00`00EQEF5@04EQD00`00
EQEF5@04EQD01000EQEF5@0015XE00<005XeFSD015Xe00@005XeFSD000AJ=@03001J=EXe00EJ=@03
001J=EXe00EJ=@03001N=Ehe009N=@04001N=Ehe0007GSD20006GUD00`00GUENE@02GUD01000GUEN
E@001V9E0P00269E00<0069eHWD01F9e00<0069e00001V9e00<0069e00001VIe0P001fJE00<006JE
IYD01FJE00<006JE00001FJE00@006ZEJYD000=ZU@03001Z]FZe009Z]@03001Z]@0000MZ]@03001Z
]FZe00AZ]@07001^]FjeK[D006je00001FkE00<006kE00000fkF00<006kFK]H00fkF00<006kfK_H0
0fkf00<007;fL_H00g;f00<007;fL_H00W;f00<007;fL_H00g;f00<007<FLaH00W<F00<007<FLaH0
0W<F00D007<F001c5P0000Ag5P03001g=WLf009g=P80009g=P05001g=WLfMcH00003McH01P00MeIg
EP00MeH000=gEP04001gEgMG0003NgL01@00NgL007]g00000g]g00<007]g000017^G00<007^G0000
0g^G0P0000AkU`00NkL000=k]`03001k]`00009k]`03001k]`00009ke`03001ke`00009ke`05001k
e`00MmL00002MoL02P00MoL007Og001gm`00MoL007?g0P0000=cm`00LoL00P0000=_m`00KoL01@00
00AWmP000000009SmP@000EFo@03001FoEKm00<00003E_d005Km00AFo@03001Fo@000080009Fo@03
001FoEKm00=Fo@03001Fo@0000800003E_d005Km00EFo@@0009Fo@03001FoEKm00AFo@8000EFo@04
001FoEKmE_d40005E_d01000E_eFoEKm10001EKm00<005Km00000P0000=Fo@00E_d01EKm00<005Km
00000P0000=Fo@00E_d01EKm10000UKm00<005KmE_d015Km10000UKm00<005KmE_d00eKm0P0000=o
o`00Ool0<goo001WOol00`00Oomoo`37Ool00`00E_eFo@02E_d30005E_d01000E_eFoEKm0`001UKm
00<005Km00000P0000]Fo@000000003g0000m`000?L0003g00L000040?L000000?L300001`3g0000
m`3g00055`000084m`0400095`002AL200001PdG000=5`004AL0008A5`03000E=`00008E5`07000I
=aTg6CL001Tg00000adg00@001dg7CLM=`80008QE`03000QEb5G008000039EL002EG008UE`03000U
EbEG008000<YE`04000YMRUf0003;GH20003;GH01@00<GHaMS5f0000135f00<0035f00000P0013FF
00D003FF=IHeUP0000@iUP03000iUSVF008iUP03000iUP0000<000<mUP03000mUSfF00<mUP03000m
]Sff008m]P05000m]Sff?KH00005@KH00`00@KE1]@02@KD00`00@KE1]@03@KD00`00AKE5]@02AKD0
0`00AKE5]@03AKD00`00AME5e@02AMD00`00AME5e@03AMD00`00BME9e@04BMD00`00BME9e@02BMD0
0`00BME9e@03BMD00`00BME9e@03BMD00`00CME=e@02CMD30004COD00`00COE=m@04COD00`00COE=
m@03COD00`00COE=m@03COD00`00DOEAm@02DOD00`00DOD00006DOD00`00DOEAm@04DOD00`00DOEA
m@04DOD20004DQD00`00EQEF5@04EQD00`00EQEF5@03EQD20006EQD00`00EQEF5@05EQD20005FQD0
0`00FSEJ=@05FSD20005FSD00`00FSEJ=@05FSD00`00FSEJ=@05FSD01@00GSEN=Ehe00000ehe00<0
05heGSD01Ehe00<005iEGUD01EiE00D005iEGUENE@0000=NE@03001REF9E00=RE@04001REF9E0007
HUD00`00HWERM@06HWD00`00HWERM@06HWD00`00IWEVM@05IWD00`00IYEVU@06IYD00`00IYEVU@05
IYD00`00IYD00005IYD01000JYEZU@000fZE00<006ZeJ[D00VZe00<006Ze00001VZe00<006Ze0000
16Ze00<006jeK[D00Vje00<006je00001FkE00<006kE00000fkF00<006kFK]H00VkF00<006kF0000
0fkf00<007;fL_H017;f00<007;fL_H00W;f00<007;fL_H00W;f00<007<F00000g<F00D007<FLaIc
5P0000=c5P03001g5WLF009g5P03001g=WLf009g=P06001g=WLf001g=P000gLf00D007LfMcIg=P00
00=gEP03001gEWMF009gEP04001gEgMG0003NgL00`00NgMkM`020002NgL01000NgMkM`000g^G00@0
07^GNiL0009kU`03001kUg^G00800005NkL007^gNkL00002NkL01@00NkL007^g00000g_G00T007_G
001ke`00NmL007OG00000WOg00X007Og001gm`00MoL007Og001cm`800005LoL007?g001_m`020000
1Vog000006_g001[m`P0009Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm009Fo@8000IFo@04001F
oEKmE_d30005E_d00`00E_eFo@0300000eKm001Fo@04E_d00`00E_eFo@0300000eKm001Fo@04E_d4
0003E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d20005E_d01000E_eFoEKm10001EKm00<0
05KmE_d00`0000=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d015Km00<005Km00000P0000EF
o@00Oomoo`0003=oo`001goo10003Woo0`003goo10003Woo0`003Goo1P0057oo00<007ooOol0b7oo
00@005Km000000=Fo@03001FoEKm009Fo@@000=Fo@03001FoEKm00=Fo@8000EFo@<000050?L0003g
0000m`0500000`3G0000m`0200001P3g0000003g0000m`8000040?L0000000021?L00`002AL00002
2AL01@003AL=5`003AL00P000Q4G0P0000@E=`005ALE5`8000046CL001Tg6CL200027CL020007CLM
=`007CL0025G00038EL300039EL010009ELUEbEG0P000RUG00D002Uf:GHYMP0000<]MP80008]MP05
000aMS5f<GH00004<GH01000<GHaMS5f0P000cFF00D003FF=IHeUP0000@iUP03000iUSVF008iUP03
000iUSVF008iUP80008mUP03000mUSfF00<mUP03000m]Sff008m]P03000m]Sff008m]P030011]T6f
0091]P030011]D6e0091]@030011]D6e00=1]@030015]DFe0095]@030015]DFe00=5]@030015eDGE
0095e@030015eDGE00A5e@030019eDWE00=9e@030019eDWE0099e@030019eDWE00=9e@030019eDWE
00A9e@@00003CMD004ge00E=m@03001=mDge00==m@03001=mDge00==m@03001=mDge00==m@03001A
mE7e0080009Am@03001AmE7e00AAm@03001AmE7e00AAm@03001AmE7e00=Am@8000EB5@03001F5EHE
00AF5@03001F5EHE009F5@03001F5@0000MF5@03001F5EHE00AF5@03001J5EXE00AJ5@03001J=EXe
00EJ=@03001J=EXe00EJ=@03001J=EXe00=J=@8000MJ=@05001N=EheGSD00003GSD00`00GSEN=@05
GSD00`00GUENE@05GUD01000GUENE@001EiE00<0069EHUD00V9E00@0069EHUD000IRE@8000QRM@03
001RMF9e00IRM@03001VMFIe00EVM@03001VUFJE00EVU@03001VU@0000EVU@04001VUFJE0004IYD0
0`00JYEZU@02JYD01000JYEZU@001FZe00<006ZeJ[D01FZe00<006Ze00000fZe00<006jeK[D016je
00<006kEK]D00fkE00L006kEK]E^e@00K]H00005K]H00`00K]H00003K_H00`00L_IbmP03L_H00`00
L_H00003L_H00`00L_IbmP02L_H01P00LaIc5P00LaH000Ac5P05001c5W<FLaH00004MaH00`00McIg
=P02McH01@00McIg=WLf00000gLf00D007LfMcIg=P0000AgEP80009gEP04001gEgMG0003NgL02`00
NgMkMg]g001kM`00NgL007]g00000g^G00@007^GNiL0009kU`06001kUg^GNiL007^g0`0000Ak]`00
NkL0009k]`03001k]`00009ke`03001ke`00009ke`07001ke`00MmL007Og00000WOg00/007Og0000
07Og001cm`00LoL007?g00800003KoL0000000800004JoL00000JoL400000f?f00000002E_d01@00
E_eFo@00E_d00`0000=Fo@00E_d01EKm00<005Km00000P0000=Fo@00E_d01EKm10000UKm00<005Km
E_d00eKm0`001EKm00@005KmE_eFo@@000EFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@00
00800003E_d005Km00EFo@03001Fo@0000800003E_d005Km00AFo@@000=Fo@03001FoEKm00=Fo@<0
00EFo@03001FoEKm009Fo@<000EFo@04001FoEKmE_d30005E_d01000Oomoo`00<Woo0005Ool8000;
Ool5000<Ool8000<Ool3000;Ool:000AOol00`00Oomoo`3:Ool00`00E_eFo@04E_d01000E_d00000
0eKm00<005KmE_d00UKm00<005Km00000P000UKm00<005KmE_d00eKm0`0000<0m`0000000P0000@0
e`000=L00080e`@000040?L000000?L400000`3g000000031?L00`002AL000022AL300023AL01000
4ALA5a4G0`000QDG00/001DG000I=`006CL001Tg000M=`0000<M=`04000M=`0000038EL010008EL0
00000REG00H002EG9ELUE`00:EH30003:GH01P00;GH]MRef000]MP<000@aMP03000aMS5f008aMP04
000aMS5f<GH20002=IH00`00=IHeUP02=IH01@00>IHiUSVF00001CVF00H003VF>IHiUP00>IH40004
?IH00`00?KHm]P02?KH00`00?KHm]P02?KH00`00@KI1]P03@KH00`00@KE1]@02@KD00`00@KE1]@03
@KD01@00AKE5]DFe00001TFe00<004GEAMD00TGE00<004GEAMD00dGE00<004WEBMD00dWE00<004WE
BMD00TWE00<004WEBMD00dWE00<004WEBMD00dWE0P0014gE00<004geCOD014ge00<004geCOD00dge
00<004geCOD014ge00<004geCOD00dge0P001E7e00<0057eDOD00e7e00<0057eDOD0157e00<0057e
DOD00U7e00<0057e00001U8E00<005HEEQD00eHE00D005HEEQEF5@0000=F5@03001F5EHE00AF5@03
001F5EHE00=F5@8000MJ5@03001J=EXe00AJ=@03001J=EXe00EJ=@03001J=EXe009J=@04001J=EXe
0006FSD01000GSEN=@0015he00<005heGSD015he0P001eiE00@005iEGUD000ENE@05001REF9EHUD0
0003HUD00`00HUERE@03HUD01000HWERM@001V9e0P001f9e0P001VIe00<006Ie00001VJE00<006JE
00001FJE00D006JEIYEVU@0000=VU@03001ZUFZE009ZU@03001ZU@0000IZ]@03001Z]FZe00AZ]@05
001Z]FZeJ[D00002J[D00`00K[E^]@04K[D00`00K]E^e@03K]D01`00K]E^eFkE001^eP0000E^eP06
001^eVkF001^mP001W;f00H007;fL_H007;f0004L_H01`00LaIc5W<F001c5P0000=c5P07001c5W<F
LaH007LF00000WLF00<007LfMcH00WLf00<007LfMcH00WLf00@007LfMcH000Ag=P05001gEWMFMeH0
0002MeH00`00MeH00002MeL01@00NgMkMg]g00000W]g00@007]gNgMkM`800003NgL007^G009kU`03
001kU`0000=kU`04001kUg^G0002NkL00`00NkMk]`04000017^g001k]`000g_G00T007_G001ke`00
NmL007OG00000WOg00X007Og001gm`00MoL007Og001cm`800003LoL0000000800003KoL006og00<0
0003JoL0000000@0009SmP03001FoEKm00@000EFo@04001FoEKmE_d40005E_d00`00E_eFo@030000
0eKm001Fo@04E_d00`00E_d000020002E_d00`00E_eFo@03E_d40002E_d00`00E_eFo@04E_d20005
E_d00`00E_eFo@03E_d20005E_d01000E_eFoEKm10001EKm00<005Km00000P0000=Fo@00E_d01EKm
00<005Km00000P0000=Fo@00E_d01EKm00<005Km00000P0000=Fo@00E_d01EKm10000UKm00<005Km
E_d00eKm0P0000=oo`00Ool0<Goo0005Ool20004Ool2000;Ool5000<Ool20004Ool2000=Ool2000;
Ool30005Ool3000@Ool00`00Oomoo`3;Ool00`00E_eFo@03E_d20006E_d00`00E_eFo@040005E_d0
1000E_eFoEKm1P0000L0e`000=L0003G0000e`0700001@3g0000m`000?L0100000@0m`000004m`<0
00895`040008m`0000023AL01P004ALA5`004AL000<E5`04000E5`0000026CL010006CL000000adg
00<001dg7CL00P000R5G00<0025G8EL00P000REG00D002EG9ELUE`00008YEP80008YMP05000]MRef
;GH00003;GH20003<GH00`00<GHaMP02<GH01P00<GHaMS5f000eMP@000<eUP05000iUSVF>IH00005
>IH01@00>IHiUSVF000013VF10000SfF00D003ff?KHm]P0000@m]P030011]T6f00=1]P030011]D6e
0091]@030011]D6e00=1]@030015]DFe0095]@030015]DFe00=5]@030015eDGE0095e@030015eDGE
00=5e@030019eDWE00=9e@030019eDWE0099e@030019eDWE00A9e@030019e@0000800003BMD004gE
00A=e@03001=mDge00==m@03001=mDge00A=m@03001=mDge00==m@03001=mDge009=m@8000IAm@03
001AmE7e00AAm@03001AmE7e00=Am@03001AmE7e0080009Am@03001B5E8E00AB5@03001F5EHE00=F
5@04001F5EHE0004EQD00`00EQEF5@04EQD00`00EQEF5@02EQD00`00EQD00007FQD00`00FSEJ=@03
FSD20007FSD01@00FSEJ=EXe00000eXe00<005XeFSD01EXe0P001Uhe00<005heGSD00Uhe00@005iE
GUD000MNE@8000INE@04001REF9E0005HUD00`00HUERE@02HUD01000HWERM@001F9e00@0069eHWD0
00ERM@04001VMFIe0005IWD00`00IWD00005IYD01000IYEVU@0016JE00<006JEIYD00VJE00@006JE
IYD000EZU@03001ZU@0000EZ]@03001Z]@0000EZ]@07001Z]FZeJ[D006Ze00001Vje00<006kE0000
0fkE00<006kEK]D00fkE00<006kFK]H00fkF00L006kFK]I^eP00K_H00005L_H01`00L_IbmW;f001b
mP0000AbmP03001c5W<F009c5P05001c5W<FLaH00004LaH01P00MaIg5P00MaH000Ag=P09001g=WLf
McH007Lf001g=P0000=g=P03001gEWMF009gEP05001gEWMFMeH00002MeL01@00NgMkMg]g00000g]g
00H007]gNgMkM`00NgL20002NiL01000NiMkU`000W^G00L007^GNiMkU`00NkL00003NkL01000NkL0
07^g0P0000Mk]`00NmMke`00NmL00002NmL01`00NmL007OG001gm`00009gm`07001gm`00001gm`00
LoL0100000=_m`00KoL00P0000E_m`00000006_g00<00003HoH0000000=SmPD00003E_d005Km00AF
o@@000=Fo@03001FoEKm00=Fo@<000EFo@04001FoEKmE_d30006E_d00`00E_d0000200000eKm001F
o@04E_d00`00E_eFo@0300000eKm001Fo@04E_d00`00E_eFo@0300000eKm001Fo@04E_d40003E_d0
0`00E_eFo@03E_d20005E_d01000E_eFoEKm10001EKm00@005KmE_eFo@@000EFo@03001FoEKm00<0
0003E_d005Km00AFo@03001Fo@0000800005E_d007ooOol0000aOol000Aoo`8000Ioo`8000Yoo`D0
00]oo`8000Ioo`8000aoo`<001=oo`80011oo`03001oogoo0<aoo`03001Fo@000080009Fo@03001F
oEKm00=Fo@<000AFo@03001FoEKm009Fo@T000070=H0003G0000e`000=L00P0000<0e`0000000`00
0P3g00`0003g0000m`000?L0003g0000m`001?L200032AL01@002?L000003AL00P0000DA5`004ALA
5`00008E5`04000E5aDG00026CL00`006CLI=`0200027CL010007CLM=adg0P000R5G00L0025G000U
E`009EL000039EL01000:EHYERUF0P000RUf00D002ef;GH]MP0000<]MP80008aMP03000aMS5f008a
MP05000aMS5f<GH00004=GH20002=IH00`00>IHiUP02>IH00`00>IHiUP02>IH00`00>IHiUP02>IH0
1@00>IHiUSVF00000cfF10000Sff00<003ff?KH00Sff00<0046f@KH00d6f00<0046e@KD00T6e00<0
046e@KD00d6e00<004FeAKD00TFe00<004FeAKD00dFe00<004GEAMD00TGE00<004GEAMD00dGE00<0
04WEBMD00dWE00<004WEBMD00dWE00<004WEBMD01@0014WE00<004gECMD00dgE00<004geCOD00dge
00<004geCOD014ge00<004geCOD00dge00<004geCOD00P0000==m@00DOD01E7e00<0057eDOD0157e
00<0057eDOD0157e0P001E7e00<0058EDQD00e8E00<005HEEQD015HE0P001EHE00<005HEEQD015HE
00D005HEEQEF5@0000=F5@03001J5EXE00AJ5@03001J=EXe009J=@04001J=EXe0006FSD01@00FSEJ
=EXe00000eXe00<005XeFSD01EXe00<005heGSD01Ehe00<005heGSD00Uhe00@005iEGUD000MNE@03
001NEEiE00ENE@04001REF9E0005HUD01@00HUEREF9E00000f9e00<0069eHWD00f9e00@0069eHWD0
00ERM@04001VMFIe0004IWD01@00IWEVMFIe000016JE00D006JEIYEVU@00009VU@03001VUFJE00=V
U@03001VU@0000MZU@03001Z]FZe00AZ]@03001Z]@0000AZ]@03001Z]FZe009Z]@03001Z]@0000I^
]@03001^e@0000=^e@03001^eFkE00=^e@03001^eVkF00=^eP03001^eVkF009^eP03001bmW;f00Ab
mP03001bmW;f009bmP03001bmW;f009bmP03001c5W<F00=c5P05001c5W<FLaH00003LaH00`00MaIg
5P02MaH00`00McIg=P02McH00`00McIg=P02McH01000McIg=P0017Lf00D007MFMeIgEP0000AgEP80
0003MeL007]g009kM`04001kMg]g0003NgL02P00NgMkM`00NiL007^G001kU`000g^G00@007^GNiL0
009k]`06001k]g^g001k]`000W^g00<007_G00001P0000Qke`00NmL007OG001gm`000WOg00<007Og
00001@0000=cm`00LoL00P0000A_m`00001_m`<00004JoL00000IoH300001V?f00000000E_d0009F
o@05001FoEKm001Fo@030002E_d00`00E_eFo@03E_d00`00E_d0000200000eKm001Fo@05E_d40002
E_d00`00E_eFo@04E_d20005E_d01000E_eFoEKm10001EKm00@005KmE_eFo@@000EFo@03001Fo@00
00800003E_d005Km00EFo@03001Fo@0000800003E_d005Km00AFo@@000=Fo@03001FoEKm00=Fo@@0
00=Fo@03001FoEKm00=Fo@<000EFo@04001FoEKmE_d30005E_d01000Oomoo`00<7oo0004Ool20006
Ool2000;Ool3000<Ool20006Ool2000<Ool3000DOol2000?Ool00`00Oomoo`3=Ool00`00E_eFo@04
E_d00`00E_d000020002E_d00`00E_eFo@03E_d00`00E_d000050003E_d300001@3F0000e`000=L0
0P0000<0e`000=L00`0000<0e`0000000`000P3g00H0003g0000m`000?L200001@Cg000000TG0000
0PSg00<000dG3AL00P0000<A5`004AL00P0000<E5`005AL00QDG00<001Tg00000aTg0P000Qdg00P0
01dg7CL001dg000QE`000R5G00@002EG000000<UE`09000YERUF:EH002UF000YMP0000<]MP06000]
MRef;GH002ef0`001C5f00D0035f<GHaMP0000<eMP03000eMP00008000@iUP03000iUSVF008iUP03
000iUSVF008iUP05000iUSVF>IH00005?IH00`00?IH000030003?KH00`00@KI1]P03@KH00`00@KE1
]@02@KD00`00@KE1]@03@KD00`00AKE5]@02AKD00`00AKE5]@03AKD00`00AME5e@02AMD00`00AME5
e@03AMD00`00BME9e@04BMD00`00BME9e@050003BMD00`00BME9e@04BMD00`00CME=e@02CMD00`00
COE=m@04COD00`00COE=m@03COD00`00COE=m@04COD20003COD00`00DOEAm@04DOD00`00DOEAm@04
DOD00`00DOEAm@03DOD20006DOD00`00DQEB5@03DQD00`00EQEF5@04EQD00`00EQEF5@04EQD00`00
EQEF5@04EQD01000EQEF5@0015HE00<005XEFQD015XE00D005XeFSEJ=@0000=J=@03001J=EXe00AJ
=@04001J=EXe0004FSD00`00FSEJ=@05FSD00`00GSEN=@05GSD01@00GSEN=Ehe00000eiE00<005iE
GUD01EiE00<005iEGUD01UiE0P001V9E00@0069EHUD000ERM@05001RMF9eHWD00003HWD00`00HWER
M@02HWD01@00IWEVMFIe000016Ie00D006IeIWEVM@0000=VU@03001VUFJE009VU@04001VUFJE0006
IYD20007JYD00`00J[EZ]@03J[D01@00J[EZ]FZe00000fZe00<006ZeJ[D00fZe00<006jeK[D016je
00D006kEK]E^e@00009^e@03001^eFkE009^e@03001^e@0000=^eP03001^eVkF00=^eP03001bmW;f
00=bmP03001bmW;f00=bmP05001bmW;fL_H00005LaH01@00LaH007<F000017<F00<007LFMaH00WLF
00<007LfMcH00WLf00D007LfMcIg=P0000=g=P80009g=P03001gEWMF009gEP05001gEWMFMeH00002
NeH20002NgL01000NgMkM`0017]g00<007]g00000g^G0P0000EkU`00NiMkU`00009kU`04001k]g^g
0002NkL01P00NkMk]`00NkL0009ke`07001keg_G001ke`00NmL0300000Egm`00LoL007?g00800004
LoL00000KoL200000fog0000000300000fOf000000040005E_d00`00E_eFo@040006E_d01000E_eF
oEKm0`001EKm00<005KmE_d00`0000=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d015Km1000
0eKm00<005KmE_d00eKm10000UKm00<005KmE_d015Km0P001EKm00@005KmE_eFo@@000EFo@03001F
o@000080009Fo@03001FoEKm00=Fo@03001Fo@0000800003E_d005Km00EFo@03001Fo@0000800003
E_d005Km00EFo@@0009Fo@03001FoEKm00=Fo@800003Ool007oo02moo`000goo0P0027oo0P0067oo
0P0027oo0P0037oo0P0057oo0P003goo00<007ooOol0cWoo00<005KmE_d00eKm0P001UKm00@005Km
E_eFo@D000AFo@05001FoEKm0000UP0200000`3F0000e`0400001@3G0000e`000=L00P0000<0e`00
00000P000P3g10000P3g00L000Cg0004m`002AL000022?L010003AL000dG0P000Q4G0P0000@E5`00
5ALE5`8000096CL001Tg6CL001Tg000M=`0000<M=`04000M=`0000028EL00`009ELUE`0200039EL0
1000:EHYEP000RUF0P000bef00D002ef;GH]MP0000<]MP8000@aMP05000aMS5f<GH00003=GH01000
=GHeMSEf0P000cVF00<003VF>IH00cVF00D003VF>IHiUP0000@iUP03000mUSfF008mUP03000mUSfF
008mUP@00003?KH0046f00A1]P050011]D6e@KD00005@KD00`00AKE5]@02AKD00`00AKE5]@03AKD0
0`00AME5e@02AMD00`00AME5e@04AMD00`00BME9e@060002BMD00`00BME9e@03BMD00`00BME9e@04
BMD00`00CME=e@02CMD00`00COE=m@04COD00`00COE=m@03COD00`00COE=m@03COD20005COD00`00
DOEAm@03DOD00`00DOEAm@04DOD00`00DOEAm@02DOD00`00DOD00006DOD00`00DQEB5@04DQD00`00
EQEF5@02EQD20006EQD00`00EQEF5@05EQD20005EQD00`00FQEJ5@04FQD01000FSEJ=@0015Xe00<0
05XeFSD01EXe0P001UXe00<005XeFSD00eXe0P001ehe00@005heGSD000ANE@03001NEEiE00ANE@80
00QNE@03001REF9E00ERE@04001REF9E0005HWD01@00HWERMF9e0000169e00D0069eHWERM@0000AV
M@04001VMFIe0004IWD01@00IYEVUFJE000016JE00<006JE00001fJE00<006ZEJYD01FZE00<006ZE
000016Ze00D006ZeJ[EZ]@0000=Z]@03001Z]FZe00=Z]@03001^]Fje00A^]@07001^eFkEK]D006kE
00001FkE00<006kE00000fkF00<006kFK]H00VkF00<007;f00000g;f00<007;fL_H00g;f00<007;f
00000W;f00<007<FLaH00g<F00D007<F001c5P0000=c5P03001g5WLF009g5P03001g=P00009g=P03
001g=WLf009g=P04001g=WLf0002McH00`00McH00003MeH01@00MeIgEWMF00000g]F00D007]f001k
M`00009kM`05001kMg]gNgL00002NgL01`00NiMkUg^G001kU`00009kU`07001kUg^GNiL007^g0000
0g^g00<007^g00000W^g00<007_G00000W_G00<007_G00000W_G00L007_G001ge`00MoL00002MoL0
1`00MoL00000LoL007?g00800006LoL00000KoL006og0`0000=[mP00IoH01@0000=SmP0000001EKm
1@0000=Fo@00E_d01EKm10000UKm00<005KmE_d00eKm0`001EKm00@005KmE_eFo@@000EFo@03001F
o@0000800003E_d005Km00EFo@03001Fo@0000800003E_d005Km00AFo@03001FoEKm00<00003E_d0
05Km00AFo@@000=Fo@03001FoEKm00=Fo@8000IFo@04001FoEKmE_d30005E_d01000E_eFoEKm1000
1EKm00<005KmE_d00`0000=Fo@00E_d015Km00<005Km00000P0000EFo@00Oomoo`0002moo`000goo
0P0027oo0P0067oo0P0027oo0P0037oo0`004goo0P003goo00<007ooOol00P00cGoo00<005Km0000
0P000UKm00<005KmE_d00eKm20001EKm0`0000=Fo@0009H02@0000<0e`000=L00P0000<0e`000=L0
0`000P3g00<0003g00000P000P3g00@000Cg0004m`800088m`03000=5`00008=5`05000A5a4G000A
5`0200035AL300036CL010006CL000000adg00<001dg7CL00P0000<QE`009EL00REG0P000REG00D0
02UF:EHYEP00008YEP8000<]MP05000]MRef;GH00003;GH20003<GH01@00<GHaMS5f000013Ef00@0
03Ef=GHeMP80008iUP03000iUSVF00<iUP05000iUSVF>IH00004>IH00`00?IHmUP02?IH00`00?IHm
UP02?IH01000?KDm]Cfe2`0000=1]@00@KD0146e00D004FeAKE5]@0000I5]@030015eDGE0095e@03
0015eDGE00H000=9e@030019eDWE0099e@030019eDWE00A9e@030019eDWE00=9e@03001=eDgE009=
e@03001=mDge00A=m@03001=mDge00==m@04001=mDgeCOD200000dge001=m@04COD00`00DOEAm@04
DOD00`00DOEAm@03DOD00`00DOEAm@020002DOD00`00DOEAm@04DOD00`00DQEB5@04DQD01`00EQEF
5EHE001F5@0000MF5@03001F5EHE00AF5@03001F5EHE00AF5@03001J5EXE00EJ5@8000EJ=@03001J
=EXe00EJ=@03001J=EXe00EJ=@03001J=EXe009J=@04001J=EXe0006GSD01000GSEN=@001EiE00<0
05iEGUD00UiE00@005iEGUD000MNE@03001REF9E00IRE@8000IRM@04001RMF9e0005HWD01000HWER
M@001FIe00@006IeIWD000EVM@03001VU@0000IVU@8000MVU@03001ZUFZE00EZU@03001ZU@0000=Z
]@03001Z]FZe00=Z]@03001Z]@0000EZ]@03001Z]@0000A^]@03001^eFkE009^e@03001^e@0000E^
e@06001^eFkE001^eP001FkF00<007;f00000g;f00<007;fL_H00g;f00D007;f001bmP0000Ec5P05
001c5W<FLaH00004LaH00`00MaIg5P02MaH01P00McIg=P00McH000=g=P05001g=WLfMcH00003McH0
0`00MeIgEP02MeH01@00MeIgEWMF00000W]F00D007]fNgIkMP00009kM`05001kMg]gNgL00002NgL0
1@00NiMkUg^G00000W^G0P0000EkU`00NiMkU`00009k]`06001k]g^g001k]`000W^g00<007_G0000
0W_G00`007_GNmL007_G001ke`00MmL007Og0002MoL01`00MoL00000LoL007?g00800003LoL006og
00800004KoL00000JoH200000fOf000000050002HoL00`00E_d0000200001EKm001FoEKm00000UKm
00<005KmE_d00`0000=Fo@00E_d015Km00<005Km00000P000UKm00<005KmE_d00eKm10000UKm00<0
05KmE_d015Km0P001EKm00@005KmE_eFo@@000EFo@04001FoEKmE_d40005E_d00`00E_d000020000
0eKm001Fo@05E_d00`00E_d0000200000eKm001Fo@05E_d40002E_d00`00E_eFo@03E_d40003E_d0
0`00E_eFo@03E_d30005E_d01000E_eFoEKm0`001EKm00@007ooOol002ioo`000goo0P0027oo0P00
67oo0P0027oo0P003Goo0P004goo0P003Woo1000d7oo00<005KmE_d015Km00<005Km00000P0000AF
o@00000000AFo@03001Fo@000080009Fo@<0000309H0002f00L00080e`8000070=L0003G0000e`00
0=L00P0000D0m`000000m`000080m`<00084m`070008m`Sg2?L000dG00000PdG00<0014G00000Q4G
00L001DG5ALE5`005AL000036CL00`006CLI=`0200027CL01@007CLM=adg00000R5G00D002EG9EL0
02EG00<000<YEP04000YERUF:EH20002;GH01@00;GH]MRef00000bef00H0035f0000035f0004<GH0
1@00=GHeMSEf00000cEf00<003FF00000`0013VF00<003VF>IH00SVF00D003VF>IHiUP0000DmUP05
000mUSfF?IH00004?KD00`00@KE1]@03@KD01000@KE1]D6e2`0000A5]@00AKE5]@/000=5e@030019
eDWE00=9e@030019eDWE00=9e@030019eDWE00=9e@030019eDWE00=9e@03001=eDgE00==e@03001=
mDge00==m@03001=mDge00A=m@<000==m@03001=mDge00==m@03001AmE7e00AAm@03001AmE7e00AA
m@8000EAm@03001AmE7e00=Am@03001B5E8E00AB5@04001F5EHE0003EQD00`00EQEF5@04EQD00`00
EQEF5@03EQD20007EQD00`00FQEJ5@04FQD00`00FSEJ=@05FSD00`00FSEJ=@04FSD00`00FSEJ=@05
FSD01@00FSEJ=EXe00000eXe00<005heGSD01Ehe0P001UiE00<005iEGUD00UiE00@005iEGUD000IN
E@8000QRE@03001RMF9e00ERM@03001RM@0000IRM@03001RM@0000IVM@03001VM@0000IVM@03001V
U@0000IVU@03001VUFJE00EVU@03001ZU@0000EZU@04001ZUFZE0003J[D00`00J[EZ]@03J[D00`00
J[D00005J[D00`00J[D00004K[D00`00K]E^e@03K]D00`00K]E^e@03K]D01`00K]E^eFkE001^eP00
00E^eP06001bmW;f001bmP001G;f00H007;fL_H007;f0005LaH01@00LaIc5W<F000017<F00D007LF
MaIg5P0000Ag=P03001g=WLf009g=P04001g=WLf0004McH20002MeH01@00MeIgEWMF00000g]F00@0
07]fNgIkMP800003NgL007]g009kM`04001kMg]g0002NiL01000NiMkU`000W^G0`0000AkU`00NkL0
009k]`06001k]g^g001k]`000W_G00h007_GNmL007_G001ke`00NmL007OG001gm`000WOg00@007Og
001gm`800005LoL007?g001cm`0500001F_f00000000IoH01`000f?g0P001EKm00D005KmE_d005Km
00<000EFo@04001FoEKmE_d30006E_d00`00E_d0000200000eKm001Fo@04E_d00`00E_eFo@030000
0eKm001Fo@04E_d40003E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d20005E_d01000E_eF
oEKm10001EKm00<005KmE_d00`0000=Fo@00E_d015Km00<005Km00000P0000=Fo@00E_d01EKm00<0
05Km00000P0000=Fo@00E_d01EKm10000UKm00<005KmE_d00eKm0P0000=oo`00Ool0;Goo0003Ool2
0008Ool2000HOol20008Ool2000=Ool2000COol2000>Ool00`00Oomoo`3BOol00`00E_eFo@03E_d2
00001UKm00000000E_d000EFo@8000IFo@03000J?@00008000030;H0000000<000030=L0000000@0
0080e`050000e`000000e`040000103g0000003g0`000PCg0P0000@8m`000000008=5`8000044AL0
014G4AL2000011DG000E5aDG0P0000<I=`006CL00QTg0P000Qdg00<001dg7CL00P0000<QE`009EL0
0REG00<002EG9EL00P000RUF00H002UF:EHYEP00:EH30003;GH01@00;GH]MRef00000c5f0`000c5f
00D003Ef=GHeMP0000<eMP03000eUSFF008eUP<0008iUP03000iUSVF008iUP05000iUSVF>IH00005
?IH00`00?IHmUP02?IH01@00?KDm]Cfe00001D6e00<0046e@KD00T6e00<0046e@KD00d6e00@004Fe
AKE5]@@000=5]@030015]DFe0095]@030015eDGE00=5e@030019eDWE00A9e@030019eDWE0099e@03
0019eDWE00=9e@030019eDWE00=9e@03001=eDgE00==e@03001=mDge00==m@03001=mDge00==m@80
00I=m@03001=mDge009=m@03001AmE7e00AAm@03001AmE7e00=Am@8000IAm@03001AmE7e00AAm@03
001B5E8E00AB5@8000AF5@03001F5EHE00AF5@03001F5EHE009F5@03001F5@0000MF5@03001J5EXE
00=J5@8000MJ=@03001J=EXe00=J=@8000MJ=@05001J=EXeFSD00003FSD00`00GSEN=@05GSD00`00
GUENE@05GUD01@00GUENEEiE00000eiE00<005iEGUD00eiE00@0069EHUD000MRE@03001RMF9e00IR
M@8000MRM@8000MVM@8000MVM@03001VUFJE00EVU@03001VUFJE00EVU@03001ZU@0000EZU@05001Z
UFZEJYD00002J[D00`00J[EZ]@04J[D00`00J[EZ]@04J[D00`00J[D00003K[D00`00K]E^e@04K]D0
0`00K]E^e@03K]D01`00K]E^eFkE001^eP0000A^eP07001bmW;fL_H007;f00001G;f00D007;fL_Ib
mP0000Ec5P07001c5W<FLaH007<F00000W<F00<007LFMaH00WLF00<007LfMcH00WLf00<007LfMcH0
0WLf00@007LfMcH000=g=P06001gEWMF001gEP000gMF00@007]FNeH000=kMP03001kMW]f0080009k
M`04001kMg]g0003NiL01000NiMkU`000W^G00<007^GNiL00P0000Mk]`00NkMk]`00NkL00002NkL0
0`00NmL00002NmL00`00NmL00002NmL04000NmL007OG001gm`00MoL007Og001gm`00LoL007?g0P00
00Icm`00001_mP00KoH400000fOf0000000500001V?g00000000E_d000EFo@03001Fo@000080009F
o@03001FoEKm00=Fo@@0009Fo@03001FoEKm00AFo@8000EFo@04001FoEKmE_d40005E_d00`00E_d0
000200000eKm001Fo@05E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d0000200000eKm001F
o@04E_d40003E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@02E_d20005E_d01000E_eFoEKm1000
1EKm00<005KmE_d00`0000=Fo@00E_d015Km00<005Km00000P0000EFo@00Oomoo`0002eoo`000goo
0P0027oo0P0067oo0P0027oo0P003Goo0`004Goo0P003goo00<007ooOol0dgoo00<005Km00001@00
1EKm00<005Km00000P000UKm00<005KmE_d00eKm0`0000@160000000]P<000040=L000000;H50002
0=L200000`3G0000e`0300000`3g0000e`020000203g0004m`Cg0004m`002?L200033AL300024AL0
2`004AL001DG000E5`005AL001Tg00000QTg00D001dg000M=`0000<M=`<000<UE`04000UEbEG9EL2
0002:EH01000:EHYEP000bUF0P000bef00D002ef;GH]MP0000@aMP80008aMP05000eMSEf=GH00004
=GH01@00=IHeUSFF00000SVF10000cVF00<003VF>IH00SVF00<003fF?IH00SfF00<003fF?IH00SfF
00<003fe?KD00Sfe00<0046e@KD00d6e00D0046e@KE1]@0000E1]@030015]DFe0095]@030015]DFe
00=5]@030015]DFe0095]@030015eDGE00A5e@030019eDWE00=9e@030019eDWE0099e@030019eDWE
00=9e@030019eDWE00A9e@03001=eDgE009=e@03001=mDge00A=m@03001=m@0000800003COD004ge
00E=m@03001=mDge009=m@03001AmE7e00AAm@03001AmE7e009Am@03001Am@0000IAm@03001AmE7e
00AAm@03001B5E8E00=B5@8000EF5@03001F5EHE00AF5@05001F5EHEEQD00003EQD00`00EQEF5@04
EQD00`00FQEJ5@02FQD00`00FQD00007FSD00`00FSEJ=@02FSD01000FSEJ=@001UXe00@005XeFSD0
00AJ=@03001N=Ehe00EN=@03001NEEiE00ENE@04001NEEiE0004GUD00`00GUENE@03GUD01000HUER
E@001V9E0P00269e00<0069eHWD01V9e00<006IeIWD01VIe00<006IeIWD01VIe00<006JEIYD016JE
00<006JE00001FJE00@006ZEJYD000AZU@03001ZUFZE009ZU@03001Z]@0000MZ]@03001Z]FZe00=Z
]@05001Z]FZeJ[D00002K[D00`00K]E^e@03K]D00`00K]D00003K]D00`00K]E^e@03K]D00`00K]I^
eP03K]H00`00L_IbmP02L_H00`00L_IbmP03L_H00`00L_IbmP02L_H00`00LaIc5P02LaH00`00LaIc
5P02LaH01P00LaIc5P00LaH000=g5P03001g=WLf009g=P03001g=P00009g=P04001g=WLf0004McH0
1@00MeIgEWMF00000gMF00D007]FNeIkEP0000=kMP08001kMW]f001kMP00NgL0009kM`04001kUg^G
0002NiL01000NiMkU`000g^G00H007^g000007^g0002NkL00`00NkL00002NmL00`00NmL00002NmL0
2@00NmL007_G001ge`00MoL00002MoL01000MoL007Og0P0000=cm`0000000P0000A_mP00001_mP@0
0003IoH0000000L000EFo@04001FoEKmE_d30003E_d01@00E_eFo@00E_d00`0000=Fo@00E_d015Km
00<005KmE_d00`0000=Fo@00E_d015Km10000eKm00<005KmE_d00eKm0P001EKm00<005KmE_d00eKm
0P001EKm00@005KmE_eFo@@000EFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@0000800003
E_d005Km00EFo@03001Fo@0000800003E_d005Km00AFo@@000=Fo@03001FoEKm00=Fo@<000EFo@04
001FoEKmE_d30005E_d01000Oomoo`00;7oo0003Ool20008Ool2000HOol20008Ool2000>Ool20009
Ool20005Ool3000?Ool00`00Oomoo`3DOol40003E_d01000E_eFoEKm0`001UKm00<005Km00000P00
0UKm0P0000@160000;H0]PH000030;H0000000800080e`040000e`0000020=L00`000=L000020000
1@3G0000003g00000PCg00D000Cg000000Sg008000043AL000dG00034AL010004AL000000QDG00@0
01DG000000<I=`04000M=`0000037CL010008CL000000REG00T002EG9ELUE`009EH002UF00000bUF
00@002UF:EHYEP80008]MP05000]MRef;GH00004<GH00`00<GH000020004=GH01@00=GHeMSEf0000
0cFF00<003VF>IH00cVF0P000SVF00<003VF>IH00SVF00<003fF?IH00SfF00<003fF?IH00SfF00<0
03fe?KD00Sfe00<0046e@KD00d6e00<0046e@KD00T6e00<0046e@KD00d6e00D004FeAKE5]@0000I5
]@030015]DFe0095]@030015eDGE00=5e@030019eDWE00=9e@030019eDWE0099e@030019eDWE00=9
e@030019eDWE00A9e@03001=eDgE009=e@03001=mDge00==m@<000A=m@03001=mDge00A=m@03001=
mDge00==m@03001AmE7e00=Am@03001AmE7e0080009Am@03001AmE7e00AAm@03001AmE7e00AAm@03
001B5E8E009B5@03001F5@0000IF5@03001F5EHE00=F5@04001F5EHE0004EQD00`00EQEF5@04EQD0
1@00FQEJ5EXE00000eXE00<005XeFSD015Xe00D005XeFSEJ=@0000=J=@03001J=EXe00EJ=@8000IJ
=@03001N=Ehe00=N=@8000MNE@04001NEEiE0005GUD01@00GUENEEiE00000f9E00<0069EHUD00f9E
00@0069EHUD000MRM@03001RMF9e00IRM@03001VMFIe00IVM@03001VMFIe00EVM@8000IVU@03001V
U@0000EVU@05001ZUFZEJYD00002JYD00`00JYEZU@03JYD00`00J[D00006J[D00`00J[D00004J[D0
1`00J[EZ]FZe001^]@0000I^e@03001^e@0000=^e@03001^eFkE00=^e@03001^eVkF009^eP03001b
mW;f00=bmP03001bmW;f009bmP03001bmW;f009bmP03001bmP0000=c5P05001c5W<FLaH00004LaH0
0`00MaIg5P02MaH00`00McIg=P02McH01P00McIg=P00McH0009g=P05001g=WLfMcH00004MeH01000
MeIgEP000g]F00D007]fNgIkMP00009kMP05001kMW]fNgH00002NgL01@00NiMkUg^G00000W^G00@0
07^GNiL0009kU`05001k]g^g001k]`05000017^g001ke`000W_G00<007_G00000W_G00`007_G001g
e`00MoL007Og001gm`00MoL400000g?f001_mP0300000fof0000000<0006E_d40002E_d01@00E_eF
oEKm00000UKm0P001EKm00@005KmE_eFo@@000EFo@03001Fo@0000800003E_d005Km00EFo@03001F
o@0000800003E_d005Km00AFo@03001FoEKm00<00003E_d005Km00AFo@@000=Fo@03001FoEKm00=F
o@8000EFo@04001FoEKmE_d40005E_d01000E_eFoEKm10001EKm00<005Km00000P0000=Fo@00E_d0
1EKm00<005Km00000P0000=Fo@00E_d01EKm10000UKm00<005KmE_d00eKm0P0000=oo`00Ool0:goo
0003Ool20008Ool2000HOol20008Ool2000>Ool20009Ool9000@Ool00`00Oomoo`3BOol300000goo
001Fo@03E_d40003E_d00`00E_eFo@03E_d20006E_d200000`4H0000000300001`2f000000000;H0
002g00<000030=L0000000800080e`8000060=L000000=L0003g0P0000`4m`001?L4m`002?L000Sg
000=5`003AL200001A4G000A5a4G00000QDG00@001DG5AL000<I=`03000M=adg0080008M=`03000Q
=b4g0080008UE`04000UEbEG00029EH20003:EH02@00:EHYERUF000]EP00;GH00003;GH00`00<GHa
MP02<GH01000<GHaMS5f0P000cEf00D003Ef=GHeMP0000@eUP03000iUSVF008iUP03000iUP0000<0
00<iUP03000mUSfF008mUP03000mUSfF008mUP03000m]Cfe008m]@030011]D6e00=1]@030011]D6e
0091]@030011]D6e00=1]@030015]DFe0095]@030015]DFe00=5]@030015]DFe0095]@030015eDGE
00=5e@030019eDWE00=9e@030019eDWE0099e@030019eDWE00A9e@030019eDWE00=9e@03001=eDgE
009=e@04001=mDgeCOD200000dgE001=m@05COD00`00COE=m@03COD00`00COE=m@03COD00`00DOEA
m@04DOD20005DOD00`00DOEAm@03DOD00`00DOEAm@04DOD01@00DQEB5E8E00000UHE00<005HEEQD0
15HE00<005HEEQD015HE0P001EHE00<005HEEQD015HE00@005XEFQD000AJ5@03001J=EXe00AJ=@04
001J=EXe0004FSD00`00FSEJ=@05FSD00`00FSEJ=@05FSD00`00GSEN=@02GSD01000GSEN=@001eiE
0P001UiE00D005iEGUENE@0000=RE@03001REF9E00=RE@04001REF9E0006HWD20007HWD20007IWD2
0007IWD00`00IYD00004IYD01000IYEVU@0016JE00<006ZEJYD00VZE00@006ZEJYD000IZU@03001Z
]FZe00EZ]@03001Z]@0000=Z]@03001Z]FZe009Z]@03001^]@0000E^e@07001^eFkEK]D006kE0000
1FkE00<006kE00000fkF00<007;fL_H00W;f00<007;f00000g;f00<007;fL_H00W;f00H007;fL_H0
07<F0004LaH00`00LaIc5P02LaH00`00MaIg5P02MaH01@00McIg=WLf000017Lf00D007LfMcIg=P00
00=g=P09001gEWMFMeH007]F001gEP0000=kEP05001kMW]fNgH00002NgH01000NgIkMW]f0P0000Ek
M`00NiMkU`00009kU`04001kUg^G0003NiL00`00NkL00002NkL01@00NkMk]`00NkL0100000ake`00
NmMke`00NmL007_G001ge`00MoL700000g?f001cmP0200001Fof00000000KoH00`0000=WmP000000
1`000VOg00<005KmE_d00`0000=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d015Km10000eKm
00<005KmE_d00eKm0P001EKm00@005KmE_eFo@@000EFo@04001FoEKmE_d40005E_d00`00E_d00002
00000eKm001Fo@05E_d00`00E_d0000200000eKm001Fo@04E_d40003E_d00`00E_eFo@03E_d40003
E_d00`00E_eFo@03E_d20005E_d01000E_eFoEKm10001EKm00<005KmE_d00`0000=Fo@00E_d015Km
00<005Km00000P0000EFo@00Oomoo`0002]oo`000goo0P0027oo0P0067oo0P0027oo0P003goo0P00
27oo0P0000=oo`0000000`004Goo00<007ooOol0cgoo0`001Goo00@005Km000000=Fo@03001FoEKm
009Fo@03001Fo@000080009Fo@03001FoEKm00=Fo@@000030=L00000008000030;H000000080]P<0
00030;H0000000<00080e`050000e`000=L000020=L01P000?L000001?L00084m`040008m`002?L2
00001PdG000=5`004AL0008A5`03000E5`0000<E5`04000I=aTg00037CL200027CL01`008CL0024g
000UE`0000<UE`03000UEREF0080008YEP05000YERUF:EH00002;EH20004;GH01@00<GHaMS5f0000
135f0P000SEf00<003Ef=GH00SEf00D003FF=IHeUP0000@iUP03000iUSVF008iUP80008iUP03000m
USfF008mUP03000mUSfF00<mUP05000m]Cfe?KD00005@KD00`00@KE1]@02@KD00`00@KE1]@03@KD0
0`00AKE5]@02AKD00`00AKE5]@03AKD00`00AKE5]@02AKD00`00AME5e@03AMD00`00BME9e@03BMD0
0`00BME9e@03BMD00`00BME9e@03BMD00`00BME9e@03BMD00`00CME=e@03CMD30003CMD00`00COE=
m@04COD00`00COE=m@03COD00`00COE=m@03COD00`00DOEAm@03DOD20006DOD00`00DOEAm@04DOD0
0`00DOEAm@03DOD01000DQEB5@0015HE00<005HEEQD00eHE00<005HEEQD015HE00<005HEEQD015HE
00<005HEEQD01EHE0P001EXE00<005XeFSD01EXe0P001EXe00<005XeFSD01EXe00<005XeFSD01EXe
00D005heGSEN=@0000=N=@03001NEEiE00ENE@03001NEEiE00ENE@04001NEEiE0005HUD01@00HUER
EF9E00000f9E00<0069eHWD00f9e00@0069eHWD000IRM@03001RM@0000IVM@03001VM@0000EVM@04
001VUFJE0004IYD01@00IYEVUFJE00000VJE00<006ZEJYD00fZE00<006ZE00001fZE00<006ZeJ[D0
16Ze00@006ZeJ[D000=Z]@03001Z]FZe00=Z]@03001^eFkE00A^e@07001^eFkEK]D006kE00001FkE
00<006kE00000VkF00<007;fL_H00g;f00H007;fL_H007;f0004L_H01`00L_IbmW;f001c5P0000=c
5P03001c5W<F009c5P03001g5P00009g5P03001g=WLf009g=P03001g=WLf009g=P04001g=WLf0003
McH00`00MeIgEP02MeH00`00NeIkEP020002NeH01@00NgIkMW]f00000W]f00D007]fNgIkMP00009k
MP04001kUg^G0003NiL00`00NiL00003NiL01P00NkMk]`00NkL0009k]`07001k]g^g001ke`00NmL0
3@0000Egm`00MoL007Og00800004LoH00000KoH200001Fof00000000JoH01P0000ASe@000000009W
m`@000EFo@04001FoEKmE_d40002E_d01@00E_eFo@00E_d00`0000=Fo@00E_d01EKm00<005Km0000
0P0000=Fo@00E_d015Km10000eKm00<005KmE_d00eKm10000eKm00<005KmE_d00eKm0P001EKm00@0
05KmE_eFo@@000EFo@03001Fo@000080009Fo@03001FoEKm00=Fo@03001Fo@0000800003E_d005Km
00EFo@03001Fo@0000800003E_d005Km00AFo@@000=Fo@03001FoEKm00=Fo@<000EFo@04001FoEKm
E_d30005E_d01000Oomoo`00:Woo0004Ool20006Ool2000JOol20006Ool2000@Ool20008Ool2000F
Ool00`00Oomoo`3=Ool30009Ool00`00E_eFo@04E_d00`00E_eFo@030006E_d00`00E_d000020002
E_d300020=L300000`2f0000000500001@2f000000000=L00P0000<0e`0000000P3G00<0003G0000
0P0000<0m`0000000PCg00<000Sg00000PSg00D000dG3AL000dG0080008A5`8000045AL001DG5AL2
00026CL02P007CLM=`007CL001dg000Q=`000R4g0P000bEG00@002EF9EHUEP80008YEP05000YERUF
:EH00002;EH20003;GH00`00<GHaMP02<GH01P00<GHaMS5f000aMP<000@eMP05000eUSFF=IH00004
>IH00`00>IHiUP02>IH00`00>IH000030003?IH00`00?IHmUP03?IH00`00?KDm]@02?KD00`00@KE1
]@02@KD00`00@KE1]@02@KD00`00@KE1]@03@KD00`00AKE5]@02AKD00`00AKE5]@03AKD00`00AKE5
]@02AKD00`00AME5e@03AMD00`00BME9e@04BMD00`00BME9e@02BMD00`00BME9e@03BMD00`00BME9
e@03BMD00`00CME=e@02CMD20006CMD00`00COE=m@03COD00`00COE=m@04COD00`00COE=m@02COD0
0`00DOEAm@02DOD00`00DOD00006DOD00`00DOEAm@04DOD00`00DOEAm@04DOD20005EQD00`00EQEF
5@04EQD00`00EQEF5@02EQD20006EQD00`00EQEF5@05EQD00`00FQEJ5@04FQD00`00FSEJ=@05FSD0
0`00FSEJ=@05FSD00`00FSEJ=@03FSD20007FSD01@00GSEN=Ehe00000ehe00<005iEGUD01EiE00<0
05iEGUD01EiE00<005iE00001V9E00D0069EHUERE@0000=RE@03001RMF9e00=RM@04001RMF9e0005
HWD01000HWERM@001FIe00@006IeIWD000EVM@04001VUFJE0003IYD00`00IYEVU@02IYD01000IYEV
U@001VZE0P001VZE00<006Ze00001FZe00L006ZeJ[EZ]@00J[D00006J[D00`00K]E^e@03K]D00`00
K]E^e@02K]D00`00K]D00004K]D01`00K]E^eFkE001^eP0000AbmP07001bmW;fL_H007;f000017;f
00<007;fL_H00W;f00<007<FLaH00W<F00<007<FLaH00W<F00H007LFMaH007LF0003McH00`00McIg
=P02McH01@00McH007Lf00000gLf00D007MFMeIgEP0000=kEP05001kEP00NeH00002NgH01@00NgIk
MW]f00000W]f00@007]fNgIkMP800005NiL007^GNiL00002NiL01000NiMkU`000W^g00@007^gNkL0
009k]`05001k]`00NmL00002NmL04@00NmMke`00NmL007_G001gm`00MoL007Og001gm`00MoL00P00
00IcmP00001_mP00KoH300000f_f0000000400000f?E000000050003E_d00`00E_eFo@03E_d40002
E_d00`00E_eFo@02E_d01000E_d000001EKm00@005KmE_eFo@@000EFo@03001Fo@0000800003E_d0
05Km00EFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@0000800003E_d005Km00AFo@@000=F
o@03001FoEKm00=Fo@8000IFo@04001FoEKmE_d30005E_d01000E_eFoEKm10001EKm00<005Km0000
0P0000=Fo@00E_d01EKm00<005Km00000P0000=Fo@00E_d01EKm10000UKm00<005KmE_d00eKm0P00
00=oo`00Ool0:Goo0004Ool20006Ool2000JOol20006Ool20007Ool20007Ool20008Ool2000FOol0
0`00Oomoo`3;Ool2000=Ool00`00E_eFo@03E_d30003E_d00`00E_eFo@03E_d20006E_d300020=L4
00000`2f0000000400000`2f0000e`0200000`2g0000000200020=L00`000=L0000200000`3g0004
m`021?L00`002?L000022?L00`003AL000023AL010004ALA5a4G0`000aDG0P0000<I=`007CL00Qdg
00@001dg0000008Q=`03000Q=b4g0080008UE`09000UEREF9EH002EF000YEP0000<YEP04000]EReF
;EH20002;GH00`00<GHaMP02<GH01@00<GHaMS5f00000c5f0P000cEf00D003FF=IHeUP0000DiUP05
000iUSVF>IH00004>IH20003?IH00`00?IHmUP02?IH00`00?KDm]@02?KD00`00@KE1]@03@KD00`00
@KE1]@02@KD00`00@KE1]@02@KD00`00AKE5]@02AKD00`00AKE5]@03AKD00`00AKE5]@02AKD00`00
AME5e@04AMD00`00BME9e@03BMD00`00BME9e@02BMD00`00BME9e@03BMD00`00BME9e@04BMD40000
0dgE001=e@05CMD00`00COE=m@03COD00`00COE=m@04COD00`00COE=m@02COD00`00DOEAm@020002
DOD00`00DOEAm@04DOD00`00DOEAm@04DOD00`00DOEAm@03DOD20006EQD00`00EQEF5@04EQD01`00
EQEF5EHE001F5@0000MF5@03001F5EHE00AF5@03001J5EXE00EJ5@03001J=EXe00AJ=@03001J=EXe
00EJ=@03001J=EXe009J=@04001J=EXe0006FSD01000GSEN=@0015he00<005iEGUD015iE0P0025iE
0P001V9E00@0069EHUD000ERE@05001RMF9eHWD00003HWD00`00HWERM@03HWD01000HWERM@001FIe
00@006IeIWD000AVM@03001VUFJE009VU@04001VUFJE0004IYD00`00IYD00007JYD00`00JYEZU@05
JYD00`00J[D00004J[D00`00J[EZ]@02J[D00`00J[D00005J[D00`00K[D00004K]D00`00K]E^e@03
K]D00`00K]E^e@03K]D01`00K]E^eFkE001^eP0000AbmP03001bmW;f009bmP03001bmW;f009bmP03
001bmW;f00=bmP03001c5W<F009c5P05001c5W<FLaH00004MaH00`00McIg=P02McH00`00McIg=P02
McH01000McIg=P0017Lf00D007MFMeIgEP00009kEP05001kEW]FNeH00003NgH01000NgIkMP000g]f
00@007]fNgH0009kU`<00004NiL007^G0003NiL00`00NkL00002NkL01000NkMk]`000W^g00D007_G
001ke`00009ke`0>001ke`00NmL007Og001gm`00MoL007Og001gm`800003LoH007?f00800004KoH0
0000JoH600000f?E0000000300000f?g001Fo@05E_d00`00E_d0000200000eKm001Fo@04E_d00`00
E_eFo@0300000eKm001Fo@04E_d40003E_d00`00E_eFo@03E_d20005E_d01000E_eFoEKm10001EKm
00@005KmE_eFo@@000EFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@0000800003E_d005Km
00EFo@@0009Fo@03001FoEKm00=Fo@@000=Fo@03001FoEKm00=Fo@8000EFo@04001FoEKmE_d40005
E_d00`00E_eFo@0300000eKm001Fo@04E_d00`00E_d0000200001EKm001oogoo0000:Goo0005Ool2
0004Ool2000LOol20004Ool20008Ool20008Ool20007Ool2000FOol00`00Oomoo`38Ool3000@Ool0
0`00E_d000020002E_d00`00E_eFo@02E_d00`00E_d000020002E_d00`00E_eFo@03E_d:00000`2f
0000000300020;H40000102g000000000P3G0`0000@0e`000000m`8000041?L0000000022?L20000
1@dG000=5`dG00000Q4G00<0014G00000aDG00@001TG000000<M=`03000M=adg008000038CL0024g
008Q=`80008UE`04000UEREF00029EH20003:EH01P00;EH]EReF000]EP<000@aMP03000aMS5f008a
MP04000aMS5f<GH20002=GH00`00=IHeUP02=IH00`00>IHiUP02>IH00`00>IHiUP02>IH01P00>IHi
USVF000mUP@000@mUP03000m]Cfe008m]@030011]D6e00=1]@030011]D6e0091]@030011]D6e00=1
]@030015]DFe0095]@030015]DFe00=5]@030015]DFe0095]@030015eDGE00=5e@030019eDWE00=9
e@030019eDWE0099e@030019eDWE00=9e@030019eDWE00=9e@8000A=e@03001=eDgE00A=e@03001=
mDge00==m@03001=mDge00A=m@03001=mDge00==m@8000EAm@03001AmE7e00=Am@03001AmE7e00AA
m@03001AmE7e009Am@03001Am@0000IF5@03001F5EHE00AF5@04001F5EHE0003EQD00`00EQEF5@04
EQD00`00EQEF5@03EQD20007FQD00`00FSEJ=@03FSD20007FSD01@00FSEJ=EXe00000eXe00<005Xe
FSD01EXe0P001Uhe00<005iEGUD00UiE00@005iEGUD000MNE@03001REF9E00ERE@03001RE@0000IR
E@05001RMF9eHWD00004HWD01@00HWERMF9e0000169e00D006IeIWEVM@0000AVM@04001VMFIe0005
IYD01000IYEVU@001FJE0P001fZE00<006ZEJYD016ZE00@006ZeJ[D000=Z]@03001Z]FZe00=Z]@03
001Z]@0000EZ]@03001^]@0000=^e@03001^eFkE00A^e@03001^eFkE009^e@03001^eFkE00=^e@03
001bmW;f009bmP03001bmW;f00=bmP03001bmW;f009bmP03001bmW;f009bmP03001c5P00009c5P03
001c5W<F009c5P03001g5WLF009g5P03001g=WLf009g=P05001g=WLfMcH00003McH20002McH01@00
MeIgEWMF00000g]F00D007]FNeIkEP00009kMP05001kMW]fNgH00002NgH01@00NgIkMW]f00000W^G
00<007^GNiL00P0000EkU`00NiMkU`00009k]`03001k]`00009k]`08001k]g^g001ke`00NmL0009k
e`0B001ke`00NmL007Og001gm`00MoL007Og001gm`00LoH007?f1@0000=_mP000000100000=Se@00
0000100000ASm`00IoP000=Fo@@000EFo@04001FoEKmE_d40002E_d01@00E_eFo@00E_d00`0000=F
o@00E_d01EKm00<005Km00000P0000=Fo@00E_d015Km10000eKm00<005KmE_d00eKm10000eKm00<0
05KmE_d00eKm0P001EKm00@005KmE_eFo@@000EFo@03001FoEKm00<00003E_d005Km00AFo@03001F
o@0000800003E_d005Km00EFo@03001Fo@0000800003E_d005Km00AFo@@000=Fo@03001FoEKm00=F
o@<000EFo@04001FoEKmE_d30005E_d00`00Ool0000YOol000Eoo`P001aoo`P000Qoo``000Moo`X0
00ioo`03001oogoo0<Eoo`<001Aoo`03001FoEKm00AFo@03001FoEKm00@000EFo@03001Fo@000080
009Fo@030000eP0000H000040;H000000;H800000`2g0000e`0200002`3G000000000=L0003g0000
e`001?L00P000`Sg0`000PdG0P0000DA5`004ALA5`00008E5`03000I5aTG0080008M=`07000M=adg
7CL0024g00000b4g00D0024f000UE`0000<UEP03000UEREF008000<YEP04000]EReF0003;EH20003
<GH00`00<GHaMP02<GH01P00<GHaMS5f000eMP@000<eUP03000iUSVF008iUP03000iUSVF008iUP05
000iUSVF>IH00004?IH40002?IH01@00?KDm]Cfe00001D6e00<0046e@KD00T6e00<0046e@KD00d6e
00<004FeAKD00TFe00<004FeAKD00dFe00<004FeAKD00TFe00<004GEAMD00dGE00<004WEBMD00dWE
00<004WEBMD00TWE00<004WEBMD014WE00<004WE00000P0000=9e@00CMD014gE00<004gECMD00dgE
00<004geCOD014ge00<004geCOD00dge00<004geCOD00Tge0P001U7e00<0057eDOD0157e00<0057e
DOD00e7e00<0057eDOD00P000U7e00<005HEEQD015HE00<005HEEQD01EHE0P0015HE00<005HEEQD0
15HE00<005HEEQD00UHE00@005HEEQD000IJ5@03001J=EXe009J=@04001J=EXe0006FSD01@00FSEJ
=EXe00000eXe00<005XeFSD01EXe00<005heGSD01Ehe00<005iEGUD00UiE00@005iEGUD000MNE@03
001REF9E00IRE@8000IRE@04001RMF9e0005HWD01000HWERM@001F9e00@006IeIWD000EVM@04001V
MFIe0005IYD00`00IYD00006IYD00`00JYEZU@05JYD00`00JYD00005JYD01@00J[EZ]FZe00000VZe
00<006ZeJ[D016Ze00<006ZeJ[D00fZe00D006jeK[E^]@00009^e@03001^eFkE00=^e@03001^e@00
00=^e@03001^eFkE00=^e@03001bmW;f009bmP03001bmW;f009bmP03001bmP0000=bmP03001bmW;f
009bmP06001c5W<F001c5P000g<F00<007LFMaH00WLF00<007Lf00000WLf00<007LfMcH00WLf00@0
07LfMcH0009g=P03001g=P00009gEP05001kEW]FNeH00003NeH01@00NgH007]f00000g]f00@007]f
NgH0009kMP04001kUg^G0003NiL00`00NiL00002000017^G001k]`000W^g00P007^gNkL007^g001k
e`000W_G00T007_GNmL007_G001ke`00MoL00P000WOg00@007Og001gm`800006LoH00000KoH006of
1P0000=Sm@0000001@0000ASm`00IoQWn0@000=Fo@03001FoEKm00=Fo@@000=Fo@06001FoEKmE_d0
05Km0P001EKm00@005KmE_eFo@@000EFo@03001Fo@000080009Fo@03001FoEKm00=Fo@03001Fo@00
00800003E_d005Km00EFo@03001Fo@0000800003E_d005Km00AFo@@000=Fo@03001FoEKm00=Fo@<0
00EFo@04001FoEKmE_d30005E_d01000E_eFoEKm10001EKm00<005Km00000P0000=Fo@00E_d01EKm
00<005Km00000P0000=Fo@00E_d01EKm10000UKm00<005KmE_d00eKm0P0000=oo`00Ool09goo0007
Ool4000POol4000:Ool<0007Ool:000>Ool00`00Oomoo`32Ool3000HOol00`00E_eFo@03E_d30004
E_d00`00E_eFo@02E_d30005E_d010000=H0003F10000P2f100000<0]P0000000`000P2g0P0000D0
eP000000e`000080e`040000m`000=L200001`Cg000000Sg0008m`0000<=5`8000034AL0014G0080
008E5`03000I5aTG0080008M=`04000M=adg00028CL010008CLQ=`000R4f0P000bEF00@002EF9EHU
EP80008YEP05000]EReF;EH00003;EH20002<GH00`00<GHaMP02<GH01@00<GHaMS5f000013Ef0P00
0SFF00<003VF>IH00SVF00<003VF>IH00SVF00<003VF>IH00SVF00D003fF?IHmUP0000<mU@H00003
?KD0046e00=1]@030011]D6e0091]@030011]D6e00=1]@030015]DFe0095]@030015]DFe00=5]@03
0015]DFe0095]@030015eDGE00=5e@030019eDWE00=9e@030019eDWE00=9e@030019eDWE00D000A9
e@03001=eDgE00==e@03001=eDgE00==e@03001=mDge00A=m@03001=mDge00==m@03001=mDge0080
0003COD0057e00EAm@03001AmE7e00AAm@03001AmE7e00AAm@8000EAm@03001F5EHE00AF5@03001F
5EHE00AF5@03001F5EHE00=F5@03001F5EHE00AF5@05001F5EHEEQD00003EQD00`00FQEJ5@04FQD0
1@00FSEJ=EXe00000eXe00<005XeFSD015Xe00@005XeFSD000AJ=@03001J=EXe00EJ=@03001N=Ehe
00EN=@05001NEEiEGUD00003GUD00`00GUENE@04GUD20008HUD00`00HUERE@05HUD00`00HWD00006
HWD01000HWERM@001F9e00@006IeIWD000EVM@03001VM@0000MVU@8000IVU@03001ZUFZE00EZU@03
001ZU@0000AZU@03001Z]FZe009Z]@03001Z]@0000MZ]@03001Z]FZe00=Z]@07001^]FjeK[D006kE
00001VkE00<006kE00000fkE00<006kEK]D00VkE00<007;e00000g;f00<007;fL_H00W;f00H007;f
L_H007;f0004L_H00`00LaIc5P02LaH00`00LaIc5P02LaH00`00MaIg5P02MaH01P00McIg=P00McH0
00=g=P05001g=WLfMcH00003McH01@00MeIgEWMF00000g]F00D007]FNeIkEP00009kMP80009kMP04
001kMW]f0003NgH01000NiMkU`000W^G00@007^GNiL0009kU`800004NkL007^g0002NkL02000NkMk
]`00NmL007_G0002NmL03P00NmL007_G001gm`00MoL007Og001gm`00MoL4000016of000006of1@00
00=Wm@0000001P0000=Sm`0000000P000UKm00<005KmE_d00eKm00<005Km00000P0000=Fo@00E_d0
1EKm00<005Km00000P0000=Fo@00E_d015Km10000eKm00<005KmE_d00eKm0P001UKm00@005KmE_eF
o@<000EFo@04001FoEKmE_d40005E_d00`00E_d000020002E_d00`00E_eFo@03E_d00`00E_d00002
00000eKm001Fo@05E_d40002E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d20005E_d01000
E_eFoEKm10001EKm00<005KmE_d00`0000=Fo@00E_d015Km00<005Km00000P0000EFo@00Oomoo`00
02Moo`00I7oo00<007oo00000P00_Goo0`0077oo00<005Km00000P000UKm00<005KmE_d00eKm00@0
05Km000000=Fo@03001FoEKm009Fo@8000030=H0003F00X000050;H000000000]P0500001P3F0000
003G0000e`<00080e`090004m`001?L000Sg0008m`00008=5`04000=5`0000024AL200002ADG000I
5aTG000I5`007CL000037CL00`008CL000038CL00`008CHQ=P0200029EH02@009EHUEREF000YEP00
:EH00003;EH01P00;EH]EReF000]MP800003<GH0035f00<aMP05000aMS5f<GH00003=GH00`00=GH0
00020004>IH00`00>IHiUP02>IH00`00>IHiUP02>IH01@00?IHmUSfF00001CfE00@003fE?IDmU@@0
0091]@030011]D6e0091]@030011]D6e00=1]@030015]DFe0095]@030015]DFe00=5]@030015]DFe
0095]@030015eDGE00=5e@030019eDWE00A9e@030019eDWE00D000=9e@030019eDWE00A9e@03001=
eDgE009=e@03001=eDgE00A=e@03001=mDge00==m@03001=mDge00A=m@8000==m@03001AmE7e00AA
m@03001AmE7e00AAm@03001AmE7e00=Am@8000IAm@03001F5EHE00AF5@03001F5EHE00=F5@8000IF
5@03001F5EHE00=F5@04001F5EHE0004EQD00`00FQEJ5@04FQD01000FSEJ=@0015Xe00<005XeFSD0
1EXe0P001UXe00<005XeFSD00eXe0P001ehe00@005iEGUD000ANE@03001NEEiE00=NE@04001NEEiE
0007HUD00`00HUERE@06HUD20006HWD00`00HWD00006HWD00`00IWD00007IWD20007IYD00`00IYEV
U@04IYD00`00JYD00005JYD01000JYEZU@0016ZE00<006ZeJ[D00VZe00<006Ze00001VZe00<006Ze
00000fZe00<006jeK[D00Vje00<006kE00001FkE00L006kEK]E^e@00K]D00005K]D01P00L_Ebm@00
L_H000EbmP06001bmW;f001bmP0017;f00<007<FLaH00W<F00<007<FLaH00W<F00D007LFMaIg5P00
00Ag=P05001g=WLfMcH00003McH00`00McIg=P02McH01000MeIgEP000g]F00D007]FNeIkEP0000=k
MP07001kMP00NgH007]f00000g]f00@007^GNiL000=kU`03001kU`0000=kU`06001k]`00001k]`00
0W^g00D007^g001ke`00009ke`09001keg_G001ke`00NmL007Og00800003MoL0000000<00003LoH0
07?f00<00003KoH0000000800003IoD0000000@00004GmD00000HoL20006E_d01000E_eFoEKm0`00
1EKm00@005KmE_eFo@@0009Fo@05001FoEKm001Fo@030002E_d00`00E_eFo@03E_d00`00E_d00002
00000eKm001Fo@05E_d40002E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d20006E_d01000
E_eFoEKm0`001EKm00<005KmE_d00`0000=Fo@00E_d015Km00<005Km00000P0000=Fo@00E_d01EKm
00<005Km00000P0000=Fo@00E_d015Km10000eKm00<005KmE_d00eKm0`001EKm00@005KmE_eFo@<0
00EFo@03001oo`0002Moo`00I7oo0P00_Goo0`0087oo00<005KmE_d015Km00@005KmE_eFo@<000IF
o@04001Fo@000002E_d600000`2E0000000500000`2f0000]P0200000`2f0000000200000`3F0000
e`020000103G000000000P3G00@000Cg0004m`8000052?L000003AL000023AL01@004ALA5`005AL0
0P000aTG00@001TG000000<M=`<000<Q=`04000Q=R4f8CH200029EH010009EHUEP000RUF0P000beF
00D002eF;EH]EP0000<]MP8000@aMP05000aMS5f<GH00003=GH01000=GHeMSEf0P000cVF00<003VF
>IH00cVF00D003VF>IHiUP0000@mUP03000mUCfE008mU@03000mUCfE008mU@03000m]Cfe00@000A1
]@030011]D6e0091]@030015]DFe0095]@030015]DFe00=5]@030015]DFe0095]@030015eDGE00A5
e@030019eDWE00H00099e@030019eDWE00=9e@030019eDWE00A9e@03001=eDgE009=e@03001=eDgE
00A=e@03001=mDge00==m@03001=mDge00==m@8000E=m@03001AmE7e00=Am@03001AmE7e00AAm@03
001AmE7e009Am@03001Am@0000IAm@03001F5EHE00AF5@03001F5EHE009F5@03001F5@0000IF5@03
001F5EHE00AF5@8000IF5@03001J5EXE00AJ5@8000EJ=@03001J=EXe00EJ=@03001J=EXe00EJ=@03
001J=EXe009J=@04001N=Ehe0006GSD01000GUENE@001EiE00<005iEGUD00UiE00@005iEGUD000IR
E@8000QRE@03001RMF9e00IRM@8000MRM@8000MVM@03001VUFJE00IVU@03001VUFJE00AVU@03001Z
U@0000EZU@05001ZUFZEJYD00002JYD00`00J[EZ]@04J[D00`00J[EZ]@05J[D00`00J[D00003J[D0
0`00K[E^]@03K[D00`00K]E^e@04K]D01`00K]E^eFkE001^e@0000A^e@07001bmG;eL_D007;f0000
17;f00<007;fL_H00W;f00<007;fL_H00W;f00<007<FLaH00W<F00<007<F00000W<F00<007LFMaH0
0WLF00<007LfMcH00WLf00D007LfMcIg=P0000=g=P09001g=WLfMcH007MF001gEP0000=kEP05001k
EW]FNeH00002NgH01000NgIkMW]f0P0000=kMP00NgH00W]f00<007^G00000g^G00@007^GNiL0009k
U`05001k]g^g001k]`0500001W^g001ke`00NmL0009ke`06001ke`00NmL007Og1@0000=gmP00LoH0
0P0000EcmP00000006of00<00003IoD0000000@00003GmD0000000D000IFo@@0009Fo@03001FoEKm
00=Fo@@000=Fo@06001FoEKmE_d005Km0P001UKm00@005KmE_eFo@<000EFo@03001FoEKm00<00003
E_d005Km00AFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@0000800003E_d005Km00EFo@@0
009Fo@03001FoEKm00=Fo@<000EFo@04001FoEKmE_d30005E_d01000E_eFoEKm10001EKm00<005Km
00000P0000=Fo@00E_d01EKm00<005Km00000P0000=Fo@00E_d01EKm10000UKm00<005KmE_d00eKm
0P0000=oo`00Ool09Goo001SOol00`00Oomoo`2jOol3000TOol00`00E_eFo@03E_d40003E_d00`00
E_eFo@03E_d20006E_d500000`2E0000000400020;H200000`2f0000]P0300020=H00`000=L00002
00001`3G0000e`3G0004m`000084m`030008m`Sg008000073AL000dG3AL0014G00000QDG0P000QTG
00<001TG6AL00P000Qdg00@001df0000008Q=`09000Q=R4f8CH002Df000UEP0000<UEP03000YERUF
008000<]EP05000]EReF;EH00003;GH20003<GH01@00<GHaMS5f000013Ef00@003Ef=GHeMP8000<i
UP03000iUSVF008iUP05000iUSVF>IH00004?IH00`00?IDmU@03?ID01@00?IDmUCfE00001Cfe2@00
0T6e00<004FeAKD00TFe00<004FeAKD00dFe00<004FeAKD00TFe00<004GEAMD01P000dGE00<004WE
BMD00TWE00<004WEBMD014WE00<004WEBMD00dWE00<004gECMD00TgE00<004gECMD014gE00<004ge
COD00dge00@004geCOE=m@800003COD004ge00A=m@03001AmE7e00AAm@03001AmE7e00=Am@05001A
mE7eDOD00002DOD00`00DOEAm@04DOD00`00EQEF5@04EQD01@00EQEF5EHE00000eHE00<005HEEQD0
0eHE00<005HEEQD015HE00<005HEEQD01EHE00<005XEFQD015XE00<005XeFSD01EXe00<005XeFSD0
15Xe00<005XeFSD01EXe00D005XeFSEJ=@0000=N=@03001N=Ehe00EN=@8000INE@05001NEEiEGUD0
0003GUD00`00HUERE@03HUD01000HUERE@001f9E00<0069eHWD01V9e00<0069eHWD01V9e00<006Ie
IWD01VIe00<006JEIYD01FJE00<006JE000016JE00D006ZEJYEZU@0000=ZU@03001ZUFZE009ZU@04
001ZUFZE0006J[D00`00J[EZ]@04J[D01@00J[EZ]FZe00000VZe00<006jeK[D00fje00<006kEK]D0
0fkE00<006kEK]D00fkE00<006kEK]D00fkE00<007;eL_D00W;e00<007;fL_H00g;f00<007;fL_H0
0W;f00<007;fL_H00W;f00<007<FLaH00W<F00H007<FLaH007<F0003MaH00`00McIg=P02McH01@00
McH007Lf00000gLf00<007LfMcH00WLf00<007MFMeH00P000W]F00D007]FNeIkEP0000=kMP06001k
MW]fNgH007]f0P000W]f00@007^GNiL000=kU`03001kU`00009kU`04001k]g^g0002NkL01@00NkMk
]`00NkL03P0000MgmP00MoH007Of001cmP02000017?f000006of0`0000=[m@000000100000EOe@00
000005_E00<0009[nP03001FoEKm00<00003E_d005Km00AFo@03001Fo@000080009Fo@03001FoEKm
00=Fo@03001Fo@0000800003E_d005Km00EFo@@0009Fo@03001FoEKm00=Fo@<000EFo@04001FoEKm
E_d30005E_d01000E_eFoEKm10001EKm00<005KmE_d00`0000=Fo@00E_d015Km00<005Km00000P00
00=Fo@00E_d01EKm10000UKm00<005KmE_d00eKm10000eKm00<005KmE_d00eKm0P001EKm00@005Km
E_eFo@@000EFo@03001FoEKm00<00003E_d005Km00AFo@03001Fo@0000800005E_d007ooOol0000U
Ool006=oo`03001oogoo0;Moo`<002Qoo`03001Fo@000080009Fo@03001FoEKm00=Fo@03001Fo@00
0080009Fo@03001FoEKm00=Fo@H0000409D0000009H700002`2f0000]P000;H0003F0000e`000=H0
0P0000L0e`000=L0e`001?L000021?L010002?L000Sg0P000PdG0P0000@A5`005ALE5`8000036AL0
01TG008I5`80008M=`04000M=P0000028CL010008CHQ=P000RDf0P000bEF00@002UF:EHYEP80008]
EP05000]EReF;EH00003;GH01P00<GH00000<GH000@aMP05000eMSEf=GH00003=GH00`00=GH00003
0004>IH00`00>IHiUP02>IH01@00?IHmUSfF00001CfE00<003fE?ID00SfE00<003fe?KD00Sfe00<0
046e@KD00T6e00@0046e@KE1]AD000=5e@030015eDGE00=5e@030019eDWE00=9e@030019eDWE00=9
e@030019eDWE00=9e@03001=eDgE00==e@03001=eDgE00==e@03001=mDge00A=m@<000==m@03001=
mDge00==m@03001AmE7e00AAm@03001AmE7e00AAm@03001Am@0000AAm@03001AmE7e00=Am@03001F
5EHE00AF5@04001F5EHE0004EQD00`00EQEF5@03EQD00`00EQEF5@04EQD00`00EQEF5@05EQD00`00
FQEJ5@04FQD00`00FSEJ=@05FSD00`00FSEJ=@03FSD20007FSD01@00FSEJ=EXe00000ehe00<005he
GSD01Ehe00<005iEGUD01EiE00@005iEGUD000ANE@03001REF9E00=RE@04001REF9E0006HUD20008
HWD00`00HWERM@06HWD00`00IWEVM@05IWD20007IYD00`00IYD00004IYD01@00JYEZUFZE00000fZE
00<006ZEJYD00VZE00<006ZE00001VZe00<006Ze00001FZe00L006ZeJ[EZ]@00J[D00005K[D00`00
K]D00003K]D00`00K]E^e@04K]D00`00K]E^e@02K]D00`00L_Ebm@03L_D00`00L_IbmP02L_H00`00
L_IbmP02L_H00`00L_H00003L_H00`00LaIc5P02LaH01@00LaIc5W<F000017LF00<007LfMcH00WLf
00D007Lf001g=P0000=g=P05001g=WLfMcH00003MeH01@00NeH007]F00000g]F00@007]fNgH000=k
MP0:001kMW]f001kMP00NgH007^G0003NiL01000NiMkU`000W^G00H007^gNkL007^g0002NkL02000
NkMk]`00NmL007_F0002NmH01P00NmH007_F001gmP800007MoH007Of001cmP00LoH00P0000E_mP00
000006_e00@00003IoD006?E00P000=[nP<000EFo@04001FoEKmE_d30006E_d01000E_eFoEKm0`00
0UKm00@005KmE_d0009Fo@<00003E_d005Km00AFo@03001Fo@0000800003E_d005Km00EFo@@0009F
o@03001FoEKm00=Fo@@000=Fo@03001FoEKm00=Fo@<000EFo@04001FoEKmE_d30005E_d00`00E_eF
o@0300000eKm001Fo@04E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d0000200000eKm001F
o@04E_d40003E_d00`00E_eFo@03E_d30005E_d01000E_eFoEKm0`001EKm00<007oo00009Goo001S
Ool00`00Oomoo`2eOol2000/Ool20005E_d01000E_eFoEKm0`001UKm00<005Km00000P000UKm2P00
00<0U@0000000`0000<0]P000;H00`0000L0eP000=L0003F0000e`020000103G000000000PCg00<0
00Sg00000PSg00@000dG3AL=5`<0008E5`05000E5`006AL000026AL02`006AH001dg000M=P007CH0
024g00000b4f00<002Df9CH00P000REF00H002UF:EHYEP00:EH30003;EH01@00;GH]MRef00000c5f
0`000c5f00D003Ef=GHeMP0000<eMP03000eMSEf008eMP8000<iUP03000iUSVF008iUP05000mUSfF
?IH00005?ID00`00?IDmU@02?ID00`00?KDm]@02?KD00`00@KE1]@02@KD00`00@KE1]@03@KD00`00
@KE1]@02@KD00`00AKE5]@03AKD00`00AKE5]@02AKD00`00AME5e@03AMD00`00AME5e@04AMD00`00
BME9e@02BMD00`00BME9e@03BMD00`00BME9e@03BMD00`00CME=e@03CMD00`00CME=e@03CMD00`00
COE=m@03COD20006COD00`00COE=m@02COD00`00DOEAm@04DOD00`00DOEAm@04DOD20005DOD00`00
DOEAm@04DOD00`00EQEF5@04EQD20005EQD00`00EQEF5@04EQD00`00EQEF5@02EQD20007EQD00`00
FQEJ5@03FQD20007FSD00`00FSEJ=@02FSD01000FSEJ=@001UXe00@005XeFSD000AN=@03001N=Ehe
00EN=@03001NEEiE00ENE@04001NEEiE0005GUD01@00HUEREF9E00000f9E00<0069EHUD00f9E00@0
069EHUD000IRM@8000MRM@8000MVM@03001VM@0000EVU@04001VUFJE0003IYD00`00JYEZU@02JYD0
1@00JYEZUFZE00001FZE0P001VZe00<006Ze000016Ze00<006ZeJ[D00VZe00<006Ze00001Fje00<0
06kE00000fkE00<006kEK]D00fkE00<006kE00000fkE00<007;eL_D00W;e00<007;e00000g;f00<0
07;fL_H00W;f00H007;fL_H007;f0004LaH00`00LaIc5P02LaH00`00MaIg5P02MaH01@00McIg=WLf
00000gLf00<007LfMcH00WLf00D007LfMcIg=P00009gEP05001kEW]FNeH00004NeH01000NgIkMP00
0g]f00<007]f00000g]f0P0000=kU`00NiL00W^G00<007^G00000W^G00@007^gNkL0009k]`03001k
]`00009k]`05001ke`00NmH00002NmH01P00NmH007_F001gmP800004MoH007OfMoH200000g?f001c
mP0300000f_e0000000200000fOe00000009000016_j000000000UKm00<005KmE_d00eKm10000UKm
00<005KmE_d015Km10000UKm00H005KmE_eFo@00E_d30005E_d01000E_eFoEKm0`001EKm00<005Km
E_d00`0000=Fo@00E_d015Km00<005Km00000P000UKm00<005KmE_d00eKm00<005Km00000P0000=F
o@00E_d01EKm10000UKm00<005KmE_d00eKm0`001EKm00@005KmE_eFo@<000EFo@04001FoEKmE_d4
0005E_d00`00E_d000020002E_d00`00E_eFo@03E_d00`00E_d0000200000eKm001Fo@05E_d40002
E_d00`00E_eFo@03E_d200000goo001oo`0SOol006=oo`03001oogoo0;9oo`<0031oo`03001FoEKm
009Fo@@000=Fo@03001FoEKm00=Fo@8000IFo@@0000309D0000000<0000309D0000000800080]P80
00030;H0000000<00080eP050000e`000000e`0200031?L00`002?L000022?L01P003AL=5`004?L0
00<E5`04000E5`0000036AL010006AH000000Qdf00@001df000000<Q=P04000U=RDf9CH200029EH0
1000:EHYEP000bUF0P000beF00D002ef;GH]MP0000@aMP80008aMP05000eMSEf=GH00004=GH01P00
=GHeMSEf000iUP800003>IH003VF00<iUP03000mUSfF008mUP03000mUCfE008mU@03000mUCfE008m
U@03000m]Cfe00<m]@030011]D6e0091]@030011]D6e0091]@030011]D6e0091]@030015]DFe00=5
]@030015]DFe0095]@030015eDGE00A5e@030015eDGE00=5e@030019eDWE0099e@030019eDWE00=9
e@030019eDWE00A9e@03001=eDgE009=e@03001=eDgE00A=e@03001=mDge00800003COD004ge00E=
m@03001=mDge009=m@03001AmE7e00AAm@03001AmE7e00=Am@8000IAm@03001AmE7e00AAm@03001F
5EHE00=F5@8000IF5@03001F5EHE00AF5@05001F5EHEEQD00002EQD00`00EQEF5@05EQD01@00FQEJ
5EXE00000UXE00<005XeFSD015Xe00D005XeFSEJ=@0000=J=@03001J=EXe00EJ=@8000IN=@03001N
=Ehe00=N=@8000QNE@8000INE@05001REF9EHUD00003HUD00`00HUERE@03HUD01000HUERE@001F9e
00@0069eHWD000ERM@04001VMFIe0005IWD01000IWEVM@001FJE00D006JEIYEVU@00009VU@03001Z
UFZE00=ZU@03001ZU@0000IZU@03001Z]FZe00AZ]@04001Z]FZe0003J[D00`00J[EZ]@04J[D00`00
K[E^]@03K[D01`00K]E^eFkE001^e@0000I^e@03001^e@0000=^e@03001bmG;e009bm@03001bm@00
009bmP03001bmW;f00=bmP06001bmW;f001bmP0017<F00L007<FLaIc5P00MaH00002MaH00`00McIg
=P02McH01000McIg=WLf0P000WLf00D007LfMcIg=P0000=gEP04001kEW]FNeH20002NeH01000NgIk
MP000g]f00@007]fNgH000=kMP04001kUP000002NiL01P00NiMkU`00NiL0009k]`04001k]g^g0002
NkL00`00NkL00002NmL05000NmH007_F001keP00NmH007Of001gmP00MoH007Of001cmP00LoH30000
0foe0000000200000fOe0000000<0006E_d00`00E_d0000200000eKm001Fo@04E_d00`00E_eFo@03
00000eKm001Fo@04E_d00`00E_d0000200000eKm001Fo@05E_d40002E_d00`00E_eFo@03E_d30005
E_d01000E_eFoEKm0`001UKm00@005KmE_eFo@<000EFo@03001FoEKm00<00003E_d005Km00AFo@03
001Fo@0000800003E_d005Km00EFo@@0009Fo@03001FoEKm00=Fo@@000=Fo@03001FoEKm00=Fo@80
00IFo@04001FoEKmE_d30005E_d00`00E_eFo@0300000eKm001Fo@04E_d00`00E_d0000200000eKm
00000002000SOol006=oo`03001oogoo0:moo`<003Aoo`04001Fo@000002E_d00`00E_eFo@03E_d0
0`00E_d000020002E_d00`00E_eFo@03E_d500000`2E000000030000202E0000002F0000]P000;H2
0000102f000000000P3F00@0003G0000eP8000040=L000001?L300022?L200001@dG000@ma3g0000
0QDG00@001DG5AL000<I5`03000I5QTF008000047CH001df7CH200028CH02@009CHU=RDf000UEP00
9EH00003:EH01000:EHYERUF0P000ReF00D002ef;GH]MP0000@aMP03000aMP00008000@eMP05000e
MSEf=GH00003=GH01000>IHiUSVF0`000cVF00<003fF?IH00SfF00<003fE?ID00cfE00D003fE?IDm
U@0000Dm]@030011]D6e0091]@030011]D6e00=1]@030011]D6e0091]@030015]DFe00=5]@030015
]DFe0095]@030015eDGE00=5e@030015eDGE00=5e@030019eDWE0099e@030019eDWE00=9e@030019
eDWE00A9e@03001=eDgE009=e@03001=eDgE00A=e@<000==m@03001=mDge00A=m@03001=mDge00==
m@03001AmE7e00=Am@03001AmE7e009Am@03001Am@0000IAm@03001AmE7e00AAm@03001F5EHE009F
5@03001F5@0000IF5@03001F5EHE00AF5@04001F5EHE0003EQD00`00EQEF5@05EQD01000FQEJ5@00
0eXE00<005XeFSD015Xe00@005XeFSD000AJ=@03001J=EXe00EJ=@03001N=Ehe00EN=@03001N=Ehe
009N=@04001N=5hd0007GUD00`00GUENE@05GUD01000HUERE@001F9E00D0069EHUERE@0000=RE@03
001RMF9e00=RM@04001RMF9e0005HWD01000IWEVM@001FIe00@006IeIWD000AVU@03001VUFJE009V
U@04001VUFJE0005JYD00`00JYD00006JYD00`00J[EZ]@04J[D01@00J[EZ]FZe00000VZe00<006Ze
J[D016Ze00<006jeK[D00fje00L006kEK]E^e@00K]D00005K]D01`00K]E^eFkE001^e@0000Abm@07
001bmG;eL_D007;f000017;f00<007;fL_H00W;f00<007<FLaH00W<F00<007<FLaH00W<F00H007LF
MaH007LF0003McH01@00McIg=WLf00000WLf00<007Lf00000gLf00@007MFMeH000=kEP06001kEW]F
001kEP000W]f00L007]fNgIkMP00NgH00003NgH02P00NiIkUP00NiH007^G001kU`000W^G00H007^g
NkL007^g0002NkL02000NkMk]`00NmL007_F0002NmH01P00NmH007_F001gmP800004MoH007OfMoH2
000017?f000006of100000E[m@00000006?E00T0009Fo@03001FoEKm00AFo@8000EFo@04001FoEKm
E_d40005E_d01000E_eFoEKm0`000eKm00<005Km00000UKm0`0000=Fo@00E_d015Km00<005Km0000
0P000UKm00<005KmE_d00eKm10000UKm00<005KmE_d015Km10000UKm00<005KmE_d00eKm0`001EKm
00@005KmE_eFo@<000EFo@03001FoEKm00<00003E_d005Km00AFo@03001Fo@0000800003E_d005Km
00EFo@03001Fo@0000800003E_d005Km00EFo@@0009Fo@03001FoEKm00=Fo@<000EFo@04001FoEKm
E_d30005E_d00`00Ool0000SOol006=oo`03001oogoo0:aoo`<003Qoo`03001FoEKm00=Fo@04001F
oEKmE_d30006E_d00`00E_d000020002E_d400000`2E00000002000209D400000`2f000000020000
0`2f0000]P0200002`3F0000e`000=H0003G0000eP001?L00P000`Sg0P0000<=5`004?L00P0000<E
5`005AL00QDG00@001TG6AL000<I5P03000M=P0000<M=P80008Q=P04000U=RDf00029EH20003:EH0
2@00:EHYERUF000]EP00;EH00003;GH00`00<GHaMP02<GH01000<GHaMS5f0P000cEf00D003Ef=GHe
MP0000@eMP03000iUSVF008iUP80008iUP03000mUSfF008mUP03000mUCfE00<mU@05000mUCfE?ID0
0005?KD00`00@KE1]@02@KD00`00@KE1]@03@KD00`00@KE1]@02@KD00`00AKE5]@03AKD00`00AKE5
]@02AKD00`00AME5e@03AMD00`00AME5e@03AMD00`00BME9e@02BMD00`00BME9e@04BMD00`00BME9
e@03BMD00`00CME=e@02CMD00`00CME=e@03CMD20006COD00`00COE=m@03COD00`00COE=m@03COD0
0`00DOEAm@04DOD01000DOD000000U7e00<0057eDOD0157e00<0057eDOD0157e00D005HEEQEF5@00
009F5@03001F5EHE00EF5@03001F5EHE00AF5@8000AF5@03001F5EHE00EF5@04001J5EXE0003FQD0
0`00FSEJ=@05FSD20006FSD00`00FSEJ=@04FSD00`00GSEN=@05GSD01@00GSEN=Ehe00000ehd00<0
05iEGUD01EiE00<005iEGUD01EiE00<0069E00001V9E00D0069EHUERE@0000ARE@05001RMF9eHWD0
0003HWD00`00HWERM@02HWD01@00IWEVMFIe000016Ie00<006IeIWD00VIe00@006JEIYD000EVU@03
001VU@0000MZU@03001ZUFZE00AZU@03001ZU@0000AZ]@03001Z]FZe009Z]@03001Z]@0000IZ]@03
001^]@0000=^]@03001^eFkE00=^e@03001^eFkE00A^e@07001^eFkEK]D006kE000017;e00L007;e
L_Ebm@00L_H00004L_H00`00L_IbmP02L_H00`00LaIc5P02LaH01@00LaIc5W<F000017LF00D007Lf
McIg=P0000Ag=P05001g=WLfMcH00004McH01000MeIgEP000g]F00D007]FNeIkEP00009kMP05001k
MW]fNgH00002NgH01`00NgIkMW]f001kUP0000=kUP800004NiL007^G0002NkL01P00NkMk]`00NkL0
009k]`05001ke`00NmH00002NmH03000NmH007_F001gmP00MoH007Of001gmP@00003KoH000000080
0005JoD00000001We@090005E_d00`00E_eFo@0300000eKm001Fo@04E_d40003E_d00`00E_eFo@03
E_d40002E_d01P00E_eFoEKm001Fo@<000EFo@04001FoEKmE_d30006E_d00`00E_d0000200000eKm
001Fo@04E_d00`00E_eFo@0300000eKm001Fo@04E_d00`00E_d0000200000eKm001Fo@05E_d40002
E_d00`00E_eFo@03E_d30005E_d01000E_eFoEKm0`001EKm00@005KmE_eFo@@000EFo@03001FoEKm
00<00003E_d005Km00AFo@03001Fo@0000800003E_d005Km00EFo@@0009Fo@03001FoEKm00=Fo@<0
02=oo`00HWoo00<007ooOol0ZWoo0`00?7oo00<005KmE_d00UKm10000eKm00<005KmE_d00eKm0P00
1UKm4`000P2f0P0000<0]P0000000P000P3F00@0003G0000eP8000061?L000Sg2?L000Sg0P000Q3g
0P0000@E5`005ALE5`80008I5`04000I5QTF00027CH020007CHM=P008CH0024f00039CH00`009EHU
EP020002:EH01@00:EHYERUF00000ReF0P0012ef00<0035f<GH00S5f00@0035f<GHaMP80008eMP05
000eMSEf=GH00004=GH00`00>IHiUP02>IH00`00>ID000030003?IH00`00?IDmU@03?ID00`00?IDm
U@02?ID00`00?KDm]@02?KD00`00@KE1]@02@KD00`00@KE1]@03@KD00`00@KE1]@02@KD00`00AKE5
]@03AKD00`00AKE5]@02AKD00`00AME5e@03AMD00`00AME5e@03AMD00`00BME9e@03BMD00`00BME9
e@03BMD00`00BME9e@03BMD00`00CME=e@03CMD00`00CMD0000200000dgE001=m@05COD00`00COE=
m@03COD00`00COE=m@03COD00`00DOEAm@04DOD20005DOD00`00DOEAm@04DOD00`00DOEAm@03DOD0
1000EQEF5@0015HE00<005HEEQD015HE00<005HEEQD015HE00<005HEEQD015HE00<005HEEQD01EHE
0P001EXE00<005XeFSD015Xe00<005XeFSD01EXe00<005XeFSD00eXe0P001ehe00D005heGSEN=@00
00=N=003001NEEiE00ANE@03001NE@0000MNE@8000IRE@04001REF9E0005HUD01@00HWERMF9e0000
169e00D0069eHWERM@0000AVM@04001VMFIe0005IWD01000IYEVU@001VJE0P001fZE00<006ZEJYD0
16ZE00<006ZE000016Ze00<006ZeJ[D00VZe00<006Ze00001VZe00<006je00000fje00<006kEK]D0
0fkE00<006kEK]D00fkE00<006kEK]D00fkE00<007;eL_D00W;e00<007;eL_D00g;e00<007;fL_H0
0W;f00<007;fL_H00W;f00<007<F00000W<F00<007<FLaH00W<F00<007LFMaH00WLF00D007LfMcIg
=P0000=g=P03001g=WLf009g=P80009g=P04001gEWMF0003NeH00`00NeIkEP02NeH200000g]f001k
MP02NgH00`00NgH00003NgH01000NiIkUP000g^F00<007^F0000100000Ak]`00NkL0009k]`08001k
]g^g001ke`00NmH0009keP06001keP00NmH007Of0P0000MgmP00000007?f001cmP0400001F_e0000
0000ImD0100000=Oe00000000`0000=Se@00E_d00UKm10001EKm00<005Km00000P0000=Fo@00E_d0
1EKm00<005Km00000P0000=Fo@00E_d015Km00<005Km00000P000UKm00<005KmE_d00eKm10000UKm
00<005KmE_d015Km0P001EKm00@005KmE_eFo@@000EFo@04001FoEKmE_d30005E_d00`00E_eFo@03
00000eKm001Fo@04E_d00`00E_d0000200000eKm001Fo@05E_d40002E_d00`00E_eFo@03E_d40003
E_d00`00E_eFo@03E_d30005E_d01000E_eFoEKm0`001EKm00<005KmE_d00`0000=Fo@00E_d015Km
00<005Km00000P0000=Fo@0000008goo001ROol00`00Oomoo`2WOol30010Ool01000E_d000000eKm
00<005KmE_d00UKm00<005Km00000P000UKm00<005KmE_d00eKm0`0000<0M00000000`0000<0M@00
00001P0000L0]P000;H0002f0000]P0300020=H00`000=L000020=H01P001?L000002?L00088m`05
000@ma3g000@mP0200035AL200000aTG000I5P026AH00`007CH000037CH010008CH000000bDf00@0
02EF9EHUEP80008YEP05000YERUF:EH00002;EH20003;GH00`00<GHaMP02<GH01P00<GHaMS5f000a
MP<000@eMP05000eMSEf=GH00004>IH00`00>IDiU@02>ID20002?IH00`00?IDmU@03?ID00`00?IDm
U@02?ID00`00?KDm]@03?KD01@00@KE1]D6e00001D6e00<0046e@KD00T6e00<004FeAKD00dFe00<0
04FeAKD00TFe00<004GEAMD00dGE00<004GEAMD014GE00<004WEBMD00TWE00<004WEBMD00dWE00<0
04WEBMD00dWE00<004gECMD00TgE0`0014gE00<004geCOD014ge00<004geCOD014ge00<004geCOD0
0Tge00<0057eDOD00e7e0P001U7e00<0057eDOD0157e00<0057eDOD0157e0P001EHE00<005HEEQD0
15HE00<005HEEQD00eHE0P001UHE00<005HEEQD01EHE00<005XEFQD015XE00<005XeFSD015Xe00<0
05XeFSD01EXe00<005XeFSD00UXe00@005XeFSD000IN=@04001N=Ehe0004GS@00`00GUENE@03GUD0
1000GUENE@001eiE00<0069EHUD01F9E00<0069E00001V9E00@0069eHWD000ERM@04001RMF9e0005
IWD01000IWEVM@001FIe00<006JE00001fJE00<006ZEJYD01FZE00<006ZE000016ZE00@006ZEJYD0
00=Z]@03001Z]FZe00AZ]@03001Z]FZe00AZ]@05001^]FjeK[D00002K[D00`00K]E^e@02K]D00`00
K]D00004K]D00`00K]E^e@03K]D00`00L_Ebm@02L_D00`00L_Ebm@03L_D00`00L_IbmP02L_H00`00
L_IbmP02L_H01P00LaIc5P00LaH000=c5P03001g5WLF009g5P05001g5P00McH00004McH01@00McIg
=WLf00000WLf00<007Lf00000WMF00D007]FNeIkEP0000=kEP03001kMW]f0080009kMP04001kMW]f
0003NgH00`00NiH00003NiH01P00NiIkUP00NkH0009k]P800004NkL007^g0002NkL01@00NmL007_F
00000W_F00H007_F001keP00MoH5000017?f000007?f0`0000E_m@00000006Oe00@00003Gm@00000
00@0009Se@@000=Fo@03001FoEKm00=Fo@8000EFo@04001FoEKmE_d40005E_d01000E_eFoEKm0`00
0eKm00D005KmE_d005Km00<00003E_d005Km00AFo@03001FoEKm00<00003E_d005Km00AFo@@0009F
o@03001FoEKm00AFo@@0009Fo@03001FoEKm00=Fo@<000EFo@04001FoEKmE_d30005E_d00`00E_eF
o@0300000eKm001Fo@04E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d0000200000eKm001F
o@05E_d40002E_d00`00E_eFo@03E_d30005E_d01000E_eFoEKm0`001EKm00<007ooOol08Goo001R
Ool00`00Oomoo`2TOol30014Ool00`00E_eFo@04E_d00`00E_eFo@030006E_d00`00E_d000020002
E_d200000`1d0000000300000`1e0000000200000`2F0000UP0300000`2f000000020;H00`000;H0
00020=H00`000=L000020=H01P001?L000002?L00088m`06000@ma3g000@mP000aDG00@001DF0000
00<I5P<000<M=P03000Q=R4f0080008U=P09000UEREF9EH002EF000YEP0000<YEP04000]EReF;EH2
0002;GH00`00<GHaMP02<GH01@00<GHaMS5f00000c5f0P000cEf00D003Ef=GHeMP0000DiUP06000i
UCVE>ID003VE100013fE00<003fE?ID00SfE00<003fe?KD00cfe00<0046e@KD00T6e00<0046e@KD0
0d6e00D0046e@KE1]@0000E5]@030015]DFe00=5]@030015eDGE00=5e@030015eDGE00=5e@030019
eDWE0099e@030019eDWE00=9e@030019eDWE00A9e@@00003CMD004gE00E=e@03001=mDge00==m@03
001=mDge00A=m@03001=mDge009=m@04001AmE7eDOD200000dge001Am@05DOD00`00DOEAm@04DOD0
0`00DOEAm@03DOD20006EQD00`00EQEF5@04EQD00`00EQEF5@02EQD00`00EQD00006EQD00`00EQEF
5@05EQD00`00FQEJ5@04FQD00`00FSEJ=@03FSD20008FSD01@00FSEJ=EXe00000UXe00<005heGSD0
1Ehe0P001Uhd00<005iEGUD00UiE00@005iEGUD000MNE@03001REF9E00IRE@8000IRE@03001RM@00
00IRM@03001RM@0000IVM@03001VM@0000MVM@8000MVU@03001ZUFZE00EZU@03001ZU@0000AZU@05
001ZUFZEJYD00002J[D00`00J[EZ]@04J[D00`00J[EZ]@04J[D01`00K[E^]Fje001^]@0000E^e@03
001^e@0000=^e@03001^eFkE00=^e@03001be@00009bm@03001bmG;e00=bm@03001bm@00009bmP03
001bmW;f009bmP07001c5W<FLaH007<F00000g<F00<007LFMaH00WLF00D007LF001g=P0000=g=P03
001g=WLf009g=P05001g=WLfMcH00003MeH01000NeIkEP000g]F00T007]fNgIkMP00NgH007]f0000
0W]f00@007]fNgH0009kUP09001kUW^FNiH007^F001k]P0000=k]P03001k]P0000H00003NmL007_F
00T00005MoH007Of001cmP02000017?f000006of0`0000=[m@0000003@0000=Fo@00E_d01EKm00<0
05Km00000P0000=Fo@00E_d015Km10000eKm00<005KmE_d00eKm10000UKm00D005KmE_eFo@00009F
o@8000EFo@04001FoEKmE_d40005E_d00`00E_d0000200000eKm001Fo@04E_d00`00E_eFo@030000
0eKm001Fo@04E_d00`00E_d0000200000eKm001Fo@05E_d40002E_d00`00E_eFo@03E_d30005E_d0
1000E_eFoEKm0`001EKm00@005KmE_eFo@@000EFo@03001FoEKm00<00003E_d005Km00AFo@03001F
o@0000800003E_d005Km00EFo@@0009Fo@03001FoEKm00=Fo@80029oo`00HWoo00<007ooOol00P00
Wgoo0`00B7oo00<005KmE_d00eKm0`000eKm00<005KmE_d00eKm0P001UKm0P0000<0M00000000`00
00H0M@000000U@0009H200000`2f0000000300020;H30000103F000000000P3F0`0000<4mP000000
0PSg0P0000D@m`004?H@mP00008E5`03000E5QDF0080008I5P04000I5P0000027CH010008CHQ=R4f
0P000RDf00@002EF9EH0008UEP8000<YEP06000]EReF;EH002eF0`00135f00<0035f<GH00S5f00@0
035f<GHaMP80008eMP03000eMSEf008eMP03000iUSVF008iUP05000iUCVE>ID00004>ID40002?ID0
1@00?IDmUCfE00001Cfe00<0046e@KD00T6e00<0046e@KD00d6e00<0046e@KD00T6e00<004FeAKD0
0dFe00<004FeAKD00TFe00<004GEAMD00dGE00<004GEAMD00dGE00<004WEBMD00TWE00<004WEBMD0
0dWE00<004WEBMD00dWE0P0014gE00<004gECMD014gE00<004geCOD00dge00<004geCOD014ge00<0
04geCOD00dge0`000dge00<0057eDOD0157e00<0057eDOD0157e00<0057eDOD00U7e00<0057e0000
1UHE00<005HEEQD015HE00D005HEEQEF5@0000=F5@03001F5EHE00=F5@03001F5EHE00AF5@8000IJ
5@03001J=EXe009J=@04001J=EXe0007FSD01000FSEJ=@000eXe00<005heGSD01Ehe00<005hdGS@0
1Ehd00D005iEGUENE@0000ANE@03001NEEiE00=NE@03001RE@0000MRE@03001REF9E00IRE@8000MR
M@8000MVM@8000MVM@03001VUFJE00EVU@8000IZU@04001ZUFZE0003JYD00`00JYEZU@02JYD00`00
J[D00006J[D00`00J[D00004J[D00`00K[E^]@02K[D00`00K[D00005K]D01000K]E^e@000VkE00<0
06kEK]D00fkE00<007;E00000W;e00<007;eL_D00g;e00H007;eL_D007;f0004L_H00`00LaIc5P02
LaH01@00LaIc5W<F000017LF00D007LFMaIg5P0000Ag=P05001g=WLfMcH00004McH01000MeIgEP00
0g]F00D007]FNeIkEP00009kMP05001kMW]fNgH00002NgH01`00NgIkMW]f001kUP0000=kUP06001k
UW^F001k]P000W^f00H007^fNkH007^f0002NmH00`00NmH0000300001g_F001keP00MmH007Of0080
0005MoH007?f001cmP0200001Fof00000000JoD02@0000=K]00000000P001EKm00@005KmE_eFo@@0
00EFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@0000800003E_d005Km00AFo@03001FoEKm
00<00003E_d005Km00AFo@@0009Fo@03001FoEKm00AFo@8000EFo@04001FoEKmE_d40005E_d01000
E_eFoEKm0`001EKm00<005KmE_d00`0000=Fo@00E_d015Km00<005Km00000P0000=Fo@00E_d01EKm
10000UKm00<005KmE_d00eKm10000eKm00<005KmE_d00eKm0`001EKm00@005KmE_eFo@<000EFo@03
001FoEKm00<00003E_d005Km00AFo@03001Fo@0000800003Ool007oo025oo`00HWoo0`00WWoo0`00
C7oo00<005Km00000P000UKm00<005KmE_d00UKm00<005Km00000P000UKm00<005KmE_d00eKm2@00
00<0M@0000001P0000@0UP0000000080]P050000]P000000eP0200030=H300000`Cf0008m`022?L3
00024?H200025AL00`005AHE5P0200026AH010006AH000000Qdf00P0024f8CH0024f000U=P000bEF
00<002EF9EH00P000bUF00@002eF;EH000<]EP8000@aMP05000aMS5f<GH00003<GH00`00=GH00002
0004=GH00`00>IHiUP02>IH00`00>IDiU@02>ID01@00>IDiUCVE00000cfE10000SfE00<003fe?KD0
0cfe00<0046e@KD00T6e00<0046e@KD00d6e00<0046e@KD00T6e00<004FeAKD00dFe00<004FeAKD0
0TFe00<004GEAMD00dGE00<004GEAMD00dGE00<004WEBMD00TWE00<004WEBMD014WE00<004WE0000
0P0000=9e@00CMD014gE00<004gECMD00dgE00<004geCOD014ge00<004geCOD00dge00<004geCOD0
0Tge0P001Tge00<0057eDOD00e7e00<0057eDOD0157e00D0057eDOEAm@00009Am@03001F5EHE00AF
5@03001F5EHE00EF5@03001F5@0000AF5@03001F5EHE00AF5@03001F5EHE009F5@04001F55HD0006
FQD01@00FSEJ=EXe00000UXe00<005XeFSD01EXe00@005XeFSD000AJ=@03001N=Ehe00AN=@03001N
=5hd00EN=004001NEEiE0005GUD00`00GUENE@03GUD00`00HUD00007HUD00`00HUERE@06HUD00`00
HWERM@06HWD00`00IWEVM@06IWD00`00IWEVM@06IWD00`00IYEVU@05IYD00`00JYD00005JYD01@00
JYEZUFZE00000VZE00<006ZEJYD00VZE00<006Ze00001VZe00<006Ze000016Ze00<006jeK[D00fje
00<006kEK]D00fkE00L006kEK]E^e@00K]D00005K]D01P00L]Ebe@00L_D000Ebm@07001bmG;eL_D0
07;f00000g;f00<007<FLaH00g<F00D007<FLaIc5P0000Ag5P05001g5WLFMaH00004McH01@00McIg
=WLf00000gLf00D007]F001gEP0000=kEP04001kEW]F0003NgH01000NgIkMW]f0P0000EkMP00NgIk
MP00009kUP04001kUW^F0002NiH00`00NkH00003NkH01@00NkH007^f00000W_F00d007_FNmH007_F
001keP00NmH007OF001gmP0200001gOf001cmP00LoH007?f00<00003JoD0000000@00003Hm@00000
00L000EFo@@000=Fo@03001FoEKm00=Fo@8000EFo@04001FoEKmE_d40005E_d01000E_eFoEKm1000
0UKm00D005KmE_d005Km00<00003E_d005Km00AFo@03001FoEKm00<00003E_d005Km00AFo@@000=F
o@03001FoEKm00=Fo@@0009Fo@03001FoEKm00=Fo@<000EFo@04001FoEKmE_d30005E_d00`00E_eF
o@0300000eKm001Fo@04E_d00`00E_d000020002E_d00`00E_eFo@03E_d00`00E_d0000200000eKm
001Fo@05E_d40002E_d00`00E_eFo@03E_d30005E_d01000E_eFoEKm0`0017oo00<007ooOol087oo
001ROol00`00Oomoo`2LOol2001@Ool00`00E_eFo@04E_d00`00E_eFo@040005E_d00`00E_d00002
0002E_d00`0005<0000>0000102F0000]P000P2f0P0000D0]P000000eP000080eP060000eP000004
mP000PSg00@000cf0000008@mP80000?5AL001DF5AH001DF000I5P006AH001dF000M=P00008Q=P03
000Q=R4f008000<UEP04000UEREF9EH20002:EH01@00;EH]EReF00000beF0P000c5f00D0035f<GHa
MP0000<aMP04000eMSEf=GH20003=GH00`00>IHiUP02>IH00`00>IDiU@02>ID01@00>IDiUCVE0000
1CfE00<003fE00000`0013fe00<0046e@KD00T6e00<0046e@KD00d6e00<0046e@KD00T6e00<004Fe
AKD00dFe00<004FeAKD00TFe00<004GEAMD00dGE00<004GEAMD00dGE00<004WEBMD00dWE00<004WE
BMD01@0014WE00<004gECMD00dgE00<004gECMD00dgE00<004geCOD014ge00<004geCOD00dge00<0
04geCOD00P0000==m@00COD01Dge00<0057eDOD0157e00<0057eDOD0157e00<0057e0000157e00<0
05HEEQD015HE00<005HEEQD015HE0P001EHE00<005HEEQD015HE00D005HEEQEF5@0000=F5003001J
5EXE00AJ5@04001J=EXe0003FSD00`00FSEJ=@06FSD20005FSD00`00GSEN=@03GSD20007GS@01000
GUENE@001EiE00<005iEGUD00UiE00@0069EHUD000IRE@03001RE@0000MRE@03001RMF9e00IRM@03
001VMFIe00IVM@03001VMFIe00EVM@8000IVU@04001ZUFZE0004JYD00`00JYEZU@02JYD01000JYEZ
U@001FZE00<006ZeJ[D016Ze00@006ZeJ[D000=Z]@03001^]Fje00A^]@03001^eFkE00=^e@07001^
eFkEK]D006kE00001FkE00@007;EL]Ebe@8000Ebm@03001bmG;e009bm@03001bmW;f009bmP03001c
5W<F009c5P05001g5P00LaH00004MaH01`00MaIg5WLF001g=P00009g=P05001g=WLfMcH00004McH0
0`00NeIkEP020002NeH01@00NeIkEW]F00000W]f00D007]fNgIkMP00009kMP<00004NgH007^F0003
NiH00`00NiH00002NkH01000NkIk]P000W^f00<007^f00000W_F00L007_F001keP00NmH00002NmH2
00000gOf001gmP020002LoH00`00LoH0000200000foe0000000400000f?D000000070002IoP00`00
E_d000020002E_d00`00E_eFo@03E_d00`00E_d0000200000eKm001Fo@04E_d40003E_d00`00E_eF
o@03E_d40004E_d00`00E_eFo@040005E_d01000E_eFoEKm10001EKm00<005Km00000P0000=Fo@00
E_d01EKm00<005Km00000P0000=Fo@00E_d015Km00<005Km00000P000UKm00<005KmE_d00eKm1000
0UKm00<005KmE_d00eKm0`001EKm00@005KmE_eFo@<000IFo@04001FoEKmE_d30005E_d00`00E_eF
o@0300000eKm001Fo@04E_d00`00E_d0000200000eKm001Fo@05E_d40007Ool00`00Oomoo`0POol0
065oo`03001oogoo09Yoo`<005=oo`03001FoEKm00=Fo@<000AFo@80009Fo@<000IFo@030000D`00
00d00080UP<000070;H000000000]P000=H00P0000H0eP000=H0eP001?H200001@Sg000<mPcf0000
0Q3f00@0013f000000<E5P04000E5P0000026AH010007AH000000b4f00<0024f8CH00P000REF00T0
02EF9EHUEP00:EH002UF00000beF00L002eF;EH]EP00;EH00002<GH01@00<GHaMS5f0000135f00@0
03Ef=GHeMP80008eMP03000iUSVF00<iUP05000iUCVE>ID00004>ID00`00?IDmU@02?ID00`00?IDm
U@02?ID40002?KD01@00@KE1]D6e00001D6e00<0046e@KD00T6e00<004FeAKD00dFe00<004FeAKD0
0TFe00<004GEAMD00dGE00<004GEAMD014GE00<004WEBMD01@000dWE00<004WEBMD014WE00<004gE
CMD00TgE00<004gECMD00dgE00<004geCOD014ge00<004geCOD014ge0P000dge00<004geCOD014ge
00<0057eDOD0157e00<0057eDOD0157e0P001E7e00<005HEEQD015HE00<005HEEQD00eHE0P001UHE
00<005HEEQD015HE00@005HEEQD000AF5003001J5EXE00AJ5@04001J=EXe0004FSD00`00FSEJ=@05
FSD00`00FSEJ=@04FSD00`00GSEN=@03GSD00`00FS@00007GS@20007GUD01000GUENE@00169E00<0
069EHUD00f9E00<0069E00001V9E00<0069E00001V9e0P001fIe0P001fIe00<006JE00001FJE00@0
06ZEJYD000AZU@03001ZUFZE009ZU@03001ZU@0000IZU@03001Z]FZe00AZ]@05001Z]FZeJ[D00002
J[D00`00K[E^]@03K[D00`00K]D00003K]D00`00K]E^e@03K]D00`00K]E^e@03K]D00`00L]Ebe@02
L]D00`00L_Ebm@03L_D00`00L_Ebm@03L_D01@00L_IbmW;f00001G<F00D007LF001c5P0000Ag5P05
001g5WLFMaH00002McH00`00McH00003McH01@00McIg=WLf00000g]F00D007]F001kEP00009kEP05
001kMW]fNgH00003NgH01000NgIkMP000W]f0P0000EkUP00NiIkUP00009kUP03001k]P0000=k]P05
001k]P00NkH00002NmH01@00NmH007_F00000W_F00H007_F001geP00MoH200001GOf001cmP00LoH0
0P0000=_m@0000000P0000=[m@00Hm@02P000VOh0`001UKm00@005KmE_eFo@<000EFo@03001Fo@00
0080009Fo@03001FoEKm00=Fo@03001Fo@0000800003E_d005Km00EFo@@0009Fo@03001FoEKm00=F
o@@000=Fo@03001FoEKm00=Fo@8000EFo@04001FoEKmE_d40005E_d01000E_eFoEKm0`001UKm00<0
05Km00000P0000=Fo@00E_d015Km00<005Km00000P000UKm00<005KmE_d00eKm10000UKm00<005Km
E_d015Km10000eKm00@005KmE_eFo@@000EFo@03001FoEKm00@000EFo@03001FoEKm00<000]oo`03
001oogoo021oo`00HGoo00<007ooOol0Ugoo0`00Egoo00<005Km00000P000UKm00<005KmE_d00eKm
0`000eKm00<005KmE_d00eKm300000<0M@0009D0100000@0]P000000]P800080]P060000eP000000
eP000P3F00H000Cf000000Sg00023?H00`004?H000024?H200025AH00`005AHE5P02000011TF000M
5QdF0P000R4f00@0024f8CHQ=P80008UEP04000UEREF0002:EH20003;EH01@00;EH]EReF00000ReF
0`00135f00D0035f<GHaMP0000<eMP03000eMP00008000DiUP05000iUCVE>ID00004>ID00`00?IDm
U@03?ID01@00?IDmUCfE00000cfE1P0000=1]@00@KD0146e00D0046e@KE1]@0000E5]@030015]DFe
00=5]@030015eDGE00=5e@030015eDGE00H00099e@030019eDWE00=9e@030019eDWE00A9e@03001=
eDgE009=e@03001=eDgE00A=e@03001=mDge00==m@03001=mDge00==m@8000E=m@03001=mDge00==
m@03001AmE7e00AAm@03001AmE7e00=Am@8000IAm@03001F5EHE00AF5@03001F5EHE009F5@03001F
500000IF5@03001F5EHE00EF5@8000EF5003001J5EXE00EJ5@8000EJ=@03001J=EXe00EJ=@03001J
=EXe00AJ=@03001N=Ehe009N=@04001J=5Xd0007GS@00`00GUENE@06GUD01000GUENE@00169E00<0
069EHUD00V9E00@0069EHUD000IRE@03001RE@0000IRM@03001RM@0000IVM@03001VM@0000EVM@04
001VUFJE0004IYD00`00JYEZU@02JYD01000JYEZU@001VZE0P001FZE00<006ZE000016Ze00<006Ze
J[D00VZe00<006Ze00001Vje00<006kE00000fkE00<006kEK]D00fkE00<006kEK]D00fkE00<007;E
L]D00W;E00<007;eL_D00W;e00<007;eL_D00g;e00<007;e00000W;f00<007<FLaH00W<F00D007LF
MaIg5P0000Ag5P03001g5WLF009g5P05001g=WLfMcH00004McH01@00McIg=WLf00000W]F00D007]F
NeIkEP00009kEP05001kMW]fNgH00003NgH01000NgIkMP000g]f00<007^F00000P0000AkUP00NiH0
009k]P08001k]W^f001k]P00NkH0009keP0?001keW_F001keP00NmH007_F001geP00MoH007Of0080
0005LoH00000001_m@0400000f_e0000000400000e^c000000070002E_d00`00E_eFo@04E_d40002
E_d00`00E_eFo@03E_d20006E_d01000E_eFoEKm0`001EKm00<005KmE_d00`0000EFo@00E_eFo@00
009Fo@03001Fo@0000800003E_d005Km00EFo@03001Fo@0000800003E_d005Km00AFo@@000=Fo@03
001FoEKm00=Fo@@000=Fo@04001FoEKmE_d40005E_d01000E_eFoEKm0`001UKm00<005Km00000P00
00=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d015Km10000UKm00<005KmE_d00eKm10000eKm
00<005KmE_d00eKm0`003Woo00<007ooOol087oo001QOol00`00Oomoo`2DOol3001KOol00`00E_eF
o@04E_d00`00E_d000020002E_d00`00E_eFo@02E_d00`00E_d000020002E_d500001`1d00000000
07D0001e00<0000509D000000000UP0200000`2f0000]P0300000`3F000000020=H010001?H000SF
0P000Pcf0P0000D@mP004?H@mP00008E5P07000E5QDF5AH001TF00000adF00@0024f8CH000<Q=P05
000Q=P009EH000039EH00`00:EHYEP020003;EH01@00;EH]EReF00000beF0P000c5f00D0035f<GHa
MP0000<eMP04000eMSEf=GH20004>IH00`00>IDiU@02>ID01@00>IDiUCVE00001CfE00D003fE?IDm
U@0000DmU@040011UD6E@ID;00000d6e0015]@04AKD00`00AKE5]@0;0003AMD00`00BME9e@02BMD0
0`00BME9e@04BMD00`00BME9e@03BMD00`00CME=e@02CMD00`00CME=e@04CMD00`00COE=m@03COD0
1000COE=mDge0P0000==m@00COD014ge00<004geCOD00dge00<0057eDOD0157e00<0057eDOD00U7e
00<0057d00001U7e00<005HEEQD015HE00D005HEEQEF5@00009F5003001F5EHE00EF5@03001F5EHE
00AF5@03001F55HD00AF5003001J5EXE00EJ5@03001J=EXe00AJ=@03001J=EXe00AJ=@8000MJ=@04
001N=Ehe0003FS@00`00GSAN=005GS@00`00GUENE@06GUD00`00GUD00005HUD00`00HUERE@02HUD0
1@00HUEREF9E0000169E00@0069EHUD000ERM@04001RMF9e0005IWD01000IWEVM@001FIe00@006JE
IYD000AVU@03001ZUFZE009ZU@04001ZUFZE0006JYD00`00JYEZU@04JYD00`00JYD00004J[D00`00
J[EZ]@02J[D00`00J[D00005K[D01`00K]E^eFkE001^e@0000E^e@03001^e@0000=^e@03001beG;E
009be@03001bm@0000=bm@03001bmG;e00=bm@05001bm@00L_H00005LaH01@00MaIg5WLF000017LF
00D007LFMaIg5P0000Ag=P80009g=P05001g=WLfMcH00003NeH01000NeIkEW]F0P0000=kEP00NgH0
0W]f00D007]fNgIkMP00009kMP04001kMW]f0002NiH00`00NiIkUP02000017^F001k]P000g^f00D0
07^f001k]P00009keP07001keP00NmH007_F00000W_F00@007OF001gmPH00003LoD0000000800003
JoD0000000h000EFo@03001FoEKm00<00003E_d005Km00AFo@03001Fo@0000800003E_d005Km00EF
o@@0009Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm00@000EFo@04001FoEKmE_d40005E_d00`00
E_d0000200000eKm001Fo@05E_d00`00E_d0000200000eKm001Fo@04E_d40003E_d00`00E_eFo@03
E_d40002E_d00`00E_eFo@04E_d20005E_d01000E_eFoEKm10001EKm00<005Km00000P0000=Fo@00
E_d015Km00<005Km00000P0000=Fo@00E_d01EKm00<005Km00000P004Goo00<007ooOol087oo001Q
Ool00`00Oomoo`2AOol3001OOol00`00E_eFo@03E_d20006E_d00`00E_eFo@040005E_d<0000102E
0000002E0`0000<0UP000;H00P0000H0]P000000003F00030=H01@001?H000SF00000`cf0`000Q3f
0P000QDF00@001DF5AH0008I5P03000M5QdF0080008Q=P04000Q=R4f00028CH200039EH01000:EHY
ERUF0P000ReF00D002eF;EH]EP0000@]EP80008aMP05000aMS5f<GH00004=GH01000=GHeMSEf0`00
0SVF00<003VE>ID00SVE00D003VE>IDiU@0000DmU@03000mUCfE008mU@03000mUCfE008mU@030011
UD6E0091U@030011]D6e00=1]@040011]D6e@KD:0002AKD00`00AKE5]@03AKD00`00AME5e@03AMD0
0`00BME9e@03BMD00`00BME9e@03BMD00`00BME9e@03BMD00`00CME=e@03CMD00`00CME=e@03CMD0
0`00COE=m@04COD30003COD00`00COE=m@03COD00`00COE=m@04COD00`00DOEAm@03DOD01@00DOEA
mE7e00000U7d00<0057eDOD0157e00<005HEEQD015HE00@005HEEQD000AF5003001F5EHE00AF5@03
001F5EHE00=F5@8000MF5003001J5EXE00AJ5@03001J=EXe00AJ=@03001J=EXe00=J=@04001J=EXe
0006FSD01000GSEN=@0015Xd00<005hdGS@00ehd0P002EiE0P001V9E00@0069EHUD000ARE@03001R
EF9E009RE@05001REF9EHUD00004HWD01000HWERM@001FIe00@006IeIWD000AVM@03001VUFJE009V
U@04001VUFJE0005JYD00`00JYD00007JYD00`00JYEZU@04JYD00`00JYD00003J[D00`00J[EZ]@04
J[D00`00K[E^]@04K[D01`00K]E^eFkE001^e@0000E^e@03001^e@0000=^e@03001beG;E009be@06
001bmG;e001bm@001G;e00H007;eL_D007;f0004LaH01`00MaIg5WLF001g5P00009g5P03001g5WLF
009g5P05001g=WLfMcH00002McH00`00McH00002McH01@00NeIkEW]F00000g]F00<007]FNeH00P00
0W]f00D007]fNgIkMP00009kMP07001kMW]fNgH007^F00000g^F00H007^F000007^f0002NkH01@00
NkH007^f00000W_F00d007_FNmH007_F001keP00NmH007OF001gmP0200001G?e001cm@00LoD00`00
00E_m@00000006OD00`0009[n`04001FoEKmE_d40005E_d01000E_eFoEKm0`001EKm00<005KmE_d0
0`0000=Fo@00E_d015Km00<005Km00000P0000=Fo@00E_d01EKm1@0000=Fo@00E_d015Km10000eKm
00<005KmE_d00eKm0P001EKm00@005KmE_eFo@@000EFo@03001Fo@0000800003E_d005Km00EFo@03
001Fo@0000800003E_d005Km00AFo@03001FoEKm00<00003E_d005Km00AFo@@0009Fo@03001FoEKm
00AFo@8000EFo@04001FoEKmE_d30005E_d01000E_eFoEKm10005Goo00<007ooOol07goo001QOol0
0`00Oomoo`2>Ool3001SOol00`00E_d000020002E_d00`00E_eFo@03E_d30004E_d00`00E_eFo@02
E_d900000`1d0000000200000`1e0000U@02000209H00`000;H0000200001@2f0000eP3F00000P3F
0`000PSF00H000cf3?H000cf00034?H2000011DF000E5QDF0P0000TI5P007AHM5P007CH0024f0000
0b4f00<0024f8CH00P000REF00T002UF:EHYEP00:EH002eF00000beF00<002eF;EH00ReF00<0035f
00000P00135f00D003Ef=GHeMP0000<eMP03000eMCEe00@000<iU@03000iUCVE008iU@03000mUCfE
008mU@03000mUCfE008mU@03000mUCfE00<mU@050011UD6E@ID00005@KD00`00@KE1]@02@KD00`00
AKE5]@03AKD00`00AKE5]@02AKD00`00AKE5]@03AKD00`00AME5e@04AMD00`00BME9e@02BMD00`00
BME9e@03BMD00`00BME9e@03BMD00`00CME=e@03CMD00`00CME=e@03CMD00`00COE=m@03COD20006
COD00`00COE=m@02COD00`00COE=m@04COD00`00DOEAm@04DOD00`00DOD00004DO@00`00DOEAm@04
DOD00`00EQEF5@04EQD20005EQ@00`00EQEF5@04EQD00`00EQEF5@02EQD00`00EQD00007EQ@00`00
FQEJ5@03FQD20007FSD01@00FSEJ=EXe00000eXe00<005XeFSD015Xe00<005he00001EXd00<005hd
GS@00ehd00<005hd000025iE00<0069EHUD01F9E00@0069EHUD000ARE@05001REF9EHUD00004HUD0
1@00HWERMF9e0000169e00D006IeIWEVM@0000AVM@05001VMFIeIWD00004IYD01000IYEVU@001VZE
0P001VZE00<006ZE000016ZE00D006ZEJYEZU@00009Z]@03001Z]FZe00AZ]@03001^]Fje00=^]@03
001^eFkE009^e@03001^e@0000E^e@06001^eFkE001^e@001G;E00H007;eL_D007;e0005L_D01@00
L_EbmG;e000017<F00<007LFMaH00WLF00H007LFMaH007LF0003MaH00`00McIg=P02McH01@00McIg
=WLf00000gLf00D007]FNeIkEP0000=kEP08001kEW]F001kMP00NgH000=kMP04001kMW]f0002NgH0
1000NiIkUP000W^F00D007^FNiH007^f00<00006NkH007^f001k]P000W_F00L007_F001keP00NmH0
0002NmH400001WOf000007?e001cm@800005KoD00000001[e004000015oC000005Nc1@000f_k1000
0eKm00<005KmE_d00eKm10000UKm00<005KmE_d00eKm0`001EKm00@005KmE_eFo@<000EFo@03001F
oEKm00<00005E_d005KmE_d00002E_d00`00E_d0000200000eKm001Fo@05E_d00`00E_d000020000
0eKm001Fo@04E_d40003E_d00`00E_eFo@03E_d20005E_d01000E_eFoEKm10001EKm00@005KmE_eF
o@@000EFo@03001Fo@0000800003E_d005Km00AFo@03001FoEKm00<00003E_d005Km00AFo@@0009F
o@03001FoEKm00=Fo@@001Uoo`03001oogoo01moo`00HGoo00<007ooOol0Rgoo0`00Igoo00<005Km
E_d015Km00<005Km00000P000UKm00<005KmE_d00eKm00@005Km0000009Fo@P0000307@000000080
000307D0002E0080000509H000000000]P0200000`2f0000eP020000103F0000eP000PSF0P0000D<
mP003?H<mP00008@mP04000@mP0000035AH300037AH010007CH000000b4f00D0024f8CHQ=P0000<U
EP04000YERUF0002:EH20003;EH00`00;EH]EP02;EH01000<GHaMS5f0P000c5f00D003Ef=GHeMP00
00<eMP03000eMCEe00<eM@80008iU@03000iUCVE008iU@03000mUCfE00<mU@05000mUCfE?ID00005
?ID00`00@IE1U@02@ID00`00@KE1]@03@KD01@00@KE1]D6e00001DFe00<004FeAKD00dFe00<004Fe
AKD00dFe00<004GEAMD00dGE00<004WEBMD00TWE00<004WEBMD00dWE00<004WEBMD014WE00<004gE
CMD00TgE00<004gECMD00dgE00@004geCOE=m@800003COD004ge00E=m@03001=mDge00==m@03001=
mDge00==m@03001AmE7e00AAm@8000EAm003001AmE7e00AAm@03001F5EHE00=F5@8000IF5003001F
5EHE00AF5@05001F5EHEEQD00003EQD00`00EQAF5004EQ@00`00FQEJ5@02FQD01000FSAJ=0001UXe
00D005XeFSEJ=@0000=J=@03001J=EXe00EJ=@8000EJ=003001N=5hd009N=004001N=5hd0008GUD0
0`00HUERE@05HUD00`00HUD00006HUD01000HUERE@00169E00D0069eHWERM@0000ARM@04001VMFIe
0005IWD01000IWEVM@001FJE00<006JE00001fZE00<006ZEJYD01FZE00<006ZE000016ZE00L006ZE
JYEZU@00J[D00006J[D00`00K[D00004K[D00`00K]E^e@03K]D00`00K]E^e@03K]D01`00K]E^eFkE
001^e@0000Abe@03001bmG;e009bm@03001bmG;e00=bm@03001bmG;e009bm@03001c5W<F009c5P03
001g5WLF009g5P05001g5WLFMaH00004MaH01@00McIg=WLf000017Lf00@007LfMcH000=kEP05001k
EW]FNeH00002NeH01000NgIkMW]f0P000W]f00@007]fNgH000=kMP03001kUP00009kUP04001kUW^F
0002NkH00`00NkIk]P0A00000gOF001gmP0300001G?e001cm@00KoD00`0000=[m00000000P0000=O
d`0000001`0000I[n`00000005Km0006E_d00`00E_d0000200000eKm001Fo@04E_d00`00E_d00002
0002E_d00`00E_eFo@03E_d40002E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@040005E_d01000
E_eFoEKm10001EKm00<005Km00000P0000=Fo@00E_d01EKm00<005Km00000P0000=Fo@00E_d015Km
10000eKm00<005KmE_d00eKm10000UKm00<005KmE_d015Km0P001EKm00@005KmE_eFo@@000EFo@03
001Fo@0000800003E_d005Km00AFo@03001Fo@00008001eoo`03001oogoo01moo`00H7oo00<007oo
Ool0RGoo0`00Jgoo00<005KmE_d00eKm0P001UKm00@005KmE_eFo@<000EFo@P0000407@000000002
07D40000202F000000000;H0002f00020=H20000103F0000eP000PSF0P0000<<mP003?H00P0000@@
mP004?H@mP80008E5P04000I5P0000027AH00`007CHM=P0200028CH010008CHQ=R4f0P000REF00D0
02UF:EHYEP00008YEP8000<]EP05000]EReF;EH00004<GH20002<GH01@00=GHeMSEf000013Ef00<0
03Ee=GD00SEe00<003Ue00000`000cVE00<003fE?ID00cfE00D003fE?IDmU@0000DmU@030011UD6E
0091U@030011]D6e00=1]@030011]D6e0091]@030015]DFe00=5]@030015]DFe0095]@030015]DFe
00=5]@030015eDGE00=5e@030019eDWE0099e@030019eDWE00=9e@030019eDWE00A9e@03001=eDgE
009=e@03001=eDgE00A=e@<000==m@03001=mDge00A=m@03001=mDge00==m@03001=mDge00==m@03
001AmE7e00=Am@8000IAm003001AmE7e00AAm@03001F5EHE009F5@03001F5@0000IF5003001F5EHE
00AF5@04001F5EHE0004EQD00`00EQAF5004EQ@01@00FQEJ5EXE00000eXd00<005XeFSD015Xe00@0
05XeFSD000AJ=@03001J=EXe00EJ=@03001J=5Xd00AJ=003001N=5hd009N=004001N=5hd0007GUD2
0008HUD20006HUD00`00HUD00006HUD01000HWERM@00169e00@006IeIWD000EVM@04001VMFIe0006
IYD20007JYD00`00JYEZU@04JYD01000JYEZU@000fZE00<006ZEJYD00VZE00<006Ze00001VZe00<0
06je00000fje00<006kEK]D016kE00<006kEK]D00fkE00<006kEK]D00VkE00<007;EL]D00g;E00<0
07;eL_D00W;e00<007;eL_D00g;e00L007;eL_Ebm@00LaD00002LaH00`00MaIg5P02MaH00`00MaIg
5P02MaH01@00MaIg5WLF000017Lf00T007LfMcIg=P00McH007Lf00000g]F00D007]FNeIkEP00009k
EP09001kMW]fNgH007]f001kMP00009kMP04001kMW]f0002NiH01000NiIkUP000W^F00<007^f0000
0g^f00D007^f001k]P00009keP07001keP00NmH007_F00000W_F0P0000AgmP00001cm@80009cm@<0
0003Jo@0000000l000EFo@04001FoEKmE_d40005E_d01000E_eFoEKm0`001UKm00<005Km00000P00
00=Fo@00E_d015Km00<005Km00000P000UKm00<005KmE_d00eKm1@0000=Fo@00E_d015Km10000eKm
00<005KmE_d00eKm0P001EKm00@005KmE_eFo@@000EFo@03001Fo@0000800003E_d005Km00EFo@03
001Fo@0000800003E_d005Km00AFo@03001FoEKm00<00003E_d005Km00AFo@@0009Fo@03001FoEKm
00AFo@8000EFo@04001FoEKmE_d3000POol00`00Oomoo`0OOol0061oo`03001oogoo08Moo`8006mo
o`03001Fo@000080009Fo@03001FoEKm00=Fo@@000=Fo@03001FoEKm009Fo@T0000707@000000000
M@0009D0100000X0UP000;H0]P000;H0003F0000]P8000060=H000002=H000SF0P000Pcf0P0000D@
mP004?H@mP00008E5P04000I5QTF00027AH010007CHM=Qdf0P000R4f00P0024f8CH002Df000UEP00
0bUF00@002UF:EHYEP80008]EP03000]EReF008]EP06000aMS5f<GH0035f0`0013Ef00D003Ef=GHe
MP0000@eM@03000iMCUe008iM@80008iU@03000mUCfE00<mU@03000mUCfE008mU@03000mUCfE008m
U@030011UD6E0091U@030011]D6e00=1]@030011]D6e0091]@030015]DFe00=5]@030015]DFe0095
]@030015]DFe00=5]@030015eDGE00=5e@030019eDWE0099e@030019eDWE00A9e@030019eDWE00=9
e@03001=eDgE009=e@03001=eDgE00==e@8000I=m@03001=mDge00==m@03001=mDge00==m@03001=
mDge00==m@04001AmE7eDOD200000e7e001Am005DO@00`00DOEAm@04DOD01@00EQEF5EHE00000UHE
00<005HDEQ@015HD00<005HEEQD01EHE0P001EHE00<005HDEQ@015HD00D005XEFQEJ5@0000=J=003
001J=EXe00EJ=@8000IJ=@03001J=EXe00AJ=@03001J=5Xd00EJ=004001N=5hd0004GS@00`00GUEN
E@03GUD01000HUERE@001f9E00<0069EHUD01F9E00<0069E00001V9E00<0069e00001F9e00<006Ie
00001VIe00<006Ie00001fJE00<006ZEJYD01FZE00<006ZE00001FZE00D006ZEJYEZU@00009ZU@03
001ZUFZE00=ZU@03001Z]FZe00EZ]@04001^]Fje0002K[D00`00K]E^e@03K]D00`00K]D00003K]D0
0`00K]E^e@03K]D00`00L]Ebe@02L]D00`00L_Ebm@02L_D00`00L_D00003L_D00`00L_Ebm@02L_D0
1P00LaEc5@00LaH000Ag5P07001g5WLFMaH007LF00000WLF00D007LfMcIg=P0000Ag=P04001g=WLf
0004NeH01000NeIkEP000W]F00D007]fNgIkMP0000=kMP04001kMW]f0003NgH00`00NiH00002NiH0
1000NiIkUP000W^f00P007^fNkH007^f001k]P000W_F00L007_F001keP00NmH00002NmH01@00MmH0
0000MoH00P0000=cm@00LoD00P0000=_m@0000001`0000=K/`0000001@0000=Fo@00E_d015Km1000
0eKm00<005KmE_d00eKm10000eKm00@005KmE_eFo@@000EFo@04001FoEKmE_d30006E_d00`00E_d0
000200001EKm001FoEKm00000UKm00<005Km00000P000UKm00<005KmE_d00eKm00<005Km00000P00
00=Fo@00E_d015Km10000eKm00<005KmE_d00eKm0P001EKm00@005KmE_eFo@@000EFo@04001FoEKm
E_d40005E_d00`00E_d0000200000eKm001Fo@04E_d00`00E_eFo@0300000eKm001Fo@04E_d4000S
Ool00`00Oomoo`0OOol0061oo`03001oogoo08Aoo`<0079oo`8000EFo@03001Fo@000080009Fo@03
001FoEKm00=Fo@04001Fo@000003E_d;0000101e0000001e0`0000D0UP000;H0002f008000040=H0
002f00020=H2000010SF0008eP000Pcf00@000cf0000008@mP80008E5P04000I5P0000027AH02000
7CHM=P007CH0024f00038CH010009CH000000bUF00T002UF:EHYEP00:EH002eF000012eF00D0035f
<GHaMP0000<aMP8000<eMP05000eMSEf=GH00005=GD01P00>GDiMCUe000iU@<000DmU@03000mUCfE
008mU@03000mUCfE00<mU@050011UD6E@ID00005@KD00`00@KE1]@02@KD00`00AKE5]@03AKD00`00
AKE5]@02AKD00`00AKE5]@03AKD00`00AME5e@03AMD00`00BME9e@03BMD00`00BME9e@03BMD00`00
BME9e@03BMD00`00CME=e@03CMD00`00CME=e@0200000dgE001=m@05COD00`00COE=m@03COD00`00
COE=m@04COD00`00COE=m@03COD30003DOD00`00DOAAm004DO@00`00DOEAm@04DOD01000EQEF5@00
15HE00<005HDEQ@015HD00<005HEEQD015HE00<005HEEQD015HE00<005HDEQ@01EHD00<005XE0000
15Xd00<005XeFSD01EXe00<005XeFSD01EXe00<005XeFSD00eXe0P001eXd00@005hdGS@000AN=003
001NEEiE00=NE@04001REF9E0007HUD00`00HUERE@06HUD00`00HUERE@05HUD00`00HWD00006HWD2
0007IWD20007IYD00`00JYEZU@05JYD00`00JYD00004JYD00`00JYEZU@02JYD00`00JYD00006JYD0
0`00J[EZ]@04J[D01`00K[E^]Fje001^]@0000I^e@03001^e@0000=^e@03001^eFkE009^e@03001^
e@0000=be@03001bmG;e009bm@03001bm@0000=bm@03001bmG;e009bm@05001c5G<ELaD00004MaH0
0`00MaIg5P02MaH01P00MaIg5P00MaH000=g=P05001g=WLfMcH00003McH20002NeH01@00NeIkEW]F
00000W]F00D007]fNgIkMP0000=kMP800005NgH007]fNgH00002NiH01000NiIkUP000W^F00<007^f
00000g^f00D007^f001k]P00009keP0<001keP00NmH007_F001keP00MmH007Of0P0000=cm@000000
0P0000=_m@000000100000=Se00000001`001EKm00<005Km00000P000UKm00<005KmE_d00eKm00<0
05Km00000P0000=Fo@00E_d015Km10000eKm00<005KmE_d00eKm10000UKm00<005KmE_d015Km0P00
1EKm00<005KmE_d010001UKm00@005KmE_eFo@<000EFo@03001Fo@000080009Fo@03001FoEKm00=F
o@03001Fo@0000800003E_d005Km00AFo@@000=Fo@03001FoEKm00=Fo@@000=Fo@04001FoEKmE_d4
0005E_d01000E_eFoEKm10001EKm00<005Km00000P009goo00<007ooOol07goo001POol00`00Ool0
0002001oOol3001gOol00`00E_eFo@02E_d20006E_d01000E_eFoEKm0`001UKm3P0000D0M@000000
UP000080]P030000]P0000800080]P040000eP000=H200022=H00`003?H000023?H010004?H@mQ3f
0P0000@E5P006AHI5P8000057AH001df7CH000027CH200038CH00`009CHU=P020003:EH01000:EHY
EP000RUF0P0012eF00<0035f<GH00S5f00@0035f<GHaMP80008eMP05000eMSEf=GH00005=GD01@00
>GDiMCUe00000cVE0P0013fE00<003fE?ID00SfE00<003fE?ID00cfE00D0046E@IE1U@0000E1]@03
0011]D6e0091]@030015]DFe00=5]@030015]DFe0095]@030015]DFe00=5]@030015eDGE00A5e@03
0019eDWE0099e@030019eDWE00=9e@030019eDWE00=9e@03001=eDgE00==e@<000==e@03001=mDge
00A=m@03001=mDge00A=m@03001=mDge00==m@03001=mDge009=m@8000IAm@03001Am57d00AAm003
001AmE7e00AAm@8000EF5@03001F55HD00AF5003001F5EHE00=F5@8000IF5@03001F55HD00EF5080
00IJ=003001J=EXe00AJ=@03001J=EXe00EJ=@03001J=EXe009J=@04001J=EXe0006FS@00`00GS@0
0005GS@00`00GUENE@02GUD01@00HUEREF9E00001V9E0P00269E00<0069EHUD01V9E00<0069eHWD0
1F9e00<006IeIWD01VIe00<006JEIYD01FJE00<006ZE00001FZE00@006ZEJYD000AZU@03001ZUFZE
009ZU@03001ZU@0000EZU@03001Z]@0000EZ]@07001^]FjeK[D006je00001FkE00L006kEK]E^e@00
K]D00005K]D00`00K]D00002L]D00`00L_Ebm@03L_D01P00L_Ebm@00L_D000Abm@03001c5G<E009c
5@03001g5WLF009g5P03001g5WLF009g5P05001g5WLFMaH00004McH01@00McIg=WLf00000WLf00H0
07]FNeH007]F0003NeH00`00NeH00003NgH01@00NgIkMW]f00000W]f0`0000MkMP00NiIkUP00NiH0
0002NiH01000NkIk]P000W^f00D007^f001k]P00009keP07001keP00NmH007_F00000W_F0P0000=g
mP00MoH0100000=cm@0000000P0000=[m000Im@02`001EKm0P001UKm00@005KmE_eFo@<000EFo@03
001Fo@000080009Fo@03001FoEKm00=Fo@03001Fo@0000800003E_d005Km00AFo@03001FoEKm00<0
0003E_d005Km00AFo@D00003E_d005Km00EFo@@000=Fo@04001FoEKmE_d30006E_d01000E_eFoEKm
0`001EKm00<005Km00000P0000=Fo@00E_d01EKm00<005Km00000P0000=Fo@00E_d015Km10000eKm
00<005KmE_d00eKm10000UKm00<005KmE_d015Km0P00:Woo00<007ooOol07goo001POol2001oOol3
001kOol01000E_d000000UKm00<005KmE_d00eKm10000eKm00<005KmE_d00eKm3P000P1e0P0000<0
UP000;H00`0000L0]P000;H0]P000=H000020=H010002=H8eP000Pcf00@000cf3?H0008@mP04000D
mP0000026AH010006AH000000adf00<001df7CH00P000R4f00@002Df9CHU=P80008YEP05000YERUF
:EH00002:EH20003;EH00`00<GHaMP02<GH01P00<GHaMS5f000aMP<000@eMP03000eMCEe008eM@03
000iMCUe008iM@04000iUCVE>ID40002?ID01@00?IDmUCfE00001CfE00<0046E@ID00T6E00<0046e
@KD00d6e00D0046e@KE1]@0000E5]@030015]DFe00=5]@030015]DFe00=5]@030015eDGE00=5e@03
0019eDWE0099e@030019eDWE00=9e@030019eDWE00A9e@04001=eDgECMD20006CMD00`00COE=m@03
COD00`00COE=m@04COD00`00COE=m@03COD01`00COE=mDge001=m@0000IAm@03001Am57d00AAm003
001AmE7e00AAm@03001F5EHE00AF5@03001F55HD00AF5003001F5EHE009F5@03001F5@0000MF5@03
001F55HD00AF5003001J=5Xd00EJ=003001J=EXe00=J=@8000MJ=@05001J=EXeFSD00003FSD00`00
FSAJ=005FS@20006GS@01@00GUENEEiE00000f9E00<0069EHUD00f9E00@0069EHUD000IRE@8000QR
E@03001RMF9e00ERM@03001VMFIe00IVM@03001VUFJE00EVU@03001ZU@0000EZU@05001ZUFZEJYD0
0002JYD00`00JYEZU@04JYD20005JYD00`00J[D00004J[D00`00K[E^]@03K[D00`00K]E^e@04K]D0
1`00K]E^eFkE001^e@0000E^e@06001^eFkE001be@0017;e00L007;eL_Ebm@00L_D00004L_D01`00
LaEc5G<E001g5@00009g5P03001g5WLF009g5P03001g5WLF009g5P80009g=P05001g=WLfMcH00003
McH01000NeIkEW]F0P000W]F00@007]FNeH000=kMP05001kMW]fNgH00002NgH01000NiIkUP000W^F
00<007^F00000g^F00<007^f00000W^f00H007^fNkH007^f0002NmH2000017_F001keP000W_F00@0
07OF001gmP<00003LoD007?e00<00003Jo@0000000@00003Fk<0000000@0009Wn@03001Fo@000080
0003E_d005Km00EFo@@0009Fo@03001FoEKm00=Fo@8000IFo@04001FoEKmE_d30005E_d01000E_eF
oEKm10001EKm00<005Km00000P0000=Fo@00E_d00UKm00<005Km00000UKm0`0000=Fo@00E_d015Km
10000UKm00<005KmE_d015Km10000UKm00<005KmE_d00eKm0P001EKm00@005KmE_eFo@@000EFo@03
001Fo@0000800003E_d005Km00EFo@03001Fo@0000800003E_d005Km00AFo@03001FoEKm00<002eo
o`03001oogoo01ioo`00H7oo00<007ooOol0Ngoo0`00Ogoo0P0015Km00<005Km00000P000UKm00<0
05KmE_d00eKm00<005Km00000P000UKm1@0000T0E0000000001d0000M@0007D00P0000@0UP000000
]P800080]P060000]P2f0000eP000P3F00H000SF2=H000cf00023?H20000113f000DmQCf0P0000@I
5P006AHI5P80008M=P05000M=Qdf7CH000038CH020009CHU=P009CH002UF0003:EH01000:EHYERUF
0P000ReF00<0035f<GH00S5f00D0035f<GHaMP0000<aMP8000<eMP03000eMCEe008eM@03000iMCUe
008iM@05000iUCVE>ID00003>ID40002?ID00`00?IDmU@03?ID00`00@IE1U@02@ID00`00@KE1]@03
@KD00`00@KE1]@02@KD00`00AKE5]@03AKD00`00AKE5]@02AKD00`00AKE5]@03AKD00`00AME5e@03
AMD00`00BME9e@02BMD00`00BME9e@03BMD00`00BME9e@04BMD400000dgD001=e@05CMD00`00COE=
m@03COD00`00COE=m@04COD00`00COE=m@03COD01000COE=m@000Tge00<0057eDOD0157e00<0057d
DO@0157d00<0057eDOD00e7e0P001UHE00<005HDEQ@015HD00D005HEEQEF5@0000=F5@03001F5EHE
00AF5@03001F55HD00AF5003001J=5Xd00EJ=003001J=EXe009J=@04001N=Ehe0006FSD01000FSEJ
=@0015Xe00<005XdFS@01EXd00<005hdGS@01Ehd00@005iEGUD000ERE@03001REF9E009RE@04001R
EF9E0005HUD01000HUERE@001V9E0P001V9e00<0069d00001VIe00<006Ie00001FJE00@006ZEJYD0
00AZU@03001ZUFZE009ZU@04001ZUFZE0006JYD00`00JYEZU@04JYD01000J[EZ]@000fZe00<006je
K[D00fje00<006kEK]D00fkE00<006kEK]D00VkE00<006kE000016kE00L006kEK]E^e@00L]D00004
L_D00`00L_Ebm@02L_D00`00L_Ebm@02L_D00`00LaEc5@02LaD01P00MaEg5@00MaH000Ag5P05001g
5WLFMaH00002McH00`00McH00002McH01@00McIg=WLf000017]F00D007]F001kEP00009kEP04001k
MW]f0003NgH01000NgIkMP000g^F0P0000AkUP00NiH0009kUP04001k]W^f0002NkH01@00NkH007^f
00000W_F00L007_F001keP00NmH00002NmH2000017Of000007?e0P0000=cm@00KoD03`000VOi0`00
1EKm00<005KmE_d00`0000=Fo@00E_d015Km00<005Km00000P0000=Fo@00E_d01EKm10000UKm00<0
05KmE_d00eKm10000eKm00<005KmE_d00eKm0P001EKm00<005KmE_d01@001EKm00<005Km00000P00
00=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d015Km00<005Km00000P0000=Fo@00E_d015Km
10000eKm00<005KmE_d00eKm0P001EKm00@005KmE_eFo@@000EFo@04001FoEKmE_d4000`Ool00`00
Oomoo`0NOol005moo`03001oogoo07Uoo`<008Aoo`03001FoEKm00@000EFo@04001FoEKmE_d30006
E_d900001@1d0000000007D00P0000L0UP000000002F0000]P020000102f000000000P3F00<000SF
2=H00`000`cf0P0000D@mP005?HDmP00008I5P04000I5QTF00027CH010007CHM=Qdf0P000R4f00@0
02Df9CH0008U=P8000<YEP06000YERUF:EH002eF0P0000<]EP00<GH00S5f00<0035f<GH00S5f00@0
035f<GHaMP80008eMP03000eMCEe00<eM@05000iMCUe>GD00003>ID00`00>IDiU@03>ID00`00?ID0
00030004?ID00`00@IE1U@02@ID00`00@KE1]@03@KD00`00@KE1]@02@KD00`00AKE5]@03AKD00`00
AKE5]@02AKD00`00AKE5]@03AKD00`00AME5e@03AMD00`00BME9e@02BMD00`00BME9e@04BMD00`00
BME9e@02BMD20004CM@00`00CME=e@04CMD00`00COE=m@04COD00`00COE=m@03COD00`00COE=m@04
COD20003COD00`00DOEAm@04DOD00`00DOAAm004DO@00`00DOEAm@02DOD00`00EQD00006EQD00`00
EQAF5004EQ@01000EQEF5@0015HE00<005HEEQD015HE00<005HDEQ@00eHD0P001eXd00D005XeFSEJ
=@0000=N=@03001J=EXe00EJ=@8000EJ=@03001J=5Xd00EJ=003001N=5hd00EN=003001NE@0000IR
E@05001REF9EHUD00003HUD00`00HUERE@03HUD01000HUERE@001V9E00<0069E00001F9e00<0069d
00001VIe00<006Ie00001FJE00D006ZEJYEZU@00009ZU@03001ZUFZE00=ZU@03001ZU@0000MZU@03
001ZUFZE00=ZU@05001Z]FZeJ[D00002J[D00`00K[E^]@03K[D00`00K[D00004K]D00`00K]E^e@03
K]D00`00K]E^e@03K]D00`00K]E^e@02K]D00`00L_Ebm@02L_D00`00L_Ebm@03L_D00`00L_Ebm@02
L_D00`00LaEc5@02LaD01P00MaEg5@00MaH000=g5P03001g5WLF009g5P05001g=WLfMcH00003McH0
1@00McIg=WLf00000g]F00D007]FNeIkEP00009kEP05001kMW]fNgH00003NgH01000NgIkMP000W^F
00<007^FNiH01@0000AkUP00NkH0009k]P06001k]W^f001k]P000W_F0P0000AkeP00NmH0009keP05
001geP00001gm@0300000g?e001_m@0300000fOD0000000<0003E_d01000E_eFoEKm10001EKm00@0
05KmE_eFo@<000EFo@03001FoEKm00<00003E_d005Km00AFo@03001Fo@0000800003E_d005Km00EF
o@03001Fo@0000800003E_d005Km00AFo@D0009Fo@03001FoEKm00=Fo@8000EFo@04001FoEKmE_d4
0005E_d01000E_eFoEKm0`001EKm00<005Km00000P000UKm00<005KmE_d00eKm00<005Km00000P00
00=Fo@00E_d015Km10000eKm00<005KmE_d00eKm1000=7oo00<007ooOol07Woo001OOol00`00Oomo
o`1fOol30028Ool20004E_d00`00E_eFo@02E_d40003E_d00`00E_eFo@03E_d;00000`1e00000004
00000`2E0000UP020000102f0000002f0P000`3F00@000SF0008eP80008<mP04000<mP0000025?H2
000011TF000I5QTF0P000Qdf00P001df7CH0024f000Q=P000bDf00<002Df9CH00P000bUF00@002UF
:EH000<]EP8000@aMP05000aMS5f<GH00003<GH00`00=GD000020005=GD01@00>GDiMCUe000013VE
00<003VE>ID00SVE00<003fE?ID00SfE10000SfE00D0046E@IE1U@0000E1]@030011]D6e0091]@03
0015]DFe00=5]@030015]DFe0095]@030015]DFe00=5]@030015eDGE00=5e@030019eDWE00=9e@03
0019eDWE00=9e@030019e@0000800003BMD004gD00A=e003001=eDgE00==e@03001=mDge00A=m@03
001=mDge00==m@03001=mDge00==m@8000E=m@03001AmE7e00=Am@03001Am57d00AAm005001AmE7e
DOD00003EQD00`00EQEF5@04EQD00`00EQAF5004EQ@20005EQD00`00EQEF5@04EQD00`00EQAF5002
EQ@01000EOAEm0001UXd00@005XeFSD000AN=@03001J=EXe00EJ=@03001J=EXe00AJ=@03001J=5Xd
00AJ=08000QN=08000IRE@05001REF9EHUD00004HUD01@00HUEREF9E00000f9E00<0069EHUD00f9E
00@0069EHUD000ERM@03001RM00000EVM@04001VMFIe0004IYD00`00JYEZU@02JYD01000JYEZU@00
1VZE0P001VZE00<006ZE000016ZE00<006ZeJ[D00VZe00<006Ze00001Fje00<006je00000fkE00<0
06kEK]D016kE00<006kEK]D00VkE00<006kEK]D00fkE00<007;eL_D00W;e00<007;eL_D00W;e00<0
07;e00000W;e00<007<ELaD00W<E00<007LEMaD00WLE00<007LFMaH00WLF00D007LFMaIg5P0000Ag
=P04001g=WLf0003McH00`00NeIkEP02NeH01000NeIkEW]F0P0000=kEP00NgH00W]f00@007]fNgH0
009kMP05001kUW^FNiH00002NiH00`00NiH00002NiH200002G^f001k]W^f001k]P00NkH00002NmH0
1P00NmH007_F001kePD0000;MoD00000001cm@00LoD006oe001[e00200000fOD001O/`0700000eKm
001Fo@04E_d40003E_d00`00E_eFo@03E_d40002E_d00`00E_eFo@03E_d30005E_d01000E_eFoEKm
0`001EKm00@005KmE_eFo@@000EFo@03001Fo@0000800003E_d005Km009Fo@05001FoEKm001Fo@03
00000eKm001Fo@04E_d40002E_d00`00E_eFo@04E_d40003E_d01000E_eFoEKm0`001UKm00@005Km
E_eFo@<000EFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@00008003Qoo`03001oogoo01io
o`00Ggoo00<007ooOol0Lgoo0`00S7oo00<005KmE_d00eKm00@005Km0000009Fo@03001FoEKm00=F
o@03001Fo@0000800003E_d0000000X0000307D0000000800080U@030000UP00008000050;H00000
0;H000020=H2000010SF0008eP000Pcf00@000cf3?H000<DmP<000<I5P8000037CH001df008M=P04
000Q=P0000039CH010009CHU=RDf0P000RUF00D002UF:EHYEP0000<]EP8000<aMP05000aMS5f<GH0
0003<GH01000=GDeMCEe0P0013Ee00<003Ue>GD00SUe00D003VE>IDiU@0000DiU@05000mUCfE?ID0
0003?ID40002@ID00`00@KE1]@03@KD00`00@KE1]@02@KD00`00AKE5]@03AKD00`00AKE5]@02AKD0
0`00AKE5]@03AKD00`00AME5e@04AMD00`00BME9e@0:0004BMD00`00CMA=e003CM@00`00CME=e@03
CMD00`00COE=m@04COD00`00COE=m@04COD00`00COE=m@0200000dge001=m@04COD00`00DOEAm@04
DOD00`00DOAAm004DO@00`00DOD00004EQD00`00EQEF5@04EQD00`00EQAF5004EQ@00`00EQEF5@04
EQD00`00EQEF5@04EQD01@00EQAF55HD00000eGd00<005XdFS@01EXd0P001Ehe00<005XeFSD01EXe
00<005XeFSD01EXe00<005XdFS@00UXd00@005XDFQ@000MN=003001REF9E00ERE@04001REF9E0005
HUD01@00HUEREF9E00000f9E00<0069EHUD00f9E00@0069EHUD000ARM@05001RM69dHW@00004IWD0
1@00IWEVMFIe00000VJE00<006ZEJYD00fZE00<006ZE00001fZE00<006ZEJYD01FZE00<006ZE0000
0fZE00<006ZeJ[D00fZe00<006Ze00001Fje00@006jeK[D0009^e@03001^eFkE00=^e@03001^e@00
00=^e@03001^eFkE009^e@03001bm@0000=bm@03001bmG;e009bm@06001bmG;e001bm@0017<E00<0
07LEMaD00WLE00D007LFMaIg5P0000Ag5P09001g=WLfMcH007Lf001g=P0000=g=P05001kEW]FNeH0
0003NeH00`00NeIkEP020002NgH01000NgIkMP000g]f00@007^FNiH0009kUP03001kUP0000=kUP03
001k]P0000@00004NkH007^f0002NmH700000gOE001ge@0300001W?e000007?e001_m@d000AFo@03
001Fo@000080009Fo@03001FoEKm00=Fo@03001Fo@0000800003E_d005Km00AFo@03001Fo@000080
009Fo@03001FoEKm00=Fo@@0009Fo@03001FoEKm00=Fo@@000AFo@04001FoEKmE_d30005E_d01000
E_eFoEKm10001EKm00<005Km00000P0000=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d015Km
10000UKm00<005KmE_d015Km10000UKm00<005KmE_d00eKm0P001EKm00@005KmE_eFo@@003]oo`03
001oogoo01ioo`00Ggoo00<007ooOol0L7oo0`00T7oo00@005KmE_eFo@<000EFo@04001FoEKmE_d3
0005E_d400000`0c0000000500001P1e0000002E0000U@<0000609D000000;H0002f0P0000<0eP00
1=H00P0000<8eP0000000Pcf00@000cf3?H0008DmP04000DmP0000026AH010006AH000000adf00<0
024f8CH00P000RDf00T002Df9CHU=P00:CH002UF00000bUF00L002eF;EH]EP00;EH00002<GH01@00
<GHaMS5f0000135f00@003Ee=GDeM@8000<eM@03000iMCUe008iM@05000iUCVE>ID00005>ID01@00
?IDmUCfE00001CfE00<003fE00000`001D6e00D0046e@KE1]@0000E5]@030015]DFe00=5]@030015
]DFe00=5]@030015eDGE00H00095e@030019eDWE00=9e@030019eDWE00=9e@03001=e4gD00==e003
001=eDgE00A=e@03001=mDge00==m@03001=mDge00A=m@<000==m@03001=mDge00==m@03001AmE7e
00AAm@03001Am57d00AAm08000EF5@03001F5EHE00AF5@03001F55HD00=F508000IF5@03001F5EHE
00EF5@03001F500000AEm003001J=5Xd00EJ=003001N=Ehe00EN=@03001J=EXe00=J=@8000MJ=@03
001J=5Xd009J=004001J55XD0007GS@00`00HUERE@05HUD00`00HUD00006HUD01000HUERE@001F9E
00D0069EHUERE@0000=RE@03001RMF9e009RM@05001RM69dHW@00003IWD00`00IWEVM@02IWD01000
IYEVU@001VZE0P001fZE00<006ZEJYD016ZE00@006ZEJYD000=ZU@03001Z]FZe00AZ]@03001^]Fje
00=^]@07001^]FjeK[D006kE00001VkE00<006kE00000VkE00<006kEK]D00fkE00<007;e00000W;e
00<007;eL_D00g;e00H007;eL_D007;e0003LaD00`00MaEg5@02MaD00`00MaD00002MaH01@00MaIg
5WLF000017Lf00@007LfMcH000Ag=P05001kEW]FNeH00003NeH02000NeIkEP00NgH007]f0002NgH0
1000NgIkMP000g^F00H007^FNiH007^F0002NiH01000NkIk]P000W^f00<007^f00001@0000UkeP00
NmH007_F001ge@00MmD00P0000Agm@00001cmA0000EFo@8000IFo@04001FoEKmE_d30005E_d01000
E_eFoEKm0`001UKm00<005Km00000P0000=Fo@00E_d015Km00<005Km00000P000UKm00<005KmE_d0
0eKm10000UKm00<005KmE_d00eKm1@000UKm00<005KmE_d00eKm0P001EKm00@005KmE_eFo@@000EF
o@03001Fo@0000800003E_d005Km00AFo@03001FoEKm00<00003E_d005Km00AFo@03001Fo@000080
0003E_d005Km00AFo@@003moo`03001oogoo01ioo`00Ggoo00<007ooOol0KWoo0P00U7oo0`000eKm
00<005KmE_d00UKm10000eKm00<005KmE_d00eKm200000<0E00000000P1e100000H0U@000000002E
00020;H020000;H000000=H000CF00022=H200001@cf000<mPcf00000QCf00@001Cf5?H0008I5P03
000I5QTF0080008M=P04000Q=R4f8CH200029CH010009CHU=P000RTf0P000bUF00D002eF;EH]EP00
008]EP<000@aMP05000aMS5f<GH00003=GD01P00=GD00000=GD000@iM@05000iUCVE>ID00005>ID0
0`00?IDmU@02?ID00`00?IDmU@02?ID00`00?IDmU@02?ID:00000d6e0015]@04AKD00`00AKE5]@02
AKD00`00AKE5]@060003AMD00`00AME5e@02AMD00`00BME9e@03BMD00`00BME9e@04BMD00`00CMA=
e002CM@00`00CME=e@04CMD00`00COE=m@03COD00`00COE=m@03COD20006COD00`00COE=m@02COD0
0`00DOEAm@04DOD00`00DOAAm003DO@20006EQD00`00EQEF5@04EQD00`00EQAF5002EQ@00`00EO@0
0007EQD00`00EQEF5@04EQD20005EO@00`00FSAJ=005FS@00`00GSEN=@05GSD00`00FSEJ=@02FSD0
1000FQAJ50001UXe00D005XdFSAJ=00000=J5003001N=5hd00AN=08000QRE@8000IRE@03001RE@00
00IRE@04001REF9E0005HUD01000HWERM@00169d00D006IeIWEVM@0000AVM@03001VU@0000MZU@03
001ZUFZE00EZU@03001ZU@0000EZU@07001ZUFZEJYD006ZE00001fZe00<006jeK[D00fje00L006je
K[E^]@00K]D00005K]D01`00K]E^eFkE001^e@0000E^e@06001bmG;e001bm@0017;e00<007;eL_D0
0W;e00<007<ELaD00W<E00<007LEMaD00WLE00H007LEMaD007LF0003MaH01@00McIg=WLf00000gLf
0P000WLf00D007]FNeIkEP0000=kEP04001kEW]F0003NgH01000NgIkMP000g]f00@007^FNiH0009k
UP03001kUP0000=kUP03001k]P00009k]P06001k]W^f001k]P000W_F0P0000UkeP00NmH007OE001g
e@00MoD00P0000=cm@0000000P0000I_e000001We000Hm<700000f?g001Fo@0300000eKm001Fo@05
E_d40002E_d00`00E_eFo@03E_d40002E_d00`00E_eFo@04E_d20005E_d01000E_eFoEKm0`001UKm
00<005Km00000P0000=Fo@00E_d015Km00<005Km00000P0000=Fo@00E_d00UKm00D005KmE_d005Km
00<00003E_d005Km00AFo@@0009Fo@03001FoEKm00AFo@8000EFo@04001FoEKmE_d40005E_d01000
E_eFoEKm0`001EKm00<005Km00000P00@goo00<007ooOol07Woo001OOol00`00Oomoo`1[Ool3002G
Ool00`00E_eFo@03E_d01000E_d000000UKm00<005KmE_d00eKm00<005Km00000P0000EFo@000000
000b00@0000405@0000007D600002P2E0000002E0000]P000;H0002f0P000PCF00@000SF0008eP80
00<<mP05000DmQCf000DmP0200026AH00`006AHI5P0200027CH020008CHQ=P008CH002Df00039CH0
0`00:CHY=P020003:EH01@00;EH]EReF00000beF0P000c5f00D0035f<GHaMP0000<eM@04000eMCEe
=GD30003>GD00`00>IDiU@02>ID00`00>IDiU@02>ID00`00?IDmU@02?ID00`00?IDmU@02?ID00`00
?IDmU@02?ID00`00@IE1U@03@ID01000@KE1]D6e3`000dFe00<004GEAMD00dGE00<004GEAMD00dGE
00<004WEBMD00dWE00<004WEBMD00dWE00<004gDCM@00TgD00<004gECMD014gE00<004geCOD014ge
00<004ge00000P0000==m@00COD01Dge00<004geCOD00Tge00<0057eDOD0157e00<0057dDO@00U7d
00<0057d00001UHE00<005HEEQD015HE00D005HDEQAF500000=Em003001F5EHE00AF5@03001F5EHE
00AF5@03001Em5Gd00AEm003001J=5Xd00AJ=08000MN=@05001J=EXeFSD00003FQ@00`00FSEJ=@04
FSD01000FSAJ=00015XD00<005hdGS@015hd00<0069D00001f9E00<0069EHUD01V9E0P001V9E00@0
069EHUD000ERE@04001RMF9e0005HW@01000IWEVM@001FIe0P001fZE00<006ZEJYD01FZE00<006ZE
000016ZE00<006ZEJYD00VZE00<006ZE00001VZe00<006je00000fje00<006jeK[D00fje00<006kE
K]D016kE00L006kEK]E^e@00K]D00004K]D01`00L_EbmG;e001bm@0000Abm@03001bmG;e009bm@05
001c5G<ELaD00005MaD01@00MaEg5GLE000017LF00D007LfMcIg=P00009g=P06001k=W/f001g=P00
0g]F00D007]FNeIkEP00009kEP04001kMW]fNgH200000g]f001kMP02NgH00`00NiH00003NiH00`00
NiH00002NiH01P00NkIk]P00NkH0009k]P03001k]P00009keP0:001keP00NmH007_F001ge@00MmD2
00001gOe00000000Ko@006oD00/0009Sm`<000EFo@03001FoEKm00<00003E_d005Km00AFo@03001F
o@0000800003E_d005Km00AFo@03001FoEKm00<00003E_d005Km00AFo@@0009Fo@03001FoEKm00AF
o@8000EFo@04001FoEKmE_d30005E_d01000E_eFoEKm10001EKm00<005Km00000P0000=Fo@00E_d0
15Km00<005KmE_d00`0000=Fo@00E_d015Km10000UKm00<005KmE_d015Km10000eKm00@005KmE_eF
o@<004Ioo`03001oogoo01ioo`00Ggoo00<007ooOol0J7oo0`00Vgoo00@005KmE_eFo@<000EFo@04
001FoEKmE_d40004E_d300000`0b0000000500000`1e000000040000102E0000U@000P2f00D0002f
0000]P000084eP030008eP000088eP80008<mP8000085?H001Cf000DmP006AH0008I5P05000M5P00
7CH000028CH00`008CHQ=P0200039CH01000:CHY=RTf0P000RUF00D002eF;EH]EP0000@]EP80008a
MP05000aMS5f<GH00004=GD00`00=GDeM@02=GD20002>GD00`00>IDiU@02>ID00`00>IDiU@02>ID0
0`00?IDmU@02?ID00`00?IDmU@03?ID01@00?IDmUCfE00001D6E00<0046e@KD00T6e00<004FeAKD0
0dFe00<004FeAKD00TFe00<004FeAKD00dFe00<004GEAMD014GE00<004GEAMD00TGE00<004WEBMD0
0dWE00<004WEBMD00dWE00<004gDCM@00dgD00<004gECMD00dgE00<004geCOD00dge0`0014ge00<0
04geCOD014ge00<004geCOD00dge00<0057eDOD00e7e00D0057dDOAAm000009Am003001F5EHE00EF
5@03001F5EHE00AF5@03001F500000AEm003001F5EHE00AF5@03001F5EHE00=F5@8000MEm003001J
=5Xd009J=004001NEEiE0006GSD01@00FSEJ=EXe00000eXD00<005XeFSD015Xe00@005XdFS@000AJ
5003001N=5hd00=N=004001RE69D0007HUD00`00HUERE@06HUD00`00HUERE@05HUD00`00HUD00006
HUD00`00HWD00006HW@00`00IWD00006IWD00`00JYEZU@05JYD00`00JYD00005JYD01000JYEZU@00
16ZE00<006ZEJYD00VZE00<006ZE00001VZe00<006je00000fje00<006jeK[D00fje00<006kEK]D0
0fkE00<006kEK]D00fkE00<006kEK]D00fkE00<007;eL_D00W;e00<007;eL_D00W;e00<007;eL_D0
0W;e00<007<E00000W<E00<007LEMaD00WLE00<007LEMaD00WLE0P000WLF00D007LfMcIg=P0000=g
=P05001k=W/fNcH00004NeH01000NeIkEP000g]F00@007]fNgH0009kMP80009kMP04001kUW^F0002
NiH00`00NiH00003NiH00`00NkH00002NkH04`00NkIk]P00NkH007_F001keP00NmH007_F001ge@00
MmD007Oe00<00004Lo@00000Km@700000e^b000000040002E_d00`00E_eFo@03E_d30005E_d01000
E_eFoEKm0`001EKm00@005KmE_eFo@@000EFo@03001Fo@0000800003E_d005Km00AFo@03001FoEKm
00<00003E_d005Km00AFo@@0009Fo@03001FoEKm00=Fo@D000=Fo@04001FoEKmE_d30005E_d01000
E_eFoEKm10001EKm00<005Km00000P0000=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d015Km
1000BWoo00<007ooOol07Goo001NOol00`00Oomoo`03Ool2001QOol3002OOol30003E_d00`00E_eF
o@02E_d40004E_d01000E_eFoEKm100000<0<P0000002@0000P0M@0009D0U@0009D0002f0`000P2f
00H000CF1=H000SF00022=H01@003?H<mP004?H00P000QCf00@001Cf000000<I5P04000M5P000003
8CH00`008CHQ=P0200029CH02@00:CHY=RTf000YEP00:EH00003;EH00`00;EH]EP02;EH00`00<EH0
00020004<GH01@00=GDeMCEe000013Ee00<003Ee00000`000cVE00<003VE>ID00cVE00D003fE?IDm
U@0000DmU@03000mUCfE008mU@030011UD6E0091U@030011]D6e0091]@030015]DFe00=5]@030015
]DFe0095]@030015]DFe00A5]@030015eDGE00=5e@030015eDGE0095e@030019eDWE00=9e@030019
eDWE00=9e@03001=e4gD00==e003001=eDgE00==e@04001=mDgeCOD200000dge001=m@05COD00`00
COE=m@03COD00`00COE=m@03COD00`00DOEAm@04DOD00`00DO@00004DO@00`00EQEF5@04EQD00`00
EQEF5@04EQD20005EO@00`00EQEF5@04EQD00`00EQEF5@02EQD00`00EQD00007EO@00`00FSAJ=002
FS@01000GUENE@001Uhe00@005XeFSD000AJ5003001J=EXe00EJ=@8000IJ5003001N=5hd009N=004
001RE69D0006HUD20008HUD00`00HUERE@06HUD20006HUD00`00HWD00006HW@00`00IWD00006IWD0
0`00JYEZU@05JYD00`00JYD00005JYD01@00JYEZUFZE00000VZE00<006ZEJYD016ZE00<006ZeJ[D0
16Ze00L006jeK[E^]@00K[D00005K[D00`00K]D00004K]D00`00K]E^e@03K]D00`00K]E^e@02K]D0
0`00L_Ebm@03L_D00`00L_Ebm@02L_D00`00L_Ebm@02L_D01P00LaEc5@00LaD000Ag5@05001g5GLE
MaD00002MaD00`00MaH00003McH01@00McIg=WLf00000g/f0P000W]F00@007]FNeH000=kEP05001k
MW]fNgH00002NgH01`00NgH007]f001kUP0000=kUP03001kUP00009kUP06001k]W^f001k]P000W^f
00<007^f00000W_F00P007_F000007_F001ge@000WOE0`0000Ucm000000006oD001[e000Im<02@00
1EKm00<005Km00000P000UKm00<005KmE_d00eKm10000UKm00<005KmE_d00eKm100015Km00@005Km
E_eFo@<000EFo@04001FoEKmE_d40005E_d00`00E_d0000200000eKm001Fo@04E_d00`00E_d00002
0002E_d01000E_eFo@000UKm10000UKm00<005KmE_d00eKm10000eKm00<005KmE_d00eKm0P001EKm
00@005KmE_eFo@@000EFo@03001Fo@00008004ioo`03001oogoo01eoo`00GWoo00<007ooOol00`00
H7oo0`00Xgoo00<005KmE_d00eKm00@005Km000000=Fo@03001FoEKm009Fo@@0009Fo@<000030380
000000L0000707D0001e0000U@0009D00P0000<0]P0000000P2f0P0000@4eP0000000088eP80008<
mP06000@mP00000DmP000QCf0P000QTF00<001dF7AH00P000R4f00D0024f8CHQ=P0000<U=P04000Y
=RTf0002:EH20003;EH00`00;EH]EP02;EH01000<EHaES5F0P000c5f00D003Ee=GDeM@0000@eM@03
000eMCEe008eM@80008iU@03000iUCVE00<iU@05000mUCfE?ID00005?ID00`00?IDmU@02?ID00`00
@IE1U@02@ID00`00@KE1]@03@KD00`00AKE5]@03AKD00`00AKE5]@02AKD00`00AKE5]@03AKD00`00
AME5e@03AMD00`00AME5e@02AMD00`00BME9e@03BMD00`00BME9e@03BMD00`00CMA=e003CM@00`00
CME=e@04CMD30003COD00`00COE=m@04COD00`00COE=m@03COD00`00COE=m@03COD00`00DOEAm@04
DOD20005DO@00`00EQEF5@04EQD00`00EQEF5@03EQD20006EO@00`00EQEF5@04EQD01@00EQEF5EHE
00000UHE00<005GdEO@01EGd00D005XdFSAJ=00000=NE@03001N=Ehe00EN=@8000EJ5003001J=EXe
00EJ=@03001J55XD00EJ5005001N=5hdGS@00003HU@00`00HUERE@03HUD01000HUERE@001V9E0P00
269E00<0069EHUD01V9E0P001f9d00<006IeIWD016Ie00<006Ze00001VZE00<006ZE000016ZE00<0
06ZEJYD00VZE00@006ZEJYD000IZU@03001Z]FZe00AZ]@07001^]FjeK[D006je00001Fje00<006kE
00000fkE00<006kEK]D00fkE00<006kE00000fkE00<007;eL_D00W;e00<007;e00000W;e00<007;e
L_D00g;e00D007<ELaEc5@0000Ag5@03001g5GLE009g5@05001g5GLEMaD00003McH01@00McIg=WLf
00000g/f00H007]FNeH007]F0002NeH01@00NeIkEW]F00000W]f00@007]fNgH000=kMP800005NiH0
07^FNiH00002NiH01P00NiIkUP00NkH0009k]P05001k]P00NkH00002NmH02P00NmH007_F001keP00
MmD007OE0P0000Ecm@00000006od00800003Jm@0000000P0009[n`04001FoEKmE_d30006E_d00`00
E_d0000200000eKm001Fo@04E_d00`00E_d0000200000eKm001Fo@05E_d40002E_d00`00E_eFo@03
E_d40004E_d01000E_eFoEKm0`001EKm00@005KmE_eFo@<000IFo@03001Fo@0000800003E_d005Km
00AFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@0000800003E_d005Km00AFo@@0009Fo@03
001FoEKm00AFo@80055oo`03001oogoo01eoo`00GWoo0`00H7oo0`00Ygoo00@005KmE_eFo@<000IF
o@04001Fo@000002E_d00`00E_eFo@02E_d900001@1D0000E00007D00`0000<0U@0009D00`0000@0
]P000;H0]P8000031=H0000000<8eP8000073?H0013f4?H001Cf00000aCf00@001TF6AH000<M5P04
000Q=R4f00038CH200029CH01@00:CHY=RTf00000RUF0P000beF00<002eF;EH00ReF00@0035F<EHa
EP80008aMP05000eMCEe=GD00004=GD00`00=GDeM@02=GD00`00>GD000020005>ID00`00?IDmU@02
?ID00`00?IDmU@02?ID00`00?IDmU@02?ID00`00@IE1U@03@ID00`00@KE1]@02@KD00`00AKE5]@03
AKD00`00AKE5]@02AKD00`00AKE5]@03AKD00`00AME5e@03AMD00`00AME5e@02AMD00`00BME9e@03
BMD00`00BME9e@04BMD00`00CMA=e002CM@00`00CME=e@03CMD20006COD00`00COE=m@03COD00`00
COE=m@04COD00`00COE=m@02COD00`00DOEAm@03DOD20006DO@00`00EQEF5@04EQD00`00EQEF5@02
EQD00`00DQD00006EO@00`00EQEF5@05EQD00`00EQD00004EQD00`00EOAEm004EO@01000FSAJ=000
15iE00<005heGSD01Ehe00<005XDFQ@01EXD00<005XeFSD015Xe00<005XDFQ@01EXD00@005hdGS@0
00ERE003001REF9E009RE@04001REF9E0006HUD00`00HUD00007HUD00`00HUERE@06HUD00`00HWAR
M006HW@00`00IWEVM@04IWD00`00J[D00005JYD01@00JYEZUFZE00000VZE00<006ZEJYD00fZE00<0
06ZE00001VZE00<006ZE000016Ze00<006jeK[D00Vje00<006je00001Fje00@006kEK]D0009^e@03
001^eFkE00=^e@03001^e@00009^e@03001bmG;e00=bm@06001bmG;e001bm@0017;e00<007<ELaD0
0W<E00<007LEMaD00WLE00<007LEMaD00WLE00D007LEMaEg5@0000=g=P05001g=WLfMcH00003NcH0
1@00NeIkEW]F00000W]F00D007]FNeIkEP0000=kMP04001kMW]f0003NgH00`00NiH00002000017^F
001kUP000W^F00H007^fNkH007^f0002NkH01@00NkH007_F00000W_F0P0000=keP00MmD00`0000Eg
m@00000007?d00P00003Gk80000000<000=[n`@000=Fo@04001FoEKmE_d40005E_d01000E_eFoEKm
0`001EKm00<005KmE_d00`0000=Fo@00E_d015Km00<005Km00000P0000=Fo@00E_d01EKm10000UKm
00<005KmE_d00eKm10000UKm00<005KmE_d015Km0P000UKm00@005KmE_d000=Fo@<000EFo@04001F
oEKmE_d40005E_d00`00E_d0000200000eKm001Fo@04E_d00`00E_eFo@03001COol00`00Oomoo`0M
Ool005ioo`03001oogoo05eoo`<00:]oo`<000=Fo@03001FoEKm00=Fo@8000EFo@04001FoEKmE_d:
00001P1D0000001e0000M@D0000409D0002f00020;H01P000;H000001=H00088eP040008eP000002
4?H010005?HDmP000QCf0P000QTF00<001dF7AH00P000R4f00P0024f8CH002Df000U=P000bTf00@0
02UF:EHYEP80008]EP03000]EReF008]EP09000aES5F<EH0035e000aMP0000@eM@03000eMCEe008e
M@05000eMCEe=GD00003>GD20004>ID00`00?IDmU@02?ID00`00?IDmU@02?ID00`00?IDmU@02?ID0
0`00@IE1U@03@ID00`00@KE1]@02@KD00`00AKE5]@03AKD00`00AKE5]@02AKD00`00AKE5]@03AKD0
0`00AME5e@03AMD00`00AME5e@03AMD00`00BME9e@03BMD00`00BME9e@03BMD00`00CMA=e002CM@0
0`00CME=e@02CMD00`00COD00006COD00`00COE=m@03COD00`00COE=m@04COD00`00COE=m@02COD0
0`00DOEAm@02DOD00`00CM@00006DO@00`00EQEF5@04EQD01@00EQEF5EHE00000U8E00<005GdEO@0
1EGd00<005HEEQD015HE0P001EHE00<005GdEO@015Gd00@005XdFS@000ENE@03001N=Ehe00AN=@03
001J55XD00EJ5003001J=EXe00=J=@8000MJ5004001N=5hd0005HU@01@00HUEREF9E00000f9E00<0
069EHUD00f9E00@0069EHUD000IRE@8000QRE@03001RM69d00ERM08000IVM@03001Z]@0000EZU@05
001ZUFZEJYD00002JYD00`00JYEZU@04JYD20006JYD00`00JYD00004J[D00`00K[E^]@03K[D00`00
K[E^]@03K[D01`00K]E^eFkE001^e@0000E^e@07001^eFkEK]D006kE00001G;e00H007;eL_D007;e
0004L_D01`00LaEc5G<E001g5@00009g5@03001g5GLE009g5@09001g5GLEMaD007Le001g=P0000=g
=P03001k=W/f009k=P04001kEW]FNeH200000g]F001kEP02NeH01000NgIkMP000W]f00D007]fNgIk
MP00009kUP03001kUW^F00800009NiH007^FNiH007^f001k]P00009k]P03001k]P00009keP06001k
eP00NmH007_F0`0000Ege@00000007?d00800004Ko@00000Jm<900001V_k00000000E_d000EFo@@0
00=Fo@03001FoEKm00=Fo@@0009Fo@03001FoEKm00=Fo@<000EFo@04001FoEKmE_d30005E_d00`00
E_eFo@0300000eKm001Fo@04E_d00`00E_d0000200000eKm001Fo@04E_d00`00E_eFo@0300001EKm
001FoEKm00000UKm10000UKm00<005KmE_d00eKm100015Km00@005KmE_eFo@<000EFo@04001FoEKm
E_d4001FOol00`00Oomoo`0MOol005ioo`03001oogoo05Yoo`<00:moo`03001FoEKm00=Fo@03001F
o@000080009Fo@03001FoEKm009Fo@@000=Fo@T0000305@0001e0080000407D00000000209D01@00
0;H0002f00000P2f00H000CF000000SF00022=H200024?H00`005?H000025?H01@006AH001TF0000
0QdF00D001dF000Q=P0000<Q=P04000U=P000003:CH02@00:EHYERUF000YEP00;EH00004;EH01@00
<EHaES5F00000S5e0P0013Ee00<003Ee=GD00SEe00<003Ee=GD00SEe00@003Ue>GDiM@<0008iU@03
000mUCfE008mU@03000mUCfE008mU@03000mUCfE008mU@030011UD6E00=1U@030011]D6e0091]@03
0015]DFe00=5]@030015]DFe0095]@030015]DFe00=5]@030015eDGE00A5e@030015eDGE0095e@03
0019eDWE00=9e@030019eDWE00=9e@03001=e4gD00==e004001=e@000002COD00`00COE=m@04COD0
0`00COE=m@03COD00`00COE=m@04COD00`00COE=m@03COD01000DOD000000TgD00<0057dDO@0157d
00<005HEEQD01EHE00<005HE00000e8E00<005GdEO@01EGd00<005HEEQD00eHE0P001UHE00<005Gd
EO@01EGd0P001UiE00<005heGSD00ehe0P001eXD00<005XeFSD00UXe00<005iE00001eXD00<005hd
00001V9D00D0069EHUERE@0000=RE@03001REF9E00=RE@04001REF9E0005HUD01000HUERE@001V9E
0P001f9d00<0069D000016Ie00D006ZeJ[EZ]@0000=ZU@03001ZUFZE009ZU@03001ZU@0000MZU@03
001ZUFZE00AZU@04001ZUFZE0004J[D00`00K[E^]@03K[D00`00K[E^]@03K[D01`00K]E^eFkE001^
e@0000E^e@07001^eFkEK]D006kE000017;e00<007;eL_D00W;e00<007;eL_D00W;e00<007<ELaD0
0W<E00H007LEMaD007LE0004MaD02@00MaEg5GLE001g=@00McH00003McH01@00NcIk=W/f00000g]F
00@007]FNeH000=kEP05001kMW]fNgH00002NgH01`00NgIkMW]f001kUP0000=kUP03001oUP0000@0
0004NkH007^f0002NkH01@00NkH007_F00000W_F100000Ege@00MmD007Oe00<00007Lo@00000001[
d`00Im<02@001EKm00<005Km00000P000UKm00<005KmE_d00eKm00<005Km00000P0000=Fo@00E_d0
15Km00<005Km00000P000UKm00<005KmE_d00eKm10000UKm00<005KmE_d00eKm0`001EKm00@005Km
E_eFo@<000EFo@04001FoEKmE_d40005E_d00`00E_d0000200000eKm001Fo@04E_d00`00E_d00002
00000eKm001Fo@05E_d40002E_d00`00E_eFo@03E_d4001JOol00`00Oomoo`0MOol005ioo`03001o
ogoo05Qoo`800;=oo`04001FoEKmE_d40005E_d01000E_d000000UKm00<005KmE_d00eKm3P0000L0
M@0009D0002E0000]P0200001P2f0000]P2f0004eP8000052=H000SF2=H000024?H300035?H01000
6AH000000adF00@001dF000000<Q=P03000U=RDf008000<Y=P04000YERUF0002:EH20004;EH00`00
<EHaEP02<EH00`00<GDaM@020003=GD00`00=GDeM@02=GD00`00=GDeM@02=GD01@00>GDiMCUe0000
0SVE10000cfE00<003fE?ID00SfE00<003fE?ID00cfE00<0046E@ID00T6E00<0046e@KD00T6e00<0
04FeAKD00dFe00<004FeAKD00TFe00<004FeAKD014Fe00<004GEAMD00dGE00<004GEAMD00TGE00<0
04WEBMD00dWE00<004WEBMD00dWE00<004gDCM@00dgD0P001Dge00<004geCOD00dge00<004geCOD0
14ge00<004geCOD00dge00<004geCOD00dge0P0014gD00<0057dDO@01E7d00<005HEEQD015HE0P00
1E8E00<005GdEO@015Gd00<005HEEQD00UHE00<005YF00001UHE00<005GdEO@01EGd00<005iEGUD0
1EiE00<005heGSD00Uhe00@005iFGUH000IJ5005001J=EXeFSD00003GUD00`00FQAJ5005FQ@20006
HU@01000HUERE@001F9E00D0069EHUERE@0000=RE@03001REF9E00=RE@04001REF9E0006HUD00`00
HU@00005HW@01000HUARE00016Ie00D006ZeJ[EZ]@0000=ZU@03001ZUFZE00=ZU@8000MZU@03001Z
UFZE00AZU@05001ZUFZEJYD00002J[D00`00K[E^]@03K[D00`00K[D00003K[D00`00K]E^e@03K]D0
0`00K]E^e@03K]D00`00K]E^e@03K]D00`00L_Ebm@03L_D00`00L_Ebm@02L_D00`00L_Ebm@02L_D0
0`00LaEc5@02LaD01P00MaEg5@00MaD000=g5@05001g5GLEMaD00003McD01@00McIg=WLf000017/f
00D007]FNeIkEP00009kEP80009kEP07001kMW]fNgH007]f00000g]f00@007^FNiH0009kUP04001o
UWnF0002OkH00`00OkH0000<00000g_E001ke@020002MmD300000g?d0000000200000f_C00000007
0002E_d00`00E_eFo@03E_d20006E_d01000E_eFoEKm0`001EKm00@005KmE_eFo@@000EFo@03001F
o@0000800003E_d005Km00AFo@03001Fo@0000800003E_d005Km00EFo@@0009Fo@03001FoEKm00=F
o@@000=Fo@04001FoEKmE_d40002E_d01000E_eFo@000eKm0`001EKm00<005KmE_d00`0000=Fo@00
E_d015Km00<005Km00000P00GWoo00<007ooOol07Goo000QOol4000>Ool3000<Ool:000AOol00`00
Oomoo`1FOol3002fOol30004E_d01000E_eFoEKm0`001EKm00@005KmE_eFo@D000030180000000L0
0080M@800080U@030000]P0000800080]P040004eP001=H200022=H200000a3f000@mP0200025?H0
0`006AHI5P0200027AH00`007AHM5P0200028CH010009CHU=RDf0P000RTf00D002UF:EHYEP00008Y
EP8000@]EP05000aES5F<EH00003<GD20002=GD00`00=GDeM@02=GD00`00=GDeM@02=GD01@00>GDi
MCUe00001CVE0P000SfE00<003fE?ID00cfE00<003fE?ID00SfE00<0046E@ID00T6E00<0046e@KD0
0d6e00<004FeAKD00dFe00<004FeAKD00TFe00<004FeAKD00dFe00<004GEAMD00dGE00<004GEAMD0
0TGE00<004WEBMD00dWE00<004WEBMD00dWE00<004gDCM@00TgD0P001Tge00<004geCOD00dge00<0
04geCOD014ge00<004geCOD00dge00<004geCOD00Tge0P001TgD00<0057dDO@0157d00<005HEEQD0
0eHE0P001U8E00<005GdEO@015Gd00D005HEEQEF5@00009JEP03001F5EHE00AF5@03001Em5Gd00EE
m003001NEEiE00ENE@05001N=EheGSD00003GUH00`00FQAJ5004FQ@01000FSEJ=@0015iE00<005XD
FQ@01EXD00<0069DHU@01F9D00<0069E00001V9E00@0069EHUD000ERE@05001REF9EHUD00003HUD0
0`00HUERE@03HUD01000HUARE0001F9d00@0069DHU@000=VM@03001Z]FZe00=Z]@03001ZU@0000IZ
U@03001ZUFZE00EZU@03001VU@0000AZU@03001ZUFZE009ZU@04001Z]FZe0005K[D00`00K[D00003
K[D00`00K]E^e@03K]D00`00K]E^e@03K]D00`00K]E^e@03K]D00`00L_Ebm@02L_D00`00L_Ebm@02
L_D00`00L_D00002L_D00`00LaEc5@02LaD00`00MaEg5@02MaD00`00MaEg5@02MaD01@00MaEg5GLE
00000gLe0P000WLf00D007/fNcIk=P0000=kEP04001kEW]F0002NeH00`00NeH00002NgH01000NgIk
MP000g]f00<007^F00000g^F00<007nF00000Wnf00H007nfOkH007nf0002NkH01@00NmD007_E0000
0W_E0P0000Eke@00MmD007OE00800007LoD00000001_e000Jm<02@0015Km00<005Km00000P000UKm
00<005KmE_d00eKm10000UKm00<005KmE_d00eKm100015Km00@005KmE_eFo@<000EFo@04001FoEKm
E_d30005E_d00`00E_eFo@0300000eKm001Fo@04E_d00`00E_d0000200000eKm001Fo@04E_d40003
E_d01000E_eFo@000UKm10000UKm00<005KmE_d00eKm0`001EKm00@005KmE_eFo@<0069oo`03001o
ogoo01aoo`007goo20002goo1@002goo2P004Goo00<007ooOol0Dgoo0`00^Woo00<005KmE_d00eKm
10000eKm00<005KmE_d00UKm10000UKm100000@04P000000<`80000905@0001d0000M@0009D0002E
00<000030;D0002f0080]P800084eP040008ePSF2=H20000113f000@mP000QCf00D001TF6AHI5P00
008M5P05000M5QdF7AH000038CH020009CHU=P009CH002Tf0003:EH01000:EHYERUF0P000beF00D0
035F<EHaEP0000<aM@03000aM@00008000@eM@03000eMCEe008eM@03000iMCUe008iM@03000iUCVE
008iU@03000mU@0000<000@mU@03000mUCfE008mU@030011UD6E0091U@030011]D6e00=1]@030015
]DFe00=5]@030015]DFe0095]@030015]DFe00=5]@030015eDGE00=5e@030015eDGE0095e@030019
eDWE00=9e@030019eDWE00=9e@07001=e4gDCM@004gD00001Tge00<004geCOD014ge00<004geCOD0
0dge00<004geCOD014ge00H004ge000004gE0006CM@00`00DOAAm004DO@00`00EQEF5@02EQD00`00
FSH00006DQD00`00EOAEm004EO@01000EQEF5@0015YF00<005HEEQD00eHE00<005GdEO@015Gd0P00
1eiE00@005heGSD000ANEP03001J55XD00EJ508000ENE@03001J55XD00EJ5003001RE69D00IRE080
00IRE@04001REF9E0005HUD01@00HUEREF9E00000f9E00<0069EHUD00f9E00@0069DHU@000ARM003
001RE69D009RE004001VMFIe0005J[D00`00JYD00006JYD00`00JYEZU@05JYD00`00IYD00004JYD0
0`00JYEZU@02JYD00`00J[D00005K[D01000K[E^]@000fje00<006kEK]D00VkE00<006kE000016kE
00<006kEK]D00VkE00<007;E00000g;e00<007;eL_D00W;e00H007;eL_D007;e0004LaD00`00MaEg
5@02MaD01@00MaEg5GLE00000gLE00D007LeMcEg=@00009g=@03001g=P0000=k=P05001kEW]FNeH0
0002NeH01000NeIkEW]F0`0000EkMP00NgIkMP00009kMP04001kUW^F0002NiH01000OiIoUP000Wnf
00D007nf001o]P00009k]P05001ke@00NmD00002NmD01000NmD007_E0P0000=ge@00MoD00`0000=_
e00000000`0000AS/P00001GT@@000=Fo@<000IFo@03001Fo@0000800003E_d005Km00AFo@03001F
o@0000800003E_d005Km00EFo@@0009Fo@03001FoEKm00=Fo@@0009Fo@03001FoEKm00=Fo@<000EF
o@04001FoEKmE_d30005E_d00`00E_d000020002E_d00`00E_eFo@03E_d00`00E_d0000200000eKm
001Fo@04E_d00`00E_d000020002E_d00`00E_eFo@03E_d4001UOol00`00Oomoo`0LOol001moo`80
00Aoo`8000]oo`D000moo`8001Eoo`03001oogoo051oo`<00;ioo`03001Fo@000080009Fo@03001F
oEKm00=Fo@04001Fo@000002E_d00`00E_eFo@02E_d70000100c0000001D0P000P1e0`0000<0U@00
00000P2e00<0002f0;H00`000PCF00D000SF2=H000cF008000034?H00000008DmP04000I5QTF0003
7AH00`007AHM5P0200028CH010009CHU=P000RDf0P000bUF00L002UF:EHYEP00;ED00002;EH01@00
<EHaES5F00000c5e00@0035e<GDaM@8000<eM@03000eMCEe008eM@03000iMCUe008iM@03000iUCVE
008iU@03000mUCfE008mU@@00003?ID003fE00<mU@030011UD6E0091U@030011]D6e00=1]@030015
]DFe00=5]@030015]DFe0095]@030015]DFe00=5]@030015eDGE00=5e@030015eDGE00=5e@030019
eDWE00=9e@030019eDWE00=9e@03001=e000009=e003001=mDge00A=m@03001=mDge00A=m@03001=
mDge00==m@03001=mDge00A=m@8000==e@03001=e4gD00A=e003001Am57d00AAm005001F5EHEEQD0
0002FSH00`00DQEB5@04DQD00`00EOAEm005EO@20005FUH00`00EQEF5@04EQD00`00EOAEm003EO@0
0`00McH00007GUD20005GUH00`00FQAJ5005FQ@00`00GUENE@04GUD00`00FQAJ5004FQ@20008HU@0
0`00HUERE@05HUD00`00HUD00006HUD01000HUERE@001F9E00D0069EHUERE@0000ARE005001RM69d
HW@00004HU@01000IWEVM@001FZe00<006ZE00001FZE00<006Ze00001FZE00@006JEIYD000AZU@03
001ZUFZE00=ZU@8000E^]@07001^]FjeK[D006je00001FkE00<006kE00000fkE00<006kEK]D00fkE
00<007;E00000W;e00<007;eL_D00W;e00L007;eL_Ebm@00L_D00003LaD00`00MaEg5@02MaD00`00
MaD00002MaD01@00MaEg5GLE00000gLe00D007LeMcEg=@0000=k=P05001kEW]FNeH00003NeH01@00
NeIkEW]F00000W]f00@007]fNgH000=kMP03001kUP0000=kUP03001oUP00009o]P06001o]Wnf001o
]P000W^f00D007_E001ke@00009ke@800003NmD00000009ge@<00003Lm@0000000<00003Im800000
00D00003Jo/00000008000=Fo@04001FoEKmE_d40005E_d01000E_eFoEKm0`001EKm00<005KmE_d0
0`0000=Fo@00E_d015Km00<005Km00000P0000=Fo@00E_d015Km00<005Km00000P000UKm00<005Km
E_d00eKm10000UKm00<005KmE_d00eKm0P001UKm00@005KmE_eFo@<0009Fo@04001FoEKm0003E_d3
0006E_d00`00E_d00002001YOol00`00Oomoo`0LOol001ioo`8000Ioo`8000Yoo`D000moo`8001Eo
o`03001oogoo04eoo`<00<9oo`03001FoEKm00AFo@04001FoEKmE_d30005E_d01000E_eFoEKm2P00
00D0E00007@0001e00D0000309D0002e008000040;H0000000021=H010002=H8eP000PcF00<0013f
4?H00P0000@DmP006AHI5P80008M5P08000M5QdF000M5P008CH000<U=P03000U=RDf0080008YEP05
000YERUF:EH00002;ED30004<EH01@00<GDaMC5e00000c5e0P000SEe00<003Ee=GD00cEe00D003Ue
>GDiM@0000DiU@05000mUCfE?ID00003?ID40002?ID00`00@IE1U@03@ID00`00@KE1]@02@KD00`00
AKE5]@03AKD00`00AKE5]@02AKD00`00AKE5]@03AKD00`00AME5e@04AMD00`00AME5e@02AMD00`00
BME9e@03BMD00`00BME9e@03BMD20004CM@00`00COE=m@03COD00`00COE=m@04COD00`00COE=m@03
COD00`00COE=m@03COD20004CMD00`00CMA=e004CM@00`00DOAAm004DO@01000EQEF5@0015Xf00<0
058EDQD00e8E00<005GdEO@01EGd00<005YFFUH015YF00<005HEEQD015HE00<005GdEO@00UGd00@0
07LfMcH000MNE@03001NEUiF00ANEP03001J55XD00EJ5003001NEEiE00ANE@03001J55XD00AJ5003
001g=P0000MRE003001REF9E00IRE@8000IRE@03001RE@0000IRE@04001REF9E0005HU@01000HWAR
M0001F9D00<006Ie00001fZe00<006ZEJYD016ZE00<006Ze00001FZE00D006JEIYEVU@00009ZU@03
001ZUFZE00AZU@03001^]Fje00=^]@03001^]Fje009^]@03001^]@0000E^e@04001^eFkE0002K]D0
0`00K]E^e@02K]D01`00L]EbeG;E001bm@0000Abm@03001bmG;e009bm@03001c5G<E009c5@03001g
5GLE009g5@06001g5GLE001g5@000gLE00D007LeMcEg=@0000=g=@80009k=P05001kEW]FNeH00002
NeH01@00NeIkEW]F00000g]f0P0000=kMP00NgH00W]f00<007^F00000W^F00@007nFOiH0009o]P05
001o]P00OkH00002NkH01@00NmD007_E00000W_E0P0000Mke@00MmD007OE001gm@0500000f_C001W
dP0900000eKm001Fo@04E_d40003E_d00`00E_eFo@03E_d40002E_d00`00E_eFo@03E_d30005E_d0
1000E_eFoEKm0`001EKm00@005KmE_eFo@<000IFo@03001Fo@0000800003E_d005Km00AFo@03001F
o@0000800003E_d005Km00EFo@@0009Fo@06001FoEKmE_d005Km10000eKm00@005KmE_eFo@@006ao
o`03001oogoo01aoo`007Woo0P001Woo0P002goo0`0047oo0P005Goo00<007ooOol0BWoo0`00aWoo
00<005KmE_d00eKm10000eKm00<005KmE_d00UKm10000UKm2@0000D0E0000000001e0080000407D0
002E00020;D200000`2f000000031=H010002=H8eP000PcF00@0013f000@mP8000<I5P8000037AH0
01dF008M5P04000M5P0000039CH01@009CHU=RDf00000bUF00D002UF:EHYEP0000<]E@8000<aEP05
000aMC5e<GD00003<GD01P00=GD00000=GD000@eM@05000iMCUe>GD00005>ID01@00?IDmUCfE0000
13fE00<003fE?ID01000146E00<0046e@KD00T6e00<004FeAKD00dFe00<004FeAKD00TFe00<004Fe
AKD014Fe00<004GEAMD00dGE00<004GEAMD03`001DgD00<004geCOD014ge00<004geCOD00dge00<0
04geCOD014ge00<004ge00000P0000==e@00CMD014gE00<004gDCM@00dgD00<0057dDO@01E7d0P00
1EXf00<0058EDQD0158E00<005GdEO@015Gd00<005YFFUH015YF00<005HEEQD015HE00<005GdEO@0
0UGd00@007LfMcH000MNE@03001NEUiF00ENEP03001J55XD00=J508000MNE@03001J55XD009J5004
001g=WLf0006HU@20008HUD00`00HUERE@06HUD20006HUD01000HUERE@001F9D00@0069dHW@000ER
E003001VM@0000MZ]@03001ZUFZE00AZU@04001Z]FZe0003JYD00`00IYEVU@02IYD01000JYEZU@00
1VZE00<006jeK[D00fje00<006jeK[D00Vje00<006je000016kE00L006kEK]E^e@00K]D00005K]D0
1`00L]EbeG;E001bm@0000=bm@03001bmG;e00=bm@05001c5G<ELaD00004MaD00`00MaEg5@02MaD0
1@00MaEg5GLE00000gLe00D007LeMcEg=@00009k=@03001k=P00009kEP05001kEW]FNeH00003NeH0
1000NgIkMP000W]f0P000W]f00@007^FNiH0009kUP03001oUP00009o]P06001o]Wnf001o]P000W^f
00@007_E0000009ke@04001ke@00NmD20002MmD400000foD000000090005E_d00`00E_d000020002
E_d00`00E_eFo@03E_d00`00E_d0000200000eKm001Fo@04E_d00`00E_d000020002E_d00`00E_eF
o@03E_d40002E_d00`00E_eFo@03E_d40003E_d01000E_eFoEKm10001EKm00@005KmE_eFo@<000EF
o@03001FoEKm00<00003E_d005Km00AFo@03001Fo@0000800003E_d005Km00AFo@@0071oo`03001o
ogoo01aoo`007Goo0P0027oo0P007Goo0P005Goo00<007ooOol0Agoo0`00bWoo00<005Km00000P00
0UKm00<005KmE_d00eKm00@005Km0000009Fo@03001FoEKm009Fo@8000030140000000X00080M@06
0000U@000;D0002E0P0000@0]@001=H4eP8000072=H000cF3=H0013f00000Q3f0P000QTF00@001TF
000000<M5P03000M5QdF0080008U=P04000U=RDf9CH20002:EH01@00:EHYERUF000012eE0P000S5F
00D0035e<GDaM@0000<aM@04000eMCEe=GD20004=GD00`00>GDiM@02>GD00`00>IDiU@02>ID00`00
?IDmU@02?ID01@00?IDmUCfE00001CfE100000=1U@00@KD0146e00<004FeAKD00dFe00<004FeAKD0
0TFe00<004FeAKD030000TGE00<004FeAKD00dFe00<004FeAKD00dFe00<004gDCM@00dgD00<004ge
COD014ge00<004geCOD00dge00<004geCOD00dge0`0014gE00<004gECMD00dgE00<004gDCM@00dgD
00<0057dDO@01E7d00<005XfFSH015Xf00<0058EDQD0158E00<005GdEO@00eGd0P001UYF00<005HE
EQD015HE00D005GdEOAEm00000=g=P03001NEEiE00ANE@8000MNEP03001J55XD009J5004001c=g<g
0006GUD00`00FQAJ5002FQ@01000McIg=P001F9D00@007LgMcL000MRE@03001REF9E00IRE@03001R
EF9E00ERE@03001RE@0000IRE003001RM00000MRE08000IZ]@03001VM@0000AZU@05001Z]FZeJ[D0
0003JYD00`00IYEVU@02IYD00`00JYD00006JYD00`00K]D00004K[D00`00K[E^]@03K[D00`00K]E^
e@03K]D01`00K]E^eFkE001^e@0000A^e@03001beG;E00=be@03001bmG;e009bm@03001bmG;e009b
m@03001g5@00009c5@03001g5GLE009g5@03001g5GLE009g5@05001g5GLEMaD00003McD01@00McEg
=GLe00000g/e00D007]FNeIkEP00009kEP05001kEW]FNeH00003NgH02P00NgIkMP00NgH007]f001k
UP000g^F00<007nF00000Wnf00D007nf001o]P00009k]P05001ke@00NmD00002NmD200000g_E001g
e@0300000g?D0000000500000fOB000000050005E_d20006E_d01000E_eFoEKm0`001EKm00@005Km
E_eFo@<000IFo@03001Fo@0000800003E_d005Km00AFo@03001Fo@0000800003E_d005Km00AFo@@0
00=Fo@03001FoEKm00=Fo@@000=Fo@04001FoEKmE_d40005E_d01000E_eFoEKm0`000UKm00D005Km
E_d005Km00<007Aoo`03001oogoo01aoo`007Goo0P0027oo0P007Goo0P0057oo00<007ooOol0AGoo
0`00cWoo00<005KmE_d015Km00@005KmE_eFo@<000EFo@03001Fo@0000H000030180000000@00007
05@0001e0000M@0009D00P0000H0]@0009D0002e00021=H010001=H000000`cF00<0013f00000Q3f
00@001TF6AH0008I5P80008M5P05000M5QdF7AH000039CH020009CHU=P009CH002UF0003:EH00`00
;ED]E@02;ED01@00;ED0035F00000c5e00<0035e<GD00S5e00@003Ee=GDeM@8000<eM@03000iMCUe
008iM@03000iUCVE008iU@03000mUCfE008mU@03000mUCfE008mU@03000mUCfE008mU@040011UD6E
@ID50002@KD00`00AKE5]@03AKD00`00AKE5]@050003AKD00`00AME5e@03AMD00`00AME5e@02AMD0
0`00AKE5]@03AKD00`00AKE5]@03AKD00`00CMA=e003CM@00`00COE=m@04COD00`00COE=m@04COD0
0`00COE=m@0200000dge001=e@05CMD00`00CME=e@02CMD00`00CMA=e004CM@00`00DOAAm004DO@0
0`00FSIJ=P04FSH00`00DQEB5@04DQD00`00EOAEm002EO@01000LcQc>0001UYF00<005HEEQD00eHE
00@005GdEO@000Eg=P03001NEEiE009NE@04001c>7<h0006GUH00`00FQAJ5002FQ@01000LcMc=`00
1UiE00D005XDFQAJ500000=g=P03001RE69D00=RE004001g=gLg0006HUD20008HUD00`00HUERE@06
HUD20007HU@20007HU@00`00J[EZ]@05J[D00`00IWD00004JYD01@00J[EZ]FZe00000fZE00<006JE
IYD00fJE0P001VZE00<006kE00000fje00<006jeK[D016je00<006kEK]D00VkE00<006kEK]D00fkE
00<006kEK]D00fkE00<007;EL]D00g;E00D007;eL_Ebm@0000Ebm@06001g5GLE001c5@000gLE00<0
07LEMaD00WLE00D007LE001g5@0000=g=@03001g=GLe009g=@05001k=G/eNcD00002NeH01@00NeIk
EW]F00000g]F00@007]fNgH0009kMP04001kMW]fNgH200001g^F001kUW^F001oUP0000=o]P05001o
]P00OkH00002NkH01000NmD000000W_E00@007_E001ke@<00003Mm@0000000800005Km@006_C001W
dP060002E_d00`00E_d000020002E_d00`00E_eFo@03E_d40002E_d00`00E_eFo@03E_d40003E_d0
1000E_eFoEKm10001EKm00@005KmE_eFo@<000EFo@03001Fo@000080009Fo@03001FoEKm00=Fo@03
001Fo@0000800003E_d005Km00AFo@@000=Fo@03001FoEKm00=Fo@@0009Fo@06001FoEKmE_d005Km
0P00Mgoo00<007ooOol077oo000MOol20008Ool2000MOol2000DOol00`00Ool000020010Ool3003B
Ool00`00E_eFo@03E_d40003E_d00`00E_eFo@02E_d30003E_d40000200B0000000c0000E00005@2
000207D00`0009D00002000209D00`000;D000021=H010001=H000000PcF0`000Q3f0P000QTF00@0
01TF6AH000<M5P03000M5QdF0080008U=P06000U=RDf9CH002Df0P000bUF00<002eE;ED00ReE00<0
02eE;ED00P00135e00D0035e<GDaM@0000<eM@06000eM@00000eM@0013Ue00<003VE>ID00SVE00<0
03fE?ID00SfE00<003fE?ID00SfE00<003fE?ID00SfE00<0046E@ID00T6E00@0046E@IE1U@/00095
]@030015]DFe00=5]@030015eDGE00=5e@030015eDGE00=5e@030015]DFe00=5]@030015]DFe0095
]@03001=e4gD00==e003001=mDge00A=m@03001=mDge00A=m@<000==m@03001=eDgE00A=e@03001=
eDgE009=e@03001=e4gD00A=e003001Am57d00=Am08000IJ=P03001B5E8E00AB5@03001Em5Gd009E
m004001c>7<h0006FUH00`00EQEF5@03EQD01000EOAEm0001GLf00D005iEGUENE@0000=c>003001N
EUiF00ANEP05001J55XDFQ@00003LcL00`00GUENE@04GUD01000FQAJ50001GLf00D0069DHUARE000
00=g=`03001REF9E00=RE@04001g=gLg0006HUD20008HUD00`00HUARE006HU@00`00HUARE006HU@0
0`00J[EZ]@04J[D01000IWEVM@000fZE00<006ZeJ[D00fZe00<006ZE00001VJE00<006ZEJYD016ZE
00D006kEK]E^e@00009^]@03001^]Fje00=^]@03001^]@0000=^e@03001^eFkE00=^e@03001^eFkE
00=^e@03001beG;E009be@03001bm@00009bm@03001bmG;e009bm@03001g5GLE009g5@03001g5GLE
009g5@03001g5GLE009g5@05001g5@00MaD00003McD01@00McEg=GLe00000g/e00D007]F001kEP00
009kEP05001kEW]FNeH00003NgH01000NgIkMP000g]f00<007nF00000P0000AkUP00OiH0009o]P05
001o]P00OkH00002NkH01@00NmD007_E00000W_E100000=ge@00Mm@00`0000=ce00000000P000VOB
1@000UKm10001EKm00<005Km00000P0000=Fo@00E_d015Km00<005Km00000P0000=Fo@00E_d015Km
10000eKm00<005KmE_d00eKm10000UKm00<005KmE_d00eKm0P001UKm00@005KmE_eFo@<000EFo@03
001Fo@0000800003E_d005Km00EFo@03001Fo@0000800003E_d005Km00AFo@03001Fo@00008007Yo
o`03001oogoo01]oo`007Goo0P0027oo0P007Goo0P0057oo0P00@Goo0P00eWoo00<005Km00000P00
0UKm00<005KmE_d00eKm00@005Km000000=Fo@04001FoEKmE_d70000200c0000001D0000M@0007D3
00001P2E0000U@2E0000]@8000051=H000CF1=H000023=H300034?H2000011TF000I5QTF0P000QdF
00P001dF7AH0024F000U=P000bDf00<002Df9CH00P000bUF00D002eE;ED]E@0000<]E@8000<aM@05
000aMC5e<GD00003=GD01000=GDeMCEe0`000cUe00<003VE>ID00cVE00D003fE?IDmU@0000@mU@03
000mUCfE00<mU@050011UD6E@ID00005@ID00`00AKE5]@03AKD00`00AKE5]@02AKD00`00AKE5]@04
AKD00`00AME5e@03AMD00`00AME5e@02AMD00`00AKE5]@03AKD00`00AKE5]@02AKD00`00CMA=e004
CM@00`00COE=m@03COD00`00COE=m@03COD20006COD00`00CME=e@03CMD00`00CME=e@02CMD00`00
CMA=e004CM@00`00DOAAm002DO@01000LcMc=`001UXf00<0058EDQD00e8E00D005GdEOAEm00000=c
>003001JEUYF00AJEP03001F5EHE00AF5@8000Ig=P05001NEEiEGUD00003LcP00`00GUINEP04GUH0
1000FQAJ50001G<g00<005iEGUD00eiE00@005XDFQ@000Eg=P05001RE69DHU@00003McL00`00HUER
E@03HUD01000McMg=`001V9E00<007Lg00001f9E00<0069DHU@01V9D00<0069DHU@01F9D00<007/e
00001FZe00D006IeIWEVM@00009ZU@03001Z]FZe00=Z]@03001ZU@0000IVU@03001ZUFZE00AZU@07
001^eFkEK]D006je00001Vje00<006je00000fkE00<006kEK]D00VkE00<006kE00000fkE00<007;E
L]D00g;E00D007;e001bm@0000Ebm@03001g5GLE009g5@05001g5GLEMaD00004MaD01@00MaEg5GLE
00000gLe00<007LeMcD00WLe00D007/eNcEk=@00009kEP80009kEP05001kEW]FNeH00002NgH01000
NgIkMP000g]f00@007nFOiH0009oUPD00006OkH007nf001o]P000W^f00<007_E0000100000=ke@00
MmD00P0000=ge000Lm@01`0000=WdP0000001P0015Km00@005KmE_eFo@<000EFo@04001FoEKmE_d3
0005E_d00`00E_d000020002E_d00`00E_eFo@03E_d00`00E_d0000200000eKm001Fo@04E_d00`00
E_d0000200000eKm001Fo@05E_d40002E_d00`00E_eFo@03E_d20005E_d01000E_eFoEKm10001EKm
00@005KmE_eFo@<0009oo`03001oogoo07Qoo`03001oogoo01]oo`007Goo0P0027oo0P007Goo0P00
57oo00<007ooOol0?Goo0`00fGoo0P001EKm00@005KmE_eFo@@000EFo@03001Fo@0000T0000305@0
001D00<0000307D000000080U@030000U@2E008000030;D000000084eP80008<eP<0008@mP04000D
mP0000026AH01@006AH001dF00000adF00@0024F000000<U=P04000U=RDf9CH20002:EH00`00;ED]
E@02;ED01000;ED]EBeE0P000S5e00D0035e<GDaM@0000@eM@03000eMCEe008eM@80008iM@03000i
UCVE00<iU@05000mUCfE?ID00004?ID00`00?IDmU@03?ID00`00@IE1U@02@ID00`00@IE1U@02@ID0
0`00AKE5]@03AKD00`00AKE5]@03AKD00`00AKE5]@03AKD00`00AME5e@03AMD00`00AME5e@02AMD0
0`00AKE5]@03AKD00`00AKE5]@02AKD00`00CMA=e004CM@00`00COE=m@04COD00`00COE=m@020000
0dge001=m@05COD00`00CME=e@03CMD00`00CME=e@03CMD00`00CMA=e003CM@00`00DOAAm002DO@0
1000LcMc=`001UXf00<0058EDQD00e8E00@005GdEO@000Ec>003001JEUYF00=JEP03001F5EHE00AF
5@8000Ig=P04001NEEiE0005LcP00`00GUINEP04GUH00`00FQ@00005LcL00`00GUENE@04GUD20006
McH01000HUARE0001GLg00D0069EHUERE@0000=g=`03001REF9E00=RE@04001g=gLg0006HUD20007
HU@20007HU@00`00NcD00004J[D00`00IWEVM@02IWD00`00JYD00007J[D00`00IYEVU@04IYD00`00
IW@00004JYD00`00K]E^e@02K]D00`00K[D00005K[D01`00K[E^]Fje001^e@0000E^e@03001^e@00
00=^e@03001beG;E009be@06001bmG;e001bm@0017;e00<007LEMaD00WLE00<007LE00000WLE00<0
07LEMaD00WLE00@007LEMaEg5@80009g=@05001g=GLeMcD00004NcD02000NeIkEP00NeH007]F0003
NeH01000NgIkMP000W]f00L007]fNgIkMP00OiH00003OiH00`00OiH00002OkD:000017_E001keG_E
0P0000Ige@00001ge000Lm@300000foC0000000700000eKm001Fo@05E_d40002E_d00`00E_eFo@03
E_d40002E_d00`00E_eFo@03E_d20006E_d01000E_eFoEKm0`001EKm00@005KmE_eFo@<000EFo@03
001FoEKm00<00003E_d005Km00AFo@03001Fo@0000800003E_d005Km00AFo@@000=Fo@03001FoEKm
00=Fo@@000Ioo`03001oogoo07Moo`03001oogoo01]oo`007Goo0P0027oo0P007Goo0P0057oo00<0
07ooOol0>Woo0`00gWoo00<005KmE_d00UKm100015Km00@005KmE_eFo@<000=Fo@l0000407D0002E
000209D300000`2e000000021=H2000010cF000<eP000Q3f00<001Cf5?H00P000QTF00@001TF0000
00<M5P03000Q5R4F0080008U=P09000U=RDf9CH002Te000YEP0000@]E@06000]EBeE;ED0035E0`00
135e00D003Ee=GDeM@0000@eM@03000iM@0000<000@iU@03000mUCfE008mU@05000mUCfE?ID00005
?ID00`00@IE1U@02@ID00`00@IE1U@03@ID00`00AKE5]@03AKD00`00AKE5]@02AKD00`00AKE5]@03
AKD00`00AME5e@03AMD00`00AME5e@02AMD00`00AKE5]@03AKD00`00AKE5]@03AKD00`00CMA=e003
CM@00`00COE=m@04COD30003COD00`00COE=m@04COD00`00CME=e@03CMD00`00CME=e@03CMD00`00
CMA=e003CM@01@00DOAAm57d00000g<g00<005XfFSH015Xf00<0058EDQD0158E00<005Gd00001G<h
00<005YFFUH00eYF00<005HEEQD00eHE0P0027Lf0P001W<h00<005iFGUH015iF0P001W<g00<005iE
GUD015iE0P001WLf00<0069D00001WLg00D0069EHUERE@0000=g=`03001REF9E00=RE@04001g=gLg
0005HUD01000McMg=`001V9D00<007Lf00001F9D00@007/eNcD000=Z]@03001VMFIe00=VM@03001Z
U@0000MZ]@03001VUFJE00AVU@03001VM00000AZU@03001^eFkE00=^e@03001^]Fje00A^]@07001^
]FjeK[D006kE00001FkE00H006kEK]D006kE0005L]D01@00L_EbmG;e00001G;e00<007LEMaD00WLE
00D007LE001g5@0000Ag5@05001g5GLEMaD00002McD00`00McD00003McD01@00NcEk=G/e00000W]F
00@007]FNeIkEP80009kEP04001kMW]f0002NgH01@00NgIkMW]f00000WnF00H007nFOiH007nF0003
OkD01@00OkD007ne00000W^e00@007_E0000009ke@04001ke@00MmD200000gOD001ce00700000f>b
000000020003E_d00`00E_eFo@0300000eKm001Fo@04E_d00`00E_d0000200000eKm001Fo@04E_d0
0`00E_d000020002E_d00`00E_eFo@03E_d40002E_d00`00E_eFo@03E_d40003E_d01000E_eFoEKm
10001EKm00@005KmE_eFo@<000EFo@03001Fo@0000800003E_d005Km00EFo@03001Fo@00008000]o
o`03001oogoo07Ioo`03001oogoo01]oo`007Goo0P0027oo0P007Goo0P0057oo00<007ooOol0=goo
0`00hWoo00@005Km0000009Fo@03001FoEKm00=Fo@@000=Fo@03001FoEKm00d0000407@0001e0002
09D00`0009D0000200020;D01@001=H4eP002=D00P0000<<eP0000000Q3f00@001Cf5?H0008I5P03
000I5QTF0080008M5P05000Q5R4F8AH000039CH010009CHU=P000RTe0P0012eE00D002eE;ED]E@00
00<aE@8000<aM@05000eMCEe=GD00004=GD00`00>GDiM@02>GD20003>ID00`00?IDmU@02?ID00`00
?IDmU@02?ID00`00?IDmU@02?ID00`00@IE1U@02@ID00`00@IE1U@03@ID00`00AKE5]@03AKD00`00
AKE5]@02AKD00`00AKE5]@03AKD00`00AME5e@03AMD00`00AME5e@02AMD00`00AKE5]@03AKD00`00
AKE5]@03AKD00`00CMA=e003CM@00`00COE=m@03COD20006COD00`00COE=m@03COD00`00CME=e@04
CMD00`00CME=e@02CMD00`00CMA=e003CM@01000DOAAm0001G<g00<005XfFSH00eXf00<0058EDQD0
158E0P001W<h00<005YFFUH015YF00<005HE00000P000U<M00<007LfMcH017Lf0P001g<h00<005iF
GUH00eiF0P001g<g00<005iEGUD00eiE0P0027Lf0P001WLg00@0069EHUD000Eg=`05001REF9EHUD0
0003McL00`00HUERE@03HUD01000McMg=`001F9D00@007LfMcH000ERE005001k=G/eNcD00002J[D0
0`00IWEVM@04IWD20006J[D20006IYD00`00IW@00004JYD00`00K]E^e@03K]D00`00K[E^]@03K[D0
0`00K[E^]@02K[D00`00K]D00004K]D01`00K]E^eFkE001^e@0000Abe@03001bmG;e009bm@03001b
mG;e009bm@03001g5GLE009g5@06001g5GLE001g5@0017LE00D007LEMaEg5@0000=g=@05001g=GLe
McD00004NcD01000NeIkEP000g]F00D007]F001kEP00009kMP04001kMW]f0003NgH00`00OiH00003
OiH00`00OiH00002OkD01@00OkD007ne00000W^e00X007_E001ke@00NmD007_E001ge@800003Mm@0
07?D00L00003Hk800000008000AFo@<000EFo@04001FoEKmE_d30005E_d01000E_eFoEKm0`001UKm
00<005Km00000P0000=Fo@00E_d015Km00<005Km00000P0000=Fo@00E_d015Km10000eKm00<005Km
E_d00eKm10000eKm00@005KmE_eFo@<000EFo@04001FoEKmE_d4000>Ool00`00Oomoo`1fOol00`00
Oomoo`0KOol001eoo`8000Qoo`8001eoo`8001=oo`03001oogoo03Eoo`<00>Ioo`8000AFo@03001F
o@000080009Fo@03001FoEKm00=Fo@03001Fo@0000<000040140000003<200002@1D0000E00007@0
001e0000U@0200000`2E000000020;D2000010CF0008e@SE0P0000D<eP00000@mP00008DmP04000I
5QTF00036AH01@007AHM5QdF00000R4F0P000RDf00D002Df9CHU=P00008Y=@8000<]E@03000]EBeE
008]E@04000aEC5E<ED20002<GD01@00=GDeMCEe00001CEe00H003Ue>GDiM@00>GD200000cVE000m
U@03?ID00`00?IDmU@02?ID00`00?IDmU@02?ID00`00@IE1U@02@ID00`00@IE1U@03@ID00`00AKE5
]@03AKD00`00AKE5]@02AKD00`00AKE5]@03AKD00`00AME5e@03AMD00`00AME5e@03AMD00`00AKE5
]@03AKD00`00AKE5]@02AKD00`00CMA=e003CM@00`00COE=m@02COD00`00ESH00006COD00`00COE=
m@03COD00`00CME=e@04CMD00`00CME=e@02CMD00`00CMA=e004CM@00`00DO@00005LcL00`00FSIJ
=P03FSH00`00DQEB5@03DQD20007LcP00`00FUIJEP03FUH30006Dad00`00McIg=P0300000e<M001c
>007LcP00`00GUH0000200000e<M001c=`07LcL00`00GUD000020002Dad00`00McIg=P04McH20007
McL00`00HUD00006McL01000HUERE@001GLg00D0069EHUERE@0000=g=`03001RE69D00=RE004001g
=WLf0005HU@01`00NcEk=G/e001Z]@0000MVM@03001Z]FZe00EZ]@03001VM@0000AVU@05001VM6Id
IW@00002JYD00`00K]E^e@03K]D00`00K]D00004K[D00`00K[E^]@03K[D00`00K]E^e@03K]D00`00
K]E^e@02K]D00`00L]Ebe@03L]D01`00L_EbmG;e001g5@0000=bm@03001g5GLE009g5@05001g5GLE
MaD00004MaD00`00MaEg5@02MaD01000McEg=GLe0P000WLe00D007/eNcEk=@00009kEP05001kEW]F
NeH00003NeH01000NgIkMP000g]f00@007]fNgH0009oUP06001oUWnF001oUP000Wne00H007neOkD0
07ne0002NkD01000NmD000000W_E00D007_E000007OE00@00003Lm<006oC00<00003Hk80000000<0
0004E_d000000002E_d00`00E_eFo@03E_d40002E_d00`00E_eFo@03E_d40003E_d01000E_eFoEKm
10001EKm00@005KmE_eFo@<000EFo@03001Fo@000080009Fo@03001FoEKm00=Fo@03001Fo@000080
0003E_d005Km00AFo@@0009Fo@03001FoEKm00=Fo@@001=oo`03001oogoo07Eoo`03001oogoo01]o
o`007Woo0P001Woo0P007Woo0P004goo00<007ooOol0<Woo0`00jgoo00<005KmE_d00`001UKm00@0
05KmE_eFo@<0009Fo@H0000403<0000005@200000`1d0000M@0200001P2E0000000009D00080]@80
00081=H000SE2=D000cF000<eP80008DmP80008I5P03000I5QTF0080008M5P08000Q5R4F000Q=@00
9CH000<U=P04000Y=BTe:CD20002;ED00`00;ED]E@02;ED02@00<EDaEC5E000aE@00<GD00004=GD0
0`00=GDeM@02=GD01@00>GDiMCUe00000cUe0`000cfE00<003fE?ID00SfE00<003fE?ID00cfE00D0
046E@IE1U@0000E1U@030015]DFe00=5]@030015]DFe0095]@030015]DFe00A5]@030015eDGE00=5
e@030015eDGE0095e@030015]DFe00=5]@030015]DFe0095]@03001=e4gD00A=e004001=m@000002
ESH00`00COE=m@04COD00`00COE=m@04COD00`00CME=e@03CMD00`00CME=e@02CMD00`00CMA=e004
CM@20006LcL00`00FSIJ=P04FSH00`00DQD000020002Dad00`00LcQc>005LcP00`00FUH000020002
Dad00`00DaeC7@04Dad30005Dad00`00LcQc>004LcP30005Dad00`00LcMc=`04LcL30006Dad00`00
McIg=P0300000e<M001g=`07McL20006McL01000HUERE@001GLg00D0069EHUERE@0000=g=`03001R
E69D009RE005001g=WLfMcH00004HU@00`00NcEk=@02NcD00`00J[D00007IWD00`00J[EZ]@04J[D0
1000IWEVM@0016JE00D006IdIWAVM000009ZU@03001^eFkE00=^e@03001^e@0000=^]@03001^]Fje
00A^]@03001^eFkE009^e@03001^eFkE00=^e@03001beG;E00=be@05001bmG;eL_D00002MaD00`00
L_D00004MaD00`00MaEg5@02MaD00`00MaEg5@02MaD01@00MaEg5GLE00000gLe00H007/eNcD007Le
0003NcD01000NeIkEP000g]F00@007]FNeIkEP800005NgH007]fNgH00002NgH01000OiIoUP000gnF
00<007nF00000Wne00D007ne001o]@00009k]@0:001ke@00NmD007_E001ke@00MmD400000g?D0000
000400000f>b000000060005E_d00`00E_d0000200000eKm001Fo@04E_d00`00E_d0000200000eKm
001Fo@04E_d40003E_d00`00E_eFo@03E_d40003E_d01000E_eFoEKm0`001UKm00@005KmE_eFo@<0
00EFo@03001Fo@0000800003E_d005Km00AFo@03001Fo@00008001Qoo`03001oogoo07Aoo`03001o
ogoo01]oo`007Woo0P001Woo0P007Woo0P004goo00<007ooOol0;goo0`00kgoo0P000eKm00<005Km
E_d00eKm10000eKm00<005KmE_d01@0000X0<`000000E00005@0001d0000M@<0000409D0002E0002
0;D010000;D000000PSE00<000cF00000PcF0P000QCf0P0000TI5P006AHI5P007AH001dF00000b4F
00@0024e000000<U=P09000Y=BTe:CD002UE000]E@0000@]E@05000aEC5E<ED00002<ED20004=GD0
0`00=GDeM@02=GD00`00>GDiM@02>GD00`00>GDiM@02>GD20002?ID00`00?IDmU@02?ID00`00?IDm
U@03?ID00`00@IE1U@02@ID00`00@IE1U@02@ID00`00AKE5]@03AKD00`00AKE5]@03AKD00`00AKE5
]@03AKD00`00AME5e@03AMD00`00AME5e@02AMD00`00AKE5]@03AKD00`00AKE5]@02AKD00`00CMA=
e004CM@20005ESH00`00COE=m@03COD00`00COE=m@04COD00`00CME=e@03CMD00`00CME=e@03CMD0
0`00CMA=e002CM@20007LcL00`00FSIJ=P03FSH30006Dad01000LcQc>7<h1@001U<M00<005<MDad0
0`0000=C7@00Dad01U<M00<007<hLcP00`000U<M00<005<MDad015<M00<007<gLcL00`000U<M00<0
05<MDad015<M0`001E<M00<007LgMcL017Lg0P001gLg00<0069E00001WLg00@0069EHUD000Eg=`05
001RE69DHU@00004McH01@00HUARE69D00001G/e00<006IeIWD01FIe00<007Le00001FZe00@006Ie
IWD000=VU@03001VM6Id009VM003001ZU@0000I^e@04001^eFkE0002K[D00`00K[E^]@03K[D00`00
L]D00003K]D00`00K]E^e@02K]D00`00K]D00003L]D00`00L_Ebm@02L_D01P00MaEg5@00L_D000Ag
5@07001g5GLEMaD007LE00000WLE00<007LEMaD00WLE00D007LeMcEg=@0000=k=@05001k=G/eNcD0
0002NeH00`00NeIkEP02NeH01000NeIkEP000W]f0`0000EkMP00NgIkMP00009oUP06001oUWnF001o
UP000Wne00H007neOkD007ne0002NkD01P00NmD00000NmD0009ke@<00003Lm@007?D00<00003Km<0
000000H000AFo@04001FoEKmE_d30005E_d01000E_eFoEKm0`001EKm00<005Km00000P000UKm00<0
05KmE_d00eKm00<005Km00000P0000=Fo@00E_d015Km10000UKm00<005KmE_d015Km10000UKm00<0
05KmE_d00eKm0P001EKm00@005KmE_eFo@<001aoo`03001oogoo07=oo`03001oogoo01]oo`007goo
0P0017oo0P006goo0`0000=oo`0000004goo00<007ooOol0;7oo0`00lgoo00<005KmE_d00UKm00<0
05Km00000P000UKm00<005KmE_d00eKm00<005Km00001@0000@0<`000000E0H0000907D0002E09D0
002E0000]@000080]@070008e@SE2=D000cF00000PcF00D001Cf5?H001Cf008000<I5P04000M5P00
00038AH00`008CDQ=@0200039CH01000:CDY=@000RUE00<002eE00000beE00<0035E<ED00S5E00<0
035E<ED00P000cEe00<003Ee=GD00SEe00<003Ue>GD00SUe00<003Ue>GD00SUe00<003VE00000`00
0cfE00<003fE?ID00cfE00<0046E@ID00T6E00<0046E@ID00d6E00<004FeAKD00dFe00<004FeAKD0
0TFe00<004FeAKD00dFe00<004GEAMD00dGE00<004GEAMD00TGE00<004FeAKD00dFe00<004FeAKD0
0TFe00<004gDCM@014gD00<005HfESH015Hf00<004geCOD00dge00<004geCOD014ge00<004gECMD0
0dgE00<004gECMD00dgE00<004gD00000P000U<M00<007<gLcL01G<g00<005Xf00000P000e<M00<0
05<MDad00e<M100015<M00<005<MDad015<M0`001E<M00<005<MDad015<M0`001U<M00@005<MDaeC
7@D000IC7@03001C7E<M00<00003Dad005<M00IC7@03001g=gLg00<0009C7@03001g=gLg00Eg=`80
00Ig=`03001RE@0000Ig=`04001RE69D0005McH01000HUARE0001W/e00<006IeIWD01FIe00<007Le
000016Ze00<006IeIWD00VIe00@006JEIYD000EVM08000E^e@07001^eFkEK]D006je00001Vje00<0
07;E00000VkE00<006kEK]D00fkE00<006kE00000g;E00D007;eL_Ebm@0000Ag5@03001g5GLE00=g
5@05001g5GLEMaD00002MaD00`00MaD00003MaD00`00McEg=@02McD01000NcEk=G/e0P000W/e00@0
07]FNeH000=kEP05001kEW]FNeH00002NgH01000NgEkM@000W]f00L007nFOiIoUP00OiH00002OiH0
2000OkEo]@00OkD007ne0002NkD02P00NmD007_E001ke@00NmD007OE0`000W?D1`0000AKT@000000
00EFo@@0009Fo@03001FoEKm00=Fo@@000=Fo@04001FoEKmE_d30006E_d01000E_eFoEKm0`001EKm
00<005Km00000P0000=Fo@00E_d015Km00<005KmE_d00`0000=Fo@00E_d015Km00<005Km00000P00
00=Fo@00E_d015Km10007goo00<007ooOol0M7oo00<007ooOol06Woo000OOol8000KOol6000COol0
0`00Oomoo`0ZOol2003gOol00`00E_eFo@030006E_d01000E_eFoEKm100000=Fo@00000030000P1e
00@0002E0000U@8000050;D0002e0;D000022=D300023=H010005?HDmP000QCf0P000QTF00<001dF
7AH00P000R4F00@0024e8CDQ=@80008U=P05000Y=BTe:CD00002:ED20004;ED01@00<EDaEC5E0000
0c5E0P000SEe00<003Ee=GD00cEe00D003Ue>GDiM@0000@iM@03000iUCVE008iU@8000<mU@03000m
UCfE008mU@030011UD6E0091U@030011UD6E00=1U@030015]DFe00=5]@030015]DFe0095]@030015
]DFe00=5]@030015eDGE00=5e@030015eDGE0095e@030015]DFe00=5]@030015]DFe0095]@03001=
e4gD00A=e003001F=UHf00AF=P03001=mDge00A=m@03001=mDge00==m@03001=eDgE00A=e@04001=
eDgECMD30006Dad00`00LcMc=`03LcL30007Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00
DaeC7@030002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40004Dad00`00
DaeC7@04Dad30005Dad00`00DaeC7@04Dad30006Dad01000McMg=gLg100027Lg0P001WLg00@0069D
HU@000Eg=P04001RE69D0005NcD20006IWD01000McEg=@000fZe00<006IeIWD00fIe00@006JEIYD0
00EVM003001^eFkE00A^e@07001^eFkEK]D006je00001Fje00L007;EL]Ebe@00K]D00005K]D01P00
K]E^e@00L]D000Abm@03001g5GLE009g5@03001g5GLE009g5@03001g5GLE009g5@05001g5GLEMaD0
0004MaD01@00McEg=GLe00000g/e00H007]ENeD007/e0002NeH01@00NeIkEW]F00000g]F00<007]f
00000g]e0P0000EkMP00OiIoUP00009oUP06001oUWnF001o]@000Wne00<007ne00000W^e00H007_E
000007_E0002NmD300000g?D001ce00700001e^A00000000E_d005Km00<00003E_d005Km00AFo@03
001Fo@0000800003E_d005Km00AFo@@000=Fo@03001FoEKm00=Fo@@0009Fo@03001FoEKm00=Fo@80
00EFo@04001FoEKmE_d40005E_d01000E_eFoEKm0`001EKm00<005Km00000P0097oo00<007ooOol0
Lgoo00<007ooOol06Woo000QOol4000POol3000COol00`00Oomoo`0WOol3003jOol20003E_d00`00
E_eFo@03E_d40004E_d00`00E_d0000200000`0A0000000400001P1D0000E00007D00080U@800003
09D000000080]@030008e@SE00<0008<eP80008DmP04000DmQCf00026AH01@007AHM5QdF00000b4F
00P0024e8CD002De000U=P000bTe00@002UE:EDYE@8000<]E@05000aEC5E<ED00003<ED00`00<ED0
00020005=GD01@00>GDiMCUe000013Ue00<003VE>ID00SVE00<003fE00000`0013fE00<0046E@ID0
0T6E00<0046E@ID00d6E00<004FeAKD00dFe00<004FeAKD00TFe00<004FeAKD00dFe00<004GEAMD0
0dGE00<004GEAMD00dGE00<004FeAKD00dFe00D004FeAKE5]@0000E=e003001c>00000EF=P03001=
mDge00A=m@03001=mDge00==m@03001=eDgE00A=e@@000=C7@03001C7E<M00AC7@03001c=`000080
00=C7@03001C7E<M00AC7@8000IC7@03001C7E<M00=C7@<000IC7@03001C7E<M00=C7@<000IC7@03
001C7E<M00<00003Dad005<M00IC7@03001C7E<M00<00003Dad005<M00IC7@03001C7E<M00<0009C
7@03001C7E<M00AC7@@000AC7@03001g=gLg00Ag=`8000Mg=`03001RE00000Ig=P03001RE00000Ek
=@04001c=g<g0005IWD01@00McEg=GLe00000VZe00<006IeIWD00fIe00<006JE00001VId00<006kE
K]D00fkE00<006kEK]D00fkE00<006jeK[D016je00L007;EL]Ebe@00K]D00004K]D01`00K]E^eFkE
001be@0000=bm@03001g5GLE009g5@03001g5@0000=g5@05001g5GLEMaD00004MaD01@00MaEg5GLE
000017Le00D007/eNcEk=@0000=kE@04001kEW]F0003NeH01@00NeIkEW]F00000W]f00@007]eNgD0
009kM@<00004OiH007nF0002OiH00`00OkD00003OkD20002NkD01000NmD007_E1@0000Uge0000000
07?D001cd`00Jm802`001EKm00@005KmE_eFo@<000EFo@03001Fo@0000800003E_d005Km00EFo@03
001Fo@0000800003E_d005Km00AFo@03001Fo@0000800003E_d005Km00AFo@@000=Fo@03001FoEKm
00=Fo@@000=Fo@04001FoEKmE_d3000XOol00`00Oomoo`1bOol00`00Oomoo`0JOol005Yoo`03001o
ogoo02Eoo`<00?ioo`03001FoEKm009Fo@03001Fo@000080009Fo@03001FoEKm00=Fo@H000040140
000003<2000205@2000207D00`0009D0000200000`2E0000]@020;D00`002=D8e@0300023=H20000
11Cf000DmQCf0P000QTF00<001dF7AH00P000R4F00@0024e8CD0008U=@8000<Y=@07000YEBUE:ED0
02eE00000ReE00D0035E<EDaE@0000<aE@04000aEC5E<ED20004=GD01@00>GDiMCUe00001CUe00D0
03VE>IDiU@0000@mU@@0008mU@050011UD6E@ID00005@ID00`00AKE5]@03AKD00`00AKE5]@02AKD0
0`00AKE5]@04AKD00`00AME5e@03AMD00`00AME5e@060002AKD01@00AKE5]DFe000014gD00@007<h
LcP000IF=P03001=mDge00==m@03001=mDge00A=m@03001=eDgE009=e@8000MC7@04001C7E<MDad4
0007Dad00`00DaeC7@0300000e<M001C7@06Dad00`00Dad000020003Dad00`00DaeC7@04Dad00`00
Dad000020003Dad00`00DaeC7@03Dad30005Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad3
0006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00McMg=`0300000e<M001g=`07McL20006McH0
0`00HU@00005NcD01000LcMc=`0016Ie00<007LeMcD00WLe00<006Ze00001VIe00<006JE00001VId
0P0016kE00<006kEK]D00fkE00<006jeK[D00fje00<007;EL]D00g;E00<006kEK]D00fkE00<006kE
K]D00VkE00<007;eL_D00W;e00<007LEMaD00WLE00H007LEMaD007LE0004MaD01`00MaEg5GLE001g
5@00009g5@05001g=GLeMcD00004NcD01000NeEkEG]E0P0000=kEP00NeH00W]F00D007]FNeIkEP00
009kMP04001kMG]e0002NgD00`00OiEoU@0200001gnF001oUWnF001o]@00009o]@03001o]@00009k
]@06001ke@00001ke@000W_D10000W?D2`000eKm00<005KmE_d00eKm10000UKm00<005KmE_d00eKm
0P001EKm00@005KmE_eFo@@000EFo@04001FoEKmE_d30005E_d00`00E_d0000200000eKm001Fo@05
E_d00`00E_d0000200000eKm001Fo@04E_d4000/Ool00`00Oomoo`1aOol00`00Oomoo`0JOol005Yo
o`03001oogoo00<001moo`<00?moo`=oo`03001FoEKm00@000EFo@03001Fo@000080009Fo@P00008
03<0000005@0001D0000M@80000309D000000080U@030000]@2e008000042=D000SE00023=H01000
4=D000000QCf00D001Se000I5P00008M5P05000M5@008AH000038CD00`009CDU=@020002:CD01@00
:EDYEBUE00000ReE0`00135E00D0035E<EDaE@0000<aE@8000<eM@03000iMCUe008iM@03000iMCUe
008iM@03000iUCVE008iU@05000mUCfE?ID00003?ID600000d6E0011U@03@ID00`00AKE5]@03AKD0
0`00AKE5]@03AKD00`00AKE5]@03AKD00`00AME5e@060002AMD01000@KI1]T6f0`000dFe00<004gD
CM@00TgD00@007<hLcP000IF=P03001=mDge00==m@03001=mDge00A=m@03001=e@000080009C7@03
001C7E<M00AC7@@000AC7@03001C7E<M00AC7@<000EC7@03001C7E<M00AC7@8000MC7@04001C7E<M
Dad40007Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00DaeC7@030003Dad00`00DaeC7@03
Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad30005Dad00`00McMg
=`04McL20008McH20004NcD01@00LcMc=g<g000016Ie00<007LeMcD00WLe00<006Ze00001fIe0P00
1FId00<007/D000016kE00<006kEK]D00VkE00<006Id000016je00<007;EL]D00g;E00<006kEK]D0
0VkE00<006kEK]D00fkE00<007;eL_D00W;e00<007LEMaD00WLE00H007LEMaD007LE0003MaD00`00
MaEg5@02MaD01P00MaEg5@00MaD000=g=@05001k=G/eNcD00003NeD01000NeEkE@000g]F00D007]F
NeIkEP00009kMP07001kMG]eNgD007]e00000gnE00<007nE00001`0000=o]@0000001@0000=ke@00
00000W_D00H007OD001ce000Lm@;0005E_d00`00E_d0000200000eKm001Fo@04E_d00`00E_d00002
00000eKm001Fo@04E_d40003E_d00`00E_eFo@03E_d40003E_d01000E_eFoEKm0`001EKm00@005Km
E_eFo@@000EFo@03001Fo@000080031oo`03001oogoo075oo`03001oogoo01Yoo`00FWoo0`007goo
0`00ogoo1goo0P0015Km00@005KmE_eFo@<000IFo@L0000303<000000080E0<0000307D000000080
0080U@050000]@2e0000]@0200001@SE000<ePcF00000Q3E0P000QCf00@001Se000000<M5P04000M
5@0000038CD01@009CDU=BDe00000bTe00D002UE:EDYE@0000<]E@8000<aE@05000aEC5E<ED00003
<ED01P00=GD00000=GD000@iM@03000iMCUe008iM@03000iUCVE008iU@05000mUCfE?ID00005?ID0
1000?IDmUCfE10000d6E00<004FeAKD00dFe00<004FeAKD00TFe00<004FeAKD01P000dWE00<004GE
AMD00TGE00<0046f@KH00d6f0P000dFe00@004gDCM@000Ac>003001F=UHf00=F=P03001=mDge00==
m@03001=mDge00==m@<000IC7@03001C7E<M00<00003Dad005<M00IC7@03001C7E<M00<00003Dad0
05<M00IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00AC7@8000IC7@03
001C7E<M00=C7@<000MC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00
DaeC7@030002Dad00`00DaeC7@04Dad00`00McMg=`030002Dad00`00McIg=P04McH20005NcD00`00
LcMc=`02LcL01@00IWEVMFIe00001GLe00<006IeIWD01VIe00<006IdIW@016Id00@007/DNa@0009^
e@03001^eFkE00=^e@03001VM00000A^]@03001beG;E009be@03001^e@0000=^e@03001^eFkE009^
e@03001fm@00009bm@03001g5GLE009g5@03001g5GLE009g5@03001g5GLE009g5@03001g5GLE009g
5@05001g5GLEMaD00004McD01@00NcEk=G/e00000g]E00<007]ENeD00P000W]F00D007]FNeIkEP00
009kMP04001kMG]e0002NgD01000OiEoU@000WnE00H007nEOiD007ne0002OkD00`00OkD00002NkD0
1P00NmD00000NmD0009ke0@0009ce0X00003E_d005Km009Fo@<000EFo@04001FoEKmE_d30005E_d0
0`00E_d000020002E_d00`00E_eFo@03E_d00`00E_d0000200000eKm001Fo@04E_d40002E_d00`00
E_eFo@03E_d40004E_d01000E_eFoEKm0`00=7oo00<007ooOol0L7oo00<007ooOol06Woo001JOol0
0`00Oomoo`0LOol3003oOol;Ool00`00E_eFo@02E_d40003E_d00`00E_eFo@03E_d80000100c0000
001D1@0000@0M00009D00080U@050000]@2e0000]@0200001@SE000<ePcF00000Q3E00@001Cf5?H0
008Hm@80008M5P03000M5AdE0080008Q=@04000U=BDe9CD20002:CD01@00:EDYEBUE000012eE0P00
0S5E00D0035E<EDaE@0000<aE@04000eMCEe=GD30003>GD00`00>GDiM@02>GD00`00>IDiU@02>ID0
0`00?IDmU@02?ID00`00?IDmU@02?ID00`00?IDmU@02?ID00`00?IDmU@040005AKD00`00AKE5]@05
0003BMD00`00BME9e@03BMD00`00AME5e@03AMD00`00@KI1]P02@KH00`007AH00002AKD00`00CM@0
0005LcP00`00ESIF=P03ESH00`00COE=m@04COD00`00COD000020002Dad00`00DaeC7@04Dad30005
Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad30006Dad00`00DaeC7@0300000e<M001C7@06
Dad00`00DaeC7@0300000e<M001C7@06Dad00`00Dad000020003Dad00`00DaeC7@04Dad40004Dad0
0`00DaeC7@03Dad30005Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M1@001U<M00<007LfMcH0
0`0000=C7@00NcD00g/e00<007<gLcL00g<g00@006IeIWD000Ig=@03001VMFIe00IVM@03001VM6Id
00AVM007001k57/DNa@006kE00001FkE00<006Id00000fje00<007;EL]D00g;E00<006kE00000fkE
00<006kEK]D00VkE00H007KeM_D007;e0004MaD00`00MaEg5@02MaD01@00MaEg5GLE000017LE00<0
07LEMaD00WLE00D007LeMcEg=@0000=k=@05001kEG]ENeD00002NeD01P00NeEkE@00NeH0009kEP04
001kMW]f0003NgD00`00NgD00003OiD00`00OiD00002OiD00`00OkD00003OkD20002NkD01000NmD0
07_E0P000W_D0`0000=ce00000002P000UKm10000UKm00<005KmE_d00eKm10000eKm00@005KmE_eF
o@<000IFo@04001FoEKmE_d30005E_d00`00E_d0000200000eKm001Fo@04E_d00`00E_d000020002
E_d00`00E_eFo@03E_d4000hOol00`00Oomoo`1_Ool00`00Oomoo`0JOol005Yoo`03001oogoo01Uo
o`<00?moo`moo`04001Fo@000002E_d00`00E_eFo@03E_d00`00E_d000020002E_d:00000`1D0000
0002000207@2000209D200001P2e0000]@2e0008e@8000053=H0013E4=D000025?H01@006?DHmASe
00000QdF00D001dE7ADM5@0000<Q=@08000U=BDe000U=@00:CD000<YE@03000]EBeE008]E@05000]
E@00<ED00003<ED00`00<EDaE@02<ED00`00=GDeM@02=GD20002>GD00`00>GDiM@02>GD00`00>IDi
U@02>ID00`00?IDmU@02?ID00`00?IDmU@03?ID01@00?IDmUCfE00001CfE2@000TFd00<004WEBMD0
0dWE00<004WEBMD014WE00<004GEAMD00TGE00<0046f@KH00d6f00L001dF0015]@00CM@00006LcP0
0`00ESIF=P03ESH00`00COE=m@050006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00DaeC7@03
0002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04
Dad30005Dad00`00DaeC7@04Dad20007Dad00`00DaeC7@0300000e<M001C7@06Dad00`00Dad00002
0002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@04
Dad30005Dad01000NcEk=@001W<g00@006IeIWD000Eg=@8000MVM@8000EVM003001k57/D009k5003
001^e@0000A^e@05001VM6IdIW@00002K[D00`00L]Ebe@02L]D01`00K]E^eFkE001^e@0000E^e@06
001fmGKe001bm@000gLE00<007LEMaD00WLE00<007LE00000WLE00<007LEMaD00WLE00L007LEMaEg
5@00MaD00002McD01@00NcEk=G/e00000g]E00@007]ENeD000=kE@80009kEP04001kMW]f0002NgD0
1000NgEkM@000WnE00@007nEOiD0009oU@03001o]@00009o]@05001o]@00NkD00002NmD200001G_E
001ke000Mm@0100000Acd`00001[dPT00003E_d005Km00AFo@03001Fo@0000800003E_d005Km00AF
o@@000=Fo@03001FoEKm00=Fo@@000=Fo@04001FoEKmE_d30005E_d01000E_eFoEKm10001EKm00<0
05Km00000P00?7oo00<007ooOol0L7oo00<007ooOol06Goo001JOol00`00Oomoo`0FOol3003oOolC
Ool00`00E_eFo@03E_d01000E_eFoEKm0`001UKm0`0000<04@0000001@0000/0E00005@0001d0000
U@0009D0002E00800080]@040008e@002=D200024=D200025?H010006?DHm@000adF00<001dE7AD0
0P000R4e00H002De9CDU=@009CD20003:ED00`00;ED]E@02;ED00`00;ED]E@020004<ED01@00<EDa
EC5E000013Ee00<003Ee00000P0013Ue00<003VE>ID00SVE00<003fE?ID00SfE00<003fE?ID00cfE
00<003fE?ID00SfE00<003fE?ID00SfE00<004FDAI@00dFD00<004FdAK@00TFd00<004WEBMD014WE
00<004WEBMD00dWE00<004GEAMD00TGE00<0046f@KH00d6f00<001dF7AH00`001g<h00<005HfESH0
0UHf100015<M00<005<MDad015<M0`001E<M00<005<MDad015<M0`001U<M00@005<MDaeC7@D000IC
7@03001C7E<M00<00003Dad005<M00IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7E<M
00<0009C7@03001C7E<M00AC7@<000EC7@03001C7E<M00AC7@8000IC7@03001C7E<M00=C7@<000IC
7@03001C7E<M00<00003Dad005<M00IC7@03001C7E<M00<00003Dad005<M00IC7@03001k=@0000Ic
=`03001VM@0000Eg=@04001c>7<h0005IWD01000McIg=P0016Id00<007/DNa@00g/D00<006kEK]D0
0fkE00L006IdIWAVM000K[D00005L]D01`00K]E^eFkE001^e@0000A^e@03001fmGKe009fm@03001g
5GLE009g5@03001g5GLE009g5@06001g5GLE001g5@000gLE00<007LEMaD00WLE00H007LEMaD007Le
0003NcD01000NeEkE@000g]E00/007]ENeEkE@00NeD007]F001kMP0000=kM@03001kM@0000=oU@03
001oU@00009oU@03001o]@0000=o]@80009k]@04001ke@00NmD20002Nm@300000g?C001cd`0:0005
E_d01000E_eFoEKm0`001EKm00<005Km00000P000UKm00<005KmE_d00eKm00<005Km00000P0000=F
o@00E_d015Km10000UKm00<005KmE_d00eKm100015Km00@005KmE_eFo@<0041oo`03001oogoo06mo
o`03001oogoo01Uoo`00FWoo00<007ooOol04goo0`00ogoo5goo00<005KmE_d00UKm10000eKm00<0
05KmE_d00eKm2@0000@0<`0005@0E0800080M0<0000309D0002E00800080]@040008e@002=D20002
4=D2000011Cf000HmASe0P000QdF00P001dE7AD0024E000Q=@000bDe00<002De9CD00P000bUE00<0
02eE;ED00ReE00<002eE;ED00P000c5E00D0035E<EDaE@0000@eM@04000eMCEe=GD20003>GD00`00
>IDiU@03>ID01@00?IDmUCfE00001CfE00<003fE?ID00SfE00<003fE?ID00SfE00<004FDAI@00dFD
00<004FdAK@00dFd00<004WEBMD00dWE00<004WEBMD00dWE00<004GEAMD00TGE00<0046f@KH00d6f
00@001dF7AHM5P8000Mc>003001F=P000080009C7@03001C7E<M00AC7@03001C7E<M00<00003Dad0
05<M00IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00AC7@<000EC7@03
001C7E<M00AC7@<000IC7@04001C7E<MDad50006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00
DaeC7@030002Dad00`00DaeC7@04Dad00`00Dad000020003Dad00`00DaeC7@03Dad30005Dad00`00
DaeC7@04Dad30005Dad00`00DaeC7@04Dad20008LcL20005McD01000LcQc>0001FIe00@007LfMcH0
00AVM003001k57/D00=k5003001^eFkE009^e@03001VM6Id009VM003001^]@0000Abe@03001^eFkE
009^e@03001^e@0000A^e@03001fmGKe009fm@03001g5GLE009g5@03001g5GLE009g5@05001g5GLE
MaD00004MaD00`00MaEg5@02MaD01@00MaEg5GLE00000g/e00D007]ENeEkE@00009kE@05001kEG]E
NeD00003NeD01000NgIkMP000W]e00@007]eNgD0009oU@04001oUGnE0002OiD00`00OkD00002OkD0
1@00OkD007^e00000W_E0P0000Eke@00Nm@007OD00<00003Lm<0000000L00003E_d005Km00AFo@@0
00=Fo@04001FoEKmE_d30006E_d01000E_eFoEKm0`001EKm00<005Km00000P0000=Fo@00E_d015Km
00<005Km00000P0000=Fo@00E_d01EKm1000A7oo00<007ooOol0KWoo00<007ooOol06Goo001IOol0
0`00Oomoo`0BOol2003oOolKOol01000E_d000000UKm00<005KmE_d00eKm00<005Km00000P000UKm
100000/04P000000000c0000E00005@0001d00D00080U@030000]@2e00<00088e@05000@eA3E000@
e@0200036?D200000adF000M5@027AD010008AD000000bDe00@002De9CDU=@80008YE@03000]EBeE
008]E@04000]EBeE;ED20002<ED01@00<EDaEC5E00001CEe00@003Ee=GDeM@8000<iM@03000iUCVE
008iU@05000mUCfE?ID00005?ID00`00?IDmU@02?ID00`00?IDmU@02?ID00`00AIA5U003AI@00`00
AKA5]003AK@00`00BME9e@03BMD00`00BME9e@03BMD00`00AME5e@03AMD00`00@KI1]P03@KH00`00
7AHM5P027AH00`00LcQc>004LcP20006Dad00`00DaeC7@03Dad30005Dad00`00DaeC7@04Dad30006
Dad00`00DaeC7@0300000e<M001C7@06Dad00`00DaeC7@0300000e<M001C7@06Dad00`00DaeC7@03
0002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad30006Dad0
1000DaeC7E<M10001e<M00<005<M00000P0000=C7@00Dad01U<M00<005<MDad00`000U<M00<005<M
Dad015<M00<005<MDad00`000U<M00<007<gLcL017<g0P001GLe00D007<hLcQc>00000AVM@05001g
=WLfMcH00003IW@00`00NaAk5003Na@00`00McD00003K]D00`00IWAVM003IW@00`00L]Ebe@03L]D0
0`00K]E^e@03K]D00`00K]E^e@03K]D01`00M_EfmGKe001g5@00009g5@03001g5GLE009g5@03001g
5GLE009g5@03001g5GLE009g5@05001g5GLEMaD00004MaD20002NcD01000NeEkE@000g]E00D007]E
NeEkE@0000=kE@800005NgH007]eNgD00002NgD01P00OiEoU@00OiD0009oU@03001o]@0000=o]@80
009k]@04001ke@00NmD20002Nm@3000017?C000006oC1`000eKm00<005Km00000P0000=Fo@00E_d0
15Km10000UKm00<005KmE_d015Km10000eKm00@005KmE_eFo@<000EFo@04001FoEKmE_d30005E_d0
0`00E_eFo@030019Ool00`00Oomoo`1]Ool00`00Oomoo`0IOol005Uoo`03001oogoo00moo`<00?mo
oaioo`03001FoEKm00=Fo@04001FoEKmE_d40005E_d70000100c0000E01D1P0000D0M@0009D0U@00
0080]@<00088e@04000@eA3E00024=D200026?D010006?D000000adE00<0024E8AD00P000RDe00T0
02De9CDU=@00:CD002UE000012eE00T002eE;ED]E@00<ED0035E0000135E00<003Ee=GD00SEe00H0
03Ee=GDeM@00>GD200000cUe000iU@03>ID00`00?IDmU@02?ID00`00?IDmU@02?ID00`00?IDmU@02
?ID00`00?IDmU@03?ID00`00AIA5U002AI@00`00AKA5]003AK@00`00BME9e@03BMD00`00BME9e@03
BMD00`00AME5e@03AMD00`00@KI1]P03@KH00`007AHM5P037AH00`00LcQc>00300000e<M001C7@06
Dad00`00Dad000020003Dad00`00DaeC7@03Dad00`00DaeC7@030003Dad00`00DaeC7@03Dad30005
Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad30006Dad00`00DaeC7@0300000e<M001C7@06
Dad00`00DaeC7@0300000e<M001C7@06Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40004Dad0
0`00DaeC7@04Dad20005Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M1@001U<M00<007<gLcL0
0`0000=C7@00McD00gLe00<007<hLcP00g<h00D006IeIWEVM@0000=g=P05001VM6IdIW@00005Na@0
0`00McD00003K]D00`00IWAVM003IW@00`00L]Ebe@03L]D00`00K]E^e@03K]D00`00K]E^e@02K]D0
0`00M_Efm@02M_D01P00MaEg5@00MaD000Ag5@07001g5GLEMaD007LE00000WLE00<007LEMaD00WLE
00D007LEMaEg5@00009k=@03001k=@00009kE@04001kEG]E0004NeD01000NeEkE@000W]e0`0000Ak
M@00NgD000=oU@03001oU@00009oU@03001o]@00009o]@05001o]@00NkD00002NmD200001G_E0000
0000Mm@00`0000=cd`0000001P000eKm0`001EKm00<005Km00000P0000=Fo@00E_d015Km00<005Km
E_d00`0000=Fo@00E_d015Km10000UKm00<005KmE_d00eKm10000UKm00<005KmE_d00eKm0`00C7oo
00<007ooOol0KGoo00<007ooOol06Goo001IOol00`00Oomoo`0<Ool3003oOolROol00`00E_eFo@02
E_d40004E_d01000E_eFoEKm2@0000<0<`0005@00P0000@0E00000000080M@040000U@2E00020;D3
00022=D010004=D@e@000Q3E00@001Se6?D0008Hm@80008M5@05000Q5B4E8AD000039CD010009CDU
=@000RTe0P0012eE00D002eE;ED]E@00008aE@8000@aE@03000eMCEe008eM@05000eMCEe=GD00003
>GD20004>ID00`00?IDmU@02?ID00`00?IDmU@03?ID01@00?IDmUCfE00001CfE00<004FDAI@00dFD
00<004FdAK@00TFd00<004WEBMD00dWE00<004WEBMD014WE00<004GEAMD00TGE00<0046f@KH00d6f
00<001dF7AH00adF0`001E<M00<005<MDad015<M0P001e<M00@005<MDaeC7@@000MC7@03001C7@00
0080009C7@03001C7E<M00AC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7E<M00<0009C
7@03001C7E<M00AC7@<000EC7@03001C7E<M00AC7@<000EC7@03001C7E<M00AC7@<000IC7@03001C
7E<M00<00003Dad005<M00IC7@03001C7E<M00<00003Dad005<M00EC7@03001C7E<M00<0009C7@03
001C7E<M00AC7@@000AC7@03001C7E<M00AC7@<000EC7@05001g=GLeMcD00005LcP01000IWEVM@00
1GLf00@006IdIW@000Ak5007001g=GLeMcD006kE00001FId00<007/d00000g;E00<006kEK]D00fkE
00<006Id00000fkE00<007KeM_D00WKe00H007LEMaD007LE0003MaD00`00MaEg5@02MaD01P00MaEg
5@00MaD000=g5@03001g5GLE009g5@05001k=G/eNcD00002NeD01@00NeEkEG]E00000g]E00D007]E
NeEkE@00009kM@03001kMG]e00800005NgD007nEOiD00002OiD01P00OiEoU@00OkD0009o]@04001o
]@000002NmD00`00NmD0000200000gOD00000002000017?C000006_B2@000eKm00@005KmE_eFo@<0
00EFo@04001FoEKmE_d40005E_d00`00E_d0000200000eKm001Fo@04E_d00`00E_d0000200000eKm
001Fo@04E_d00`00E_d00002001@Ool00`00Oomoo`1/Ool00`00Oomoo`0IOol005Uoo`03001oogoo
00Uoo`<00?moobIoo`04001Fo@000002E_d00`00E_eFo@03E_d40003E_d00`000100000600000`1D
000000020000101d0000M@000P2E0P0000@0]@001;D00088e@8000054=D0013E4=D000036?D01000
6?DHm@000adE00<0024E8AD00P000RDe00D002De9CDU=@00008Y=@8000@]E@05000]EBeE;ED00002
<ED20003<ED00`00=GDeM@02=GD00`00=GDeM@02=GD01000>GDiMCUe0`000SVE00<003fE?ID00SfE
00<003fE?ID00cfE00<003fE?ID00SfE00<003fE?ID00SfE00<004FDAI@00dFD00<004FdAK@00TFd
00<004WEBMD014WE00<004WEBMD00dWE00<004GEAMD00TGE00<0046f@KH0146f00<001dF00000P00
00=C7@00Dad01U<M00<005<MDad00`000U<M00<005<MDad015<M100015<M00<005<MDad015<M0P00
1U<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@D000IC7@03001C7E<M00<00003Dad005<M00IC
7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7E<M00<0009C7@03001C7E<M00AC7@<000EC
7@03001C7E<M00AC7@<000EC7@03001C7E<M00=C7@<000IC7@03001C7E<M00<00003Dad005<M00IC
7@03001C7E<M00<00003Dad005<M00IC7@03001g=@0000Ic>003001VM@0000Ig=P03001VM00000Ek
5007001g=GLeMcD006kE00001FId00<007/d00000g;E00<006kEK]D00fkE00<006Id00000fkE00D0
07KeM_Efm@0000Ag5@03001g5GLE009g5@03001g5GLE009g5@06001g5GLE001g5@000gLE00<007LE
MaD00WLE00@007/eNcEk=@800003NeD007]E009kE@05001kEG]ENeD00002NeD01000NgEkM@000g]e
00<007me00000P0000AoU@00OiD0009oU@03001o]@00009o]@05001o]@00NkD00002NmD200001G_D
001ge000Mm@0100000=_dP0000001@0000=Fo@00E_d015Km10000UKm00<005KmE_d00eKm10000eKm
00<005KmE_d00eKm0P001EKm00@005KmE_eFo@<000EFo@04001FoEKmE_d3001DOol00`00Oomoo`1[
Ool00`00Oomoo`0IOol005Uoo`03001oogoo00Ioo`<00?moobYoo`8000AFo@03001Fo@000080009F
o@03001FoEKm00=Fo@/0000405@0001d000207D0100009D0002E0P0000H4]@002=D8e@003=D20002
4=D200026?D00`006?DHm@0200027AD020008ADQ5@008AD002De00039CD01000:CDY=BTe0P000beE
00D002eE;ED]E@0000<aE@80008aE@03000eMCEe008eM@03000eMCEe008eM@05000iMCUe>GD00002
>ID40003?ID00`00?IDmU@03?ID00`00?IDmU@02?ID00`00?IDmU@02?ID00`00AIA5U003AI@00`00
AKA5]003AK@00`00BME9e@03BMD00`00BME9e@03BMD00`00AME5e@02AMD00`00@KI1]P03@KH30005
Dad00`00DaeC7@04Dad30006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00DaeC7@0300000e<M
001C7@06Dad00`00Dad000020003Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@04Dad30005Dad0
0`00DaeC7@04Dad30006Dad01000DaeC7E<M1@001U<M00<005<MDad00`0000=C7@00Dad01U<M00<0
05<MDad00`000U<M00<005<MDad015<M00<005<M00000P000e<M00<005<MDad00e<M0`001E<M00<0
05<MDad015<M0`001E<M00<005<MDad015<M0P0027<h0P001WLf00<006Id000017/D00<007LeMcD0
0WLe00<006kE00001FId00H007/dNc@007;E0005K]D01`00IWAVM6Id001^e@0000Afm@03001g5GLE
009g5@03001g5GLE009g5@05001g5GLEMaD00004MaD00`00MaEg5@02MaD01@00MaEg5GLE00000g/e
00@007]ENeD000=kE@05001kEG]ENeD00003NeD01000NgEkM@000W]e00@007meOgD0009oU@800007
OiD007nEOiD007ne00000Wne00<007ne0000100000=ke00000000WOD1@0000=_dP000000100015Km
00<005Km00000P0000=Fo@00E_d015Km00<005Km00000P000UKm00<005KmE_d00eKm00<005Km0000
0P0000=Fo@00E_d015Km10000UKm00<005KmE_d00eKm1000F7oo00<007ooOol0Jgoo00<007ooOol0
67oo001IOol00`00Oomoo`03Ool3003oOol_Ool00`00E_eFo@030006E_d01000E_eFoEKm100000<0
4@0001800P0000<0<`0000000P1D00@0001d0000M@80000309D0002E008000061;D000SE2=D000cE
0P000Q3E0P0000THm@006?DHm@006?D001dE00000b4E00@0024E000000<U=@07000Y=BTe:CD002de
00000ReE00D002eE;ED]E@0000<aE@03000aE@00008000DeM@05000eMCEe=GD00003>GD00`00>IDi
U@03>ID20002?ID00`00?IDmU@03?ID00`00?IDmU@02?ID00`00?IDmU@02?ID00`00AIA5U003AI@0
0`00AKA5]003AK@00`00BME9e@03BMD00`00BME9e@03BMD00`00AME5e@03AMD00`00@KH000020002
Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad3
0005Dad00`00DaeC7@04Dad20007Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00DaeC7@03
0002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@04
Dad30005Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M10001e<M00<005<M00000P0000=C7@00
Dad01U<M00<005<MDad00`000U<M00<005<MDad015<M00<005<MDad00`000U<M00<007<hLcP017<h
0P001gLf00<006Id000017/D00<007LeMcD00gLe00<006IdIW@00fId00L007/dNcAk=000L]D00005
K]D01`00IWAVM6Id001^e@0000Afm@07001g5GLEMaD007LE00000WLE00<007LEMaD00WLE00<007LE
MaD00WLE00D007LEMaEg5@0000Ag5@05001k=G/eNcD00002NeD20002NeD01@00NeEkEG]E00000W]E
00D007]eNgEkM@00009kM@03001oM@0000=oU@03001oU@0000X00004NkD007_DNm@200000g_D001g
e00200001GOC00000000Km801P000eKm0`001EKm00@005KmE_eFo@<000IFo@04001FoEKmE_d30005
E_d00`00E_d0000200000eKm001Fo@04E_d00`00E_d00002001LOol00`00Oomoo`1[Ool00`00Oomo
o`0HOol005Qoo`03001oogoo00@00?mooc=oo`8000=Fo@03001FoEKm00=Fo@@0009Fo@D000040180
000003<200000`1D0000M00300000`1d0000000209D01P001;D000002=D0008<e@05000@eA3E000D
m@0200036?D010006?D000000b4E00<0024E8AD00P000RDe00D002Te:CDY=@00008]=@03000]E@00
00<]E@05000aEC5E<ED00003<ED20004=GD01@00=GDeMCEe000013Ue00<003VE>ID00SVE00<003Ue
00000`0013fE00<003fE?ID00SfE00<003fE?ID00SfE00<004FDAI@00dFD00<004FdAK@00dFd00<0
04WEBMD00dWE00<004WEBMD00dWE00<004GEAMD00TGE0`001U<M00@005<MDaeC7@D000IC7@03001C
7E<M00<00003Dad005<M00IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7E<M00<0009C
7@03001C7E<M00AC7@8000IC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad50006Dad00`00DaeC
7@0300000e<M001C7@06Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad0
0`00DaeC7@04Dad40004Dad00`00DaeC7@04Dad20005Dad00`00DaeC7@04Dad30006Dad01000DaeC
7E<M1@001U<M00<007<hLcP00`0000=C7@00McH01gLf00<007/DNa@00W/D00<007LeMcD017Le00<0
06IdIW@00fId00<007/dNc@00W/d00<006kEK]D00fkE00<006IdIW@00VId00<006kE00000gKe00<0
07LEMaD00WLE00H007LEMaD007LE0003MaD00`00MaEg5@02MaD00`00L_D00002MaD01@00MaEg5GLE
00000g/e00@007]ENeD0009kE@03001kE@00009kE@05001kEG]ENeD00002NgD01000NgEkM@000Wme
00@007nEOiD0009oU@06001oUGnE001o]@000Wne00@007ne0000009ke004001ke0000002Mm@50000
0foB000000080002E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d40003E_d01000E_eFoEKm
0`001EKm00@005KmE_eFo@<0061oo`03001oogoo06Yoo`03001oogoo01Qoo`00F7oo1000ogoo=goo
00<005KmE_d00UKm00<005Km00000P000UKm00<005KmE_d00UKm100000@04P000000<`800080E080
000507@0000007@0000209D010001;D000Be0P000PcE00@0013E4=D0008Dm@80008Hm@03000HmASe
0080008Q5@05000Q5B4E8AD000039CD01@00:CDY=BTe00000Rde0P0012eE00D0035E<EDaE@0000<a
E@8000<eM@05000eMCEe=GD00004>GD00`00>IDiU@02>ID00`00>GDiM@02>GD40002?ID01@00?IDm
UCfE00001CfE00<004FDAI@00TFD00<004FdAK@00dFd00<004WEBMD00dWE00<004WEBMD014WE1000
0e<M00<005<MDad00e<M100015<M00<005<MDad015<M0`001E<M00<005<MDad015<M0`001U<M00@0
05<MDaeC7@D000IC7@03001C7E<M00<00003Dad005<M00IC7@03001C7@00008000=C7@03001C7E<M
00=C7@@000AC7@03001C7E<M00AC7@<000EC7@03001C7E<M00AC7@<000IC7@04001C7E<MDad50006
Dad00`00DaeC7@0300000e<M001C7@06Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC
7@030002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@04Dad30005Dad00`00McIg=P04McH20004
Na@00`00McEg=@03McD20005IW@00`00NcAk=002Nc@00`00K]E^e@03K]D00`00IWAVM003IW@00`00
M_Efm@02M_D00`00MaEg5@02MaD01P00MaEg5@00MaD000=g5@03001g5GLE009g5@06001bmG;e001g
5@000gLE00D007/eNcEk=@00009kE@04001kEG]ENeD20002NeD01000NeEkE@000g]e00@007]eNgD0
009oM@06001oUGnE001oU@000WnE00<007ne00000Wne00D007ne001k]@00009ke0800003Nm@007OD
00800003Mm<0000000800003Jm80000000<00003E_d005Km00AFo@03001Fo@000080009Fo@03001F
oEKm00=Fo@03001Fo@0000800003E_d005Km00AFo@@0009Fo@03001FoEKm00=Fo@@006Aoo`03001o
ogoo06Uoo`03001oogoo01Qoo`00F7oo0P00ogoo>Woo00<005KmE_d010001EKm00<005Km00001P00
00@04P000000<`80000305@0000000<00080M0070000U@2E0004]@001;D00P0000<<e@0000000Q3E
00@001Ce5?D0008Hm@05000HmASe6?D000038AD00`008ADQ5@0200029CD01@00:CDY=BTe00000bde
0P000beE00D0035E<EDaE@0000<aE@03000aE@00008eM@03000eMCEe008eM@05000iMCUe>GD00005
>ID01@00>GDiMCUe00000d6D10000cfE00<003fE?ID00SfE00<004FDAI@00TFD00<004FdAK@00dFd
00<004WEBMD014WE00<004WEBMD010001e<M00<005<M00000P000U<M00<005<MDad015<M00<005<M
Dad00`000U<M00<005<MDad015<M00<005<MDad00`000U<M00<005<MDad015<M100015<M00<005<M
Dad015<M0`001E<M00<005<MDad015<M0P001e<M00<005<M00000P000U<M00<005<MDad015<M00<0
05<MDad00`0000=C7@00Dad01U<M00<005<MDad00`000U<M00<005<MDad015<M100015<M00<005<M
Dad015<M0`001E<M00<005<MDad015<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003
Dad005<M00IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001g=WLf00<0009C7@04001k57/D
0005McD01000LcMc=`000fId00<007/dNc@00W/d00<007Lf000016kE00<006IdIW@00fId00<007Ke
M_D00WKe00D007LEMaEg5@0000Ag5@03001g5GLE009g5@03001g5GLE009g5@05001bmG;eL_D00004
MaD01000NcEk=@000g]E00T007]ENeEkE@00NeD007]E00000W]E00@007]eNgD0009kM@04001oMGme
0003OiD00`00OiD00002OiD00`00OkD00002OkD01000OkD000000W_D00@007_D0000009ge0D00003
Km80000000<000AFo@04001FoEKmE_d30006E_d01000E_eFoEKm0`001EKm00<005Km00000P0000=F
o@00E_d015Km00<005Km00000P00J7oo00<007ooOol0JGoo00<007ooOol067oo001JOol00`00Oomo
o`3oOolhOol20004E_d01000E_eFoEKm0`0015Km2P0000D0E0000000M0000080M0030000U@2E00<0
0084]@03000<e@cE008000044=D001Ce5?D200026?D00`006?DHm@0200028AD020008ADQ5@009AD0
02De0003:CD00`00;CD]=@02;CD20002;ED01@00<EDaEC5E00000c5E00<0035E<ED00`0013Ee00D0
03Ue>GDiM@0000DiU@05000iMCUe>GD00005@I@00`00?ID000030004?ID00`00AIA5U002AI@00`00
AKA5]004AK@00`00BME9e@02BMD40004Dad00`00DaeC7@04Dad20006Dad00`00DaeC7@03Dad30006
Dad01000DaeC7E<M1@001U<M00<005<MDad00`0000=C7@00Dad01U<M00<005<MDad00`000U<M00<0
05<MDad015<M00<005<MDad00`000U<M00<005<MDad015<M0P001U<M00<005<MDad00e<M0`001E<M
00<005<MDad015<M0`001U<M00<005<MDad00`0000=C7@00Dad01U<M00<005<MDad00`0000=C7@00
Dad01U<M00<005<MDad00`000U<M00<005<MDad015<M100015<M00<005<MDad00e<M0`001E<M00<0
05<MDad015<M0`001U<M00@005<MDaeC7@D000IC7@03001k500000Eg=@04001c=g<g0003IW@00`00
NcAk=002Nc@00`00McH00003K]D00`00IWAVM003IW@00`00Na@00002M_D00`00MaEg5@02MaD00`00
MaEg5@02MaD01@00MaEg5GLE000017LE00<007;eL_D00W;e00D007LEMaEg5@0000=k=@04001kEG]E
0003NeD01@00NeEkEG]E00000W]E00D007]eNgEkM@00009kM@04001oMGme0002OiD00`00OiD00002
OiD00`00OkD00002OkD01@00OkD007^e00000W_D0P0000=ke000Mm@00P0000Acd`00001_dPH000AF
o@@000=Fo@03001FoEKm00=Fo@@000=Fo@04001FoEKmE_d30005E_d01000E_eFoEKm0`00K7oo00<0
07ooOol0J7oo00<007ooOol067oo001KOol00`00Oomoo`3oOolhOol00`00E_eFo@02E_d40003E_d0
1000E_eFoEKm0P0000<04000000020000P1d00D0001d07@0002E00<00084]@05000<e@cE000<e@02
00025?D01@005?D001Se00000QSe00D001ce000Q5@0000<Q5@04000U5@000003:CD00`00;CD]=@02
;CD01@00;ED002eE00000c5E00<0035E<ED00S5E00@0035E<EDaE@8000<eM@05000iMCUe>GD00005
>ID01@00>GDiMCUe00001D6D00<003fE?ID00SfE0P000cfE00<004FDAI@00dFD00<004FdAK@00dFd
00<004WE00000P0000=C7@00Dad01U<M00<005<MDad00`0000=C7@00Dad01U<M00<005<M00000P00
0e<M00<005<MDad00e<M100015<M00<005<MDad015<M0`001E<M00<005<MDad015<M0`001U<M00@0
05<MDaeC7@D000IC7@03001C7E<M00<00003Dad005<M00IC7@03001C7@00008000=C7@03001C7E<M
00=C7@03001C7E<M00<0009C7@03001C7E<M00AC7@<000EC7@03001C7E<M00AC7@<000EC7@03001C
7E<M00AC7@<000IC7@03001C7E<M00<00003Dad005<M00IC7@03001C7@0000800003Dad005<M00IC
7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00AC7@8000Eg=@05001c=g<g
LcL00003IW@00`00NcAk=002Nc@01000McIg=P000VkE00<006IdIW@00fId00H007/DNa@007Ke0003
MaD00`00MaEg5@02MaD00`00MaD00002MaD00`00MaEg5@02MaD01`00L_EbmG;e001bm@00009g5@05
001k=G/eNcD00002NeD01@00NeEkEG]E00000g]E0P0000EkE@00NgEkM@00009kM@04001oMGme0003
OiD00`00OiD00002OiD00`00OkD00002OkD01000OkD000000W_D00@007_D0000009ge0D00003Km80
000000@00004E_d000000002E_d00`00E_eFo@03E_d00`00E_d0000200000eKm001Fo@04E_d40002
E_d00`00E_eFo@03E_d4001`Ool00`00Oomoo`1WOol00`00Oomoo`0HOol005aoo`03001oogoo0?mo
ocQoo`04001Fo@000002E_d00`00E_eFo@03E_d00`00E_d0000:00001P0c0000E00007@00080M080
000509D000000004]@02000010cE000<e@cE0P000QCe00@001Ce000000<Hm@04000Lm@0000038AD0
0`009ADU5@020003:CD01@00;CD]=Bde00000ReE0P00135E00D0035E<EDaE@0000@aE@80008eM@03
000iMCUe008iM@03000iUCVE008iU@03000iMCUe008iM@030011U46D00=1U007000mUCfE?ID001dF
00000SfE00<004FDAI@00dFD00<004FdAK@00TFd0`001E<M00<005<MDad015<M0`001E<M00<005<M
Dad015<M0P001e<M00<005<M00000P000U<M00<005<MDad015<M00<005<MDad00`000U<M00<005<M
Dad015<M00<005<MDad00`000U<M00<005<MDad015<M100015<M00<005<MDad015<M0`001E<M00<0
05<MDad015<M0P001e<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad005<M00IC7@03001C
7E<M00<0009C7@03001C7E<M00AC7@03001C7E<M00<0009C7@03001C7E<M00AC7@<000EC7@03001C
7E<M00AC7@8000EC7@03001C7E<M00AC7@<000IC7@03001C7E<M00<00003Dad005<M00IC7@03001C
7E<M00<00003Dad007Le00=g=@03001c=g<g00=c=`03001VM00000Ak=007001g=WLfMcH006kE0000
1VId00H007/DNa@007Ke0003MaD00`00MaEg5@02MaD01P00MaEg5@00MaD000=g5@03001bmG;e009b
m@06001bmG;e001g5@000W/e00@007]ENeD000AkE@04001kEG]E0002NeD20002NgD01000NgEkM@00
0Wme00H007nEOiD007nE0002OiD00`00OkD00002OkD01@00OkD007^e00000W_D0P0000=ke0000000
0P0000=cd`0000002@001UKm00@005KmE_eFo@<000EFo@03001Fo@0000800003E_d005Km00AFo@03
001Fo@00008007Eoo`03001oogoo06Ioo`03001oogoo01Qoo`00GGoo0P00ogoo>Goo00<005KmE_d0
0eKm00@005KmE_eFo@<000=Fo@<000070140000000004`0003<00P000P1d00@0001d0000M0800004
09D000Be1;D200001@cE000<e@cE00000QCe00<001Ce5?D00P000QSe00<001ce7?D00P000R4E00D0
02DE9ADU5@0000<Y=@05000]=Bde;CD00003;ED20003<ED01@00<EDaEC5E0000135E00D0035E000e
M@0000@iM@03000iUCVE00<iU@05000iMCUe>GD00005@I@01@00?IDmUCfE00000QdF00<003fE0000
1DFD00<004Fd00000P0000=C7@00Dad01U<M00<005<MDad00`000U<M00<005<MDad015<M00<005<M
Dad00`000U<M00<005<MDad015<M0P001U<M00<005<MDad00e<M0`001U<M00<005<MDad00e<M0`00
1U<M00<005<MDad00`0000=C7@00Dad01U<M00<005<MDad00`0000=C7@00Dad01U<M00<005<MDad0
0`000U<M00<005<MDad015<M100015<M00<005<MDad00e<M0`001E<M00<005<MDad015<M0`001U<M
00@005<MDaeC7@D000IC7@03001C7E<M00<00003Dad005<M00IC7@03001C7E<M00<0009C7@03001C
7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00AC7@<000EC7@03001C7E<M00AC7@<000EC7@05
001g=GLeMcD00005LcL00`00IW@00004Nc@01`00McIg=WLf001^e@0000EVM003001k57/D009k5003
001g5GLE009g5@05001g5GLEMaD00004MaD00`00MaEg5@02MaD01@00L_EbmG;e000017;e00D007/e
NcEk=@00009kE@05001kEG]ENeD00003NeD02P00NeEkE@00NeD007]e001kM@000Wme00L007nEOiEo
U@00OiD00002OiD01@00OkD007ne00000Wne00H007^e001ke000Nm@300000gOC0000000300000f^a
000000030003E_d00`00E_eFo@03E_d40003E_d01000E_eFoEKm0`001EKm00@005KmE_eFo@<007Qo
o`03001oogoo06Moo`03001oogoo01Moo`00Ggoo00<007ooOol0ogoo=goo00<005KmE_d00UKm1000
0eKm00@005KmE_eFo@D000080180000003<0001D0000M080000607@000000000U@000PBe00@000Be
0000008<e@04000DmACe00035?D010006?DHm@000ace00@0024E8AD000<U5@80008Y=@03000]=Bde
008]=@04000]EBeE;ED20002<ED01@00<EDaEC5E0000135E00H0035E<ED003Ee0003>GD00`00>IDi
U@03>ID01@00>GDiMCUe00001D6D00<003fE?ID00SfE00H001dF7AH003fE0003AI@30005Dad00`00
DaeC7@04Dad30006Dad01000DaeC7E<M1@001U<M00<005<MDad00`0000=C7@00Dad01U<M00<005<M
00000P000e<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad015<M0`001E<M00<005<M
Dad015<M0`001E<M00<005<MDad015<M0`001U<M00<005<MDad00`0000=C7@00Dad01U<M00<005<M
00000P000U<M00<005<MDad015<M00<005<MDad00`000U<M00<005<MDad015<M100015<M00<005<M
Dad015<M0`001E<M00<005<MDad015<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003
Dad005<M00IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001g=@0000Ic=`03001VM00000=k
=003001g=WLf00=g=P03001VM6Id00AVM003001k57/D009k5005001g5GLEMaD00004MaD00`00MaEg
5@02MaD01@00MaEg5GLE000017;e00<007;eL_D00W;e00@007/eNcD000=kE@05001kEG]ENeD00002
NeD01000NeEkE@000g]E0P0000EkM@00OgEoM@00009oU@04001oUGnE0002OiD01@00OkD007ne0000
0Wne0P000W_D0P0000=ke000Mm<01@0000=[/@0000000`001EKm00<005Km00000P0000=Fo@00E_d0
15Km10000UKm00<005KmE_d00eKm1000O7oo00<007ooOol0IWoo00<007ooOol05goo001POol00`00
Oomoo`3oOolgOol01000E_d000000UKm00<005KmE_d00eKm00<005Km00001`0000<04`0003<01000
00@0M0000000M080000509D000Be0004]@0200023=D200025?D010005?DDm@000aSe00@001ce7?D0
00<Q5@08000U5BDE000U=@00:CD000@]=@09000]EBeE;ED0035E000aE@0000@aE@03000aEC5E008a
E@03000aEC5E008000<iM@03000iUCVE00<iU@05000iMCUe>GD00005@I@00`00?IDmU@02?ID01000
7AHM5QdF1@000e<M00<005<MDad00e<M00<005<MDad00`000e<M00<005<MDad00e<M100015<M00<0
05<MDad015<M0`001E<M00<005<MDad015<M0P001e<M00@005<MDaeC7@@000IC7@03001C7E<M00<0
0003Dad005<M00IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7E<M00<0009C7@03001C
7E<M00AC7@<000EC7@03001C7E<M00AC7@8000IC7@04001C7E<MDad50006Dad00`00DaeC7@030000
0e<M001C7@06Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC
7@04Dad40003Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M1000
27<g00<007/dNc@00W/d00<007LfMcH00gLf00<006IdIW@016Id00L007/DNaAk5000NcD00002MaD0
1@00MaEg5GLE000017LE00<007LE00000WLE00D007;eL_Ebm@0000Abm@05001oE000NcD00002NeD0
1@00NeEkEG]E00000g]E00@007]ENeD000=kE@03001oM@0000800007OgD007nEOiD007nE00000WnE
00D007ne001o]@00009o]@03001k]@0000800006Nm@00000Mm<007OC2@0000=Fo@00E_d00UKm0`00
1EKm00<005Km00000P0000=Fo@00E_d015Km00<005Km00000P00PGoo00<007ooOol0IGoo00<007oo
Ool05goo001QOol00`00Oomoo`3oOolgOol00`00E_eFo@03E_d01000E_eFoEKm100000=Fo@0000l0
300000H0M00007@0M00009D200000`Be0004]@0200023=D2000011Ce000DmACe0P000QSe00<001ce
7?D00P000R4E00H002DE9ADU5@009CD20004;CD01@00;ED]EBeE00000S5E0P00135E00<0035E<ED0
0S5E00@0035E<EDaE@80008iM@03000iUCVE00<iU@05000iMCUe>GD00005@I@00`00?IDmU@02?ID0
0`007AHM5P027AH00`00DaeC7@05Dad01000DaeC7E<M10001e<M00<005<M00000P000U<M00<005<M
Dad015<M00<005<MDad00`000U<M00<005<MDad015<M00<005<MDad00`000U<M00<005<MDad015<M
100015<M00<005<MDad00e<M0`001E<M00<005<MDad015<M0`001U<M00@005<MDaeC7@D000IC7@03
001C7E<M00<00003Dad005<M00IC7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000AC7@03001C
7E<M00AC7@<000EC7@03001C7E<M00AC7@<000IC7@04001C7E<MDad50006Dad00`00DaeC7@030000
0e<M001C7@05Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC
7@04Dad40004Dad00`00LcMc=`04LcL20003Nc@00`00McIg=P03McH20005IW@00`00NaAk5002Na@0
1P00NcEk=@00MaD000=g5@03001g5GLE009g5@06001g5GLE001g5@000g;e00<007;eL_D00W;e00<0
07mDOe@00P000W]E00D007]ENeEkE@00009kE@05001kEG]ENeD00002NeD01000OgEoM@000Wme0`00
00AoU@00OiD0009oU@05001o]@00OkD00002OkD300001W_D000007_D001gd`D00003Jk4000000080
009Fo@@000=Fo@04001FoEKmE_d30005E_d01000E_eFoEKm0`00QGoo00<007ooOol0I7oo00<007oo
Ool05goo001ROol2003oOolhOol00`00E_eFo@02E_d40004E_d00`00E_d0000<000207@01P0007@0
002E0000U@800084]@05000<e@cE000@e@0200035?D200000aSe000Lm@027?D200000b4E000U5@02
9AD00`009CDU=@020003;CD00`00;ED]E@02;ED00`00<EDaE@020003<ED00`00<EDaE@02<ED01P00
<EDaEC5E000mM0@000@iU@03000iMCUe008iM@030011U46D00=1U003000mUCfE008mU@03000M5QdF
008M5P03001C7E<M00AC7@@000AC7@03001C7E<M00AC7@8000IC7@03001C7E<M00=C7@<000IC7@04
001C7E<MDad50006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00Dad000020003Dad00`00DaeC
7@03Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@04Dad30005Dad00`00
DaeC7@04Dad30006Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00DaeC7@0300000e<M001C
7@06Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@04Dad30005Dad00`00
DaeC7@03Dad30006Dad01000DaeC7E<M1@001U<M00<005<MDad00`0000=C7@00Dad01U<M00<007<g
LcL00`000U<M00@007/dNc@000Eg=P03001c=`0000AVM003001k57/D009k5005001k=G/eNcD00003
MaD00`00MaEg5@02MaD00`00MaEg5@02MaD00`00L_Ebm@02L_D01@00L_EbmG;e00000gmD00D007]E
001kE@00009kE@05001kEG]ENeD00002NeD01`00NeEkEG]E001oM@0000=oM@03001oUGnE00d00005
Nk@007_D001ke00200000gOC001gd`0;00000eKm001Fo@04E_d40002E_d00`00E_eFo@03E_d40028
Ool00`00Oomoo`1TOol00`00Oomoo`0GOol006Aoo`03001oogoo0?moocIoo`04001Fo@000002E_d0
0`00E_eFo@03E_d?000207@01@0007@0M00009D00`000PBe00@000cE3=D0008@e@80008Dm@04000H
m@0000037?D010007AD000000bDE00D002De9CDU=@0000<]=@03000]EBeE008]E@04000aEC5E<ED2
0002<ED00`00<EDaE@02<ED01@00<EDaEC5E000013ed10000SVE00D003Ue>GDiM@0000E1U003000m
UCfE008mU@03000M5QdF00<M5P03001C7E<M00<00003Dad005<M00IC7@03001C7E<M00<00003Dad0
05<M00IC7@03001C7@00008000=C7@03001C7E<M00=C7@@000AC7@03001C7E<M00AC7@<000EC7@03
001C7E<M00AC7@8000MC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00
DaeC7@030002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad20006Dad00`00
DaeC7@03Dad30005Dad00`00DaeC7@04Dad30006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00
DaeC7@0300000e<M001C7@06Dad00`00Dad000020002Dad00`00DaeC7@04Dad40004Dad00`00DaeC
7@04Dad30005Dad00`00DaeC7@04Dad30006Dad00`00Nc@00004McH01000LcMc=`000fId00<007/D
Na@00W/D00<007/eNcD00W/e00D007LEMaEg5@0000Ag5@03001g5GLE009g5@05001bmG;eL_D00004
L_D01000OeAoE0000g]E0P000W]E00@007]ENeD000=kE@07001kEG]ENeD007me00000Wme00L007nE
OiEoU@00OiD00002OiD01@00OkD007ne00000Wnd0P000W_D0P0000Ake000001gd`T000EFo@03001F
o@0000800003E_d005Km00AFo@03001Fo@00008008eoo`03001oogoo06=oo`03001oogoo01Moo`00
IGoo00<007ooOol0ogoo=Woo0P0015Km00<005Km00000P000UKm0`0000<0400000000P0000H04`00
03<0001D000207@00`0007@0000200000`2E000000021;D010003=D<e@000Q3E00@001Ce5?D0008H
m@80008Lm@03000M5AdE0080008U5@04000U=BDe9CD20002;CD00`00;ED]E@02;ED01P00<EDaEC5E
000aE@<000@aE@05000aEC5E<ED00004?G@01000?IDmUCfE0`000cUe00<0046D@I@00d6D00<003fE
?ID00SfE00<001dF7AH00adF0`001E<M00<005<MDad015<M0`001E<M00<005<MDad015<M0P001e<M
00<005<M00000P000U<M00<005<MDad015<M00<005<MDad00`0000=C7@00Dad01U<M00<005<MDad0
0`000U<M00<005<MDad015<M100015<M00<005<MDad00e<M0`001E<M00<005<MDad015<M0`001U<M
00@005<MDaeC7@D000IC7@03001C7E<M00<00003Dad005<M00IC7@03001C7@00008000=C7@03001C
7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00AC7@<000EC7@03001C7E<M00AC7@<000EC7@03
001C7E<M00AC7@8000IC7@03001C7E<M00<00003Dad005<M00IC7@03001C7E<M00<00003Dad005<M
00IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@8000Ag=P05001c=g<gLcL00003IW@00`00NaAk
5002Na@02@00NcEk=G/e001k=@00MaD00004MaD00`00MaEg5@02MaD00`00L_D00002L_D00`00L_Eb
m@02L_D01000OeAoE0000g]E00D007]E001kE@00009kE@04001kEG]E0003NeD01000OgEoM@000Wme
00H007nEOiD007nE0002OiD01@00OkD007ne00000Wnd00H007^d001ke000Nm@200000gOC001gd`03
00000f^a0000000200000eKm001Fo@02E_d30005E_d01000E_eFoEKm0`00TGoo00<007ooOol0HWoo
00<007ooOol05goo001VOol00`00Oomoo`3oOolgOol00`00E_eFo@030006E_d500001P0A0000000C
0000<`800080M0D00080U@030004]@Be008000053=D0013E4=D000035?D010006?DHm@000Qce00D0
01dE7ADM5@0000<U5@08000U=BDe000Y=@00;CD000@]E@05000aEC5E<ED00003<ED20004<ED01@00
<EDaEC5E00000ced00<003fE?ID00cfE00D003Ue>GDiM@0000E1U003000mUCfE00<mU@03000M5P00
0080009C7@03001C7E<M00AC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7E<M00<0009C
7@03001C7E<M00AC7@8000IC7@03001C7E<M00=C7@<000EC7@03001C7E<M00AC7@<000IC7@03001C
7E<M00<00003Dad005<M00IC7@03001C7@00008000=C7@03001C7E<M00=C7@03001C7E<M00<0009C
7@03001C7E<M00AC7@@000AC7@03001C7E<M00AC7@<000EC7@03001C7E<M00AC7@8000MC7@04001C
7E<MDad40006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00DaeC7@030002Dad00`00DaeC7@04
Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad30005Dad00`00DaeC7@04Dad30005Dad00`00DaeC
7@04Dad30006Dad00`00DaeC7@0300000e<M001g=P03McH00`00LcMc=`02LcL01000IWAVM0000g/D
00<007/eNcD00W/e00D007/e001g5@0000Ag5@03001g5GLE009g5@05001bm@00L_D00004L_D01@00
OeAoE7mD00000W]E00D007]ENeEkE@00009kE@05001kEG]ENeD00003NeD00`00OgD00003OgD01P00
OiEoU@00OiD0009oU@05001o]@00OkD00002Ok@20002Nm@200000g_D000000090002E_d40002E_d0
0`00E_eFo@03E_d4002DOol00`00Oomoo`1SOol00`00Oomoo`0FOol006Moo`03001oogoo0?moocMo
o`8000=Fo@03001FoEKm00=Fo@P0000901<0000c0000E00007@0001D00@0000609D000Be1;D000Re
0P000Q3E0P000QCe00@001Se6?D000<Lm@04000M5AdE00039AD02@009CDU=BDe000Y=@00;CD00004
;ED01@00<EDaEC5E00000c5E0P000c5E00D0035E<EDaE@0000@mM003000mUCfE008mU@80008iM@03
0011U46D00=1U003000mUCfE008mU@<000IC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad50006
Dad00`00DaeC7@0300000e<M001C7@06Dad00`00Dad000020003Dad00`00DaeC7@03Dad00`00DaeC
7@030002Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad20007Dad01000DaeC7E<M10001U<M
00<005<MDad00`0000=C7@00Dad01U<M00<005<MDad00`000U<M00<005<MDad015<M00<005<MDad0
0`000U<M00<005<MDad015<M10000e<M00<005<MDad015<M0`001E<M00<005<MDad015<M0`001U<M
00@005<MDaeC7@D000IC7@03001C7@0000800003Dad005<M00IC7@03001C7E<M00<0009C7@03001C
7E<M00AC7@03001C7E<M00<0009C7@03001C7E<M00AC7@<000EC7@04001g=WLf0005LcL00`00IW@0
0004Na@01@00NcEk=G/e00000g/e00<007LEMaD00WLE00<007LEMaD00WLE00H007;eL_D007;e0004
L_D01000OeAoE0000g]E00@007]ENeEkE@800005NeD007]ENeD00003NeD01000OgEoM@000Wme00@0
07nEOiD0009oU@03001oU@00009o]@80009o]006001k]000Nm@007_D100000=cdP000000200000=F
o@00E_d015Km00<005Km00000P00VGoo00<007ooOol0HWoo00<007ooOol05Woo001XOol2003oOolh
Ool00`00E_eFo@02E_d00`00E_d000020002E_d700000`0C0000<`0300001P1d0000000007@00080
U@050004]@Be0008]@0200024=D2000011Ce000HmASe0P000Qce00<001dE7AD00P000RDE00D002De
9CDU=@00008Y=@8000@]E@05000aEC5E<ED00003<ED00`009CD00002<ED01@00<EDaEC5E000013ed
00<003fE?ID00cfE0P0000<iM@00@I@01D6D10000e<M00<005<MDad015<M00<005<M00000P000e<M
00<005<MDad00e<M100015<M00<005<MDad015<M0`001E<M00<005<MDad015<M0P001e<M00@005<M
DaeC7@@000IC7@03001C7E<M00<00003Dad005<M00IC7@03001C7E<M00<0009C7@03001C7E<M00AC
7@@000AC7@03001C7E<M00=C7@<000EC7@03001C7E<M00AC7@<000IC7@04001C7E<MDad50006Dad0
0`00DaeC7@0300000e<M001C7@05Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00DaeC7@03
0002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@04Dad20005Dad00`00DaeC7@04Dad30006Dad0
1000DaeC7E<M1@001U<M00<005<MDad00`0000=C7@00Dad01U<M00<007Lf00001G<g00<006Id0000
17/D00D007/eNcEk=@0000=k=@03001g5GLE009g5@03001g5GLE009g5@05001bmG;eL_D00004L_D0
1@00OeAoE7mD00000g]E00@007]ENeD0009kE@80009kE@07001kEG]ENeD007me00000gme00H007nE
OiD007nE0002OiD01@00OkD007ne00000Wnd0P0000Eke000Nm@007_D00800003Lm80000000H000EF
o@04001FoEKmE_d3002MOol00`00Oomoo`1QOol00`00Oomoo`0FOol006Yoo`03001oogoo0?moocIo
o`03001FoEKm00@000EFo@h0000405@0001d000209D200001@Be0008]@Re00000Q3E00@0013E0000
00<Hm@8000037?D001dE008M5@8000039AD002De008U=@04000Y=BTe:CD20003;ED01@00<EDaEC5E
00000c5E00H002De9CD0035E0003<ED00`00?G@mM002?G@00`00?IDmU@03?ID01@007AH003Ue0000
146D0P001e<M00@005<MDaeC7@@000MC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7E<M
00<0009C7@03001C7E<M00AC7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000AC7@03001C7E<M
00=C7@<000EC7@03001C7E<M00AC7@<000IC7@03001C7E<M00<00003Dad005<M00IC7@03001C7@00
0080009C7@03001C7E<M00AC7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000AC7@03001C7E<M
00AC7@<000EC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad50006Dad00`00DaeC7@0300000e<M
001C7@06Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@04
Dad40004Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad20007LcL20003Na@00`00NcEk=@02
NcD01P00NcEk=@00McD0009g5@03001g5GLE009g5@03001bmG;e009bm@03001bmG;e009bm@04001o
E7mD0003NeD01@00NeEkEG]E00000W]E00D007]E001kE@00009kE@04001oMGme0002OgD01000OiEo
U@000WnE00<007nE00000Wne0P000Wnd00H007^d001ke000Nm@30002Lm880005E_d4002QOol00`00
Oomoo`1POol00`00Oomoo`0FOol006]oo`03001oogoo0?moocIoo`8000AFo@04001FoEKmE_d30000
0`0?0000000700002P1C0000E01D0000M00009D0002D0P000PRe00@0013E4=D0008@e@80008Hm@04
000Hm@0000037AD010008AD000000bDe00L002Te:CDY=@00<ED00002;ED01@00<EDaEC5E0000135E
00<002De9CD00P000c5E00<003ed?G@00Sed00<003fE?ID00cfE00<001dF7AH00P0000A1U0000000
009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00AC7@8000IC7@03001C7E<M00=C7@<000IC7@04
001C7E<MDad50006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00Dad000020003Dad00`00DaeC
7@03Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad20006Dad00`00
DaeC7@03Dad30006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00DaeC7@0300000e<M001C7@06
Dad00`00Dad000020002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@04Dad30005Dad00`00DaeC
7@04Dad30006Dad01000DaeC7E<M10001U<M00<005<MDad00`0000=C7@00Dad01U<M00<005<MDad0
0`000U<M00<005<MDad015<M00<005<MDad00`0000=C7@00LcL01G<g0P0017/D00D007/eNcEk=@00
00=k=@06001g=GLe001g5@0017LE00L007;eL_Ebm@00JY@00002L_D01@00OeAoE7mD00000g]E00@0
07]ENeD0009kE@04001kEG]ENeD20002NeD00`00OgD00003OgD01P00OiEoU@00OiD0009oU@05001o
]@00OkD00002Ok@00`00Nk@00003000017OC000007?B1`000UKm00<005Km00000P00YGoo00<007oo
Ool0H7oo00<007ooOol05Woo001/Ool00`00Oomoo`3oOolfOol00`00E_eFo@02E_d40003E_d:0002
05<0100005@0001d0P0000<0U@0009@00P0000<8]@0000000Q3E00@0013E4=D0008Hm@03000HmASe
0080008M5@03000Q5B4E008000<U=@04000Y=BTe0002<ED30004<ED01@00<EDaEC5E00000bDe0P00
0c5E00D003ed?G@mM00000HmU@03000M5QdF008000IC7@03001C7E<M00<00003Dad005<M00IC7@03
001C7E<M00<0009C7@03001C7E<M00AC7@03001C7@00008000=C7@03001C7E<M00=C7@@000AC7@03
001C7E<M00AC7@<000EC7@03001C7E<M00AC7@8000MC7@04001C7E<MDad40006Dad00`00DaeC7@03
00000e<M001C7@06Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00
DaeC7@04Dad30005Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad20006Dad00`00DaeC7@03
00000e<M001C7@06Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00
DaeC7@04Dad40003Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M
1@001E<M00<007<gLcL00`0000=C7@00Na@00W/D00<007/eNcD00W/e00D007/eNcEk=@0000=g=@03
001g5GLE00=g5@05001bmG;eL_D00002JY@00`00L_D00003Oe@01000NeEkE@000g]E00@007]ENeD0
00=kE@07001kE@00NeD007me00000Wme00@007nEOiD0009oU@03001oU@00009o]@03001o]@00009o
]0800003Nm@007_C00<00003Lm80000000H00004E_d00000002YOol00`00Oomoo`1OOol00`00Oomo
o`0FOol006eoo`800?moocMoo`04001Fo@000002E_d00`00E_eFo@03E_d200002P0@00004P000180
000c0000D`000P1D0P0000<0M00000000P2D00<000Re2;D00P0000D@e@004=D@e@0000<Hm@04000H
mASe00027AD01@008ADQ5B4E00000bDe00D002Te:CDY=@0000<aE@8000<aE@05000aEC5E<ED00004
9CD01@00<EDaEC5E000013ed00<003fE?ID00cfE00<001dF7AH00QdF00<005<MDad00e<M0`001E<M
00<005<MDad015<M0`001U<M00@005<MDaeC7@@000MC7@03001C7@0000800003Dad005<M00IC7@03
001C7E<M00<0009C7@03001C7E<M00AC7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000=C7@03
001C7E<M00AC7@<000EC7@03001C7E<M00AC7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@03
00000e<M001C7@06Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00
DaeC7@03Dad30005Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M1@001U<M00<005<MDad00`00
00=C7@00Dad01E<M00<005<MDad00`000U<M00<005<MDad015<M00<005<MDad00`000U<M00<005<M
Dad015<M100015<M00<005<MDad00e<M0`001E<M00@007/DNa@000=k=@05001k=G/eNcD00004McD0
0`00MaEg5@02MaD00`00L_Ebm@02L_D01P00JYAZU000L_D0009oE005001kEG]ENeD00002NeD01@00
NeEkEG]E00000W]E00@007]ENeEkE@800005OgD007meOgD00002OiD00`00OiD00002OiD01@00OkD0
07ne00000Wnd00L007^d000007_C001gd`0200000g?B00000007002]Ool00`00Oomoo`1NOol00`00
Oomoo`0FOol006moo`03001oogoo0?moocEoo`03001FoEKm00=Fo@04001FoEKmE_d600000`0B0000
4P02000205<0100005@0001d0`000P2D00D000Re2;D000be0080008@e@80008Hm@04000HmASe0003
7AD00`008ADQ5@0200029CD01@00:CDY=BTe0000135E0P000S5E00D0035E<EDaE@0000@U=@05000a
EC5E<ED00004?G@00`00?IDmU@03?ID00`007AHM5P037AH00`00Dad000020002Dad00`00DaeC7@04
Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@04Dad20005Dad00`00DaeC
7@04Dad30006Dad01000DaeC7E<M1@001U<M00<005<MDad00`0000=C7@00Dad01E<M00<005<MDad0
0`000U<M00<005<MDad015<M00<005<MDad00`000U<M00<005<MDad015<M100015<M00<005<MDad0
0e<M0`001E<M00<005<MDad015<M0`001U<M00@005<MDaeC7@D000IC7@03001C7@000080009C7@03
001C7E<M00AC7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00AC7@<000EC
7@03001C7E<M00=C7@<000IC7@04001C7E<MDad50006Dad00`00DaeC7@0300000e<M001C7@06Dad0
0`00Dad000020002Dad00`00DaeC7@04Dad00`00Na@00003NcD01@00NcEk=G/e00000gLe00<007Lf
00000gLE00D007;eL_Ebm@0000AZU080009oE004001kEG]E0003NeD01000NeEkE@000g]E00H007]E
NeEkE@00OgD3000017me001oU@000WnE00<007nE00000Wne00<007ne00000Wnd0P0000=kd`00Nm<0
0`0000=cdP0000001@00/Goo00<007ooOol0GWoo00<007ooOol05Goo001`Ool00`00Oomoo`3oOole
Ool00`00E_eFo@02E_d40002E_d400001`0B00004P0003<0001C00D0000407@0000009@2000010Re
000<]@be0P000Q3E0P0000@Hm@006?DHm@80008M5@08000Q5B4E000Q5@009CD000<Y=@03000aEC5E
008aE@05000]E@00<ED00004<ED010009CDU=BDe0P000S5E00<003ed?G@00Sed00<003fE?ID00cfE
00<001dF7AH00adF0P001U<M00<005<MDad00e<M0`001U<M00<005<MDad00`0000=C7@00Dad01U<M
00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad015<M100015<M
00<005<MDad015<M0`001E<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@D000IC7@03001C7E<M
00<00003Dad005<M00IC7@03001C7@00008000=C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03
001C7E<M00AC7@@000AC7@03001C7E<M00AC7@8000IC7@03001C7E<M00=C7@<000IC7@03001C7E<M
00<00003Dad005<M00IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7@000080009C7@03
001C7E<M00AC7@@000AC7@03001C7E<M00AC7@<000EC7@03001C7E<M00AC7@8000IC7@04001C7E<M
Dad40003NcD01@00NcEk=G/e000017Le00H007LfMcH007LE0004L_D00`00JYAZU002JY@01@00Nfl0
07mD00000W]E00D007]ENeEkE@00009kE@05001kEG]ENeD00002NeD01000OgEoM@000WnD0P0000Mo
U@00OiEoU@00OiD00002OkD500001W^d000007_C001gd`800003Lm80000000D00;5oo`03001oogoo
05ioo`03001oogoo01Eoo`00LGoo00<007ooOol0ogoo=Goo00@005Km0000009Fo@03001FoEKm009F
o@@000030180000B00@0000405<00000000207@00`0009@0U00200001@Re000<]@be00000Q3E00@0
01CE000000<Hm@8000037AD0024E008Q5@04000Q5@000003:CD00`00<EDaE@02<ED00`00;ED]E@02
0004<ED00`009CDU=@029CD200000c5E000mM003?G@00`00?IDmU@04?ID00`007AH000020002Dad0
0`00DaeC7@04Dad00`00Dad000020003Dad00`00DaeC7@03Dad30005Dad00`00DaeC7@04Dad30006
Dad01000DaeC7E<M10001U<M00<005<MDad00`0000=C7@00Dad01U<M00<005<MDad00`000U<M00<0
05<MDad015<M00<005<M00000P000e<M00<005<MDad00e<M100015<M00<005<MDad015<M0`001E<M
00<005<MDad015<M0P001e<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad005<M00IC7@03
001C7E<M00<0009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@<000EC7@03
001C7E<M00AC7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00
DaeC7@030002Dad00`00DaeC7@04Dad00`00DaeC7@0300000e<M001C7@05Dad40004Dad01000NcEk
=@000g/e00<007LeMcD00WLe00H007LfMcH007LE0003L_D00`00JYAZU003JY@00`00NfmkK`030000
1G]E001kEG]E00000W]E00D007]ENeEkE@0000=kE@03001oM@0000=oU003001oU@0000P00004Ok@0
07ndOk@200000g_C001kd`0;002cOol00`00Oomoo`1MOol00`00Oomoo`0EOol0079oo`800?moocIo
o`03001FoEKm00=Fo@03001Fo@0000X0000303<0000000@0000607@0002D09@000BD0P000Pbe00@0
013E4=D0008De@80008Hm@04000Hm@0000038AD00`008ADQ5@020003:CD00`00<EDaE@02<ED00`00
;ED]E@020003<ED00`009CDU=@029CD010005=@0000013ed00<003fE?ID00cfE0`001U<M00@005<M
DaeC7@@000MC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7E<M00<0009C7@03001C7E<M
00AC7@@000AC7@03001C7E<M00=C7@<000EC7@03001C7E<M00AC7@<000IC7@04001C7E<MDad40007
Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00
DaeC7@030002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad3
0006Dad01000DaeC7E<M10001U<M00<005<MDad00`0000=C7@00Dad01U<M00<005<MDad00`000U<M
00<005<MDad015<M10000e<M00<005<MDad015<M0`001E<M00<005<MDad015<M0`001U<M00@005<M
DaeC7@D000EC7@03001C7E<M00<00003Dad005<M00IC7@03001k=@0000=k=@05001g=GLeMcD00004
McH00`00L_Ebm@02L_D00`00JYAZU002JY@01@00NfmkKg]_00000Wme00D007]ENeEkE@00009kE@05
001kEG]ENeD00002NeD01000OgEoM@000WnD00@007nEOiD0009oU@03001o]000009o]080009o]007
001k]000001kd`00Mm<00P0000=cdP0000000P0000=OS`00Ool0]7oo00<007ooOol0G7oo00<007oo
Ool05Goo001dOol00`00Oomoo`3oOoldOol01000E_eFoEKm10000UKm2`0000@0D`0005@00080M004
0000U00019@200023;D200024=D010005=DDe@000QSe00<001Se6?D00P000R4E00D0024E8ADQ5@00
00<Y=@03000aEC5E008aE@04000]EBeE;ED20002<ED00`009CDU=@029CD01@005=@0035E000013ed
00<003fE00000P000U<M00<005<MDad015<M100015<M00<005<MDad015<M0P001U<M00<005<MDad0
0e<M0`001U<M00<005<MDad00`0000=C7@00Dad01U<M00<005<M00000P000U<M00<005<MDad015<M
00<005<MDad00`000U<M00<005<MDad015<M100015<M00<005<MDad015<M0P001U<M00<005<MDad0
0e<M0`001U<M00@005<MDaeC7@D000IC7@03001C7E<M00<00003Dad005<M00EC7@03001C7E<M00<0
009C7@03001C7E<M00AC7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00=C
7@<000EC7@03001C7E<M00AC7@<000IC7@03001C7E<M00<00003Dad005<M00EC7@03001C7E<M00<0
0003Dad005<M00IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00=C7@<0
00EC7@03001C7E<M00AC7@8000=k=@03001g=GLe009g=@03001g=WLf009g=P03001bmG;e009bm@03
001ZU6ZD009ZU004001kKg]_0003OgD01000NeEkE@000g]E00@007]ENeD000=kE@04001oMGme0002
Oi@00`00OiD00002OiD00`00Ok@00002Ok@00`00Ok@00002Ok@200000g_C001kd`0300000g?B0000
0005002eOol00`00Oomoo`1LOol00`00Oomoo`0EOol007Eoo`03001oogoo0?moocAoo`<000AFo@05
001FoEKm00003`060000100c0000D`1C0P000P1d0P0000<0U00019@00P000Pbe0P0000D@e@005=DD
e@0000<Hm@04000HmASe00028AD010008ADQ5B4E0P000RTe00<0035E<ED00S5E00H002eE;ED]E@00
>GD300049CD00`005=@De0020002?G@40006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00DaeC
7@030002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04Dad30005Dad00`00DaeC
7@04Dad20006Dad00`00DaeC7@03Dad30006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00DaeC
7@030002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04Dad40004Dad00`00DaeC
7@04Dad30005Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M1@001U<M00<005<MDad00`0000=C
7@00Dad01U<M00<005<M00000P000U<M00<005<MDad015<M00<005<MDad00`000U<M00<005<MDad0
15<M0`001E<M00<005<MDad00e<M0`001E<M00<005<MDad015<M0`001U<M00<005<MDad00`0000=C
7@00Dad01U<M00<005<M00000P000U<M00<005<MDad015<M00<005<MDad00`000U<M00@007/eNcD0
00=g=@03001g=WLf009g=P03001g=P00009bm@03001ZU6ZD00=ZU004001kKg]_0002OgD01@00NeD0
07]E00000W]E00D007]ENeEkE@00009kE@04001oMGme0003Oi@00`00OiD00002OiD00`00Ok@00002
Ok@01P00Ok@007nd001k]080009kd`@00003Kk40000000<00;Moo`03001oogoo05]oo`03001oogoo
01Eoo`00MWoo00<007ooOol0ogoo=7oo00<005KmE_d00eKm1P0000<0400001400P000P0c00P0001C
0000E00007@0001d0P000PBD00D000be3;D000be0080008De@80008Hm@04000HmASe00038AD02000
8ADQ5@00:AD002Te0004<ED01@00;ED]EBeE00000cUe0P0012De00<001CD5=@00`0015<M00<005<M
Dad00e<M0`001E<M00<005<MDad015<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003
Dad005<M00IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7@00008000=C7@03001C7E<M
00=C7@<000EC7@03001C7E<M00AC7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M
001C7@06Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00Dad000020003Dad00`00DaeC7@03
Dad40004Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M1@001U<M
00<005<MDad00`0000=C7@00Dad01U<M00<005<M00000P000U<M00<005<MDad015<M00<005<MDad0
0`000U<M00<005<MDad015<M0`001E<M00<005<MDad015<M0P001U<M00@005<MDaeC7@D000IC7@03
001k=@0000=g=@03001g=WLf009g=P06001g=WLf001bm@001FZD00@007]_Nfl0009oM@03001kEG]E
0080009kE@05001kEG]ENeD00002NeD01000OgEoM@000WnD00@007nEOiD0009oU@07001o]000Ok@0
07nd00000Wnd0P0000=kd`00Nm<00`0000=cdP0000001000^Goo00<007ooOol0FWoo00<007ooOol0
5Goo001gOol2003oOoleOol00`00E_d000020002E_d00`00E_d0000400001@0A0000000c00000P1C
0`0000@0M00000000084U005000<]@be000<]@0200035=D2000011Se000HmASe0P000R4E00H0024E
8ADQ5@00:AD20005<ED01@00;ED]EBeE00000cUe0P000bDe00@001CD5=@000MC7@03001C7@000080
00=C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00=C
7@<000EC7@03001C7E<M00AC7@<000IC7@04001C7E<MDad40007Dad00`00Dad000020002Dad00`00
DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@03Dad30005Dad0
0`00DaeC7@04Dad30006Dad01000DaeC7E<M10001e<M00<005<M00000P0000=C7@00Dad01U<M00<0
05<MDad00`000U<M00<005<MDad015<M00<005<MDad00`000U<M00<005<MDad00e<M100015<M00<0
05<MDad015<M0`001E<M00<005<MDad015<M0P001U<M00@005<MDaeC7@D000IC7@03001C7E<M00<0
0003Dad005<M00IC7@03001C7E<M00<00003Dad005<M00EC7@@000AC7@03001C7E<M00AC7@8000Ag
=@05001g=WLfMcH00003McH00`00L_D00004JY@01000NfmkK`000Wme00T007]ENeEkE@00NeD007]E
00000W]E00L007]ENeEkE@00OgD00003Oi@00`00OiD00002OiD00`00Ok@00002Ok@01P00Ok@007nd
001k]080009kd`@00003Kk40000000<00;Yoo`03001oogoo05Uoo`03001oogoo01Eoo`00NGoo00<0
07ooOol0ogoo<goo00<005KmE_d015Km00<005Km00000`0000<04@0000000P0c00D0001C0000001D
0080000407@0000019@200023;D010003;D000000QCE00@001CE000000<Hm@8000038AD0024E008Q
5@03000Y5BTE008000@aE@05000]EBeE;ED00003>GD00`007AH000029CD01@005=@De1CD00001U<M
0P001e<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad005<M00IC7@03001C7@00008000=C
7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00AC7@80
00IC7@03001C7E<M00=C7@<000IC7@03001C7E<M00<00003Dad005<M00IC7@03001C7@000080009C
7@03001C7E<M00AC7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00AC7@80
00EC7@03001C7E<M00AC7@<000IC7@04001C7E<MDad50006Dad00`00Dad0000200000e<M001C7@06
Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40004
Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@0300000e<M001C7@06
Dad00`00DaeC7@0300000e<M001g=@02McD00`00McIg=P02McH00`00McIg=P02McH00`00JYAZU003
JY@01000NfmkK`000Wme00@007]ENeD000=kE@80009kE@04001kEG]E0002OgD01000OiAoU0000WnE
00X007nEOiD007nd001o]000Ok@0009o]003001k]00000D00003Lm80000000@00;]oo`03001oogoo
05Yoo`03001oogoo01Aoo`00NWoo00<007ooOol0ogoo<goo00<005KmE_d00eKm1`0000@04@000000
<`L00080M0030004U0BD008000053;D000be3;D000025=D00`005=DDe@0200026?D010006?D00000
0b4E00@002TE:ADY5@8000<aE@05000]EBeE;ED00004>GD00`007AH0000200045=@00`00DaeC7@03
0002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@03Dad30005Dad00`00DaeC7@04Dad20007Dad0
1000DaeC7E<M10001U<M00<005<MDad00`0000=C7@00Dad01U<M00<005<MDad00`000U<M00<005<M
Dad015<M00<005<M00000P000U<M00<005<MDad015<M0`001E<M00<005<MDad015<M0P001U<M00<0
05<MDad00e<M0`001U<M00<005<MDad00`0000=C7@00Dad01U<M00<005<MDad00`000U<M00<005<M
Dad00e<M00<005<MDad00`000U<M00<005<MDad015<M100015<M00<005<MDad015<M0P001E<M00<0
05<MDad015<M0`001U<M00@005<MDaeC7@D000IC7@03001C7@0000800003Dad005<M00IC7@03001C
7E<M00<0009C7@03001C7E<M00AC7@03001C7E<M00<0009C7@03001C7E<M00=C7@<000EC7@03001C
7E<M00AC7@<000EC7@04001g=GLe0003McH00`00McIg=P03McH00`00JYAZU003JY@00`00Nfl00002
OgD01@00NeEkEG]E00000g]E00D007]E001kE@00009kE@04001oMGme0002Oi@00`00OiD00002OiD0
0`00Ok@00002Ok@00`00Ok@00002Ok@400000gOC0000000200000fna00000003002lOol00`00Oomo
o`1IOol00`00Oomoo`0DOol007]oo`03001oogoo0?mooc=oo`03001Fo@000080009Fo@/0000405<0
000005@200001P1d0004U0BD0004U080008<]@05000DeACE5=D000025=D010006?DHm@000QSe0P00
0R4E00L002TE:ADY5@00=E@00002<ED01@00;ED]EBeE000013Ue00@001dF7AHM5P80008De0@000IC
7@03001C7E<M00<00003Dad005<M00IC7@03001C7@00008000=C7@03001C7E<M00=C7@03001C7E<M
00<0009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00=C7@<000EC7@03001C7E<M00AC7@<000IC
7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00DaeC7@030002Dad00`00
DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad30006Dad0
1000DaeC7E<M10001U<M00<005<MDad00`0000=C7@00Dad01U<M00<005<MDad00`000U<M00<005<M
Dad00e<M00<005<MDad00`000U<M00<005<MDad015<M100015<M00<005<MDad015<M0P001E<M00<0
05<MDad015<M0`001U<M00@005<MDaeC7@D000IC7@03001C7@0000800003Dad005<M00IC7@03001C
7E<M00<0009C7@03001C7E<M00AC7@03001g=@0000=g=P03001g=WLf009g=P8000AZU004001kKg]_
0002OgD01@00NeEkEG]E00000W]E00D007]ENeEkE@00009kE@04001oMGme0003Oi@00`00OiD00002
OiD00`00Ok@00002Ok@20002Ok@01@00Nk@00000Mm<02P00_Woo00<007ooOol0F7oo00<007ooOol0
57oo001lOol2003oOoldOol20005E_d=000205@01`0007@0M00019@000BD0080008<]@80008De@04
000DeACE00026?D01@006?DHmASe00000R4E00D002TE:ADY5@00008eE0<000<]E@03000iMCUe008i
M@03000M5QdF008M5P<000=C7@03001C7E<M00AC7@<000EC7@03001C7E<M00AC7@8000MC7@04001C
7E<MDad40006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00Dad000020003Dad00`00DaeC7@03
Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@03Dad30005Dad00`00DaeC
7@04Dad30006Dad01000DaeC7E<M10001U<M00<005<MDad00`0000=C7@00Dad01U<M00<005<MDad0
0`000U<M00<005<MDad015<M10000e<M00<005<MDad015<M0`001E<M00<005<MDad015<M0`001U<M
00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad005<M00IC7@03001C7E<M00<0009C7@03001C
7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00AC7@8000EC7@03
001C7E<M00AC7@<000IC7@04001C7E<MDad40004McH01@00McIg=WLf00000W<h00D006ZDJYAZU000
009kK`04001oMGme0002NeD01@00NeEkEG]E00000g]E0P0000EkE@00OgEoM@00009oU003001oU@00
009oU@03001o]000009o]003001o]000009o]0<00003Mm<007OB00<00003Kk00000000800<1oo`03
001oogoo05Moo`03001oogoo01Aoo`00OWoo00<007ooOol0ogoo<goo00@005KmE_eFo@@0000300l0
000000H0000403<0001D000207@200000`BD0004U00200023;D2000011CE000DeACE0P000QSe00@0
01Se6?D000<Q5@04000Y5BTE0004=E@20003;ED00`00>GDiM@02>GD01@007AHM5QdF00001U<M00<0
05<MDad00`000U<M00<005<MDad015<M00<005<MDad00`000U<M00<005<MDad015<M100015<M00<0
05<MDad00e<M0`001E<M00<005<MDad015<M0P001e<M00@005<MDaeC7@@000IC7@03001C7E<M00<0
0003Dad005<M00IC7@03001C7@00008000=C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C
7E<M00AC7@@000AC7@03001C7E<M00=C7@<000EC7@03001C7E<M00AC7@<000IC7@03001C7E<M00<0
0003Dad005<M00EC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7E<M00<0009C7@03001C
7E<M00AC7@@000=C7@03001C7E<M00AC7@<000EC7@03001C7E<M00AC7@<000IC7@04001C7E<MDad4
0006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00DaeC7@0300000e<M001C7@05Dad00`00DaeC
7@030002Dad00`00DaeC7@04Dad40004Dad01000McIg=P0017Lf00@007<hLcP000=ZU003001kK`00
009oM@05001kEG]ENeD00003NeD01000NeEkE@000W]E0`0000MoM@00OiAoU000OiD00002OiD00`00
Ok@00002Ok@00`00Ok@00002000017^c000007OC100000=_/00000000`00`7oo00<007ooOol0Egoo
00<007ooOol057oo001oOol00`00Oomoo`3oOolcOol30003E_d600000`0B0000<`03000205@01000
07@0001d0P000PBD00D000be3;D0013E008000<De@8000046?D001Se6?D200028AD01@00:ADY5BTE
000013ED00D002eE;ED]E@0000@iM@03000M5QdF008M5P03001C7E<M00=C7@<000IC7@04001C7E<M
Dad50006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00Dad000020002Dad00`00DaeC7@04Dad0
0`00DaeC7@030002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@03Dad30005Dad00`00DaeC7@04
Dad20007Dad01000DaeC7E<M10001U<M00<005<MDad00`0000=C7@00Dad01U<M00<005<M00000P00
0e<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad015<M0`001E<M00<005<MDad00e<M
0`001U<M00@005<MDaeC7@D000IC7@03001C7E<M00<00003Dad005<M00EC7@03001C7E<M00<0009C
7@03001C7E<M00AC7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@<0
00EC7@03001C7E<M00AC7@<000EC7@04001C7E<MDad50006Dad00`00DaeC7@0300000e<M001C7@06
Dad00`00McH00003McH01@00LcQc>7<h00000fZD00<007]_00000Wme00@007]ENeD000=kE@05001k
EG]ENeD00002NeD00`00NeEkE@03000017nD001oU@000WnE00<007nd00001@0000Mk/`00000007OC
001gdP0300000fn`000000020032Ool00`00Oomoo`1FOol00`00Oomoo`0DOol0081oo`03001oogoo
0?mooc=oo`03001FoEKm00=Fo@<0000:014000000180000c0000<`0005@20000101d000000000PBD
00@000be3;D0008@e@80008De@04000De@0000036?D200000b4E000Y5@02:AD00`00=E@eE002=E@2
0002;ED00`00>GDiM@02>GD00`007AHM5P037AH00`00Dad000020003Dad00`00DaeC7@03Dad40004
Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M1@001U<M00<005<M
Dad00`0000=C7@00Dad01U<M00<005<M00000P000U<M00<005<MDad015<M00<005<MDad00`000U<M
00<005<MDad015<M100015<M00<005<MDad00e<M0`001E<M00<005<MDad015<M0P001e<M00@005<M
DaeC7@@000IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7@00008000=C7@03001C7E<M
00=C7@@000AC7@03001C7E<M00AC7@<000EC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad50006
Dad00`00DaeC7@0300000e<M001C7@05Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00DaeC
7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad20003
McH00`00LcQc>003LcP00`00JY@00002Nfl00`00OgD00003NeD01@00NeEkEG]E00000g]E00<007]E
00000g]E00<007nCOi<02@0000Mo]000Ok@007^c001k/`0200000gOC0000000200000fn`00000002
0034Ool00`00Oomoo`1EOol00`00Oomoo`0DOol0085oo`03001oogoo0?mooc=oo`04001FoEKmE_d7
00001@0B0000<`0003<00`0000@0D`000000M080000319@00000008<]@04000@eA3E00025=D01000
5=D000000aSe00@001SD000000<Y5@03000eE3ED008eE005000Hm@00;ED00005>GD00`007AHM5P04
0007Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad0
0`00DaeC7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04
Dad20006Dad01000DaeC7E<M1@001U<M00<005<MDad00`0000=C7@00Dad01U<M00<005<M00000P00
0U<M00<005<MDad015<M00<005<MDad00`000U<M00<005<MDad015<M10000e<M00<005<MDad015<M
0`001U<M00@005<MDaeC7@@000MC7@03001C7@0000800003Dad005<M00IC7@03001C7E<M00<0009C
7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00AC7@<0
00EC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad50006Dad00`00Dad0000200000e<M001C7@06
Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00DaeC7@0300000e<M001g=P02McH00`00LcQc
>003LcP01000JY@007]_0P0000EoM@00NeEkE@0000=kE@05001kEG]ENeD00002NeD01000NeEkE@00
0gnC00<007nD00000WnD00L007nd001o]000Ok@00002Nk<300000gOC001gdP070035Ool00`00Oomo
o`1FOol00`00Oomoo`0COol0089oo`800?moocAoo`<0009Fo@H000030180000c00<0000405@00000
000207@00`0019@4U00200001@be000@eA3E00000QCE00<001CE5=D00P000QSe00@001SD000000<Y
5@03000eE3ED00<eE004000Hm@000004>GD40004Dad00`00DaeC7@04Dad20006Dad00`00DaeC7@03
Dad30006Dad01000DaeC7E<M1@001U<M00<005<M00000P000U<M00<005<MDad015<M00<005<MDad0
0`000U<M00<005<MDad015<M00<005<MDad00`000U<M00<005<MDad00e<M100015<M00<005<MDad0
15<M0`001E<M00<005<MDad015<M0P001U<M00@005<MDaeC7@D000IC7@03001C7E<M00<00003Dad0
05<M00EC7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00AC7@8000EC7@03
001C7E<M00AC7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00
DaeC7@030002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04Dad40004Dad00`00
DaeC7@04Dad20005Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M1@001E<M00<007Lf00001W<h
00H006ZD001kK`00LcP20002NeD01@00NeEkEG]E00000g]E00@007]ENeD0009kE@06001oTgnC001o
U0000WnD00<007nd00000Wnd00H007nd001k/`00Nk<700000fn`000000020036Ool00`00Oomoo`1E
Ool00`00Oomoo`0COol008Aoo`03001oogoo0?mooc9oo`03001FoEKm009Fo@T0000503<000000000
D`0200001P1d0004U0BD0008]080008@e@80008De@04000DeACE00026?D00`006=@He0020002:AD0
0`00=E@eE003=E@00`006?DHm@050002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC
7@04Dad00`00Dad000020003Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@04Dad20006Dad00`00
DaeC7@03Dad30006Dad01000DaeC7E<M1@001U<M00<005<M00000P000U<M00<005<MDad015<M00<0
05<MDad00`000U<M00<005<MDad015<M00<005<MDad00`000U<M00<005<MDad00e<M100015<M00<0
05<MDad015<M0`001E<M00<005<MDad00e<M0`001U<M00<005<MDad00`0000=C7@00Dad01U<M00<0
05<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad015<M100015<M00<0
05<MDad00e<M0`001E<M00<005<MDad015<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<0
0003Dad005<M00IC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C
7E<M00AC7@@000AC7@03001C7E<M00=C7@8000Mc>004001ZU0000002LcP01@00McH007]E00000W]E
00D007]ENeEkE@00009kE@05001kEG]ENeD00002Oi<00`00Oi@00002Oi@00`00Ok@00002Ok@20002
Nk<2000017_C000007Nb1`00b7oo00<007ooOol0E7oo00<007ooOol04goo0025Ool00`00Oomoo`3o
OolbOol00`00E_d0000>000205<01`0007@0000019@000Rd008000<@e@8000055=D001CE5=D00003
6?D010006=@He0000bTE00<003ED=E@00SED00D001Se6?DHm@0000IC7@03001C7E<M00=C7@<000IC
7@04001C7E<MDad40007Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad0
0`00DaeC7@04Dad00`00Dad000020003Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@04Dad20006
Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M1@001U<M00<005<M00000P000U<M00<005<MDad0
15<M00<005<MDad00`000U<M00<005<MDad015<M00<005<M00000P000e<M00<005<MDad00e<M0`00
1E<M00<005<MDad015<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad005<M00IC
7@03001C7@000080009C7@03001C7E<M00AC7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000=C
7@03001C7E<M00AC7@<000EC7@03001C7E<M00AC7@<000IC7@04001C7E<MDad40006Dad00`00DaeC
7@0300000e<M001C7@06Dad00`00Dad000020002Dad00`00LcQc>005LcP20002LcP01000McIg=WLf
0P000W]E00D007]ENeEkE@00009kE@04001kEG]E0002Oi<01000OiAoU0000WnD00X007nd001o]000
Ok@007^c001k/`<00005Mk800000001_/003003:Ool00`00Oomoo`1COol00`00Oomoo`0COol008Io
o`03001oogoo0?mooc9oo`80009Fo@X0000503<0000005<0000207@200000`BD0008]00200024=D0
10005=D000000QCE0P000QSe00@001SD6=@000<Y5@03000eE3ED00<eE004000HmASe0007Dad00`00
Dad000020003Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@04Dad20006Dad00`00DaeC7@03Dad3
0006Dad01000DaeC7E<M10001e<M00<005<M00000P000U<M00<005<MDad015<M00<005<MDad00`00
0U<M00<005<MDad015<M00<005<M00000P000e<M00<005<MDad00e<M100015<M00<005<MDad015<M
0P001U<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000MC7@03001C7@0000800003Dad005<M
00IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@<000EC7@03001C
7E<M00AC7@8000IC7@04001C7E<MDad50006Dad00`00DaeC7@0300000e<M001C7@05Dad00`00DaeC
7@030002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40003Dad00`00DaeC
7@04Dad30005Dad00`00DaeC7@04Dad20006Dad01000LcQc>7<h1@000W<h00T007LfMcIg=P00McH0
07]E00000g]E00<007]E00000g]E00H007nCOi<007nD0002Oi@00`00Ok@00002Ok@2000017^c001k
/g^c0`0000=g/P0000001000bgoo00<007ooOol0Dgoo00<007ooOol04goo0027Ool2003oOoldOol0
0`00E_eFo@0:0000200c0000D`1C0000M00007@200022;@01@004=D@e@005=D00P000aCE0P0000@H
m@006=@He080008Y5@03000eE3ED00<eE005000HmASe6?D00006Dad20007Dad00`00Dad000020002
Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00Dad000020003Dad00`00
DaeC7@03Dad40004Dad00`00DaeC7@04Dad20006Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M
10001e<M00<005<M00000P0000=C7@00Dad01U<M00<005<MDad00`000U<M00<005<MDad015<M00<0
05<M00000P000U<M00<005<MDad015<M100015<M00<005<MDad015<M0P001E<M00<005<MDad015<M
0`001U<M00<005<MDad00`0000=C7@00Dad01E<M00<005<MDad00`000U<M00<005<MDad015<M00<0
05<MDad00`000U<M00<005<MDad00e<M100015<M00<005<MDad015<M0`001E<M00<005<MDad00e<M
0`001U<M00@005<MDaeC7@D000IC7@03001C7E<M00<00003Dad005<M00EC7@03001C7E<M00<0009C
7@03001C7E<M00AC7@03001C7E<M00<00003Dad005<M00EC7@@000=C7@04001c>7<h0003McH01@00
McIg=WLf00000g]E00@007]ENeD000=kE@03001oT`00009oU00=001oU7nD001o]000Ok@007nd001k
/`00Nk<00`0000=g/P0000001@00c7oo00<007ooOol0DWoo00<007ooOol04goo0029Ool00`00Oomo
o`3oOolbOol800001P0B0000<`0003<00080D`<0000307@000000088]004000@eA3E00025=D20002
5=D010005=D000000aSD0P0000<Y5@00=E@013ED00<001Se6?D00QSe00<005<MDad00`000U<M00<0
05<MDad015<M0P001U<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000MC7@03001C7@000080
0003Dad005<M00IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C
7E<M00AC7@@000AC7@03001C7E<M00AC7@8000EC7@03001C7E<M00AC7@<000IC7@04001C7E<MDad4
0006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00
DaeC7@030002Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M1@00
1U<M00<005<M00000P0000=C7@00Dad01U<M00<005<MDad00`000U<M00<005<MDad015<M00<005<M
00000P000U<M00<005<MDad015<M100015<M00<005<MDad015<M0`001E<M00<005<MDad00e<M0`00
1U<M00@005<MDaeC7@D000EC7@03001C7E<M00<00003Dad005<M00=C7@05001c>7<hLcP00003McH0
1000McIg=WLf0P000W]E00@007]ENeD0009kE@06001oTgnC001oU0000WnD00<007nd00000Wnd00@0
07nd0000009k/`<00003Mk80000000@00<ioo`03001oogoo055oo`03001oogoo01=oo`00RWoo00<0
07ooOol0ogoo<Woo00<005Km00000`0000<04@0001800P000P0c00L0001C0000001d0000M0020000
0`Rd000000024=D010005=DDe@000QCE00<001CE5=D00P000QSD00@0012d000000HeE003000HmASe
00@000IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC
7@@000AC7@03001C7E<M00AC7@8000EC7@03001C7E<M00AC7@<000IC7@04001C7E<MDad40006Dad0
0`00DaeC7@0300000e<M001C7@06Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@03
0002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@03Dad30005Dad00`00DaeC7@04Dad30006Dad0
1000DaeC7E<M10001U<M00<005<MDad00`000U<M00<005<MDad015<M00<005<M00000P000U<M00<0
05<MDad015<M100015<M00<005<MDad015<M0P001E<M00<005<MDad015<M0`001U<M00@005<MDaeC
7@@000IC7@03001C7E<M00<00003Dad005<M00IC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03
001C7E<M00<0009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00=C7@<000EC7@05001C7E<MDad0
0002LcP00`00McIg=P02McH01000McIg=P000WLe00D007]E001kE@0000=kE@03001oT`00009oU00;
001oU7nD001o]000Ok@007nd001k/`0500000gNb00000004003@Ool00`00Oomoo`1AOol00`00Oomo
o`0BOol008]oo`03001oogoo0?mooc9oo`L000050180000c0000<`020000101C000000000P1d00<0
00Rd2;@00P0000D@e@005=DDe@0000<De@04000DeACE00026=@01@004;@002TE000013ED100015<M
00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad005<M00IC7@03
001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000AC7@03
001C7E<M00=C7@<000EC7@03001C7E<M00AC7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@03
00000e<M001C7@06Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00
DaeC7@04Dad40003Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M10001U<M00<005<MDad00`00
00=C7@00Dad01U<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<M
Dad015<M100015<M00<005<MDad00e<M0`001E<M00<005<MDad015<M0`001U<M00@005<MDaeC7@@0
00IC7@03001C7E<M00<00003Dad005<M00IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C
7@0000=c>005001g=WLfMcH00003McH01@00McEg=GLe00000W]E00T007]ENeEkE@00Oi<007nD0000
0WnD00<007nd00000Wnd00<007nd00000P0000Ek/P00000007Nb00H00=1oo`03001oogoo055oo`03
001oogoo019oo`00S7oo0P00ogoo<goo1`0000<04P0000000P0000<0<`0000000P000P1d00D000Rd
2;@0012d0080008De@80008De@04000DeACE00026=@00`004;@@]002000013ED000000000U<M00<0
05<MDad015<M00<005<M00000P000U<M00<005<MDad015<M100015<M00<005<MDad00e<M0`001E<M
00<005<MDad015<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad005<M00IC7@03
001C7@00008000=C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000AC7@03
001C7E<M00=C7@<000EC7@03001C7E<M00AC7@8000IC7@04001C7E<MDad50006Dad00`00DaeC7@03
0002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@03
Dad30005Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M10001U<M00<005<MDad00`0000=C7@00
Dad01U<M00<005<M00000P000U<M00<005<MDad015<M00<005<MDad00`000U<M00<005<MDad015<M
10000e<M00<005<MDad015<M0`001E<M00<005<MDad015<M0P001U<M00@005<MDaeC7@@000Ac>005
001g=WLfMcH00002McH00`00McEg=@02McD200001g]E001kEG]E001oT`00009oU006001oU7nD001o
]0000Wnd0P0000=k/`00Nk800`000WNb1@00dWoo00<007ooOol0D7oo00<007ooOol04Woo002>Ool0
0`00Oomoo`3oOolaOol>0000101C0000001d0P0000<8]0004;@00P000aCE0P0000@De@005=DDe@80
008He003000@]12d008000IC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M001C7@06Dad0
0`00Dad000020003Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40004Dad0
0`00DaeC7@03Dad30005Dad00`00DaeC7@04Dad20007Dad01000DaeC7E<M10001U<M00<005<MDad0
0`0000=C7@00Dad01U<M00<005<M00000P000U<M00<005<MDad015<M00<005<MDad00`000U<M00<0
05<MDad00e<M100015<M00<005<MDad015<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<0
0003Dad005<M00IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7E<M00<0009C7@03001C
7E<M00AC7@@000=C7@03001C7E<M00AC7@<000EC7@03001C7E<M00AC7@8000IC7@04001C7E<MDad5
0006Dad00`00DaeC7@0300000e<M001C7@05Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00
DaeC7@0300000e<M001C7@05Dad40004Dad01000LcQc>0000gLf00D007LfMcIg=P0000=g=@03001k
=G/e0080009kE@03001oT`00009oU005001oU7nD001o]00300000gnd00000002Nk8300000gNb0000
0004003COol00`00Oomoo`1?Ool00`00Oomoo`0BOol008moo`03001oogoo0?mooc5oo`/0000503<0
000005<0000207@200000`Rd000@]00200025=D010005=D000000aCE0P0000<He0004;@00Q2d00<0
05<MDad015<M100015<M00<005<MDad00e<M0`001E<M00<005<MDad015<M0P001e<M00@005<MDaeC
7@@000IC7@03001C7E<M00<00003Dad005<M00IC7@03001C7@00008000=C7@03001C7E<M00=C7@03
001C7E<M00<0009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@<000EC7@03001C7E<M00AC
7@8000IC7@04001C7E<MDad50006Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00DaeC7@03
0002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad20006Dad0
1000DaeC7E<M1@001U<M00<005<MDad00`0000=C7@00Dad01E<M00<005<MDad00`000U<M00<005<M
Dad015<M00<005<MDad00`000U<M00<005<MDad00e<M100015<M00<005<MDad015<M0`001E<M00<0
05<MDad00e<M0`001U<M00@005<MDaeC7@D000EC7@03001C7E<M00<00003Dad005<M00IC7@03001c
>00000=g=P04001g=WLf0004McD01`00NcEk=@00NcD007]E00/00006Ok@00000Nk<007^b0P0000=g
/P00Mk801@00e7oo00<007ooOol0Cgoo00<007ooOol04Woo002@Ool00`00Oomoo`3oOolaOol00`00
00h00007000203<00`0005<0000207@200001@Rd000@]12d00000QCE00<001CE5=D00P000QCE00@0
01CD000000@@]003001C7E<M00<00003Dad005<M00IC7@03001C7@00008000=C7@03001C7E<M00=C
7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00=C7@<000EC7@03001C7E<M
00AC7@8000MC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M001C7@05Dad00`00DaeC7@03
0002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@04
Dad20006Dad00`00DaeC7@03Dad30006Dad00`00DaeC7@0300000e<M001C7@05Dad00`00DaeC7@03
0002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@04
Dad30005Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M1@001U<M00<005<M00000P0000=C7@00
Dad01U<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad015<M
100015<M00<005<MDad00e<M0`001E<M00<005<MDad015<M0P000gLf00D007LfMcIg=P0000=g=@04
001k=G/e0003NcD00`00Mhh00002Oi@03@00OiEoU@00Ok<007nd001o]000Nk<007^b00T00=Ioo`03
001oogoo04ioo`03001oogoo019oo`00TGoo0P00ogoo<Goo0`0000X03`000140000B0000<`0003<0
0080D`040000M00019@200024;@01@005=DDeACE00000QCE00D001CE5=D001CD008000@@]0<000EC
7@03001C7E<M00AC7@8000MC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M001C7@06Dad0
0`00Dad000020003Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40003Dad0
0`00DaeC7@04Dad30005Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M1@001U<M00<005<M0000
0P0000=C7@00Dad01U<M00<005<MDad00`000U<M00<005<MDad015<M00<005<M00000P000U<M00<0
05<MDad015<M0`001E<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@D000IC7@03001C7@000080
0003Dad005<M00IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C
7E<M00AC7@@000AC7@03001C7E<M00AC7@8000EC7@03001C7E<M00AC7@<000IC7@04001C7E<MDad4
0006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00
DaeC7@030002Dad01000McIg=P000gLf00D007LeMcEg=@00009k=@04001k=G/eNcD20002Oi@01P00
OiEoU@00Ok<0009o]007001o]000001k/P00Mk800P0000=c/@0000000`00egoo00<007ooOol0CGoo
00<007ooOol04Woo002COol00`00Oomoo`3oOol_Ool500000`0A00004P02000203<01@0005<00000
07@00`000Q2d0P000QCE00@001CE5=D0008De@03000De1CD00D000=C7@03001C7E<M00=C7@03001C
7E<M00<0009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00=C7@<000EC7@03001C7E<M00AC7@80
00MC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M001C7@05Dad00`00DaeC7@030002Dad0
0`00DaeC7@04Dad00`00Dad000020003Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@04Dad20005
Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M10001U<M00<005<MDad00`000U<M00<005<MDad0
15<M00<005<M00000P000e<M00<005<MDad00e<M100015<M00<005<MDad015<M0P001E<M00<005<M
Dad015<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad005<M00IC7@03001C7E<M
00<00003Dad005<M00EC7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC
7@<000EC7@03001C7E<M00AC7@8000IC7@04001C7E<MDad50006Dad00`00McH00002McH01@00McEg
=GLe00000g/e00@007/eNcEk=@80009oU00=001oUGnE001o/`00Ok@007nd001k/`00Nk800`0000=c
/@0000000`00fGoo00<007ooOol0C7oo00<007ooOol04Woo002DOol00`00Oomoo`3oOol_Ool40000
1`0A00004P0003<0000c00@0000307@000BD0080008@]08000045=D001CE5=D200025=D010005=@D
e0001e<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad005<M00IC7@03001C7@00008000=C
7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@<0
00EC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40007Dad00`00Dad0000200000e<M001C7@06
Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40004
Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M10001e<M00<005<M00000P0000=C7@00Dad01U<M
00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad015<M100015<M
00<005<MDad00e<M0`001E<M00<005<MDad015<M0`001E<M00@005<MDaeC7@D000IC7@03001C7E<M
00<00003Dad005<M00EC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7E<M00<00003Dad0
05<M00EC7@@000AC7@03001C7E<M00AC7@8000=g=P05001g=GLeMcD00002NcD01`00NcEk=G/e001g
SP00009oU003001oU@00009o/`04001o]000Ok@20002Nk8300000g>a00000003003IOol00`00Oomo
o`1=Ool00`00Oomoo`0AOol009Eoo`03001oogoo0?moobmoo`@000030140000B00D0000405<00000
000219@01@004;@@]0004=@00P000aCE0P0000<De@005=@00QCD00<005<MDad015<M100015<M00<0
05<MDad00e<M0`001E<M00<005<MDad015<M0P001e<M00@005<MDaeC7@@000IC7@03001C7E<M00<0
0003Dad005<M00EC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7@00008000=C7@03001C
7E<M00=C7@@000AC7@03001C7E<M00AC7@8000EC7@03001C7E<M00AC7@<000IC7@04001C7E<MDad4
0006Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04Dad4
0004Dad00`00DaeC7@04Dad20005Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M10001U<M00<0
05<MDad00`0000=C7@00Dad01U<M00<005<M00000P000U<M00<005<MDad015<M00<005<MDad00`00
0U<M00<005<MDad00e<M100015<M00<005<MDad015<M0`001E<M00<005<MDad00e<M0`001U<M00@0
05<MDaeC7@D000EC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7E<M00<00005Dad007Lf
McH00004McD01000NcEk=@000g/e0P000WnD00d007nEOiD007nc001o]000Ok@007^c001k/P030000
0g>a00000003003KOol00`00Oomoo`1<Ool00`00Oomoo`0AOol009Ioo`800?moobmoo`X0000303<0
000000<00084U004000@]12d00024=@200025=D010005=@0000011CD00<005<MDad00`0000=C7@00
Dad01U<M00<005<M00000P000e<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad015<M
10000e<M00<005<MDad015<M0`001E<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000MC7@03
001C7@0000800003Dad005<M00IC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0
009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad00`00
DaeC7@0300000e<M001C7@06Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002
Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad20006Dad01000
DaeC7E<M1@001U<M00<005<M00000P0000=C7@00Dad01U<M00<005<MDad00`000U<M00<005<MDad0
15<M00<005<M00000P000U<M00<005<MDad015<M100015<M00<005<MDad00e<M0`001U<M00@005<M
DaeC7@D000EC7@03001g=P0000=g=@05001k=G/eNcD00003NcD20002Oi@00`00OiD00002Ok<01000
Ok@007nd0P000W^b0`0000=c/@0000000`00g7oo00<007ooOol0Bgoo00<007ooOol04Goo002HOol0
0`00Oomoo`3oOol]Ool=0000100c000000BD0P000Q2d00@0013D4=@0008De@04000De00000045=@3
0005Dad00`00DaeC7@04Dad20007Dad01000DaeC7E<M10001U<M00<005<MDad00`0000=C7@00Dad0
1E<M00<005<MDad00`000U<M00<005<MDad015<M00<005<M00000P000e<M00<005<MDad00e<M1000
15<M00<005<MDad015<M0P001E<M00<005<MDad015<M0`001U<M00@005<MDaeC7@@000IC7@03001C
7E<M00<0009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@@000AC7@03001C
7E<M00=C7@<000EC7@03001C7E<M00AC7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@030000
0e<M001C7@05Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC
7@03Dad40004Dad00`00DaeC7@04Dad20005Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M1000
1U<M00<005<MDad00`000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad015<M1000
15<M00<005<MDad00e<M0P0017Le00@007/eNcD000=k=@80009oU008001oUGnE001o/`00Ok@0009o
]0H00003Lk40000000<00=eoo`03001oogoo04]oo`03001oogoo015oo`00VGoo00<007ooOol0ogoo
;Goo2P0000D0<P000000<`000084U08000054;@0013D4=@000025=D00`005=@De0050003Dad00`00
DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad30005Dad0
0`00DaeC7@03Dad30006Dad01000DaeC7E<M10001e<M00<005<M00000P0000=C7@00Dad01U<M00<0
05<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad015<M100015<M00<0
05<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad005<M00IC7@03001C
7@00008000=C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000=C7@03001C
7E<M00AC7@<000EC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad50006Dad00`00Dad000020000
0e<M001C7@06Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC
7@04Dad40003Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M10001U<M00<005<MDad00`0000=C
7@00Dad01U<M00<005<M00000P000U<M00@007LeMcD000=k=@04001k=G/eNcD20002Oi@03@00OiEo
U@00Ok<007nd001o]000Nk<007Na00<00003Lk40000000800=moo`03001oogoo04Yoo`03001oogoo
015oo`00VWoo00<007ooOol0ogoo;7oo200000L0<`000000<P0003<0000219@010003;@000000Q3D
0P000QCE00@001CD5=@000MC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M001C7@05Dad0
0`00DaeC7@030002Dad00`00DaeC7@04Dad00`00Dad000020003Dad00`00DaeC7@03Dad40004Dad0
0`00DaeC7@04Dad20005Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M10001U<M00<005<MDad0
0`000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad015<M100015<M00<005<MDad0
0e<M0`001E<M00<005<MDad015<M0P001e<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad0
05<M00EC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC
7@@000AC7@03001C7E<M00AC7@8000EC7@03001C7E<M00AC7@<000IC7@04001C7E<MDad40006Dad0
0`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40003Dad0
0`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad20006Dad00`00McD00003NcD01000NcEk=G/e0P00
0WnD00L007nE001o/`00Ok@00002Ok@200001GNa00000000Lk401@00h7oo00<007ooOol0BGoo00<0
07ooOol04Goo002KOol00`00Oomoo`3oOol/Ool400002@0A0000000003<0000b0000<`0200000`BD
000<]00200034=@200000aCE000De0025=@00`00DaeC7@04Dad40004Dad00`00DaeC7@03Dad30005
Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M10001e<M00<005<M00000P0000=C7@00Dad01U<M
00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad015<M100015<M
00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad005<M00IC7@03
001C7@000080009C7@03001C7E<M00AC7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000=C7@03
001C7E<M00AC7@<000EC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@03
00000e<M001C7@06Dad00`00DaeC7@0300000e<M001C7@05Dad00`00DaeC7@030002Dad00`00DaeC
7@04Dad40003Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M10001U<M00<005<MDad00`0000=C
7@00Dad01E<M00<005<MDad00`000U<M00<005<MDad015<M00<005<MDad00`0000=C7@00Dad01E<M
0P000g/e00@007/eNcEk=@80009oU008001oUGnE001o/`00Ok@0009o]0800005Mk400000001c/@04
003ROol00`00Oomoo`18Ool00`00Oomoo`0AOol009aoo`800?moobaoo`<000030100000A00800006
03<0000b0380000c0P0000<4U0003;@00P000Q3D00@001CD000000@De003001C7E<M00<00003Dad0
05<M00IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@00008000=C7@03001C7E<M00=C
7@@000AC7@03001C7E<M00AC7@8000EC7@03001C7E<M00AC7@<000IC7@04001C7E<MDad40006Dad0
0`00DaeC7@030002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04Dad40004Dad0
0`00DaeC7@03Dad30005Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M1@001U<M00<005<MDad0
0`0000=C7@00Dad01E<M00<005<MDad00`000U<M00<005<MDad015<M00<005<M00000P000U<M00<0
05<MDad015<M100015<M00<005<MDad00e<M0`001E<M00<005<MDad015<M0`001E<M00@005<MDaeC
7@D000IC7@03001C7E<M00<00003Dad005<M00EC7@03001C7E<M00<0009C7@03001C7E<M00AC7@@0
00=C7@03001C7E<M00AC7@<000EC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad50005Dad00`00
DaeC7@0300000e<M001k=@02NcD01000NcEk=G/e0P000WnD00<007nE00000Wnc1P0000Ag/@00001g
/@H00>9oo`03001oogoo04Uoo`03001oogoo011oo`00WWoo00<007ooOol0ogoo:Woo100000<04@00
00000P0c00@0000b0000<`80000519@000bd3;@000024=@010005=@0000011CD0`001E<M00<005<M
Dad015<M0P001U<M00@005<MDaeC7@@000MC7@03001C7@00008000=C7@03001C7E<M00=C7@03001C
7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000AC7@03001C
7E<M00=C7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00Dad0
00020002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC
7@04Dad30005Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M10001U<M00<005<MDad00`000U<M
00<005<MDad015<M00<005<M00000P000U<M00<005<MDad015<M00<005<MDad00`000U<M00<005<M
Dad00e<M100015<M00<005<MDad015<M0`001E<M00@005<MDaeC7@D000IC7@03001C7E<M00<00003
Dad005<M00EC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M
00AC7@@000AC7@03001C7E<M00=C7@<000EC7@04001k=G/e0003NcD20002Oi@00`00OiD000020000
17nd001oU7nD0P0000=g/@0000001P00i7oo00<007ooOol0B7oo00<007ooOol047oo002OOol00`00
Oomoo`3oOolZOol200000`0@00004@0200000`0c0000000300000`0c000000023;@010004=@@e000
0QCD1@000e<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M100015<M00<005<M
Dad015<M0P001e<M00@005<MDaeC7@@000IC7@04001C7E<MDad40006Dad00`00DaeC7@030002Dad0
0`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@03Dad30005
Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M1@001U<M00<005<M00000P000U<M00<005<MDad0
15<M00<005<MDad00`000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad015<M1000
15<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@04001C7E<MDad50006Dad00`00Dad0
00020002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC
7@04Dad30005Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M10001U<M00<005<MDad00`0000=C
7@00Dad01U<M00<005<M00000P000U<M00<005<MDad015<M0P000g/e200000=cSP0000000WnD00D0
07^a000007Na00L00>Eoo`03001oogoo04Moo`03001oogoo011oo`00X7oo00<007ooOol0ogoo:Goo
100000<04@0000000`0000<0<P0000000`000Pbd0P000Q3D00@001CD5=@000MC7@04001C7E<MDad4
0006Dad00`00Dad000020003Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad4
0003Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M10001U<M00<0
05<MDad00`0000=C7@00Dad01U<M00<005<M00000P000e<M00<005<MDad00e<M00<005<MDad00`00
0U<M00<005<MDad00e<M100015<M00<005<MDad015<M0P001U<M00<005<MDad00e<M0`001U<M00@0
05<MDaeC7@@000IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C
7E<M00AC7@@000AC7@03001C7E<M00=C7@@000AC7@03001C7E<M00AC7@8000IC7@04001C7E<MDad5
0006Dad00`00Dad0000200000e<M001C7@06Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00
DaeC7@030002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@04Dad2
0006Dad01000DaeC7E<M10000g/e0P000W<g00L007Lf001cSP00Ok@00002Oi@200001GNa00000000
Lk401000igoo00<007ooOol0AWoo00<007ooOol047oo002QOol2003oOolZOol700000`0c00000003
00000`0c000000023;@200000a3D000De0025=@00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad2
0007Dad01000DaeC7E<M10001U<M00<005<MDad00`0000=C7@00Dad01E<M00<005<MDad00`000U<M
00<005<MDad015<M00<005<M00000P000e<M00<005<MDad00e<M100015<M00<005<MDad00e<M0`00
1E<M00<005<MDad015<M0P001e<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M
00AC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@@0
00AC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M001C7@06
Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40004
Dad00`00DaeC7@04Dad20005Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M10001U<M00<005<M
Dad00`0000=C7@00Dad01E<M00<005<MDad00`000U<M00<005<MDad015<M00<005<MDad00`0000=C
7@00Dad01E<M100015<M00@007/eNcD0009c=`03001g=P00009cSP03001o]000009oU0<00003Mk40
000000<00003Ed`007oo0>Ioo`03001oogoo04Ioo`03001oogoo011oo`00Xgoo00<007ooOol0ogoo
9goo2`0000D04@0003<0<`00008<]004000De00000045=@00`00DaeC7@030002Dad00`00DaeC7@03
Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@03Dad30005Dad00`00DaeC
7@03Dad30006Dad01000DaeC7E<M10001e<M00<005<M00000P0000=C7@00Dad01U<M00<005<M0000
0P000e<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad015<M10000e<M00<005<MDad0
15<M0P001U<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<0009C7@03
001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00=C7@<000EC
7@03001C7E<M00AC7@8000IC7@04001C7E<MDad50006Dad00`00Dad0000200000e<M001C7@06Dad0
0`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40003Dad0
0`00DaeC7@04Dad30005Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M1@001E<M00<005<MDad0
0`000U<M00<005<MDad015<M0`000W<g00<007Lf00000W>>0P000WnD0P0000Eg/@00000007>a00@0
0>Uoo`03001oogoo04Eoo`03001oogoo011oo`00Y7oo00<007ooOol0ogoo9goo200000<0<P000000
0P0000H0<`003;@<]0005=@200045=@30006Dad01000DaeC7E<M10001U<M00<005<MDad00`0000=C
7@00Dad01U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000e<M00<005<MDad0
0e<M100015<M00<005<MDad015<M0P001E<M00<005<MDad015<M0P001e<M00@005<MDaeC7@@000IC
7@03001C7E<M00<00003Dad005<M00EC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7@00
0080009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad0
0`00DaeC7@0300000e<M001C7@06Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00DaeC7@03
0002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@04Dad20005Dad00`00DaeC7@04Dad30006Dad0
1000DaeC7E<M10001U<M00<005<MDad00`0000=C7@00Dad01E<M00<005<MDad00`000U<M00<005<M
Dad015<M00<005<M00000P000U<M00<005<MDad015<M100015<M00<005<MDad00e<M0`001U<M00@0
05<MDaeC7@@0009c=`08001g=WLf001cSP00Ok@0009oU0/00>Yoo`03001oogoo04Aoo`03001oogoo
011oo`00YGoo00<007ooOol0ogoo9Woo0`0000@03`0000004P8000050380000A0000<`02000010bd
000De1CD1@000U<M00<005<MDad015<M100015<M00<005<MDad00e<M0`001E<M00<005<MDad015<M
0P001U<M00@005<MDaeC7@@000MC7@03001C7@0000800003Dad005<M00IC7@03001C7E<M00<0009C
7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@<0
00EC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@030002Dad00`00DaeC
7@04Dad00`00Dad000020002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@03Dad30005Dad00`00
DaeC7@04Dad20006Dad01000DaeC7E<M1@001U<M00<005<M00000P0000=C7@00Dad01U<M00<005<M
Dad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad015<M10000e<M00<005<M
Dad015<M0`001E<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<0009C
7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@@0009C7@07001c=g<gLcL007Lf
00000W>>0P000WnD0P0000=g/@0000000P0000A_/00000000>]oo`03001oogoo04Eoo`03001oogoo
00moo`00YWoo0P00ogoo9goo1P0000H04P000380000A000203<200001@bd000De1CD00001U<M00<0
05<MDad00`0000=C7@00Dad01U<M00<005<M00000P000e<M00<005<MDad00e<M00<005<MDad00`00
0U<M00<005<MDad00e<M100015<M00<005<MDad015<M0P001E<M00<005<MDad015<M0`001U<M00@0
05<MDaeC7@@000IC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C
7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00=C7@<000IC7@04
001C7E<MDad40006Dad00`00DaeC7@0300000e<M001C7@06Dad00`00Dad000020002Dad00`00DaeC
7@04Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@04Dad20005Dad00`00
DaeC7@04Dad30006Dad01000DaeC7E<M10001U<M00<005<MDad00`000U<M00<005<MDad00e<M00<0
05<MDad00`000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad015<M100015<M00<0
05<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad005<M00=C7@04001c
=g<g0002McH01@00Lhh007nd00000WnD0`0000=g/@0000001000kGoo00<007ooOol0A7oo00<007oo
Ool03goo002XOol00`00Oomoo`3oOolTOol300001@0?0000000B00000P0b00@0000A0000<`800003
3;@001CD008De003001C7E<M00=C7@<000EC7@03001C7E<M00AC7@8000MC7@04001C7E<MDad40006
Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00
DaeC7@030002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M1000
1U<M00@005<MDaeC7@@000IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7@000080009C
7@03001C7E<M00AC7@@000AC7@03001C7E<M00=C7@<000EC7@03001C7E<M00AC7@8000IC7@04001C
7E<MDad50006Dad00`00Dad0000200000e<M001C7@06Dad00`00DaeC7@030002Dad00`00DaeC7@03
Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad30006Dad01000DaeC
7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7@00
0080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@<000EC7@04001C7E<M0003LcL02000
McIg=P00Lhh007nd0002Oi@:003^Ool00`00Oomoo`13Ool00`00Oomoo`0?Ool00:Uoo`03001oogoo
0?moobAoo`D000804P030000<P000080000303<0012d008000@De003001C7@00008000=C7@03001C
7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@8000IC7@03
001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad0
0`00Dad000020002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03
Dad30006Dad01000DaeC7E<M10001U<M00<005<MDad00`0000=C7@00Dad01U<M00<005<M00000P00
0U<M00<005<MDad015<M00<005<MDad00`000U<M00<005<MDad00e<M100015<M00<005<MDad015<M
0P001E<M00<005<MDad015<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<0009C7@03001C
7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@@000=C7@03
001C7E<M00AC7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M001C7@05Dad00`00
DaeC7@030002Dad00`00DaeC7@04Dad00`00Dad00002LcL02000McIg=P00Lhh007nd0002Oi@30000
0gNa00000004003`Ool00`00Oomoo`12Ool00`00Oomoo`0?Ool00:Yoo`03001oogoo0?moob=oo`H0
00030180000000D000034;@0000000@De08000MC7@04001C7E<MDad40006Dad00`00DaeC7@030000
0e<M001C7@05Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC
7@04Dad40004Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M10001U<M00<005<MDad00`0000=C
7@00Dad01U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000e<M00<005<MDad0
0e<M100015<M00<005<MDad00e<M0`001E<M00<005<MDad015<M0P001U<M00@005<MDaeC7@D000IC
7@03001C7@0000800003Dad005<M00IC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M
00<0009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@<000IC7@04001C7E<MDad40006Dad0
0`00DaeC7@0300000e<M001C7@05Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@03
0002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@03Dad30006Dad0
1000DaeC7E<M10000g<g00P007LfMcH007>>001o]0000WnD100000=c/@00Khl00`00l7oo00<007oo
Ool0@Woo00<007ooOol03goo002[Ool2003oOolTOol800001`0b0000000003<0012d00D0009C7@03
001C7E<M00AC7@@000AC7@03001C7E<M00=C7@<000EC7@03001C7E<M00=C7@<000IC7@04001C7E<M
Dad40006Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04
Dad40004Dad00`00DaeC7@03Dad30005Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M10001e<M
00<005<M00000P0000=C7@00Dad01U<M00<005<M00000P000e<M00<005<MDad00e<M00<005<MDad0
0`000U<M00<005<MDad00e<M100015<M00<005<MDad015<M0P001E<M00<005<MDad015<M0`001U<M
00@005<MDaeC7@@000IC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03
001C7E<M00AC7@@000=C7@03001C7E<M00AC7@<000EC7@03001C7E<M00=C7@<000IC7@04001C7E<M
Dad40006Dad00`00DaeC7@0300000e<M001C7@05Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad0
0`00Dad000020002Dad00`00DaeC7@04Dad40003Dad01000LcMc=`000gLf00D007>>001o]000009o
U0800003Mk40000000@00?9oo`03001oogoo045oo`03001oogoo00moo`00[Goo00<007ooOol0ogoo
8Goo1P0000<04P0000001@000Q2d00<005<MDad015<M00<005<MDad00`000U<M00<005<MDad015<M
00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000e<M00<005<MDad00e<M100015<M
00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad005<M00IC7@03
001C7@000080009C7@03001C7E<M00AC7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000AC7@03
001C7E<M00AC7@8000EC7@03001C7E<M00AC7@8000MC7@04001C7E<MDad40006Dad00`00Dad00002
0002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad0
0`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M10001U<M00<005<MDad0
0`0000=C7@00Dad01E<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<0
05<MDad015<M10000e<M00<005<MDad015<M0`001E<M00<005<MDad00e<M0`001U<M00@005<MDaeC
7@@000IC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001c=`00009g=P03001cSP0000L00004
Mk400000Khl2003dOol00`00Oomoo`10Ool00`00Oomoo`0?Ool00:ioo`03001oogoo0?moob5oo`T0
000403<0000000034;@00`00DaeC7@03Dad30006Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@0
00MC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@00008000=C7@03001C7E<M00=C7@@0
00AC7@03001C7E<M00=C7@<000EC7@03001C7E<M00AC7@8000IC7@04001C7E<MDad50006Dad00`00
Dad0000200000e<M001C7@06Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002
Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M1@001U<M00@005<M
DaeC7@@000IC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M
00AC7@@000=C7@03001C7E<M00AC7@<000EC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006
Dad00`00DaeC7@0300000e<M001C7@05Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00Dad0
00020002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M0`000gLf
00D007>>001c=`00009g=@800003Mk40000000@00?Eoo`03001oogoo041oo`03001oogoo00ioo`00
[goo00<007ooOol0ogoo87oo1`0000@04P000000<`8000@@]003001C7@00008000=C7@03001C7E<M
00=C7@@000AC7@03001C7E<M00=C7@@000AC7@03001C7E<M00AC7@8000IC7@04001C7E<MDad40007
Dad00`00Dad0000200000e<M001C7@06Dad00`00Dad000020003Dad00`00DaeC7@03Dad00`00DaeC
7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@04Dad20005Dad00`00DaeC7@04Dad30006
Dad01000DaeC7E<M10001U<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M
00<005<MDad00e<M100015<M00<005<MDad015<M10000e<M00<005<MDad015<M0`001U<M00@005<M
DaeC7@@000IC7@03001C7E<M00<00003Dad005<M00EC7@03001C7E<M00<0009C7@03001C7E<M00=C
7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@<000EC7@03001C7E<M
00=C7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC
7@030002Dad00`00DaeC7@04Dad40003Dad00`00McIg=P02000017<g001g=GLe0`0000Ig/@000000
06N>003fOol00`00Oomoo`10Ool00`00Oomoo`0>Ool00;1oo`800?moob5oo`80000300h0000B0080
00030180000c00<0008@]0<000MC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080
00=C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00AC
7@8000EC7@03001C7E<M00AC7@8000MC7@04001C7E<MDad40006Dad00`00Dad000020003Dad00`00
DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@04
Dad40003Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M10001U<M00<005<M00000P0000=C7@00
Dad01U<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad015<M
10000e<M00<005<MDad015<M0`001E<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@03
001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7@00
0080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@<000IC7@04001C7E<MDad40006Dad0
0`00DaeC7@0300000e<M001C7@05Dad30002LcL00`00McEg=@08003hOol00`00Oomoo`0oOol00`00
Oomoo`0>Ool00;9oo`03001oogoo0?mooamoo`@000050180000B0000<`050003Dad00`00DaeC7@04
Dad20006Dad00`00DaeC7@03Dad20007Dad01000DaeC7E<M10001U<M00<005<M00000P000U<M00<0
05<MDad015<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad0
15<M10000e<M00<005<MDad015<M0P001e<M00@005<MDaeC7@@000IC7@04001C7E<MDad40006Dad0
0`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40003Dad0
0`00DaeC7@04Dad20005Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M10001U<M00<005<MDad0
0`0000=C7@00Dad01E<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<0
05<MDad015<M10000e<M00<005<MDad015<M0`001U<M00@005<MDaeC7@@000IC7@04001C7E<MDad4
0006Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad4
0003Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@03Dad30002LcL00`00McEg=@08003iOol00`00
Oomoo`0nOol00`00Oomoo`0>Ool00;=oo`03001oogoo0?mooaioo`@000060180000B0180000c0P00
1U<M00<005<MDad00`000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad015<M1000
0e<M00<005<MDad015<M0P001U<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@03001C
7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000=C7@03001C
7E<M00AC7@@000AC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@030000
0e<M001C7@05Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC
7@04Dad40003Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M1000
1U<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad015<M1000
0e<M00<005<MDad015<M10000e<M00<005<MDad015<M0`001U<M00@005<MDaeC7@@000IC7@03001C
7E<M00<00003Dad005<M00EC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<00005
Dad007<gLcL00002McD8003jOol00`00Oomoo`0nOol00`00Oomoo`0>Ool00;Aoo`03001oogoo0?mo
oaioo`@000080180000B0000<`006?D000EC7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@03
0002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00Dad000020002Dad0
0`00DaeC7@04Dad40004Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M10001U<M00<005<MDad0
0`0000=C7@00Dad01E<M00<005<MDad00`000U<M00<005<MDad015<M00<005<M00000P000U<M00<0
05<MDad015<M10000e<M00<005<MDad015<M0`001E<M00<005<MDad00e<M0`001U<M00@005<MDaeC
7@@000IC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00AC
7@03001C7@000080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@<000IC7@04001C7E<M
Dad40006Dad00`00DaeC7@0300000e<M001C7@05Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad0
0`00DaeC7@030002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad30005Dad00`00DaeC7@03
Dad30006Dad01000DaeC7E<M10000e<M00D007<gLcMc=`00009g=@800006Nm@00000001OC000ngoo
00<007ooOol0?Goo00<007ooOol03Woo002eOol00`00Oomoo`3oOolMOol400000`0B000000030002
6?D00`00Dad000020003Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad30006Dad01000DaeC
7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7@00
0080009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00=C7@<000EC7@03001C7E<M00=C7@<000IC
7@04001C7E<MDad40006Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad0
0`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad30006
Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<0009C7@03001C7E<M00=C
7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@<000EC7@03001C7E<M
00=C7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M001C7@05Dad00`00DaeC7@03
0002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad40003Dad01@00DaeC7E<M
00000W<g00@007LeMcEg=@L00?eoo`03001oogoo03aoo`03001oogoo00ioo`00]Woo0P00ogoo7Woo
1@0000<4U00000000P000QSe00<005<MDad01E<M00<005<M00000P000U<M00<005<MDad015<M00<0
05<M00000P000e<M00<005<MDad00e<M100015<M00<005<MDad00e<M100015<M00<005<MDad00e<M
0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad005<M00IC7@03001C7@000080009C
7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00=C7@<0
00IC7@04001C7E<MDad40006Dad01000DaeC7E<M10001U<M00<005<MDad00`000U<M00<005<MDad0
0e<M00<005<MDad00`000U<M00<005<MDad015<M10000e<M00<005<MDad015<M100015<M00<005<M
Dad00e<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad005<M00EC7@03001C7E<M
00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000=C7@03001C7E<M
00AC7@<000EC7@04001C7E<MDad50006Dad01000DaeC7E<M10001U<M00<005<MDad00`0000=C7@00
Dad01E<M00<005<M00000g<g00<007LeMcD00P0000Ike000000005m<003nOol00`00Oomoo`0kOol0
0`00Oomoo`0>Ool00;Qoo`03001oogoo0?mooaaoo`T000<Hm@03001C7E<M00AC7@8000IC7@04001C
7E<MDad40007Dad00`00Dad0000200000e<M001C7@06Dad00`00Dad000020002Dad00`00DaeC7@04
Dad00`00Dad000020003Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad30005Dad00`00DaeC
7@04Dad20006Dad01000DaeC7E<M10001U<M00<005<MDad00`000U<M00<005<MDad015<M00<005<M
00000P000U<M00<005<MDad015<M10000e<M00<005<MDad015<M100015<M00<005<MDad00e<M0`00
1U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad005<M00EC7@03001C7E<M00<0009C7@03
001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@<000EC
7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@030002Dad00`00DaeC7@03
Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@04Dad40003Dad00`00DaeC
7@04Dad30005Dad01000DaeC7E<M10000g<g00@007LeMcEg=@<00004Lk400000003oOol00`00Oomo
o`0lOol00`00Oomoo`0=Ool00;Uoo`03001oogoo0?mooa]oo`D0000419@0000=00046?D00`00DaeC
7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@04Dad20005Dad00`00DaeC7@04Dad20006
Dad01000DaeC7E<M10001e<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000e<M
00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M100015<M00<005<MDad00e<M0`00
1U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad005<M00EC7@03001C7E<M00<0009C7@03
001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@@000AC7@03001C7E<M00=C7@<000EC
7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@030002Dad00`00DaeC7@03
Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04Dad40003
Dad00`00DaeC7@04Dad30006Dad01000DaeC7E<M10001U<M00<005<M00000P0000=C7@00Dad01U<M
00<005<MDad00`0000=C7@00Dad01E<M00<005<MDad00`000U<M00<005<MDad00e<M100015<M00@0
07<gLcL000=g=@03001ke00000800003Gd`007oo0?moo`03001oogoo03]oo`03001oogoo00eoo`00
^Woo00<007ooOol0ogoo6goo0P0000@0400019@4U0<0008Hm@@000IC7@03001C7@000080009C7@03
001C7E<M00AC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M
00=C7@@000AC7@03001C7E<M00AC7@8000IC7@04001C7E<MDad40007Dad01000DaeC7E<M10001U<M
00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000e<M00<005<MDad00e<M100015<M
00<005<MDad00e<M0`001E<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M
00<00003Dad005<M00IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03
001C7E<M00AC7@@000=C7@03001C7E<M00AC7@<000IC7@04001C7E<MDad40006Dad01000DaeC7E<M
10001U<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad015<M
10000e<M00<005<MDad015<M0P001E<M00<005<MDad015<M0`001E<M00@005<MDaeC7@D000IC7@03
001C7@0000800003Dad005<M00IC7@03001c=`00009g=@<00004Lk400000003oOol3Ool00`00Oomo
o`0jOol00`00Oomoo`0=Ool00;]oo`800?mooa]oo`D0000319@001dF00<000AC7@03001C7E<M00=C
7@8000IC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad00`00Dad000020003Dad00`00
DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@04Dad40003Dad0
0`00DaeC7@04Dad20006Dad01000DaeC7E<M10001e<M00<005<M00000P0000=C7@00Dad01U<M00<0
05<M00000P000U<M00<005<MDad015<M00<005<M00000P000e<M00<005<MDad00e<M100015<M00<0
05<MDad00e<M0`001E<M00<005<MDad015<M0P001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<0
009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC
7@@000=C7@03001C7E<M00AC7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M001C
7@05Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad4
0004Dad00`00DaeC7@04Dad20005Dad00`00DaeC7@04Dad20003McD00`00Nm@0000200000em<001o
o`3oOol3Ool00`00Oomoo`0iOol00`00Oomoo`0=Ool00;eoo`03001oogoo0?mooaUoo`8000070100
00BD19@001dF00001U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<0
05<MDad015<M100015<M00<005<MDad00e<M0P001e<M00@005<MDaeC7@@000IC7@03001C7@000080
009C7@03001C7E<M00AC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03
001C7E<M00=C7@@000AC7@03001C7E<M00AC7@8000EC7@03001C7E<M00AC7@8000IC7@04001C7E<M
Dad40007Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04
Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad30006Dad01000DaeC
7E<M10001U<M00<005<MDad00`0000=C7@00Dad01E<M00<005<MDad00`000U<M00<005<MDad00e<M
00<005<MDad00`000U<M00<005<MDad015<M10000e<M00<005<MDad015<M0`001E<M00<005<MDad0
0e<M0`001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7E<M
00<00003Dad005<M00EC7@03001C7E<M00<0009C7@03001g=GLe00H00?moo`Eoo`03001oogoo03Uo
o`03001oogoo00eoo`00_Woo00<007ooOol0ogoo67oo0P0000D0400019@4U000008M5P04001C7E<M
Dad40006Dad01000DaeC7E<M10001U<M00<005<MDad00`000U<M00<005<MDad015<M00<005<M0000
0P000U<M00<005<MDad015<M10000e<M00<005<MDad015<M0P001U<M00<005<MDad00e<M0`001U<M
00@005<MDaeC7@@000IC7@03001C7@00008000=C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03
001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00AC7@8000IC
7@04001C7E<MDad40006Dad01000DaeC7E<M1@001U<M00<005<M00000P000U<M00<005<MDad015<M
00<005<M00000P000U<M00<005<MDad015<M10000e<M00<005<MDad015<M0`001E<M00<005<MDad0
0e<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad005<M00EC7@03001C7E<M00<0
009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC
7@8000IC7@04001C7E<MDad50005Dad01000DaeC7E<M1@001U<M0P0000=ke00000000`00ogoo1Woo
00<007ooOol0>7oo00<007ooOol03Goo002oOol00`00Oomoo`3oOolHOol400000`BD000M5P027AH3
0004Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M10001U<M00<0
05<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad015<M00<005<M0000
0P000U<M00<005<MDad015<M10000e<M00<005<MDad015<M0P001e<M00@005<MDaeC7@@000IC7@04
001C7E<MDad40006Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00DaeC7@030002Dad00`00
DaeC7@03Dad40004Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M
10001U<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad015<M
00<005<M00000P000U<M00<005<MDad015<M10000e<M00<005<MDad015<M0`001E<M00@005<MDaeC
7@D000IC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M001C7@05Dad00`00DaeC7@030000
0e<M001C7@05Dad40004Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@04Dad3000016M]00000000
ogoo27oo00<007ooOol0=goo00<007ooOol03Goo0030Ool2003oOolHOol200001@0@000000BD0000
0QdF00<005<MDad01E<M00<005<M00000P000e<M00<005<MDad00e<M00<005<M00000P000e<M00<0
05<MDad00e<M100015<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@04001C7E<MDad4
0006Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad4
0003Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M1@001U<M00<0
05<M00000P0000=C7@00Dad01U<M00<005<M00000P000U<M00<005<MDad015<M00<005<MDad00`00
0U<M00<005<MDad00e<M100015<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@04001C
7E<MDad40006Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC
7@03Dad40004Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad30005Dad01000DaeC7E<M1@00
1E<M00<005<MDad00`0000=C7@00Dad01U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M
Dad0100000=c>00000000`00ogoo27oo00<007ooOol0>7oo00<007ooOol037oo0032Ool00`00Oomo
o`3oOolFOol01000010001CD0P000adF00<005<MDad015<M0P001e<M00@005<MDaeC7@<000MC7@03
001C7@000080009C7@03001C7E<M00AC7@03001C7@00008000=C7@03001C7E<M00=C7@@000AC7@03
001C7E<M00=C7@@000AC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@03
00000e<M001C7@05Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00
DaeC7@03Dad40004Dad00`00DaeC7@04Dad20005Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M
1@001U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad015<M
10000e<M00<005<MDad015<M100015<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@03
001C7@0000800003Dad005<M00IC7@03001C7E<M00<00003Dad005<M00EC7@03001C7E<M00<0009C
7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@<000EC7@03001C7E<M00AC7@8000IC7@04001C
7E<MDad50003Dad2000016M]00000000ogoo2Woo00<007ooOol0=goo00<007ooOol037oo0033Ool0
0`00Oomoo`3oOolEOol300000aCD000000047AH00`00DaeC7@030002Dad00`00DaeC7@04Dad40003
Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M10001e<M00<005<M00000P0000=C7@00Dad01U<M
00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad015<M100015<M
00<005<MDad00e<M0`001E<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@03001C7@00
008000=C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C
7@03001C7E<M00=C7@@000AC7@03001C7E<M00AC7@8000IC7@04001C7E<MDad40006Dad00`00DaeC
7@0300000e<M001C7@05Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00Dad000020002Dad0
0`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad20005Dad00`00DaeC7@04Dad30005Dad01000DaeC
7E<M1@001U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad0
15<M00<005<MDad00`0000=C7@00Dad01E<M100015<M00D005<MDad007<h00D00?moo`]oo`03001o
ogoo03Ioo`03001oogoo00aoo`00a7oo00<007ooOol0ogoo5Goo0P000QCD0P000QdF10001U<M00<0
05<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M100015<M00<0
05<MDad015<M0P001E<M00<005<MDad015<M0P001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<0
009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03
001C7E<M00AC7@@000=C7@03001C7E<M00AC7@8000MC7@04001C7E<MDad40006Dad01000DaeC7E<M
10001U<M00<005<M00000P000U<M00<005<MDad015<M00<005<MDad00`0000=C7@00Dad01E<M1000
15<M00<005<MDad00e<M0`001E<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@03001C
7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0
009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00AC7@8000IC7@04001C7E<MDad40006Dad01000
DaeC7E<M1@001E<M00<005<MDad00`000U<M00<005<MDad015<M00@005<M001c>0@00?moo`eoo`03
001oogoo03Eoo`03001oogoo00aoo`00aGoo0P00ogoo5Goo0`000QCD0`0015<M00<005<MDad00e<M
0`001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7E<M00<0
009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C
7@<000IC7@04001C7E<MDad40006Dad01000DaeC7E<M10001U<M00<005<MDad00`000U<M00<005<M
Dad00e<M00<005<MDad00`000U<M00<005<MDad015<M10000e<M00<005<MDad015<M10000e<M00<0
05<MDad015<M0P001U<M00@005<MDaeC7@D000EC7@03001C7E<M00<00003Dad005<M00IC7@03001C
7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@@000=C7@03001C
7E<M00AC7@<000IC7@04001C7E<MDad40006Dad01000DaeC7E<M10001U<M00<005<M00000P000U<M
00<005<MDad015<M00<005<MDad00`0000=C7@00Dad01E<M100015<M00<005<MDad00e<M100015<M
00<005<MDad00e<M0`001U<M00@005<MDaeC7@@00003LcP006M]00<00?moo`eoo`03001oogoo03Eo
o`03001oogoo00aoo`00agoo00<007ooOol0ogoo4goo0P000aCD00<005<MDad015<M00<005<M0000
0P000e<M00<005<MDad00e<M100015<M00<005<MDad00e<M0P001U<M00<005<MDad00e<M0`001U<M
00@005<MDaeC7@@000IC7@03001C7@00008000=C7@03001C7E<M00=C7@03001C7@00008000=C7@03
001C7E<M00=C7@@000AC7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@<000IC7@04001C7E<M
Dad40006Dad00`00DaeC7@0300000e<M001C7@05Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad0
0`00DaeC7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad30005Dad00`00DaeC7@04
Dad20006Dad01000DaeC7E<M10001U<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad0
0`000U<M00<005<MDad015<M10000e<M00<005<MDad015<M10000e<M00<005<MDad015<M0P001U<M
00@005<MDaeC7@D000EC7@03001C7E<M00<00003Dad005<M00IC7@03001C7@000080009C7@03001C
7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@@0009C7@03001c>7<h00@00?moo`moo`03
001oogoo03Aoo`03001oogoo00aoo`00b7oo00<007ooOol0ogoo4Woo0P0011CD00@005<MDaeC7@@0
00MC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@03
001C7@000080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@8000MC7@04001C7E<MDad3
0007Dad00`00Dad0000200000e<M001C7@06Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00
Dad000020002Dad00`00DaeC7@04Dad40004Dad00`00DaeC7@03Dad30005Dad00`00DaeC7@03Dad3
0006Dad01000DaeC7E<M10001U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P00
0U<M00<005<MDad015<M00<005<MDad00`000U<M00<005<MDad00e<M100015<M00<005<MDad00e<M
0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad005<M00EC7@03001C7E<M00<0009C
7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@<0
00EC7@03001C7E<M00AC7@8000IC7@04001C7E<MDad40006Dad00`00DaeC7@030002Dad02000DaeC
7E<M001c>000Ifd2003oOolAOol00`00Oomoo`0cOol00`00Oomoo`0<Ool00<Uoo`03001oogoo0?mo
oa9oo`03000De1CD008De0@000AC7@03001C7E<M00AC7@8000IC7@04001C7E<MDad40006Dad01000
DaeC7E<M10001U<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<M
Dad015<M10000e<M00<005<MDad015<M0P001E<M00<005<MDad015<M0P001U<M00@005<MDaeC7@@0
00IC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@03
001C7@000080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@8000IC7@04001C7E<MDad4
0006Dad01000DaeC7E<M1@001U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P00
0U<M00<005<MDad015<M10000e<M00<005<MDad015<M0`001E<M00<005<MDad00e<M0`001U<M00@0
05<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C
7E<M00AC7@03001C7E<M00<00003Dad005<M00EC7@@000=C7@03001C7E<M00AC7@<000IC7@03001C
7@00009c>0@00?mooa9oo`03001oogoo03=oo`03001oogoo00]oo`00bWoo0P00ogoo4Woo1@000e<M
00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M100015<M00<005<MDad00e<M1000
15<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<0009C7@03001C7E<M
00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@0
00AC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad01000DaeC7E<M10001U<M00<005<M
Dad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M100015<M00<005<M
Dad00e<M100015<M00<005<MDad015<M0P001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<0009C
7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C
7E<M00AC7@@000=C7@03001C7E<M00AC7@8000IC7@04001C7E<MDad40006Dad01000DaeC7E<M1@00
1E<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad015<M0P00
0W<h00@006M]00000?mooa=oo`03001oogoo03=oo`03001oogoo00]oo`00c7oo00<007ooOol0ogoo
47oo00<005<MDad01E<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00AC7@03
001C7@00008000=C7@03001C7E<M00=C7@03001C7@00008000=C7@03001C7E<M00=C7@@000AC7@03
001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad01000DaeC7E<M10001U<M00<005<M00000P00
0U<M00<005<MDad015<M00<005<M00000P000e<M00<005<MDad00e<M100015<M00<005<MDad00e<M
100015<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C
7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7E<M00<0009C7@03001C7E<M00=C
7@@000AC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad01000DaeC7E<M10001U<M00<0
05<MDad00`0000=C7@00Dad01E<M00<005<MDad00`0000=C7@00Dad01E<M100015<M00<005<MDad0
0e<M100015<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00004Dad0
07<hLcP200000g<g001oo`3oOolCOol00`00Oomoo`0bOol00`00Oomoo`0;Ool00<eoo`03001oogoo
0?moo`moo`8000IC7@@000=C7@03001C7E<M00AC7@8000IC7@04001C7E<MDad40007Dad01000DaeC
7E<M0`001e<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad0
15<M10000e<M00<005<MDad015<M10000e<M00<005<MDad015<M0P001U<M00@005<MDaeC7@@000MC
7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@03001C
7@000080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@8000IC7@04001C7E<MDad40006
Dad01000DaeC7E<M1@001U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M
00<005<MDad015<M10000e<M00<005<MDad015<M10000e<M00<005<MDad015<M0`001E<M00@005<M
DaeC7@D000EC7@03001C7E<M00<0009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M
00AC7@03001C7@000080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@<000EC7@05001c
>000LcL0003oOolFOol00`00Oomoo`0aOol00`00Oomoo`0;Ool00<ioo`03001oogoo0?moo`moo`80
009C7@<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000AC7@03001C
7E<M00AC7@@000=C7@03001C7E<M00AC7@8000IC7@04001C7E<MDad40006Dad00`00DaeC7@030000
0e<M001C7@05Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC
7@03Dad40004Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC
7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000AC
7@03001C7E<M00=C7@@000AC7@03001C7E<M00AC7@8000IC7@04001C7E<MDad40006Dad00`00DaeC
7@0300000e<M001C7@05Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad0
0`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M10001U<M00@005<MDaeC
7@@000IC7@03001C7E<M00<00003Dad005<M00EC7@03001C7E<M00<0009C7@03001C7E<M00=C7@<0
0003LcL007oo0?mooaEoo`03001oogoo035oo`03001oogoo00]oo`00cgoo00<007ooOol0ogoo3Woo
10001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7E<M00<0
009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C
7@<000EC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad00`00Dad000020003Dad00`00
DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad40004Dad0
0`00DaeC7@03Dad30006Dad01000DaeC7E<M10001U<M00<005<M00000P0000=C7@00Dad01U<M00<0
05<M00000P000U<M00<005<MDad015<M00<005<MDad00`0000=C7@00Dad01E<M100015<M00<005<M
Dad00e<M0`001E<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C
7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@@0
00=C7@03001C7E<M00AC7@<000EC7@04001C7E<MDad50006Dad00`00Dad0000200001E<M001c=g<g
0000ogoo5goo00<007ooOol0<7oo00<007ooOol02goo003@Ool2003oOol?Ool200000adF001C7@04
Dad40004Dad00`00DaeC7@03Dad20006Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M10001U<M
00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad015<M00<005<M
00000P000U<M00<005<MDad015<M100015<M00<005<MDad00e<M0P001e<M00@005<MDaeC7@@000IC
7@03001C7@0000800003Dad005<M00IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@00
0080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@8000EC7@03001C7E<M00AC7@8000IC
7@04001C7E<MDad50005Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00Dad000020002Dad0
0`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad20006
Dad01000DaeC7E<M10001U<M00<005<MDad00`0000=C7@00Dad01E<M00<005<MDad00`000U<M00<0
05<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M100015<M00<005<MDad015<M0P000e<M
00@007<gLcL00?mooaUoo`03001oogoo02moo`03001oogoo00]oo`00dWoo00<007ooOol0ogoo37oo
0P000QdF00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad015<M
00<005<M00000P000U<M00<005<MDad015<M10000e<M00<005<MDad015<M0P001U<M00@005<MDaeC
7@@000IC7@04001C7E<MDad40006Dad00`00DaeC7@030002Dad00`00DaeC7@04Dad00`00Dad00002
0002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad20005Dad00`00DaeC7@04Dad20006Dad0
1000DaeC7E<M10001U<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<0
05<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M100015<M00<005<MDad00e<M0`001U<M
00@005<MDaeC7@@000IC7@04001C7E<MDad40006Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad0
0`00DaeC7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad30005Dad00`00DaeC7@03
Dad30006Dad01000DaeC7E<M10001U<M00<005<M00000P000U<M00<005<MDad015<M00<005<MDad0
0`0000=C7@00Dad00U<M00@007<gLcL00?mooaYoo`03001oogoo02ioo`03001oogoo00]oo`00dgoo
00<007ooOol0ogoo37oo00D001dF7AHM5P0000IC7@04001C7E<MDad40006Dad01000DaeC7E<M1000
1U<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M1000
15<M00<005<MDad00e<M100015<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@03001C
7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0
009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad01000
DaeC7E<M10001U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<M
Dad015<M10000e<M00<005<MDad015<M10000e<M00<005<MDad015<M0`001U<M00@005<MDaeC7@@0
00IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@03
001C7@000080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@8000IC7@04001C7E<MDad5
0005Dad00`00Dad00003LcL00`00Oomoo`3oOolHOol00`00Oomoo`0_Ool00`00Oomoo`0:Ool00=Ao
o`03001oogoo0?moo`]oo`8000<M5P03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@@000AC7@03
001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad00`00Dad000020003Dad00`00DaeC7@03Dad0
0`00Dad000020003Dad00`00DaeC7@03Dad00`00Dad000020003Dad00`00DaeC7@03Dad40004Dad0
0`00DaeC7@03Dad30006Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7@000080
009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC
7@@000=C7@03001C7E<M00AC7@8000IC7@04001C7E<MDad40006Dad00`00DaeC7@030002Dad00`00
DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@04
Dad40003Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03
001C7E<M00<00003Dad005<M00EC7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000AC7@03001C
7E<M00=C7@8000=c=`03001oogoo0?mooaYoo`03001oogoo02ioo`03001oogoo00Yoo`00eGoo0P00
ogoo2goo0P0011dF00<005<M00000P000e<M00<005<MDad00e<M00<005<M00000P000e<M00<005<M
Dad00e<M00<005<M00000P000e<M00<005<MDad00e<M100015<M00<005<MDad00e<M0P001e<M00@0
05<MDaeC7@<000MC7@04001C7E<MDad30007Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00
Dad000020002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad2
0006Dad01000DaeC7E<M10001U<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`00
0U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M100015<M00<005<MDad00e<M
0`001U<M00@005<MDaeC7@@000IC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M001C7@05
Dad00`00DaeC7@0300000e<M001C7@05Dad40003Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04
Dad30005Dad01000DaeC7E<M1@001U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M0000
0P000U<M00@007<gLcL00?mooaeoo`03001oogoo02eoo`03001oogoo00Yoo`00egoo00<007ooOol0
ogoo2Goo00<001dF7AH00QdF0P001e<M00@005<MDaeC7@<000MC7@04001C7E<MDad30007Dad00`00
Dad000020002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04Dad40003Dad00`00
DaeC7@04Dad40003Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M10001U<M00<005<MDad00`00
0U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<0
05<MDad00e<M100015<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@04001C7E<MDad4
0006Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04Dad4
0003Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad30005Dad01000DaeC7E<M1@001E<M00<0
05<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad0
0`000U<M00<005<MDad00e<M100015<M00<005<MDad015<M0P001U<M00@005<MDaeC7@@000IC7@03
001c=`000?mooaioo`03001oogoo02aoo`03001oogoo00Yoo`00f7oo00<007ooOol0ogoo27oo1@00
0U<M00<005<MDad015<M10000e<M00<005<MDad015<M10000e<M00<005<MDad015<M0P001U<M00@0
05<MDaeC7@@000IC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C
7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@<000IC7@04
001C7E<MDad40006Dad01000DaeC7E<M10001U<M00<005<M00000P000U<M00<005<MDad015<M00<0
05<M00000P000U<M00<005<MDad015<M10000e<M00<005<MDad015<M10000e<M00<005<MDad015<M
0P001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0
009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C
7@<000IC7@04001C7E<MDad40006Dad01000DaeC7E<M10001U<M00<005<M00000P000U<M00<005<M
Dad015<M00<005<MDad00`0000=C7@00Dad01E<M10000e<M00<005<MDad015<M0P00ogoo7goo00<0
07ooOol0;7oo00<007ooOol02Woo003IOol00`00Oomoo`3oOol8Ool00`00DaeC7@04Dad00`00DaeC
7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002
Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M10001U<M00@005<M
DaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M
00AC7@@000=C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@8000IC7@04001C7E<MDad40006
Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00
DaeC7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M1000
1U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C
7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@8000IC7@04001C
7E<MDad50005Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@04003oOolQOol00`00
Oomoo`0[Ool00`00Oomoo`0:Ool00=Yoo`800?moo`Uoo`03001C7E<M00=C7@<000IC7@04001C7E<M
Dad40006Dad01000DaeC7E<M10001U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M0000
0P000U<M00<005<MDad015<M10000e<M00<005<MDad015<M10000e<M00<005<MDad015<M0P001U<M
00@005<MDaeC7@@000IC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03
001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@<000IC
7@04001C7E<MDad40006Dad01000DaeC7E<M10001U<M00<005<M00000P000U<M00<005<MDad015<M
00<005<M00000P000U<M00<005<MDad015<M10000e<M00<005<MDad015<M10000e<M00<005<MDad0
15<M0P001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M
00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000AC7@03001C7E<M
00=C7@<000IC7@04001C7E<MDad40003Dad00`00Oomoo`3oOolPOol00`00Oomoo`0ZOol00`00Oomo
o`0:Ool00=aoo`03001oogoo0?moo`Ioo`800004Dad000000003Dad00`00DaeC7@03Dad40004Dad0
0`00DaeC7@03Dad40003Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M10001U<M00<005<MDad0
0`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M
00<005<MDad00e<M100015<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@04001C7E<M
Dad40006Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04
Dad40003Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M10001U<M
00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<M
Dad00`000U<M00<005<MDad00e<M100015<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC
7@04001C7E<MDad40006Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00Dad000020002Dad0
0`00DaeC7@04Dad40003Dad01000DaeC7@00ogoo8goo00<007ooOol0:goo00<007ooOol02Goo003M
Ool00`00Oomoo`3oOol6Ool20007Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00Dad00002
0002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03
Dad30006Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C
7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@@000=C7@03
001C7E<M00AC7@8000IC7@04001C7E<MDad40006Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad0
0`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40004Dad0
0`00DaeC7@03Dad30006Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7@000080
009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC
7@@000=C7@03001C7E<M00AC7@8000IC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M001C
7@05Dad00`00Dad0003oOolTOol00`00Oomoo`0ZOol00`00Oomoo`09Ool00=ioo`03001oogoo0?mo
o`Eoo`03000M5P0000IC7@8000IC7@04001C7E<MDad40006Dad01000DaeC7E<M10001U<M00<005<M
00000P000e<M00<005<MDad00e<M00<005<M00000P000e<M00<005<MDad00e<M100015<M00<005<M
Dad00e<M10000e<M00<005<MDad015<M0P001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<0009C
7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C
7E<M00=C7@@000AC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad01000DaeC7E<M1000
1U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad015<M1000
0e<M00<005<MDad015<M10000e<M00<005<MDad015<M0P001U<M00@005<MDaeC7@@000IC7@03001C
7E<M00<00003Dad005<M00EC7@03001C7E<M00<00003Dad005<M00EC7@03001C7E<M00<00003Dad0
05<M00EC7@@000=C7@03001C7E<M00AC7@<000EC7@04001C7E<MDad4003oOolVOol00`00Oomoo`0Y
Ool00`00Oomoo`09Ool00=moo`800?moo`Eoo`04000M5QdF0002Dad30002Dad00`00DaeC7@03Dad4
0004Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad20007Dad01000DaeC7E<M0`001e<M00<0
05<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad00e<M00<005<MDad0
0`000U<M00<005<MDad00e<M100015<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@04
001C7E<MDad40006Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00
DaeC7@04Dad40003Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M
10001U<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`0000=C7@00Dad01E<M00<0
05<MDad00`0000=C7@00Dad01E<M10000e<M00<005<MDad015<M0`001E<M00@005<MDaeC7@D000EC
7@04001C7E<MDad50005Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad0
0`00DaeC7@03Dad40002Dad00`00Oomoo`3oOolVOol00`00Oomoo`0XOol00`00Oomoo`09Ool00>5o
o`03001oogoo0?moo`=oo`03000M5QdF008000IC7@03001C7@000080009C7@03001C7E<M00AC7@03
001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@@000=C7@03
001C7E<M00AC7@8000IC7@04001C7E<MDad40006Dad01000DaeC7E<M10001U<M00<005<M00000P00
0e<M00<005<MDad00e<M00<005<M00000P000U<M00<005<MDad015<M10000e<M00<005<MDad015<M
10000e<M00<005<MDad015<M0P001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<0009C7@03001C
7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C
7@@000AC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40005Dad01000DaeC7E<M1@001E<M00<0
05<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M100015<M00<0
05<MDad00e<M100015<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@03001C7@000080
009C7@04001C7E<M003oOolYOol00`00Oomoo`0XOol00`00Oomoo`09Ool00>9oo`03001oogoo0?mo
o`9oo`05000M5QdF7AH00006Dad20006Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03
001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000AC7@03
001C7E<M00=C7@@000AC7@03001C7E<M00=C7@8000MC7@04001C7E<MDad30006Dad00`00DaeC7@03
0002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad0
0`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M10001U<M00@005<MDaeC
7@@000IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC
7@@000=C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad0
0`00Dad000020002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00Dad0
00020002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad20006Dad00`00Dad0003oOolZOol0
0`00Oomoo`0WOol00`00Oomoo`09Ool00>=oo`03001oogoo0?moo`5oo`03000M5QdF008M5P03001C
7E<M00<0009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@<0
00IC7@04001C7E<MDad40006Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00Dad000020002
Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@03Dad3
0006Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M
00AC7@03001C7@000080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@@000=C7@03001C
7E<M00AC7@8000IC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M001C7@05Dad00`00Dad0
00020002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04Dad40003Dad00`00DaeC
7@04Dad20006Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad0
05<M00EC7@03001C7E<M00<00003Dad005<M00EC7@800?moobaoo`03001oogoo02Ioo`03001oogoo
00Uoo`00i7oo0P00ogoo0Woo00<001dF7AH010001U<M00<005<M00000P000e<M00<005<MDad00e<M
00<005<M00000P000e<M00<005<MDad00e<M00<005<M00000P000U<M00<005<MDad015<M10000e<M
00<005<MDad015<M0P001U<M00@005<MDaeC7@@000IC7@04001C7E<MDad40006Dad00`00DaeC7@03
0002Dad00`00DaeC7@03Dad00`00Dad000020003Dad00`00DaeC7@03Dad40003Dad00`00DaeC7@04
Dad40003Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M10001U<M00<005<MDad00`000U<M00<0
05<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`0000=C7@00Dad01E<M
10000e<M00<005<MDad015<M0`001E<M00@005<MDaeC7@@000IC7@04001C7E<MDad40006Dad00`00
DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40003Dad00`00
DaeC7@04Dad40003Dad00`00DaeC7@04Dad30005Dad01000DaeC7E<M1@001E<M00<005<MDad01000
ogoo;Woo00<007ooOol09Woo00<007ooOol027oo003VOol00`00Oomoo`3nOol30004Dad00`00DaeC
7@03Dad20007Dad01000DaeC7E<M0`001e<M00@005<MDaeC7@<000IC7@03001C7E<M00<0009C7@03
001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@@000AC
7@03001C7E<M00=C7@<000IC7@04001C7E<MDad30007Dad00`00Dad000020002Dad00`00DaeC7@03
Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40004
Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000EC7@03001C7E<M
00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000AC7@03001C7E<M
00=C7@@000AC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad00`00Dad000020002Dad0
0`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC
7@03Dad40004Dad00`00DaeC7@03Dad30003Dad00`00Oomoo`3oOol/Ool00`00Oomoo`0VOol00`00
Oomoo`08Ool00>Moo`03001oogoo0?ioo`03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M
00AC7@@000=C7@03001C7E<M00AC7@@000=C7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006
Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00
Dad000020002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M1000
1U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C
7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC7@@000=C7@03001C7E<M00=C7@<000IC7@04001C
7E<MDad40006Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC
7@04Dad00`00Dad000020002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad20006Dad01000
DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C
7@000080009C7@04001C7E<M003oOol`Ool00`00Oomoo`0UOol00`00Oomoo`08Ool00>Qoo`03001o
ogoo0?ioo`04001C7E<MDad40006Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@03
0002Dad00`00DaeC7@03Dad00`00Dad000020003Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03
Dad20006Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<0009C7@03001C
7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000=C7@03001C7E<M00AC7@@000=C7@03
001C7E<M00AC7@8000IC7@04001C7E<MDad40006Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad0
0`00DaeC7@0300000e<M001C7@05Dad00`00Dad000020002Dad00`00DaeC7@04Dad40003Dad00`00
DaeC7@04Dad20006Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003
Dad005<M00EC7@03001C7E<M00<00003Dad005<M00EC7@@000=C7@03001C7E<M00AC7@@000=C7@03
001C7E<M00AC7@8000IC7@04001C7E<MDad40006Dad00`00Dad0003oOolaOol00`00Oomoo`0TOol0
0`00Oomoo`08Ool00>Uoo`03001oogoo0?ioo`<000AC7@03001C7E<M00=C7@<000IC7@04001C7E<M
Dad40006Dad01000DaeC7E<M0`001e<M00<005<M00000P000U<M00<005<MDad015<M00<005<M0000
0P000U<M00<005<MDad00e<M100015<M00<005<MDad00e<M100015<M00<005<MDad00e<M0`001U<M
00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03
001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@<000IC
7@04001C7E<MDad40005Dad01000DaeC7E<M10001U<M00<005<MDad00`000U<M00<005<MDad00e<M
00<005<MDad00`000U<M00<005<MDad00e<M100015<M00<005<MDad00e<M100015<M00<005<MDad0
0e<M0`001E<M00@005<MDaeC7@D000EC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M
00<0009C7@03001C7E<M00=C7@03001C7E<M00<00003Dad005<M00EC7@@000=C7@03001C7E<M00AC
7@800?mooc9oo`03001oogoo02Aoo`03001oogoo00Qoo`00jWoo0P00ogoo0Goo00<005<MDad00e<M
00<005<M00000P000e<M00<005<MDad00e<M10000e<M00<005<MDad015<M10000e<M00<005<MDad0
15<M0P001U<M00@005<MDaeC7@@000IC7@03001C7@00008000=C7@03001C7E<M00=C7@03001C7@00
0080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M
00AC7@8000IC7@04001C7E<MDad40006Dad01000DaeC7E<M10001U<M00<005<M00000P000U<M00<0
05<MDad015<M00<005<M00000P000U<M00<005<MDad015<M10000e<M00<005<MDad00e<M100015<M
00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00AC
7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00=C7@@000AC
7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad01000DaeC7E<M10001E<M00<005<MDad0
0`000U<M00<005<MDad00e<M00<005<MDad01000ogoo=7oo00<007ooOol08goo00<007ooOol027oo
003/Ool00`00Oomoo`3nOol01000DaeC7E<M0`001e<M00<005<M00000P000U<M00<005<MDad00e<M
00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M100015<M
00<005<MDad00e<M0P001e<M00@005<MDaeC7@<000IC7@04001C7E<MDad40006Dad00`00DaeC7@03
0002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40003Dad00`00DaeC7@04
Dad40003Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M10001U<M00<005<MDad00`000U<M00<0
05<MDad00e<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad0
15<M10000e<M00<005<MDad015<M0P001U<M00@005<MDaeC7@@000IC7@04001C7E<MDad40006Dad0
0`00Dad000020002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04Dad40003Dad0
0`00DaeC7@04Dad40003Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M10000e<M00<007ooOol0
ogoo<goo00<007ooOol08Woo00<007ooOol027oo003]Ool00`00Oomoo`3nOol30003Dad00`00DaeC
7@04Dad20006Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03
001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00=C7@@000AC
7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad00`00Dad000020002Dad00`00DaeC7@03
Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40004
Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M
00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000=C7@03001C7E<M
00AC7@@000=C7@03001C7E<M00AC7@8000IC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M
001C7@05Dad00`00DaeC7@0300000e<M001C7@05Dad00`00Dad000020002Dad00`00DaeC7@04Dad4
0003Dad01000DaeC7@00ogoo=goo00<007ooOol08Goo00<007ooOol027oo003^Ool00`00Oomoo`3n
Ool00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad4
0003Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M10001U<M00<005<MDad00`000U<M00<005<M
Dad00e<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad015<M
10000e<M00<005<MDad015<M0P001U<M00@005<MDaeC7@@000IC7@04001C7E<MDad40006Dad00`00
Dad000020002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04Dad40003Dad00`00
DaeC7@03Dad40004Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M10001U<M00<005<M00000P00
0U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<0
05<MDad00e<M100015<M00<005<MDad00e<M0`001E<M00@005<MDaeC7@D000EC7@04001C7E<MDad4
0006Dad00`00DaeC7@0300000e<M001C7@05Dad00`00Dad0003oOolgOol00`00Oomoo`0ROol00`00
Oomoo`07Ool00>moo`800?moo`04001C7E<MDad40006Dad00`00Dad000020002Dad00`00DaeC7@04
Dad00`00Dad000020002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40004
Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M
00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000=C7@03001C7E<M
00AC7@@000=C7@03001C7E<M00AC7@8000IC7@04001C7E<MDad40006Dad00`00DaeC7@0300000e<M
001C7@05Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@04
Dad40003Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03
001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00=C7@@000AC7@03
001C7E<M00=C7@@000AC7@03001C7E<M00=C7@<000EC7@04001C7E<MDad4003oOoliOol00`00Oomo
o`0QOol00`00Oomoo`07Ool00?5oo`03001oogoo0?eoo`<000=C7@03001C7E<M00AC7@8000IC7@04
001C7E<MDad40006Dad01000DaeC7E<M10001U<M00<005<M00000P000U<M00<005<MDad015<M00<0
05<M00000P000U<M00<005<MDad015<M10000e<M00<005<MDad00e<M100015<M00<005<MDad00e<M
0`001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00=C7@03001C7E<M00<0
009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C
7@<000EC7@04001C7E<MDad40006Dad01000DaeC7E<M1@001E<M00<005<MDad00`000U<M00<005<M
Dad00e<M00<005<MDad00`0000=C7@00Dad01E<M10000e<M00<005<MDad015<M10000e<M00<005<M
Dad015<M0P001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C
7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00=C7@@0009C7@03001o
ogoo0?moocUoo`03001oogoo021oo`03001oogoo00Moo`00lWoo00<007ooOol0oGoo00<005<MDad0
0e<M00<005<MDad00`000U<M00<005<MDad00e<M100015<M00<005<MDad00e<M100015<M0P000e<M
0`001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7@000080
00=C7@03001C7E<M00=C7@03001C7@000080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00AC
7@8000IC7@04001C7E<MDad40006Dad01000DaeC7E<M10001U<M00<005<M00000P000U<M00<005<M
Dad015<M00<005<M00000P000U<M00<005<MDad00e<M100015<M00<005<MDad00e<M10001E<M00@0
05<MDaeC7@@000IC7@04001C7E<MDad40005Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00
DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@0300000e<M001C7@05Dad40003Dad00`00DaeC
7@04Dad20006Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@04
001C7E<M003oOolmOol00`00Oomoo`0OOol00`00Oomoo`07Ool00?=oo`03001oogoo0?eoo`04001C
7E<MDad40006Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC
7@04Dad40003Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M0`00
1e<M00@005<MDaeC7@@000EC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0009C
7@03001C7E<M00=C7@@000=C7@03001C7E<M00AC7@@000AC7@04001C7E<MDad40006Dad01000DaeC
7E<M10001U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad0
15<M10000e<M00<005<MDad015<M10000e<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC
7@04001C7E<MDad40005Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad0
0`00DaeC7@03Dad40003Dad00`00DaeC7@04Dad40004Dad01000DaeC7E<M10001U<M00<005<M0000
ogoo?Goo00<007ooOol07goo00<007ooOol01goo003dOol2003nOol30004Dad00`00DaeC7@03Dad2
0006Dad01000DaeC7E<M10001U<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<M00000P00
0e<M00<005<MDad00e<M00<005<M00000P000U<M00<005<MDad015<M10000e<M00<005<MDad015<M
100015<M00@005<MDaeC7@@000IC7@04001C7E<MDad40006Dad00`00Dad000020002Dad00`00DaeC
7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad40004Dad00`00
DaeC7@03Dad20006Dad01000DaeC7E<M10001U<M00<005<MDad00`000U<M00<005<MDad00e<M00<0
05<MDad00`0000=C7@00Dad01E<M00<005<M00000P000U<M00<005<MDad015<M10000e<M00<005<M
Dad015<M100015<M00@005<MDaeC7@@000IC7@04001C7E<MDad40006Dad00`00Dad000020002Dad0
0`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad2003o
OoloOol00`00Oomoo`0NOol00`00Oomoo`07Ool00?Ioo`03001oogoo0?aoo`03001C7E<M00AC7@03
001C7@000080009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad3
0007Dad01000DaeC7E<M0`001U<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<MDad00`00
0U<M00<005<MDad00e<M10000e<M00<005<MDad015<M10000e<M00<005<MDad015<M0P001U<M00@0
05<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C
7E<M00AC7@03001C7@000080009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@<000IC7@04
001C7E<MDad40005Dad01000DaeC7E<M10001U<M00<005<MDad00`000U<M00<005<MDad00e<M00<0
05<MDad00`0000=C7@00Dad01E<M10000e<M00<005<MDad015<M10000e<M00<005<MDad015<M0P00
1U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@0000<00?mo
od5oo`03001oogoo01eoo`03001oogoo00Moo`00mgoo00<007ooOol0o7oo00@005<MDaeC7@@000IC
7@03001C7@00008000=C7@03001C7E<M00=C7@03001C7@000080009C7@03001C7E<M00AC7@@000=C
7@03001C7E<M00AC7@@000=C7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40006Dad00`00Dad0
00020002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002
Dad00`00DaeC7@03Dad40003Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M10001U<M00@005<M
DaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M
00AC7@@000=C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40005
Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00
DaeC7@0300000e<M001C7@05Dad40003Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M10000e<M
00<007ooOol0ogoo?goo00<007ooOol07Woo00<007ooOol01Woo003hOol00`00Oomoo`3kOol40004
Dad00`00DaeC7@03Dad20007Dad01000DaeC7E<M0`001U<M00<005<MDad00`000U<M00<005<MDad0
0e<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<M00000P000U<M00<005<MDad015<M1000
0e<M00<005<MDad015<M0P001U<M00@005<MDaeC7@@000IC7@04001C7E<MDad40006Dad00`00Dad0
00020002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40004Dad00`00DaeC
7@03Dad40003Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M10001U<M00<005<MDad00`0000=C
7@00Dad01E<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad0
15<M10000e<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000IC7@04001C7E<MDad40005Dad0
0`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@0300000e<M001C7@05Dad40003Dad01000
DaeC7@00ogoo@goo00<007ooOol07Goo00<007ooOol01Woo003iOol2003lOol00`007AH00005Dad0
0`00Dad000020002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M
10001U<M00@005<MDaeC7@@000EC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<0
009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@@000AC7@04001C7E<MDad40006Dad01000
DaeC7E<M10001U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<M
Dad00e<M00<005<MDad00`000U<M00<005<MDad00e<M100015<M00<005<MDad00e<M0`001E<M00@0
05<MDaeC7@@000IC7@04001C7E<MDad50005Dad00`00DaeC7@0300000e<M001C7@05Dad00`00Dad0
00020002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad40004Dad01000DaeC7E<M10001U<M
00@005<MDaeC7@@000EC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7@000?moodAoo`03
001oogoo01aoo`03001oogoo00Ioo`00ngoo00<007ooOol0nGoo00@001dF7AH000=C7@@000EC7@03
001C7E<M00<0009C7@03001C7E<M00=C7@03001C7@00008000=C7@03001C7E<M00=C7@@000=C7@03
001C7E<M00AC7@@000AC7@04001C7E<MDad40006Dad01000DaeC7E<M10001U<M00<005<M00000P00
0U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad00e<M100015<M00<005<MDad00e<M
10000e<M00<005<MDad015<M0P001U<M00@005<MDaeC7@@000IC7@04001C7E<MDad40006Dad00`00
Dad000020002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@03Dad40004Dad00`00
DaeC7@03Dad40005Dad01000DaeC7E<M10001E<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003
Dad005<M00EC7@03001C7E<M00<00003Dad005<M00EC7@@000=C7@03001C7E<M00AC7@@000=C7@03
001C7E<M00=C7@<000IC7@04001C7E<MDad3003oOom6Ool00`00Oomoo`0KOol00`00Oomoo`06Ool0
0?aoo`03001oogoo0?Qoo`04000M5QdF7AH30004Dad01000DaeC7E<M10001U<M00@005<MDaeC7@<0
00MC7@03001C7@000080009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@0
00AC7@03001C7E<M00=C7@@000=C7@03001C7E<M00AC7@8000IC7@04001C7E<MDad40006Dad00`00
Dad000020002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@03Dad00`00DaeC7@03
0002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad40004Dad01000DaeC7E<M10001U<M00@0
05<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C
7E<M00AC7@@000=C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@<000EC7@04001C7E<MDad5
0005Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00DaeC7@0300000e<M001C7@05Dad00`00
Dad000020002Dad00`00DaeC7@04Dad4003oOom9Ool00`00Oomoo`0KOol00`00Oomoo`06Ool00?eo
o`03001oogoo0?Qoo`05000M5QdF7AH00005Dad40004Dad00`00DaeC7@03Dad40003Dad00`00DaeC
7@04Dad20006Dad01000DaeC7E<M10001U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M
00000P000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M100015<M00<005<M
Dad00e<M0P001U<M00@005<MDaeC7@@000IC7@04001C7E<MDad40006Dad00`00Dad000020002Dad0
0`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad40004
Dad00`00DaeC7@03Dad20006Dad01000DaeC7E<M10001U<M00<005<MDad00`0000=C7@00Dad01E<M
00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad00e<M100015<M
00<005<MDad00e<M0`001U<M00@005<MDaeC7@@000EC7@04001C7E<MDad40006Dad00`00DaeC7@04
003oOom=Ool00`00Oomoo`0JOol00`00Oomoo`06Ool00?ioo`800?Qoo`03000M5QdF008M5P03001C
7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00=C7@03001C7E<M00<0
009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@8000IC7@04001C7E<MDad40006Dad01000
DaeC7E<M10001U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<M
Dad00e<M100015<M00<005<MDad00e<M10000e<M00<005<MDad015<M0P001U<M00@005<MDaeC7@@0
00IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00AC7@03
001C7@000080009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@<000EC7@04001C7E<MDad4
0006Dad01000DaeC7E<M10001U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P00
0U<M00<005<MDad015<M10000e<M00<005<MDad00e<M100015<M00<005<MDad00e<M0`000e<M00<0
07ooOol0ogooC7oo00<007ooOol06Goo00<007ooOol01Woo003oOol1Ool00`00Oomoo`3eOol00`00
7AHM5P027AH20006Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C
7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@@0
00AC7@04001C7E<MDad40006Dad01000DaeC7E<M10001U<M00<005<M00000P000U<M00<005<MDad0
15<M00<005<M00000P000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M1000
15<M00<005<MDad00e<M0P001U<M00@005<MDaeC7@@000IC7@04001C7E<MDad40006Dad00`00Dad0
00020002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@03Dad40004Dad00`00DaeC
7@03Dad40004Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7E<M00<00003Dad0
05<M00EC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@04001C7E<M003o
Oom@Ool00`00Oomoo`0IOol00`00Oomoo`05Ool00?moo`9oo`03001oogoo0?Eoo`@0009oo`03001C
7E<M00=C7@@000AC7@03001C7E<M00=C7@@000AC7@04001C7E<MDad40006Dad01000DaeC7E<M1000
1U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad00e<M1000
15<M00<005<MDad00e<M100015<M00<005<MDad00e<M0P001U<M00@005<MDaeC7@@000IC7@04001C
7E<MDad40006Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC
7@03Dad40004Dad00`00DaeC7@03Dad40004Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC
7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00=C7@@000AC
7@03001C7E<M00=C7@@000=C7@03001C7E<M00AC7@<000EC7@04001C7E<MDad40006Dad01000DaeC
7E<M10001U<M00<005<M0000ogooD7oo00<007ooOol06Goo00<007ooOol01Goo003oOol3Ool00`00
Oomoo`3dOol00`00Oomoo`04Ool00`00Dad000020002Dad00`00DaeC7@04Dad00`00Dad000020002
Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad20006Dad01000
DaeC7E<M10001U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<M
Dad015<M00<005<M00000P000U<M00<005<MDad00e<M100015<M00<005<MDad00e<M100015<M00@0
05<MDaeC7@@000IC7@04001C7E<MDad40006Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00
Dad000020002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad40003Dad00`00DaeC7@04Dad2
0006Dad01000DaeC7E<M10001U<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P00
0U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M10000e<M00<005<MDad015<M
100015<M00@005<MDaeC7@@00?mooe9oo`03001oogoo01Qoo`03001oogoo00Eoo`00ogoo17oo00<0
07ooOol0ngoo00<005<MDad015<M00@005<MDaeC7@@000IC7@03001C7@00008000=C7@03001C7E<M
00=C7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00=C7@@0
00AC7@03001C7E<M00=C7@8000IC7@04001C7E<MDad40006Dad01000DaeC7E<M1@001E<M00<005<M
00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad00e<M100015<M00<005<M
Dad00e<M10000e<M00<005<MDad015<M0P001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C
7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C
7E<M00=C7@@000=C7@03001C7E<M00AC7@8000IC7@04001C7E<MDad40006Dad01000DaeC7E<M1000
1U<M00<005<M00000P000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M1000
ogooEgoo00<007ooOol05goo00<007ooOol01Goo003oOol5Ool2003lOol00`00DaeC7@03Dad40004
Dad00`00DaeC7@03Dad20007Dad01000DaeC7E<M0`001U<M00@005<MDaeC7@D000EC7@03001C7@00
0080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00=C7@@000AC7@03001C7E<M
00=C7@@000EC7@04001C7E<MDad30006Dad01000DaeC7E<M10001U<M00<005<M00000P000U<M00<0
05<MDad015<M00<005<M00000P000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad0
0e<M100015<M00<005<MDad00e<M0P001U<M00@005<MDaeC7@@000IC7@04001C7E<MDad40006Dad0
0`00Dad000020002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad40003Dad0
0`00DaeC7@04Dad40004Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7@000080
0003Dad007oo0?mooeQoo`03001oogoo01Moo`03001oogoo00Eoo`00ogoo1goo00<007ooOol0nWoo
00<005<M00000P000e<M00<005<MDad00e<M00<005<M00000P000U<M00<005<MDad015<M10000e<M
00<005<MDad00e<M10001E<M00@005<MDaeC7@<000IC7@04001C7E<MDad40006Dad00`00Dad00002
0003Dad00`00DaeC7@03Dad00`00Dad000020002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@03
Dad40004Dad00`00DaeC7@03Dad20006Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03
001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00=C7@@000AC7@03
001C7E<M00=C7@@000AC7@04001C7E<MDad40006Dad01000DaeC7E<M10001U<M00<005<M00000P00
0U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M10000e<M00<005<MDad015<M
10000e<M00<005<MDad015<M0P0015<M00<007ooOol0ogooF7oo00<007ooOol05Woo00<007ooOol0
1Goo003oOol8Ool00`00Oomoo`3jOol00`00DaeC7@05Dad01000DaeC7E<M0`001U<M00<005<MDad0
0`000U<M00<005<MDad00e<M00<005<M00000P000U<M00<005<MDad015<M10000e<M00<005<MDad0
0e<M100015<M00<005<MDad00e<M0P001e<M00@005<MDaeC7@<000IC7@03001C7E<M00<0009C7@03
001C7E<M00=C7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M
00=C7@@000AC7@03001C7E<M00=C7@@000AC7@04001C7E<MDad40006Dad01000DaeC7E<M10001U<M
00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad00e<M100015<M
00<005<MDad00e<M10000e<M00<005<MDad015<M0P001U<M00@005<MDaeC7@@000IC7@03001C7@00
0080009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<00003
Dad005<M009C7@03001oogoo0?mooeYoo`03001oogoo01Eoo`03001oogoo00Eoo`00ogoo2Goo00<0
07ooOol0nWoo00<005<MDad015<M10000e<M00<005<MDad00e<M0`001U<M00@005<MDaeC7@<000IC
7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7@000080009C7@03001C7E<M00AC7@03001C
7@000080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00=C7@<000IC7@04001C7E<MDad30006
Dad01000DaeC7E<M1@001E<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M
00<005<MDad00e<M100015<M00<005<MDad00e<M10000e<M00<005<MDad015<M0P001U<M00@005<M
DaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M
00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000=C7@03001C7E<M00AC7@8000IC7@04001C
7E<MDad40006Dad01000DaeC7E<M10001E<M00<005<M0000ogooGWoo00<007ooOol057oo00<007oo
Ool01Goo003oOol:Ool2003kOol00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00Dad000020002
Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M0`001U<M00@005<M
DaeC7@D000EC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7@000080009C7@03001C7E<M
00AC7@@000=C7@03001C7E<M00=C7@@000EC7@04001C7E<MDad30006Dad01000DaeC7E<M10001U<M
00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad00e<M00<005<M
Dad00`000U<M00<005<MDad00e<M10000e<M00<005<MDad015<M0P001U<M00@005<MDaeC7@@000IC
7@04001C7E<MDad40006Dad00`00Dad000020002Dad00`00DaeC7@03Dad00`00DaeC7@0300000e<M
001C7@05Dad40003Dad00`00DaeC7@04Dad40004Dad01000DaeC7E<M0`00ogooGgoo00<007ooOol0
5Goo00<007ooOol017oo003oOol<Ool00`00Oomoo`3iOol20006Dad01000DaeC7E<M10001E<M00<0
05<MDad00`000U<M00<005<MDad00e<M00<005<M00000P000e<M00<005<MDad00e<M10000e<M00<0
05<MDad00e<M10001E<M00@005<MDaeC7@@000IC7@04001C7E<MDad30006Dad00`00DaeC7@030002
Dad00`00DaeC7@03Dad00`00Dad000020002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@03Dad4
0004Dad00`00DaeC7@03Dad20006Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03001C
7@000080009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000=C7@03001C
7E<M00AC7@@000AC7@04001C7E<MDad40006Dad01000DaeC7E<M10001E<M00<005<MDad00`000U<M
00<005<MDad00e<M00<005<MDad00`0000=C7@00Dad01E<M10000U<M00<007ooOol0ogooGWoo00<0
07ooOol057oo00<007ooOol017oo003oOol=Ool00`00Oomoo`3jOol00`00DaeC7@03Dad40004Dad0
1000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00=C7@03
001C7@00008000=C7@03001C7E<M00=C7@@000=C7@03001C7E<M00AC7@@000=C7@03001C7E<M00=C
7@<000IC7@04001C7E<MDad30006Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00Dad00002
0002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03
Dad40004Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C
7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000=C7@03001C7E<M00AC7@@000=C7@03
001C7E<M00=C7@<000IC7@04001C7E<MDad40005Dad00`00DaeC7@030002Dad01000DaeC7@00ogoo
HWoo00<007ooOol04goo00<007ooOol017oo003oOol>Ool00`00Oomoo`3jOol00`00Dad000020002
Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad40004Dad01000DaeC7E<M10001U<M00@005<M
DaeC7@<000MC7@03001C7@000080009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M
00=C7@03001C7@000080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00=C7@<000IC7@04001C
7E<MDad30006Dad01000DaeC7E<M1@001E<M00<005<M00000P000U<M00<005<MDad015<M00<005<M
00000P000U<M00<005<MDad00e<M100015<M00<005<MDad00e<M100015<M00@005<MDaeC7@@000IC
7@04001C7E<MDad40006Dad00`00Dad000020002Dad00`00DaeC7@03Dad00`00DaeC7@0300000e<M
001C7@05Dad00`00Dad000020002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@03Dad30006Dad0
0`00Dad0003oOomROol00`00Oomoo`0COol00`00Oomoo`04Ool00?moo`moo`800?]oo`03001C7E<M
00AC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00=C7@@0
00AC7@03001C7E<M00=C7@@000=C7@03001C7E<M00AC7@8000IC7@04001C7E<MDad40006Dad01000
DaeC7E<M10001E<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<M00000P000U<M00<005<M
Dad015<M10000e<M00<005<MDad00e<M10001E<M00@005<MDaeC7@<000IC7@04001C7E<MDad40006
Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@03Dad40003
Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@04Dad20006Dad01000DaeC7E<M10001E<M00@005<M
DaeC7@D000EC7@03001C7E<M00<00003Dad005<M00EC7@03001C7@000080009C7@03001C7E<M00AC
7@800?moofAoo`03001oogoo019oo`03001oogoo00Aoo`00ogoo4Goo00<007ooOol0nGoo00<005<M
Dad00e<M0P001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00AC7@03001C
7@000080009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000=C7@03001C
7E<M00AC7@@000AC7@04001C7E<MDad40006Dad01000DaeC7E<M10001E<M00<005<MDad00`000U<M
00<005<MDad00e<M00<005<M00000P000U<M00<005<MDad015<M10000e<M00<005<MDad00e<M1000
0e<M00<005<MDad015<M0P001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M
00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7E<M00<00003Dad005<M00EC7@@000=C
7@03001C7E<M00=C7@@000EC7@04001C7E<MDad40005Dad01000DaeC7E<M1@001E<M00<005<MDad0
0`00ogooIgoo00<007ooOol04Goo00<007ooOol017oo003oOolBOol00`00Oomoo`3iOol00`00Dad0
00020002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad20006Dad01000DaeC7E<M10001U<M
00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03
001C7E<M00=C7@@000=C7@03001C7E<M00AC7@@000AC7@04001C7E<MDad40006Dad01000DaeC7E<M
0`001U<M00<005<MDad00`0000=C7@00Dad01E<M00<005<M00000P000U<M00<005<MDad00e<M00<0
05<MDad00`000U<M00<005<MDad00e<M10000e<M00<005<MDad015<M0P001U<M00@005<MDaeC7@@0
00IC7@04001C7E<MDad40005Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00Dad000020002
Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@03Dad40005Dad01000DaeC7E<M1000ogooJgoo00<0
07ooOol047oo00<007ooOol017oo003oOolCOol00`00Oomoo`3iOol20005Dad00`00Dad000020002
Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@03Dad40004Dad00`00DaeC7@03Dad4
0004Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M
00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@@000=C7@03001C7E<M00AC7@@000=C7@03001C
7E<M00=C7@<000EC7@04001C7E<MDad40006Dad01000DaeC7E<M10001U<M00<005<M00000P000U<M
00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad00e<M10000e<M00<005<MDad015<M1000
15<M00@005<MDaeC7@@000IC7@04001C7E<MDad40005Dad00`00DaeC7@0300000e<M001C7@05Dad0
0`00Dad000020002Dad00`00DaeC7@04Dad4003oOom_Ool00`00Oomoo`0AOol00`00Oomoo`03Ool0
0?mooaAoo`800?]oo`04001C7E<MDad30006Dad01000DaeC7E<M1@001E<M00<005<M00000P000U<M
00<005<MDad015<M00<005<M00000P000U<M00<005<MDad00e<M100015<M00<005<MDad00e<M1000
15<M00@005<MDaeC7@@000IC7@04001C7E<MDad40006Dad00`00Dad000020002Dad00`00DaeC7@03
Dad00`00DaeC7@0300000e<M001C7@05Dad00`00Dad000020002Dad00`00DaeC7@03Dad40004Dad0
0`00DaeC7@03Dad40004Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7@000080
009C7@03001C7E<M00=C7@03001C7E<M00<00003Dad005<M00EC7@@000=C7@03001C7E<M00AC7@@0
00AC7@04001C7E<MDad40005Dad01000DaeC7E<M10001U<M00<005<MDad00`0000=C7@00Ool0ogoo
LGoo00<007ooOol047oo00<007ooOol00goo003oOolFOol00`00Oomoo`3iOol30003Dad00`00DaeC
7@03Dad40005Dad01000DaeC7E<M0`001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03
001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@@000=C
7@03001C7E<M00AC7@8000IC7@04001C7E<MDad40005Dad01000DaeC7E<M1@001E<M00<005<M0000
0P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad00e<M100015<M00<005<MDad0
0e<M100015<M00@005<MDaeC7@@000IC7@04001C7E<MDad40005Dad00`00DaeC7@030002Dad00`00
DaeC7@03Dad00`00DaeC7@0300000e<M001C7@05Dad40003Dad00`00DaeC7@03Dad40004Dad00`00
DaeC7@03Dad30003Dad00`00Oomoo`3oOombOol00`00Oomoo`0?Ool00`00Oomoo`03Ool00?mooaMo
o`03001oogoo0?Uoo`03001C7E<M00=C7@03001C7@00008000=C7@03001C7E<M00=C7@@000=C7@03
001C7E<M00=C7@@000AC7@03001C7E<M00=C7@8000IC7@04001C7E<MDad40006Dad00`00Dad00002
0002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@03Dad00`00DaeC7@0300000e<M
001C7@05Dad40003Dad00`00DaeC7@03Dad40005Dad01000DaeC7E<M0`001U<M00@005<MDaeC7@D0
00EC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C7E<M00=C7@@0
00=C7@03001C7E<M00AC7@@000=C7@03001C7E<M00=C7@<000IC7@04001C7E<MDad40005Dad00`00
DaeC7@030002Dad00`00DaeC7@03Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00Dad00002
0002Dad01@00DaeC7E<M0000ogooMGoo00<007ooOol03Woo00<007ooOol00goo003oOolHOol00`00
Oomoo`3iOol01000DaeC7E<M0`001e<M00<005<M00000P000U<M00<005<MDad00e<M00<005<M0000
0P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad00e<M100015<M00<005<MDad0
0e<M0P001U<M00@005<MDaeC7@@000IC7@04001C7E<MDad40005Dad00`00DaeC7@030002Dad00`00
DaeC7@03Dad00`00Dad000020002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@03Dad40005Dad0
1000DaeC7E<M0`001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00=C7@03
001C7E<M00<0009C7@03001C7E<M00=C7@03001C7@000080009C7@03001C7E<M00AC7@@000=C7@03
001C7E<M00=C7@<000IC7@04001C7E<MDad30006Dad01000DaeC7E<M10001U<M00<005<M0000ogoo
MWoo00<007ooOol03Woo00<007ooOol00goo003oOolIOol2003jOol30002Ool20006Dad20006Dad0
1000DaeC7E<M0`001U<M00@005<MDaeC7@D000EC7@03001C7@000080009C7@03001C7E<M00AC7@03
001C7@000080009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@@000AC7@04001C7E<MDad4
0006Dad01000DaeC7E<M0`001U<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<M00000P00
0U<M00<005<MDad015<M10000e<M00<005<MDad00e<M10000e<M00<005<MDad015<M0P001U<M00@0
05<MDaeC7@@000IC7@04001C7E<MDad40005Dad00`00DaeC7@0300000e<M001C7@05Dad00`00Dad0
00020002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@03Dad40004Dad01000DaeC7E<M1000ogoo
N7oo00<007ooOol03Goo00<007ooOol00goo003oOolKOol00`00Oomoo`3lOol00`00Ool00002Dad3
0002Dad00`00DaeC7@03Dad40003Dad00`00DaeC7@03Dad40005Dad01000DaeC7E<M0`001U<M00@0
05<MDaeC7@D000EC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03001C
7E<M00=C7@@000=C7@03001C7E<M00AC7@@000=C7@03001C7E<M00=C7@<000IC7@04001C7E<MDad3
0006Dad00`00DaeC7@0300000e<M001C7@05Dad00`00Dad000020002Dad00`00DaeC7@03Dad00`00
DaeC7@030002Dad00`00DaeC7@03Dad40003Dad00`00DaeC7@04Dad40004Dad01000DaeC7E<M1000
1E<M00@005<MDaeC7@D000EC7@03001C7E<M00<00003Dad005<M00EC7@03001C7@000080009C7@03
001C7E<M00=C7@@00?moogeoo`03001oogoo00aoo`03001oogoo00=oo`00ogoo77oo00<007ooOol0
ngoo00<007ooOol00P001U<M00<005<M00000P000U<M00<005<MDad00e<M00<005<M00000P000e<M
00<005<MDad00e<M10000e<M00<005<MDad00e<M10001E<M00@005<MDaeC7@<000IC7@04001C7E<M
Dad40006Dad00`00Dad000020002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00DaeC7@03
Dad00`00Dad000020002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@03Dad30005Dad01000DaeC
7E<M10001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00=C7@03001C7E<M
00<00003Dad005<M00EC7@@000=C7@03001C7E<M00=C7@@000EC7@04001C7E<MDad40005Dad01000
DaeC7E<M10001U<M00<005<M00000P00ogooPGoo00<007ooOol03Goo00<007ooOol00Woo003oOolM
Ool00`00Oomoo`3jOol00`00Oomoo`02Ool01000DaeC7E<M10001U<M00@005<MDaeC7@@000IC7@03
001C7@000080009C7@03001C7E<M00=C7@03001C7@000080009C7@03001C7E<M00AC7@@000=C7@03
001C7E<M00=C7@@000AC7@03001C7E<M00=C7@8000IC7@04001C7E<MDad40006Dad01000DaeC7E<M
10001E<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<M00000P000U<M00<005<MDad00e<M
100015<M00<005<MDad00e<M100015<M00@005<MDaeC7@@000IC7@04001C7E<MDad40005Dad00`00
DaeC7@030002Dad00`00DaeC7@03Dad00`00Dad000020002Dad00`00DaeC7@04Dad40003Dad00`00
DaeC7@03Dad40003Dad00`00DaeC7@04Dad2003oOon5Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool0
0?mooaioo`03001oogoo0?Uoo`03001oogoo00=oo`<000AC7@03001C7E<M00=C7@@000AC7@04001C
7E<MDad40006Dad01000DaeC7E<M0`001U<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<M
00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad00e<M10000e<M00<005<M
Dad015<M100015<M00@005<MDaeC7@@000IC7@04001C7E<MDad40005Dad00`00Dad000020002Dad0
0`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@03Dad40003Dad00`00DaeC7@04Dad40004
Dad01000DaeC7E<M10001U<M00@005<MDaeC7@<000IC7@03001C7E<M00<00003Dad005<M00EC7@03
001C7@000080009C7@03001C7E<M00=C7@03001C7E<M00@00?moohMoo`03001oogoo00]oo`03001o
ogoo009oo`00ogoo7goo0P00nGoo00<007ooOol017oo00<005<MDad015<M00<005<M00000P000U<M
00<005<MDad00e<M100015<M00<005<MDad00e<M10000e<M00<005<MDad00e<M0`001U<M00@005<M
DaeC7@<000IC7@04001C7E<MDad50005Dad00`00Dad000020002Dad00`00DaeC7@03Dad00`00DaeC
7@030002Dad00`00DaeC7@03Dad40003Dad00`00DaeC7@04Dad40004Dad01000DaeC7E<M0`001U<M
00@005<MDaeC7@D000EC7@03001C7@000080009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03
001C7E<M00=C7@@000=C7@03001C7E<M00AC7@@000=C7@03001C7E<M00=C7@<000EC7@04001C7E<M
Dad40006Dad01000DaeC7E<M10000e<M00<007ooOol0ogooQWoo00<007ooOol02Woo00<007ooOol0
0Woo003oOolQOol00`00Oomoo`3fOol00`00Oomoo`05Ool01000DaeC7E<M10001U<M00<005<M0000
0P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad00e<M00<005<M00000P000U<M
00<005<MDad015<M10000e<M00<005<MDad00e<M10001E<M00@005<MDaeC7@<000IC7@04001C7E<M
Dad40006Dad00`00Dad000020002Dad00`00DaeC7@03Dad00`00DaeC7@0300000e<M001C7@05Dad4
0003Dad00`00DaeC7@03Dad40005Dad01000DaeC7E<M0`001U<M00@005<MDaeC7@@000IC7@03001C
7@000080009C7@03001C7E<M00=C7@03001C7E<M00<00003Dad005<M00EC7@03001C7@000080009C
7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@@000AC7@03001C7@000?moohUoo`03001oogoo
00Yoo`03001oogoo009oo`00ogoo8Woo00<007ooOol0mGoo00<007ooOol01Woo0`0017oo00<005<M
Dad00e<M0P001U<M00@005<MDaeC7@@000IC7@04001C7E<MDad40005Dad00`00DaeC7@030002Dad0
0`00DaeC7@03Dad00`00Dad000020002Dad00`00DaeC7@04Dad40003Dad00`00DaeC7@03Dad40004
Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@000EC7@03001C7E<M00<0009C7@03001C7E<M00=C
7@03001C7@000080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00=C7@@000=C7@03001C7E<M
00AC7@8000IC7@04001C7E<MDad40005Dad01000DaeC7E<M1@001E<M00<005<M00000P000U<M00<0
05<MDad015<M00<005<M00000P000U<M00<005<MDad00e<M0P00ogooRgoo00<007ooOol02Goo00<0
07ooOol00Woo003oOolSOol00`00Oomoo`3dOol00`00Oomoo`0>Ool00`00Dad000020002Dad00`00
DaeC7@03Dad40004Dad00`00DaeC7@03Dad40004Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@0
00EC7@03001C7E<M00<00003Dad005<M00EC7@03001C7@000080009C7@03001C7E<M00=C7@@000AC
7@03001C7E<M00=C7@@000AC7@04001C7E<MDad40006Dad01000DaeC7E<M0`001U<M00<005<MDad0
0`0000=C7@00Dad01E<M00<005<M00000P000U<M00<005<MDad00e<M00<005<MDad00`0000=C7@00
Dad01E<M10000e<M00<005<MDad00e<M10001E<M00@005<MDaeC7@<000IC7@04001C7E<MDad40006
Dad00`00Dad00002003oOon>Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00?moobAoo`800?Aoo`03
001oogoo00moo`8000EC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@000080009C7@03
001C7E<M00=C7@@000=C7@03001C7E<M00AC7@@000AC7@04001C7E<MDad40005Dad01000DaeC7E<M
1@001E<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad00e<M
10000e<M00<005<MDad015<M10000e<M00<005<MDad00e<M0`001E<M00@005<MDaeC7@@000IC7@04
001C7E<MDad40005Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00Dad000020002Dad00`00
DaeC7@04Dad40003Dad00`00DaeC7@03Dad40004Dad01000DaeC7E<M1000ogooTWoo00<007ooOol0
1goo00<007ooOol00Woo003oOolVOol00`00Oomoo`3aOol00`00Oomoo`0AOol01000DaeC7E<M0`00
1U<M00@005<MDaeC7@D000EC7@03001C7@000080009C7@03001C7E<M00=C7@03001C7E<M00<0009C
7@03001C7E<M00=C7@@000=C7@03001C7E<M00=C7@@000EC7@04001C7E<MDad30006Dad01000DaeC
7E<M10001U<M00<005<M00000P000U<M00<005<MDad00e<M00<005<MDad00`000U<M00<005<MDad0
0e<M00<005<M00000P000U<M00<005<MDad00e<M100015<M00<005<MDad00e<M100015<M00@005<M
DaeC7@@000IC7@04001C7E<MDad40005Dad00`00DaeC7@0300000e<M001C7@05Dad00`00Dad00002
0002Dad00`00DaeC7@03Dad4003oOonFOol00`00Oomoo`08Ool00`00Oomoo`01Ool00?moobMoo`03
001oogoo0>moo`03001oogoo01=oo`<000=C7@03001C7E<M00=C7@@000EC7@04001C7E<MDad30006
Dad01000DaeC7E<M10001U<M00<005<M00000P000U<M00<005<MDad00e<M00<005<M00000P000U<M
00<005<MDad015<M10000e<M00<005<MDad00e<M10000e<M00<005<MDad015<M0P001U<M00@005<M
DaeC7@@000IC7@04001C7E<MDad40005Dad00`00Dad000020002Dad00`00DaeC7@04Dad00`00Dad0
00020002Dad00`00DaeC7@03Dad40003Dad00`00DaeC7@04Dad40004Dad01000DaeC7E<M10001E<M
00@005<MDaeC7@@000IC7@03001C7@0000800?mooi]oo`03001oogoo00Moo`03001oogoo005oo`00
ogoo:7oo00<007ooOol0kWoo00<007ooOol057oo00<005<MDad00e<M00<005<M00000P000U<M00<0
05<MDad015<M10000e<M00<005<MDad00e<M100015<M00@005<MDaeC7@@000IC7@04001C7E<MDad3
0006Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00Dad000020002Dad00`00DaeC7@03Dad0
0`00DaeC7@030002Dad00`00DaeC7@03Dad40003Dad00`00DaeC7@04Dad40004Dad01000DaeC7E<M
0`001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00=C7@03001C7E<M00<0
0003Dad005<M00EC7@@000=C7@03001C7E<M00=C7@@000AC7@04001C7E<MDad4003oOonOOol00`00
Oomoo`06Ool00`00Oomoo`01Ool00?moobUoo`800>ioo`03001oogoo01Eoo`04001C7E<MDad40005
Dad00`00DaeC7@030002Dad00`00DaeC7@03Dad00`00Dad000020002Dad00`00DaeC7@03Dad40004
Dad00`00DaeC7@03Dad40003Dad00`00DaeC7@03Dad30006Dad01000DaeC7E<M0`001U<M00@005<M
DaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00=C7@03001C7E<M00<00003Dad005<M00EC
7@@000=C7@03001C7E<M00=C7@@000AC7@04001C7E<MDad40006Dad01000DaeC7E<M10001E<M00<0
05<MDad00`000U<M00<005<MDad00e<M00<005<M00000P000U<M00<005<MDad00e<M1000ogooXgoo
00<007ooOol01Woo00<007ooOol00Goo003oOol[Ool00`00Oomoo`3[Ool00`00Oomoo`0FOol30004
Ool01000DaeC7E<M10001U<M00@005<MDaeC7@<000IC7@03001C7@000080009C7@03001C7E<M00AC
7@03001C7@000080009C7@03001C7E<M00=C7@03001C7@000080009C7@03001C7E<M00AC7@@000=C
7@03001C7E<M00=C7@@000AC7@04001C7E<MDad40006Dad01000DaeC7E<M10001E<M00<005<MDad0
0`000U<M00<005<MDad00e<M00<005<M00000P000U<M00<005<MDad00e<M100015<M00<005<MDad0
0e<M100015<M00@005<MDaeC7@@000IC7@04001C7E<MDad30006Dad00`00Dad00002003oOonXOol0
0`00Oomoo`05Ool00`00Oomoo`01Ool00?moobaoo`03001oogoo0>Yoo`03001oogoo01ioo`<000=o
o`03001C7E<M00AC7@@000=C7@03001C7E<M00=C7@8000IC7@04001C7E<MDad40006Dad01000DaeC
7E<M10001E<M00<005<MDad00`000U<M00<005<MDad00e<M00<005<M00000P000U<M00<005<MDad0
0e<M100015<M00<005<MDad00e<M100015<M00@005<MDaeC7@@000IC7@04001C7E<MDad40005Dad0
0`00Dad000020002Dad00`00DaeC7@04Dad00`00Dad000020002Dad00`00DaeC7@03Dad40003Dad0
0`00DaeC7@04Dad40003Dad00`00DaeC7@03Dad2003oOon/Ool00`00Oomoo`04Ool00`00Oomoo`01
Ool00?moobeoo`03001oogoo0>Uoo`03001oogoo02Eoo`03001C7E<M00<0009C7@03001C7E<M00=C
7@03001C7@000080009C7@03001C7E<M00=C7@@000AC7@03001C7E<M00=C7@@000AC7@04001C7E<M
Dad40006Dad01000DaeC7E<M10001E<M00<005<M00000P000U<M00<005<MDad015<M00<005<M0000
0P000U<M00<005<MDad00e<M10000e<M00<005<MDad015<M100015<M00@005<MDaeC7@<000IC7@04
001C7E<MDad40006Dad00`00Dad000020002Dad00`00DaeC7@03Dad00`00DaeC7@0300000e<M001C
7@05Dad00`00Dad00002003oOon_Ool00`00Oomoo`03Ool00`00Oomoo`01Ool00?moobioo`800>Uo
o`03001oogoo02Ioo`8000IC7@04001C7E<MDad40005Dad00`00Dad000020002Dad00`00DaeC7@04
Dad00`00Dad000020002Dad00`00DaeC7@03Dad40003Dad00`00DaeC7@04Dad40004Dad01000DaeC
7E<M0`001U<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00=C7@03001C7E<M
00<00003Dad005<M00EC7@@000=C7@03001C7E<M00=C7@@000AC7@04001C7E<MDad40006Dad01000
DaeC7E<M10001E<M00@005<MDaeC7@@00?mook9oo`03001oogoo00Aoo`40005oo`5oo`00ogoo<7oo
00<007ooOol0iWoo00<007ooOol09goo00<005<MDad015<M100015<M00@005<MDaeC7@<000IC7@04
001C7E<MDad50005Dad00`00Dad000020002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad00`00
DaeC7@03Dad40003Dad00`00DaeC7@03Dad40004Dad01000DaeC7E<M10001U<M00@005<MDaeC7@@0
00EC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7@000080009C7@03001C7E<M00=C7@@0
00=C7@03001C7E<M00AC7@@000=C7@03001C7E<M00=C7@@0009C7@03001oogoo0?mook9oo`03001o
ogoo00=oo`40005oo`5oo`00ogoo<Goo00<007ooOol0iGoo00<007ooOol0:7oo00<005<MDad00`00
0Woo00<005<MDad00e<M10000e<M00<005<MDad00e<M10001E<M00@005<MDaeC7@<000IC7@04001C
7E<MDad40006Dad00`00Dad000020002Dad00`00DaeC7@03Dad00`00Dad000020002Dad00`00DaeC
7@03Dad40004Dad00`00DaeC7@03Dad40004Dad01000DaeC7E<M10001U<M00@005<MDaeC7@<000IC
7@03001C7@000080009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C
7@000080009oo`05001C7E<MDad0003oOoneOol00`00Oomoo`02Ool10001Ool1Ool00?mooc9oo`03
001oogoo0>Aoo`03001oogoo02Uoo`8000Ioo`03001C7@000080009C7@03001C7E<M00=C7@03001C
7@000080009C7@03001C7E<M00AC7@@000=C7@03001C7E<M00=C7@@000AC7@04001C7E<MDad40006
Dad01000DaeC7E<M10001E<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M
00<005<MDad00e<M10000e<M00<005<MDad015<M10000e<M00<005<MDad00e<M0P001U<M00@005<M
DaeC7@@000IC7@04001C7E<MDad30006Ool00`00Dad0003oOongOol01@00Oomoogoo00000Woo003o
OolcOol2003TOol00`00Oomoo`0bOol00`00DaeC7@04Dad01000DaeC7E<M10001E<M00<005<MDad0
0`000U<M00<005<MDad00e<M00<005<M00000P000U<M00<005<MDad00e<M10000e<M00<005<MDad0
15<M100015<M00@005<MDaeC7@<000IC7@04001C7E<MDad40006Dad00`00Dad000020002Dad00`00
DaeC7@03Dad00`00DaeC7@0300000e<M001C7@05Dad00`00Dad000020002Dad00`00DaeC7@03Dad4
0003Dad00`00DaeC7@04Dad4000:Ool00`00Oomoo`3oOonfOol01@00Oomoogoo00000Woo003oOole
Ool00`00Oomoo`3QOol00`00Oomoo`0cOol00`00DaeC7@03Dad40004Dad01000DaeC7E<M10001U<M
00@005<MDaeC7@@000EC7@03001C7@000080009C7@03001C7E<M00=C7@03001C7E<M00<0009C7@03
001C7E<M00=C7@@000=C7@03001C7E<M00=C7@@000AC7@04001C7E<MDad40006Dad01000DaeC7E<M
10001E<M00@005<MDaeC7@@000IC7@03001C7@000080009C7@03001C7E<M00=C7@03001C7E<M00<0
0?moolQoo`04001oogoo0002Ool00?moocIoo`03001oogoo0>1oo`03001oogoo03Aoo`03001C7@00
0080009oo`03001C7E<M00=C7@@000=C7@03001C7E<M00AC7@@000AC7@04001C7E<MDad30006Dad0
1000DaeC7E<M10001U<M00<005<M00000P000U<M00<005<MDad00e<M00<005<M00000P000U<M00<0
05<MDad00e<M100015<M00<005<MDad00e<M10000e<M00<005<MDad00e<M100015<M00@005<MDaeC
7@@000IC7@04001C7E<MDad4003oOoo<Ool00`00Ool00002Ool00?moocMoo`03001oogoo0=moo`03
001oogoo03Eoo`03001oogoo00Aoo`03001C7@000080009oo`03001C7E<M00=C7@03001C7E<M00<0
0003Dad005<M00EC7@@000=C7@03001C7E<M00=C7@@000AC7@04001C7E<MDad40006Dad01000DaeC
7E<M10001E<M00<005<M00000P000U<M00<005<MDad015<M00<005<M00000P000U<M00<005<MDad0
0e<M00<005<M00000P000U<M00<005<MDad00e<M100015<M00<005<MDad00e<M1000ogood7oo00@0
07ooOol0005oo`00ogoo>7oo00<007ooOol0gWoo00<007ooOol0?Goo00<007ooOol017oo00@005<M
DaeC7@@000EC7@03001C7E<M00<0009C7@03001C7E<M00=C7@03001C7@000080009C7@03001C7E<M
00=C7@@000=C7@03001C7E<M00AC7@@000AC7@04001C7E<MDad30006Dad01000DaeC7E<M10001U<M
00@005<MDaeC7@@000EC7@03001C7@000080009C7@03001C7E<M00AC7@03001C7@0000800?moomEo
o`03001oo`00005oo`00ogoo>Goo0P00gWoo00<007ooOol0AGoo0`0017oo00@005<MDaeC7@@000IC
7@04001C7E<MDad40005Dad00`00Dad000020002Dad00`00DaeC7@03Dad00`00DaeC7@030002Dad0
0`00DaeC7@03Dad40003Dad00`00DaeC7@03Dad40003Dad00`00DaeC7@04Dad40004Dad01000DaeC
7E<M0`001U<M00@005<MDaeC7@@00?moomUoo`80005oo`00ogoo>goo00<007ooOol0fgoo00<007oo
Ool0CGoo0`000goo00<005<MDad015<M100015<M00@005<MDaeC7@<000IC7@04001C7E<MDad40006
Dad00`00Dad000020002Dad00`00DaeC7@03Dad00`00Dad000020002Dad00`00DaeC7@03Dad00`00
DaeC7@030002Dad00`00DaeC7@03Dad40003Ool00`00DaeC7@03Dad4003oOooLOol30001Ool00?mo
ocaoo`03001oogoo0=Yoo`03001oogoo05Aoo`03001C7E<M00<0009oo`03001C7E<M00=C7@@000=C
7@03001C7E<M00=C7@@000AC7@04001C7E<MDad40006Dad01000DaeC7E<M0`001U<M00@005<MDaeC
7@@000IC7@03001C7@00008000Qoo`03001C7@0000800?moomaoo`@000Aoo`00ogoo?Goo00<007oo
Ool0fGoo00<007ooOol0EGoo0P001Woo00<005<M00000P000Woo00<005<MDad00e<M00<005<M0000
0P000Woo00<005<MDad00e<M10000goo00<005<MDad015<M10000e<M00<005<MDad00e<M100017oo
00@005<MDaeC7@@000aoo`03001oogoo0?moomUoo`@000Qoo`00ogoo?Woo0P00fGoo00<007ooOol0
GWoo00<007ooOol017oo00@005<MDaeC7@<000Ioo`03001C7@00008000Qoo`03001C7E<M00<0009o
o`03001C7E<M00=C7@03001C7@00008000Uoo`<00?moonUoo`<000aoo`00ogoo@7oo00<007ooOol0
eWoo00<007ooOol0IWoo0`002Woo00<007ooOol02Woo0P001Woo00@005<MDaeC7@<00?moooAoo`@0
00moo`00ogoo@Goo00<007ooOol0eGoo00<007ooOol0RGoo0`00ogoolgoo10004goo003oOom2Ool0
0`00Oomoo`3DOol00`00Oomoo`3oOoooOomlOol4000GOol00?mood=oo`800=Aoo`03001oogoo0?mo
oomoogQoo`@001]oo`00ogooAGoo00<007ooOol0dGoo00<007ooOol0ogooogooMGoo0`007goo003o
Oom6Ool00`00Oomoo`3@Ool00`00Oomoo`3oOoooOomaOol4000ROol00?moodMoo`03001oogoo0<mo
o`03001oogoo0?mooomoofeoo`@002Ioo`00ogooB7oo0P00cgoo00<007ooOol0ogooogooJGoo1000
:Woo003oOom:Ool00`00Oomoo`3<Ool00`00Oomoo`3oOoooOomUOol4000^Ool00?mood]oo`03001o
ogoo0<]oo`03001oogoo0?mooomoof5oo`@0039oo`00ogooC7oo00<007ooOol0bGoo00<007ooOol0
ogooogooGgoo0`00=Woo003oOom=Ool20039Ool00`00Oomoo`3oOoooOomKOol4000iOol00?moodmo
o`03001oogoo0<Ioo`03001oogoo0?mooomooeMoo`@003eoo`00ogooD7oo00<007ooOol0aGoo00<0
07ooOol0ogooogooDgoo1000@Goo003oOomAOol00`00Oomoo`34Ool00`00Oomoo`3oOoooOom?Ool4
0015Ool00?mooe9oo`03001oogoo0<=oo`03001oogoo0?mooomoodaoo`<004Uoo`00ogooDgoo0P00
`goo00<007ooOol0ogooogooB7oo1000C7oo003oOomEOol00`00Oomoo`30Ool00`00Oomoo`3oOooo
Oom4Ool4001@Ool00?mooeIoo`03001oogoo0;moo`03001oogoo0?mooomood1oo`@005Aoo`00ogoo
Egoo00<007ooOol0_Woo00<007ooOol0ogooogoo?7oo1000F7oo003oOomHOol2002nOol00`00Oomo
o`3oOoooOolhOol4001LOol00?mooeYoo`03001oogoo0;]oo`03001oogoo0?mooomoocEoo`<0061o
o`00ogooFgoo00<007ooOol0^Woo00<007ooOol0ogooogoo<Goo1000Hgoo003oOomLOol00`00Oomo
o`2iOol00`00Oomoo`3oOoooOol]Ool4001WOol00?mooeeoo`800;Uoo`03001oogoo0?mooomoobUo
o`@006]oo`00ogooGgoo00<007ooOol0]Woo00<007ooOol0ogooogoo9Goo1000Kgoo003oOomPOol0
0`00Oomoo`2eOol00`00Oomoo`3oOoooOolROol3001cOol00?moof5oo`03001oogoo0;Aoo`03001o
ogoo0?mooomooaioo`@007Ioo`00ogooHWoo0P00]7oo00<007ooOol0ogooogoo6Woo1000NWoo003o
OomTOol00`00Oomoo`2aOol00`00Oomoo`3oOoooOolFOol4001nOol00?moofEoo`03001oogoo0;1o
o`03001oogoo0?mooomooa9oo`@0089oo`00ogooIWoo00<007ooOol0[goo00<007ooOol0ogooogoo
3Woo1000QWoo003oOomWOol2002_Ool00`00Oomoo`3oOoooOol;Ool3002:Ool00?moofUoo`03001o
ogoo0:aoo`03001oogoo0?mooomoo`Moo`@008eoo`00ogooJWoo00<007ooOol0Zgoo00<007ooOol0
ogooogoo0goo1000TGoo003oOom[Ool00`00Oomoo`2ZOol00`00Oomoo`3oOoonOol4002EOol00?mo
ofaoo`03001oogoo0:Uoo`03001oogoo0?moooYoo`@009Uoo`00ogooKGoo0P00ZGoo00<007ooOol0
ogoomgoo0`00WGoo003oOom_Ool00`00Oomoo`2VOol00`00Oomoo`3oOoocOol4002POol00?moog1o
o`03001oogoo0:Aoo`03001oogoo0?mooo1oo`@00:Aoo`00ogooLGoo00<007ooOol0Xgoo00<007oo
Ool0ogook7oo1000Z7oo003oOombOol2002SOol00`00Oomoo`3oOooXOol4002/Ool00?moogAoo`03
001oogoo0:1oo`03001oogoo0?moonEoo`<00;1oo`00ogooMGoo00<007ooOol0Wgoo00<007ooOol0
ogoohGoo1000/goo003oOomfOol00`00Oomoo`2NOol00`00Oomoo`3oOooMOol4002gOol00?moogMo
o`8009ioo`03001oogoo0?moomUoo`@00;]oo`00ogooNGoo00<007ooOol0Vgoo00<007ooOol0ogoo
eGoo1000_goo003oOomjOol00`00Oomoo`2JOol00`00Oomoo`3oOooAOol40033Ool00?moog]oo`03
001oogoo09Uoo`03001oogoo0?moolioo`<00<Moo`00ogooO7oo0P00VGoo00<007ooOol0ogoobWoo
1000bWoo003oOomnOol00`00Oomoo`2FOol00`00Oomoo`3oOoo6Ool4003>Ool00?moogmoo`03001o
ogoo09Eoo`03001oogoo0?mool9oo`@00=9oo`00ogooP7oo00<007ooOol0U7oo00<007ooOol0ogoo
_Woo1000eWoo003oOon1Ool2002DOol00`00Oomoo`3oOonkOol3003JOol00?mooh=oo`03001oogoo
095oo`03001oogoo0?mookMoo`@00=eoo`00ogooQ7oo00<007ooOol0T7oo00<007ooOol0ogoo/goo
1000hGoo003oOon5Ool00`00Oomoo`2?Ool00`00Oomoo`3oOon_Ool4003UOol00?moohIoo`03001o
ogoo08ioo`03001oogoo0?mooj]oo`@00>Uoo`00ogooQgoo0P00SWoo00<007ooOol0ogooYgoo1000
kGoo003oOon9Ool00`00Oomoo`2;Ool00`00Oomoo`3oOonTOol3003aOol00?moohYoo`03001oogoo
08Yoo`03001oogoo0?mooj1oo`@00?Aoo`00ogooRgoo00<007ooOol0RGoo00<007ooOol0ogooW7oo
1000n7oo003oOon<Ool20029Ool00`00Oomoo`3oOonHOol4003lOol00?moohioo`03001oogoo08Io
o`03001oogoo0?mooiAoo`@00?moo`5oo`00ogooSgoo00<007ooOol0QGoo00<007ooOol0ogooTGoo
0`00ogoo1Goo003oOon@Ool00`00Oomoo`24Ool00`00Oomoo`3oOon=Ool4003oOol8Ool00?mooi5o
o`8008Aoo`03001oogoo0?moohUoo`@00?moo`aoo`00ogooTgoo00<007ooOol0PGoo00<007ooOol0
ogooQGoo1000ogoo47oo003oOonDOol00`00Oomoo`20Ool00`00Oomoo`3oOon1Ool4003oOolDOol0
0?mooiEoo`03001oogoo07ioo`03001oogoo0?moogioo`@00?mooaQoo`00ogooUWoo0P00OWoo00<0
07ooOol0ogooNgoo0`00ogoo77oo003oOonHOol00`00Oomoo`1kOol00`00Oomoo`3oOomgOol4003o
OolOOol00?mooiUoo`03001oogoo07Yoo`03001oogoo0?moog=oo`@00?moob=oo`00ogooVWoo00<0
07ooOol0NGoo00<007ooOol0ogooKgoo1000ogoo9goo003oOonKOol2001iOol00`00Oomoo`3oOom[
Ool4003oOol[Ool00?mooieoo`03001oogoo07Ioo`03001oogoo0?moofQoo`<00?moobmoo`00ogoo
WWoo00<007ooOol0MGoo00<007ooOol0ogooI7oo1000ogoo<Woo003oOonOOol00`00Oomoo`1dOol0
0`00Oomoo`3oOomPOol4003oOolfOol00?mooj1oo`03001oogoo07=oo`03001oogoo0?mooeaoo`@0
0?moocYoo`00ogooXGoo0P00Lgoo00<007ooOol0ogooF7oo1000ogoo?Woo003oOonSOol00`00Oomo
o`1`Ool00`00Oomoo`3oOomDOol4003oOom2Ool00?moojAoo`03001oogoo06moo`03001oogoo0?mo
oe5oo`<00?moodIoo`00ogooYGoo00<007ooOol0KWoo00<007ooOol0ogooCGoo1000ogooBGoo003o
OonVOol2001^Ool00`00Oomoo`3oOom9Ool4003oOom=Ool00?moojQoo`03001oogoo06]oo`03001o
ogoo0?moodEoo`@00?mooe5oo`00ogooZGoo00<007ooOol0JWoo00<007ooOol0ogoo@Goo1000ogoo
EGoo003oOonZOol00`00Oomoo`1YOol00`00Oomoo`3oOolnOol3003oOomIOol00?mooj]oo`8006Uo
o`03001oogoo0?moocYoo`@00?mooeaoo`00ogoo[Goo00<007ooOol0IWoo00<007ooOol0ogoo=Woo
1000ogooH7oo003oOon^Ool00`00Oomoo`1UOol00`00Oomoo`3oOolbOol4003oOomTOol00?moojmo
o`03001oogoo06Aoo`03001oogoo0?moobioo`@00?moofQoo`00ogoo/7oo0P00I7oo00<007ooOol0
ogoo:Woo1000ogooK7oo003oOonbOol00`00Oomoo`1QOol00`00Oomoo`3oOolWOol3003oOom`Ool0
0?mook=oo`03001oogoo061oo`03001oogoo0?moob=oo`@00?moog=oo`00ogoo]7oo00<007ooOol0
Ggoo00<007ooOol0ogoo7goo1000ogooMgoo003oOoneOol2001OOol00`00Oomoo`3oOolKOol4003o
OomkOol00?mookMoo`03001oogoo05aoo`03001oogoo0?mooaMoo`@00?moogmoo`00ogoo^7oo00<0
07ooOol0Fgoo00<007ooOol0ogoo57oo0`00ogooPgoo003oOoniOol00`00Oomoo`1IOol00`00Oomo
o`3oOolAOol4003oOon6Ool00?mookYoo`03001oogoo05Qoo`03001oogoo0?moo`eoo`@00?moohYo
o`00ogoo^goo0P00F7oo00<007ooOol0ogoo2Goo1000ogooSWoo003oOonmOol00`00Oomoo`1EOol0
0`00Oomoo`3oOol5Ool4003oOonBOol00?mookioo`03001oogoo05Aoo`03001oogoo0?moo`5oo`@0
0?mooiIoo`00ogoo_goo00<007ooOol0Dgoo00<007ooOol0oGoo0`00ogooVWoo003oOoo0Ool2001C
Ool00`00Oomoo`3iOol4003oOonMOol00?mool9oo`03001oogoo051oo`03001oogoo0?Eoo`@00?mo
oj5oo`00ogoo`goo00<007ooOol0Cgoo00<007ooOol0lGoo1000ogooYGoo003oOoo4Ool00`00Oomo
o`1>Ool00`00Oomoo`3]Ool4003oOonYOol00?moolEoo`8004ioo`03001oogoo0>Yoo`<00?moojeo
o`00ogooagoo00<007ooOol0Bgoo00<007ooOol0iWoo1000ogoo/7oo003oOoo8Ool00`00Oomoo`1:
Ool00`00Oomoo`3ROol4003oOondOol00?moolUoo`03001oogoo04Uoo`03001oogoo0=ioo`@00?mo
okQoo`00ogoobWoo0P00BGoo00<007ooOol0fWoo1000ogoo_7oo003oOoo<Ool00`00Oomoo`16Ool0
0`00Oomoo`3FOol4003oOoo0Ool00?mooleoo`03001oogoo04Eoo`03001oogoo0==oo`<00?moolAo
o`00ogoocWoo00<007ooOol0A7oo00<007ooOol0cgoo1000ogooagoo003oOoo?Ool20014Ool00`00
Oomoo`3;Ool4003oOoo;Ool00?moom5oo`03001oogoo045oo`03001oogoo0<Moo`@00?moolmoo`00
ogoodWoo00<007ooOol0@7oo00<007ooOol0`goo1000ogoodgoo003oOooCOol00`00Oomoo`0oOol0
0`00Oomoo`30Ool3003oOooGOol00?moomAoo`03001oogoo03ioo`03001oogoo0;aoo`@00?moomYo
o`00ogooeGoo0P00?Woo00<007ooOol0^7oo1000ogoogWoo003oOooGOol00`00Oomoo`0kOol00`00
Oomoo`2dOol4003oOooROol00?moomQoo`03001oogoo03Yoo`03001oogoo0;1oo`@00?moonIoo`00
ogoofGoo00<007ooOol0>Goo00<007ooOol0[7oo1000ogoojWoo003oOooJOol2000iOol00`00Oomo
o`2YOol3003oOoo^Ool00?moomaoo`03001oogoo03Ioo`03001oogoo0:Eoo`@00?mooo5oo`00ogoo
gGoo00<007ooOol0=Goo00<007ooOol0XGoo1000ogoomGoo003oOooNOol00`00Oomoo`0cOol00`00
Oomoo`2NOol4003oOooiOol00?moommoo`8003=oo`03001oogoo09Yoo`@00?moooeoo`00ogoohGoo
00<007ooOol0<7oo00<007ooOol0Ugoo0`00ogooogoo0Woo003oOooROol00`00Oomoo`0_Ool00`00
Oomoo`2COol4003oOoooOol5Ool00?moon=oo`03001oogoo02ioo`03001oogoo08moo`@00?mooomo
o`Uoo`00ogooi7oo0P00;Woo00<007ooOol0Rgoo1000ogooogoo3Goo003oOooVOol00`00Oomoo`0[
Ool00`00Oomoo`27Ool4003oOoooOolAOol00?moonMoo`03001oogoo02Yoo`03001oogoo08Aoo`<0
0?mooomooaEoo`00ogooj7oo00<007ooOol0:Goo00<007ooOol0P7oo1000ogooogoo67oo003oOooY
Ool2000YOol00`00Oomoo`1lOol4003oOoooOolLOol00?moon]oo`03001oogoo02Ioo`03001oogoo
07Qoo`@00?mooomoob1oo`00ogook7oo00<007ooOol09Goo00<007ooOol0M7oo1000ogooogoo97oo
003oOoo]Ool00`00Oomoo`0TOol00`00Oomoo`1`Ool4003oOoooOolXOol00?moonioo`03001oogoo
02=oo`03001oogoo06eoo`<00?mooomoobaoo`00ogookgoo0P008goo00<007ooOol0JGoo1000ogoo
ogoo;goo003oOooaOol00`00Oomoo`0POol00`00Oomoo`1UOol4003oOoooOolcOol00?mooo9oo`03
001oogoo01moo`03001oogoo065oo`@00?mooomoocMoo`00ogoolgoo00<007ooOol07Woo00<007oo
Ool0GGoo1000ogooogoo>goo003oOoodOol2000NOol00`00Oomoo`1JOol3003oOoooOoloOol00?mo
ooIoo`03001oogoo01]oo`03001oogoo05Ioo`@00?mooomood9oo`00ogoomgoo00<007ooOol06Woo
00<007ooOol0DWoo1000ogooogooAWoo003oOoohOol00`00Oomoo`0IOol00`00Oomoo`1>Ool4003o
OoooOom:Ool00?moooUoo`8001Uoo`03001oogoo04Yoo`@00?mooomoodioo`00ogoongoo00<007oo
Ool05Woo00<007ooOol0AWoo1000ogooogooDWoo003oOoolOol00`00Oomoo`0EOol00`00Oomoo`13
Ool3003oOoooOomFOol00?moooeoo`03001oogoo01Aoo`03001oogoo03moo`@00?mooomooeUoo`00
ogoooWoo0P0057oo00<007ooOol0>goo1000ogooogooGGoo003oOoooOol1Ool00`00Oomoo`0AOol0
0`00Oomoo`0gOol4003oOoooOomQOol00?mooomoo`9oo`03001oogoo011oo`03001oogoo03=oo`@0
0?mooomoofEoo`00ogooogoo0goo00<007ooOol03Woo00<007ooOol0<Goo0`00ogooogooJGoo003o
OoooOol4Ool2000>Ool00`00Oomoo`0]Ool4003oOoooOom/Ool00?mooomoo`Ioo`03001oogoo00]o
o`03001oogoo02Uoo`@00?mooomoog1oo`00ogooogoo1goo00<007ooOol02Woo00<007ooOol09Goo
1000ogooogooM7oo003oOoooOol8Ool00`00Oomoo`09Ool00`00Oomoo`0QOol4003oOoooOomhOol0
0?mooomoo`Uoo`03001oogoo00Qoo`03001oogoo01eoo`@00?mooomoogaoo`00ogooogoo2Woo0P00
27oo00<007ooOol06Woo0`00ogooogooP7oo003oOoooOol<Ool00`00Oomoo`05Ool00`00Oomoo`0F
Ool4003oOoooOon3Ool00?mooomoo`eoo`03001oogoo00Aoo`03001oogoo019oo`@00?mooomoohMo
o`00ogooogoo3Woo00<007ooOol00goo00<007ooOol03Woo1000ogooogooRgoo003oOoooOol?Ool2
0003Ool00`00Oomoo`0:Ool4003oOoooOon?Ool00?mooomooa5oo`04001oogoo0009Ool3003oOooo
OonCOol00?mooomooa9oo`03001oo`0000Eoo`@00?mooomooiIoo`00ogooogoo4goo0P0000=oo`00
00000P00ogooogooVWoo003oOoooOolDOol2003oOoooOonNOol00?mooomooomooomookAoo`00ogoo
ogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo
]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOooo
OoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOond
Ool00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomo
oomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAo
o`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogoo
ogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo
003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOooo
OoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol0
0?mooomooomooomookAoo`00ogooogooogooogoo]7oo0000\
\>"], "Graphics",
  CellLabel->"From In[55]:=",
  Evaluatable->False,
  ImageSize->{400, 324.438},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[TextData[{
  "The picture shows the resulting vector potential with its logarithmic drop \
between ",
  Cell[BoxData[
      \(TraditionalForm\`r\_0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`r\_1\)]],
  "."
}], "Text",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell["gradient field... ", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[{
    \(\(g = 
        Table[{u[\([i, j + 1]\)] - u[\([i, j]\)], 
            u[\([i + 1, j]\)] - u[\([i, j]\)]}, {i, 1, nz - 1}, {j, 1, 
            ns - 1}];\)\), "\n", 
    \(\(lrow = 
        Table[{u[\([nz, j + 1]\)] - u[\([nz, j]\)], 
            u[\([nz, j]\)] - u[\([nz - 1, j]\)]}, {j, 1, 
            ns - 1}];\)\ \), "\[IndentingNewLine]", 
    \(\(g = Append[g, lrow];\)\), "\[IndentingNewLine]", 
    \(\(lcol = 
        Append[Table[{u[\([i, ns]\)] - u[\([i, ns - 1]\)], 
              u[\([i + 1, ns]\)] - u[\([i, ns]\)]}, {i, 1, 
              nz - 1}], {u[\([nz, ns]\)] - u[\([nz, ns - 1]\)], 
            u[\([nz, ns]\)] - 
              u[\([nz - 1, ns]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(g = Transpose[Append[Transpose[g], lcol]];\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(\[Mu]\_0 = 4.  \[Pi]*10\^\(-7\);\)\)], "Input",
  CellLabel->"In[69]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  "Calculate \[ContourIntegral] ",
  Cell[BoxData[
      \(TraditionalForm\`H\&\[RightVector]\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]l\&\[RightVector]\)]],
  " around inner conductor on a circle with radius r and center (xr,yr);\n",
  Cell[BoxData[
      \(TraditionalForm\`H\&\[RightVector]\)]],
  "\[CenterDot] ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]l\&\[RightVector]\)]],
  " = (",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_y\ A\_z\)]],
  ", - ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_x\ A\_z\)]],
  ") \[CenterDot] (-r d\[CurlyPhi] sin\[CurlyPhi], r d\[CurlyPhi] cos\
\[CurlyPhi]) and ",
  Cell[BoxData[
      \(TraditionalForm\`A\_z\)]],
  " is evaluated at (xr + r cos\[CurlyPhi], yr + r sin\[CurlyPhi])"
}], "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dphi = \[Pi]/100;\)\), "\[IndentingNewLine]", 
    \(i = 
      Table[\ Sum[\(-rr\)*
            dphi \((\[IndentingNewLine]g[\([Round[yr + rr*Sin[phi]], 
                      Round[xr + rr*Cos[phi]], 2]\)]*Sin[phi] + 
                g[\([Round[yr + rr*Sin[phi]], Round[xr + rr*Cos[phi]], 1]\)]*
                  Cos[phi])\), \[IndentingNewLine]{phi, 0, 2  \[Pi], 
            dphi}], {rr, 31, 59}]\), "\[IndentingNewLine]", 
    \(iMean = Apply[Plus, i]/Length[i]\)}], "Input",
  CellLabel->"In[70]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \({0.9976552846887818`, 0.998140481875725`, 0.9978530210795039`, 
      0.9959823179631949`, 0.9939185019384442`, 0.9975801564544899`, 
      0.9955835157116247`, 0.9984640689881206`, 0.9956316626971611`, 
      0.9980364307046519`, 0.9972055866009992`, 0.996703553930234`, 
      1.0005952099357345`, 0.9987644812258286`, 0.9985026005925058`, 
      0.9994526966722194`, 0.9999964168128266`, 1.0003119866336245`, 
      0.9994625867443341`, 1.0022261142997302`, 1.0025054390138388`, 
      1.0022525903197013`, 1.0025816003600754`, 1.0029775560433074`, 
      1.0061780753625875`, 1.0046822335681407`, 1.0041766782647406`, 
      1.0012297150961762`, 1.0113441975954451`}\)], "Output",
  CellLabel->"Out[71]="],

Cell[BoxData[
    \(0.9999998193508188`\)], "Output",
  CellLabel->"Out[72]="]
}, Open  ]],

Cell["\<\
The above cell shows the mean of many loop integrals that all \
should give the same result as long as the radius rr does not touch other \
currents. v1 in the cell at the start of this section must be varied such \
that iMean becomes 1. The following result is only correct, if the number for \
iMean is close enough to 1.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["result:", "Subsubsection"],

Cell[TextData[{
  "With  ",
  Cell[BoxData[
      \(TraditionalForm\`H\&\[RightVector]\)]],
  " = (",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_y\ A\_z\)]],
  ", - ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_x\ A\_z\)]],
  ") and (36) the external ",
  "inductance",
  " (between ",
  Cell[BoxData[
      \(TraditionalForm\`r\_0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`r\_1\)]],
  ") is in [H/m] :"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`L\_ii'\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_0\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Integral]\_A\%\ \), 
            SuperscriptBox[
              RowBox[{"(", 
                FormBox[\(\[PartialD]\_y\ A\_z\),
                  "TraditionalForm"], ")"}], "2"]}], "+", 
          " ", \(\(\((\[PartialD]\_x\ 
                    A\_z)\)\^2\) \[DifferentialD]x \[DifferentialD]y\)}], 
        TraditionalForm]]],
  ","
}], "NumberedEquation"],

Cell["leading to:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ind = \[Mu]\_0*
        Sum[g[\([i, j]\)] . g[\([i, j]\)], {i, 1, nz}, {j, 1, ns}]\)], "Input",\

  CellLabel->"In[75]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(1.4058731111309756`*^-7\)], "Output",
  CellLabel->"Out[75]="]
}, Open  ]],

Cell["This is in nice agreement with the theoretical value:", "Text",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[Mu]\_0\/\(2  \[Pi]\)\) Log[r1\/r0]\)], "Input",
  CellLabel->"In[76]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(1.3862943611198907`*^-7\)], "Output",
  CellLabel->"Out[76]="]
}, Open  ]],

Cell[TextData[{
  "For the complete coax including inner wire and shield we have (compare \
Fig. 5 with ",
  Cell[BoxData[
      \(TraditionalForm\`r\_0\)]],
  " = 30,  ",
  Cell[BoxData[
      \(TraditionalForm\`r\_1\)]],
  " = 60,  \n",
  Cell[BoxData[
      \(TraditionalForm\`r\_2\)]],
  " = 63; current in the wire =+1, current in the shield =-1) :\n\[Bullet] \
the magnetic Field as function of r (",
  StyleBox["Ref. 7",
    FontWeight->"Bold"],
  ", p.321f) :"
}], "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(h[r_] := 
      Which[r < r0, r\/\(2  \[Pi]\ r0\^2\), r > r2, 0. , 
        r > r1, \(1\/\(2  \[Pi]\ r\)\) \(r2\^2 - r\^2\)\/\(r2\^2 - r1\^2\), 
        True, 1\/\(2  \[Pi]\ r\)]\), "\[IndentingNewLine]", 
    \(\(Plot[h[r], {r, 0, ns/2}, 
        AxesLabel -> {"\<r\>", "\<H(r)\>"}];\)\)}], "Input",
  CellLabel->"In[77]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P00025A000`40O003h00OogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00<1o
o`X000]oo`@0051oo``000]oo`@005Eoo`D000ioo`@005Ioo`L000Yoo`@005Aoo`H000ioo`@005Eo
o`D000eoo`@006ioo`00`7oo2P002Goo2000CWoo30002Goo2000DGoo2@002Woo2000E7oo1`0027oo
2000D7oo2P002Woo2000DGoo20002Woo2000K7oo0034Ool2000=Ool20004Ool2001?Ool30006Ool2
0009Ool20004Ool2001@Ool40004Ool30009Ool20004Ool2001GOol2000:Ool20004Ool2001@Ool3
0005Ool30009Ool20004Ool2001AOol20004Ool30009Ool20004Ool2001/Ool00<Aoo`8000aoo`80
00Ioo`8004moo`<000moo`8000Ioo`8004moo`8000Moo`<000Moo`8000Ioo`8005Ioo`8000Uoo`80
00Ioo`8005Qoo`8000Qoo`8000Ioo`8004moo`8000Ioo`<000Moo`8000Ioo`8006]oo`00a7oo0P00
37oo0P001Woo0P00D7oo0`003Woo0P001Woo0P00FGoo0P001goo0P001Woo0P00EWoo0P002Goo0P00
1Woo0P00FGoo0P001goo0P001Woo0P00CWoo0P0027oo0P001goo0P001Woo0P00Jgoo0034Ool2000;
Ool20008Ool2001@Ool3000<Ool20008Ool2001HOol20006Ool20008Ool2001=Ool<0006Ool20008
Ool2001HOol20006Ool20008Ool2001=Ool20008Ool20006Ool20008Ool2001ZOol00<Aoo`8000]o
o`8000Qoo`80055oo`<000]oo`8000Qoo`8005Qoo`8000Ioo`8000Qoo`8004eoo``000Ioo`8000Qo
o`8005Qoo`8000Ioo`8000Qoo`8004eoo`8000Qoo`8000Ioo`8000Qoo`8006Yoo`00a7oo0P002goo
0P0027oo0P00DWoo0`002Woo0P0027oo0P00Egoo0`001Woo0P0027oo0P00CGoo0P001Woo0P0000=o
o`00Ool01Goo0P0027oo0P00F7oo0P001Woo0P0027oo0P00CGoo0P0027oo0P001Woo0P0027oo0P00
JWoo0034Ool2000;Ool20008Ool2001COol30009Ool20008Ool2001FOol30007Ool20008Ool2001>
Ool20005Ool20008Ool20008Ool2001HOol20006Ool20008Ool2001=Ool30006Ool30006Ool20008
Ool2001ZOol00<Aoo`8000]oo`8000Qoo`8005Aoo`<000Qoo`8000Qoo`8005=oo`D000Qoo`8000Qo
o`8004ioo`<000Aoo`8000Qoo`8000Qoo`8005Moo`8000Moo`8000Qoo`8004eoo`@000Aoo`<000Mo
o`8000Qoo`8006Yoo`00a7oo0P002goo0P0027oo0P00EGoo0P0027oo0P0027oo0P00Dgoo10002Goo
0P0027oo0P00Cgoo0P0017oo0P0027oo0P0027oo0P00Cgoo0P001Goo0`001goo0P0027oo0P00CGoo
0P0000=oo`0000001@0027oo0P0027oo0P00JWoo0034Ool2000;Ool20008Ool2001FOol20007Ool2
0008Ool2001FOol20008Ool20008Ool2001@Ool20003Ool20008Ool20008Ool2001?Ool90008Ool2
0008Ool2001>Ool00`00Oomoo`050009Ool20008Ool2001ZOol00<Aoo`8000]oo`8000Qoo`8005Io
o`8000Moo`8000Qoo`8005Moo`8000Moo`8000Qoo`80051oo`<0009oo`8000Qoo`8000Qoo`8004mo
o`800003Ool0000000<000Uoo`8000Qoo`8004ioo`8000moo`8000Qoo`8006Yoo`00a7oo0P0037oo
0P001Woo0P00CWoo0P001goo0P0027oo0P001Woo0P00F7oo0P0027oo0P001Woo0P00DWoo0P000Woo
0P002Goo0P001Woo0P00D7oo0P0047oo0P001Woo0P00Cgoo0`003goo0P001Woo0P00Jgoo0034Ool2
000<Ool20006Ool2001>Ool30006Ool20008Ool20006Ool2001@Ool20006Ool20008Ool20006Ool2
001COol200000goo00000009Ool20006Ool2001@Ool2000@Ool20006Ool2001@Ool3000>Ool20006
Ool2001[Ool00<1oo`<00003Ool0000000eoo`8000Aoo`8004moo`@000Aoo`8000Yoo`8000Aoo`80
055oo`<000Aoo`<000Uoo`8000Aoo`8005Eoo`@000Yoo`8000Aoo`80055oo`80015oo`8000Aoo`80
059oo`<000ioo`8000Aoo`8006aoo`00`7oo1P003Goo2000D7oo20002goo2000DWoo20002Woo2000
EGoo10002Woo2000DGoo2P002Goo2000Dgoo200027oo2000K7oo0033Ool3000?Ool4001DOol5000>
Ool4001EOol5000>Ool4001HOol3000<Ool4001COol:000;Ool4001GOol6000:Ool4001^Ool00?mo
oomooomoof=oo`00ogooogooogooHgoo001SOol00`00Oomoo`3oOoooOoolOol006=oo`03001oogoo
0?mooomoooaoo`00Hgoo00<007ooOol0ogooogooo7oo001SOol00`00Oomoo`3oOoooOooSOol<000=
Ool006=oo`03001oogoo0?mooomoon=oo``000eoo`00Hgoo00<007ooOol0ogooogooigoo0P004goo
001SOol00`00Oomoo`3oOoooOooWOol2000COol006=oo`03001oogoo0?mooomoonMoo`8001=oo`00
Hgoo00<007ooOol0ogooogooigoo0P004goo001SOol00`00Oomoo`3oOoooOooWOol2000COol006=o
o`03001oogoo0?mooomoonMoo`8001=oo`00DGooo`00o`00h00077oo0P004goo001SOol00`00Oomo
o`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomo
o`0COol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomo
o`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomo
o`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomo
o`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomo
o`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomo
o`0COol00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`0BOol00`00Oomoo`0QOol3000BOol0
06=oo`8001=oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03
001oogoo01=oo`03001oogoo019oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03
001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03
001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03
001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03
001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03
001oogoo01=oo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo019oo`03001oogoo025oo`@0
015oo`00Hgoo00<007oo00004Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04goo00<0
07ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04goo00<0
07ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<0
07ooOol04goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04goo00<0
07ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<0
07ooOol04goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04goo00<0
07ooOol04Woo00<007ooOol04goo00<007ooOol01goo00<007ooOol027oo00<007ooOol04Woo00<0
07ooOol08Goo0P0000=oo`00000017oo0P002Woo001SOol01000Oomoo`00Igoo00<007ooOol0J7oo
00<007ooOol0JGoo00<007ooOol0J7oo00<007ooOol0JGoo00<007ooOol0J7oo00<007ooOol07Goo
00<007ooOol0?Woo1@000Woo1`002Woo001SOol01000Oomoo`00ogooogooXGoo00<007ooOol0?goo
1@0017oo10002goo001SOol01@00Oomoogoo0000ogooogooX7oo00<007ooOol0Egoo001SOol00`00
Oomoo`02Ool00`00Oomoo`3oOoooOonMOol00`00Oomoo`1GOol006=oo`03001oogoo00=oo`03001o
ogoo0?mooomooiaoo`03001oogoo05Moo`00Hgoo00<007ooOol00goo00<007ooOol0ogooogooW7oo
00<007ooOol0Egoo001SOol00`00Oomoo`04Ool00`00Oomoo`3oOoooOonJOol00`00Oomoo`1HOol0
06=oo`03001oogoo00Eoo`03001oogoo0?mooomooiUoo`03001oogoo05Qoo`00Hgoo00<007ooOol0
1Goo00<007ooOol0ogooogooVGoo00<007ooOol0F7oo001SOol00`00Oomoo`06Ool00`00Oomoo`3o
OoooOonHOol00`00Oomoo`1HOol006=oo`03001oogoo00Moo`03001oogoo0?mooomooiMoo`03001o
ogoo05Qoo`00Hgoo00<007ooOol027oo00<007ooOol0ogooogooUWoo00<007ooOol0F7oo001SOol3
0008Ool00`00Oomoo`3oOoooOonFOol00`00Oomoo`1HOol006=oo`03001oogoo00Uoo`03001oogoo
0?mooomooiEoo`03001oogoo05Qoo`00Hgoo00<007ooOol02Woo00<007ooOol0ogooogooTgoo00<0
07ooOol0FGoo001SOol00`00Oomoo`0;Ool00`00Oomoo`3oOoooOonBOol00`00Oomoo`1IOol006=o
o`03001oogoo00]oo`03001oogoo0?mooomooi9oo`03001oogoo05Uoo`00Hgoo00<007ooOol037oo
00<007ooOol0ogooogooTGoo00<007ooOol0FGoo001SOol00`00Oomoo`0=Ool00`00Oomoo`3oOooo
Oon@Ool00`00Oomoo`1IOol006=oo`03001oogoo00ioo`03001oogoo0?mooomoohmoo`03001oogoo
05Uoo`00Hgoo00<007ooOol03Woo00<007ooOol0ogooogooSgoo00<007ooOol0FGoo001SOol00`00
Oomoo`0?Ool00`00Oomoo`3oOoooOon>Ool00`00Oomoo`1IOol006=oo`03001oogoo011oo`03001o
ogoo0?mooomoohaoo`03001oogoo05Yoo`00Hgoo00<007ooOol04Goo00<007ooOol0ogooogooRgoo
00<007ooOol0FWoo001SOol00`00Oomoo`0AOol00`00Oomoo`3oOoooOon;Ool00`00Oomoo`1JOol0
06=oo`03001oogoo019oo`03001oogoo0?mooomoohYoo`03001oogoo05Yoo`00Hgoo00<007ooOol0
4goo00<007ooOol0ogooogooRGoo00<007ooOol0FWoo001SOol00`00Oomoo`0COol00`00Oomoo`3o
OoooOon9Ool00`00Oomoo`1JOol006=oo`<001Aoo`03001oogoo0?mooomoohQoo`03001oogoo05Yo
o`00Hgoo00<007ooOol05Goo00<007ooOol0ogooogooQgoo00<007ooOol0FWoo001SOol00`00Oomo
o`0FOol00`00Oomoo`3oOoooOon5Ool00`00Oomoo`1KOol006=oo`03001oogoo01Ioo`03001oogoo
0?mooomoohEoo`03001oogoo05]oo`00Hgoo00<007ooOol05goo00<007ooOol0ogooogooQ7oo00<0
07ooOol0Fgoo001SOol00`00Oomoo`0HOol00`00Oomoo`3oOoooOon3Ool00`00Oomoo`1KOol006=o
o`03001oogoo01Uoo`03001oogoo0?mooomooh9oo`03001oogoo05]oo`00Hgoo00<007ooOol06Goo
00<007ooOol0ogooogooPWoo00<007ooOol0Fgoo001SOol00`00Oomoo`0JOol00`00Oomoo`3oOooo
Oon1Ool00`00Oomoo`1KOol006=oo`03001oogoo01]oo`03001oogoo0?mooomoogmoo`03001oogoo
05aoo`00Hgoo00<007ooOol077oo00<007ooOol0ogooogooOWoo00<007ooOol0G7oo001SOol00`00
Oomoo`0LOol00`00Oomoo`3oOoooOomnOol00`00Oomoo`1LOol006=oo`03001oogoo01eoo`03001o
ogoo0?mooomoogeoo`03001oogoo05aoo`00Hgoo00<007ooOol07Woo00<007ooOol0ogooogooO7oo
00<007ooOol0G7oo001SOol00`00Oomoo`0OOol00`00Oomoo`3oOoooOomjOol00`00Oomoo`1MOol0
06=oo`03001oogoo01moo`03001oogoo0?mooomoogYoo`03001oogoo05eoo`00Hgoo00<007ooOol0
87oo00<007ooOol0ogooogooNGoo00<007ooOol0GGoo001SOol3000QOol00`00Oomoo`3oOoooOomh
Ool00`00Oomoo`1MOol006=oo`03001oogoo029oo`03001oogoo0?mooomoogMoo`03001oogoo05eo
o`00Hgoo00<007ooOol08Woo00<007ooOol0ogooogooMgoo00<007ooOol0GGoo001SOol00`00Oomo
o`0SOol00`00Oomoo`3oOoooOomeOol00`00Oomoo`1NOol006=oo`03001oogoo02Aoo`03001oogoo
0?mooomoogAoo`03001oogoo05ioo`00Hgoo00<007ooOol09Goo00<007ooOol0ogooogooLgoo00<0
07ooOol0GWoo001SOol00`00Oomoo`0UOol00`00Oomoo`3oOoooOomcOol00`00Oomoo`1NOol006=o
o`03001oogoo02Ioo`03001oogoo0?mooomoog9oo`03001oogoo05ioo`00Hgoo00<007ooOol09goo
00<007ooOol0ogooogooL7oo00<007ooOol0Ggoo001SOol00`00Oomoo`0XOol00`00Oomoo`3oOooo
Oom_Ool00`00Oomoo`1OOol006=oo`03001oogoo02Uoo`03001oogoo0?mooomoofioo`03001oogoo
05moo`00Hgoo00<007ooOol0:Goo00<007ooOol0ogooogooKWoo00<007ooOol0Ggoo001SOol00`00
Oomoo`0ZOol00`00Oomoo`3oOoooOom]Ool00`00Oomoo`1OOol006=oo`03001oogoo02]oo`03001o
ogoo0?mooomoofaoo`03001oogoo05moo`00Hgoo00<007ooOol0;7oo00<007ooOol0ogooogooJWoo
00<007ooOol0H7oo001SOol00`00Oomoo`0/Ool00`00Oomoo`3oOoooOomZOol00`00Oomoo`1POol0
06=oo`<002eoo`03001oogoo0?mooomoofUoo`03001oogoo061oo`00Hgoo00<007ooOol0;Woo00<0
07ooOol0ogooogooJ7oo00<007ooOol0H7oo001SOol00`00Oomoo`0_Ool00`00Oomoo`3oOoooOomW
Ool00`00Oomoo`1POol006=oo`03001oogoo02moo`03001oogoo0?mooomoofMoo`03001oogoo061o
o`00Hgoo00<007ooOol0<7oo00<007ooOol0ogooogooIWoo00<007ooOol0H7oo001SOol00`00Oomo
o`0aOol00`00Oomoo`3oOoooOomTOol00`00Oomoo`1QOol006=oo`03001oogoo039oo`03001oogoo
0?mooomoof=oo`03001oogoo065oo`00Hgoo00<007ooOol0<Woo00<007ooOol0ogooogooHgoo00<0
07ooOol0HGoo001SOol00`00Oomoo`0cOol00`00Oomoo`3oOoooOomROol00`00Oomoo`1QOol000Mo
o`@000ioo`<000moo`@000ioo`@000]oo`X000eoo`03001oogoo03Aoo`03001oogoo0?mooomoof5o
o`03001oogoo065oo`001Goo20002goo1@0037oo20002Woo20002Goo2P003Goo00<007ooOol0=Goo
00<007ooOol0ogooogooH7oo00<007ooOol0HGoo0005Ool20004Ool2000;Ool5000<Ool20004Ool2
000:Ool20004Ool2000=Ool2000AOol00`00Oomoo`0eOol00`00Oomoo`3oOoooOomPOol00`00Oomo
o`1QOol000Aoo`8000Ioo`8000Yoo`D000]oo`8000Ioo`8000Qoo`8000Ioo`8000aoo`80015oo`03
001oogoo03Ioo`03001oogoo0?mooomooeioo`03001oogoo069oo`0017oo0P001Woo0P002goo0`00
37oo0P001Woo0P0027oo0P001Woo0P0037oo0P004Goo00<007ooOol0=goo00<007ooOol0ogooogoo
GGoo00<007ooOol0HWoo0003Ool20008Ool2000HOol20008Ool20006Ool20008Ool2000;Ool2000A
Ool00`00Oomoo`0hOol00`00Oomoo`3oOoooOomLOol00`00Oomoo`1ROol000=oo`8000Qoo`8001Qo
o`8000Qoo`8000Ioo`8000Qoo`8000]oo`80015oo`03001oogoo03Qoo`03001oogoo0?mooomooeao
o`03001oogoo069oo`000goo0P0027oo0P0067oo0P0027oo0P001Woo0P0027oo0P002goo0P004Goo
1@00=goo00<007ooOol0ogooogooFgoo00<007ooOol0HWoo0003Ool20008Ool2000HOol20008Ool2
0006Ool20008Ool2000;Ool2000AOol00`00Oomoo`0jOol00`00Oomoo`3oOoooOomJOol00`00Oomo
o`1ROol000=oo`8000Qoo`8001Qoo`8000Qoo`8000Ioo`8000Qoo`8000]oo`80015oo`03001oogoo
03]oo`03001oogoo0?mooomooeUoo`03001oogoo069oo`000goo0P0027oo0P0067oo0P0027oo0P00
1Woo0P0027oo0P002goo0P004Goo00<007ooOol0>goo00<007ooOol0ogooogooF7oo00<007ooOol0
Hgoo0003Ool20008Ool2000HOol20008Ool20006Ool20008Ool2000;Ool2000AOol00`00Oomoo`0l
Ool00`00Oomoo`3oOoooOomGOol00`00Oomoo`1SOol000=oo`8000Qoo`8001Qoo`8000Qoo`8000Io
o`8000Qoo`8000]oo`80015oo`03001oogoo03eoo`03001oogoo0?mooomooeIoo`03001oogoo06=o
o`0017oo0P001Woo0P006Woo0P001Woo0P0027oo0P001Woo0P0037oo0P004Goo00<007ooOol0?Woo
00<007ooOol0ogooogooEGoo00<007ooOol0Hgoo0004Ool20006Ool2000JOol20006Ool20008Ool2
0006Ool2000<Ool2000AOol00`00Oomoo`0nOol00`00Oomoo`3oOoooOomEOol00`00Oomoo`1SOol0
00Eoo`8000Aoo`8001aoo`8000Aoo`8000Yoo`8000Aoo`8000Uoo`<00003Ool00000015oo`03001o
ogoo03moo`03001oogoo0?mooomooeAoo`03001oogoo06=oo`001Goo200077oo20002Woo20002Goo
1P004Goo00<007ooOol0@7oo00<007ooOol0ogooogooDgoo00<007ooOol0Hgoo0007Ool4000POol4
000>Ool4000>Ool3000AOol00`00Oomoo`11Ool00`00Oomoo`3oOoooOomAOol00`00Oomoo`1TOol0
06=oo`03001oogoo045oo`03001oogoo0?mooomooe5oo`03001oogoo06Aoo`00Hgoo00<007ooOol0
@Woo00<007ooOol0ogooogooD7oo00<007ooOol0I7oo001SOol00`00Oomoo`13Ool00`00Oomoo`3o
OoooOom?Ool00`00Oomoo`1TOol006=oo`03001oogoo04Aoo`03001oogoo0?mooomoodioo`03001o
ogoo06Aoo`00Hgoo00<007ooOol0A7oo00<007ooOol0ogooogooCWoo00<007ooOol0I7oo001SOol0
0`00Oomoo`15Ool00`00Oomoo`3oOoooOom=Ool00`00Oomoo`1TOol006=oo`<004Ioo`03001oogoo
0?mooomood]oo`03001oogoo06Eoo`00Hgoo00<007ooOol0Agoo00<007ooOol0ogooogooBWoo00<0
07ooOol0IGoo001SOol00`00Oomoo`17Ool00`00Oomoo`3oOoooOom:Ool00`00Oomoo`1UOol006=o
o`03001oogoo04Qoo`03001oogoo0?mooomoodUoo`03001oogoo06Eoo`00Hgoo00<007ooOol0BGoo
00<007ooOol0ogooogooB7oo00<007ooOol0IGoo001SOol00`00Oomoo`19Ool00`00Oomoo`3oOooo
Oom8Ool00`00Oomoo`1UOol006=oo`03001oogoo04Yoo`03001oogoo0?mooomoodMoo`03001oogoo
06Eoo`00Hgoo00<007ooOol0Bgoo00<007ooOol0ogooogooAGoo00<007ooOol0IWoo001SOol00`00
Oomoo`1<Ool00`00Oomoo`3oOoooOom4Ool00`00Oomoo`1VOol006=oo`03001oogoo04aoo`03001o
ogoo0?mooomoodAoo`03001oogoo06Ioo`00Hgoo00<007ooOol0CGoo00<007ooOol0ogooogoo@goo
00<007ooOol0IWoo001SOol00`00Oomoo`1>Ool00`00Oomoo`3oOoooOom2Ool00`00Oomoo`1VOol0
06=oo`03001oogoo04moo`03001oogoo0?mooomood5oo`03001oogoo06Ioo`00Hgoo00<007ooOol0
Cgoo00<007ooOol0ogooogoo@7oo00<007ooOol0Igoo001SOol00`00Oomoo`1@Ool00`00Oomoo`3o
OoooOoloOol00`00Oomoo`1WOol006=oo`03001oogoo055oo`03001oogoo0?mooomoocioo`03001o
ogoo06Moo`00Hgoo0`00DWoo00<007ooOol0ogooogoo?Goo00<007ooOol0Igoo001SOol00`00Oomo
o`1BOol00`00Oomoo`3oOoooOolmOol00`00Oomoo`1WOol006=oo`03001oogoo05=oo`03001oogoo
0?mooomoocaoo`03001oogoo06Moo`00Hgoo00<007ooOol0E7oo00<007ooOol0ogooogoo>goo00<0
07ooOol0Igoo001SOol00`00Oomoo`1EOol00`00Oomoo`3oOoooOoliOol00`00Oomoo`1XOol006=o
o`03001oogoo05Eoo`03001oogoo0?mooomoocUoo`03001oogoo06Qoo`00Hgoo00<007ooOol0EWoo
00<007ooOol0ogooogoo>7oo00<007ooOol0J7oo001SOol00`00Oomoo`1GOol00`00Oomoo`3oOooo
OolgOol00`00Oomoo`1XOol006=oo`03001oogoo05Qoo`03001oogoo0?mooomoocIoo`03001oogoo
06Qoo`00Hgoo00<007ooOol0F7oo00<007ooOol0ogooogoo=Woo00<007ooOol0J7oo001SOol00`00
Oomoo`1IOol00`00Oomoo`3oOoooOoleOol00`00Oomoo`1XOol006=oo`03001oogoo05Yoo`03001o
ogoo0?mooomooc=oo`03001oogoo06Uoo`00Hgoo00<007ooOol0Fgoo00<007ooOol0ogooogoo<Woo
00<007ooOol0JGoo001SOol00`00Oomoo`1KOol00`00Oomoo`3oOoooOolbOol00`00Oomoo`1YOol0
06=oo`03001oogoo05aoo`03001oogoo0?mooomooc5oo`03001oogoo06Uoo`00Hgoo00<007ooOol0
GGoo00<007ooOol0ogooogoo<7oo00<007ooOol0JGoo001SOol3001MOol00`00Oomoo`3oOoooOol`
Ool00`00Oomoo`1YOol006=oo`03001oogoo05ioo`03001oogoo0?mooomoobmoo`03001oogoo06Uo
o`00Hgoo00<007ooOol0Ggoo00<007ooOol0ogooogoo;Goo00<007ooOol0JWoo001SOol00`00Oomo
o`1POol00`00Oomoo`3oOoooOol/Ool00`00Oomoo`1ZOol006=oo`03001oogoo061oo`03001oogoo
0?mooomoobaoo`03001oogoo06Yoo`00Hgoo00<007ooOol0HGoo00<007ooOol0ogooogoo:goo00<0
07ooOol0JWoo001SOol00`00Oomoo`1ROol00`00Oomoo`3oOoooOolZOol00`00Oomoo`1ZOol006=o
o`03001oogoo06=oo`03001oogoo0?mooomoobUoo`03001oogoo06Yoo`00Hgoo00<007ooOol0Hgoo
00<007ooOol0ogooogoo:Goo00<007ooOol0JWoo001SOol00`00Oomoo`1TOol00`00Oomoo`3oOooo
OolWOol00`00Oomoo`1[Ool006=oo`03001oogoo06Eoo`03001oogoo0?mooomoobIoo`03001oogoo
06]oo`00Hgoo00<007ooOol0IWoo00<007ooOol0ogooogoo9Goo00<007ooOol0Jgoo001SOol00`00
Oomoo`1VOol00`00Oomoo`3oOoooOolUOol00`00Oomoo`1[Ool006=oo`03001oogoo06Moo`03001o
ogoo0?mooomoobAoo`03001oogoo06]oo`00Hgoo00<007ooOol0J7oo00<007ooOol0ogooogoo8goo
00<007ooOol0Jgoo001SOol00`00Oomoo`1YOol00`00Oomoo`3oOoooOolROol00`00Oomoo`1[Ool0
06=oo`<006Uoo`03001oogoo0?mooomoob5oo`03001oogoo06aoo`00Hgoo00<007ooOol0JWoo00<0
07ooOol0ogooogoo87oo00<007ooOol0K7oo001SOol00`00Oomoo`1[Ool00`00Oomoo`3oOoooOolO
Ool00`00Oomoo`1/Ool006=oo`03001oogoo06]oo`03001oogoo0?mooomooamoo`03001oogoo06ao
o`00Hgoo00<007ooOol0K7oo00<007ooOol0ogooogoo7Woo00<007ooOol0K7oo001SOol00`00Oomo
o`1]Ool00`00Oomoo`3oOoooOolMOol00`00Oomoo`1/Ool006=oo`03001oogoo06ioo`03001oogoo
0?mooomooaaoo`03001oogoo06aoo`00Hgoo00<007ooOol0KWoo00<007ooOol0ogooogoo6goo00<0
07ooOol0KGoo001SOol00`00Oomoo`1_Ool00`00Oomoo`3oOoooOolJOol00`00Oomoo`1]Ool006=o
o`03001oogoo071oo`03001oogoo0?mooomooaUoo`03001oogoo06eoo`001goo10003Woo0`003goo
10003Woo10002Goo30003Goo00<007ooOol0LGoo00<007ooOol0ogooogoo67oo00<007ooOol0KGoo
0005Ool8000;Ool5000<Ool8000:Ool80007Ool<000=Ool00`00Oomoo`1aOol00`00Oomoo`3oOooo
OolHOol00`00Oomoo`1]Ool000Eoo`8000Aoo`8000]oo`D000aoo`8000Aoo`8000Yoo`8000Aoo`80
00Qoo`<000Ioo`8000eoo`03001oogoo079oo`03001oogoo0?mooomooaMoo`03001oogoo06eoo`00
17oo0P001Woo0P002Woo1@002goo0P001Woo0P0027oo0P001Woo0P0027oo0`0057oo00<007ooOol0
Lgoo00<007ooOol0ogooogoo5Goo00<007ooOol0KWoo0004Ool20006Ool2000;Ool3000<Ool20006
Ool20008Ool20006Ool20009Ool3000COol00`00Oomoo`1dOol00`00Oomoo`3oOoooOolDOol00`00
Oomoo`1^Ool000=oo`8000Qoo`8001Qoo`8000Qoo`8000Ioo`8000Qoo`8000Uoo`<0019oo`03001o
ogoo07Aoo`03001oogoo0?mooomooaAoo`03001oogoo06ioo`000goo0P0027oo0P0067oo0P0027oo
0P001Woo0P0027oo0P002Woo0`004Goo00<007ooOol0MGoo00<007ooOol0ogooogoo4goo00<007oo
Ool0KWoo0003Ool20008Ool2000HOol20008Ool20006Ool20008Ool2000;Ool3000@Ool5001dOol0
0`00Oomoo`3oOoooOolBOol00`00Oomoo`1^Ool000=oo`8000Qoo`8001Qoo`8000Qoo`8000Ioo`80
00Qoo`8000aoo`<000moo`03001oogoo07Moo`03001oogoo0?mooomooa5oo`03001oogoo06ioo`00
0goo0P0027oo0P0067oo0P0027oo0P001Woo0P0027oo0P003Goo0`003Woo00<007ooOol0Mgoo00<0
07ooOol0ogooogoo4Goo00<007ooOol0KWoo0003Ool20008Ool2000HOol20008Ool20006Ool20008
Ool2000>Ool2000>Ool00`00Oomoo`1hOol00`00Oomoo`3oOoooOol?Ool00`00Oomoo`1_Ool000=o
o`8000Qoo`8001Qoo`8000Qoo`8000Ioo`8000Qoo`8000moo`8000eoo`03001oogoo07Uoo`03001o
ogoo0?mooomoo`ioo`03001oogoo06moo`000goo0P0027oo0P0067oo0P0027oo0P001Woo0P0027oo
0P003goo0P003Goo00<007ooOol0NWoo00<007ooOol0ogooogoo3Goo00<007ooOol0Kgoo0004Ool2
0006Ool2000JOol20006Ool20008Ool20006Ool20007Ool20007Ool2000=Ool00`00Oomoo`1jOol0
0`00Oomoo`3oOoooOol=Ool00`00Oomoo`1_Ool000Aoo`8000Ioo`8001Yoo`8000Ioo`8000Qoo`80
00Ioo`8000Moo`<000Ioo`8000eoo`03001oogoo07]oo`03001oogoo0?mooomoo`aoo`03001oogoo
06moo`001Goo0P0017oo0P0077oo0P0017oo0P002Woo0P0017oo0P0027oo100017oo0P003Woo00<0
07ooOol0O7oo00<007ooOol0ogooogoo2goo00<007ooOol0Kgoo0005Ool8000LOol8000:Ool80009
Ool8000?Ool00`00Oomoo`1mOol00`00Oomoo`3oOoooOol:Ool00`00Oomoo`1_Ool000Moo`@0021o
o`@000ioo`@000eoo`D0011oo`03001oogoo07eoo`03001oogoo0?mooomoo`Uoo`03001oogoo071o
o`00Hgoo00<007ooOol0OWoo00<007ooOol0ogooogoo27oo00<007ooOol0L7oo001SOol00`00Oomo
o`1oOol00`00Oomoo`3oOoooOol7Ool00`00Oomoo`1`Ool006=oo`03001oogoo081oo`03001oogoo
0?mooomoo`Ioo`03001oogoo071oo`00Hgoo00<007ooOol0P7oo00<007ooOol0ogooogoo1Woo00<0
07ooOol0L7oo001SOol00`00Oomoo`21Ool00`00Oomoo`3oOoooOol5Ool00`00Oomoo`1`Ool006=o
o`<0089oo`03001oogoo0?mooomoo`=oo`03001oogoo075oo`00Hgoo00<007ooOol0PWoo00<007oo
Ool0ogooogoo0goo00<007ooOol0LGoo001SOol00`00Oomoo`23Ool00`00Oomoo`3oOoooOol2Ool0
0`00Oomoo`1aOol006=oo`03001oogoo08Aoo`03001oogoo0?mooomoo`5oo`03001oogoo075oo`00
Hgoo00<007ooOol0QGoo00<007ooOol0ogooogoo00<007ooOol0LGoo001SOol00`00Oomoo`25Ool0
0`00Oomoo`3oOoooOol00`00Oomoo`1aOol006=oo`03001oogoo08Ioo`03001oogoo0?moooioo`03
001oogoo075oo`00Hgoo00<007ooOol0Qgoo00<007ooOol0ogooo7oo00<007ooOol0LWoo001SOol0
0`00Oomoo`28Ool00`00Oomoo`3oOookOol00`00Oomoo`1bOol006=oo`03001oogoo08Qoo`03001o
ogoo0?mooo]oo`03001oogoo079oo`00Hgoo00<007ooOol0RGoo00<007ooOol0ogoonWoo00<007oo
Ool0LWoo001SOol00`00Oomoo`2:Ool00`00Oomoo`3oOooiOol00`00Oomoo`1bOol006=oo`03001o
ogoo08]oo`03001oogoo0?moooQoo`03001oogoo079oo`00Hgoo00<007ooOol0Rgoo00<007ooOol0
ogoon7oo00<007ooOol0LWoo001SOol00`00Oomoo`2<Ool00`00Oomoo`3oOoofOol00`00Oomoo`1c
Ool006=oo`03001oogoo08eoo`03001oogoo0?moooEoo`03001oogoo07=oo`00Hgoo0`00SWoo00<0
07ooOol0ogoom7oo00<007ooOol0Lgoo001SOol00`00Oomoo`2>Ool00`00Oomoo`3oOoodOol00`00
Oomoo`1cOol006=oo`03001oogoo08moo`03001oogoo0?mooo=oo`03001oogoo07=oo`00Hgoo00<0
07ooOol0T7oo00<007ooOol0ogoolWoo00<007ooOol0Lgoo001SOol00`00Oomoo`2AOol00`00Oomo
o`3oOooaOol00`00Oomoo`1cOol006=oo`03001oogoo095oo`03001oogoo0?mooo1oo`03001oogoo
07Aoo`00Hgoo00<007ooOol0TWoo00<007ooOol0ogookgoo00<007ooOol0M7oo001SOol00`00Oomo
o`2COol00`00Oomoo`3oOoo^Ool00`00Oomoo`1dOol006=oo`03001oogoo09Aoo`03001oogoo0?mo
oneoo`03001oogoo07Aoo`00Hgoo00<007ooOol0U7oo00<007ooOol0ogookGoo00<007ooOol0M7oo
001SOol00`00Oomoo`2EOol00`00Oomoo`3oOoo/Ool00`00Oomoo`1dOol006=oo`03001oogoo09Io
o`03001oogoo0?moon]oo`03001oogoo07Aoo`00Hgoo00<007ooOol0Ugoo00<007ooOol0ogoojWoo
00<007ooOol0M7oo001SOol00`00Oomoo`2GOol00`00Oomoo`3oOooYOol00`00Oomoo`1eOol006=o
o`03001oogoo09Qoo`03001oogoo0?moonQoo`03001oogoo07Eoo`00Hgoo00<007ooOol0VGoo00<0
07ooOol0ogooigoo00<007ooOol0MGoo001SOol00`00Oomoo`2JOol00`00Oomoo`3oOooVOol00`00
Oomoo`1eOol006=oo`<009Yoo`03001oogoo0?moonIoo`03001oogoo07Eoo`00Hgoo00<007ooOol0
Vgoo00<007ooOol0ogooiGoo00<007ooOol0MGoo001SOol00`00Oomoo`2LOol00`00Oomoo`3oOooT
Ool00`00Oomoo`1eOol006=oo`03001oogoo09eoo`03001oogoo0?moon9oo`03001oogoo07Ioo`00
Hgoo00<007ooOol0WGoo00<007ooOol0ogooh7oo0`00N7oo001SOol00`00Oomoo`2NOol00`00Oomo
o`3oOooLOol3001kOol006=oo`03001oogoo09moo`03001oogoo0?moomUoo`8007ioo`00Hgoo00<0
07ooOol0Wgoo00<007ooOol0ogooegoo0P00P7oo001SOol00`00Oomoo`2POol00`00Oomoo`3oOooB
Ool40022Ool006=oo`03001oogoo0:5oo`03001oogoo0?moolioo`<008Ioo`00Hgoo00<007ooOol0
XWoo00<007ooOol0ogoobWoo0`00RGoo001SOol00`00Oomoo`2ROol00`00Oomoo`3oOoo7Ool3002<
Ool006=oo`03001oogoo0:=oo`03001oogoo0?moolAoo`8008moo`00Hgoo00<007ooOol0Y7oo00<0
07ooOol0ogoo`7oo0`00TGoo001SOol00`00Oomoo`2UOol00`00Oomoo`3oOonmOol2002DOol006=o
o`03001oogoo0:Eoo`03001oogoo0?mookYoo`<009Ioo`00Hgoo0`00YWoo00<007ooOol0ogoo]goo
0P00VGoo001SOol00`00Oomoo`2WOol00`00Oomoo`3oOoncOol3002KOol006=oo`03001oogoo0:Qo
o`03001oogoo0?moojmoo`<009ioo`00Hgoo00<007ooOol0Z7oo00<007ooOol0ogoo[7oo0`00XGoo
001SOol00`00Oomoo`2YOol00`00Oomoo`3oOonYOol2002TOol006=oo`03001oogoo0:Yoo`03001o
ogoo0?moojEoo`<00:Ioo`00Hgoo00<007ooOol0Zgoo00<007ooOol0ogooXGoo0`00ZGoo001SOol0
0`00Oomoo`2[Ool00`00Oomoo`3oOonOOol2002/Ool006=oo`03001oogoo0:aoo`03001oogoo0?mo
oi]oo`<00:ioo`001goo10003Woo0`003goo10003Woo10003Goo1@0047oo00<007ooOol0[Goo00<0
07ooOol0ogooUgoo0`00/Goo0005Ool8000;Ool5000<Ool8000:Ool80009Ool9000>Ool00`00Oomo
o`2^Ool00`00Oomoo`3oOonCOol3002dOol000Eoo`8000Aoo`8000]oo`D000aoo`8000Aoo`8000Yo
o`8000Aoo`8000Qoo`@000Aoo`<000eoo`03001oogoo0:ioo`03001oogoo0?mooi5oo`800;Moo`00
17oo0P001Woo0P002Woo1@002goo0P001Woo0P0027oo0P001Woo0P001goo0P001goo0`0037oo00<0
07ooOol0[goo00<007ooOol0ogooSGoo0`00^Goo0004Ool20006Ool2000;Ool3000<Ool20006Ool2
0008Ool20006Ool2000AOol2000<Ool00`00Oomoo`2`Ool00`00Oomoo`3oOon:Ool2002lOol000=o
o`8000Qoo`8001Qoo`8000Qoo`8000Ioo`8000Qoo`80011oo`8000aoo`03001oogoo0;5oo`03001o
ogoo0?moohMoo`800;ioo`000goo0P0027oo0P0067oo0P0027oo0P001Woo0P0027oo0P0047oo0P00
37oo00<007ooOol0/Goo00<007ooOol0ogooQ7oo0`00`7oo0003Ool20008Ool2000HOol20008Ool2
0006Ool20008Ool2000?Ool3000<Ool5002`Ool00`00Oomoo`3oOon1Ool20033Ool000=oo`8000Qo
o`8001Qoo`8000Qoo`8000Ioo`8000Qoo`8000ioo`<000eoo`03001oogoo0;=oo`03001oogoo0?mo
ogioo`800<Eoo`000goo0P0027oo0P0067oo0P0027oo0P001Woo0P0027oo0P002goo1@003Woo00<0
07ooOol0]7oo00<007ooOol0ogooNWoo0`00agoo0003Ool20008Ool2000HOol20008Ool20006Ool2
0008Ool2000;Ool4000?Ool00`00Oomoo`2dOol00`00Oomoo`3oOomhOol2003:Ool000=oo`8000Qo
o`8001Qoo`8000Qoo`8000Ioo`8000Qoo`8000ioo`8000ioo`03001oogoo0;Eoo`03001oogoo0?mo
ogEoo`800<aoo`000goo0P0027oo0P0067oo0P0027oo0P001Woo0P0027oo0P003goo0P003Goo00<0
07ooOol0]Woo00<007ooOol0ogooLGoo0`00cWoo0004Ool20006Ool2000JOol20006Ool20008Ool2
0006Ool2000@Ool2000=Ool00`00Oomoo`2gOol00`00Oomoo`3oOom^Ool2003AOol000Aoo`8000Io
o`8001Yoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000eoo`03001oogoo0;Moo`03001o
ogoo0?moofaoo`800==oo`001Goo0P0017oo0P0077oo0P0017oo0P002Woo0P0017oo0P002Goo0`00
17oo0`003Goo00<007ooOol0^7oo00<007ooOol0ogooJGoo0P00eGoo0005Ool8000LOol8000:Ool8
000:Ool8000>Ool00`00Oomoo`2iOol00`00Oomoo`3oOomVOol2003GOol000Moo`@0021oo`@000io
o`@000eoo`D0011oo`03001oogoo0;Yoo`03001oogoo0?moof=oo`800=Uoo`00Hgoo00<007ooOol0
^Woo00<007ooOol0ogooHGoo0P00fgoo001SOol00`00Oomoo`2kOol00`00Oomoo`3oOomNOol2003M
Ool006=oo`03001oogoo0;aoo`03001oogoo0?mooe]oo`800=moo`00Hgoo00<007ooOol0_Goo00<0
07ooOol0ogooEgoo0`00hGoo001SOol00`00Oomoo`2mOol00`00Oomoo`3oOomEOol2003TOol006=o
o`<00;ioo`03001oogoo0?mooe9oo`800>Ioo`00Hgoo00<007ooOol0_goo00<007ooOol0ogooCgoo
0P00j7oo001SOol00`00Oomoo`30Ool00`00Oomoo`3oOom<Ool2003ZOol006=oo`03001oogoo0<1o
o`03001oogoo0?moodYoo`800>aoo`00Hgoo00<007ooOol0`Goo00<007ooOol0ogooAgoo0P00kWoo
001SOol00`00Oomoo`32Ool00`00Oomoo`3oOom4Ool2003`Ool006=oo`03001oogoo0<=oo`03001o
ogoo0?mood5oo`800?9oo`00Hgoo00<007ooOol0`goo00<007ooOol0ogoo?goo0P00m7oo001SOol0
0`00Oomoo`34Ool00`00Oomoo`3oOolmOol00`00Oomoo`3dOol006=oo`03001oogoo0<Eoo`03001o
ogoo0?moocYoo`800?Moo`00Hgoo00<007ooOol0aWoo00<007ooOol0ogoo=goo0P00nGoo001SOol0
0`00Oomoo`36Ool00`00Oomoo`3oOoleOol2003kOol006=oo`03001oogoo0<Moo`03001oogoo0?mo
oc9oo`800?eoo`00Hgoo00<007ooOol0b7oo00<007ooOol0ogoo;goo0P00ogoo001SOol00`00Oomo
o`39Ool00`00Oomoo`3oOol]Ool00`00Oomoo`3oOol006=oo`03001oogoo0<Uoo`03001oogoo0?mo
ob]oo`800?moo`=oo`00Hgoo00<007ooOol0bWoo00<007ooOol0ogoo:7oo0P00ogoo1Goo001SOol3
003;Ool00`00Oomoo`3oOolUOol2003oOol7Ool006=oo`03001oogoo0<aoo`03001oogoo0?moob9o
o`800?moo`Uoo`00Hgoo00<007ooOol0c7oo00<007ooOol0ogoo8Goo00<007ooOol0ogoo2Goo001S
Ool00`00Oomoo`3=Ool00`00Oomoo`3oOolNOol2003oOol<Ool006=oo`03001oogoo0<ioo`03001o
ogoo0?mooa]oo`800?moo`ioo`00Hgoo00<007ooOol0cgoo00<007ooOol0ogoo67oo0P00ogoo47oo
001SOol00`00Oomoo`3?Ool00`00Oomoo`3oOolGOol00`00Oomoo`3oOol@Ool006=oo`03001oogoo
0=1oo`03001oogoo0?mooaAoo`800?mooa=oo`00Hgoo00<007ooOol0dGoo00<007ooOol0ogoo4Goo
0P00ogoo5Goo001SOol00`00Oomoo`3BOol00`00Oomoo`3oOol?Ool00`00Oomoo`3oOolEOol006=o
o`03001oogoo0=9oo`03001oogoo0?moo`eoo`800?mooaQoo`00Hgoo00<007ooOol0dgoo00<007oo
Ool0ogoo2Woo0P00ogoo6Woo001SOol00`00Oomoo`3DOol00`00Oomoo`3oOol8Ool00`00Oomoo`3o
OolJOol006=oo`03001oogoo0=Eoo`03001oogoo0?moo`Eoo`800?mooaeoo`00Hgoo00<007ooOol0
eGoo00<007ooOol0ogoo0goo0P00ogoo7goo001SOol00`00Oomoo`3FOol00`00Oomoo`3oOol1Ool0
0`00Oomoo`3oOolOOol006=oo`<00=Moo`03001oogoo0?eoo`800?moob9oo`00Hgoo00<007ooOol0
f7oo00<007ooOol0nWoo0P00ogoo97oo001SOol00`00Oomoo`3HOol00`00Oomoo`3iOol00`00Oomo
o`3oOolTOol006=oo`03001oogoo0=Uoo`03001oogoo0?Ioo`800?moobMoo`00Hgoo00<007ooOol0
fWoo00<007ooOol0lgoo0P00ogoo:Goo001SOol00`00Oomoo`3KOol00`00Oomoo`3aOol00`00Oomo
o`3oOolYOol006=oo`03001oogoo0=]oo`03001oogoo0>moo`800?moobaoo`00Hgoo00<007ooOol0
g7oo00<007ooOol0kGoo00<007ooOol0ogoo;7oo001SOol00`00Oomoo`3MOol00`00Oomoo`3ZOol2
003oOol_Ool006=oo`03001oogoo0=ioo`03001oogoo0>Qoo`03001oogoo0?moobmoo`00Hgoo00<0
07ooOol0gWoo00<007ooOol0iWoo0P00ogoo<Woo001SOol00`00Oomoo`3OOol00`00Oomoo`3TOol0
0`00Oomoo`3oOolbOol006=oo`03001oogoo0>1oo`03001oogoo0>5oo`800?moocEoo`00Hgoo00<0
07ooOol0hGoo00<007ooOol0ggoo00<007ooOol0ogoo=Goo001SOol00`00Oomoo`3QOol00`00Oomo
o`3MOol2003oOolhOol006=oo`03001oogoo0>9oo`03001oogoo0=]oo`03001oogoo0?moocQoo`00
Hgoo0`00hgoo00<007ooOol0f7oo0P00ogoo>goo001SOol00`00Oomoo`3TOol00`00Oomoo`3FOol0
0`00Oomoo`3oOolkOol006=oo`03001oogoo0>Aoo`03001oogoo0=Aoo`800?moocioo`00Hgoo00<0
07ooOol0iGoo00<007ooOol0dWoo00<007ooOol0ogoo?Woo001SOol00`00Oomoo`3VOol00`00Oomo
o`3?Ool2003oOom1Ool006=oo`03001oogoo0>Moo`03001oogoo0<eoo`03001oogoo0?mood5oo`00
Hgoo00<007ooOol0igoo00<007ooOol0bgoo0P00ogooA7oo001SOol00`00Oomoo`3XOol00`00Oomo
o`39Ool00`00Oomoo`3oOom4Ool006=oo`03001oogoo0>Uoo`03001oogoo0<Ioo`800?moodMoo`00
Hgoo00<007ooOol0jWoo00<007ooOol0a7oo00<007ooOol0ogooAgoo0007Ool4000>Ool3000?Ool4
000>Ool4000?Ool7000<Ool00`00Oomoo`3ZOol00`00Oomoo`32Ool2003oOom:Ool000Eoo`P000]o
o`D000aoo`P000Yoo`P000eoo`L000aoo`03001oogoo0>]oo`03001oogoo0<1oo`03001oogoo0?mo
odYoo`001Goo0P0017oo0P002goo1@0037oo0P0017oo0P002Woo0P0017oo0P0047oo0P003Woo00<0
07ooOol0k7oo00<007ooOol0_Woo00<007ooOol0ogooBgoo0004Ool20006Ool2000:Ool5000;Ool2
0006Ool20008Ool20006Ool2000?Ool2000>Ool00`00Oomoo`3]Ool00`00Oomoo`2lOol00`00Oomo
o`3oOom<Ool000Aoo`8000Ioo`8000]oo`<000aoo`8000Ioo`8000Qoo`8000Ioo`8000moo`8000io
o`03001oogoo0>eoo`03001oogoo0;Yoo`800?moodmoo`000goo0P0027oo0P0067oo0P0027oo0P00
1Woo0P0027oo0P001Woo300037oo00<007ooOol0kWoo00<007ooOol0^7oo00<007ooOol0ogooCgoo
0003Ool20008Ool2000HOol20008Ool20006Ool20008Ool20006Ool<000<Ool00`00Oomoo`3_Ool0
0`00Oomoo`2fOol00`00Oomoo`3oOom@Ool000=oo`8000Qoo`8001Qoo`8000Qoo`8000Ioo`8000Qo
o`8000Ioo`8000Ioo`800003Ool007oo00]oo`D00>ioo`03001oogoo0;=oo`800?mooe=oo`000goo
0P0027oo0P0067oo0P0027oo0P001Woo0P0027oo0P001goo0P001Goo0P003Woo00<007ooOol0l7oo
00<007ooOol0/Woo00<007ooOol0ogooDgoo0003Ool20008Ool2000HOol20008Ool20006Ool20008
Ool20007Ool30004Ool2000>Ool00`00Oomoo`3aOol00`00Oomoo`2`Ool00`00Oomoo`3oOomDOol0
00=oo`8000Qoo`8001Qoo`8000Qoo`8000Ioo`8000Qoo`8000Qoo`8000Aoo`8000ioo`03001oogoo
0?9oo`03001oogoo0:ioo`03001oogoo0?mooeEoo`000goo0P0027oo0P0067oo0P0027oo0P001Woo
0P0027oo0P002Goo0P000goo0P003Woo00<007ooOol0lgoo00<007ooOol0Zgoo0P00ogooF7oo0003
Ool20008Ool2000HOol20008Ool20006Ool20008Ool20009Ool30002Ool2000>Ool00`00Oomoo`3c
Ool00`00Oomoo`2ZOol00`00Oomoo`3oOomHOol000Aoo`8000Ioo`8001Yoo`8000Ioo`8000Qoo`80
00Ioo`8000]oo`80009oo`8000ioo`03001oogoo0?Aoo`03001oogoo0:Qoo`03001oogoo0?mooeUo
o`0017oo0P001Woo0P006Woo0P001Woo0P0027oo0P001Woo0P0037oo0P0000=oo`0000003Woo00<0
07ooOol0mGoo00<007ooOol0YWoo00<007ooOol0ogooFWoo0005Ool20004Ool2000LOol20004Ool2
000:Ool20004Ool2000>Ool4000>Ool00`00Oomoo`3fOol00`00Oomoo`2SOol2003oOomMOol000Eo
o`P001aoo`P000Yoo`P000ioo`@000ioo`03001oogoo0?Moo`03001oogoo0:5oo`03001oogoo0?mo
oeeoo`001goo100087oo10003Woo10004Goo0`003Woo00<007ooOol0mgoo00<007ooOol0X7oo00<0
07ooOol0ogooGWoo001SOol00`00Oomoo`3hOol00`00Oomoo`2MOol2003oOomQOol006=oo`03001o
ogoo0?Uoo`03001oogoo09]oo`03001oogoo0?moof5oo`00Hgoo00<007ooOol0nWoo00<007ooOol0
VGoo00<007ooOol0ogooHWoo001SOol00`00Oomoo`3jOol00`00Oomoo`2HOol00`00Oomoo`3oOomS
Ool006=oo`03001oogoo0?]oo`03001oogoo09Eoo`800?moofIoo`00Hgoo0`00o7oo00<007ooOol0
Tgoo00<007ooOol0ogooIWoo001SOol00`00Oomoo`3mOol00`00Oomoo`2AOol00`00Oomoo`3oOomW
Ool006=oo`03001oogoo0?eoo`03001oogoo091oo`03001oogoo0?moofQoo`00Hgoo00<007ooOol0
oWoo00<007ooOol0SWoo00<007ooOol0ogooJGoo001SOol00`00Oomoo`3oOol00`00Oomoo`2<Ool0
0`00Oomoo`3oOomZOol006=oo`03001oogoo0?moo`5oo`03001oogoo08Yoo`03001oogoo0?moof]o
o`00Hgoo00<007ooOol0ogoo0Goo00<007ooOol0RGoo00<007ooOol0ogooK7oo001SOol00`00Oomo
o`3oOol2Ool00`00Oomoo`27Ool00`00Oomoo`3oOom]Ool006=oo`03001oogoo0?moo`=oo`03001o
ogoo08Aoo`800?moog1oo`00Hgoo00<007ooOol0ogoo17oo00<007ooOol0PWoo00<007ooOol0ogoo
L7oo001SOol00`00Oomoo`3oOol4Ool00`00Oomoo`21Ool00`00Oomoo`3oOomaOol006=oo`03001o
ogoo0?moo`Eoo`03001oogoo07moo`03001oogoo0?moog9oo`00Hgoo00<007ooOol0ogoo1Woo00<0
07ooOol0OGoo00<007ooOol0ogooLgoo001SOol00`00Oomoo`3oOol7Ool00`00Oomoo`1kOol00`00
Oomoo`3oOomdOol006=oo`03001oogoo0?moo`Moo`03001oogoo07Yoo`03001oogoo0?moogEoo`00
Hgoo00<007ooOol0ogoo27oo00<007ooOol0N7oo00<007ooOol0ogooMWoo001SOol3003oOol9Ool0
0`00Oomoo`1eOol2003oOomiOol006=oo`03001oogoo0?moo`Uoo`03001oogoo07Aoo`03001oogoo
0?moogUoo`00Hgoo00<007ooOol0ogoo2Woo00<007ooOol0LWoo00<007ooOol0ogooNWoo001SOol0
0`00Oomoo`3oOol;Ool00`00Oomoo`1`Ool00`00Oomoo`3oOomkOol006=oo`03001oogoo0?moo`ao
o`03001oogoo06ioo`03001oogoo0?moogaoo`00Hgoo00<007ooOol0ogoo37oo00<007ooOol0KGoo
00<007ooOol0ogooOGoo001SOol00`00Oomoo`3oOol=Ool00`00Oomoo`1[Ool00`00Oomoo`3oOomn
Ool006=oo`03001oogoo0?moo`ioo`03001oogoo06Uoo`03001oogoo0?moogmoo`00Hgoo00<007oo
Ool0ogoo3goo00<007ooOol0Igoo00<007ooOol0ogooP7oo001SOol00`00Oomoo`3oOol?Ool00`00
Oomoo`1VOol00`00Oomoo`3oOon1Ool006=oo`03001oogoo0?mooa1oo`03001oogoo06Eoo`03001o
ogoo0?mooh5oo`00Hgoo00<007ooOol0ogoo4Goo00<007ooOol0Hgoo00<007ooOol0ogooPWoo001S
Ool00`00Oomoo`3oOolBOol00`00Oomoo`1QOol00`00Oomoo`3oOon3Ool006=oo`03001oogoo0?mo
oa9oo`03001oogoo061oo`03001oogoo0?moohAoo`00Hgoo00<007ooOol0ogoo4goo00<007ooOol0
GWoo00<007ooOol0ogooQGoo001SOol00`00Oomoo`3oOolDOol00`00Oomoo`1LOol00`00Oomoo`3o
Oon6Ool006=oo`<00?mooaAoo`03001oogoo05]oo`03001oogoo0?moohMoo`00Hgoo00<007ooOol0
ogoo5Goo00<007ooOol0FGoo00<007ooOol0ogooR7oo001SOol00`00Oomoo`3oOolFOol00`00Oomo
o`1GOol00`00Oomoo`3oOon9Ool006=oo`03001oogoo0?mooaMoo`03001oogoo05Eoo`03001oogoo
0?moohYoo`00Hgoo00<007ooOol0ogoo5goo00<007ooOol0E7oo00<007ooOol0ogooRgoo001SOol0
0`00Oomoo`3oOolHOol00`00Oomoo`1BOol00`00Oomoo`3oOon<Ool006=oo`03001oogoo0?mooaUo
o`03001oogoo051oo`03001oogoo0?mooheoo`00Hgoo00<007ooOol0ogoo6Woo00<007ooOol0CWoo
00<007ooOol0ogooSWoo001SOol00`00Oomoo`3oOolJOol00`00Oomoo`1=Ool00`00Oomoo`3oOon?
Ool006=oo`03001oogoo0?mooa]oo`03001oogoo04]oo`03001oogoo0?mooi1oo`00Hgoo00<007oo
Ool0ogoo77oo00<007ooOol0BWoo00<007ooOol0ogooT7oo001SOol00`00Oomoo`3oOolMOol00`00
Oomoo`18Ool00`00Oomoo`3oOonAOol006=oo`03001oogoo0?mooaeoo`03001oogoo04Moo`03001o
ogoo0?mooi9oo`00Hgoo00<007ooOol0ogoo7Woo00<007ooOol0AGoo00<007ooOol0ogooTgoo001S
Ool00`00Oomoo`3oOolOOol00`00Oomoo`13Ool00`00Oomoo`3oOonDOol006=oo`03001oogoo0?mo
oamoo`03001oogoo049oo`03001oogoo0?mooiEoo`00Hgoo00<007ooOol0ogoo87oo00<007ooOol0
@7oo00<007ooOol0ogooUWoo001SOol3003oOolQOol00`00Oomoo`0nOol00`00Oomoo`3oOonGOol0
06=oo`03001oogoo0?moob9oo`03001oogoo03aoo`03001oogoo0?mooiQoo`00Hgoo00<007ooOol0
ogoo8Woo00<007ooOol0>goo00<007ooOol0ogooVGoo001SOol00`00Oomoo`3oOolSOol00`00Oomo
o`0iOol00`00Oomoo`3oOonJOol006=oo`03001oogoo0?moobAoo`03001oogoo03Moo`03001oogoo
0?mooi]oo`00Hgoo00<007ooOol0ogoo9Goo00<007ooOol0=Goo00<007ooOol0ogooW7oo001SOol0
0`00Oomoo`3oOolUOol00`00Oomoo`0dOol00`00Oomoo`3oOonMOol006=oo`03001oogoo0?moobIo
o`03001oogoo039oo`03001oogoo0?mooiioo`00Hgoo00<007ooOol0ogoo9goo00<007ooOol0<7oo
00<007ooOol0ogooWgoo0007Ool4000>Ool3000?Ool4000>Ool4000<Ool6000@Ool00`00Oomoo`3o
OolXOol00`00Oomoo`0_Ool00`00Oomoo`3oOonOOol000Eoo`P000]oo`D000aoo`P000Yoo`P000Qo
o`X000ioo`03001oogoo0?moobQoo`03001oogoo02ioo`03001oogoo0?mooj1oo`001Goo0P0017oo
0P002goo1@0037oo0P0017oo0P002Woo0P0017oo0P0027oo0`001Goo0`003Goo00<007ooOol0ogoo
:Goo00<007ooOol0;7oo00<007ooOol0ogooXGoo0004Ool20006Ool2000:Ool5000;Ool20006Ool2
0008Ool20006Ool2000@Ool2000=Ool00`00Oomoo`3oOolZOol00`00Oomoo`0ZOol00`00Oomoo`3o
OonROol000Aoo`8000Ioo`8000]oo`<000aoo`8000Ioo`8000Qoo`8000Ioo`80015oo`8000aoo`03
001oogoo0?moob]oo`03001oogoo02Qoo`03001oogoo0?mooj=oo`000goo0P0027oo0P0067oo0P00
27oo0P001Woo0P0027oo0P0047oo0P0037oo00<007ooOol0ogoo:goo00<007ooOol09goo00<007oo
Ool0ogooY7oo0003Ool20008Ool2000HOol20008Ool20006Ool20008Ool2000@Ool2000<Ool00`00
Oomoo`3oOol/Ool00`00Oomoo`0VOol00`00Oomoo`3oOonTOol000=oo`8000Qoo`8001Qoo`8000Qo
o`8000Ioo`8000Qoo`80011oo`8000aoo`D00?moob]oo`03001oogoo02Aoo`03001oogoo0?moojEo
o`000goo0P0027oo0P0067oo0P0027oo0P001Woo0P0027oo0P0047oo0P0037oo00<007ooOol0ogoo
;Woo00<007ooOol08Woo00<007ooOol0ogooYWoo0003Ool20008Ool2000HOol20008Ool20006Ool2
0008Ool2000?Ool2000=Ool00`00Oomoo`3oOol^Ool00`00Oomoo`0QOol00`00Oomoo`3oOonWOol0
00=oo`8000Qoo`8001Qoo`8000Qoo`8000Ioo`8000Qoo`8000Moo`8000Eoo`<000eoo`03001oogoo
0?moobmoo`03001oogoo01moo`03001oogoo0?moojQoo`000goo0P0027oo0P0067oo0P0027oo0P00
1Woo0P0027oo0P001goo2@003Woo00<007ooOol0ogoo<7oo00<007ooOol07Woo00<007ooOol0ogoo
Z7oo0003Ool20008Ool2000HOol20008Ool20006Ool20008Ool20007Ool200000goo00000003000?
Ool00`00Oomoo`3oOolaOol00`00Oomoo`0LOol00`00Oomoo`3oOonYOol000Aoo`8000Ioo`8001Yo
o`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8001Eoo`03001oogoo0?mooc5oo`03001oogoo01]oo`03
001oogoo0?moojYoo`0017oo0P001Woo0P006Woo0P001Woo0P0027oo0P001Woo0P0027oo0P005Goo
00<007ooOol0ogoo<Woo00<007ooOol06Goo00<007ooOol0ogooZgoo0005Ool20004Ool2000LOol2
0004Ool2000:Ool20004Ool20009Ool2000EOol00`00Oomoo`3oOolcOol00`00Oomoo`0GOol00`00
Oomoo`3oOon/Ool000Eoo`P001aoo`P000Yoo`P000Uoo`X000eoo`03001oogoo0?moocAoo`03001o
ogoo01Eoo`03001oogoo0?moojeoo`001goo100087oo10003Woo10002goo2P003Goo00<007ooOol0
ogoo=Goo00<007ooOol057oo00<007ooOol0ogoo[Goo001SOol00`00Oomoo`3oOoleOol00`00Oomo
o`0COol00`00Oomoo`3oOon^Ool006=oo`03001oogoo0?moocIoo`03001oogoo015oo`03001oogoo
0?moojmoo`00Hgoo00<007ooOol0ogoo=goo00<007ooOol03goo00<007ooOol0ogoo/7oo001SOol0
0`00Oomoo`3oOolhOol00`00Oomoo`0=Ool00`00Oomoo`3oOonaOol006=oo`03001oogoo0?moocQo
o`03001oogoo00aoo`03001oogoo0?mook9oo`00Hgoo0`00ogoo>Goo00<007ooOol02Woo00<007oo
Ool0ogoo/goo001SOol00`00Oomoo`3oOoljOol00`00Oomoo`08Ool00`00Oomoo`3oOondOol006=o
o`03001oogoo0?moocYoo`03001oogoo00Qoo`03001oogoo0?mookAoo`00Hgoo00<007ooOol0ogoo
>goo00<007ooOol01Woo00<007ooOol0ogoo]Goo001SOol00`00Oomoo`3oOollOol00`00Oomoo`04
Ool00`00Oomoo`3oOonfOol006=oo`03001oogoo0?mooceoo`03001oogoo00=oo`03001oogoo0?mo
okIoo`00Hgoo00<007ooOol0ogoo?Woo00D007ooOomoo`000?mookUoo`00Hgoo00<007ooOol0ogoo
?goo00<007oo0000ogoo^Woo001SOol00`00Oomoo`3oOoloOol2003oOonkOol006=oo`03001oogoo
0?mooomoooaoo`00Hgoo00<007ooOol0ogooogooo7oo001SOol00`00Oomoo`3oOoooOoolOol006=o
o`03001oogoo0?mooomoooaoo`00Hgoo00<007ooOol0ogooogooo7oo001SOol00`00Oomoo`3oOooo
OoolOol006=oo`03001oogoo0?mooomoooaoo`00Hgoo00<007ooOol0ogooogooo7oo001SOol3003o
OoooOoolOol006=oo`03001oogoo0?mooomoooaoo`00Hgoo00<007ooOol0ogooogooo7oo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo001MOol00`00Oomo
o`0JOol00`00Oomoo`3oOoooOooUOol005aoo`03001oogoo01aoo`03001oogoo0?mooomoonAoo`00
G7oo00<007ooOol077oo00<007ooOol0ogooogooi7oo001KOol2000NOol2003oOoooOooUOol005]o
o`03001oogoo01ioo`03001oogoo0?mooomoon=oo`00FWoo0P0087oo0P00ogooogooi7oo0010Ool7
0002Ool7000:Ool20008Ool<000<Ool2003oOoooOooTOol0041oo`L0009oo`L000Yoo`8000Qoo``0
00aoo`800?mooomoonAoo`00@Woo0P0027oo0P002goo0P003Goo0P004goo0P00ogooogoohgoo0012
Ool20008Ool2000;Ool2000=Ool2000COol2003oOoooOooSOol0049oo`8000Qoo`8000]oo`8000eo
o`8001=oo`800?mooomoon=oo`00@Woo0P0027oo0P002goo0P003Goo0P004goo0P00ogooogoohgoo
0012Ool20008Ool2000;Ool2000=Ool2000COol2003oOoooOooSOol0049oo`8000Qoo`8000]oo`80
00eoo`8001=oo`800?mooomoon=oo`00@Woo30002goo0P003Goo0P004goo0P00ogooogoohgoo0012
Ool<000;Ool2000=Ool3000BOol2003oOoooOooSOol0049oo`8000Qoo`8000]oo`8000eoo`@0015o
o`800?mooomoon=oo`00@Woo0P0027oo0P0037oo0P0037oo0P0000=oo`00000017oo0P002Goo0P00
ogooogooi7oo0012Ool20008Ool2000<Ool20009Ool50002Ool70009Ool2003oOoooOooTOol0049o
o`8000Qoo`8000aoo`8000Uoo`D000Aoo`@000Yoo`800?mooomoonAoo`00@Woo0P0027oo0P003Goo
00<007ooOol07Woo00<007ooOol0ogooogoohgoo0010Ool70002Ool7000;Ool2000NOol2003oOooo
OooUOol0041oo`L0009oo`L000aoo`03001oogoo01aoo`03001oogoo0?mooomoonAoo`00G7oo00<0
07ooOol077oo00<007ooOol0ogooogooi7oo001MOol00`00Oomoo`0JOol00`00Oomoo`3oOoooOooU
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo0000\
\>"], "Graphics",
  CellLabel->"From In[77]:=",
  Evaluatable->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\[Bullet] the current density :", "Text",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{

Cell[BoxData[{
    \(jz[r_] := 
      Which[r < r0, 1\/\(\[Pi]\ r0\^2\), r > r2, 0. , r > r1, 
        1\/\(\[Pi] \((r1\^2 - r2\^2)\)\), True, 0]\), "\[IndentingNewLine]", 
    \(\(Plot[jz[r], {r, 0, ns/2}, 
        AxesLabel -> {"\<r\>", "\<J(r)\>"}];\)\)}], "Input",
  CellLabel->"In[79]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P00025A000`40O003h00OogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00QWoo00<007ooOol0ogooogoofGoo0026Ool00`00Oomoo`3o
OoooOooIOol008Ioo`03001oogoo0?mooomoomUoo`00QWoo00<007ooOol0ogooogoofGoo0026Ool0
0`00Oomoo`3oOoooOooIOol008Ioo`03001oogoo0?mooomoomUoo`00QWoo00<007ooOol0ogooogoo
fGoo0026Ool00`00Oomoo`3oOoooOooIOol008Ioo`03001oogoo0?mooomoomUoo`00QWoo00<007oo
Ool0ogooogoofGoo0026Ool00`00Oomoo`3oOoooOomUOolO001EOol008Ioo`03001oogoo0?mooomo
ofEoo`03001oogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooIGoo00<007ooOol0
6goo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1C
Ool008Ioo`@00?mooomoofAoo`03001oogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogoo
ogooIGoo00<007ooOol06goo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomo
o`0KOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo
05=oo`00QWoo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo0026Ool00`00
Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofEo
o`03001oogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooIGoo00<007ooOol06goo
00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol0
08Ioo`03001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=oo`006Goo10003Woo0`00
3goo10003Woo10003Woo10003Goo1P003Woo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<0
07ooOol0Dgoo000GOol8000;Ool5000<Ool8000:Ool8000:Ool8000:Ool8000=Ool00`00Oomoo`3o
OoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol001Moo`8000Aoo`8000]oo`D000aoo`8000Ao
o`8000Yoo`8000Aoo`8000Yoo`8000Aoo`8000Uoo`<000Aoo`<000aoo`03001oogoo0?mooomoofEo
o`03001oogoo01]oo`03001oogoo05=oo`005Woo0P001Woo0P002Woo1@002goo0P001Woo0P0027oo
0P001Woo0P0027oo0P001Woo0P001goo0`001Woo0`002goo00<007ooOol0ogooogooIGoo00<007oo
Ool06goo00<007ooOol0Dgoo000FOol20006Ool2000;Ool3000<Ool20006Ool20008Ool20006Ool2
0008Ool20006Ool20007Ool20008Ool2000;Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol0
0`00Oomoo`1COol0009oo`d000Ioo`8000Qoo`8001Qoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`80
00Qoo`8000Ioo`8000Qoo`8000]oo`03001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo
05=oo`000Woo3@001Woo0P0027oo0P0067oo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P00
1Woo0P0027oo0P002goo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo0002
Ool=0006Ool20008Ool2000HOol20008Ool20006Ool20008Ool20006Ool20008Ool20006Ool30006
Ool3000;Ool6003oOoooOomROol00`00Oomoo`0KOol00`00Oomoo`1COol001Eoo`8000Qoo`8001Qo
o`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Moo`<000Aoo`<000aoo`03001oogoo0?mo
oomoofEoo`03001oogoo01]oo`03001oogoo05=oo`005Goo0P0027oo0P0067oo0P0027oo0P001Woo
0P0027oo0P001Woo0P0027oo0P0027oo20003Goo00<007ooOol0ogooogooIGoo00<007ooOol06goo
00<007ooOol0Dgoo000EOol20008Ool2000HOol20008Ool20006Ool20008Ool20006Ool20008Ool2
0008Ool8000=Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol001Eoo`80
00Qoo`8001Qoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Moo`<000Aoo`<000aoo`03
001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=oo`005Goo0P0027oo0P0067oo0P00
27oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P002goo00<007ooOol0ogooogoo
IGoo00<007ooOol06goo00<007ooOol0Dgoo000FOol20006Ool2000JOol20006Ool20008Ool20006
Ool20008Ool20006Ool20007Ool20008Ool2000;Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0K
Ool00`00Oomoo`1COol001Ioo`8000Ioo`8001Yoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Io
o`8000Moo`8000Qoo`8000]oo`03001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=o
o`005goo0P0017oo0P0077oo0P0017oo0P002Woo0P0017oo0P002Woo0P0017oo0P002Goo0`0017oo
10002goo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo000GOol8000LOol8
000:Ool8000:Ool80009Ool:000<Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomo
o`1COol001Uoo`@0021oo`@000ioo`@000ioo`@000eoo`H000ioo`03001oogoo0?mooomoofEoo`03
001oogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<0
07ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol008Io
o`03001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogoo
ogooIGoo00<007ooOol06goo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomo
o`0KOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo
05=oo`00QWoo1000ogooogooI7oo00<007ooOol06goo00<007ooOol0Dgoo0026Ool00`00Oomoo`3o
OoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofEoo`03001o
ogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<007oo
Ool0Dgoo0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol008Ioo`03
001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogoo
IGoo00<007ooOol06goo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0K
Ool00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=o
o`00QWoo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo0026Ool00`00Oomo
o`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofEoo`03
001oogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<0
07ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol008Io
o`03001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogoo
ogooIGoo00<007ooOol06goo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomo
o`0KOol00`00Oomoo`1COol008Ioo`@00?mooomoofAoo`03001oogoo01]oo`03001oogoo05=oo`00
QWoo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo0026Ool00`00Oomoo`3o
OoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofEoo`03001o
ogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<007oo
Ool0Dgoo0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol008Ioo`03
001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogoo
IGoo00<007ooOol06goo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0K
Ool00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=o
o`00QWoo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo0026Ool00`00Oomo
o`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofEoo`03
001oogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<0
07ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol008Io
o`03001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogoo
ogooIGoo00<007ooOol06goo00<007ooOol0Dgoo0026Ool4003oOoooOomTOol00`00Oomoo`0KOol0
0`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=oo`00
QWoo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo0026Ool00`00Oomoo`3o
OoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofEoo`03001o
ogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<007oo
Ool0Dgoo0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol008Ioo`03
001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogoo
IGoo00<007ooOol06goo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0K
Ool00`00Oomoo`1COol001Uoo`@000ioo`<000moo`@000ioo`@000ioo`@000ioo`D000ioo`03001o
ogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=oo`005goo20002goo1@0037oo20002Woo
20002Woo20002Woo20003Goo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo
000GOol20004Ool2000;Ool5000<Ool20004Ool2000:Ool20004Ool2000:Ool20004Ool2000:Ool2
0004Ool3000<Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol001Ioo`80
00Ioo`8000Yoo`D000]oo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`<0
00]oo`03001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=oo`005Woo0P001Woo0P00
2goo0`0037oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P001goo0P0027oo0P002goo00<0
07ooOol0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo0002Ool=0006Ool20008Ool2000H
Ool20008Ool20006Ool20008Ool20006Ool20008Ool20006Ool20008Ool2000;Ool00`00Oomoo`3o
OoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol0009oo`d000Ioo`8000Qoo`8001Qoo`8000Qo
o`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000]oo`03001oogoo0?mooomoofEo
o`03001oogoo01]oo`03001oogoo05=oo`000Woo3@001Woo0P0027oo0P0067oo0P0027oo0P001Woo
0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P002goo1P00ogooogooHWoo00<007ooOol06goo
00<007ooOol0Dgoo000EOol20008Ool2000HOol20008Ool20006Ool20008Ool20006Ool20008Ool2
0006Ool30006Ool3000;Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol0
01Eoo`8000Qoo`8001Qoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`@000Aoo`<0
00aoo`03001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=oo`005Goo0P0027oo0P00
67oo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0000=oo`0000001@003Goo00<0
07ooOol0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo000EOol20008Ool2000HOol20008
Ool20006Ool20008Ool20006Ool20008Ool20007Ool00`00Oomoo`05000>Ool00`00Oomoo`3oOooo
OomUOol00`00Oomoo`0KOol00`00Oomoo`1COol001Eoo`8000Qoo`8001Qoo`8000Qoo`8000Ioo`80
00Qoo`8000Ioo`8000Qoo`8000Moo`8001Aoo`03001oogoo0?mooomoofEoo`03001oogoo01]oo`03
001oogoo05=oo`005Woo0P001Woo0P006Woo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P00
27oo0`004goo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo000FOol20006
Ool2000JOol20006Ool20008Ool20006Ool20008Ool20006Ool20009Ool3000BOol00`00Oomoo`3o
OoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol001Moo`8000Aoo`8001aoo`8000Aoo`8000Yo
o`8000Aoo`8000Yoo`8000Aoo`8000]oo`<0015oo`03001oogoo0?mooomoofEoo`03001oogoo01]o
o`03001oogoo05=oo`005goo200077oo20002Woo20002Woo200037oo20002goo00<007ooOol0ogoo
ogooIGoo00<007ooOol06goo00<007ooOol0Dgoo000IOol4000POol4000>Ool4000>Ool4000@Ool6
000;Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol008Ioo`03001oogoo
0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooIGoo00<0
07ooOol06goo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00
Oomoo`1COol008Ioo`03001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=oo`00QWoo
00<007ooOol0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOooo
OomUOol00`00Oomoo`0KOol00`00Oomoo`1COol008Ioo`@00?mooomoofAoo`03001oogoo01]oo`03
001oogoo05=oo`00QWoo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo0026
Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol008Ioo`03001oogoo0?mo
oomoofEoo`03001oogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooIGoo00<007oo
Ool06goo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomo
o`1COol008Ioo`03001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=oo`00QWoo00<0
07ooOol0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomU
Ool00`00Oomoo`0KOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofEoo`03001oogoo01]o
o`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo
0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol008Ioo`03001oogoo
0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooIGoo00<0
07ooOol06goo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00
Oomoo`1COol008Ioo`03001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=oo`00QWoo
00<007ooOol0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo0026Ool4003oOoooOomTOol0
0`00Oomoo`0KOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofEoo`03001oogoo01]oo`03
001oogoo05=oo`00QWoo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo0026
Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol008Ioo`03001oogoo0?mo
oomoofEoo`03001oogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooIGoo00<007oo
Ool06goo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomo
o`1COol008Ioo`03001oogoo0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=oo`00QWoo00<0
07ooOol0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomU
Ool00`00Oomoo`0KOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofEoo`03001oogoo01]o
o`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo
0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol008Ioo`03001oogoo
0?mooomoofEoo`03001oogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooIGoo00<0
07ooOol06goo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00
Oomoo`1COol008Ioo`@00?mooomoofAoo`03001oogoo01]oo`03001oogoo05=oo`00QWoo00<007oo
Ool0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomUOol0
0`00Oomoo`0KOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofEoo`03001oogoo01]oo`03
001oogoo05=oo`00QWoo00<007ooOol0ogooogooIGoo00<007ooOol06goo00<007ooOol0Dgoo0026
Ool00`00Oomoo`3oOoooOomUOol00`00Oomoo`0KOol00`00Oomoo`1COol008Ioo`03001oogoo0?mo
oomoofEoo`03001oogoo01]oo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooI7oo00<007oo
Ool077oo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00Oomo
o`1COol008Ioo`03001oogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=oo`006Goo1000
3Woo0`003goo10003Woo10003Woo10003goo1`002goo00<007ooOol0ogooogooI7oo00<007ooOol0
77oo00<007ooOol0Dgoo000GOol8000;Ool5000<Ool8000:Ool8000:Ool8000=Ool7000;Ool00`00
Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00Oomoo`1COol001Moo`8000Aoo`8000]oo`D000ao
o`8000Aoo`8000Yoo`8000Aoo`8000Yoo`8000Aoo`80011oo`8000eoo`03001oogoo0?mooomoofAo
o`03001oogoo01aoo`03001oogoo05=oo`005Woo0P001Woo0P002Woo1@002goo0P001Woo0P0027oo
0P001Woo0P0027oo0P001Woo0P003goo0P003Goo00<007ooOol0ogooogooI7oo00<007ooOol077oo
00<007ooOol0Dgoo000FOol20006Ool2000;Ool3000<Ool20006Ool20008Ool20006Ool20008Ool2
0006Ool2000?Ool2000=Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00Oomoo`1COol0
009oo`d000Ioo`8000Qoo`8001Qoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo``0
00]oo`03001oogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=oo`000Woo3@001Woo0P00
27oo0P0067oo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo30002goo00<007ooOol0
ogooogooI7oo00<007ooOol077oo00<007ooOol0Dgoo0002Ool=0006Ool20008Ool2000HOol20008
Ool20006Ool20008Ool20006Ool20008Ool20006Ool20006Ool200000goo001oo`0:Ool6003oOooo
OomQOol00`00Oomoo`0LOol00`00Oomoo`1COol001Eoo`8000Qoo`8001Qoo`8000Qoo`8000Ioo`80
00Qoo`8000Ioo`8000Qoo`8000Moo`8000Eoo`8000eoo`03001oogoo0?mooomoofAoo`03001oogoo
01aoo`03001oogoo05=oo`005Goo0P0027oo0P0067oo0P0027oo0P001Woo0P0027oo0P001Woo0P00
27oo0P001goo0`0017oo0P003Goo00<007ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0
Dgoo000EOol20008Ool2000HOol20008Ool20006Ool20008Ool20006Ool20008Ool20008Ool20004
Ool2000=Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00Oomoo`1COol001Eoo`8000Qo
o`8001Qoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Uoo`8000=oo`8000eoo`03001o
ogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=oo`005Goo0P0027oo0P0067oo0P0027oo
0P001Woo0P0027oo0P001Woo0P0027oo0P002Goo0`000Woo0P003Goo00<007ooOol0ogooogooI7oo
00<007ooOol077oo00<007ooOol0Dgoo000FOol20006Ool2000JOol20006Ool20008Ool20006Ool2
0008Ool20006Ool2000;Ool20002Ool2000=Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol0
0`00Oomoo`1COol001Ioo`8000Ioo`8001Yoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`80
00aoo`800003Ool0000000eoo`03001oogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=o
o`005goo0P0017oo0P0077oo0P0017oo0P002Woo0P0017oo0P002Woo0P0017oo0P003Woo10003Goo
00<007ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0Dgoo000GOol8000LOol8000:Ool8
000:Ool8000>Ool4000=Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00Oomoo`1COol0
01Uoo`@0021oo`@000ioo`@000ioo`@0015oo`<000eoo`03001oogoo0?mooomoofAoo`03001oogoo
01aoo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0
Dgoo0026Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00Oomoo`1COol008Ioo`03001o
ogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooI7oo
00<007ooOol077oo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol0
0`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=oo`00
QWoo1000ogooogooHgoo00<007ooOol077oo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomT
Ool00`00Oomoo`0LOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofAoo`03001oogoo01ao
o`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0Dgoo
0026Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00Oomoo`1COol008Ioo`03001oogoo
0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooI7oo00<0
07ooOol077oo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00
Oomoo`1COol008Ioo`03001oogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=oo`00QWoo
00<007ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOooo
OomTOol00`00Oomoo`0LOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofAoo`03001oogoo
01aoo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0
Dgoo0026Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00Oomoo`1COol008Ioo`03001o
ogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooI7oo
00<007ooOol077oo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol0
0`00Oomoo`1COol008Ioo`@00?mooomoof=oo`03001oogoo01aoo`03001oogoo05=oo`00QWoo00<0
07ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomT
Ool00`00Oomoo`0LOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofAoo`03001oogoo01ao
o`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0Dgoo
0026Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00Oomoo`1COol008Ioo`03001oogoo
0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooI7oo00<0
07ooOol077oo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00
Oomoo`1COol008Ioo`03001oogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=oo`00QWoo
00<007ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOooo
OomTOol00`00Oomoo`0LOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofAoo`03001oogoo
01aoo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0
Dgoo0026Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00Oomoo`1COol008Ioo`03001o
ogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooI7oo
00<007ooOol077oo00<007ooOol0Dgoo0026Ool4003oOoooOomSOol00`00Oomoo`0LOol00`00Oomo
o`1COol008Ioo`03001oogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=oo`00QWoo00<0
07ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomT
Ool00`00Oomoo`0LOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofAoo`03001oogoo01ao
o`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0Dgoo
0026Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00Oomoo`1COol008Ioo`03001oogoo
0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooI7oo00<0
07ooOol077oo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00
Oomoo`1COol001Uoo`@000ioo`<000moo`@000ioo`@000ioo`@000Uoo``000aoo`03001oogoo0?mo
oomoofAoo`03001oogoo01aoo`03001oogoo05=oo`005goo20002goo1@0037oo20002Woo20002Woo
20001goo300037oo00<007ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0Dgoo000GOol2
0004Ool2000;Ool5000<Ool20004Ool2000:Ool20004Ool2000:Ool20004Ool20008Ool30006Ool2
000<Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00Oomoo`1COol001Ioo`8000Ioo`80
00Yoo`D000]oo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`<001=oo`03001oogoo
0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=oo`005Woo0P001Woo0P002goo0`0037oo0P00
1Woo0P0027oo0P001Woo0P0027oo0P001Woo0P002Goo0`004Woo00<007ooOol0ogooogooI7oo00<0
07ooOol077oo00<007ooOol0Dgoo0002Ool=0006Ool20008Ool2000HOol20008Ool20006Ool20008
Ool20006Ool20008Ool20009Ool3000AOol00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00
Oomoo`1COol0009oo`d000Ioo`8000Qoo`8001Qoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qo
o`8000Yoo`<0011oo`03001oogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=oo`000Woo
3@001Woo0P0027oo0P0067oo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P002goo0`003goo
1P00ogooogooHGoo00<007ooOol077oo00<007ooOol0Dgoo000EOol20008Ool2000HOol20008Ool2
0006Ool20008Ool20006Ool20008Ool2000<Ool3000>Ool00`00Oomoo`3oOoooOomTOol00`00Oomo
o`0LOol00`00Oomoo`1COol001Eoo`8000Qoo`8001Qoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`80
00Qoo`8000eoo`<000eoo`03001oogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=oo`00
5Goo0P0027oo0P0067oo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P003Woo0P003Goo00<0
07ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0Dgoo000EOol20008Ool2000HOol20008
Ool20006Ool20008Ool20006Ool20008Ool2000?Ool2000<Ool00`00Oomoo`3oOoooOomTOol00`00
Oomoo`0LOol00`00Oomoo`1COol001Eoo`8000Qoo`8001Qoo`8000Qoo`8000Ioo`8000Qoo`8000Io
o`8000Qoo`8000moo`8000aoo`03001oogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=o
o`005Woo0P001Woo0P006Woo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P001goo0P001goo
0P0037oo00<007ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0Dgoo000FOol20006Ool2
000JOol20006Ool20008Ool20006Ool20008Ool20006Ool20007Ool30006Ool2000<Ool00`00Oomo
o`3oOoooOomTOol00`00Oomoo`0LOol00`00Oomoo`1COol001Moo`8000Aoo`8001aoo`8000Aoo`80
00Yoo`8000Aoo`8000Yoo`8000Aoo`8000Qoo`@000Aoo`8000eoo`03001oogoo0?mooomoofAoo`03
001oogoo01aoo`03001oogoo05=oo`005goo200077oo20002Woo20002Woo20002Goo20003Woo00<0
07ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0Dgoo000IOol4000POol4000>Ool4000>
Ool4000=Ool5000?Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00Oomoo`1COol008Io
o`03001oogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=oo`00QWoo00<007ooOol0ogoo
ogooI7oo00<007ooOol077oo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomTOol00`00Oomo
o`0LOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo
05=oo`00QWoo00<007ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0Dgoo0026Ool00`00
Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00Oomoo`1COol008Ioo`@00?mooomoof=oo`03001o
ogoo01aoo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooI7oo00<007ooOol077oo00<007oo
Ool0Dgoo0026Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00Oomoo`1COol008Ioo`03
001oogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogoo
I7oo00<007ooOol077oo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0L
Ool00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=o
o`00QWoo00<007ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0Dgoo0026Ool00`00Oomo
o`3oOoooOomTOol00`00Oomoo`0LOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofAoo`03
001oogoo01aoo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooI7oo00<007ooOol077oo00<0
07ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00Oomoo`1COol008Io
o`03001oogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=oo`00QWoo00<007ooOol0ogoo
ogooI7oo00<007ooOol077oo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomTOol00`00Oomo
o`0LOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo
05=oo`00QWoo00<007ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0Dgoo0026Ool4003o
OoooOomSOol00`00Oomoo`0LOol00`00Oomoo`1COol008Ioo`03001oogoo0?mooomoofAoo`03001o
ogoo01aoo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooI7oo00<007ooOol077oo00<007oo
Ool0Dgoo0026Ool00`00Oomoo`1EOol:000;Ool4001<Ool<000;Ool4001?Ool5000>Ool4001AOol7
000:Ool4001>Ool6000>Ool4001@Ool50006Ool00`00Oomoo`04Ool4000DOol00`00Oomoo`1COol0
08Ioo`03001oogoo05Eoo`X000Uoo`P004Yoo``000Uoo`P004]oo`T000Yoo`P004moo`L000Qoo`P0
04Yoo`X000Yoo`P004aoo`P000Eoo`03001oogoo009oo`P0019oo`03001oogoo05=oo`00QWoo00<0
07ooOol0FGoo0P003Goo0P0017oo0P00Bgoo0`001Woo0P002Goo0P0017oo0P00BWoo100017oo0`00
2Goo0P0017oo0P00DWoo0P002Woo0P0017oo0P00BWoo0`001Goo0`002Goo0P0017oo0P00C7oo0P00
17oo0`0017oo00<007ooOol00Woo0P0017oo0P004Woo00<007ooOol0Dgoo0026Ool00`00Oomoo`1I
Ool2000<Ool20006Ool2001;Ool3000?Ool20006Ool20019Ool20007Ool30007Ool20006Ool2001A
Ool20009Ool20006Ool2001BOol20008Ool20006Ool2001:Ool20006Ool30003Ool01000Oomoogoo
0P001Woo0P004Goo00<007ooOol0Dgoo0026Ool00`00Oomoo`1IOol2000<Ool20006Ool2001<Ool3
000>Ool20006Ool2001COol20007Ool20006Ool2001AOol20009Ool20006Ool2001COol20007Ool2
0006Ool20019Ool20008Ool20003Ool01000Oomoogoo0P001Woo0P004Goo00<007ooOol0Dgoo0026
Ool00`00Oomoo`1IOol2000;Ool20008Ool2001<Ool3000<Ool20008Ool2001BOol20006Ool20008
Ool20018Ool<0006Ool20008Ool2001BOol20006Ool20008Ool20018Ool20008Ool20003Ool00`00
Oomoo`020008Ool2000@Ool00`00Oomoo`1COol008Ioo`03001oogoo05Uoo`8000]oo`8000Qoo`80
04eoo`<000]oo`8000Qoo`80059oo`8000Ioo`8000Qoo`8004Qoo``000Ioo`8000Qoo`80059oo`80
00Ioo`8000Qoo`8004Qoo`8000Qoo`8000=oo`03001oogoo008000Qoo`80011oo`03001oogoo05=o
o`00QWoo00<007ooOol0FGoo0P002goo0P0027oo0P00CWoo0`002Woo0P0027oo0P00DGoo0`001Woo
0P0027oo0P00B7oo0P001Woo0P0000=oo`00Ool01Goo0P0027oo0P00DWoo0P001Woo0P0027oo0P00
B7oo0P0027oo0P000goo00<007ooOol00P0027oo0P0047oo00<007ooOol0Dgoo0026Ool00`00Oomo
o`1IOol2000;Ool20008Ool2001?Ool30009Ool20008Ool2001@Ool30007Ool20008Ool20019Ool2
0005Ool20008Ool20008Ool2001BOol20006Ool20008Ool20018Ool30006Ool30003Ool00`00Oomo
o`020008Ool2000@Ool00`00Oomoo`1COol008Ioo`03001oogoo05Uoo`8000]oo`8000Qoo`80051o
o`<000Qoo`8000Qoo`8004eoo`D000Qoo`8000Qoo`8004Uoo`<000Aoo`8000Qoo`8000Qoo`80055o
o`8000Moo`8000Qoo`8004Qoo`@000Aoo`<000Aoo`03001oogoo008000Qoo`80011oo`03001oogoo
05=oo`00QWoo00<007ooOol0FGoo0P002goo0P0027oo0P00DGoo0P0027oo0P0027oo0P00CGoo1000
2Goo0P0027oo0P00BWoo0P0017oo0P0027oo0P0027oo0P00BGoo0P001Goo0`001goo0P0027oo0P00
B7oo0P0000=oo`0000001@001Goo00<007ooOol00P0027oo0P0047oo00<007ooOol0Dgoo0026Ool0
0`00Oomoo`1IOol2000;Ool20008Ool2001BOol20007Ool20008Ool2001@Ool20008Ool20008Ool2
001;Ool20003Ool20008Ool20008Ool20019Ool90008Ool20008Ool20019Ool00`00Oomoo`050006
Ool00`00Oomoo`020008Ool2000@Ool00`00Oomoo`1COol008Ioo`03001oogoo05Uoo`8000]oo`80
00Qoo`80059oo`8000Moo`8000Qoo`80055oo`8000Moo`8000Qoo`8004]oo`<0009oo`8000Qoo`80
00Qoo`8004Uoo`800003Ool0000000<000Uoo`8000Qoo`8004Uoo`8000aoo`03001oogoo008000Qo
o`80011oo`03001oogoo05=oo`00QWoo1000F7oo0P0037oo0P001Woo0P00BWoo0P001goo0P0027oo
0P001Woo0P00DWoo0P0027oo0P001Woo0P00CGoo0P000Woo0P002Goo0P001Woo0P00BWoo0P0047oo
0P001Woo0P00BWoo0`002goo00@007ooOomoo`8000Ioo`80015oo`03001oogoo05=oo`00QWoo00<0
07ooOol0FGoo0P0037oo0P001Woo0P00BWoo0`001Woo0P0027oo0P001Woo0P00BWoo0P001Woo0P00
27oo0P001Woo0P00CWoo0P0000=oo`0000002Goo0P001Woo0P00BWoo0P0047oo0P001Woo0P00Bgoo
0`002Woo00@007ooOomoo`8000Ioo`80015oo`03001oogoo05=oo`00QWoo00<007ooOol0EGoo0`00
00=oo`0000003Goo0P0017oo0P00Bgoo100017oo0P002Woo0P0017oo0P00Bgoo0`0017oo0`002Goo
0P0017oo0P00D7oo10002Woo0P0017oo0P00Bgoo0P004Goo0P0017oo0P00CGoo0`002Goo00<007oo
Ool00Woo0P0017oo0P004Woo00<007ooOol0Dgoo0026Ool00`00Oomoo`1EOol6000=Ool8001<Ool8
000;Ool8001<Ool8000:Ool8001@Ool4000:Ool8001;Ool:0009Ool8001>Ool80003Ool00`00Oomo
o`02Ool8000BOol00`00Oomoo`1COol008Ioo`03001oogoo05Qoo`<000moo`@0051oo`D000ioo`@0
04moo`D000ioo`@005=oo`<000aoo`@004eoo`X000]oo`@0059oo`H000=oo`03001oogoo00Aoo`@0
01Aoo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0
Dgoo0026Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00Oomoo`1COol008Ioo`03001o
ogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo05=oo`00QWoo00<007ooOol0ogooogooI7oo
00<007ooOol077oo00<007ooOol0Dgoo0026Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol0
0`00Oomoo`0jOol<000=Ool008Ioo`03001oogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo
03Yoo``000eoo`00QWoo00<007ooOol0ogooogooI7oo00<007ooOol077oo00<007ooOol0?Woo0P00
4goo0026Ool00`00Oomoo`3oOoooOomTOol00`00Oomoo`0LOol00`00Oomoo`0nOol2000COol008Io
o`03001oogoo0?mooomoofAoo`03001oogoo01aoo`03001oogoo03ioo`8001=oo`00QWoo00<007oo
Ool0ogooogooI7oo00<007ooOol077oo00<007ooOol0?Woo0P004goo0026Ool00`00Oomoo`3oOooo
OomTOol00`00Oomoo`0LOol00`00Oomoo`0nOol2000COol008Ioo`03001oogoo0?mooomoofAoo`03
001oogoo01aoo`03001oogoo03ioo`8001=oo`00MWooo`00o`00_0006goo0P004goo0026Ool00`00
Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00
Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00
Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00
Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00
Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00
Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00
Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0OOol3000BOol008Ioo`03001o
ogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo015oo`03001oogoo015oo`03001o
ogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001o
ogoo015oo`03001oogoo015oo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001o
ogoo015oo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo015oo`03001o
ogoo015oo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo015oo`03001o
ogoo019oo`03001oogoo015oo`03001oogoo015oo`03001oogoo019oo`03001oogoo015oo`03001o
ogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo01moo`@0015oo`00QWoo00<007oo
Ool04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Goo00<007oo
Ool04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007oo
Ool04Goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007oo
Ool04Goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Goo00<007oo
Ool04Goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Goo00<007oo
Ool04Woo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Goo00<007oo
Ool04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol07goo0P0000=oo`00000017oo0P00
2Woo0026Ool00`00Oomoo`1SOol00`00Oomoo`1TOol00`00Oomoo`1SOol00`00Oomoo`1SOol00`00
Oomoo`1SOol00`00Oomoo`1SOol00`00Oomoo`1JOol50002Ool7000:Ool008Ioo`03001oogoo06=o
o`03001oogoo06Aoo`03001oogoo06=oo`03001oogoo06=oo`03001oogoo06=oo`03001oogoo06=o
o`03001oogoo05Yoo`D000Aoo`@000]oo`00QWoo00<007ooOol0ogoo<Goo00<007ooOol0ogooYGoo
0026Ool00`00Oomoo`3oOolaOol00`00Oomoo`3oOonUOol008Ioo`03001oogoo0?mooc5oo`03001o
ogoo0?moojEoo`00QWoo00<007ooOol0ogoo<Goo00<007ooOol0ogooYGoo0026Ool00`00Oomoo`3o
OolaOol00`00Oomoo`3oOonUOol008Ioo`03001oogoo0?mooc5oo`03001oogoo0?moojEoo`00QWoo
00<007ooOol0ogoo<Goo00<007ooOol0ogooYGoo0026Ool00`00Oomoo`3oOolaOol00`00Oomoo`3o
OonUOol008Ioo`03001oogoo0?mooc5oo`03001oogoo0?moojEoo`00QWoo00<007ooOol0ogoo<Goo
00<007ooOol0ogooYGoo0026Ool00`00Oomoo`3oOolaOol00`00Oomoo`3oOonUOol008Ioo`@00?mo
oc1oo`03001oogoo0?moojEoo`00QWoo00<007ooOol0ogoo<Goo00<007ooOol0ogooYGoo0026Ool0
0`00Oomoo`3oOolaOol00`00Oomoo`3oOonUOol008Ioo`03001oogoo0?mooc5oo`03001oogoo0?mo
ojEoo`00QWoo00<007ooOol0ogoo<Goo00<007ooOol0ogooYGoo0026Ool00`00Oomoo`3oOolaOol0
0`00Oomoo`3oOonUOol008Ioo`03001oogoo0?mooc5oo`03001oogoo0?moojEoo`00QWoo00<007oo
Ool0ogoo<Goo00<007ooOol0ogooYGoo0026Ool00`00Oomoo`3oOolaOol00`00Oomoo`3oOonUOol0
08Ioo`03001oogoo0?mooc5oo`03001oogoo0?moojEoo`00QWoo00<007ooOol0ogoo<Goo00<007oo
Ool0ogooYGoo0026Ool00`00Oomoo`3oOolaOol00`00Oomoo`3oOonUOol008Ioo`03001oogoo0?mo
oc5oo`03001oogoo0?moojEoo`00QWoo00<007ooOol0ogoo<Goo00<007ooOol0ogooYGoo0026Ool0
0`00Oomoo`3oOolaOol00`00Oomoo`3oOonUOol008Ioo`03001oogoo0?mooc5oo`03001oogoo0?mo
ojEoo`00QWoo00<007ooOol0ogoo<Goo00<007ooOol0ogooYGoo0026Ool4003oOol`Ool00`00Oomo
o`3oOonUOol008Ioo`03001oogoo0?mooc5oo`03001oogoo0?moojEoo`00QWoo00<007ooOol0ogoo
<Goo00<007ooOol0ogooYGoo0026Ool00`00Oomoo`3oOolaOol00`00Oomoo`3oOonUOol008Ioo`03
001oogoo0?mooc5oo`03001oogoo0?moojEoo`00QWoo00<007ooOol0ogoo<Goo00<007ooOol0ogoo
YGoo0026Ool00`00Oomoo`3oOolaOol00`00Oomoo`3oOonUOol008Ioo`03001oogoo0?mooc5oo`03
001oogoo0?moojEoo`00QWoo00<007ooOol0ogoo<Goo00<007ooOol0ogooYGoo0026Ool00`00Oomo
o`3oOolaOol00`00Oomoo`3oOonUOol008Ioo`03001oogoo0?mooc5oo`03001oogoo0?moojEoo`00
QWoo00<007ooOol0ogoo<Goo00<007ooOol0ogooYGoo0026Ool00`00Oomoo`3oOolaOol00`00Oomo
o`3oOonUOol008Ioo`03001oogoo0?mooc5oo`03001oogoo0?moojEoo`00QWoo00<007ooOol0ogoo
<Goo00<007ooOol0ogooYGoo0026Ool00`00Oomoo`3oOolaOol00`00Oomoo`3oOonUOol008Ioo`03
001oogoo0?mooc5oo`03001oogoo0?moojEoo`00QWoo1000ogoo<7oo00<007ooOol0ogooYGoo0026
Ool00`00Oomoo`3oOolaOol00`00Oomoo`3oOonUOol008Ioo`03001oogoo0?mooc5oo`03001oogoo
0?moojEoo`00QWoo00<007ooOol0ogoo<Goo00<007ooOol0ogooYGoo0026Ool00`00Oomoo`3oOola
Ool00`00Oomoo`3oOonUOol008Ioo`03001oogoo0?mooc5oo`03001oogoo0?moojEoo`00QWoo00<0
07ooOol0ogoo<Goo00<007ooOol0ogooYGoo0026Ool00`00Oomoo`3oOolaOol00`00Oomoo`3oOonU
Ool008Ioo`03001oogoo0?mooc5oo`03001oogoo0?moojEoo`00QWoo00<007ooOol0ogoo<Goo00<0
07ooOol0ogooYGoo000IOol4000>Ool3000?Ool4000>Ool4000>Ool40009Ool<000<Ool00`00Oomo
o`3oOol`Ool00`00Oomoo`3oOonVOol001Moo`P000]oo`D000aoo`P000Yoo`P000Yoo`P000Moo``0
00aoo`03001oogoo0?mooc1oo`03001oogoo0?moojIoo`005goo0P0017oo0P002goo1@0037oo0P00
17oo0P002Woo0P0017oo0P002Woo0P0017oo0P0027oo0`001Woo0P0037oo00<007ooOol0ogoo<7oo
00<007ooOol0ogooYWoo000FOol20006Ool2000:Ool5000;Ool20006Ool20008Ool20006Ool20008
Ool20006Ool20008Ool3000COol00`00Oomoo`3oOol`Ool00`00Oomoo`3oOonVOol001Ioo`8000Io
o`8000]oo`<000aoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Uoo`<0019oo`03001o
ogoo0?mooc1oo`03001oogoo0?moojIoo`005Goo0P0027oo0P0067oo0P0027oo0P001Woo0P0027oo
0P001Woo0P0027oo0P002Goo0`004Goo00<007ooOol0ogoo<7oo00<007ooOol0ogooYWoo000EOol2
0008Ool2000HOol20008Ool20006Ool20008Ool20006Ool20008Ool2000:Ool3000@Ool00`00Oomo
o`3oOol`Ool00`00Oomoo`3oOonVOol001Eoo`8000Qoo`8001Qoo`8000Qoo`8000Ioo`8000Qoo`80
00Ioo`8000Qoo`8000]oo`<000moo`H00?moobeoo`03001oogoo0?moojIoo`005Goo0P0027oo0P00
67oo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P0037oo0`003Woo00<007ooOol0ogoo<7oo
00<007ooOol0ogooYWoo000EOol20008Ool2000HOol20008Ool20006Ool20008Ool20006Ool20008
Ool2000=Ool3000=Ool00`00Oomoo`3oOol`Ool00`00Oomoo`3oOonVOol001Eoo`8000Qoo`8001Qo
o`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000ioo`8000eoo`03001oogoo0?mooc1oo`03
001oogoo0?moojIoo`005Goo0P0027oo0P0067oo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo
0P003goo0P0037oo00<007ooOol0ogoo<7oo00<007ooOol0ogooYWoo000EOol20008Ool2000HOol2
0008Ool20006Ool20008Ool20006Ool20008Ool2000?Ool2000<Ool00`00Oomoo`3oOol`Ool00`00
Oomoo`3oOonVOol001Ioo`8000Ioo`8001Yoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`80
00Moo`8000Moo`8000aoo`03001oogoo0?mooc1oo`03001oogoo0?moojIoo`005Woo0P001Woo0P00
6Woo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P001goo0`001Woo0P0037oo00<007ooOol0
ogoo<7oo00<007ooOol0ogooYWoo000GOol20004Ool2000LOol20004Ool2000:Ool20004Ool2000:
Ool20004Ool20008Ool40004Ool2000=Ool00`00Oomoo`3oOol`Ool00`00Oomoo`3oOonVOol001Mo
o`P001aoo`P000Yoo`P000Yoo`P000Uoo`P000ioo`03001oogoo0?mooc1oo`03001oogoo0?moojIo
o`006Goo100087oo10003Woo10003Woo10003Goo1@003goo00<007ooOol0ogoo<7oo00<007ooOol0
ogooYWoo0026Ool00`00Oomoo`3oOol`Ool00`00Oomoo`3oOonVOol008Ioo`03001oogoo0?mooc1o
o`03001oogoo0?moojIoo`00QWoo00<007ooOol0ogoo<7oo00<007ooOol0ogooYWoo0026Ool00`00
Oomoo`3oOol`Ool00`00Oomoo`3oOonVOol008Ioo`03001oogoo0?mooc1oo`03001oogoo0?moojIo
o`00QWoo00<007ooOol0ogoo<7oo00<007ooOol0ogooYWoo0026Ool4003oOol_Ool00`00Oomoo`3o
OonVOol008Ioo`03001oogoo0?mooc1oo`03001oogoo0?moojIoo`00QWoo00<007ooOol0ogoo<7oo
00<007ooOol0ogooYWoo0026Ool00`00Oomoo`3oOol`Ool00`00Oomoo`3oOonVOol008Ioo`03001o
ogoo0?mooc1oo`03001oogoo0?moojIoo`00QWoo00<007ooOol0ogoo<7oo00<007ooOol0ogooYWoo
0026Ool00`00Oomoo`3oOol`Ool00`00Oomoo`3oOonVOol008Ioo`03001oogoo0?mooc1oo`03001o
ogoo0?moojIoo`00QWoo00<007ooOol0ogoo<7oo00<007ooOol0ogooYWoo0026Ool00`00Oomoo`3o
Ool`Ool00`00Oomoo`3oOonVOol008Ioo`03001oogoo0?mooc1oo`03001oogoo0?moojIoo`00QWoo
00<007ooOol0ogoo<7oo00<007ooOol0ogooYWoo0026Ool00`00Oomoo`3oOol`Ool00`00Oomoo`3o
OonVOol008Ioo`03001oogoo0?mooc1oo`03001oogoo0?moojIoo`00QWoo00<007ooOol0ogoo<7oo
00<007ooOol0ogooYWoo0026Ool00`00Oomoo`3oOol`Ool00`00Oomoo`3oOonVOol008Ioo`03001o
ogoo0?mooc1oo`03001oogoo0?moojIoo`00QWoo1000ogoo;goo00<007ooOol0ogooYWoo0026Ool0
0`00Oomoo`3oOol`Ool00`00Oomoo`3oOonVOol008Ioo`03001oogoo0?mooc1oo`03001oogoo0?mo
ojIoo`00QWoo00<007ooOol0ogoo<7oo00<007ooOol0ogooYWoo0026Ool00`00Oomoo`3oOol`Ool0
0`00Oomoo`3oOonVOol008Ioo`03001oogoo0?mooc1oo`03001oogoo0?moojIoo`00QWoo00<007oo
Ool0ogoo<7oo00<007ooOol0ogooYWoo0026Ool00`00Oomoo`3oOol`Ool00`00Oomoo`3oOonVOol0
08Ioo`03001oogoo0?mooc1oo`03001oogoo0?moojIoo`00QWoo00<007ooOol0ogoo<7oo00<007oo
Ool0ogooYWoo0026Ool00`00Oomoo`3oOol`Ool00`00Oomoo`3oOonVOol008Ioo`03001oogoo0?mo
oc1oo`03001oogoo0?moojIoo`00QWoo00<007ooOol0ogoo<7oo00<007ooOol0ogooYWoo0026Ool0
0`00Oomoo`3oOol`Ool00`00Oomoo`3oOonVOol008Ioo`03001oogoo0?mooc1oo`03001oogoo0?mo
ojIoo`00QWoo00<007ooOol0ogoo<7oo00<007ooOol0ogooYWoo0026Ool4003oOol_Ool00`00Oomo
o`3oOonVOol008Ioo`03001oogoo0?mooc1oo`03001oogoo0?moojIoo`00QWooo`00=000ogooZ7oo
0026Ool00`00Oomoo`3oOoooOooIOol008Ioo`03001oogoo0?mooomoomUoo`00QWoo00<007ooOol0
ogooogoofGoo0026Ool00`00Oomoo`3oOoooOooIOol008Ioo`03001oogoo0?mooomoomUoo`00QWoo
00<007ooOol0ogooogoofGoo0026Ool00`00Oomoo`3oOoooOooIOol008Ioo`03001oogoo0?mooomo
omUoo`00QWoo00<007ooOol0ogooogoofGoo0026Ool00`00Oomoo`3oOoooOooIOol00?mooomooomo
of=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo0020Ool00`00Oomoo`0JOol00`00Oomoo`3oOooo
Ooo2Ool007moo`03001oogoo01aoo`03001oogoo0?mooomool5oo`00Ogoo00<007ooOol077oo00<0
07ooOol0ogooogoo`Goo001nOol2000NOol2003oOoooOoo2Ool007ioo`03001oogoo01ioo`03001o
ogoo0?mooomool1oo`00OGoo0P0087oo0P00ogooogoo`Goo001WOol6000@Ool20008Ool<000<Ool2
003oOoooOoo1Ool006Eoo`X000ioo`8000Qoo``000aoo`800?mooomool5oo`00I7oo100017oo0`00
3Goo0P003Goo0P004goo0P00ogooogoo`7oo001TOol30006Ool3000<Ool2000=Ool2000COol2003o
OoooOoo0Ool006Aoo`8000Qoo`8000aoo`8000eoo`8001=oo`800?mooomool1oo`00I7oo0P0027oo
0P0037oo0P003Goo0P004goo0P00ogooogoo`7oo001TOol20008Ool2000<Ool2000=Ool2000COol2
003oOoooOoo0Ool006Aoo`8000Qoo`8000aoo`8000eoo`8001=oo`800?mooomool1oo`00KWoo0P00
37oo0P003Goo0P004goo0P00ogooogoo`7oo001^Ool2000<Ool2000=Ool3000BOol2003oOoooOoo0
Ool006ioo`8000aoo`8000eoo`@0015oo`800?mooomool1oo`00KWoo0P003Goo0P0037oo0P0000=o
o`00000017oo0P002Goo0P00ogooogoo`Goo001^Ool2000=Ool20009Ool50002Ool70009Ool2003o
OoooOoo1Ool006ioo`8000eoo`8000Uoo`D000Aoo`@000Yoo`800?mooomool5oo`00KWoo0P003Woo
00<007ooOol07Woo00<007ooOol0ogooogoo`7oo001XOol<000:Ool2000NOol2003oOoooOoo2Ool0
06Qoo``000]oo`03001oogoo01aoo`03001oogoo0?mooomool5oo`00Ogoo00<007ooOol077oo00<0
07ooOol0ogooogoo`Goo0020Ool00`00Oomoo`0JOol00`00Oomoo`3oOoooOoo2Ool00?mooomooomo
of=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00ogooogooogooHgoo0000\
\>"], "Graphics",
  CellLabel->"From In[79]:=",
  Evaluatable->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[TextData[{
  "\[Bullet] the corresponding vector potential az(r) ( ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(A\_z\),
            "TraditionalForm"], "(", \(r\_2\), ")"}], TraditionalForm]]],
  " is forced to 0 ) :"
}], "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(az[r_] := 
      Which[\[IndentingNewLine]r < 
          r0, \(1\/\(4\ \[Pi]\)\) \((\(-r\^2\)\/r0\^2 + 
              Log[r1\^2\/r0\^2] + \(\(\(r2\^2\)\(\ \)\)\/\(r2\^2 - r1\^2\)\) 
                Log[r2\^2\/r1\^2])\), \[IndentingNewLine]r > r2, 
        0. , \[IndentingNewLine]r > 
          r1, \(1\/\(\(4\)\(\ \)\(\[Pi]\)\(\ \)\)\) \((\(-\(\(r2\^2 - 
                      r\^2\)\/\(r2\^2 - 
                      r1\^2\)\)\) + \(\(\(r2\^2\)\(\ \)\)\/\(r2\^2 - 
                      r1\^2\)\) 
                Log[r2\^2\/r\^2])\), \[IndentingNewLine]True, \(1\/\(4\ \[Pi]\
\)\) \((Log[r1\^2\/r\^2] - 
              1 + \(\(\(r2\^2\)\(\ \)\)\/\(r2\^2 - r1\^2\)\) 
                Log[r2\^2\/r1\^2])\)]\), "\[IndentingNewLine]", 
    \(\(Plot[az[r], {r, 0, ns/2}, 
        AxesLabel -> {"\<r\>", "\<Az(r)\>"}];\)\)}], "Input",
  CellLabel->"In[81]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P00025A000`40O003h00OogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00;Mo
o`X000]oo`@0051oo``000]oo`@005Eoo`D000ioo`@005Ioo`L000Yoo`@005Aoo`H000ioo`@005Eo
o`D000eoo`@007Moo`00]goo2P002Goo2000CWoo30002Goo2000DGoo2@002Woo2000E7oo1`0027oo
2000D7oo2P002Woo2000DGoo20002Woo2000MGoo002kOol2000=Ool20004Ool2001?Ool30006Ool2
0009Ool20004Ool2001@Ool40004Ool30009Ool20004Ool2001GOol2000:Ool20004Ool2001@Ool3
0005Ool30009Ool20004Ool2001AOol20004Ool30009Ool20004Ool2001eOol00;]oo`8000aoo`80
00Ioo`8004moo`<000moo`8000Ioo`8004moo`8000Moo`<000Moo`8000Ioo`8005Ioo`8000Uoo`80
00Ioo`8005Qoo`8000Qoo`8000Ioo`8004moo`8000Ioo`<000Moo`8000Ioo`8007Aoo`00^goo0P00
37oo0P001Woo0P00D7oo0`003Woo0P001Woo0P00FGoo0P001goo0P001Woo0P00EWoo0P002Goo0P00
1Woo0P00FGoo0P001goo0P001Woo0P00CWoo0P0027oo0P001goo0P001Woo0P00M7oo002kOol2000;
Ool20008Ool2001@Ool3000<Ool20008Ool2001HOol20006Ool20008Ool2001=Ool<0006Ool20008
Ool2001HOol20006Ool20008Ool2001=Ool20008Ool20006Ool20008Ool2001cOol00;]oo`8000]o
o`8000Qoo`80055oo`<000]oo`8000Qoo`8005Qoo`8000Ioo`8000Qoo`8004eoo``000Ioo`8000Qo
o`8005Qoo`8000Ioo`8000Qoo`8004eoo`8000Qoo`8000Ioo`8000Qoo`8007=oo`00^goo0P002goo
0P0027oo0P00DWoo0`002Woo0P0027oo0P00Egoo0`001Woo0P0027oo0P00CGoo0P001Woo0P0000=o
o`00Ool01Goo0P0027oo0P00F7oo0P001Woo0P0027oo0P00CGoo0P0027oo0P001Woo0P0027oo0P00
Lgoo002kOol2000;Ool20008Ool2001COol30009Ool20008Ool2001FOol30007Ool20008Ool2001>
Ool20005Ool20008Ool20008Ool2001HOol20006Ool20008Ool2001=Ool30006Ool30006Ool20008
Ool2001cOol00;]oo`8000]oo`8000Qoo`8005Aoo`<000Qoo`8000Qoo`8005=oo`D000Qoo`8000Qo
o`8004ioo`<000Aoo`8000Qoo`8000Qoo`8005Moo`8000Moo`8000Qoo`8004eoo`@000Aoo`<000Mo
o`8000Qoo`8007=oo`00^goo0P002goo0P0027oo0P00EGoo0P0027oo0P0027oo0P00Dgoo10002Goo
0P0027oo0P00Cgoo0P0017oo0P0027oo0P0027oo0P00Cgoo0P001Goo0`001goo0P0027oo0P00CGoo
0P0000=oo`0000001@0027oo0P0027oo0P00Lgoo002kOol2000;Ool20008Ool2001FOol20007Ool2
0008Ool2001FOol20008Ool20008Ool2001@Ool20003Ool20008Ool20008Ool2001?Ool90008Ool2
0008Ool2001>Ool00`00Oomoo`050009Ool20008Ool2001cOol00;]oo`8000]oo`8000Qoo`8005Io
o`8000Moo`8000Qoo`8005Moo`8000Moo`8000Qoo`80051oo`<0009oo`8000Qoo`8000Qoo`8004mo
o`800003Ool0000000<000Uoo`8000Qoo`8004ioo`8000moo`8000Qoo`8007=oo`00^goo0P0037oo
0P001Woo0P00CWoo0P001goo0P0027oo0P001Woo0P00F7oo0P0027oo0P001Woo0P00DWoo0P000Woo
0P002Goo0P001Woo0P00D7oo0P0047oo0P001Woo0P00Cgoo0`003goo0P001Woo0P00M7oo002kOol2
000<Ool20006Ool2001>Ool30006Ool20008Ool20006Ool2001@Ool20006Ool20008Ool20006Ool2
001COol200000goo00000009Ool20006Ool2001@Ool2000@Ool20006Ool2001@Ool3000>Ool20006
Ool2001dOol00;Moo`<00003Ool0000000eoo`8000Aoo`8004moo`@000Aoo`8000Yoo`8000Aoo`80
055oo`<000Aoo`<000Uoo`8000Aoo`8005Eoo`@000Yoo`8000Aoo`80055oo`80015oo`8000Aoo`80
059oo`<000ioo`8000Aoo`8007Eoo`00]goo1P003Goo2000D7oo20002goo2000DWoo20002Woo2000
EGoo10002Woo2000DGoo2P002Goo2000Dgoo200027oo2000MGoo002jOol3000?Ool4001DOol5000>
Ool4001EOol5000>Ool4001HOol3000<Ool4001COol:000;Ool4001GOol6000:Ool4001gOol00?mo
oomooomoof=oo`00ogooogooogooHgoo001JOol00`00Oomoo`3oOoooOoooOol6Ool005Yoo`03001o
ogoo0?mooomooomoo`Ioo`00FWoo00<007ooOol0ogooogooogoo1Woo001JOol00`00Oomoo`3oOooo
OooTOol<000EOol005Yoo`03001oogoo0?mooomoonAoo``001Eoo`00FWoo00<007ooOol0ogooogoo
j7oo0P006goo001JOol00`00Oomoo`3oOoooOooXOol2000KOol005Yoo`03001oogoo0?mooomoonQo
o`8001]oo`00FWoo00<007ooOol0ogooogooj7oo0P006goo001JOol00`00Oomoo`3oOoooOooXOol2
000KOol005Yoo`03001oogoo0?mooomoonQoo`8001]oo`00B7ooo`00o`00h0007Goo0P006goo001J
Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0B
Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0B
Ool00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0C
Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0B
Ool00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0C
Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0B
Ool00`00Oomoo`0?Ool6000COol00`00Oomoo`0COol00`00Oomoo`0QOol3000JOol005Yoo`03001o
ogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001o
ogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001o
ogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001o
ogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001o
ogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001o
ogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001o
ogoo00aoo`<000Aoo`03001oogoo019oo`03001oogoo01=oo`03001oogoo025oo`@001Uoo`00FWoo
00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo
00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo
00<007ooOol04goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04goo
00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo
00<007ooOol04goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04goo
00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo
00<007ooOol02Goo0`001goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol08Goo0P0000=o
o`00000017oo0P004Woo001JOol00`00Oomoo`1XOol00`00Oomoo`1XOol00`00Oomoo`1YOol00`00
Oomoo`1XOol00`00Oomoo`1YOol00`00Oomoo`1XOol00`00Oomoo`07Ool2001FOol50002Ool7000B
Ool005Yoo`03001oogoo0?mooomoohYoo`<005Qoo`D000Aoo`@001=oo`00FWoo00<007ooOol0ogoo
ogooQgoo0`00Ngoo001JOol00`00Oomoo`3oOoooOon5Ool2001nOol005Yoo`03001oogoo0?mooomo
ohAoo`03001oogoo07ioo`00FWoo00<007ooOol0ogooogooPWoo0P00PGoo001JOol00`00Oomoo`3o
OoooOon0Ool20023Ool005Yoo`03001oogoo0?mooomoogioo`8008Eoo`00FWoo00<007ooOol0ogoo
ogooOGoo00<007ooOol0QGoo001JOol00`00Oomoo`3oOoooOomkOol20028Ool005Yoo`03001oogoo
0?mooomoogUoo`8008Yoo`00FWoo00<007ooOol0ogooogooMgoo0P00S7oo001JOol00`00Oomoo`3o
OoooOomeOol2002>Ool005Yoo`03001oogoo0?mooomoogAoo`03001oogoo08ioo`00FWoo00<007oo
Ool0ogooogooLWoo0P00TGoo001JOol00`00Oomoo`3oOoooOom`Ool2002COol005Yoo`03001oogoo
0?mooomoofioo`8009Eoo`00FWoo00<007ooOol0ogooogooK7oo0P00Ugoo001JOol3003oOoooOomZ
Ool2002IOol005Yoo`03001oogoo0?mooomoofUoo`03001oogoo09Uoo`00FWoo00<007ooOol0ogoo
ogooIgoo0P00W7oo001JOol00`00Oomoo`3oOoooOomUOol2002NOol005Yoo`03001oogoo0?mooomo
of=oo`800:1oo`00FWoo00<007ooOol0ogooogooHGoo0P00XWoo001JOol00`00Oomoo`3oOoooOomP
Ool00`00Oomoo`2ROol005Yoo`03001oogoo0?mooomooeioo`800:Eoo`00FWoo00<007ooOol0ogoo
ogooG7oo0P00Ygoo001JOol00`00Oomoo`3oOoooOomKOol00`00Oomoo`2WOol005Yoo`03001oogoo
0?mooomooeUoo`800:Yoo`00FWoo00<007ooOol0ogooogooEgoo0P00[7oo001JOol00`00Oomoo`3o
OoooOomFOol00`00Oomoo`2/Ool005Yoo`03001oogoo0?mooomooeAoo`800:moo`00FWoo00<007oo
Ool0ogooogooDWoo0P00/Goo001JOol00`00Oomoo`3oOoooOomAOol00`00Oomoo`2aOol005Yoo`03
001oogoo0?mooomoodmoo`800;Aoo`00FWoo00<007ooOol0ogooogooCGoo0P00]Woo001JOol00`00
Oomoo`3oOoooOom<Ool00`00Oomoo`2fOol005Yoo`03001oogoo0?mooomoodYoo`800;Uoo`00FWoo
00<007ooOol0ogooogooB7oo0P00^goo001JOol00`00Oomoo`3oOoooOom7Ool00`00Oomoo`2kOol0
05Yoo`<00?mooomoodEoo`800;ioo`00FWoo00<007ooOol0ogooogooA7oo00<007ooOol0_Woo001J
Ool00`00Oomoo`3oOoooOom2Ool20031Ool005Yoo`03001oogoo0?mooomood1oo`800<=oo`00FWoo
00<007ooOol0ogooogoo?goo00<007ooOol0`goo001JOol00`00Oomoo`3oOoooOolmOol20036Ool0
05Yoo`03001oogoo0?mooomoocaoo`03001oogoo0<Ioo`00FWoo00<007ooOol0ogooogoo>Woo0P00
bGoo001JOol00`00Oomoo`3oOoooOolhOol2003;Ool005Yoo`03001oogoo0?mooomoocMoo`03001o
ogoo0<]oo`00FWoo00<007ooOol0ogooogoo=Goo0P00cWoo001JOol00`00Oomoo`3oOoooOolcOol2
003@Ool005Yoo`03001oogoo0?mooomooc9oo`03001oogoo0=1oo`00FWoo00<007ooOol0ogooogoo
<7oo0P00dgoo001JOol00`00Oomoo`3oOoooOol_Ool00`00Oomoo`3COol005Yoo`03001oogoo0?mo
oomoobeoo`800=Ioo`00FWoo00<007ooOol0ogooogoo:goo0P00f7oo001JOol00`00Oomoo`3oOooo
OolZOol00`00Oomoo`3HOol005Yoo`03001oogoo0?mooomoobQoo`800=]oo`00FWoo00<007ooOol0
ogooogoo9goo00<007ooOol0fgoo001JOol00`00Oomoo`3oOoooOolUOol2003NOol005Yoo`03001o
ogoo0?mooomoobAoo`03001oogoo0=ioo`00FWoo00<007ooOol0ogooogoo8Woo0P00hGoo001JOol3
003oOoooOolPOol2003SOol005Yoo`03001oogoo0?mooomooamoo`03001oogoo0>=oo`00FWoo00<0
07ooOol0ogooogoo7Goo0P00iWoo001JOol00`00Oomoo`3oOoooOolLOol00`00Oomoo`3VOol005Yo
o`03001oogoo0?mooomooaYoo`800>Uoo`00FWoo00<007ooOol0ogooogoo6Goo00<007ooOol0jGoo
001JOol00`00Oomoo`3oOoooOolGOol2003/Ool005Yoo`03001oogoo0?mooomooaIoo`03001oogoo
0>aoo`00FWoo00<007ooOol0ogooogoo57oo0P00kgoo001JOol00`00Oomoo`3oOoooOolBOol2003a
Ool005Yoo`03001oogoo0?mooomooa5oo`03001oogoo0?5oo`00FWoo00<007ooOol0ogooogoo3goo
0P00m7oo001JOol00`00Oomoo`3oOoooOol>Ool00`00Oomoo`3dOol005Yoo`03001oogoo0?mooomo
o`aoo`800?Moo`00FWoo00<007ooOol0ogooogoo2goo00<007ooOol0mgoo001JOol00`00Oomoo`3o
OoooOol9Ool2003jOol005Yoo`03001oogoo0?mooomoo`Qoo`03001oogoo0?Yoo`00FWoo00<007oo
Ool0ogooogoo1Woo0P00oGoo001JOol00`00Oomoo`3oOoooOol5Ool00`00Oomoo`3mOol005Yoo`03
001oogoo0?mooomoo`Aoo`03001oogoo0?ioo`00FWoo00<007ooOol0ogooogoo0Woo0P00ogoo0Woo
001JOol00`00Oomoo`3oOoooOol1Ool00`00Oomoo`3oOol2Ool005Yoo`<00?moooioo`800?moo`Eo
o`00FWoo00<007ooOol0ogoooGoo00<007ooOol0ogoo1Goo001JOol00`00Oomoo`3oOookOol2003o
Ool8Ool005Yoo`03001oogoo0?moooYoo`03001oogoo0?moo`Qoo`00FWoo00<007ooOol0ogoon7oo
0P00ogoo2goo001JOol00`00Oomoo`3oOoogOol00`00Oomoo`3oOol;Ool005Yoo`03001oogoo0?mo
ooIoo`03001oogoo0?moo`aoo`00FWoo00<007ooOol0ogoom7oo0P00ogoo3goo001JOol00`00Oomo
o`3oOoocOol00`00Oomoo`3oOol?Ool005Yoo`03001oogoo0?mooo5oo`800?mooa9oo`00FWoo00<0
07ooOol0ogool7oo00<007ooOol0ogoo4Woo001JOol00`00Oomoo`3oOoo^Ool2003oOolEOol005Yo
o`03001oogoo0?mooneoo`03001oogoo0?mooaEoo`00FWoo00<007ooOol0ogook7oo00<007ooOol0
ogoo5Woo001JOol00`00Oomoo`3oOooZOol2003oOolIOol000moo`@000ioo`<000moo`@000aoo`H0
015oo`03001oogoo0?moonUoo`03001oogoo0?mooaUoo`003Goo20002goo1@0037oo200027oo2P00
3goo00<007ooOol0ogooigoo0P00ogoo77oo000=Ool20004Ool2000;Ool5000<Ool20004Ool20008
Ool30005Ool3000>Ool00`00Oomoo`3oOooVOol00`00Oomoo`3oOolLOol000aoo`8000Ioo`8000Yo
o`D000]oo`8000Ioo`80011oo`8000ioo`03001oogoo0?moonEoo`03001oogoo0?mooaeoo`0037oo
0P001Woo0P002goo0`0037oo0P001Woo0P004Goo0P003Goo00<007ooOol0ogoohgoo0P00ogoo87oo
000;Ool20008Ool2000HOol20008Ool2000@Ool2000=Ool00`00Oomoo`3oOooROol00`00Oomoo`3o
OolPOol000]oo`8000Qoo`8001Qoo`8000Qoo`80011oo`8000eoo`03001oogoo0?moon5oo`03001o
ogoo0?moob5oo`002goo0P0027oo0P0067oo0P0027oo0P0047oo0P003Goo1@00ogoogGoo0P00ogoo
97oo000;Ool20008Ool2000HOol20008Ool2000@Ool2000=Ool00`00Oomoo`3oOooNOol00`00Oomo
o`3oOolTOol000]oo`8000Qoo`8001Qoo`8000Qoo`8000moo`8000ioo`03001oogoo0?moomeoo`03
001oogoo0?moobEoo`002goo0P0027oo0P0067oo0P0027oo0P001goo0P001Goo0`003Woo00<007oo
Ool0ogoofgoo0P00ogoo:7oo000;Ool20008Ool2000HOol20008Ool20007Ool9000?Ool00`00Oomo
o`3oOooJOol00`00Oomoo`3oOolXOol000]oo`8000Qoo`8001Qoo`8000Qoo`8000Moo`800003Ool0
000000<0011oo`03001oogoo0?moomQoo`800?moob]oo`0037oo0P001Woo0P006Woo0P001Woo0P00
27oo0P005Woo00<007ooOol0ogooegoo00<007ooOol0ogoo:goo000<Ool20006Ool2000JOol20006
Ool20008Ool2000FOol00`00Oomoo`3oOooFOol00`00Oomoo`3oOol/Ool000eoo`8000Aoo`8001ao
o`8000Aoo`8000Uoo`8001Ioo`03001oogoo0?moomAoo`800?moobmoo`003Goo200077oo20002Goo
2P003Woo00<007ooOol0ogoodgoo00<007ooOol0ogoo;goo000?Ool4000POol4000;Ool:000>Ool0
0`00Oomoo`3oOooBOol00`00Oomoo`3oOol`Ool005Yoo`03001oogoo0?moom1oo`800?mooc=oo`00
FWoo00<007ooOol0ogoocgoo00<007ooOol0ogoo<goo001JOol00`00Oomoo`3oOoo>Ool00`00Oomo
o`3oOoldOol005Yoo`03001oogoo0?mooleoo`03001oogoo0?moocEoo`00FWoo00<007ooOol0ogoo
bgoo0P00ogoo>7oo001JOol00`00Oomoo`3oOoo:Ool00`00Oomoo`3oOolhOol005Yoo`03001oogoo
0?moolUoo`03001oogoo0?moocUoo`00FWoo00<007ooOol0ogooagoo0P00ogoo?7oo001JOol00`00
Oomoo`3oOoo6Ool00`00Oomoo`3oOollOol005Yoo`03001oogoo0?moolEoo`03001oogoo0?mooceo
o`00FWoo00<007ooOol0ogooa7oo00<007ooOol0ogoo?Woo001JOol3003oOoo2Ool2003oOom1Ool0
05Yoo`03001oogoo0?mool5oo`03001oogoo0?mood5oo`00FWoo00<007ooOol0ogoo`7oo00<007oo
Ool0ogoo@Woo001JOol00`00Oomoo`3oOonoOol00`00Oomoo`3oOom3Ool005Yoo`03001oogoo0?mo
okeoo`800?moodIoo`00FWoo00<007ooOol0ogoo_7oo00<007ooOol0ogooAWoo001JOol00`00Oomo
o`3oOonkOol00`00Oomoo`3oOom7Ool005Yoo`03001oogoo0?mookUoo`800?moodYoo`00FWoo00<0
07ooOol0ogoo^7oo00<007ooOol0ogooBWoo001JOol00`00Oomoo`3oOongOol00`00Oomoo`3oOom;
Ool005Yoo`03001oogoo0?mookIoo`03001oogoo0?moodaoo`00FWoo00<007ooOol0ogoo]7oo0P00
ogooCgoo001JOol00`00Oomoo`3oOoncOol00`00Oomoo`3oOom?Ool005Yoo`03001oogoo0?mook9o
o`03001oogoo0?mooe1oo`00FWoo00<007ooOol0ogoo/Goo00<007ooOol0ogooDGoo001JOol00`00
Oomoo`3oOon`Ool00`00Oomoo`3oOomBOol005Yoo`03001oogoo0?moojmoo`03001oogoo0?mooe=o
o`00FWoo00<007ooOol0ogoo[Goo0P00ogooEWoo001JOol00`00Oomoo`3oOon/Ool00`00Oomoo`3o
OomFOol005Yoo`03001oogoo0?mooj]oo`03001oogoo0?mooeMoo`00FWoo00<007ooOol0ogooZWoo
00<007ooOol0ogooF7oo001JOol00`00Oomoo`3oOonYOol00`00Oomoo`3oOomIOol005Yoo`03001o
ogoo0?moojQoo`03001oogoo0?mooeYoo`00FWoo0`00ogooYWoo0P00ogooGGoo001JOol00`00Oomo
o`3oOonUOol00`00Oomoo`3oOomMOol005Yoo`03001oogoo0?moojAoo`03001oogoo0?mooeioo`00
FWoo00<007ooOol0ogooXgoo00<007ooOol0ogooGgoo001JOol00`00Oomoo`3oOonROol00`00Oomo
o`3oOomPOol005Yoo`03001oogoo0?mooj5oo`03001oogoo0?moof5oo`00FWoo00<007ooOol0ogoo
X7oo00<007ooOol0ogooHWoo001JOol00`00Oomoo`3oOonNOol2003oOomUOol005Yoo`03001oogoo
0?mooieoo`03001oogoo0?moofEoo`00FWoo00<007ooOol0ogooW7oo00<007ooOol0ogooIWoo001J
Ool00`00Oomoo`3oOonKOol00`00Oomoo`3oOomWOol005Yoo`03001oogoo0?mooiYoo`03001oogoo
0?moofQoo`00FWoo00<007ooOol0ogooVGoo00<007ooOol0ogooJGoo001JOol00`00Oomoo`3oOonG
Ool2003oOom/Ool005Yoo`03001oogoo0?mooiIoo`03001oogoo0?moofaoo`00FWoo00<007ooOol0
ogooUGoo00<007ooOol0ogooKGoo001JOol00`00Oomoo`3oOonDOol00`00Oomoo`3oOom^Ool005Yo
o`03001oogoo0?mooi=oo`03001oogoo0?moofmoo`00FWoo00<007ooOol0ogooTWoo00<007ooOol0
ogooL7oo001JOol00`00Oomoo`3oOonAOol00`00Oomoo`3oOomaOol005Yoo`03001oogoo0?mooi1o
o`03001oogoo0?moog9oo`00FWoo00<007ooOol0ogooSgoo00<007ooOol0ogooLgoo001JOol3003o
Oon=Ool2003oOomfOol005Yoo`03001oogoo0?moohaoo`03001oogoo0?moogIoo`00FWoo00<007oo
Ool0ogooRgoo00<007ooOol0ogooMgoo001JOol00`00Oomoo`3oOon:Ool00`00Oomoo`3oOomhOol0
05Yoo`03001oogoo0?moohUoo`03001oogoo0?moogUoo`00FWoo00<007ooOol0ogooR7oo00<007oo
Ool0ogooNWoo001JOol00`00Oomoo`3oOon7Ool00`00Oomoo`3oOomkOol005Yoo`03001oogoo0?mo
ohIoo`03001oogoo0?moogaoo`00FWoo00<007ooOol0ogooQGoo00<007ooOol0ogooOGoo001JOol0
0`00Oomoo`3oOon3Ool2003oOon0Ool005Yoo`03001oogoo0?mooh9oo`03001oogoo0?mooh1oo`00
FWoo00<007ooOol0ogooPGoo00<007ooOol0ogooPGoo001JOol00`00Oomoo`3oOon0Ool00`00Oomo
o`3oOon2Ool005Yoo`03001oogoo0?moogmoo`03001oogoo0?mooh=oo`00FWoo00<007ooOol0ogoo
OWoo00<007ooOol0ogooQ7oo001JOol00`00Oomoo`3oOommOol00`00Oomoo`3oOon5Ool005Yoo`03
001oogoo0?moogaoo`03001oogoo0?moohIoo`00FWoo00<007ooOol0ogooNgoo00<007ooOol0ogoo
Qgoo001JOol00`00Oomoo`3oOomiOol2003oOon:Ool005Yoo`03001oogoo0?moogQoo`03001oogoo
0?moohYoo`00FWoo00<007ooOol0ogooMgoo00<007ooOol0ogooRgoo001JOol00`00Oomoo`3oOomf
Ool00`00Oomoo`3oOon<Ool005Yoo`<00?moogEoo`03001oogoo0?mooheoo`00FWoo00<007ooOol0
ogooM7oo00<007ooOol0ogooSWoo001JOol00`00Oomoo`3oOomcOol00`00Oomoo`3oOon?Ool005Yo
o`03001oogoo0?moog9oo`03001oogoo0?mooi1oo`00FWoo00<007ooOol0ogooLGoo00<007ooOol0
ogooTGoo001JOol00`00Oomoo`3oOom`Ool00`00Oomoo`3oOonBOol005Yoo`03001oogoo0?moofmo
o`03001oogoo0?mooi=oo`00FWoo00<007ooOol0ogooKWoo00<007ooOol0ogooU7oo001JOol00`00
Oomoo`3oOom]Ool00`00Oomoo`3oOonEOol005Yoo`03001oogoo0?moofaoo`03001oogoo0?mooiIo
o`00FWoo00<007ooOol0ogooJgoo00<007ooOol0ogooUgoo001JOol00`00Oomoo`3oOomZOol00`00
Oomoo`3oOonHOol005Yoo`03001oogoo0?moofUoo`03001oogoo0?mooiUoo`00FWoo00<007ooOol0
ogooJ7oo00<007ooOol0ogooVWoo001JOol00`00Oomoo`3oOomWOol00`00Oomoo`3oOonKOol0025o
o`@000ioo`<000aoo`X000ioo`03001oogoo0?moofIoo`03001oogoo0?mooiaoo`007goo20002goo
1@002goo2P003Woo00<007ooOol0ogooIGoo00<007ooOol0ogooWGoo000OOol20004Ool2000;Ool5
000?Ool2000BOol00`00Oomoo`3oOomTOol00`00Oomoo`3oOonNOol001ioo`8000Ioo`8000Yoo`D0
00moo`80019oo`03001oogoo0?moof=oo`03001oogoo0?mooimoo`007Woo0P001Woo0P002goo0`00
47oo0P004Woo00<007ooOol0ogooHWoo00<007ooOol0ogooX7oo000MOol20008Ool2000MOol2000B
Ool00`00Oomoo`3oOomQOol00`00Oomoo`3oOonQOol001eoo`8000Qoo`8001eoo`80019oo`03001o
ogoo0?moof1oo`03001oogoo0?mooj9oo`007Goo0P0027oo0P007Goo0P004Woo1@00ogooGGoo00<0
07ooOol0ogooXgoo000MOol20008Ool2000MOol2000BOol00`00Oomoo`3oOomNOol00`00Oomoo`3o
OonTOol001eoo`8000Qoo`8001eoo`80019oo`03001oogoo0?mooeeoo`03001oogoo0?moojEoo`00
7Goo0P0027oo0P007Goo0P004Woo00<007ooOol0ogooGGoo00<007ooOol0ogooYGoo000MOol20008
Ool2000MOol2000BOol00`00Oomoo`3oOomLOol00`00Oomoo`3oOonVOol001eoo`8000Qoo`8001eo
o`80019oo`03001oogoo0?mooe]oo`03001oogoo0?moojMoo`007Woo0P001Woo0P007Woo0P004Woo
00<007ooOol0ogooFWoo00<007ooOol0ogooZ7oo000NOol20006Ool2000NOol2000BOol00`00Oomo
o`3oOomIOol00`00Oomoo`3oOonYOol001moo`8000Aoo`8001]oo`<00003Ool00000019oo`03001o
ogoo0?mooeQoo`03001oogoo0?moojYoo`007goo20006goo1P004Woo00<007ooOol0ogooEgoo00<0
07ooOol0ogooZgoo000QOol4000POol3000BOol00`00Oomoo`3oOomFOol00`00Oomoo`3oOon/Ool0
05Yoo`03001oogoo0?mooeEoo`03001oogoo0?moojeoo`00FWoo00<007ooOol0ogooE7oo00<007oo
Ool0ogoo[Woo001JOol00`00Oomoo`3oOomCOol00`00Oomoo`3oOon_Ool005Yoo`03001oogoo0?mo
oe9oo`03001oogoo0?mook1oo`00FWoo00<007ooOol0ogooDGoo00<007ooOol0ogoo/Goo001JOol0
0`00Oomoo`3oOom@Ool00`00Oomoo`3oOonbOol005Yoo`03001oogoo0?moodmoo`03001oogoo0?mo
ok=oo`00FWoo00<007ooOol0ogooCWoo00<007ooOol0ogoo]7oo001JOol00`00Oomoo`3oOom=Ool0
0`00Oomoo`3oOoneOol005Yoo`03001oogoo0?moodaoo`03001oogoo0?mookIoo`00FWoo00<007oo
Ool0ogooBgoo00<007ooOol0ogoo]goo001JOol00`00Oomoo`3oOom:Ool00`00Oomoo`3oOonhOol0
05Yoo`<00?moodUoo`03001oogoo0?mookUoo`00FWoo00<007ooOol0ogooB7oo00<007ooOol0ogoo
^Woo001JOol00`00Oomoo`3oOom7Ool00`00Oomoo`3oOonkOol005Yoo`03001oogoo0?moodIoo`03
001oogoo0?mookaoo`00FWoo00<007ooOol0ogooAGoo00<007ooOol0ogoo_Goo001JOol00`00Oomo
o`3oOom4Ool00`00Oomoo`3oOonnOol005Yoo`03001oogoo0?mood=oo`03001oogoo0?mookmoo`00
FWoo00<007ooOol0ogoo@Woo00<007ooOol0ogoo`7oo001JOol00`00Oomoo`3oOom1Ool00`00Oomo
o`3oOoo1Ool005Yoo`03001oogoo0?mood1oo`03001oogoo0?mool9oo`00FWoo00<007ooOol0ogoo
?goo00<007ooOol0ogoo`goo001JOol00`00Oomoo`3oOoloOol00`00Oomoo`3oOoo3Ool005Yoo`03
001oogoo0?moocioo`03001oogoo0?moolAoo`00FWoo00<007ooOol0ogoo?Goo00<007ooOol0ogoo
aGoo001JOol00`00Oomoo`3oOollOol00`00Oomoo`3oOoo6Ool005Yoo`03001oogoo0?mooc]oo`03
001oogoo0?moolMoo`00FWoo00<007ooOol0ogoo>Woo00<007ooOol0ogoob7oo001JOol00`00Oomo
o`3oOoliOol00`00Oomoo`3oOoo9Ool005Yoo`03001oogoo0?moocQoo`03001oogoo0?moolYoo`00
FWoo00<007ooOol0ogoo=goo00<007ooOol0ogoobgoo001JOol00`00Oomoo`3oOolfOol00`00Oomo
o`3oOoo<Ool005Yoo`03001oogoo0?moocEoo`03001oogoo0?mooleoo`00FWoo0`00ogoo=7oo00<0
07ooOol0ogoocWoo001JOol00`00Oomoo`3oOolcOol00`00Oomoo`3oOoo?Ool005Yoo`03001oogoo
0?mooc9oo`03001oogoo0?moom1oo`00FWoo00<007ooOol0ogoo<Goo00<007ooOol0ogoodGoo001J
Ool00`00Oomoo`3oOolaOol00`00Oomoo`3oOooAOol005Yoo`03001oogoo0?mooc1oo`03001oogoo
0?moom9oo`00FWoo00<007ooOol0ogoo;goo00<007ooOol0ogoodgoo001JOol00`00Oomoo`3oOol^
Ool00`00Oomoo`3oOooDOol005Yoo`03001oogoo0?moobeoo`03001oogoo0?moomEoo`00FWoo00<0
07ooOol0ogoo;7oo00<007ooOol0ogooeWoo001JOol00`00Oomoo`3oOol[Ool00`00Oomoo`3oOooG
Ool005Yoo`03001oogoo0?moobYoo`03001oogoo0?moomQoo`00FWoo00<007ooOol0ogoo:Goo00<0
07ooOol0ogoofGoo001JOol00`00Oomoo`3oOolXOol00`00Oomoo`3oOooJOol005Yoo`03001oogoo
0?moobMoo`03001oogoo0?moom]oo`00FWoo00<007ooOol0ogoo9Woo00<007ooOol0ogoog7oo001J
Ool00`00Oomoo`3oOolUOol00`00Oomoo`3oOooMOol005Yoo`03001oogoo0?moob=oo`800?moon1o
o`00FWoo00<007ooOol0ogoo8Woo00<007ooOol0ogooh7oo001JOol00`00Oomoo`3oOolQOol00`00
Oomoo`3oOooQOol005Yoo`03001oogoo0?moob1oo`03001oogoo0?moon9oo`00FWoo00<007ooOol0
ogoo7goo00<007ooOol0ogoohgoo001JOol3003oOolNOol00`00Oomoo`3oOooTOol005Yoo`03001o
ogoo0?mooaeoo`03001oogoo0?moonEoo`00FWoo00<007ooOol0ogoo77oo00<007ooOol0ogooiWoo
001JOol00`00Oomoo`3oOolKOol00`00Oomoo`3oOooWOol005Yoo`03001oogoo0?mooaYoo`03001o
ogoo0?moonQoo`00FWoo00<007ooOol0ogoo6Goo00<007ooOol0ogoojGoo001JOol00`00Oomoo`3o
OolHOol00`00Oomoo`3oOooZOol005Yoo`03001oogoo0?mooaMoo`03001oogoo0?moon]oo`00FWoo
00<007ooOol0ogoo5Woo00<007ooOol0ogook7oo001JOol00`00Oomoo`3oOolEOol00`00Oomoo`3o
Ooo]Ool005Yoo`03001oogoo0?mooaAoo`03001oogoo0?moonioo`00FWoo00<007ooOol0ogoo4goo
00<007ooOol0ogookgoo001JOol00`00Oomoo`3oOolBOol00`00Oomoo`3oOoo`Ool005Yoo`03001o
ogoo0?mooa5oo`03001oogoo0?mooo5oo`00FWoo00<007ooOol0ogoo47oo00<007ooOol0ogoolWoo
001JOol00`00Oomoo`3oOol?Ool00`00Oomoo`3oOoocOol005Yoo`03001oogoo0?moo`ioo`03001o
ogoo0?moooAoo`00FWoo00<007ooOol0ogoo3Goo00<007ooOol0ogoomGoo001JOol00`00Oomoo`3o
Ool<Ool00`00Oomoo`3oOoofOol005Yoo`03001oogoo0?moo`]oo`03001oogoo0?moooMoo`00FWoo
00<007ooOol0ogoo2Woo00<007ooOol0ogoon7oo001JOol00`00Oomoo`3oOol9Ool00`00Oomoo`3o
OooiOol005Yoo`03001oogoo0?moo`Qoo`03001oogoo0?moooYoo`00FWoo0`00ogoo1Woo0P00ogoo
oGoo001JOol00`00Oomoo`3oOol5Ool00`00Oomoo`3oOoomOol005Yoo`03001oogoo0?moo`Aoo`03
001oogoo0?moooioo`00FWoo00<007ooOol0ogoo0goo00<007ooOol0ogooogoo001JOol00`00Oomo
o`3oOol2Ool00`00Oomoo`3oOoooOol1Ool005Yoo`03001oogoo0?moo`800?mooomoo`Aoo`00FWoo
00<007ooOol0oWoo00<007ooOol0ogooogoo17oo001JOol00`00Oomoo`3mOol00`00Oomoo`3oOooo
Ool5Ool005Yoo`03001oogoo0?aoo`03001oogoo0?mooomoo`Ioo`00FWoo00<007ooOol0ngoo00<0
07ooOol0ogooogoo1goo001JOol00`00Oomoo`3iOol2003oOoooOol:Ool005Yoo`03001oogoo0?Qo
o`03001oogoo0?mooomoo`Yoo`00FWoo00<007ooOol0mgoo00<007ooOol0ogooogoo2goo001JOol0
0`00Oomoo`3fOol00`00Oomoo`3oOoooOol<Ool005Yoo`03001oogoo0?Eoo`03001oogoo0?mooomo
o`eoo`003goo10003Woo0`0037oo2P002Goo1P004Goo00<007ooOol0lgoo0P00ogooogoo47oo000=
Ool8000;Ool5000;Ool:0007Ool:000?Ool00`00Oomoo`3bOol00`00Oomoo`3oOoooOol@Ool000eo
o`8000Aoo`8000]oo`D000moo`8000]oo`<000Eoo`<000ioo`03001oogoo0?5oo`03001oogoo0?mo
oomooa5oo`0037oo0P001Woo0P002Woo1@003goo0P0057oo0P003Woo00<007ooOol0l7oo00<007oo
Ool0ogooogoo4Woo000<Ool20006Ool2000;Ool3000@Ool2000EOol2000=Ool00`00Oomoo`3_Ool0
0`00Oomoo`3oOoooOolCOol000]oo`8000Qoo`8001eoo`8001Eoo`8000eoo`03001oogoo0>eoo`80
0?mooomooaIoo`002goo0P0027oo0P007Goo0P005Goo0P003Goo00<007ooOol0k7oo00<007ooOol0
ogooogoo5Woo000;Ool20008Ool2000MOol2000EOol2000=Ool5003YOol00`00Oomoo`3oOoooOolG
Ool000]oo`8000Qoo`8001eoo`8001Eoo`8000eoo`03001oogoo0>Yoo`03001oogoo0?mooomooaQo
o`002goo0P0027oo0P007Goo0P0057oo0P003Woo00<007ooOol0jGoo00<007ooOol0ogooogoo6Goo
000;Ool20008Ool2000MOol2000<Ool20005Ool3000>Ool00`00Oomoo`3WOol2003oOoooOolLOol0
00]oo`8000Qoo`8001eoo`8000aoo`T000moo`03001oogoo0>Ioo`03001oogoo0?mooomooaaoo`00
2goo0P0027oo0P007Goo0P0037oo0P0000=oo`0000000`0047oo00<007ooOol0iGoo00<007ooOol0
ogooogoo7Goo000<Ool20006Ool2000NOol2000<Ool2000FOol00`00Oomoo`3SOol2003oOoooOolP
Ool000aoo`8000Ioo`8001ioo`8000aoo`8001Ioo`03001oogoo0>9oo`03001oogoo0?mooomoob1o
o`003Goo0P0017oo0P006goo0`0000=oo`00000037oo0P005Woo00<007ooOol0hGoo00<007ooOol0
ogooogoo8Goo000=Ool8000KOol6000<Ool:000>Ool00`00Oomoo`3OOol2003oOoooOolTOol000mo
o`@0021oo`<000aoo`X000ioo`03001oogoo0=ioo`03001oogoo0?mooomoobAoo`00FWoo00<007oo
Ool0gGoo00<007ooOol0ogooogoo9Goo001JOol00`00Oomoo`3KOol2003oOoooOolXOol005Yoo`03
001oogoo0=Yoo`03001oogoo0?mooomoobQoo`00FWoo00<007ooOol0fGoo00<007ooOol0ogooogoo
:Goo001JOol00`00Oomoo`3HOol00`00Oomoo`3oOoooOolZOol005Yoo`03001oogoo0=Ioo`800?mo
oomoobeoo`00FWoo00<007ooOol0eGoo00<007ooOol0ogooogoo;Goo001JOol00`00Oomoo`3DOol0
0`00Oomoo`3oOoooOol^Ool005Yoo`03001oogoo0=9oo`800?mooomooc5oo`00FWoo00<007ooOol0
dGoo00<007ooOol0ogooogoo<Goo001JOol00`00Oomoo`3@Ool00`00Oomoo`3oOoooOolbOol005Yo
o`<00<ioo`800?mooomoocEoo`00FWoo00<007ooOol0cGoo00<007ooOol0ogooogoo=Goo001JOol0
0`00Oomoo`3<Ool00`00Oomoo`3oOoooOolfOol005Yoo`03001oogoo0<Yoo`800?mooomoocUoo`00
FWoo00<007ooOol0bGoo00<007ooOol0ogooogoo>Goo001JOol00`00Oomoo`37Ool2003oOoooOoll
Ool005Yoo`03001oogoo0<Ioo`03001oogoo0?mooomoocaoo`00FWoo00<007ooOol0a7oo0P00ogoo
ogoo?goo001JOol00`00Oomoo`33Ool00`00Oomoo`3oOoooOoloOol005Yoo`03001oogoo0<5oo`80
0?mooomood9oo`00FWoo00<007ooOol0`7oo00<007ooOol0ogooogoo@Woo001JOol00`00Oomoo`2n
Ool2003oOoooOom5Ool005Yoo`03001oogoo0;aoo`800?mooomoodMoo`00FWoo00<007ooOol0^goo
00<007ooOol0ogooogooAgoo001JOol00`00Oomoo`2iOol2003oOoooOom:Ool005Yoo`03001oogoo
0;Qoo`03001oogoo0?mooomoodYoo`00FWoo00<007ooOol0]Woo0P00ogooogooCGoo001JOol00`00
Oomoo`2eOol00`00Oomoo`3oOoooOom=Ool005Yoo`03001oogoo0;=oo`800?mooomooe1oo`00FWoo
00<007ooOol0/Woo00<007ooOol0ogooogooD7oo001JOol00`00Oomoo`2`Ool2003oOoooOomCOol0
05Yoo`03001oogoo0:moo`03001oogoo0?mooomooe=oo`00FWoo0`00[Goo0P00ogooogooEWoo001J
Ool00`00Oomoo`2[Ool2003oOoooOomHOol005Yoo`03001oogoo0:Uoo`800?mooomooeYoo`00FWoo
00<007ooOol0Z7oo00<007ooOol0ogooogooFWoo001JOol00`00Oomoo`2VOol2003oOoooOomMOol0
05Yoo`03001oogoo0:Aoo`800?mooomooemoo`00FWoo00<007ooOol0XWoo0P00ogooogooHGoo001J
Ool00`00Oomoo`2POol2003oOoooOomSOol005Yoo`03001oogoo09ioo`800?mooomoofEoo`00FWoo
00<007ooOol0WGoo00<007ooOol0ogooogooIGoo001JOol00`00Oomoo`2KOol2003oOoooOomXOol0
05Yoo`03001oogoo09Uoo`800?mooomoofYoo`00FWoo00<007ooOol0Ugoo0P00ogooogooK7oo001J
Ool00`00Oomoo`2EOol2003oOoooOom^Ool005Yoo`03001oogoo09Aoo`03001oogoo0?mooomoofio
o`00FWoo00<007ooOol0TWoo0P00ogooogooLGoo001JOol00`00Oomoo`2@Ool2003oOoooOomcOol0
05Yoo`03001oogoo08ioo`800?mooomoogEoo`00FWoo00<007ooOol0S7oo0P00ogooogooMgoo001J
Ool00`00Oomoo`2:Ool2003oOoooOomiOol005Yoo`03001oogoo08Moo`<00?mooomoog]oo`00FWoo
00<007ooOol0QGoo0P00ogooogooOWoo001JOol00`00Oomoo`23Ool2003oOoooOon0Ool005Yoo`<0
085oo`800?mooomooh9oo`00FWoo00<007ooOol0Ogoo0P00ogooogooQ7oo001JOol00`00Oomoo`1m
Ool2003oOoooOon6Ool005Yoo`03001oogoo07]oo`800?mooomoohQoo`00FWoo00<007ooOol0N7oo
0`00ogooogooRWoo001JOol00`00Oomoo`1fOol2003oOoooOon=Ool005Yoo`03001oogoo07Aoo`80
0?mooomoohmoo`00FWoo00<007ooOol0LWoo0P00ogooogooTGoo001JOol00`00Oomoo`1_Ool3003o
OoooOonCOol005Yoo`03001oogoo06aoo`<00?mooomooiIoo`00FWoo00<007ooOol0JGoo0`00ogoo
ogooVGoo001JOol00`00Oomoo`1VOol3003oOoooOonLOol005Yoo`03001oogoo06=oo`<00?mooomo
oimoo`00FWoo00<007ooOol0H7oo0`00ogooogooXWoo001JOol00`00Oomoo`1MOol3003oOoooOonU
Ool005Yoo`03001oogoo05Yoo`<00?mooomoojQoo`00FWoo00<007ooOol0Egoo0`00ogooogooZgoo
001JOol00`00Oomoo`1COol4003oOoooOon^Ool005Yoo`03001oogoo04moo`@00?mooomook9oo`00
FWoo00<007ooOol0C7oo0`00ogooogoo]Woo001JOol00`00Oomoo`18Ool4003oOoooOoniOol005Yo
o`03001oogoo04Aoo`@00?mooomookeoo`00FWoo0`00?goo1@00ogooogoo`Goo001JOol00`00Oomo
o`0jOol5003oOoooOoo6Ool005Yoo`03001oogoo03Eoo`D00?mooomool]oo`00FWoo00<007ooOol0
<7oo1@00ogooogood7oo001JOol00`00Oomoo`0[Ool5003oOoooOooEOol005Yoo`03001oogoo02Eo
o`H00?mooomoomYoo`00FWoo00<007ooOol07Goo2000ogooogooh7oo001JOol00`00Oomoo`0EOol8
003oOoooOooXOol005YooaP00?mooomooo1oo`00FWoo00<007ooOol0ogooogooogoo1Woo001JOol0
0`00Oomoo`3oOoooOoooOol6Ool005Yoo`03001oogoo0?mooomooomoo`Ioo`00FWoo00<007ooOol0
ogooogooogoo1Woo001JOol00`00Oomoo`3oOoooOoooOol6Ool005Yoo`03001oogoo0?mooomooomo
o`Ioo`00FWoo00<007ooOol0ogooogooogoo1Woo001JOol00`00Oomoo`3oOoooOoooOol6Ool005Yo
o`03001oogoo0?mooomooomoo`Ioo`00FWoo00<007ooOol0ogooogooogoo1Woo001JOol00`00Oomo
o`3oOoooOoooOol6Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol005eoo`03001oogoo01Yoo`03001oogoo0?mooomoonEoo`00G7oo00<007ooOol077oo
00<007ooOol0ogooogooi7oo001LOol00`00Oomoo`0LOol00`00Oomoo`3oOoooOooTOol005]oo`80
01ioo`800?mooomoonEoo`00Fgoo00<007ooOol07Woo00<007ooOol0ogooogoohgoo001JOol2000P
Ool2003oOoooOooTOol002eoo`L000Aoo`L000=oo``000aoo`8000Qoo``000aoo`800?mooomoonAo
o`00;Goo1`0017oo1`000goo300037oo0P0027oo300037oo0P00ogooogooi7oo000_Ool2000:Ool2
0005Ool30007Ool2000;Ool2000=Ool2000COol2003oOoooOooSOol002moo`8000Yoo`8000Ioo`<0
00Ioo`8000]oo`8000eoo`8001=oo`800?mooomoon=oo`00<7oo0P0027oo0P0027oo0`001Goo0P00
2goo0P003Goo0P004goo0P00ogooogoohgoo000`Ool20008Ool20009Ool3000AOol2000=Ool2000C
Ool2003oOoooOooSOol0031oo``000Yoo`<0011oo`8000eoo`8001=oo`800?mooomoon=oo`00<Goo
2P0037oo0`003goo0P003Goo0P004goo0P00ogooogoohgoo000aOol20006Ool2000=Ool3000>Ool2
000=Ool2000COol2003oOoooOooSOol0039oo`8000Aoo`8000Qoo`8000Eoo`<000eoo`8000eoo`<0
019oo`800?mooomoon=oo`00<Woo0P0017oo0P0027oo0P001Woo0`0037oo0P003Goo10004Goo0P00
ogooogoohgoo000bOol20003Ool30008Ool20007Ool3000<Ool2000<Ool200000goo00000004Ool2
0009Ool2003oOoooOooTOol003=oo`80009oo`8000Uoo``000aoo`8000Uoo`D0009oo`L000Uoo`80
0?mooomoonAoo`00<goo0P000Woo0P002Goo300037oo0P002Goo1@0017oo10002Woo0P00ogooogoo
i7oo000cOol5000SOol00`00Oomoo`0NOol00`00Oomoo`3oOoooOooSOol0031oo`P002=oo`8001io
o`800?mooomoonEoo`00<7oo1`009Goo00<007ooOol077oo00<007ooOol0ogooogooi7oo001LOol0
0`00Oomoo`0LOol00`00Oomoo`3oOoooOooTOol005eoo`03001oogoo01Yoo`03001oogoo0?mooomo
onEoo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00001
\
\>"], "Graphics",
  CellLabel->"From In[81]:=",
  Evaluatable->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
\tThe coax geometry allows easy comparison of the theoretical value \
of its self-inductance with the one that was numerically calculated, because \
the boundary of the relaxation area has finite extension. Many of the other \
configurations of conductors with known self-inductance have boundary values \
of the vector potential that are 'zero at infinity' and require larger grids \
to reach good accuracy.\
\>", "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Some results with other geometries:", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Coefficients of capacity of a pair of wires above a grounded plane:\
\
\>", "Subsubsection"],

Cell[TextData[{
  "Parameters used in the relaxation:\ngrid size : 240 * 150, center of wire \
1 at (90, 40), center of wire 2 at (150, 40), height h above ground = 40, \
distance of wires a = 60, diameter d, s = ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(1 + 4  h\^2/a\^2\)\)]],
  ",  t = ",
  Cell[BoxData[
      \(TraditionalForm\`4  h/d\)]],
  ", all lengths in grid units, the expressions for the capacities are found \
in (",
  StyleBox["Ref. 7",
    FontWeight->"Bold"],
  ", p. 118), capacities in Table 1 are given in [F/m]:"
}], "Text"],

Cell[BoxData[GridBox[{
        {
          StyleBox["d",
            FontWeight->"Bold"], 
          StyleBox[\(\(2  \[Pi]\[Epsilon]\_0\)\/\(ln \((s*t)\)\)\),
            FontWeight->"Bold"], 
          StyleBox[\(C\_10 = \(C\_20\) \((\(num\)\(.\))\)\),
            FontWeight->"Bold"], 
          
          StyleBox[\(\(2 \( \[Pi]\[Epsilon]\_0\) 
                  ln\ s\)\/\(\((ln\ t)\)\^2 - \ \((ln\ s)\)\^2\)\),
            FontWeight->"Bold"], 
          StyleBox[\(\(C\_12\) \((\(num\)\(.\))\)\),
            FontWeight->"Bold"]},
        {
          StyleBox["2",
            FontWeight->"Bold"], \(1.14\ *\ 10\^\(-11\)\), \(1.2\ \ \ *\ 
            10\^\(-11\)\), \(1.5\ \ \ *\ 10\^\(-12\)\), \(1.15\ *\ 
            10\^\(-12\)\)},
        {
          StyleBox["4",
            FontWeight->"Bold"], \(1.32\ *\ 10\^\(-11\)\), \(1.38\ *\ 
            10\^\(-11\)\), \(2.13\ *\ 10\^\(-12\)\), \(1.58\ *\ 
            10\^\(-12\)\)},
        {
          StyleBox["6",
            FontWeight->"Bold"], \(1.47\ *\ 10\^\(-11\)\), \(1.56\ *\ 
            10\^\(-11\)\), \(2.7\ \ \ *\ 10\^\(-12\)\), \(2.06*\ 
            10\^\(-12\)\)}
        },
      GridFrame->True,
      RowLines->True,
      ColumnLines->True]], "Text"],

Cell["\<\
Table 1.  Analytical (zero at infinity) and numerical capacities of \
a pair of wires  [F/m]\
\>", "Caption"],

Cell["\<\
The main contribution to the large differences between the \
numerical relaxation and the formula from the textbook stems from the fact \
that the relaxation, however large a grid is chosen, imposes its boundary \
conditions at a finite distance, namely the border of the grid, while the \
formula uses a potential, which is 'zero at infinity'. To better check the \
accuracy of the relaxation, a new formula was developed that returns the \
exact potential of a charge in a box through the method of images with \
'infinite reflection'. If a charge Q is placed inside a (2 \[Dash] \
dimensional, rectangular) box, an infinite number of image charges of \
alternating sign will appear in x\[Dash] and y\[Dash] direction (Fig. 6). \
Every remote image adds a term to the potential, which remains finite because \
of the alternating sign. They 'compress' the potential function in such a way \
that its value at the borders of the box is constant.\
\>", "Text"],

Cell[GraphicsData["PICT", "\<\
dRX000000A41R00A0_l<0?on0001;0000B`000000004L`IU0000002Q09H02P40
000000000000X02H0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G
0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40000000000000X02H
0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G0:40UP0:0@000000
0000002P09P0X02I0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F
00X10000000000000:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I
0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F00X1000000000000
0:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40
000000000000X02H0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G
0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40000000000000X02H
0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G0:40UP0:0@000000
0000002P09P0X02I0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F
00X10000000000000:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I
0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F00X1000000000000
0:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40
000000000000X02H0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G
0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40000000000000X02H
0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G0:40UP0:0@000000
0000002P09P0X02I0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F
00X10000000000000:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I
0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F00X1000000000000
0:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40
000000000000X02H0:00V@2P09L07P0100X0000017<6I@0/00T00`I7IFiUMV40
00<00`0=00`0;P04003o000[0@41800Y004P00070000000S0000X02n0:40`00=
HgEbLVE^M71_JFid3@00X02o02814@650000X02n0:40`03=HgEbLVE^M71_JFid
838PJFiTIGPPLgER86EhHfPP<b1YKVAUN21cMF8=83<h>B0PI6Uf86EhHfPP3B0b
=c<P86AYMR0c86U^I6Eh80dP<20PLgER83<PJFiTIGPP3B0`821cMF8P=20b879_
K6`P=B1YKVAUN20e86U^I6Eh87AbHFicK65dI@e^IFLPLf=QK6D==20b879_K6`P
KVEW86EhHfPPKVEW86EhHfPPM79QKW=/HGAU80dP<SLc821cMF8PM79QKW=/HGAU
3@00X@300DTU8E1C;D5TKf9U;C<^<215D5=6;C<^<0dU9D9_MFiTJFiW@Vmh>R0P
<20`83<h>B0b=c<P3BDUE6UdK6Dj82Q<HGAdJF=U;T=>ERTP3BDU@g9UHGA_LSXP
@f5^MV5c82Pg;S0^<RTP3BDU@g9UHGAYKfi4HGAU>R0X<3H_<38_<34P@20a<SXc
=R11CBTP3BDUA6mSMFeUKWA@LVmSDfEdLcXPA6E^IF9QGd=QKWIQLd=eLgA_KD=_
K6mbL`dU9B/P@eI4JF=d3BDUA6mSMFeUKWA6KfidLcXP3BDUA6mSMFeUKWA>IFET
IFA6KfidLcXPAfE^IGIQ3@dU9DA_HgE]IFidD79_HfEcLd=_K6mbLcXP@gUQKR1=
HFMUKWAQ85UUK6a_Mb12K65SJ`dU9DE^I4=_KFeUKWAc3BDU@VEWJFi@LVm/KfLP
3@00X@30@00U9D9UIfU^DVEcKgEbHfDj871bKf=cIG@P@eI4JF=d3BDUE6UdK6Dj
84AUKVERHB1cM65^I65bI21WLV5`J6USL`dU9EIULW=YKfhj834^<38=9BE3LVEQ
M6U_KTAQM6Dj834`;c4d;cTi3BDU@fm`NG9YIfQd>R0X@bTP<CTi=2`P<CTi>B14
IFiUHV4PDgUcM6E]LbhP@Fa/859YIfQdLb1BIG=ULWIUI0eeLfEbI6USM20_@eI4
JF=d838`<21TJF=d871eM0e3ETAYHg@PHVEWJFh=;fU^MV5/JFASKfa_LWAQHVaU
?b1dLWEU86AUIR0P80d_K6EfIF`b82m/HFiWMF5WIFaUMVE/87MXIG9U87]`Kg0P
K65^IgEQIfE/IGIUK20b86MUOG]VHFacIGdPJFIUK7=U86AUIPe/IGIUK38PKVmd
87/P;gQcJ6mg87/=<21SMG9bIFidL6mYKW@P=B0]<B1bKfa/87]`Kg0PL6m`86e_
MVEdKb1TMG0P<B1QI6@P<b0a879_K6`PIGQSJ21TMG0P=20a879_K6`PIGQSJ21W
IG@P<21bKFmfIGA_86=eLW9UKWA`KfU^M7dPIGQSJ21[LfQ_M`e`Kg0PL6m`871_
L21`Kg1m86AUIR1m86UV3BmYKVUdJF5/JGYU3G]3ETAYHg@=NfAeL21hHfQUHf]k
HVU^I7eYIR1`Kg0PL6m`OFI_LV5/K0eSMG9bIFidLf=bIFE^82mOLg0PIGQSJ21T
IFHP;emcHB1UN6=X86AUIR0_Gg=V86EhHfPPI6EV3Bm4IFIQMFadDf=bIFE^Nemc
IR1OLf4P;emcL21/Kf5TOFAUIPd_A6EVHGE/M5=SLVEUKU1bKf=k82mOLg0PK6mQ
I7eTIFH=;g=UM7=dLVm[IF5TJWEcM21gJ6EbIG]`Kg0PM79eIGekIV5/LfEmJFIU
K7=U3G/_Lf4P;g=UM7=dLVm[IF5TJWEcM21/Kf5T86AUIPd_K6TP;faYKVEdKb1/
Kf5T86AUIPd_KG@P;fe_MVEdKb1/Kf5T86AUIPd_Hg@P;f=eLWIUM6lPK6mQI21T
IFH=;faX87/PHgEbLVE^M71_JFid86EhHfPPL6m`86aYKVEdKgeRJFiT86AUIPd_
K7HPNb1SMG9bIFidL6mYKW@PL6m`86EhHfPPK6U^IGA_OF9YKV@PI6EVO@ek;g=Q
Ng]SMG9bIFidI6USM21CM79_JfE1I6YeLgA4JF=d86iUNe=dLVm[ID5TJWEcM4AY
Hg@PHVEWJFimJFImNb1SMG9bIFidI6USM21CM79_JfE1I6YeLgA4JF=d86EaNfE^
I7eYIWeYIVE/LfEm869YKV@PI6EV3GEcIG9TJF=d82mCM79_JfE1I6YeLgA4JF=d
834`<21TJF=d871eM0eCM79_JfE1I6YeLgA4JF=d869UIfU^3BmON6`=NgAbHFic
IVmbK@d^<SDPLgER879_MFiT82hb=B1QI6@PIGQSJ0d^<SDPLgER879_MFiT82hb
=B1QI6@PIGQSJ0eYM79QKW=VKg9]3GeRJFiT86AUIPd_K6Uk85mhK21/JFiUM6mm
HVU^I21TIFH=;fedNb1ON6`PKFmfIGA_OF9YKV@PI6EV3BmSM7/PGgQ/86=eLWIU
M6mmHVU^I21TIFH=;faX87/PI7E`85mhK21`Kg0PHgEbLVE^M71_JFid86EhHfPP
L6m`86aYKVEdKgeRJFiT86AUIPd_K7HPNb1TMG0PGgQ/871_L21SMG9bIFidL6mY
KW@PL6m`86EhHfPPK6U^IGA_OF9YKV@PI6EV3BmbL7]ON6`_HgIOHR1hI6H_HgIO
LR1hI6H=GgQ/;f=fGg@PN6AV;f=fGf`PN6AV3F=fGf`PHgIOM21]KgIUM6l=HgIO
LR1SMUmd86aYKVEdK`eSMUmb86=fGf8PK6U^IGA_3F=fGf`PHgIOHR1/JFiUM6l=
Hfa_LfE`HGAX3GeRJFiT86AUIPeUKVAmJFIUK7=UOFAUIPd_M6EbKFU^HGAU3G]e
LfEbI6USM20_DgAbKf]U@FAZMG=dA6USM21[KVmgKR1kHgEbLVE^M6AYHg@PDgAb
Kf]U@FAZMG=dA6USM21ULG]UKVAmJFImJFH=HgEbLVE^M6AYHg@P@eI4JF=d86Ea
NfE^I7eYIWeTIFH=;fehCF5h83Hd86AUIPd_KGQCM6/PFfehCF5h87]]HGAbJGQm
879UL6EQM5eTIFH=;fehBFAh830PI6EV3BmcM6ekKGQCM6/PKGQ9I7PP<21/M21k
;fehBFAh830PLgA_LVEmJFHPKGQ9I7PPIfEd86=eLW9UKWA]HGAbJGPPL6m`82m]
N4UTN21]N4UTN20a865TI21cM6mbIGeTIFH=;g9dKG]]N4UTN20a86MU87/_KGQ9
I7PPKGQ9I7PP<B1cMF8PLgA_LVDPKGQCM6/PKGQ9I7PPIfEd87=UM6eQM79YN7eY
IR1mI6EV3BmcHf`PNb0g<R1TJGHPIGQSJ20g<R1TJGHPIGQSJ21cHf5/IB1m86AU
IPd_Lf=/JB1k83Lb86EhHfPPI6Uf86EhHfPP=c8PIGQSJ21TJGHPIGQSJ21cHf5/
IB1m86AUIPd_Gf=fKGAh86eQM79YN21TIFH=;emdN7A]M7PPKF5dLVUh86AUIPd_
GfU^JGA]M7PPKF5dLVUh86AUIPd_N6AVNfEhHfPPI6EVOFAUIPd_KFU^Nc8PHfm`
NB1WM7]UN6=XOFUV871_L7eTIFH=;feQN7/b86=_L7TPK7AkIGQSJ7eYIR1`Kg1m
I6EV3Bm3EWIUHb0b=CHPHG9bHGTPI6EV3BmD87AbMFDPI6EV3Bm686IQK7=U86AU
IPd_GfUT830PI6EV3BmOIFiSKfAYKVAUN20`86AUIPd_GfE^HfmT@G9b83<PHG9b
HGTPI6EV3BmOIV@P<21TIFH=;emdIGQdDf5fIB1^MFa/86AUIPd_GfaUM7AULU=`
HF=U830PI6EV3BmOLg1QHfEHM79Q830PI6EV3BmOD65WIE=QMVDPKWE/K21TIFH=
;em`IFiX834^<21TIFH=;em`IFif834^<21TIFH=;g=QMVD`86ieK6`PI6EV3BmO
Mb0`86AUIPd_GfPP<21TIFH=;emTLb0`86AUIPd_J6=d86IQK7=U86AUIPd_L7LP
<21TIFH=;gMTJFHP<21TIFH=;gAUKG0P<21TIFH=;f=eLW9_M20`86AUIPd_Lf5f
IFQQKVA/IG8PKWE/K21TIFH=;fUQ830PI6EV3BmYN20`86AUIPd_JGQ^834PI6EV
3Bm=MFadJG1/IDAQM65CKgEbHfEc86IQK7=U86AUIR0=;fAUHWEW3G]TMG0P;bAU
L7<PIGQSJ21^Kg@PI6EVNbmcHGIUJ65^I6aULR1ULW9_LVAYHg@P;fQQKVA/IFEb
LVmb86MUM21TIFH=IG9bKg9TJF=d3BmXHFiTK6EULW9_LW/TIG9bKg8PHVEWJFh=
KVEgIG9bKg9k;fiUMfEbLVmb86IQK7=U86AUIPecJ6mgL65WI@dg<R0g<R1cHf5/
I@d_B6E/MVEdJF=Q86IYKVAVKfid82hb87=SHFaUIVm^M21cIGAVKfid3Bhb=B0i
;SHPKFmfIGA_3BQ5LW9_LSXP:G=XKgL=IG9bKg9^HFeU3G]TMG0PM7U`IBmcM79Y
KVMdNG1U86iU3G/XHfm^MVEbM6ET86EbLVmb86iQKFDPMfU/K21UKV@PMG0PJFhP
M6QYLb1cM79YKVLYHgIcOFUV3G=XKgMmIGQUH`d^<SDP>Bhd86e_MVEdK`dXCfIV
IFiTJFiW84=_KFeQKV@j82UcJ6mg3BmSKfe]HFiT86a_HF@=NfAeL21dNG1U;g=d
LVU^IgAiL6DPKVD=NbQSKfifIG9dIF@PHfm]KF5^I21^HFeU87MYK6`PIFiT87E`
86U^87AXJG<PLgAbJFiW:F=fLgeYIPecJ6mgOFEhIF<=;S8e83T^<R1]KgIUM6l=
:5=dHF=[>R0YLfQ_M`e_LgAQHf/=Nbhb=B1SMG9bIFidL6mYKW@P;S8PLgER86Eh
HfPPL6m`86e_MVEdK`eTMG0PM7U`IBmcM79YKVMdNG1U86iUNfAeL21dNG1U;fU^
M6EWIG9dNG1U86Ea3C4PJFiTIGPPM7U`IBmbIF5/M7U`IB1ULB1_LPda86U^I6Eh
87AiL6D_KV5]IGAiL6DPIG4PKg8=KVmd87]dNG1UOFUV3BQSKfifIG9dIF@PLgAQ
Hf/PMfU/K21UKV@PMG0PJFhPM6QYLb1cM79YKVLYHgIcOFUV3G=XKgMmIVmbHFa/
3G=XKgM`HFMU3D=FA6USM20_Lf5fIFQQKVA/IG8PIfEd86EhIF=mJFH=IFiTOG1e
M7eYIWeTIFH=;faSNg=UM6aYKVESHG1mI6EV3Bm/JW]cIGA/JFiUJVmYKWeTIFH=
;fa]Ng=UM6eYM6EbK6U]JGAmI6EV3Bm/IW]cIGAVK65dOFAUIPd_Hg1kHfa_LfE`
HGAXOFAUIPd_KW1kKVEgL65dJ7eTIFH=;bA`LgXP<c0PHG9bHGTPI6EV3BlTL6Uh
830PI6EV3BmWLg]WLf5fIB0TL7=j86AeL20TL6Uh85m`IFiX871eM20TL6Uh834P
HFAT85m`IFif871eM20_971YN20TL6Uh838PHFAT86AUIWeTIFH=;fMbNfMbIG=d
Kg9U;bA`JGPP971YN20b87=eHR1TIFHP971cNR1TMG0P971YN21WIG@P;em`IFiX
86EhHfPPI6EV82A`JGPP<B1QI6@PIfEd82mOL6E^MR1UN6=X86AUIWeTIFH=;faY
NfaYKVEdKgdPI6EV3Bm/J7]SMG9bIFidL6mYKW@PIGQSJ21`Kg0PK6U^IGA_OFAU
IPd_K7IkHgEbLVE^M71_JFid871_L21UN6=X86aYKVEdKgeTIFH=;fedNfe_MVEd
KgdPI6EV3BmOHgIOKFQkHgEbLVE^M71_JFid86EhHfPPL6m`86e_MVEdKgeTIFH=
;emSMUm]MW]SMG9bIFidL6mYKW@PL6m`86EhHfPPKFmfIGA_OFAUIPd_HgAkHgEb
MVEdKgdPI6EV3BmbM7/d82db879_K6`PKFmfIGA_3FAeL20`86EhHfPPLVaYKVEd
K`eUN6=X830PLVaYKVEdK`e^IFLP<21UN6=X879/JFiUM6l=Hfa_LfE`HGAXOFAU
IPd_GfQb3G/=Nbm0IG9b86IQK7=U86AUIR1SMG9bIFidIVaQM21TMG1kIg=QMVEk
IFmSK6U`OG=dKg1`IFAkIg9ULgA_LVDP<R1]MF`PI7E`87=UM6I/HG@PI7E`838`
<21WIG/X9BDP@f5^MV5c>T=/JG0PIV5YK6ETG78YL79YKW@P;d1ULW8PM79eIB1T
IFHPL6m`86EhJGAmJFImNfMbIG=dKg9U87=UM6I/HG@PIGQYM7eYIVE/LfEmK6m_
L210IG9b86i_M21kIFmSK6U`OFUV87=UM6I/HGAm3G/_@6EbLR1VHFacIB1TIFHP
HgEbLVE^M6I/HG@PI7E`NfMcHGIUNf=/JG1mLgA_L71UI7]WLVEcM6mbIB0b86ee
K21TMG0PLfEdIVaQM21TMG0P<S0`86MUNbPU9B13HFifHG<j@faYL21VHFU/IFAL
LRU`LVU^M20_@6EbLR1dLWEU86AUIR1`Kg0PIGQYM7eYIWekIg9ULgA_LVDPLfEd
IVaQM21UN6UdOFUVIFacIGe/Kfm`841ULW8PKVmd87]SK6U`OFUV87=UM6I/HGAm
3GeTIFH=;emSLb1^MFa/86AUIPd_IVMkLfEdIg9QNGeTIFH=;g=UM6=]NF]SKfa_
LR1gJ6EbIB1kL6m`87AbMFEmNfIQK7=UOFUVIFacI@ek;fHdNb1cIGASKGU[Hfm/
Kg9mI6EVOG/_ISAk<B1cMF8P=20a879_K6`P<g/c86U^I6Eh865TI21^IFLPI7E`
830PK7AkL6m`831mJFHP<b0a879_K6amLVE`IF5d87=UM79WHV=_K6mb871_L7eT
IFImJFIUK7=U3BmcIGASKfa_LW=`HF=U87MXIG9U87]`Kg0PM79eIGekIV5/LfEm
JFIUK7=U3G/_Lf=cNb1TMG0PLfEdHfm/Kg9cL65SIB0_Gf=c86EhHfPPI6EVOFAU
IRmV<g/PGf=c87=UM6=_K6mbLg1QHfDPLfEdHfm/Kg9mI6EV3Gek;fHcNb1cIGAb
If9SKfa_LWeTIFH_Lf=cNb1`Kg1mI6EVOFUVIFacI@d_96=S83DPHG9bHGTPI6EV
3BmVJFiTHfeiJf=eLgA_KF=_K6mb87MXIG9U87]`Kg0PM79eIGekIV5/LfEmJFIU
K7=U3Fi_M21k;fIYKVASKGU[HgEcM6m]Hfm/Kg9k96=S865cM6mbIGeTIFImJFH=
;g=UM6=eLgA_KF=_K6mb87MXIG9U87]`Kg0PM79eIGekIV5/LfEmJFIUK7=U3Fi_
M7/_LfEdHgEcM6m]Hfm/Kg9kIGQSJ21QK6mQI21`Kg0PL6m`83Ak=21YKVAUN21]
MF`P=20a879_K6amLVE`IF5d87=UM6=]NF]SKfa_LR1`Kg1mI6EVOFUV3BmVHg/f
834PLVm/K21VJFiTHfeiJf=eLgA_KF=_K6mb86EhHfPPLfEdHgEcM6m]Hfm/Kg9m
I6EV3BmcIGAcIG1QLV5dJFm^Ig9QNB1gJ6EbIB1kL6m`87AbMFEmNfIQK7=UOFUV
IFacI@e^KgAk;g=UM7=UL65bHGAYKfiWLV5i87]cNG=dIFeTJF=d82mcIGAWLV5i
86MUM21UN6ESOB1TIFImJFH=;g=WNb1cIGAcIG1QLV5dJFm^Ig9QNGeTIFH=;g=`
NbmOL6E^MR1hI6H_Gg1UKVPPN6AVOFAUIPd_LW0=NbmSMUmR87QTIRmSMUmb87QT
IPd_HgIOM21hI6H_HgIOK21hI6H=HgIOK21SMUmd86e_MVEdK`eSMUmb86=fGg@P
K6U^IGA_3F=fGg8PHgIOHR1/JFiUM6l=HgIOK21SMUmR86aYKVEdK`eSK6mcIG1Q
M6QmI6EV3BmbLW/_NG9QI6UeLb1hI6H=;gQbHFAYMG<PN6AV3BmSMUmR87QTIPd_
HgIOLR1hI6H=;f=fGg@PN6AV3BmSMUm/87QTIPeSMUm/87QbHFAYMG<PHFAT86=f
Gg@PKFmfIGA_3F=fGg8PN79QI6UeLb1cMF8PHgIOM21/JFiUM6l=Gf=fKGAh86=e
LW9UKWA]HGAbJGPPL6m`3F=eLW9UKWA`KfU^M21dLV5^LfaQM6D=N79QI6UeLb1i
LV5TJGEc87=SHFaU3C4P<20a834P<B1QLV=dKb0dNg1_L7ebIG1UHG@=Gf=fKGAh
87=UM6eQM79YN0eSMUmb86=fGf8PNG9QI6UeLb1cMF8PK6U^IGA_3EmSMVedN21S
MG9bIFidKF5dLVUh871_L0eSMG9bIFidL6mYKW@PM79QKW=/HGAU3GQbHFAYMG<P
NG9QI6UeLb1cHf5/I@d`834P;C4P<B0a865bHgA_83AkL6m`OG9UL6EQM0eOHgI]
M7PPLfEdKF5dLVUh3F=fGf`PN79QI6UeLb1QI6@PHgIOHR1/JFiUM6l=Gf=fKGAh
86=eLW9UKWA]HGAbJGPPL6m`3F=eLW9UKWA`KfU^M21dLV5^LfaQM6D=N79QI6Ue
Lb1iLV5TJGEc87=SHFaU3Bda830P;C4P;C4P<B1QLV=dKb0dNg1_L7ebIG1UHG@=
Gf=fKGAh87=UM6eQM79YN0eSMUm/86=fGg@PNG9QI6UeLb1QI6@PK6U^IGA_3EmS
MVedN21SMG9bIFidKF5dLVUh871_L0eSMG9bIFidL6mYKW@PM79QKW=/HGAU3GQb
HFAYMG<PNG9QI6UeLb1cHf5/I@d`82da834P;C4P<B1QLV=dKb0dNg1_L7ebIG1U
HG@=Gf=fKGAh87=UM6eQM79YN0eSK6mcIG1QM6QmI6EV3BmUL7]OHgI]M7PPHgEb
LVE^M6eQM79YN21`Kg0=M79QKW=/HGAU3G=SHFaU3C4P<21]KgIUM6l=<20`834P
<20c=S0PHG9S3F=/Kg=UL65dJ0eOHgI]M7PPLfEdKF5dLVUhOFAUIPd_MfAkGf=f
KGAh86=eLW9UKWA]HGAbJGPPL6m`3GAbHFicK65dI@ecHf5/I@d`830PKFmfIGA_
3C0P<20a83DP;C8PLVm/K21QLV=^3F=/Kg=UL65dJ0eOHgI]M7PPLfEdKF5dLVUh
OFAUIPd_HG=kGf=fKGAh86=eLW9UKWA]HGAbJGPPL6m`3GAbHFicK65dI@ecHf5/
I@d`830P<B0e82db879_K6`PHG9SKPeOHgI]M7PPLfEdKF5dLVUhOFAUIPd_I7<=
Nem`IFif85m`IFiX86iU86AeL7]cM6dPGg1UKVPPI7E`830PK6EkL6m`835mJFHP
Gg1UKWHPI7E`830PK6EkL6m`835mJFHPLf=QK6EmNem`IFiX87=UM6aYKVEgJFAd
J7eYIVE/LfDPLgAbKf]U87]bM6emJFImI6EV3BmTIW]VJFa/OFAUIPd_I6EkIFmV
JFa/OFAUIPd_GfMcM6/P=B1QLW9QNB1TIFH=;emWLgA[Hb0`86AUIPd_GfMcM7/P
>B1TJF=d869UIfU^86aUMVE/<W/_Gf=SLb1SMG9bIFidHfm/Kg9cL65SIB1TIFHP
;emSHb1KHgEbLVE^M6=_K6mbGB1TIFImNbmOHf<PFf=eLW9UKWAbIf9SKfa_LUeT
IFImJFIUK7=U87]SMG9bIFidL6mYKWAmLgA_L71UI21k;emSL21^MFa/86AUIWek
838PHG9bHGTPHG=dKg9U82mOHg0PIGQSJ21TIFImJFIUK7=U82mOHfHPHgEbLVE^
M6I_KW@PI6EV3BmOHfag86=eLW9UKWA/JFiUMfUTM6PPI6EV82mOHfaS86=eLW9U
KWA/JFiUHf5`86AUIR0_Gf=/JR1SMG9bIFidK6U^IFY_JFhPI6EV82mOHfe/86=e
LW9UKWA]JGAULVaYKFUd86AUIR1SMG9bIFidI6USM21UKVAmI6EV3BmXLg]^IGM`
HGAX86McHGIU87=dKGeTIFH=;fQSNbmOJ78PK6mQI21UN6=X86MUM21UN6ES86iU
Mg1QM6QmI6EV3BmXIG]OIg=dJb1OIg=dJf<PGfMcM21`MG@P;emWLgA[Hb1OIg=d
Jf<P<B1QI6@PLgA_LVDP3FMbIG=dKg9U879dKB0_GfMcM6]S85mWLgA[Hb0a87=e
HR1cM6mbIB1OIg=dJb1OIg=dJf<PIfEd86aUMVE/<W]TMG0P;emSHg<PIfEd87=U
M6=_K6mbLg1QHfDPI7E`82mOHf<PIfEd865/Kf5T871_L21cIGASKfa_LWekI7E`
82mOHf<PIfEd865/Kf5T871_L21cIGAbIf9SKfa_LWeYIVE/LfDPI7E`82mOHg0P
IfEd86AeL21^MFa/86Ea80e^KgAkHFa_HF@PL6m`86e_MVEdKgekL6m`OFUVIFac
IB1TMG0P;emSIR1WIG@PLfEdIVm^M0eTMG0_Gf=/Mb1WIG@PLfEdK6U^IGMYI7AX
86AeL2mOHfaS86MUM21cIGA/JFiUHf5`86AeL2mOHfaZ86MUM21cIGA/JFiUJVmY
KR1TMG0_Gf=]K21WIG@PLfEdKFUdIG9/JFeYM21`Kg1mI6EV3BmYI7/P;emYI21h
I6ImI6EV3BmOJFeQM79YN7]OMb0`830PGfPPGfUT830PKVEkKVEW830PGfQmNc0P
<7eYIVE/LfDPGf=fKGAh865cM6mbIGeTIFH=9B13Kg1iLVUWJ7@P:4<Y834i>C0/
834i>C4PHWTP@FA_HVDPDgUcM6E]Lb19KV=_LW1_LV5dIF@^3BDP@Fa/879YIfQd
Lb1bIG=ULWIUI2h=K6EfIF`b87/PLf5fIB0_I6m^M6a_HFA/IGIUK34PN6AV87eY
IPd_LgAQLWA^Kfa_HFAkNbm^Kfa_HF@PLf5fIB1TIFIm86UVOFAUIPd_IFiTKVm/
Kf5TNg]^Kfa_HF@PLVEcM6mbIGeYIR1mI6EV3BmdIG=dLgUcM6E]I6USM7]gJ6Eb
IG]cNG=dIFeTJF=d86EaNgAbMFEmNfIQK7=UOFUVIFacIGekIV5/LfEmJFIUK7=U
OFAUIPd_KV=_K6mbLb0a86AUIPd_Hfm/Kg9YKF5WIB1gJ6EbIG]`Kg0PM79eIGek
IV5/LfEmJFIUK7=UNbm^Hfm/Kg9c830=LgAQM7EcI6USM21RIFMYKR0=;g1bKf=U
Lg=SKfa_LW<PMfQULVEkL6m`871_L21`LVmSIG=cHfm/Kg9cOG/_I6EfJF=UJFiV
Kb1gJ6EbIG]`Kg0PI6EfJF=UJFiVKb0_@fm/Kg9c86]^KgM^3G]`Kg0PNfAUMVUS
IFU^IVlP;d=_K6mbLb1WIGAmOFUVOFUVOFUVIFacIB1UKV@PI6EV3FiSKfa_LW<P
<21^IG/_Hfm/Kg9YKF5WIB1dIG=dLgUcM6E]I6USM0d_LfEdHfm/Kg9dLV5^LfIU
LR1dIG=dLgUcM6E]I6USM0d_HgEbLVE^M6=_K6mbM79QKW=VIG8PM6EcM7=iLgAU
KFAYHg@=;f=eLW9UKWASKGU[Hfm/Kg8PM6EcM7=iLgAUKFAYHg@=HFiT865^I21Q
KV@PKVmdNbm^Hfm/Kg9c830PI6EVOFUVOFUVOFUV3FiSKfa_LW<PI7E`834PKVDP
IGQSJ21TMG0P<b1^IB1UN6=X83@PKVDPHFiT865^I21k;fiSKfa_LW<P<21TIFIm
JFH=KV=_K6mbLb0a86Ea86AeL21TMG0PKVmd87=dHG9dKVm/Kf5T3G/_I6mSK7Ed
JFeQIfEkFg/b=CDPKGE/879_MFiT86=fJB1RMf=/MG@PIGQSJ21WIG@P<SDe86AY
MWdP;fEhIF<PK6mQI21TMG0PHgEbLVE^M7AbHFicIVEb86EhHfQM80eSMWPPHVU^
I21cIGAdLV5^LfIULR1OMb1OJ20h85mYKF5dLVUh85mTLb1YKF5WIGeTIFImJFH=
KVmd86E^I6i_K6mQI0e^Hfm/Kg9c86AeL20c86Ea86EhHfPP=21ULB1_LPeTMG0P
I7E`86i_M21cM65bM6i_K6mQI0ek;fieK6a`LVmSNg]mOFAUIRmSKfiSHGAeM6U/
NbmUN6ES86a_HF@==b0]<B1bKfa/82mUN6ES86a_HFAmI6EV3BmTIFIcMF9SK7Ed
3G/a865TI21WIGAYKWAULWIQK21TIFImI6EV3BmcL6=_KV=QM7AbHFicIVEb820P
3G/_A6=/MG@PIGQSJ21TIFH_@f=/MG@PIGQSJ21TIFH_@V=/MG@PIGQSJ21TIFH_
@F=/MG@PIGQSJ21TIFH_KV=_KG1eM6DPIGQSJ21/I0eSMG9bIFidHfm/Kg9dLV5^
LfIULPeKNd5SK7Ed86iSKfe`MGAUOF=_KV=QM7EdJFaM86=fN0eKNd9SK7Ed86iS
Kfe`MGAUOF=_KV=QM7EdJFaM86=fN0eKNd=SK7Ed86iSKfe`MGAUOF=_KV=QM7Ed
JFaM86=fN0eKNdASK7Ed86iSKfe`MGAUOF=_KV=QM7EdJFaM86=fN0ecIGASKfa_
LWAbHFicIVEbOFAUIPd_LfEdMG1bIf9SK7EdL`ek;f9YM3=h879WHV=/MG@PK6E^
IgAX83<PLgER86AUIPd_HVUd<GPPHVUd<gPP<b1YI6Uf86AUIRmbHfaeM21bIf9S
K7Ed86AUIPd_If=/MG@PLV=/MG@P<B1RJG@cN21TIFIcMF9SK7Ed;f9SK7Ed879S
K7Ed838PHVUd<gPPI6EVLgERHfaeM7eTIFImJFHPKVmd820=IFiTKVm/Kf5T86iS
Kfa_LW<P<b1ULB1TMG0PI7E`86i_M21cM65bM6i_K6mQI0ek;c=SKfe`MGAUNfEh
HfPPHVUd<gPPKGE/3G9_MFiT86=fJB1WIG@P<SDe86AYMWeTIFH=;fA_HfaeM6U]
HFMUNbD_LVMRHfaeM21hI6HPL6m`80ecIGAeL79WHV=/MGAc;c=SKfe`MGAU879S
K7Ed86MSK7Ed869SK7Ed86AeL0ecL6=_KV=QM7AbHFicIVEb85mg85mX83PPGfU]
HGAbJGP=FbmOI7<PK6mQI20_IGQUHb1/Kf5T82mTMG0PK6mQI21TMG1MHgIh3Fie
K6a`LVmS86ieK6a`LVmS87AbMFDP<b1SKfa_LVU]HFMUOFAUIWeYIR1^Kg@PIFiT
KVm/Kf5T86iSKfa_LW<P=21ULB1TMG0PI7E`86i_M21cM65bM6i_K6mQI0ek;g=d
MFIVHfaeM7]SKGU[JFiTIGPP<b0]<B1bKfa/871eM7eTIFH=;fIdKfU^M7/a86Eh
HfPPLgER838e=B1]MF`PLVmeKV@PHgIYOFAUIPd_=6=_KG1eM6DPNb1UN6=X869Y
M3Ah86eeK21bKgE^I21SMVTPIfEd838e=B1TJGHPOB1TIFH=;f=_KG1eM6ESKGU[
HfaeM7]cIGAeL79WHV=/MGAc;f9YM3Ah879WHV=/MG@PK6E^IgAX83<PJFAYMR0d
86eeK20d87=eHR1TIFH=;f=]NF]SK7Ed869YM3Ah83@PHFAT87=dLVU^Ib1TIFH=
;f=SK7Ed86=]NF]SK7Ed86AUIPd_KF=/MG@PHf=/MG@P<B1RJG@dN21TIFIcMF9S
K7Ed3BmiHfaeM21SHfaeM20b869YM3Ah86AUIW=eHV=/MG@=;f]SK7Ed86=SK7Ed
83<PHVUd=7PPI6EVLgERHfaeM0d_HfeiJfU^I6Eh830PI6EV3C0P<B1RJG@aN0ek
I7E`82mSKGU[JFiTIGPPIGQSJ21RJG@aN21UN6=X87=eHR0d86eeK21TIFH=<b1]
MF`PI7E`879SK7Ed86EhHfPPIfEd838e=B1TJGHPIGQSJ21TMG0PIf=/MG@PIGQS
J21WIG@P<SDe86AYMPeUN6=X869SK7Ed86EhHfPPIfEd838e=B1TJGH=LfEdLVMR
Hfm/Kg8PHgEbLVE^M6=]NF]SKfa_LPeVM6mYKW@PJf=/MG@PLgAeIVISK7Ed3FId
KfU^M21iHfaeM21cM7EVIV=/MG@=IWA_JFid86eSK7Ed87=dMFIVHfaeM0eVM6mY
KW@PHf=/MG@PLgAeIVISK7Ed3GeVKg9mI6EV3BmTKf=/MGAYKF5WIG]YKWIQK6UT
Hfm/Kg9dHF9/ICmkHfm]L7EdIF=]NF]SK7EdOFUV3BldHfm]L7EdIB1SHfaeM21]
HfaeM21iHfaeM21[HfaeM21cL6=_KV=QM7AbHFicIVEb3Emg85mX83PPGfU]HGAb
JGQK;emTLb1/Kf5T82mUN6ES86a_HF@_I7E`86a_HF@PI7E`86AeL5dPHgIh80e^
MFa/L79_Hb1^MFa/L79_Hb1^MFa/L79_Hb1dLWEU83@PHfm/Kg9YKF5WIGeTIFIm
JFH=KVmd86E^I6i_K6mQI0e^Hfm/Kg9c830PIG4=I7E`86AeL21^Kg@PLgAQLWA^
Kfa_HF@=NbmSKfa_LVEhL65^I7]]NG=dLVU^IfEhL20`879WHV=/MG@=<b1SKg1i
3CLP;C4PLVm/K0ek<b1]MF`P<b1WIGAYKWAULWIQK21`MGAYKWAULWIQK21UN6=X
83<PHFAT86EhHfPP<b1SKg1iOFI_LV5/K0e`Kg0PL6m`871_L21`Kg0PL6m`OFAU
IPd_Hg9UHGAUIGQ`HFiTLgAbNbm]NG=dLVU^IfEhL21UN6=X87=d<21/IFiWM6PP
KGE/87=dLVU^Ib1TIFImI6EV3BmTKf=/MGAYKF5WIG/_LVMRHfaeM21hI6HPL6m`
83<PHg9UHGAUIGQ`HFiTLgAb85mg85mX83PPGfU]HGAbJGP=FbmOI7<PK6mQI20_
IGQUHb1/Kf5T82mSKfa_LVEhL65^I21/Kf5T82mUN6ES86a_HFAM86=fN0eVHFac
IB0c86=_K6mbJFeQIfEmI6EVOFUV86i_M21UKVA^Kfa_HF@=K6EfIF`b87/PI6m^
M6a_HFA/IGIUK34PLVEcM6mbIB1mJFH=K6EfIF`b86i_M7/PLf5fIB0_I6m^M6a_
HFA/IGIUK38PN6AV87eYIPd_LVMRHfaeM20`86AUIPd_I6mSK7EdJFeQIfEk;fQY
MV5/838e=B1TIFHP3E/_BFiTIGQUI20_A6EfJF=UDTM286QYMV5/879WHV=/MGAM
87=UM6=_K6mbLg1QHfD=GfU]HFMUI6USM21TMG0PHVEWJFhP3BmGJFAdJ21OMb1T
IFHP3Bm8IFUWJ7@PGfPPI6EV820=;dAUHfmTIB1K<21XJGIQK5dPI6EV820=;dU]
HFMUCF5dLVUh85mYKF5dLVUh86AUIPd_@VUdLe1ULT=_KG1_KVE^M20h86AUIR0=
;dU^M6EbL6m/HGAU86IQK7=U86AUIPeUKV@PJFeQIfEmI6EV3FaUMVE/<R1^KgAk
86A_KWA/Kf5TK6EfIF`b879ULgA_LVDPOFUV3BDUAFiTD79_He=UM0d_GfU]HFMU
I6USM20a=B1TJF=d869UIfU^82m9KF5WIEAiL6DP<B1TIFH_@VUdLe1ULT=_KG1_
KVE^M20h86AUIRm9KWAULW1_K65dIB1VHFacIB1TIFHPHgEbLVE^M6AYHg@PIFiT
86AUIPd_J65cHfm/Kg8PM79eIB1TIFH=;faUMVE/<R1cNG=dIFeTJF=d82m/HFiW
MF5WIFaUMVE/86]^KgM^3G]/HFiWMF5WIFaUMVE/838PIfEmNfIQK7=UOFUVIFac
IB1TIFH=;fI_MG9ULB1k=21YKVAUN21ULB0h834PLVm/K0dd86U^I6Eh86Ea83PP
<B1bKfa/3C@PJFiTIGPPIG4P>20a879_K6`==21YKVAUN21ULB0h834PLVm/K0e`
Kg0PL6m`871_L21`Kg0PHFiT865^I21QKVAm86AUIPd_LfEdMG1RHFiTLg]WLf5f
I@d_Gg=UM7AbHFicIVEb87=iLgAUKFAYHg@P;g=UM7AbHFicIVEb86MUM21TIFH=
;emSMG9bIFidM79QKW=VIG8PLgUcM6E]I6USM20_HgEbLVE^M7AbHFicIVEb86MU
M21TIFH=;emYKF5WIB1cNG=dIFeTJF=d82mYKF5WIB1WIG@PI6EV3BmRK65^Jb0`
85mSMG9bIFidM79QKW=VIG8PIGQUH`da85mSMG9bIFidM79QKW=VIG8PIGQUHb1U
LB1TIFH=;fiUIf5dJGIU869/HFi[Nc0PGf=eLW9UKWAdLV5^LfIULR1UN6ES830^
=B1/M7d=Nc0PGf=eLW9UKWAdLV5^LfIULR1UN6ES834PGf=eLW9UKWAdLV5^LfIU
LR1UN6ES86MdOFUVIFacIB1TIFH=;fU^MVEbM6ET?b1^IFMQM6UfIB1TIFH=;emS
MG9bIFidIg9QNB1cNG=dIFeTJF=d82mSMG9bIFidIg9QNB1WIG@PI6EV3FQQLf=_
K6mbNblTHR0`86AUIWdPNblTHR0e86AUIWdPJFIUK7=U3BmcIGASKGU[Hfm/Kg8P
MfQULVEkL6m`834P<20`830PLfEdHfeiJf=_K6mb85mSMG9bIFidIg9QNB0a86Eh
HfPPLgER3C0P<B0`830PLfEdHfeiJf=_K6mb85mSMG9bIFidIg9QNB0a86EhHfPP
LgER3C0P<20a830PLfEdHfeiJf=_K6mb85mSMG9bIFidIg9QNB0a86EhHfPPLgER
3C0P<20`834PLfEdHfeiJf=_K6mb85mSMG9bIFidIg9QNB0a86EhHfPPLgER3C@P
Nc@PHfm`NGdPLVE`IF5d3C4P<20`830PIVmeLVEaNblTHR0a87=dKg9UOFUV3C0P
<B0`830PIVmeLVEaNblTHR0b87=dKg9UOFUV3C0P<20a830PIVmeLVEaNblTHR0c
87=dKg9UOFUV3C0P<20`834PIVmeLVEaNblTHR0d87=dKg9UOFUV3C0P<20`830P
IVmeLVEaNblTHR0f87=dKg9UOFUVOFUV3F9/HFi[NblTHR0f87=dKg9UOFUV3BAR
830PIG4P968P=B1ULB1_LW/_96Ad830PI6EVOFUV;bATM20]<B1TIFHPIg9ULgA_
LVEmI6EV3BmTKfU]HFMUN`e/IGIUK39kJFeQIfEmNf9UIfU^3EMYI7AX84QUJFMX
M212JGAcD6Eb@fm]L6m^IFid84U]HFMUCF5dLVUh3DAUHfmTIB1/IFiWM6PP<R1U
L@ek;dAQM65CKgEbHfDPK6mQI21UKV@PJFeQIfEmN`e4IF=_I6DPK6E^IgAX83HP
IG4=NdeeK7AYL6aUA65dHE=_MG9SIG=kA65dHE=_MG9SIB0`86MUM214HGAQDfme
LV=U834PIfEd84AQM65CKgEbHfDP<R1WIGAmNbm4HGAQDfmeLV=U86a_HFAmJFIU
K7=U3DeeK7AYL6aUA65dHE=_MG9SIG<P<b1UKV@PA5=9@fm/Kg99KF5WIGek3DAU
HfmTIB1/IFiWM6PP>21ULG]=MFadJG1/IDAQM65CKgEbHfEcNdAQM65CKgEbHfDP
<21WIG@PA65dHE=_MG9SIB0a86MUM0e4HGAQDfmeLV=U838PIfEd84AQM65CKgEb
HfDP<b1WIGAmNbm4HGAQDfmeLV=U86a_HFAmJFIUK7=U3DeeK7AYL6aUA65dHE=_
MG9SIG<P=21UKV@PA5=9@fm/Kg99KF5WIGeYIWeYIVE/LfD=OFUVIFacI@emJFIU
K7=UOFAUIPd_I7Ak;g9WHV=/MG@PN6AV82mRMf=/MG@PN6AVOFAUIPd_Hfak96TP
LfEdKF5dLVUh87AbHFicK65dIB1cHf5/I@d_GgLPGfU]HFMUI6USM20_EfUTM6PP
IfEd86AUIPd_GfPPGfU]HFMUI6USM20_B6EYIfQd86MUM21TIFH=;emTLb1OJFeQ
IfETJF=d82m4HGAQDfmeLV=U86MUM21TIFH=I6mSK7EdJFeQIfEm86AUIPd_HfAk
96TPLfEdKF5dLVUh87AbHFicK65dIB1cHf5/I@e/IGIUK39kGfU]HFMUI6USM20_
@fm/Kg9CL65SIB1WIG@PLfEdHfm/Kg9cL65SIGeYIPd_GgLPGfU]HFMUI6USM20_
EfUTM6PPIfEd86AUIPd_GfPPGfU]HFMUI6USM20_B6EYIfQd86MUM21TIFH=;emT
Lb1OJFeQIfETJF=d82m4HGAQDfmeLV=U86MUM21TIFH=GfU]HFMUI6USM21RIFMY
KPd_BFeQIfE=HGAbJGPPGfU]HGAbJGPPI6EV3F=eLW9UKWATJF=d86E^I0eTKfU]
HFMUOB1TIFH=;fU]NbAY87=UM6eQM79YN21dLV5^LfaQM6DPLf=QK6DP3FaUMVE/
<W/_A6EfJF=UAg9QNB1cIGASKfa_LW=`HF=U830PLfEdIg9QNGeYIPd_GgLPGfU]
HFMUI6USM20_EfUTM6PPIfEd86AUIPd_GfPPGfU]HFMUI6USM20_B6EYIfQd86MU
M21TIFH=;emTLb1OJFeQIfETJF=d82m4HGAQDfmeLV=U86MUM21TIFH=GfU]HFMU
I6USM21RIFMYKPdU;dAUHfmTIB1K<20aGB1TIFHP80dU;eMYI7AX85mg86AUIPdU
;dQUJFMXM21OJ21TIFH=;dU]HFMUCF5dLVUh85mYKF5dLVUh86AUIPeSMG9bIFid
I6USM21UKV@P3FA_JFeQIfDPOFAUIPd_Hfm/Kg9YKF5WIB1gJ6EbIG]`Kg0_A5=9
@fm/Kg99KF5WIB1kHfm/Kg9YKF5WIGdPI6EVOG/_A5=9@fm/Kg99KF5WIG/=;bA^
Hb1hI6HPL6m`82m`LVmS<21hI6HP<b1YKVAUN20b86U^I6Eh86eeK20g865TI20h
86AYMR1SMVTPLgAbJFiW82mcM34PN6AV3BA^Hb0c86EaNg]`LVmS<21TMG0_Lg@`
87QTIR0`86EhHfPP<b1UN6=X86aUKVMdJ20c87=eHPekI7E`87=d<21UN6=X86MU
M20^<b1]MF`P<B1YKVAUN20a865TI21cM30PIGQSJ21WIG@P;SDi86eeK21QI6@P
<B1YKVAUN20b865TI21cM30PIGQSJ21WIG@P;S4a86eeK21QI6@=HgIY86EhHfPP
<b1TJGHPHgIY86EhHfPPLg@a83<P<B1bKfa/871eM7eVKg8PLg@aOGekNg1bKf<`
86AeL2mcM30PN6AV830PIGQSJ20d86EhHfPPK6E^IgAX83@PLgERNfAeL0ecM30P
IGQSJ21WIG@P;S<PKGE/3C4PJFiTIGPP<B1QI6@PLg@`86EhHfPPIfEd82he>B1]
MF`PHFAT3C4PJFiTIGPP<R1QI6@PLg@`86EhHfPPIfEd82ha<B1]MF`PHFAT3C4P
JFiTIGPP<b1QI6@PLg@`86EhHfPPIfEd865TI21TMG0P<SDe;S0PIgAkL6m`838e
=Bh`OFUV3C8e=Bh`86EhHfPPLgER86=fJ@eUN6=X83@PI6Uf86=fJB1UN6=X3G=d
<B0c834PLVm/K21`MGAmIVmb87=d<GemJFIUK7=U3FU]HFMUOFAUIWeYIVE/LfD=
;dm@BFU]HFMUNfU]HFMUOFAUIPd_96TPKF5dLVUh86AUIPd_HVUkLf=QK6DPM79Q
KW=/HGAU82AY86=eLW9UKWA]HGAbJGPPL6m`87AbHFicK65dIB1cHf5/IB1cIGAe
L69QKVAcOFAUIPd_IFUk96TPLfEdKF5dLVUhOFAUIPd_JF]k96TPLfEdKF5dLVUh
87AbHFicK65dIB1cHf5/IB0=;emg85mYKF5WIFAYHg@P;eMYI7AX86MUM21TIFH=
;emX85mYKF5WIFAYHg@P;dQUJFMXM21WIG@PI6EV3BmOI7<PGfU]HFMUI6USM20_
A65dHE=_MG9SIB1WIG@PI6EV3Emg85mX86IQK7=U85mYKF5dLVUh83DP;C4PLVm/
K21OI7<PJFeQIfE]HG=[OFAUIPd_LW=k<R1SKg1i87AbHFicK65dI@dc82da879_
K6`PKVEW879_M65dI@e^IFLPIGQSJ21^IFLPIGQSJ21dLV5^LfaQM6D=OFAUIPd_
Hg=kGf=fKGAh865cM6mbIB1SKfiSHGAm86AUIPd_IVAk;emVI21hI6ImI6EV3BmO
IVm^M4eQM79YN7/a830P<21OIV@P<21^IG/]<B0`831mNc4P<20`OFUVIFacIB1O
HgI]M7PPHG=dKg9UOFAUIPd_LVIk;emUKV=_I6U^I6Eh87QTIPe6KfidA6UbIF=d
Kg9i86EhHfPPJfi_MfhPN`eVJFiTIVm^M21TMG0PK6E^IgAX834PHFAT86AYHg@P
HVEWJFik<B1YKVAUN2m6BD@PKVEkI6EVOG]`Kg0PL6m`OFUVIFacIGeVKg9QK6`=
I7E`82m6KfidCV5]IB1UN6=X86AUIR16KfidE7U`IB0`86iUNbm5KV=_I6U^Ib15
KV=_I6U^Ib0b=CHPHG9bHGTPHfm`NB1TIFH=GfE^HfmTJFiTIGPP<21WIG/`85mU
KV=_I45bLR1OIFiSKfAYKVAUN21WIGAkI7E`87AiL6D_KV5]IGAiL6DPIG5kAFiS
KfAYKVLP<R1YKVAUN20b86U^I6Eh871eM21`Kg0P<B1QI6Am3G]UN6=X871_L7eY
IVE/LfEmIVmbHFa/871_L7eYIWeYIPeSMG9bIFidI6USM21UKV@=I6EVJFiUIVm^
M21`Kg0POG]`Kg0PL6m`OFUVIFacIGdPI6EV3BmSMW=VNb1VJFiTIVm^M21VM5=Y
NVDP<20`86IdDfUjIB1OIV@P<21^IG/]<B1]MFamJFHP<20`85mSMVedN21QLgA_
LVDP3FeQJfEVKfid87=UM6I_KWAmI6EV3Bm]IW/c82da879_K6`PIVU^I6I_KW@P
<b0a879_K6`PIGQSJ21VM5=YNVDPKGE/86EhHfPPIWACJGYU86eeK20`86EhHfPP
<21UN6=X80eOIV@P<21^IG/]<B1]MFamJFHP<20`85mSMVedN21QLgA_LVDPKF5[
IFI_KW@PLfEdIVm^M7eTIFH=;gMbJc4P:20Y86AUIPd_MfAYHg@P<CHPI6USM21T
IFH=;eM_LV/g=B0g=B1cM79YKVLPI6EV3Bm>KF]kEfmbJcLe86=fLb1TMG1mI6EV
3Bm>L7AkL7Ed86=fKWeTIFH=;fAXCfAXNdi]Jb0b83Li84i`M7eTIFH=;fAX@VAX
Ndi]Jb0b834a<B1>L7AmI6EV3BmTJ5=TJ7]>KF/P<R0h<b1>L7AmI6EV3BmcIUMY
I7AXNfMcHGIU830P<21]KgIUM6lP<20`86aYKVEdKb0`830PK6U^IGA_830P<21/
JFiUM6lPHfa_LfE`HGAX86=/JG0PLgAbJFiWMfUTM6PPIg9ULgA_LVEmI6EV3BmV
M7=k;fIdDfUjIB1UN6=X86AUIWeTIFH=;fe[AUAkI7E`;dI_KWADNG1U86MUM20`
86EaNfAeL21]HGQ/IFiWM6PPI6USM21RIFMYKPek<B1YKVAUN2m6BD@PKVDP<R1Y
KVAUN20_EFiYLGEUBD@PKVDPHFiTNfAUIWekL6m`871_L7eYIVE/LfEmIVmbHFa/
3F=eLW9UKWATJF=d86E^I0eTMG0_ATAUL5IUHgA_LR0b86=_L7TPIfEd3E]UN6=X
83HPJFiTIGPPIGQSJ20f86U^I6Eh86EhHfQkKF]6E20c834PLVm/K7eVKg9QK6`P
L6m`871_L5dPL7Ed86AeL7ek;gAUKG16E20a<R1TJF=d86AUIPedIFe`AU@PHVEW
JFh=;dI_KWA=HGAbJGPPFc4P<20`834P<20`GB1TIFH=;dI_KWADNG1U83<PI6EV
3FAeL2m5KV=_I6U^Ib1WIG@_AFiSKfAYKVLPIGQSJ21TIFH=;g1bKf<b838PJFiT
IGPPI6EV3FAeL2mVM34PIGQSJ21TIFH=;fId<R0a865bLV5i86AUIPd_AVm^M492
KgPPFc0P<20a835M86AUIPd_@WEYK6A3J65bNd=FA6USM21RIFMYKPeUN6=X86Ae
L2mVM6Ad87QTIR1RIFMYKPegI6USM21RIFMYKPd_HfQb87QTIRmSJ79cM21gLV/a
86AeL20`86=XLR1`MG@PI6EV3FId<R0`86MUM21^MFa/86EaNfId<B1TMG0PK6E^
IgAX838PHFAT86AYHg@PHVEWJFh=Nc4PJFiTIGP_ATU486iU838PJFiTIGPP;eE^
JG5eIDU486iU865^I7]TIFImNg1_L21`Kg1mJFIUK7=UOFI_LV5/K0d_D65YKWAD
NG1U838PI6EV;e=dLVm[IEMYI7AX82h`<S@P<216KfidCF5dLVUh86UTM79QKW=V
Kg9]871_L21TIFH=HgEbLVE^M6AYHg@PIFiT3Bma86EhHfPPI6EVJFiUIVm^M0eV
M38PIGQSJ20`86EhHfPPL7EdOFUV3FIdI7@_L79_Hc8PIfEd86EhIF<PIFiT86E^
I21UKVAmI6EV86E^I21dIFe`AUAmJFIUK7=U3C<PJFiTIGPPIGQSJ0eTIFIYKVEV
Kfid86EhHfPPL6m`OFAUIPd_KF9kI7E`86AX@VAX84I_KWA4JG9UHgA_LWTP<B1Y
KVAUN21[KVmgKPekIGQSJ21`Kg1mNfAe02<0002Q0<0oog0P<R1YKVAUN0eVJFiT
IVm^M7]RKfaTL79_HgdPIGQSJ0e]JdID871_L21`Kg0PL6m`86EhHfPPL6m`3GeY
IVE/LfDPOFAUIPd_KFmkI7E`86AXCfAX84I_KWA4JG9UHgA_LWTP<B1YKVAUN21[
KVmgKPekIGQSJ21`Kg1mNfAeL20b86U^I6Eh3FIYKVAVKfidNfmeM71bKf=m86Eh
HfP=KF]6E21`Kg0PL6m`871_L21UN6=X871_L0emJFIUK7=U87eTIFH=;fecNfAe
L21TJ5=TJ216KfidA6UbIF=dKg9i834PJFiTIGPPJfi_Mfh=NfEhHfPPL6m`OG]T
MG0P<R1YKVAUN0eVJFiTIVm^M7]CJ65T@fQQLWdPIGQSJ0e]JdID821`Kg0PL6m`
871_L21UN6=X871_L0emJFIUK7=U87eTIFH=;fmeM71bKf=kIW@a87=UM6I_KW@=
Ig=QMVDPHfQbLg@PLfIGJFAdJ21WLVEcM6mbI@ecIGASJ65bMfUTM6PPI69/LfQm
I6EV3BmRKfaTL79_Hg]VM34PLfEdIVm^M0eWLf5fI@eSJ79cM21cIUMYI7AX834P
JFiTIGPP<21^IG]UN6=X82h`=B1QI6@PIGQSJ7eYIPeWLVEcM6mbI@ecIGASJ65b
MfUTM6P=IW@a82m@HFU^M5AiL6DPIfEd838PKVD=Nc0P<21]KgIUM6lPIg=QMVDP
IW@b830PIfEd87=UM6I_KW@PHfQbLg@PLfQ_Mb1WLVEcM6mbIB1SJ79cM21cJ6mg
O@ek<20`86e_MVEdKb1WLf5fIB1SJ79cM21cJ6mg86MbIG=dKg9U82h`=B0`86e_
MVEdKb1SJ79cM21cJ6mgOFUVIFacIGeTIFH=;fARK7=XNf=eLW9UKWASKfa_LR1S
MG9bIFidHfm/Kg9cL65SIB0a;S0PLfEdIg9QN@eSJ79cM20`830PKFmfIGA_87=X
KgLPLfEdHfm/Kg9cL65SIB1cIGASKfa_LPeVM38P<21WIG@PLfEdIVm^M21SJ79c
M20`830PKFmfIGA_87=XKgMmI6EV3BmCJ65T@fQQLW/=IW@a87=UM6I_KW@=Ig=Q
MVD=HfQbLg@PLfIGJFAdJ20a86U^I6Eh830PKVEkIGQSJ20^<3DPHFAT86EhHfQm
JFH=Ig9ULgA_LVD=LfEdHfQQLWMYI7AX3F=XLW=d82h`=R0`86e_MVEdKb1cJ6mg
3C0P;S0e87AbHFicK65dIB1THVacJ7eTIFH=;gAcNg=XKgMmI6EV3BmdHG/_GfaU
M7AULU=`HF=U87QTIRmOLg1QHfEHM79Q87QTIWeTIFH=;gAVNbmOM6EhM5MYI7AX
87QTIPd_GfieKE=`HF=ULb1hI6H=;emcM79YKVM<IFiWM6PPN6AV3FAeL0UcM79Y
KVMgJFAdJ21`Kg0=GfaUM7AULU=`HF=U85mcM79YKVM<IFiWM6PP<B1cMF8PKGE/
865TI0eOLg1QHfEHM79Q85m^MFeCL65SIG<PKGE/865TI0eOM6EhM5MYI7AX86Eh
HfPPLgER82mgI6UV87QTIPeOLg1QHfEHM79Q830P<c8=MfAYIR1OLgAbJFiWC6E^
IgAX86AYMPeOK6EdM6EbDg1QHfDPHFAT3C0P=R0]<B1bKfa/865gJFAdJ7=XKgMm
I6EV3Bm`HW/_Ge1QIfECHGIU87=QMVDPI6EV;g=XKgM`HFMUNgeTIFImI6EV3Bm`
IG]OD65WIE=QMVDPLVEcM6mbIGeTIFH=;g1]Nem`KB1SMG9bIFidKF5dLVUh871_
L7eTIFH=;em`KB1]HGAbJGPPI6EV3Bm`Lg]cJ6mgL65WIB1OL6dPLfEdKF5dLVUh
OFAUIPe/IGIUK39k;fEV87]WLf5fIB0f865bLV5i865cM6mbIB1SKfiSHG@PI7E`
86EhIF=VKg9]86MbIG=dKg9UOFAUIWd=NbmUIW]WLf5fIB0f865bLV5i865cM6mb
IB1SKfiSHG@PKVEgL65dJ21TMG0PHVEWJFhPCF5dLVUh86=_KV=QM0e2@Vmh86Ae
L21TMG0P<21WIG@PIGQSJ20a86MUM21]KgIUM6l=I7E`86AeL20`86MUM21UN6=X
83<PIfEd86aYKVEdK`eTMG0PI7E`838PIfEd86EhHfPP<b1WIG@PK6U^IGA_3FAe
L20b86MUM21UN6=X834PIfEd86aYKVEdKb1SK6mcIG1QM6P=HfaYL21^IGM`HGAX
851QJFidD79_Hb1UKV@PIg9ULgA_LVEmI6EVOFUVIFacI@d_HV=kLf5fIB0a<B0a
879_K6`P<C0PI6USM21RIFMYKR0_@T9_N20e834PLVm/K20d865bLV5i865cM6mb
IB1TIFH=;deQM79YN20g834PLVm/K20f865bLV5i865cM6mbIB1TIFHP;dI_LVeD
NG1U834PI6EV;e1QJFidD79_Hg/_L70PIfEd86EhIF=mI6EVOFAUIPd_IF=kL6m`
879ULgA_LVEmI6EV3Bm`LVU^M7I]Nc4PMVebIF=/HFU]87I]LgAQM7Ec871_L21U
N6=X871_L20X820P820P820P820P820P820P820P820P82USMW<PL79YKW@P:5a^
:G1bJFid86I/MG=XOFAUIPd_LfEdKgIULW1bJFid87MXIG9U87]`Kg1mNbmcIGA_
MVEbL79YKWAkL6m`OFAUIWeYIVE/LfD=;g=cM78PNb0_97=cM79c86EhHfPPI6EV
82lTLg=dLR1UN6=X86AUIR0_97=cM79i86EhHfPPI6EV82lTLg=dLWPPIGQSJ21T
IFHP;d=_MG9YIG8PIVU^I6I_KW@P97=cM79c80ecHf5/IFI_KW@PLfEdIVm^M20T
Lg=dLWPP97=cM79i86ed87=dKB0a82da87=SHFaU82AcLgAb87=XKgLPLWA]87dP
I6EV3Bm4DdU2IFMYKU1QJFidD79_Hg/_L70PKF5bJg]SMG9bIFidIVU/IB1dKf]U
KR1^KgAkOFUV86AeL2m4DdU5KVA@HFU^M51bKf<=2FEaNg1_L21SKgE^M7A_KF5b
Jb1QLW9QNB1QLgA_LVDPHgIh869YKV@P;fEhIF<PK6mQI5eSMWPPI6EV84ACBDE^
I51QJFidD79_Hb1UN6UdO@d9Nf=_MFidM6m]HG9[83<`<21WM7]SKgE^M7A_KF5b
Jb1QLW9QNB1QLgA_LVDPHgIh869YKV@P;fEhIF<PK6mQI7eYIWeYIVE/LfEmK6m_
L7eTIFH=;dACBDE^I51QJFidD79_Hg]SMG9bIFidI6USM21UKVAmI6EV3Bm4DdU2
IFMYKU1QJFidDgERD79_Hb1kLf5fIB0a<B0a879_K6`P<C0PI6USM21TMG0P;g14
86EhHfPPI6EV869UIfU^80d9;d92KgPP=B0a879_K6`P=21QLW9QNB1QLgA_LVDP
I6EV82m=HGAbJGPP=b0a879_K6`P=R1QLW9QNB1QLgA_LVDPI6EV80d9;dI_LVeD
NG1U834PI6EV82m@HFU^M51bKf<PNb0_L70PIfEd86EhIF<POB1TIFHP;g1`OB1T
IFH=;dACBDE^I51QJFidDgERD79_Hb1kHVU^I21TIFHPIFiT8714OB1TIFH=;fUQ
HB1k;fUh86Uh86UhKR1QI6@PI6EVOB1TIFH=;fUQLc8PNbmYIf5`86EhHfPPI6EV
82mOLg@`86UQ86Uh86UWHG0PHFAT86MUM21TIFHPGg=d<7dPI6EV3BmYHG<PNbmc
M30PJF4PJGPPIfEd86AUIR1YHF4PLg@`OB1TIFH=;fTh=G<PNc0PJF5c<R0_@E=3
BDTh=DAUHfmTIB1VJFadIG8PLg@`879UHFAcM79YKVLPL6m`86UQHGdPI6EV3BmY
LVaULb1k<21YHG<b82m1Dd=9BCPeA6ESKfAU86IYK7AULR0_DWE^C6E^IgAXA6ES
KfAU86IYK7AULR1cM30PLVEQI7=dLVU^Ib1`Kg0PJF5QOB1TIFH=JFiYM6UQK6Uj
I@eUKV@=9BE5KVABIG=_MG9SI@e3ETAYHg@PHVEWJFhP<21YI20a86IT3EmUKV=_
I45bLR0`3E/=<cT_LGE_M6EcJFiWK6DP>CH_Ig9QMVD=<C8h;f9eK6aUM2mRMFa/
IG@_LGE_M6EcJFiWK69QLfD_IVa_LVU^;g5eKgAUI69/HV5cIBmUK6aYL7=YLbmT
HFMWIG8_I65WIfEbI69/;f=YLV=eKFI/IGP_L6EbM6Q_MG=QKV@_Df=QLVm^;fMe
JFacJFiWK6aUIW@_CdD_HWE/K6Ed;f9eK6aUM2mRMFa/IG@=;f9eK6aUM2maMFmd
IFaUIW@_LGE_M6EbJFMXM2maMFmdIFARK6aUIW@_LGE_M6ETHVabJFMXM2mRMFa/
IG@_IFiTHG=X;fE]I65cJ2mdJFaTIBmdLV5TIFeQLV/=;g=SHG9_KPd_IgEYK7=Y
KVM/LVUWJ7@_KfD_HWE/K6Ed;f9eK6aUM2mII6UULVEcJG<=;f9eK6aUM2mUN6=/
HFeTKgM^;f=UKW@_LgAULVaYKVL_HgEbLVE^HgT_NFE^;f9bKf]UKV9QLRmcIF=d
JFm^;fAYIG9ULfUc;f=_L7UbJFMXM2m_LVAVIFeYKVU^IBmWMFU/K6E]KgA/IFId
;fa_IfUSHFa^Kg@_J7U`J6E^;g9UIfUcM6EbIF@_KF5SLVm^3BmTIFMbIFD_L6ae
LfeYKWEc;gAgKg=eL6EbJFmb;gAXLVEULgE`IG9YKg8_HF=eM6D_KGD_L65bHFMb
HG1X;g1ULVU_I6=UKWAULVET;f=UI6U/K64_KfiULgE`IG9YKg8_Kg9TKF5cHgE/
JFiU;fMeJFa/IFe_M79YIfQd;fm^IG5eHG9dIG8_KfiUJ65/IRmdJ79UIG5eHG9d
IG9c;g5eIG=dJFm^I6mgKPd_@FMbHGIU;d5QHgEdIBm1HfUbHgE]IVaUN2m1M6U/
I6D_@FAYIG9ULfUc3Bm1LVU^I`d_@DD_@f=UI6U/K64_AFMbHGIU;dEQHgEdIBm5
Ig9QMVD_AFAYIG9ULfUc;dUWLV5fIBm9HF=eM6D_BF=YLV=eKFI/IGP_BFAYIG9U
LfUc3Bm5M6P_CWAYK6AU;dmWLV5fIBm?HF=eM6D_Cf=YLV=eKFI/IGP_CgAYK6AU
;dmTJFEbIG=YLbm]MFadJG1/NBm?LfaQLfP_EFMbHGIU;eEQHgEdIBmEHfUbHgE]
IVaUN2mEI6UULVEcJG<_FF5SMGAU;eAXKg9^;fMULVeQKVARK7<=;f5WLV5fIBmQ
HF=eM6D_HF=YLV=eKFI/IGP_HGAYK6AU;f5TJFEbIG=YL`d_HG9YKVL=;f5U;f=S
IFAYK6aQ;fEWLV5fIBmUHF=eM6D_IF=YLV=eKFI/IGP_IFAYIG9ULfUc3BmYIg9Q
MVD=;fUQHgEdI@d_JF=YLV=eKFI/IGP=;fUTJFEbIG=YL`d_IGAX;fidJFaTIBm_
Ig9QMVD_Kf5SMGAU;fmSJG9SMFeVK6Eh;fmdJFaTIBm_I6UULVEcJG<_I6UfJFAU
;fmcK65cJ2meIg9QMVD_MF5SMGAU;gESJG9SMFeVK6Eh;gETJFEbIG=YLbmiHF=e
M6D_M6Q_LVh_NFAYIG9ULfUc3EdPL7Ed3EmUKV=_I45bLR0a3E/=<cT_LGE_M6Ec
JFiWK6DP>CH_Ig9QMVD=<C8h;d5TJFEbIG=YLbm1LVU^Ibm3HfETJFa/HBm5HF=e
M6D_CWAYK6AU;dmTJFEbIG=YLbmEI6UULVEcJG<_HF5SMGAU3BmQIg9QMVD_HF=Y
LV=eKFI/IGP_HFAYIG9ULfUc;f5dJFaTIBmQLVU^IbmSHfETJFa/HBmUHF=eM6D_
IFMbHGIU3BmUHfUbHgE]IVaUN2mUI6UULVEcJG<_JF5SMGAU;fUWLV5fIBmYHfUb
HgE]IVaUN2mYI6UULVEcJG<_KWAYK6AU;fmQHgEdI@d_KfMbHGIU;fmSJG9SMFeV
K6Eh;fmTJFEbIG=YLbm_M6U/I6D_MF5SMGAU;gEWLV5fIBmeHfUbHgE]IVaUN2me
I6UULVEcJG<=;fAQIfMULRmTIFMbIFD_HfE^M2mcM6EbK6U^IbmcIF=dJFm^;f9e
K6aUM2m`HG9QIg9QL6P_IfEbKF5^I69/L`d_LVEWJG=dIG9UI2mSKg1iLVUWJ7@_
M79QI6E]HG9[;f5SMGAU;fAYIG9ULfUc;fi_M6EaMF5/;d55;dmcK65cJ0d_JFiV
JFiYM7T_L6aeLfeYKWEc;faULg=ULGEQK2mWLVEQM6EbIG5eHF`_NFE^;fee;g1Q
LWAYHFaTJFIV;g=eKFeQM6U_KPd_L79_I7ESM2m`JBmYKWAUIg9QK2m_LVAVIFeY
KVU^IBm_LVA]HG=SMFaYKVD_CfeUIf4_HFD_Kg=/HG=X3BmaMFEcM6U_KVA_Mfh_
IGQSK65]I6mgKRm/KfMYHf5/KVmd;g9QI6USHF`_IVa_LVU^;f5`L79_N6EaMF5/
;dAUK7AQ;fMeJFa/IFe_M6aUIW@=;fMeJFa/IFe_M79YIfQd;fE/K6U`LfUc;f9/
HFi[;d5WLV5fIBm1M6U/I6D_CgAYK6AU;dm5;fmU3BmUKVAQLfP_IFeTHG=X;g5e
KgAUI69/K6EVM2maMFmdIFARK79YIfQd;g5eKgAUK6EVM2maMFmdIG9YIfQd;fAY
MVUTIBm/KgYUKVMU3BmiI6UULVEcJG<_FFAYIG9ULfUc;fIbHF=dJFm^;f=eLW9U
KV=i;fMeJFacJFiWK6aUIW@_IgEYK7=YKVM/LVUWJ7@_IVT_IV`=;fAQIfMULVAR
K2m`IG9YKfASIFidIG9UI2maMFmdIG=YKVM/HV5cIBmaMFmdIFARK69QLfD_L6Eb
M6Q_MG=QKV@_@F=YLV=eKFI/IGP_AF=YLV=eKFI/IGP_@F5SMGAU3Bm5I6UULVEc
JG<_AFMbHGIU;dUQHgEdIBm9HfUbHgE]IVaUN2m9I6UULVEcJG<_BFMbHGIU;dmQ
HgEdIBm?HfUbHgE]IVaUN0d_HG1`K6D_CfMbHGIU;eEQHgEdIBmEHfUbHgE]IVaU
N2mEIg9QMVD_I6mdK6EcLfT_HfUbHgE]IVaUN2mdJFaTI@d_KF5SLVm^;f9bIGIU
;fA_M65SHfE^M2mbJFiW;f=UI6U/K64_J7E^If5bMFe/HGEd;fmWKfiUJbmSHG9_
KPeM871eM0eUKV@=9BE5KVA@LVm/KfLP3BDU@VEWJFiCIGAeL20=@eI4JF=d869U
IfU^3@dU9D9UIfU^DVEcKgEbHfDj86I_KW@PAfE^IGIQ3C4d86AYHg@PHVEWJFh=
;dI_KWA>HFeU82m7IFiUMV4PI6EV3Bm6KfidCF5dLVUh85/`;S0`<B0`830P<2h`
<34P<20`GB1TIFH=;dI_KWA9KVI_834`86AYHg@PI7E`869UIfU^3Bm6MFa/CV5]
IB0XAfE^IGIQ:B1TIFH=;dIQKFU/NDiQKFDP:4MUKVEfHBTPI6EV3BmEKVAULVaY
KVE@Kg=YM6U_KR0]<C0`86AUIPd_EFiTIG9/JFiUE6QYHf]^IG=c83D`86AUIPd_
DgAbJF]UKgEdD6mcJGAYKfhP<c0`86AUIPd_DgAbJF]UKgEdE6QYHf]^IG=c838e
86AUIPd_EfEYIfQd82Q=IFAYMFdY86AUIPd_BGAQK6US@FiWK6DP<21TIFH=;fUc
AVUhIFA@JGASJ21VHFacIB1TIFH=IFiT86AUIPd_GfM/NG1X82QH820Y86AUIPd_
IgP=N`d9<B1UN6=XN`d92FAeL20a=R0X820Y86=fLW<PGfM/NG1X86EhHfPP<B1U
N6=X871eM6U^M6EbMV5/834PJFiTIGPPIGQSJ0d92EmWK7U`J21SMVhPL7Ed3@T9
OFI_LPemI6EV3Bm@HFU^M5AiL6DP<21TIFH=;dI_KWADNG1U834PI6EV3Bm5KV=_
I6U^Ib0b=CHPHG9bHGT=<20a838e=B1k834PJFiTIGPPIGQSJ20_;Vi_M6AUIR1`
MG@POB1VKg8=<c0P<SDe86Mh3FAUIPd_AVm^M492KgPPFb0`830P<20`85dPI6EV
3F=eLW9UKWATJF=d86E^I0eTMG0P;e1bJGIQM6DP>21TJF=d86AeL21RIFMYKPd_
DTAkLgAbJFiW86=eLW9UKWAVJFaU86EhHfPPLVEQI6QUN7=dLVU^Ib1`Kg1mI6EV
3Bm>A7]TIFImI6EV3Bm>D7]`MGAmI6EV3Bm2K7EUEV5/MFEcFb0]<SD`830P<S8`
<20b<S0`GB1TIFH=;deYKTIUHGAeLVDPNb0a=R0a=WdPI6EV3Bm`HG=cMfmbI20e
>3<i86AUIPd_DgERLW<P=3<PHG9bHGT=CT@=<R1YKVAUN20_@fQQLU=dLVU^Ig<P
<SDf86AYHg@PI7E`869UIfU^3Bl^KVmdI6EV820a<21BA20b=4E3@T@`=C=5@d54
<cDbASDh<B1>A0d_F30a820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDP
CT@=;eP`<R0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<3<P
834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F30d820a<R1BA20b
=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;eP`=B0P<C8PDT@P<SA5@d94<3Dc
AD8i@C0g=DA1=3Q3@dE584i43BmH<3HP834b8594838dAD=2A30e<dE2>D4`=cE4
@C@h@d=5AB1>A0d_F30g820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDP
CT@=;eP`>20P<C4PDT@P<SA5@d94<3DcAD=1A3<e<THe>3He<R1>A0d_F30i820a
<R1BA20b=4E3@T@`=C=5@SHe@d@i@S4a=48`@DDPCT@=;eP`@B0P<C8PDT@P<SA5
@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<48P834b8594838dAD=2A30e<dE2
>D4`=cE4@C@h@d=5AB1>A0d_F313820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d
>4=3ADDPCT@=;eP`A20P<C8PDT@P<SA5@d94<3DcAD8f=D=4>D8a<CA2<45584i4
3BmH<4DP834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F316820a
<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePa<20P<C8PDT@P<SA5
@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<C4P834b8594838dAD=2A30e<dE2
>D4`=cE4@C@h@d=5AB1>A0d_F34b820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d
>4=3ADDPCT@=;ePa<b0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i4
3BmH<C@P834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F34e820a
<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePa=R0P<C8PDT@P<SA5
@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<CLP834b8594838dAD=2A30e<dE2
>D4`=cE4@C@h@d=5AB1>A0d_F34h820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d
>4=3ADDPCT@=;ePa>B0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i4
3BmH<D4P834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F352820a
<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePa@b0P<C8PDT@P<SA5
@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<D@P834a8594838dAD=2A30e<dE3
@D@c=C96=CPf=C8PCT@=;ePaAB0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3
@dE584i43BmH<DHP834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_
F38`820a<R1BA20b=4E3@T@`=C=5@SHe@d@i@S4a=48`@DDPCT@=;ePb<B0P=34P
DT@P<SA5@d94<3DcAD8f=dDc<cI1@C@g<CDa=3A4@CDh<dA2<T8aA4HcAD51ACI3
A394=cM1=CTg>44g=c4f3D<`ASM1@SPc@cT`=c=3>30a<S0i>38PCT@=;ePb<R0P
=3DPDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Pc<THg=3=6=cHi<495A4@c>34e<d8h
<cTc=4HaACLhA3U1=D@b>4I23D=5=T4h=38a=D93@TDgASU1=3TgACL`<CQ1ACPa
A21>A0d_F38c820a<CPPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6>4=6>356=48i
<SHg<S4b>493>DDe@d55@S4c@DDbA30c@dA5ATI53CPb<dE4<SHa@CHd>CLbAT@e
=dHf=cDb<d<`@d8a>48a=DHb@cHg>48b=d<a>C55=SDe=D4f=4<g=DI3<Pe6<T4f
=S@i@CA3=THg=c0`>4I1=3La<3U5<dA2<d8e@C51<c0eA38fAC13=S<b=CA5=dE4
<3Hi>D<g>34=AT52<30h>4<i=T8`@SU2=TI5AS52=C11<SE4<CU2@c0bADE2<S@b
<C92AD96=D@g<C8i=THa@d4PCT@=;ePb=20P<SL`8594838dAD=2A30e<dE2>3Le
<d=1=4@fASL`A48a<dDdAC8`=TE3>D8g<C=5=SE3=30c@c<i@STb@CL`ACTf>@de
<CPh@D=3>3<c<4<eAD4bAC8i@d8c@c8d@TDh=CU6A3TeAC@`<DH`<SDh=c<g=SLa
=3<i@c<`<d=1AC@=<34d=S@eA3PfACD`<SLc>3U1=S0eASM6<S=2@C8d=3Pe@T96
ASA1<CHe>393<3D`=dDa=3@dA452=C943C@e<d@f@cPe@S<f=cE4@dA6AC91<4De
<S16A3@i<S8dAC0b=d@e=CL`<D55@d8a<4E5@SE3<T54@CDc=0d`<3<h=T4e<cTe
<D94@STb=dE4<SLh=c93>C<a=48f<cLi<SA3ACTd=cE5@SDi@CM5=D<g>CM3=D95
=c@=>4A3<d4c=SDi=S0h=S16=c=5@C4a@d8gAD8f<cM4A3Tb=T=3>D91<3U2=c@a
<DHe<3<`@SLf=4I5@DA53CD`ASHi=TA6@CQ4>D8f>4Di>D8b=d55=SQ3A4DaAD4`
>CU2>DI6ASTcATHhAS4c=D8b>44aASU6<C8aA@dgA3@c<T<`<4<e>3<aAT=3>4Dh
<d<b=C93>C8`ASPf=cLh=S12>DI2@dE4<C<e@c16=3Le>393@DI4<DH=>DHh@DA6
>30f<C@bATE4@C@h=CDg@d<d@D8g=CI6<S55=S@d<cA6<34dASU1A4<e@cTc=4@c
<48e<S<h84i43BmH<SDP838g<B1BA20b=4E3@T@`=C=5@T94>4@hADA2@CDdAT54
=CTc<c0`@CTcA456<CA1<S4eAT51=SM5ASDe<356=SP`ASL=@S<`=C95@D8g<THa
=3<e<T<fASTc<C52AST`@S<h@SQ1=dHb@T@g=TE4=44d<S94A3Pe=3Q3=S=3=D@d
3CE2<c56=C52<C92<S@dAS@d=d@a<d8e>C<c=4<hAS<c<4<b>C@aA3Dh=D=2>4Hc
<48e@S0c<cLa<4@g<@e6<30g<cA6ACU5A3A3=c@`@c13AC8gA3Dg@S92AC8d@D@g
<SU6<dE3@c0b=S0g@T@`<CDa>456A4I2>CH=@C4f=3Q2=cHg@d=3AS14<3DhAS92
<34f=4E4=S8d=CDe=cM3>4Dd=S13AC@iAD=5=3@g=cLb=DI4=S563C4e<3@a@dE6
A3He<c0hAC96=T=2<T<g=c0i=d8g=d@f=cLcA48b<S56<T8g@cDb@CLa@S16@CI4
=4I2=`diASE2<d4g>4Hf=T=3<4E5=4Db=S<h@dE2=cI4=SH`@THd@SLfA391<3Dh
<CDg<CPd<c0h=4=2>CPf=DD=<SM4<3=2=4@eA3E5=T4g>4E2=cA5A3Db@S91=3Ha
ATE3@D<a@SDe<S<g@SHg@D@hA44f<SDhAS0`=cQ23DI2<DA3ASTd>3Hd=44fATI5
=SDh<T<a=S8c@D=5ADE1@T@a>CDb@SU6>44g>3U5>D@`ASDe=CDh=CTh=Pdb=21>
A0d_F38f820c=3PPDT@P<SA5@d94<3DcAD8h<c4e<CTaADH`=3M4<C<gA3U5>DI3
<4<h=T<g=DHf<4Db@CD`<dHd>355@TH`>4I53C8g=3De<d=1<C52=dI2=S95=c55
@cU3ASA3=CM6AD4d@CA2<c51<3=4@cHe=cDi=CHa<T8i>DE3<D4c<0dcAC8e=C11
@DH`<cI2@d4iA3Lc@cHbA3@`=cE3@d8`<C<f<DHc=cPb>3Dc=C<i<34a<TDf<3Ta
>3HgA4D==dA3@cQ6@d53<30d@dI6>3Ti<c@g@d8bASPf=D4iACHe=3Hf>DDgA34e
@CP`ADI6<TA4ACTg=SPiACPf3C4c=4H`=D8h<CQ6<cI1<SA6@cDc>34`<CPh<456
=CI2>D@g@cD`<TDbASHbAD@f@c0b@CU6@CQ4<d4g=@e1=d4aA34b=CA2@DDa@S94
=DI2<D8a=4@aAS@a>355@S94>CI4A312=SI5=dDa=3Hd>4E2=cDf=3Dh=S0=<cU5
@D8c=c4f=STi>496<313=cU2>3Df>3Hb@CH`>D=6=CLc>C0c<SDcADA4=48eASE1
=cI5@c96<C0a3DE6@S4e=DDe@SE4AD4c>3M4@dH`<SDi=S8dA3E3A3Tf@S<`=D<g
ASTd<S4e<C0`=T<`ASE3<c0`@cA6APdc<T94=DA1<cA1<c=3>C55AS94<SHeA4Dg
<TE1AT56>C96AS0f@S0e<38gACLf=SE1ADE3@d93<CQ6@cD=>DI6=3E2=SM1>C8a
AT@a=SE2AC=6A3<f@T52<4HgA4@g@d@h=TDiASPe<c=2<T=2>4Dg>D4b<T4g@d8`
3CTb=4@g@CA2@T4b<cTf<cE1=C<a>3Q6@D8h=SE1=CDeAS<b=38`>C56=T8`>CLb
ACDg=D54<cTe@T4eAPdi<cPc>C=6@cPi<cD`A4@d<cM2>44b<cI6<3@c<CT`@SU1
@SPPCT@=;ePb=b0P<c0PDT@P<SA5@d94<3DcAD8f=dDc<cI1@C@g<C@f>496ACPh
AD=6=3Li@CHfA3Lc<3La=S@d>44c<C4dASLi<TDe84i43BmH<SPP834`=B1BA20b
=4E3@T@`=C=5@STg@T56=4E1=SM2AT4e@S92=cHi=SA2AC<`<cTa>C<d@C=6>3Q1
>DI6>C<d=c@d=C8=<S8a=ST`=cU1=cE3=DHe>4DbAT<eATI2@D4`A391=3@d=4Hg
=S56A4A4AC<eAT96ACTbA4<f=SM4=S523CDdAT@e=S@c@T8g=456=c=2@SLhA48a
AT8c<dHf@S4f@D<h<4Hd<D4a=SPf<S0a<C14<DE4<d91=DDhA0de>3Pd<D4d=S@b
<C0h=dE3=4=6>C=1=C<a@c13=cHPCT@=;ePb>B0P<C0d8594838dAD=2A30e<dE2
>CM2@DHdAD4f=3Pc<c8c=313AD8dASTc=d8`<316ASLc=C4fAS4a=4H`>313>4=4
=`e4A34h<4Dh@C13@S8e<C0e<C0a=CTd=44eASTbA30f<THi=D8g=c@h<THdA455
<492>D51ACA1AC12>3T=<CTc>C=2=T8b<SM2@SQ3>CA2<4H`@D@`A3@hA3E3@d@i
@c13<3<h<3TaA354<TDf>4<aASQ4=DDa>4<b3CPg>3U4A44`=dDg@c0c<391@SA4
@C8c=CPf<T8PCT@=;ePb@B0P=c4PDT@P<SA5@d94<3DcAD8i@SQ4AT=6<cHe@dE4
>CHhADA5=C=4@S@c<DHb@CTc@c8a=S4iACHa=C8`@S<h=C533DA2<d8c=4<i=T8h
>3<a<c95=4<iA4I5A34d=392=cDb=dDa=3Q1<D56<cA4<cTa<D4e<dDg<4D`=3Pc
=@e6@d8`AS4d=T<gA3M6<3Df>CU2@CM284i43BmH<T8P83@i8594838dAD=2A30e
<dE2>3Le<d=1=4@fASM5A4A1>DA6<4<cAS94=T<e<cPa<4<a<D<f<SHg=C8a<T93
=4@`<`df@cHb<4Dc<c4`=STd@SU2=38aASQ2<dHhA34a>3M2@D8`@CI4=21>A0d_
F393820g<21BA20b=4E3@T@`=C=5@SHgAC<c=T51=3Hd=T8c>4<c>44c=S<e<4A3
@dI6=dE6=D@g>D@fAS4a<d52AS0d@cP=<D@g@d94ASM3=c13@T=6A3Pb<TI6@cDf
>D<d<CQ6@c@h<T8f=c15=T@g=SLc=c=5@c4bATA2AS0i>D<b3CE1>D<c<TDgAT<g
<CDf<C8h@SE384i43BmH<T@P838f8594838dAD=2A30e<dE2>C8gAD96=c94A48h
@DA1@CTh@c<c<S<c<C@dACE4A3I4<c<hAT@fASHPCT@=;ePbAB0P<SLPDT@P<SA5
@d94<3DcAD8f=dDc<cI1@C@g<CHg<CTg>CM1=d52<dA4@cE4=DDe>C=1@CLg<T54
ADI284i43BmH<THP83<`8594838dAD=2A30e<dE2>CPf>4=1=3U5ADHc@dDc>C4`
@c@`=c<h<T54@T4h<SHaASDb>44gATHd@CI4@d8h=b1>A0d_F3<`820a<cDPDT@P
<SA5@d94<3DcAD8h=cDc@d4dA3I6>316@S4h>394=cPg<S8i>3Pg<d8eADI3>34b
ATI3@SLe=CLb=d<f3D4b<CQ3<3H`@S4c>CE5AC0h=d=5@C@a<3E6<d@g=34h@C0h
>CM4<T8a<CI3=T<h<c@dASE6=SE1ACLg<0e5<T=2<4@cA38h>DI6=D95@c4b<CHi
<c8f>44i<c56=DDhAT@h>DA4>CE4@CM4@CE4A30b=T4e@dI2<T4=@T@`=T=4=c=5
=CM5=SQ6=S96>3Ha>C8`=34i<48h>353<S8d=TE3ATA1>D<d@cD`=44f@S8a@dHd
<cPa3CU1=T8a<SLf=d<b@S15<c4a@cDb@c96>D4i@S<c>21>A0d_F3<a820c=B1B
A20b=4E3@T@`=C=5@SPg=C=3@CA4=THh<THh=CTf=3M3>34d>3<h@SQ5=3Tb=cD`
=S54A4I6<cLb=T8d=cT=<DE5<cLf@D@b=21>A0d_F3<b820a=CPPDT@P<SA5@d94
<3DcAD8h=cDc@d4dA3I5A34iACTc=S94>CDi=C0aAD4g=cI2AC15@D8a=3Pa>395
<c51@dD`3D51<S92=T4bATE2=c11>3A5<D56@S4dA3I4>4I2A3Q2=CPe<D94=S53
A4Dc>30e@c@cA38eA4@`=d8`>0dd<44h<SE1>3U3@CI5>DE2<c0i<30b<3PdASQ1
A48i=3PdADI4@TDg=494AT@c<CPe<d4gAT8c<T8a=4H=<SU5=STc=D4c<S=4<CTc
@CI6<3E6=cHe<48e<TI4>CQ2@T@e<cI2<CI2=DDc=c<d=c@i@c0d=SE5<T@g3DD`
<cU3@cPcAD8h=cI5>3Tc=cA3=d8f=CI5=c8`<DA2<4Ha=S<b=S<`=cDdAD96@CE6
ACHdAT<h<CPf=0da@SPg@S<bA3PiA3E3>C9584i43BmH<c<P838c<B1BA20b=4E3
@T@`=C=5@SPg=C=3@CA4=THh@T8hAC94=cA2=30b<44d>3E5@T8b@dDf@cLb>353
AD@a<TE6=C<=A4<b=SM5>3A1=cTi>CPa<ST`A391<D4cATHc<4<a=4<d@CPi<SDa
=4@i=T@h=3Lc>CHf<c8g<4E2ASM23CLcAS0h=4Hi@S0d@c<`<cLf@CM6@THfASE4
AC0fA4E3>C<d>3E5=CQ4@S14=cPfAD@h@S@c<C0i@d<`APd`ACD`@c14=S<aA312
<D@a<4E2=3M5=T4d=D4fADA6ACA6=TA2ACA5=SHd<CU3A4@`AT51<394ACL`@c0=
>3TgA4@d<SI3=c<b=DA1<d<e<492>D<d=d4h@cU5>DI5AS16=CDc<dE1ASTi<3Li
<cThASPe@CDe=DDe3CE3=cHeA3<f>D<g=cHh@C@b=4I3=S=2<THe@d93=c4h=cM1
AC=3<34hAD8i<4A4@c@`@CTa@S8`>C4e=`df>CPg@dE6ACHe=CM2@DA4@C0`=3<g
<S=1<DE1>CA2<C8c<DDd@SE6AC0g=S8b=STcAS0g@C=6@dHc=c0=A491>C=5=C<f
<CTaA4<f<T@f@D55=d53=SLf=S<c@TA5=314AS@e<SLc84i43BmH<c@P83H`8594
838dAD=2A30e<dE2>3Le<d=1=4@fASLhASLgAC15@dI4AS92A4<a<CHi=cI2=S12
>4Hg@c8c@SHd@DDc@@e4>3Lf<T=4=DA6=c51=c=3@cHc=D4e=38a<454<44c@cU4
@d<b<S<d@d4f<D56@S16<4I1<TA1<493=CHPCT@=;ePc=B0P<C<b8594838dAD=2
A30e<dE2>3Le<d=1=4@fASQ3=T54A4Dg@cT`@d=3=T55A3I6AS8a<d@a>4Hg<c@e
A4Di@STb=@df>3Pf=STbATDb=3A2AC@b=SPd>DI5@D<h=T8gA393=4Hb@C<d@C8b
<S8g@CQ6<3Tb=38fA34a>DHa@d4=@c8e<4Hc<D4h<4=4@C16<355@T=5=d<hAT55
AD<i=CE5=D@f=3U3>C@a=cDi=3@hASDa>4=2=D55=S4a3CHc<D@g=d<g>451<cPc
=44f>3U2<4@f=3Pc<d@dACL`>3I2=SPf@SI3=d4c<C93AT<d<d@e=cHdAT=5A@dg
<cThAD=6AT93@cPi>3Ha<T52>491A3<PCT@=;ePc=R0P<S<f8594838dAD=2A30e
<dE2>3Le<d=1=4@fASQ1=SL`@S51@SL`AS53<d@`@d@d<CTa>4@h=d53=cE2@D8h
<4Hh=0df<30`<CE6A3Pi@c0c>44h@T8c=30a=SM6>34a@c<d=D8f@DA1<3TfAD4c
>C=5>C=4=495<T<c@SPd=T4=AD96<C@`AT96=4Di=30c<3M2@cHd<D<aAD8f@CPh
=DHd<CTfAS4a>D54<cP`=D54=d92<3T`<CTd<CE53D4g>CQ4@SI3=d@a>392@CA3
ASPdAS@b<THf<T<d=C4h<CDcA4DeATHa@SQ6<cLb=STa@S0g=452<S<d>@dc=cH`
=cI3ADHe<S0hAT54@TA2@C8d>3A3=d94@cD`A3@f=cHh<D8h=356<T4g<4E5<4E4
>C<i>DHdACT==c13<SU6=D55=3TeA3Le=SPi@C14AC4gAS<dASE3@S@b=C<b=3Li
=SH`<dA5AD96>DA1=3Hd@d@fA3933CU6<4Dg=dHf=CM6=dA1=4Da@T95>D=6<D=6
<c4fASDi>38a@dDa=dE3A3DcAD@h=c91>CA6<353=D@d@@deAS11<d@`@CI2ADHg
=S0b=3=4<TD`=T@d<3U4<C0e=d92A44iATA4>CI1@D<b>4@c@d<h84i43BmH<cLP
83Pf8594838dAD=2A30e<dE2>3Le<d=1=4@fASPd@CA5=cI4AC13@C51<S@b=396
>CE4=C4a=3A6=c0eAS0a=c4b@Pe2>D8hACA3=30d=D@eASTg>DDh<SQ4AT91<C<i
=dE2=T4iA4I5<c51>3Tf@SM6>38f<C4c@d4h<d@a<D<=A3@i>CTi=T=5<SA6<CLh
@T<e>C4h>D<c<C@cACE2<3DhA4=4@cE4@SU3ADHi=S13=cDa=B1>A0d_F3<h820c
<3DPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=cA5<4Hh>CQ2A34`<3P`=4Di=455
=S<g<S8iA30f<d92ACTi>CE53C8f=CQ5>C8e=4<fA3U2<3Pa>3A2=493<3@g<d<i
A3D`@c0h@c4cATD`=c54@T94<dI3<C4i=SQ1=395<0d`<3=6<4I2AT<aA4<g>4=5
<c0iASE5>C=6>CQ1>DDe=DHb<cE1@S8dA4=6=3Hc<TDf<SU1@cPe@dE5<c0==D8c
<cI4>D93>C<`A3Lb<c=4@SDdAS11@cHc<D8g>C15<d56@DI2<dI3=313ADH`<C@b
=3=4>DE1<DA53C55=34`<c8h=c4fASU1@cE3=c8h=CPb@STi=3Lh>D=1<SHa=cDa
ACU5<DHh<4Hc@c0a@DDh@SI2=cLf=Pe2@cLc<cM3=TI3>48a<393>D8d=C<e=DA2
@cM6<3<g>4Hf@CLb<CTc=d<bAS53A491=cHb=C@e=SHe>DH=<SQ3<c93=c8a@D4h
=D=6=CE6>D55>493@c@a=S56@C@h=S0a<D<f<dD`=3Di>4Db>4=6<cPd<S4`<CM5
3CM3<3Li@DA1<CH`@TE6<d<h=S95<d@a@c16<D@c>3PdA4<f=S4fAD8`<3Ph@d8b
=3I5<CI3<CDhACA2>@e5AC4e@D@e=DDd>3<i=CHh<c16<STd=dE4@dI6@STgAS0i
>3Q6=C0e<dA5>495A44c<3L`@T91>393=TD=<C14A4I3AC54AC8h<c@e@CU4<CM4
=3Ta>3Db@DE2<dA6=T@c=C16ACI5A3Q1=d@d=3LaADDe=4H`=c4i3C@f=c@i@d52
=C@PCT@=;ePc>B0P<S<f8594838dAD=2A30e<dE2>3Le<d=1=4@fASLf=3A4<T52
=492>3Tg=d95<T@f@cQ6>4D`=CA1>D=3>C=3=STaA0di=d8`=S4f=cE1=SPaA3E4
<4@a=DDg<CLi@d8h>3Dg@dE6@S@g@cHbADE5=CTf<cU2=3Tg<c=4@cQ1@c0==SM2
=cPi=c<e>D=6>C@f<c<iA3U5AT4e>4Hg=30g@CA6=48g<SHd@C<f=TI3@d<g>D=4
=3U4@SDh>3=33CE3=C94<cT`=3@c<4H`=DDc=c13@cDd<CM6@d55<d52>313<CLa
<S4h=c@h<D51=3Ha<cHh<ST`AD@f=0da<T=4@D@`>30f<cQ1>D@c=4<e@C56<T@f
<3Lh>C4`<cI3ACHh=DDcASA6@SHbATE4ACA2<4I6AT@e>4H=<CI2=4Hg>4@`@SDb
<d8b@S4b=C0d<T4i>DDf=d@f=cI5>D@g>4@`<CLc<S4i=dA1>D=5A3Da<THf<CQ6
3D@g<c0b@c13A4I1<cU5<d8g@cPb@c0`@CPb<cHf>CI4>CM4A4A2<30h<d@`<SPa
<S14=C<b<cHd=c96>0dh@c55AT8i@S<c<dI5@S53=cHg>C8bA3A6=cHb<cDg=S8e
<S56AS8h@C4e=C51@D=3A4<d84i43BmH<d4P83@c8594838dAD=2A30e<dE2=SM5
<c<f@D4d=c4f=c4i=cTg@CM1@S=4A4<eA3E5=CTc@D4g=c91A4D`A34e=3=3<0e6
<D<b@C14>4De=3M2=CQ6<c4`<313AD@g=b1>A0d_F3=2820h>21BA20b=4E3@T@`
=C=5@SHgAC<c=T51=3Hd=T8c>4<c>44c=S<e<4A3@dI6=dE6=D@g>D@fAS4a<d52
AS0d@cP=<D@g@d94ASM3=c13@T=6A3Pb<TI6@cDf>D<d<CQ6@c@h<T8f=c15=T@g
=SLc=c=5@c4bATA2AS0i>D<b3CE1>D<c<TDgAT<g<CDf<C8h@T4e=D96=c@iA4Da
<SDa>CHd=48a>3E6=cDa>DI2A3I4AC@f<cA184i43BmH<d<P83@a8594838dAD=2
A30e<dE2>3Le<d=1=4@fASM5A4@eAT92>C4a<CLa<C4i=S0e<3=2>3TaASDf@DA4
=cE6<C8i<0dc<352@CHi=T@e=dE6<C0b<TDi@cE684i43BmH<d@P83@a8594838d
AD=2A30e<dE2>3Le<d=1=4@fASM5A4@e=C14ASTi<DHg=c<fA3Tf<SPc=DE1>CDb
<S0f<3H`<314=Pd`>3<g@T4i@D8c>3Pb@CTf@d8e<C5184i43BmH<dDP83<h8594
838dAD=2A30e<dE2>3Le<d=1=4@f@cLgA30h<CH`=C95=4Hh<38i@cDd=c0iAT=3
@CM2>C0dA4=5<cE4=@e3<DHg<THb>D4i<S94<C4f84i43BmH<dHP834g<b1BA20b
=4E3@T@`=C=5@SU5=3@`<C8e=cU4@dDiASI5=TE4ACLh@CDfAC56<c<b@c@f@C94
AT8`=4A4ASLf@D4=<D@bAT=4@T<a=3L`<STeASTb>30g<C51AT@`=d51AC11=495
ACI5<CTc>CHb>D4i=3E5@D8aADDc=cDi3C51@CLa<C<d=cPg=D=6=C95A316=D4`
=dE2AD8eADA3=c52=CE2ASDh<DA6<CA4ASE6=3=2<3Pb@C8b=`e6=4=1=T<a=SM3
@cTe=dA5<TH`=S4`=THi<S93=492<cQ1=d8e@cDgACH`<3Le=4DhA311=3Ld<D=2
AST=<C@`A4I6=DDb@S8f=TE2A3I4>4@c<d51@dE3<T8g>DDg@DDc@CE4A30aATHi
=TA2>C@b<cU1<d=2A3Hi3D<c=34b<4A1<3@hACU4ADDb>D8g>4A1<3=4A394>C=6
>CI4=4=2>3@dASI5<30PCT@=;ePd<20P<c@i8594838dAD=2A30e<dE2>44a@C51
<D8i=DHa@S0e<3Th=T=4@C0a<4E3=c@d=C<i@CQ6@S@cAS<i@CPaA452@@db=4I6
A4<d<4I1=T@h=S<h=S@dAS95A3<b=SQ6=dE1<c8eAD@c<3Hc@SU2=TDd<30e>D8c
AC12@cQ3=3T==SI1>CPcA3U4A4Dh@C4b>34c=C<i@C12>D8`=D95>3LbAC<dADHf
>4@hAC<b<TI6<cE5<T8h<D4`=d963DHc=34dA3I1@SI3=cM5>44b<CPi=44gA3M4
=34e@T<f=D8d<315=S8iAC@i=dHbAC@b=TA5=DHgA3PdA@dhATDe<cQ6@C13<CDd
=DI1=C4`<S@g<TI1A496ACPg=T8h=cHe=SQ6AS0`>3@c@SD`>CDc<T8i=dHiA4@=
A4Db<c<fACI6@cTg@c94=D4g<4<c=S<b<CU4=30c=cE1<CU4AD4i=3Dg=DE2<SHd
<d54@S0c@SE4@CH`3C92>4I4<c8cAS15@T<`>D91@C<d=cE4@d<c>30h=SPc=d4g
ADDe@cA2>48dAS=2@CU2<dHc>CQ4<T52>@di@CI2=S4i@DE5AD4b=c8g@cM1@CM5
@T=2@dHa@dDg@cU3<S0gADA3ASL`>3LiA3E3ASU1A3D`<3PeAS@=AT<c=dI1@S@g
@c8h>496>455<DE5>C<gA3A1=c13=S0`=SM4AD=2=dE2=T4a<4A6=3Pe>C93@C93
=30g3DHb=S=4@C4i@SD`=SH`=T4`@CM1<SQ6=394A395AT4e@c15@T@c<d@c<3T`
@D<dACA2@cQ2=SM5@TA1>0e2@c8`<d8hAT4g=T4g=C8fAS<eAC0hASDd<SA2>CLi
@C<g<C=5ASTaADE2>C8g@S4i<SA5>D51A3A5AD8=@T@d=C11<TDh=SA5<cPd@cPd
=3<e=dHe<dI4=CHgAC@g>351<4<PCT@=;ePd<B0P=S0PDT@P<SA5@d94<3DcAD8h
<c4e<CTaADH`>C4c=CE5=S<a>D@cASTa<C0e=S53ACA1<T96>3I6=cM4=c52<D4c
3@00X@30?oli<dHeAC4dAD@f@cM3<d<g@c8b>D4c=dI4AC<d=cQ2<d=2<T<a<3M6
AS<g<T4e@c@c=S<h<S4b<3<f=SDPCT@=;ePd<R0P<CTa8594838dAD=2A30e<dE2
>3A1>3P`<cPd=d56=T4a<CHf=S16=d4d>3He=dE2>392<S0e<D55=C4f=dA1<TI1
<Pdc@dI4@CQ4ACHe<CU2=T<a@CTh>CDa<D<e=dE3@C8fASLi=3M6@SM3<SM5@THe
=cLhASTb<T<e<4De>38=@cQ4>34g>3Pf>44a<S11<cU6<CPc@SHb<D<h=S@dAT8f
ACU1<D4`>3Hi<DE1>C4b@cDc>DHc=D@i>48i3C0e@SHf<44f@T4c=3<d=cA1>CTg
@T8i=d=3@TDg=c=6<cTh>3Pb=SE1A4Dh<DE4>C@g=cH`=SI1=C4b<0daA316<S8f
ASHc>4A1=CM4>4<hAT@e<CDi=T<fADDg@S<cA3A1=c54<D53=4E3<SHa<dE5<3Th
ATHdA3T=>C15@CU3@d53@c8b=dDe@c8`>C@`>CU5<d8aA3Tg=d<a<48d=453=c<b
AT56=dHb=C<gAS92ATA3<d=43C8c<SDi=STi=3Dh=44hAT=6@C4c<cDPCT@=;ePd
<b0P<CHd8594838dAD=2A30e<dE2>3@e=c11<S0iASI5@SM5>3D`=cTdA494@SPc
@T8c<S55A4I4>3Q3=3E6<C0cAD55A0dbA44b<48c=CDh<S0f=STh@CDg@cE2<c15
A3Q2<d<f@CLi@S12@C<c=SA3=S=6<C<h<cE5=S4hAC8a>38==c16=D@i@S<`ADHg
=4E6A3Lc=D94<T=6@SHh<cDb@CE4A3Hh<T@`<456@CTdATE5=44a>3E6=4Di@T<b
3D4eAS54AS4i<D<`<D<aA3Df@dA6=dI4>44g<S@gAD4`<c<cASQ5@C@d=C=1>3A6
<c15=SDe=cQ1<SPfAPdfA3<e>CPeASPh<cA1>D8hAT92AC8iACTh=3<a=CQ2>D<b
AS=1AC52<3<h=TE2=cPgA48hA3PiA48gA38=AD@g<cU4<496>4<`>C4h<SQ5<dA6
AT4c<C96=R1>A0d_F3@d820a<S0PDT@P<SA5@d94<3DcAD8h<492=CE1AT8h=3Di
=3E4A3Dg>D92<C<d@c4bAS0a<TD`<DHg=S56@D4g>CHb=4I13CE1AS@h@CPaADE3
<SQ5<S0aAS<a@DE6=d8d=cM5@TE3>CLc@c<d<T@f=SHh<TH`>4De<c96>CE3A48i
@Pe2=CM5=c53A3Pg>CU2>3E4<d8a=S4i=dDeA4I6@C0b<THc=351@S4c>CPh<D<i
@c8c@c96>4I1=dA4AS8=<D95>4Df<3E5<cU5=T8f<SHg<CL`=3M2>3M2=C@c=SLg
=c54=DA6AC55AC54@C4f=SQ4<cPh<T54ADI284i43BmH=3DP83@g8594838dAD=2
A30e<dE2>DI3@D4`=c4e=4Hi@T8`<4@iAC52=4<`@d@bA3H`<CA4AS@cA3Tc@c16
<c53AS@b<Pe4@T8`>38a<S=1=c0`>3PgADI5AC56=SA5ASDb@T4iA31284i43BmH
=3HP83@a8594838dAD=2A30e<dE2>CTe>C@b=CTd<CI3=44g<4I6=3A5=44b<T4e
ADHc<4A1=d8f@DA4@SHb>C=2<cD`A0dc=S16=C0h@dE4AC<g=S8i<D@d<48e84i4
3BmH=3LP834f<R1BA20b=4E3@T@`=C=5@SPf@dDb<CLa@D4i<d4e=cDaA34f>C8g
=SQ2=CM2@S8`AS<`<T8`=SQ5A3Tg<CT`>CD=<d@a<CDbASQ6<T@i<3Tf<CLh=4E2
@C8f=SI1=S8bACDd<d@e<CM5@CLg<CI4@S=3=S8i=S4f<d<c=3E13CU4=SQ2<SI4
@D@h@SL`@cPdA3@f<3Q4@SE6@TDe@S@eAD=3<3Pa>3@i=S0a<cL`>3E1=3HbAS16
>3@i@`dc@D=1A3Hb=d51<C12=4E2=3Pc=C@i=3U6>DE1<d@f<S0g<SQ2AS=3<CLi
A3Ld<SPc=C<g>312=c<d<30=>D<g>4@h=SU2=D<hAS<cACM1>C=6>34i=4I4<3Td
=c8c<C0b>3Th<SHg=THd=T54>3Q4=3E4ATHf<cU23CTh=d@`<T8i=STi>4I2A3T`
<3U2@cHfA21>A0d_F3@h820d=b1BA20b=4E3@T@`=C=5@SPaAT@d=T8`=CLeA3Pd
=cM4<cM4<cE4<cQ4<3Dd<D8e>DI5<3La<THb<TE4=S4i@T4=<38b@C<a=cLd<c@a
=352>C4`@C@g=4=6=d8e=T@g=S=5=21>A0d_F3@i820b=B1BA20b=4E3@T@`=C=5
@SHc@S<e>DE5=3@`<c12>CQ1=c4`AS4`=d93=SQ1<cI5<S15@CDi<R1>A0d_F3A1
820a<3LPDT@P<SA5@d94<3DcAD8i@CQ5=T<hATE6<CHg<d8b@c0eACDc<cU2<cA4
@c92<CLc=3DcA4E1=c0g<TDh@DDi3C=5@c@`A455AS96=3=1=3M3>C8`@SPg>3Q6
=S<g<312A3<iA3Hc=cLg@STf<cP`<3Lf=C@g<cDd<T<d@Pdh@C@b=4<gAC=1@c0d
A3<g>4Ha@S93ATDd<cPg@TA5>C0gACU6ADHb=CE2AS@g=dDeAC8b@D<i@STc<c0=
=452@c11@c0iA3@a<T@fACLb<dA6=d<gAC4h@c0hA38aA21>A0d_F3A2820e=21B
A20b=4E3@T@`=C=5@SPg<DHe=cU1<D8b<d52=D51<SDaASQ1>3Li@SPbACI5<SLa
<SE2<3Te=3A6AT54<cT==4Hg@d51A34`A48`>3Hb>D=2<c@i=44h@TI5=c0a<CP`
=496<C=2=4A1@TA2<T8c84i43BmH=4<P83<`8594838dAD=2A30e<dE2>DHc=SPf
A3@g>3Hf=CDf=SLdA3U5<C@gAT<a<D@f=CP`@cHiA3E6<3I1=dD`@CPa=21>A0d_
F3A4820g=b1BA20b=4E3@T@`=C=5@SQ6<THa<4<a=SLaAT4g<T55<T8dA3U2=d<c
>C55<cPg<d@h@C8`=T54>3Ld<CM1=TH=<352@cI6A4I1=3Lc@c4f@D56<cPg>CA4
=cA2=SDcAD=5@c=6=454AC8`=SHeAD<g@CLgAC4b>3=2=cE33C55AS=3=SDe@TDg
<c8h=S0f<C=2@CLi@S0`<3Ta<cTa>C0PCT@=;ePdAB0P=CLPDT@P<SA5@d94<3Dc
AD8h<38g@S4e<d4b>48a@D=2@C55=4I2=3=6@CLaA3Te=c13>4=2@dDcAC95=SPb
<3Q53C8f=C4a@TE4<cE3=4I4<4@g>48b<4Dh@C=2=3=6=CI2<cM5=S0h<CLf=38c
=30eA3A4=cQ2=B1>A0d_F3A6820a<cDPDT@P<SA5@d94<3DcAD8h<SU5=3@d@S0e
>DHi=D4aA3@aATE3<3E5@C8b@D4a>D@c=48e@C12<d<gAC8`<34b3D@b<D<g<D4h
>D92AS8i<SLh>4<c>38g=dHg<T4dAS55ASQ6=C0`<CE6=cDa<355AS96>D4h>4A4
<354>@e5@D4i<DE1<T95@SL`AS8h@CHbA3A5>34a<C<h<D=1=cTg@cH`=SQ4=cQ2
<3Lc@CTf@C@eAD4d=CLa<d8=A3A2=30d@T93@dE1@S8f=3@i=3DfAC<c<SU3=S4h
<T95AC@fAC=2=c=6=3=5<3U2<3Dc<D55AC@c@D@g3CE5=c<`=3Q6@C8a@S96<SLb
<44a<SPi=3Hh=S<f<b1>A0d_F3D`820a<3<PDT@P<SA5@d94<3DcAD8iAS<f>3I4
=3M1<S<i<4E4<4Hh=D=4=SLf>4H`=38b@dE5A4@h@S53@CU6=D=4=C4c3C0a=T8d
>44iACDf@cU5>3M3@DD`ATA1<cI5@DA2>CQ6=dDc<3Th=CTg@SLd<cPa<S8g<D@d
=CQ3<CI6>0da>D4dA4De=SHd=C8e=4D`<3D`=CHeACHg<C<`@SHf=38e<3M1>D4`
=D8i=3<b>4<i>3Tg<cTfAT@d<DH==4=6AC@e@S53>CLg=D<b=d<c=c4e>34`@D8P
CT@=;ePe<B0P<CTa8594838dAD=2A30e<dE2>38iAC@d=48`=CU6AC@d=D8fA312
<3Lg<dE1>3Hc@cHdA3Pe=cPcAD@bASLb=S8`=@di<cDa@CM5@C<e=c4i<dH`=D8b
@S55<d@h@D8g<T94=C14<d<i=D@f<cLb@SPb<SHe@CTd@C<c=4@c<T@=@cTh>D8e
@d<`=c91=cPg@c4i>DA2>CPf=c8d=3<i<SPd>CDd<SLi@cDf<4@b@d4a=DE3AD4e
AT@i=cLc3CQ4>3Q4@S8f<c<c=c0h@CPd<4Hb=314A3I4ADI5@d<`<TDi@CDi>351
@c@d<S51@TI4=454A38hAS@c@Pe2=313ACU3AC=6@CDcACTbA312=c4c=D4c<4=3
=3Tb@THb<cA4AT55@DI2<3Lb<CH`=TA4@C<iACPc<TH=<cDhA4E5ADHf=T@e<3=3
@SLb@cE4>396@c4h<dA3<cDhA3Pi>CI4<34d<c<h>CThAT@gASE6@CHb@DI43D<b
@D=1=T51@D<f>DHb<cHb<d8g=cHPCT@=;ePe<R0P<CHc8594838dAD=2A30e<dE2
>DA1<c0b<C@b<c8fA3=4@dA1>D55<cDe=4Ha<3HaA30f@SPb<356@C<`=S@e@dHc
>0d`=DI2A4@g=dE1<D@bAT<fA3U1ATE2=D56=495<d=4>3H`<4I1=c52AT<dAS12
AS8aAD<b<dHe<CU3<C4=A4A6@d<i<cQ3ACHa<SLc=S4a=cI3@D4i@cU2=C8i@DA2
=T4d@T<g<CHi=353<CPg<c0`<c=1@CQ2@cH`3CQ1<STb=TA2>3Ti>CDiAC96@DDi
A456>34`=d8h@C8a<d@f<T54>3I2AS51@D4b@SE2AD8`=3A2=SP`<`dc<SM3AS4e
<S<`@S8c=SI1>48a@DHg@C0a<c16@C4h=c<a>D95@d@`=c8f<T4b@c8e=S8a<cM5
@DI1>DD=@dH`<c94=CPa<3Li@TA1<3DbASE5@c8cA4DPCT@=;ePe<b0P<S<g8594
838dAD=2A30e<dE2>DA1<c0b<C@b<3E6A351@dE4ASL`A44d@dDf=CPd>48c>CI3
<cHi@dD`=CTd<D=2=0e3@d4a=DI4<c@`ASHhASQ6ASQ5AS8i<34`=dD`<STe@T<h
@D51<cI1@d96>3I3>CHf=d8h>CHc<34e=44=<S56<SI6>C93<3Q5<DDh>C<g=S8b
ASDc=44`@S95A3Le@C0gACT`@S0g=cQ2<D@f=CE4@SH`=d<f<D<b3DDd@STe@S=2
@c<f<D4`@c<b<dE3<S8a<D4dA3Hc=3HbAD=5AT=4<S<d<dHg@S0a<d8h<44i@T@d
=c0h=0db<S<d>4<a<D<a=STd=D@g<3M3<48`A4@i=C55=38g<S55=CE1>CHa>30d
>315>C@g=D8i@CPf<cU3A3P=@dA4=c56@c<f=c95>30bA3Te@cQ3ATDe<494<3Pb
@C<b@T55=c4c@TDiAD8aASE2>4=6<S@h@CTc=T923CQ3>3Q2>3E5@CHd@D4c=c@f
@C<c>4@f>456AS4d<CM6@C8h<d<`<CA5AT96A312@c8hADHg=3Q2A316<0e1@S8e
<c4b>C8iA4E1AT@i@T92=D<h<S12=d<i<3Tf<44e=3Lf=CHgAD4g=TA1>495ACM2
=DHPCT@=;ePe=20P<cHPDT@P<SA5@d94<3DcAD8h=4E2<S@d=C91<30b<c4h=CPe
<34c>C=2=C0g<396A3<c<cLg<SPg=T4gACTa>C@f3DHi>3@a@D<d<T4e=B1>A0d_
F3De820a<CHPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I3=cTb=C<b<cE5AS@c=c94
<S4`@C55<dD`>3HfA3Q3@T@i<S0e<4Hh3C96<48aACI4@C0g=CI5@cQ6<391<3Pb
>C@h>454<CA6@SM1=TI1>CLd=3M3=D8a<D=1AS@a@S0g=3Ha=0e2@SA6AC52@DI6
>3He<d54=3P`=D95<44b=T<aAD4`@TI3<4@a>3A1>DA6AD<h=DA4=cU4=dE4<S0`
=CH=>D8b=D=1<T@eA38g@d54ASHa=cH`AC<iA355=353@dA1>CLi<CQ1=D8e@DDd
=cTe=D96<b1>A0d_F3Df820d<b1BA20b=4E3@T@`=C=5@SPc<CDa>C55AS0e@d91
<c@d@c94>CL`=391<3<i<d<b<STg=34h<44i<3Pg=D4g<CP=>34e>34a>D@e@T@`
>392=DA4=dI1>3M1=TDPCT@=;ePe=b0P>3TPDT@P<SA5@d94<3DcAD92>38g<DHb
<cTa=c0d<3A5=d8i=SQ2@DI3@d@gATDi=44`AS4b=c55>3@`<30g=D=23D@d>D8`
=3Td@SHbACHe@cDdAC0c<TDa@CA1AS13@T8`A456ADH`<CI2@dDc>34gA38i>48e
<cP`>C=3<@e1ASTb=D<c<CTbAS0h=d4`<T96<4Df=C<g=SU2=d8g<S8iAT=3<dA5
<44b=T8h<T=2@C=2=3Pc>D<b84i43BmH=CPP83Hd8594838dAD=2A30e<dE2>DA5
=d8`=T4h=cI1=C=3@SDi=C4e@TA6=4Db>4=4>CI2>DDa@SM5>3Hf=391@d=5=`e4
=T8`A4<b>D8i<C8i=3Le=c53<T<f@SM1@SE2>C@dA4Df<C@b>4<cASM2=3<i@C<a
ACI6=c4i=D=1@DD=<495<C4h>C<PCT@=;ePe>B0P=3PPDT@P<SA5@d94<3DcAD8i
A4Dg@S0f@CPg=SDe@TD`@d92=34g>C4dA34`>DA5A4Dh>CI2@C16AD93@d<c@SDd
3CPi<d96<C=2<3Q6=SPf<48h>3@i<D92>3M1@cA1=T@eAT@e<R1>A0d_F3E1820d
=R1BA20b=4E3@T@`=C=5@SU6@d51<3La=CHdA44b=S96<C@a<4I3ATDh=391@DE3
<cM4>C16<SA3<cPa=T8b@SL=@CM4@S0a@STd>CDg>3PhA34h<cT`A3@c=315ADE4
@d4PCT@=;ePe@R0P<cPPDT@P<SA5@d94<3DcAD8i=d91ASA5@CHg=496ASLcA48h
<C=1@d<i>3<h@c0e<CLe<D56=d55<DDg<d93@C<b3C53ASE4@cQ1@dDh=c53<cTP
CT@=;ePe@b0P<c4PDT@P<SA5@d94<3DcAD8i>3Hh@d4d>DE5AS=3=TDhA3LiAT4a
=T<h<cTg=cTc<cA4A495@CE6<S8i=CM2@TDc3CHa84i43BmH=D@P83<h8594838d
AD=2A30e<dE2>CM2@DHdAD4f=S4`>491<30fACLc=3=5<c54>CQ5=S54<cE4>3Pc
<3E1=SPdAS4eA0d`<cHc@C0`=3E3ASDg=3U684i43BmH=DDP83@a8594838dAD=2
A30e<dE2>3Le<d=1=4@fASM5A4A1<dDeATI3ACP`AS8i@S15AD=2=d=1<CI6@THi
AC4e@C0b>0e3=SA1=d4c>316=S11<SHb<SM1=T4f84i43BmH=DHP838e8594838d
AD=2A30e<dE2>3Le<d=1=4@f@CI6<44h=3Q2<c<fAS<f>D@a@C<`>3@iA3Hi<S<h
84i43BmH=S0P83<a8594838dAD=2A30e<dE2>D=2<STg<T=2<3Hf>CQ5AT4b=C16
@CH`<c0c=cI6ADE6>3<i=DA5@DHd<d<f>C<i<Pdg=b1>A0d_F3Ha820b<c4PDT@P
<SA5@d94<3DcAD8i>CDi=38e>C@cA3Hi>C8g<SA4>CU2=3E3@cU4<D8c=cTg<3Pc
=30c<C@`<dE2=DDf3CLc>38aADH`ASQ5@THe@C=6=CTi@S8i=DDa>4<i>38`>CU4
@S8b=cQ3@S13ASQ2>391=S0e=DDf@cQ5<0db<3M1<S8a@T4h=4@i>4=6=D@bAC0d
>4Hh>C15@DA1>392<cDa@SLa<3Lg=d4c@D8d=T8c<4Hg=c=3<d4==D4bASHb=C4f
@CLf<C=3>3Q1=d<i@SI3<4A1<S94@c4gAT=5<S0`=4@h@STb<CQ2=C8i>3Q2AS8e
<DDh3C@d=SA5>D8g@cDa<D@d<4H`AC13=34a=38h<c8g=C92AT<h>CPh>D@bA3<f
>4Hb=C0cA3<a<SI6ASPiAPdi>C12@CTdAS@a@SA3<cPg@S4h<DDe>3Tf=C0b>CM3
@D=4<S@d<4E6>3Td>D@fASA2ACTdADH`<S96ASD==44f<T@fAC<d=d=4<d8e<4I6
=3<b@TDd>D95=3Pc@dHa=CQ1A3E6@dHf<c91=c=6A3<h@TI3@C13@dI43D8c<DA2
=C4g<S52A44h>DDg=TE3=cE1@d<b=4=6<SDg@d8i=dHf@DE2=R1>A0d_F3Hb820b
<34PDT@P<SA5@d94<3DcAD8iA4Dg@S0f@CPg=SQ4@cHfAT51AC@g<d4e@CLc@T8e
A4@e>3Th>3<aAT4b@c4b>3<e3D8a=dI1AC<h<C12AS0`<S@d<SHe=D4d=4I5=48a
AS52<38c=TDh<d@h<S0d<T53=4Hg@S52=SE4@C94<`di=S0g@C4d=44fAS8e<D=6
<3E5=C11A3=3AC<d=d@`AST`<4<g@S8b>4<aA3Hb<4I6=SHh@d91A3E1<4@=<S4d
<S0a<3Tc<3PiAC@`@D@a<3I4ASU1@c@i=cQ6=c<h<S8c@dHgA38f>CDc=CU2@T96
<T4d<354<dDe3D4e<T=6=cTe<SHg@c@`=dE2AC8e@TDb=CI1>C93<C13>C53<cHg
=TDhAS0g<D<i=3<e<3Pb<cU6=T<f@`e4AT8i<48e<STc>4@e<dHeASU5@CDc@D8e
@d4hA3<e@T4f@SA4=THa=C11=4@i<4HdA352=T4b>D<d<cH==c0e@T4i>4I6>D@`
<T@e<3=4=T4c<T<a@D<b=TI4<3LgAD4f<CHf<c1684i43BmH=S<P834e=B1BA20b
=4E3@T@`=C=5@STiA30`@C4c=SE3AS@gA3HfAC<iA48a=cTa>D=5@cDi<4E1>3De
>C11<cDb=cE2>CP==3Pe=C8e@D=2<d8d=3H`<CHbAS0e=S<`>D53@T=2AD@e>4@e
=dI4AC8f<3Pg<4E5AD<f<dI3@c55@SE53CHg<T95A3<f<4A1=4@eA3@g<3Db=cE4
<311<CU6AT<i>4DgAT<b@cLe>C4hASM4@TE2@c@cATHd<dDh<@dg=c0e=S@d=C14
=cE4ADE2=CU1>451@cTi>3U3<DDiAC=1A3A1>34h=3I1@CU1<S55>CA4@TI1<cHf
=4H=>3=5<C52<4I3AC<g=D93>3M4=S<`>4E5=cPg<dHi@SLd>C53ASE4@cTi<SQ2
@S11<d<i<C<c=3=6ADDd3C4g>4E1=SPc=SLPCT@=;ePf=20P<CLc8594838dAD=2
A30e<dE2>D<f<C4a<DE1@SLd=cM6A4I6@C@h<cLa<D@e@d4g@S4h=S@f=C54=38h
<d4h=C=1<@e5@c<b<cHbACU5<CE6>C<`AD8h=T4h>3Ha>C55=cU3<356A3A2<SU6
<STcA4HhATH`=44a=TA2=4I5@CP==48`@SU4@CQ1=D93A44a<S4d<T8e=c4f=T4c
>CTcACTcACI1A3@a@cTf=C0`=C11=c8e<C=4<3Tg@DA53CM5<c52<T96>48h>DE1
@cDi>CU1=354<c8eA3U4@cDd<T<e<SHe=4HfAC<i<D@e<494ACE2<SU6<S11>0de
=4I4<44cACU6<S15<4Di=3@i=d@i>3=2<S0b@cDiA3Hh<D<c=SE1@SPf@c4c>D@d
=C8fA3Q6A455>38=<CLfASI5>44`<311@C8f>D91<d8a@CU5AD<`=C56=CLd<d@g
<30a<3@c>D@h=R1>A0d_F3He820a=c8PDT@P<SA5@d94<3DcAD8iAT=1@C0g<CDf
=3=3@DE2>3<i>3@d=C@f=4@h=3A2<D4bADDd=CE4ASI4<dDb=3Lc3C<e<SHi<d8b
=C0b=SU4=SLe<SU5=3=3<30a<SE4>DDd<d8f=4=5AT@c=C=5ACPb@S95<CPh=SDg
>4Hg@`e4=c=3<dDe=CI6@CA3AC8f=C0aAC93<3Di=3@e@DH`A354ADDg@CTe<34h
ATE3>4A6=d<c@TD`=CM6=c0==4=6A3A3<3@`<cDh=D8i=CPb<4=5<dE6>C0c>C91
<3TiATI2=TE4@CThASM4=TDa<4@b@S@e=30`A3Pa3CPf@S55>3Pi=CLf<C96<CPg
=34g<d4`A3Q5>C<a>3A2<d8f@d@e<CU5@DE6@cLg=3<dADDe>CE4=S=6@`dg>C51
ACQ1>D<c=394AD8c>C<i<30a@cTiAT8g=454@cHf=cM6=3U1@D@i@b1>A0d_F3Hf
820h=B1BA20b=4E3@T@`=C=5@STc<T<h=T@f<TDe=TDgAS16=S@g@DA3<44h=C8d
AD@g@dDcAS51=c8cAC@`>CA2=C8=@dHg<SE6@S<i@D92<3E5>DHa<dE3ACLc<D8f
<S53>4A3AC@e=D<i=T<a@T8`@TI1@CPc<3@fACE3=SQ23DA1=cDh<T=3=cE2=CPh
@T@hA3Tf<c95<CLf<cE6=CHa=d8d<d51@CHi@T4f@CM6AC@a84i43BmH=SLP838d
<21BA20b=4E3@T@`=C=5@SU4ACM2<3I1>3Li=DDdADI5ACLa<CDg=48b<c8h>CM3
<SA4=cE2A3Q2>D4d<D<`=d<=>C8iAC<`@D@a@S<h<C95<SLh>3A2>C<cADE1<395
=cM2ACTe@T8i=THi=DI6=T4g<cHf=C@i>CU6>3U13C=3=cPc<C4a=453=C4`<c0i
<STiA4=1@cDb>D51<SPg<DDc@c8h<3Q6<c56@D8g=S8e@C<b=3A1=CD`<0df<TA4
>D4cA4H`@cHd>4=5AS<a<D8a=d<i=S4a<DHd<S52=SQ4=C4c@c@a<S<a@CA3@d@g
=T52=3A3=4D=@C=4=CQ5@cI6<D4c=C@e<3HiAS0i@c@h@C92@cHg<SU5>DI1ADA3
<S0f=STh=cE4<3=1<3PaASPcA3A63CLaA313@T@c>356>3M2<d8i@c15AS4b@T<e
<c8a<D@`>CDi<C8e<D<a@D93=c8g@d8fASHfA4A6<SM1A@dbACTh=S4d@C=6=S<i
<396=S52<d4a=d=5A3TeAS8d=3<i=c@i>48cAC0a<3<c<3Hf<4E1=492>C0iAS<=
@C4i<S@iAT@b>3U3<dE2@CE5AS<a<d<c@TDi@CTb@C4f=T52=STi<cPaAT@i<S0f
ASE5=d4g>4Hb>34d84i43BmH=SPP834b<21BA20b=4E3@T@`=C=5@SU6<cHh=T@d
=d4b<c13<38bAD@f>4A3@CU4>D52<cI5<44g<T8a=cHd=S15>3U6<3D==CHi=S11
<3Hc=392>CM6=CL`=3Pe=SI1<4@g@T@cA3Q1<cT`AC4h@C13A30a>3Q4A4Dh@STg
<4<h<4953CDh>C55AS8g<SU3@C55@c0gA44a=3M6>C12AC8gAS0e<CLi<3Tb@S4`
=4=2ACDbA3Pa@THe=DDi<dI3=Pe4@D<`<4Ha=DDe=D56=4Dg=CHc=c0d@SPa>3Lb
>D94<394<d51@D@h<D=2=cTf<cE5ACE4@dI2@d93=T@PCT@=;ePf>B0P<cPPDT@P
<SA5@d94<3DcAD8f@c8aACM4=T<d>D8a<3La>CI1ATE2>3A3<d8a>C=3>CLg<313
<CE5@C=1=3A2A4A33DA3=D4i=D<c>3Tg=3Tb@d8PCT@=;ePf@B0P>C4PDT@P<SA5
@d94<3DcAD8f<CDi>C@g<4I1<3@g=S94=S=1@S4e=3HgA3Hb>DA5AC0g@S4c>D92
>3Lc@STeA3H`3CTgAT4i<3Ha=SDd<SU1@c8d@DA2@cDi<455<CPf=S91>4I4A4Dc
@S=4<C94AS@dACI6<S8cADE2=3L`=`e5AS8a@CDd=D51@CA3ACQ4=4<a=34d@DA5
@DDd=D8bAT8b>C@d<dA4<CA5ATA4=3=3@SA1=3U4A30gA3<=AC@PCT@=;ePf@R0P
=C<PDT@P<SA5@d94<3DcAD8i>3Hh@d4d>DE5AS0e<T94=T@c>CA6@D=1<3=4@SLf
<S0i@STgATHe<dA4=C8c=DE23DE5A44g=C4g@c0a<d=5=SPg=TDb<dA2=3Ha>CTb
=3Ti=CM6=S<h@D@gA30i=TDPCT@=;ePf@b0P<SDPDT@P<SA5@d94<3DcAD8f@c8a
ACM4=T<fA3Hg@CQ6=CHfASDh<c=2A4<g>CHa>C4bAT4e=D@PCT@=;ePfA20P<S4a
8594838dAD=2A30e<dE2@T@g<496=C92>C4g>CQ5@c15@DHc=c15A3U3ASI5>4@`
@SE4<c4i<D93ADHc<SE5<0de<S=3A4@e@c15@THbA494@DHe<T@d@S4i>3Dc<T<i
<cQ6@CU2A392<3<c=SPeASLg>3Le>C12ADD`AC4==SA5=3Q2<4Hi=D52<DHi=ST`
=STgA3DbADHi=C15@dDh>3Da@SE3@CDe>3@gA455=SDb@TE1<455=cU13CDb@SU5
=4Hf>D<e@cPdA34cAS@hAC54>CLc<S52<S0i<TE5=T<d>4<a=C@b<3DgA48e>3I1
@D8gACE4=`db=cM6@CE5A3La<C<f=dHc@c@e<CE5=T@a@C=1>C52@CHb<3Pa>3Hg
=SDc@c94<3=2@D93ACM1@S0hA3L=<c@a@c0f@C0d<DE3AS8c<T=5ASHb<D93<dE4
<S4g>DDc>4Dg<3@`=DA4A4I2=C=3AT93=SDi>C@eATHa3D=2=SLe=30a=S0`AT<d
<D4f@C14=D<b<T8c@C0f>48d>C0`>C8b@C<`=cA6@SPa<SU2<d8c<3P`=3<eA0e2
=R1>A0d_F3I5820a<CTPDT@P<SA5@d94<3DcAD8iAS<f>3I4=3M1<S<`@c0b<TE4
=SU6=c0i<SLh@cPb=cI1<30g=3<b>4De=D@a<DA23C51=d<`>C0e@S@g@T<e=CI3
AC92AS@e>4<`=4E2=D8c<THb=CU4@CTi@cLi=SDb>D@h>4Hf>395=C8c=0dgA454
AD4h=T56=4=1=d4dAS@c<S93=cLd=C4cA38e<D8b<C=1=D4b=D8d>3A6<C<b=3Lh
AS=4=CPcAD8=<SA3=CPa@d55=cA2A3@d=492ATI1=dA4AC4i@SU4A394AS<i=3Hf
=d8c@T8g<T@iA3Q1=CPdACI5=B1>A0d_F3I6820a<c4PDT@P<SA5@d94<3DcAD8i
A44c<38a=38c<ST`<CPc>C4g=d55=48`<4Dc<T@h>4I1<3D`AS@aADE3<S0`>3A4
3C4a@C@f@C8b@c@bAC4g>C53<cDiACLbATHb=C8h>CPh=D53ASE4=c<b>CHc=T<i
>CQ3<4<b=CM1@c@a<0dd=c<e@S52=c@iAT=1@CPg>C8d<d<h@dHg>3E6@C8d<SA1
=C8e<3Tf<D8a=S53>D8bAT8c=c56<C<f@T@=>DDh>4E3<d@d<S11ACPe<S4c<S8c
@D53=38bAT4a<3P`@cDc@D8h=3U6@dE5=30f<cA3<CPi<3=6@SQ63CTh@T@c=396
=cLh=4=6AD@h<cA6=SLPCT@=;ePg<20P<CLc8594838dAD=2A30e<dE2>D<f<C4a
<DE1@SQ3A4@e>3Q6>3Lg<DHiAC<h@D8e=c4b<CDe<3Di@T4a@SLg@c0e@`dd@c@i
@CLeASDg=S=2<dDdACA6<DA4AC8f<48e=T<f>3LcAS=2AS@i=3E6@cDa<dHf>3E6
ASQ6<392=4H=>316>DDd=CE5=TI4=d4`A311=c<d=SDcASH`=d52ATE2@cPeA4Ha
ACM1=3Lc=THf<SQ3ACU4<495=d8g3C13<cPiA353@T4e>CI2>34c@cHd<SDe@T@h
=cDh<D@h@dHf@THh=c8g@D93=3I6>4@i<d93@DA6ACPe<Pe3=TD`=C<h@SDa<cDa
<3Pi@c<e<SU2=395=C8d=34b=3A6=T51=D56@C@i@THd<THdAT8i=c8cAS@`=TH=
=THf@S0fAD91<CPf@CQ1=c0g>4<f=SI5<d<`=DE2=SPh=3Th=S95@CA3=T=4=b1>
A0d_F3La820a=c<PDT@P<SA5@d94<3DcAD8i@cHa<C4aAD52=c@g=dDa@c14=DDc
>DHe@cP`<D4g@SLh=CHe<c@`>3M5=3Th=THf3D53=4A5<3Pb<48b>CTh>D8e<CDb
@d4`ACE1=c56<S12=C=3AD4d<cTc@S8aAD=2ASM5>C@`ATA3=T8c@@dg<SHd=dHg
A48a<c@d=S8g@S92AS@h@CDc@S96<CHeADHfA494>311=DDc<S<c<D<c@C0g<SHg
@cA3ATD==SPhASU6<T96<S8d=CDi<S@d@C<`>CQ6<STcAD4i>CU3=30`=TDg>CQ5
<CU4A3@a=dHg=d51=SU6AC113CQ1>CDa<c@`=T93>CHaAS93@D4f<C13<DD`A44h
ASHg@dI3=S8b>3M3=S=3=S0a<3Hc<DDc>4E6@C55APe1>C@`=CDgA3Dd<30a<d93
<38b>4Hg>313@d4e@cPa<CDe@C13>38h>4Hc@S0`84i43BmH=c8P83Lh8594838d
AD=2A30e<dE2>C=5=dI3A492>C@g>3L`<d94>D<d<TI5=4Hi=dHb>C4a=CI6<DDe
@TA3<48f=cPb@Pdf<dA2ACU4=DA5@T@bA44cAT53<C0g<3T`@CE1@THa<c=1<30e
>38h@TA2>4<f<D<aA3Dd<4I6AT@d=cD=@DDdA3A2<dI2<cI3A353=T55>CT`<3A2
@CHb>3M1<T8h@d4a84i43BmH=c<P838a>21BA20b=4E3@T@`=C=5@SU2>D53<c@h
>30bAC8a>C0g<C52=4HaA3=3@dDh<THa@c55=D8c=3Ld@S=4>4=6<38=<CLd=c4c
A3A1<SHeASM6<cHh>C4iAT8g<c93AT<b@c@e@SI1=48d@C4c@CPi<SDa<c8d<4@f
=ST`=C0g3C=1<4<hACLbAC0f@CL`@c@b@D54AC<i<S8c@S4`ASHiAS<a@CDe<CI6
<3Pe<30fAD@c<d=6<3Ha<CI5>@db<SPc=3La<dA2<SPf<SI5=TE5<c<a=SPi@SE1
=cE1ASLb<C4a<d@a@DI4AT4`AD51<44iA4@h=cM3>CP=>D=2=THi=dHdA3Tb=3P`
@CU3>4<gAS=5A3M5=cD`<DE3>4E5@cPhA4D`>C<i=cM5@dDd<TI4>4Dg=DHa3CHc
AT<c<44`@CTg<SPg=T8i<c=3>392<S94<T91@cPa@STb@SE1<3L`<D<c=C8`=316
ASE1>3Tc>38hAPe3<44b>3E5A3Q6@S=6>C0g<T<`<S54ASE2@SH`ASDi@CDdASPc
=C4f=cTeAT95<DH`@C13=44cAT96<S<==4Hi>C@f<d@cACE4=DA3A21>A0d_F3Ld
820a<38PDT@P<SA5@d94<3DcAD8i=SLhASI3@c<h<SPh<CA2=SM1>3<h=4A2>3I2
<D4eA3Dd=D<f<34bA30d<CDeASA33D4c@DDa=30`=4=4@C95<S91>D8e<DE2=S4i
ACPg>48h=CTb=c4f@S<`A3Ta<C14ACLg@dDa@D55<3@gAPe4>CTg@C@f@TE1=c8a
=c@c>3Pa>3HdASA2AT94>312=cLd@cA5=dE2@c8`>DDa@S<g<SPa<4E3<4I2@DD=
=S4f=4A1AC<b<C4i<CDd<c0e>4E2AD@g84i43BmH=cDP834`=b1BA20b=4E3@T@`
=C=5@SU6<cHh=T@d=d54A4@`<3P`=c54ADD`=CL`<c96ACDe=S96AD@`<T55@SLa
=cTd<34=A395@S8i>CU4=4HeAS14>CTd<TA3@C=4@TDe<cDa=CDdA3U6=3Q2@SI6
=4@h=SH`=3U4<D4f=D<aAC913DA6=c4c@S16<4A2=T=6@TA5@THc>4Hf@S=1=cE4
=d8e=DI5<T=5<D=3>3<`<c8iA354=cPc<d<fA3M6@@e1>3Hc<3E4A4=1AT@c=c52
<d<g@S8c<4Dg<CLa=TDg=CA584i43BmH=cHP83@a8594838dAD=2A30e<dE2>DD`
<DDdAC<h=cPe=TA3<TI6<3E6<c<f=3La=TI3@SPfAT4g=THh<c4d>CLi>CDd=Pe5
ACPgA44h@DDa<SM2<3Hc=cA3<30c84i43BmH=cLP83Pe8594838dAD=2A30e<dE2
>4I1=d@e@D<eA396>3Tb<c4e=T<g=cM2<S0b@S4b=SPe<3E6AD4eA3A6@CLg<48g
=`dgAT4e@CPf@DE3=DA3>DI4@dI6A3<g@CPi>3Da<c=5@TE5=D<eAS@d@SPbA3U6
AC13>4@e<cU3@CTiAC8==CM6<d4`=CTg>48b<CI4@D8e=c53=d4f@CHcA44`ACTg
=T56ACDfAC93>D=3ACM6=CTPCT@=;ePg>20P=S<PDT@P<SA5@d94<3DcAD8i>4E6
>CI4@cE4>3Pg<c0g=S@`@SLb<dDhADE4=D51=CT`<cM6<3=5=cLgA48h@dI33DE6
<34bA34i<THc@SLa<CLf=TDc=T94@d53=C<aATI1<T<b=34c@STa=34h<3Df@D<i
AD91<d<i=3I3<Pe6AD@i=d@PCT@=;ePg>B0P>C4PDT@P<SA5@d94<3DcAD8iASPf
<4I3AD4f@c8h=44g>CHb<3@f<D<h<CLa=SHb@DHh>3Ph=SHc>D4g<493@dDg3DDd
@C0c=S@i=3He@dI6>C52<3Q1=48i<d=5@SDaA34i@SDh>CDf>C53@c51A30g<cLg
<3HdAC8d<dA2<0di@CQ3@d=6=CLi=C8a<3Hi=c<b=4<h>DHb@SPc=3Q5@cPe@C8f
<CPfA4=4<C8b@d=4AS4hAC<`ASDh>4@=AT4PCT@=;ePg@B0P=3HPDT@P<SA5@d94
<3DcAD8i>CDi=38e>C@cA4=4AS53@STd<dHc=c=4>D4e<DD`ASPg>3Pd<3H`=DI5
=3<h@SHb3D8i=S95=cP`@SPc<30d=c92=c=5@cQ3@D91@cDd=S<i84i43BmH=d8P
838b<21BA20b=4E3@T@`=C=5@STgAT@a<C94=D8d<3U6=C@g<3=6AT=3>D4c=D4h
<cLeA3@`<d4eAT91@S4`=THg>C<=<3Hh<SE1ACI1=d4iACI2>3HfACLb@CLh=c0g
=455@cDi=CT`>3Hh=D52=DA5>3Tc=cE2A3A1<T4f<CQ13C93>C8f=c14=3=5<S<f
@c=4>C<c<cE6=D=3<4<b=T96<3@fACDa=4DcASLb@SLh=S96ASPf=d4h>4@f<`e4
<4=5A4=6ADE2<d8i>311@DDcAC51@dA6@SPe=C<i=TA3>38cAC4f<CHf=CLg<d@h
AC4b<THc=4A4=cT=>CU4=313<S<d<C<b>4Dh@cTg=DHeAD@a=3ThA38f>DDaASI6
A4@iA3Hh<D@i<SM2@DE1=CI2=DI5>30d3DDd=c15>D4cA3Hd<C8g=TE2<48`<C15
>3E4<SU2>DA3<CI3@C8bA3U5AC@`@S0c@T@h<4Hh=cDf<C8g@`e2=3=2<SPd<S0d
<SE6<3La<3LcADHd>38f@S=5<3Lb=DI6<SHc<D<a@cTa=3@f=CU1AC8h<c<h<3M2
=S0=AD56=SLf<CT`<T8i@D8h>4@bAC8PCT@=;ePg@b0P<SDPDT@P<SA5@d94<3Dc
AD8f<cM6<cI2=THg<3<b=d92@SA6<3TbA4I4>3M5@THi=dA6@SPe=TDPCT@=;ePg
A20P<S8a8594838dAD=2A30e<dE2>CM6A34a<T@e@S8i<dDa=C0h=S@h=CLf>D<f
<cL`=d54=CA6@SHe=STe<SE1>CLh@`dbAC0a<DA3>3Ti>4Ha@cLaACQ4<S0g>CI4
ASQ4<CU2<3<c@cA1>4I5=C<h=cDc=d@d=DHf@cDh>3A5<T4=A4E2<T@d=DE2<44f
<c0b=D@b@SA6@cLc@d@e=T4b<CHh<cDb<cA4<cPa@cLcAD8f@d@a<cQ5>CHfA493
3D<`<3@a@d4i=TDg=d<f=d55ACTg@cDa=CI1=CPfACHe@SE6>44g=dA6=3L`>C11
A3<c=SHa=D54@CU1A0dg=4Db<DA5AD<`<T4`>DDi<T8h<4@cACM5<dE2=STe@SH`
=dA3<dH`@D@a<4E1<3Ti<3TaASPd>C8g=D4==TE4AD4h>4=6@dDf=TE2<S4h<3I6
<c@g<3Dg=TA5<cA4<3Ld=T=5A3<cASE2>3Te<c95ATI6@SA5<c0c3DHh=30g=dDg
@d@dA4E4<SPb=D@c=THb=T91A30g@dDg=CQ3@cQ2ACHcA3He@CE2>3M6AC0c<d91
>3<b@`daADHi=c54=c0h=dHb>C8c@d54=CDa84i43BmH=dDP834c>B1BA20b=4E3
@T@`=C=5@SPg=C=3@CA4=T<g>D=2<395>C8h<493<S=6A30fAS12ASA5>3D`<4D`
@S95@cTe@T@=<cHd=34h<d@a=T56<D@`=d8c@C8a>4Da@CU5@C@b@c56<T=6<d4i
=d8d=dE6<cLhASPbA4@b=d8i<S@a3CQ6<c4aAT=1A3Ti@cE3=30fAD=1AT@d@T8d
>D=3<SM1<SHb<D94<TE4>C@`=T93ASTfA4<e<30c<S4i<`d`<4<`=4HcA355<CI6
<D=6<3Q2@c<`AC<`@cE2=3=5>3=4AC92<S<g<cLf@TDcA4HgAC4g<D92=C8d<S8=
=3M6<dDb@DHe<CPaA3DaAS14=cPg@d=5=DDd@cA1=SHc=3E3A30PCT@=;ePgAR0P
<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH>30P83Pe8594838d
AD=2A30e<dE2>3<a=C4i<DE6<3Ta<cDeACHc<CU4<dHi<C4`=CHa@dDd@C92ASPf
ASLgA3La@S51<`di<dHeAC4dAD@f@cM3<d<g@c8b>D4c=dI4AC<d=cQ2<d=2<T<a
<3M6AS<g<T4e@c@c=S<h<S4b<3<fAT4=<dI2<c0g=C53<3HiAS8b<d8i<d<f>CTb
<c0`=3U1<STf>4Hf<S8g@STb@cLd@c@g=4DPCT@=;ePh<B0P<CLg8594838dAD=2
A30e<dE2>3<a=C4i<DE6<48g@d93=SPb=3M4=4DaA3<a>3Pi=CTi@d<`=4HcACTc
<d95=3@g=0dc<T<e@dDf@dDfAT@a<SA6=SDdATI2<3E3@DD`<c4iASDdAT@`<4Hf
=T4c@T@d=3De>D56<4H`>3Tf@T@==cU4@S=2@SI1AT8i@TH`<T4`@SA5>3=3A38d
@SDi=d4b@SLd<TE3AT4b=SA4=c55<dDf=SPiAS4`=34e3C0i@DHa@c96@C=1=3A1
@C0g=cL`=dA1@cQ6ASQ3>DDb>48h@DDg=SD`=C0a=d<f<THh<c@b@T4a=SP`@Pe6
@C0g<C@dA3<eATE5@c0h<S4hA3<hATI1AC4c>38d<DDg@c13=D8b@TH`@CD`>DDd
=495=4<h<3Q2=S8==CA4=T51<3M2>C4b<S<a>3Q1=d92AC8gAS15=S=5A3HcATHg
<SHf<cA5<D4a=3Q1>D4fAS1284i43BmH>38P838d=R1BA20b=4E3@T@`=C=5@SPd
=CL`@C8`>DHi<496<d8aA30g@d8e=38g<c<`AS8h=392@DHg<316ACU6A48g<4H=
<3M4@DDe@C15>CPe<44b@STb<SPaAS@i=C<a>CI2>D4g<T53=d<f=TDd@S=1=S<g
AD54=CM6ACI6AC4e3C4d=SQ4@SPc<3Pe=D@g<3U6<cH`=SLg>3M3@d8a=3A1=d4a
@c4h=TA4<SA2=D<f=S0a@DHb<T<e@DHcA@e3>C0dASDe<CHaADE6=C0g>D4c<S55
=d51AD@h>DE2A3HaAS56@C<c<S0c<4He=c51@cT`@SDb=SI2>3T=>DA4A3M3AS@c
ADDa<4Di>CHi>C4c@D94=c4i>34bA4Hh<cI6@cM2@D=2=C0`AC0b@S0e=D=1AS8a
A3A23DDe>3L`<d92=3Q2AC4a@T@f<38f<SA2ADA2AD<a=492>3D`=THe=CDdASI1
<C<a<cDi=4@a@cHc<T<g<@ddAST`<dA4@S=2<3E1A4@f>DDi=4Dc@S<b<3Hf@dA1
>3<b>3@f<THb<c4h=cA1=cH`>CA3>38a<S0e=3H=A3He=3I2>4E2>4DhAS<f=3Ti
AD@f=D<g@T94<4E5ACA1AT=5<D8b>CQ4=d52<3@fAS@e=30c=C0e=D8b3DE1=4@d
<cHaAS15A21>A0d_F3Pc820f=b1BA20b=4E3@T@`=C=5@SU6@d51<3La=CA6>D92
<314>DDa@SA3<4=4<T@f<34dA4Hd<d@i<d<`AS<a@dHd<S8=A492<3Pb<C8c@CL`
<3Ph=dE6ADDaASHdADHe<T91>DA6<SE2=4Hh>3=1<4=3>34e=DI1ASD`<3E1@CM1
3D8`@CHf=cM3A4E1<3@`84i43BmH>3@P834f=b1BA20b=4E3@T@`=C=5@SP`<SM2
<CDc@C8h@S51@d91<DDdAT8d<dI1=c54>CDg<4<h@d93AC=5<TDf>38`>4D=<SHe
<C52AD@c=D<dAT@`A3Lh@S8`ACQ1<d8d<dHe=T8c=dDf<3Pa=cHd<S<d<3E4=4@g
>3A3=351<3Th3CQ5<cM3>DDf=C<d@d4i>3Q2>492>4Db@cTbAS92=34c>C<g=cDb
@D8d<D<i<T4d=CDb@C53=CHd=d92>@de<CTg@T53AT4dAS55@C93=394@cPaAS=5
<34b@SA3>C0cASM3=3Lh@SPi<d@i=D4fADI5ASU1>3I1<CH=<cQ4A3U6A4E6>C4a
AC<gADI5>315<4I4@dE1ACLcA356@CPaA3@f>CU4<dHd@c16=3M1<dI2=C4cA4E4
3D53<T4`>454ASDc>3Pa>D<a@cHh>3Pi=cE1A3@gA494@cHPCT@=;ePh=B0P<CHa
8594838dAD=2A30e<dE2>38iAC@d=48`=CU6>CE1<D@d<DI5@c0eAD4b<T51<CU4
<cA2=D4`@S=3=dDb<30a<Pe4<S53=c51>3U2@THb>C8g>3Q3<cPb=cM6=c91=4Ha
ADHhASD`<34eASLe<C0aADHbASU1>3Q4A30aA3T=AD51>C55@C92AD8g<4Hb>44f
<T@dACPa<C4c>353@CLi=d<f<3HhA3Lh@S0g<d4i=T4d=DE1=3Dg<C=23D@d@S@`
=492@d=5@D8b=S@d>C@e=TDc<c8i@cHa>392ADDd=TDc@SLcAS@cAC0i@S0e<c51
ADDd<d54=`deACLc<3@hAT4b<D8bAS8g<S11<C8h>C@f>3Hc>CH`=cQ6@CTa=3Pf
AC<`=S0g<312>3Lc=4@cA3M5AT<=@cPe>C8h@C0d<C<c=S@e<392@DDg>21>A0d_
F3Pf820a=34PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I3=cTb=C<b<cE5AS@c=c94
<S4`@C55<dD`>3HfA3Q3@T@i<S0e<4Hh3C96<48aACI4@C0g=CI5@cQ6<391<3Pb
>C@h>454<CA6@SM1=TI1>CLd=3M3=D8a<D=1AS@a@S0g=3Ha=0e2@SA6AC52@DI6
>3He<d54=3P`=D95<44b=T<aAD4`@TI3<4@a>3A1>DA6AD<h=DA4=cU4=dE4<S0`
=CH=>D8b=D=1<T@eA38g@d54ASHa=cH`AC<iA355=353@dA1>CLi<CQ1=D8e@DDd
=cTe=D8`@DHa=S96AC8i3D@h<CQ6@S@b@S@`@dA4<4=6A4Hi<30gASHaAD4dAS4i
>DI3<SLg=dDfAB1>A0d_F3Pg820b=C400:40`3oo8594838dAD=2A30e<dE2>CTe
>C@b=CTd<d@f>CTb=c8dA3Ti@S@e@d<iA352<cLi=c0h<c@`<c4d<3=5@SE5=Pdg
<cPb<DE6<4HhAD96=D4cASDi>D8b>CE5<CQ3>CPb<3TiA48b<SLh@d8`@dHh@SPb
@CH`=CE5=T<hAC0=<S0g@C8b<D91>3A4>CQ3ASE4<TD`=3Q6>3T`AD54@CPb@S<e
<D8g<C0g=cM1<d52=3I2<c16=cLc@c=13CE1<THf<SDa=T4g=S4c@cPh@CM3>D8f
@c14@C8bA4<a=dI3AC8`<3A4>48i<S4h@SDb>CPh@THb=C55>0dd=3HdACU2=d<e
<C54=316<4D`@c@a<C@b>3<b=cDb@TI3>3Th>3U4<T@c=SQ6<SD`<d@c<C8fATHh
>DH=>CT`@T4i=4Hd<D8d@c<h=d8a>355=CPi=SD`<STg@d53A38d=315ASPi=3U4
=THd@TDi=4E6<38bATHe3CA1=S94=TDc=3M3A3=2=C16AS@c<T95=3U2AC@h<d=6
<CDh@D@eAT=6=S<b@CLcAT@c>496@d4`@d=6A0e2<c54@SDa=c8a@TA1>3U5=cI5
@cLe@D=3<SA3AS8e=d=2>CM6=T55=3<g<S0a>38bACM3=SDd@CHb@S8=>DI4>3I2
<4Hb<4<b=3LgADE6=D=3@B1>A0d_F3Ph820b=C0PDT@P<SA5@d94<3DcAD8i>CDi
=38e>C@cA3Hi>C8g<SA4>CU2=3E3@cU4<D8c=cTg<3Pc=30c<C@`<dE2=DDf3CLc
>38aADH`ASQ5@THe@C=6=CTi@S8i=DDa>4<i>38`>CU4@S8b=cQ3@S13ASQ2>391
=S0e=DDf@cQ5<0db<3M1<S8a@T4h=4@i>4=6=D@bAC0d>4Hh>C15@DA1>392<cDa
@SLa<3Lg=d4c@D8d=T8c<4Hg=c=3<d4==D4bASHb=C4f@CLf<C=3>3Q1=d<i@SI3
<4A1<S94@c4gAT=5<S0`=4@h@STb<CQ2=C8i>3Q2AS8e<DDh3C@d=SA5>D8g@cDa
<D@d<4H`AC13=34a=38h<c8g=C92AT<h>CPh>D@bA3<f>4Hb=C0cA3<a<SI6ASPi
APdi>C12@CTdAS@a@SA3<cPg@S4h<DDe>3Tf=C0b>CM3@D=4<S@d<4E6>3Td>D@f
ASA2ACTdADH`<S96ASD==44f<T@fAC<d=d=4<d8e<4I6=3<b@TDd>D95=3Pc@dHa
=CQ1A3E6@dHf<c91=c=6A3<h@TI3@C13@dI43D8c<DA2=C4g<S52A44h>DDg=TE3
=cE1@d<b=4=6<SDg@d8i=dHf@DDc>C53=S13=C12@cI4ACDcA3U4@`df<C53ADI3
=SQ6=C8c@CTa=cTe>21>A0d_F3Pi820b=CTPDT@P<SA5@d94<3DcAD8i>CDi=38e
>C@cA3Hi>C8g<SA4>CU2=3E3@cU4<D8c=cTg<3Pc=30c<C@`<dE2=DDf3CLc>38a
ADH`ASQ5@THe@C=6=CTi@S8i=DDa>4<i>38`>CU4@S8b=cQ3@S13ASQ2>391=S0e
=DDf@cQ5<0db<3M1<S8a@T4h=4@i>4=6=D@bAC0d>4Hh>C15@DA1>392<cDa@SLa
<3Lg=d4c@D8d=T8c<4Hg=c=3<d4==D4bASHb=C4f@CLf<C=3>3Q1=d<i@SI3<4A1
<S94@c4gAT=5<S0`=4@h@STb<CQ2=C8i>3Q2AS8e<DDh3C@d=SA5>D8g@cDa<D@d
<4H`AC13=34a=38h<c8g=C92AT<h>CPh>D@bA3<f>4Hb=C0cA3<a<SI6ASPiAPdi
>C12@CTdAS@a@SA3<cPg@S4h<DDe>3Tf=C0b>CM3@D=4<S@d<4E6>3Td>D@fASA2
ACTdADH`<S96ASD==44f<T@fAC<d=d=4<d8e<4I6=3<b@TDd>D95=3Pc@dHa=CQ1
A3E6@dHf<c91=c=6A3<h@TI3@C13@dI43D8c<DA2=C4g<S52A44h>DDg=TE3=cE1
@d<b=4=6<SDg@d8i=dHf@DDd<dI2>CLd<SPc=44i@C4h>3Pg>@dhAT8i>4E3=38c
=SA5A3@hA30b=C=1=C4g<3A6@CDb@dHiA3M6>21>A0d_F3Q1820b=CLPDT@P<SA5
@d94<3DcAD8i>CDi=38e>C@cA3Hi>C8g<SA4>CU2=3E3@cU4<D8c=cTg<3Pc=30c
<C@`<dE2=DDf3CLc>38aADH`ASQ5@THe@C=6=CTi@S8i=DDa>4<i>38`>CU4@S8b
=cQ3@S13ASQ2>391=S0e=DDf@cQ5<0db<3M1<S8a@T4h=4@i>4=6=D@bAC0d>4Hh
>C15@DA1>392<cDa@SLa<3Lg=d4c@D8d=T8c<4Hg=c=3<d4==D4bASHb=C4f@CLf
<C=3>3Q1=d<i@SI3<4A1<S94@c4gAT=5<S0`=4@h@STb<CQ2=C8i>3Q2AS8e<DDh
3C@d=SA5>D8g@cDa<D@d<4H`AC13=34a=38h<c8g=C92AT<h>CPh>D@bA3<f>4Hb
=C0cA3<a<SI6ASPiAPdi>C12@CTdAS@a@SA3<cPg@S4h<DDe>3Tf=C0b>CM3@D=4
<S@d<4E6>3Td>D@fASA2ACTdADH`<S96ASD==44f<T@fAC<d=d=4<d8e<4I6=3<b
@TDd>D95=3Pc@dHa=CQ1A3E6@dHf<c91=c=6A3<h@TI3@C13@dI43D8c<DA2=C4g
<S52A44h>DDg=TE3=cE1@d<b=4=6<SDg@d8i=dHf@DDd<cHd=D8f<SLa=4Hh=C52
@DHb@@d`=SE3<cPb@THa=c8b<dI1A4Df=3LdAD8e@S<b>CTf=cTh84i43BmH>48P
83<b<21BA20b=4E3@T@`=C=5@STi=CTd<SDi=3=4=STi<SLb=4@i>D8d=D=3>D@a
@S<g>CL`>3<d<3<a=30cAD8eACH==c<h<S55AS16>4E2ASE1<dHe>CU2<STeAC4h
@cTh<S0i>DA2<S8g>4=2<4=6>48h<T4f<3DeACI3>4D`3C8`=d4b<S52@CPdA3Th
@dHeA395<3@hASPi<4E1A44h<T8c=C52=c4`=cLg@C=1@S@f@S<`ASLg<d<c@@de
@C96=S8e<CI1=cHa<d<h>44g@cU2=T<`A44b<TA3<CM6@dDb<30dA3Q2>C8a>48e
<STh>496<SDaACP==3@f=4Di@SM3=C4aA3@`AS15<4<d<C4d<SPc<SLe<T96@cPi
>3PiA394<cHhAS8e<3=4<c4b=TI6>3U63CTi<491>CA6=352=4<c>3M2<CPaACDh
>CHe<38i=d=1@d@b=3@`ADHh>C@iA3I6=495>CA5AS0b<TI6=@dd@CHbA3I5<c@g
@d@c@SD`ATHd<c92AC@i@TDd>3=3AS4e>454=DI3ASHc<T4g<dI4<cQ2AT=1<4=3
AT@=@S<aA48e<CLb<D94@CPiACLfAD<g=D53@c8d@dHb=CM3@STgASI1AC@c>C4`
<D@a=D=5<S=6ADHg>C563D4d@TH`=d91@SH`=C12@c=3<DI2<DI1ASI5=D93AS<c
@TA5=THh<4@fAT@b=3<`@c92<CPa=493>4I1=Pe2=c@eA4E4@T<f@D8gACA2<44f
<C56@TI3=D4h<4H`A3Df>C96=cDf@cTcA4@hAS8fACQ5<3Pb=C0h=CH=@d<`AC11
=T8h@d8aA3<c@C=2<STa=SU5=T8b@CI5<4A2=CPi<T<g<21>A0d_F3Q3820c=C8P
DT@P<SA5@d94<3DcAD8i>CDi=38e>C@cA3Hi>C8g<SA4>CU2=3E3@cU4<D8c=cTg
<3Pc=30c<C@`<dE2=DDf3CLc>38aADH`ASQ5@THe@C=6=CTi@S8i=DDa>4<i>38`
>CU4@S8b=cQ3@S13ASQ2>391=S0e=DDf@cQ5<0db<3M1<S8a@T4h=4@i>4=6=D@b
AC0d>4Hh>C15@DA1>392<cDa@SLa<3Lg=d4c@D8d=T8c<4Hg=c=3<d4==D4bASHb
=C4f@CLf<C=3>3Q1=d<i@SI3<4A1<S94@c4gAT=5<S0`=4@h@STb<CQ2=C8i>3Q2
AS8e<DDh3C@d=SA5>D8g@cDa<D@d<4H`AC13=34a=38h<c8g=C92AT<h>CPh>D@b
A3<f>4Hb=C0cA3<a<SI6ASPiAPdi>C12@CTdAS@a@SA3<cPg@S4h<DDe>3Tf=C0b
>CM3@D=4<S@d<4E6>3Td>D@fASA2ACTdADH`<S96ASD==44f<T@fAC<d=d=4<d8e
<4I6=3<b@TDd>D95=3Pc@dHa=CQ1A3E6@dHf<c91=c=6A3<h@TI3@C13@dI43D8c
<DA2=C4g<S52A44h>DDg=TE3=cE1@d<b=4=6<SDg@d8i=dHf@DDd<dHc<3=3<cHd
=C<i@C8c=3M4>0dbAC=2>455=cA3>4<d>CM1@C51<c8c<3=5=CTb<CDc>D51@SU5
=cI1ACTfA3Hi@SPbAC0d@SM1=c13@cD=<D=3=CI5A34g=3=1=C<i>C4f=d@cA4De
ACP`A4=5<3A6<D8a>CDd@C4`<SDc=cTb<cQ6@DHi<4I1<SM53C@d=SDi=SE2<SHg
A3De<d8e<D@`AS<`A3DgAS0b@THh>D4e>30g<SHh=c8f>3=1>C<f=d<a@T8c<dHa
APdh@C4i>D@`A3De@cE6=3Q5ACA2>3Lb=c53>C0e<D<a<S94AS=4=316ADH`AR1>
A0d_F3Q4820b<SDPDT@P<SA5@d94<3DcAD8i>D@`<44a<cHe<c<`=D51=S93=S8h
@D55@SA1>DI2@SE6A314@SDa@D4b>C@d=TE23C96A3@c@T@c=C0cA4<f=T<gAC4e
@CQ4<c@i<4<aA4Hc@C@cAS0h=CU1>452<SPf<3Li@CI2<SE5AC0i>@e6@D92@SLa
@SI4>3Dc=D4d<T4b<SI4@c0g@c@a>30aA3I2=S<`=D=2<3Q5<SPa>C8i=44i=DI5
@S@hAT@==3@`A3DiASHa=d8dADHd@C<c<d8d<cU6<T<`A4@i<SI2<SU3>4E1=3He
@D56@D@e@C55@c=6A4=1@CU13CDaAT4g=48b@CE5>D8h@T93=4Hc@CTi<34f=TA5
=d4d@c0c<dDb<44a=D@g=SI5<C@g<T53<4I4<CPe<`dd@DHd=C53=392<d8h>3Tf
A4Hi=D8a@D4d>4HcA3Q2=S0b<S0f@S4d<495A3Tg<SA5@cM3@cM1AC@a=CL=@C=3
>C95<D=3=DDg@d@f@d4d<354AC56<CQ5A4A3<3Tg@cDe<CE6>C=4=S95ACE3=3@d
ACE4@C0f=C<i3CHf=T=2ACHa<D56>4@f<3<c<SL`@C@i@S@f@T8c@B1>A0d_F3Q5
820a>C4PDT@P<SA5@d94<3DcAD8iAT=1@C0g<CDf=3<d<C4`@S0a=3Q5<d<b@SM4
=34d<3Li<dDh@c<g>D@`ACDd@c963D8a<d4e<cLi>CI5=CDfAD<b@d=4ATI4>3I6
>CLd<c8d<3Di=S0b=3Hf=38e<3=1>4De@dE1ADDh>C12<Pe3<CHg<dHaASPh@T=5
=TDg<D4cASE4=SQ6ASPgAS=2@D<h@CA3=T8f>CP`>4Hf=D@d>3@a>C4i@C<h<C8=
ACDf=SI3@cA2=T8e<cA5ACPi<SPi>3DfAT<iAS4d=CLd=cI5<SA2>D52>3Pa<CE6
@SLf@DDaA3Df<cI43DDa@T91A3A6AC@`@dH`<S8iA3=5<SPh<cA3AT53=dE5=c<i
@C8aASPh<4I5@CHe=T@d>4Db=C8f=S@iAPdd=44iA3Hc=4I4=d4fAT@`<3<eA4A2
AS0`<496=CM6@C4h<CDgA3=3=DH`ATHf=c0cAT4i@TA3=T@`<T4=@TA4>38`=38d
A4Hg@S0e@S0a>C<g=R1>A0d_F3Q6820a>C8PDT@P<SA5@d94<3DcAD8iAT=1@C0g
<CDf=3<d<C4`@S0a=3Q5<d<b@SM4=34d<3Li<dDh@c<g>D@`ACDd@c963D8a<d4e
<cLi>CI5=CDfAD<b@d=4ATI4>3I6>CLd<c8d<3Di=S0b=3Hf=38e<3=1>4De@dE1
ADDh>C12<Pe3<CHg<dHaASPh@T=5=TDg<D4cASE4=SQ6ASPgAS=2@D<h@CA3=T8f
>CP`>4Hf=D@d>3@a>C4i@C<h<C8=ACDf=SI3@cA2=T8e<cA5ACPi<SPi>3DfAT<i
AS4d=CLd=cI5<SA2>D52>3Pa<CE6@SLf@DDaA3Df<cI43DDa@T91A3A6AC@`@dH`
<S8iA3=5<SPh<cA3AT53=dE5=c<i@C8aASPh<4I5@CHe=T@d>4Db=C8f=S@iAPdd
=44iA3Hc=4I4=d4fAT@`<3<eA4A2AS0`<496=CM6@C4h<CDgA3=3=DHf<SH`<D<a
@c15<c@f>D8f<C<=A3A2@cDa<S93=3@f=4=1<4E6A4<g<C@a84i43BmH>C0P838`
<21BA20b=4E3@T@`=C=5@SU6@d51<3La=CHd<c@a<C12<34d>4Dc@c92=d@d<C@`
=cTcACQ3<cLiA315=CA3<TH=@S4c@CDc=cTi=TDe=CI5@c93@dA6AT@h=THi=c@c
<S@`=CTf<38d=SHd<SD`<d4hACE3AD55ACPi<48b3D<a=SLcAS56>3Q2@dDfACLa
@C=6=D@f>4I6>3M6<d91@cQ1=4<f@SHi>30hASHeA3@h=34i<CU1<cPa<Pe5=CHf
=T=3=48f@SDc=4E5>3Tb>3Th=CI6@cU6<C@e=c@g=TDb=48i@D8h>34a=DI2=cI1
AC54=CHc=T@=AC52@T54=4I5=313AS0b<SU4<dDb>3Pc=4=6@D<gADDg<cU1<S56
>3P`ATE1=SDfA3@hAC8e<SHf=3U63C@d@CU4=S<dAT@g@CI6A30`<cE4A496<30`
@THe=dI1<CPa=CM4<d<eASHb@d4i@d@h<DDa=cPc=T95>0dg=44e=3H`>48eAT@`
AC8`@cM5AD@d=SQ1@dE3<cE4@SE6@D8hAS<a84i43BmH>C4P834i=b1BA20b=4E3
@T@`=C=5@SU6@d51<3La=CHd<c@a<C12<34d>4Dc@c92=d@d<C@`=cTcACQ3<cLi
A315=CA3<TH=@S4c@CDc=cTi=TDe=CI5@c93@dA6AT@h=THi=c@c<S@`=CTf<38d
=SHd<SD`<d4hACE3AD55ACPi<48b3D<a=SLcAS56>3Q2@dDfACLa@C=6=D@f>4I6
>3M6<d91@cQ1=4<f@SHi>30hASHeA3@h=34i<CU1<cPa<Pe5=CHf=T=3=48f@SDc
=4E5>3Tb>3Th=CI6@cU6<C@e=c@g=TDb=48i@D8h>34a=DI2=cI1AC54=CHc=T@=
AC52@T54=4I5=313AS0b<SU4<dDb>3Pc=4=6@D<gADDg<cU1<S56>3P`ATE1=SDf
A3@hAC8e<SHf=3U63C@d@CU4=S<dAT@g@CI6A30`<cE4A496<30`@THe=dI1<CPa
=CM4<d<eAS4f=C4d<c4a>D@a<c53=c4e@Pdi@C@b=3Da=C93>452@C=6@cU4@S55
A4<b<T@d=DDi<C0i84i43BmH>C8P83@d8594838dAD=2A30e<dE2=T<b<DDgA3I3
=3U2<C0g<CTf@DI5@SPd@c=2<CTc@cTg=c0`@c4e<cDi@CHiA48fAPe2<48a<4@f
A3=5<495A44i=dHgAC@d<C4dA3Hd84i43BmH>C<P83@e8594838dAD=2A30e<dE2
=T<b<DDgA3I3=3U2<C0g<CTf@DI5@SPd@c=2<CTc@cTg=c0`@c4eAD4a@d@aAC0c
@Pd`>C4d<S54ACI3@S0f=391=T91<C<e<C93<CA6A3@PCT@=;ePi=20P=C<PDT@P
<SA5@d94<3DcAD8f@c8aACM4=T<d>D8a<3La>CI1ATE2>3A3<d8a>C=3>CLg<313
<CE1=CHc>495AS=53C11<T4f<30c=SPi@C4a<D=6@S4hA3Lc=S<e@SPbAT@f>D4d
<356<c=5<c@b<dDPCT@=;ePi=B0P=C0PDT@P<SA5@d94<3DcAD8f@c8aACM4=T<d
>D8a<3La>CI1ATE2>3A3<d8a>C=3>CLg<313<CDc@c<gASA4<T@h3C<g<DH`@D<d
<TE3<c<h<c=2@SM4@d8e<CM1ASTgACPf<d8iACHe@TDPCT@=;ePi=R0P<S0g8594
838dAD=2A30e<dE2>DHc=SPfA3@g@C8c<4<`<S95A3HiASL`>C8g>4<h<SLf@C0`
=c@c<SQ5=CE4<C54@Pda@CM3<3T`=D8d=d93=CDf@dDb@THd=CQ3<3A5@SE2<c96
<SDiA44i>D<g>CHe<SU4>3Q6=SPbACDb<c@==dA1A4E1>3I1ASA3@CM1=4Hd<c8b
@cLg=3Da<d@b=C52<S4c@CE1<SE2=3PdAS4c<S@g>4HcA3Dh<dE23C8d@cDh<D=1
ACLd@T@d=3A2@TI6@CM4A4Da>D8iA4@bA4Hc>C@f=SM2<d92=c94>D@h@CDh=4Df
=3Dd@Pdf=SM2AD8g<CLhAD95=CHb<cQ4=d95=4A5@d4a=3TbAS<c<3Lg<c@e=3He
ACHi@cP`AS0i>C<g>DHg<48=<D8bACPi>CM6<cPc@S=5<cHdA4<i<3Pd>C<i<CU6
=44d<3<f<d<c>44i@C0h@d<dAC@aATHi=TI4=CTc3D4g=cM6=d4aASI4@DI4=34d
=dHg=SPf<455>C4c<CDf<4<`=3Tg<C4g@cM3<C4h=C8`>CQ5<21>A0d_F3Tg820a
=C4PDT@P<SA5@d94<3DcAD8iA44c<38a=38c<ST`<CPc>C4g=d55=48`<4Dc<T@h
>4I1<3D`AS@aADE3<S0`>3A43C4a@C@f@C8b@c@bAC4g>C53<cDiACLbATHb=C8h
>CPh=D53ASE4=c<b>CHc=T<i>CQ3<4<b=CM1@c@a<0dd=c<e@S52=c@iAT=1@CPg
>C8d<d<h@dHg>3E6@C8d<SA1=C8e<3Tf<D8a=S53>D8bAT8c=c56<C<f@T@=>DDh
>4E3<d@d<S11ACPe<S4c<S8c@D53=38bAT4a<3P`@cDc@D8h=3U6@dE5=30f<cA3
<CPi<3=6@SQ63CTh@T@c=396=cLh=4=6AD@h<cA6>C95@SE6=S<f<SL`ACPb@dI6
A44f>C52>4Hb<3Pe@d93A4I3<C0h=Pdf<R1>A0d_F3Th820a=C0PDT@P<SA5@d94
<3DcAD8iA44c<38a=38c<ST`<CPc>C4g=d55=48`<4Dc<T@h>4I1<3D`AS@aADE3
<S0`>3A43C4a@C@f@C8b@c@bAC4g>C53<cDiACLbATHb=C8h>CPh=D53ASE4=c<b
>CHc=T<i>CQ3<4<b=CM1@c@a<0dd=c<e@S52=c@iAT=1@CPg>C8d<d<h@dHg>3E6
@C8d<SA1=C8e<3Tf<D8a=S53>D8bAT8c=c56<C<f@T@=>DDh>4E3<d@d<S11ACPe
<S4c<S8c@D53=38bAT4a<3P`@cDc@D8h=3U6@dE5=30f<cA3<CPi<3=6@SQ63CTh
@T@c=396=cLh=4=6AD@h<cA6>D@b=CI4<dA6ATA3>CDe<CHd@dHh@T@d<T4b=SE5
=dDaACTd=C=4<R1>A0d_F3Ti820a=CLPDT@P<SA5@d94<3DcAD8iA44c<38a=38c
<ST`<CPc>C4g=d55=48`<4Dc<T@h>4I1<3D`AS@aADE3<S0`>3A43C4a@C@f@C8b
@c@bAC4g>C53<cDiACLbATHb=C8h>CPh=D53ASE4=c<b>CHc=T<i>CQ3<4<b=CM1
@c@a<0dd=c<e@S52=c@iAT=1@CPg>C8d<d<h@dHg>3E6@C8d<SA1=C8e<3Tf<D8a
=S53>D8bAT8c=c56<C<f@T@=>DDh>4E3<d@d<S11ACPe<S4c<S8c@D53=38bAT4a
<3P`@cDc@D8h=3U6@dE5=30f<cA3<CPi<3=6@SQ63CTh@T@c=396=cLh=4=6AD@h
<cA6>C0gASDh<T4i=c12<C<cAT<iASTb@SHh<cA1=D=5AT4i>3A2>4E6=0e5=3Tg
@SQ5=4E6=4=4@B1>A0d_F3U1820a=CLPDT@P<SA5@d94<3DcAD8iA44c<38a=38c
<ST`<CPc>C4g=d55=48`<4Dc<T@h>4I1<3D`AS@aADE3<S0`>3A43C4a@C@f@C8b
@c@bAC4g>C53<cDiACLbATHb=C8h>CPh=D53ASE4=c<b>CHc=T<i>CQ3<4<b=CM1
@c@a<0dd=c<e@S52=c@iAT=1@CPg>C8d<d<h@dHg>3E6@C8d<SA1=C8e<3Tf<D8a
=S53>D8bAT8c=c56<C<f@T@=>DDh>4E3<d@d<S11ACPe<S4c<S8c@D53=38bAT4a
<3P`@cDc@D8h=3U6@dE5=30f<cA3<CPi<3=6@SQ63CTh@T@c=396=cLh=4=6AD@h
<cA6>C94=C4b>CPiACDd>3U6@CU4<D=6>C0eAC96=3<bACM3@DHdACQ5@`e4=cA6
@CHi@cQ3=DHe=b1>A0d_F3U2820b<CTPDT@P<SA5@d94<3DcAD8iA44c<38a=38c
<ST`<CPc>C4g=d55=48`<4Dc<T@h>4I1<3D`AS@aADE3<S0`>3A43C4a@C@f@C8b
@c@bAC4g>C53<cDiACLbATHb=C8h>CPh=D53ASE4=c<b>CHc=T<i>CQ3<4<b=CM1
@c@a<0dd=c<e@S52=c@iAT=1@CPg>C8d<d<h@dHg>3E6@C8d<SA1=C8e<3Tf<D8a
=S53>D8bAT8c=c56<C<f@T@=>DDh>4E3<d@d<S11ACPe<S4c<S8c@D53=38bAT4a
<3P`@cDc@D8h=3U6@dE5=30f<cA3<CPi<3=6@SQ63CTh@T@c=396=cLh=4=6AD@h
<cA6=30b=dE1<4Hb@S12=4@d>3<iAD4i@d8e>DA6<CM3=394ACDh>C8eA@db<4E5
=3Pd=C15<SE3<SA5<44f<3U2A3A2<SM4@DE5@T=6=d92=dE2<SDc>4A3>C<h@d8b
AC=3<492=C0==c55=cDbACDf@c52>C<c=T8i<451=DA6=3Da>DA2=D@bADA3@cLg
=S<e<dH`@CLa=cU4>CDf<3Ph<c<`3D@`@C8f=3E1=d55A44g>C11=b1>A0d_F3U3
820a<SHPDT@P<SA5@d94<3DcAD8iAS<f>3I4=3M1A4A4<30h<3LaA4E5<3Dg<3<b
ATDe=CHbATE4<391AD8g<CLi=30a3D@bAD8b>CTiA3A6=DH`A3Ti=394@d4cA495
=C<e<CDe=4@iAS@h@T8fASA4>3Hf<3@iA351=SE3<DDb@@e4ASLa<d8`AS14@SI3
AT94AD96<cQ6=T8c@CLeA3M2=CE6AC93AC53@cPc<3<b>D@aA3Lh<c=3=T@gAT4=
@CPf<c0eA4A3@DI4<cLa@S=3=d8b<c15=c4g<CI5=cE2@S8`AC0g=SDg>312=d@`
>4Hc@THb=d8b=SHa3C0c=DA4@CD`@T<iAB1>A0d_F3U4820a<SDPDT@P<SA5@d94
<3DcAD8iAS<f>3I4=3M1A4A4<30h<3LaA4E5<3Dg<3<bATDe=CHbATE4<391AD8g
<CLi=30a3D@bAD8b>CTiA3A6=DH`A3Ti=394@d4cA495=C<e<CDe=4@iAS@h@T8f
ASA4>3Hf<3@iA351=SE3<DDb@@e4ASLa<d8`AS14@SI3AT94AD96<cQ6=T8c@CLe
A3M2=CE6AC93AC53@cPc<3<b>D@aA3Lh<c=3=T@gAT4=@CPf<c0eA4A3@DI4<cLa
@S=3=d8b<c15=c4g<CI5=cDb<CDb@SU1@c4f<C0f=D4a<D=3@d4dASTg=3M43CQ5
>CLa>C=5=c@PCT@=;ePiAB0P<C<e8594838dAD=2A30e<dE2>DHc=SPfA3@g@DA4
A30`>30g<DA5AC0e=c0c<TI5=CDf<TI5A30b@DE2=c4g>C@`<@e4<TE2<STi>D@d
ASE6<4@i>C@bA4=1<dA2ACDc=C4e=CA4>DHd>492=THdA3Pf=S0d>D@a@CHe@c55
<T4=A4Hg<C=2<4H`A48f@dI2A4E2AS<hASI2<d4g=D@g@SDeATDb@dDa@d<h<c0c
<SU4<D@g>3<c@cI4=dI13D4h=S<`=DA4@d56A3<g<D8c@cM2<S<`ACLa=c4fACLe
@T91<c4g=SU5@c0h@c=4>3@f@CHd=cPd<T4h<Pda@CD`>C@c=4<e<d8g=d@dADA3
A4@d=SI3=cI1=c8PCT@=;ePiAR0P<C<b8594838dAD=2A30e<dE2>DHc=SPfA3@g
@DA4A30`>30g<DA5AC0e=c0c<TI5=CDf<TI5A30b@DE2=c4g>C@`<@e4<TE2<STi
>D@dASE6<4@i>C@bA4=1<dA2ACDc=C4e=CA4>DHd>492=THdA3Pf=S0d>D@a@CHe
@c55<T4=A4Hg<C=2<4H`A48f@dI2A4E2AS<hASI2<d4g=D@g@SDeATDb@dDa@d<h
<c0c<SU4<D@g>3<c@cI4=dI13D4h=S<`=DA4@d56A3<g<D8c@cM2<S<`ACLa=c4f
ACLe@T8`@CE6<4=3=T8c<CDd<S4d@c@b=DDb=4E1@Pdc@T51<S15@C4`AC@g=C<a
ASLa=THc<T4PCT@=;eQ1<20P=CTPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=c0f
<C96=S91<CHbA3Hd@T91<44d>D92ADE2ACP`@T@`=3ThAT8i3D8a@dA3@SDcAD@g
<TE2<TDe@cPd@cI4<T51=3@a@THb@T53>4Hb<SQ2<cQ5<cU4>D8`@c=1<4A6ATDP
CT@=;eQ1<B0P<C<b8594838dAD=2A30e<dE2=SDd=TA4@C55<CQ3@S=2<D@c>CH`
=C4g>34f@C0e>451<T54<CL`>3Hg>4E2=S8a<`e3@T<f=SQ1A456=CA4=CHc=cHh
ATDaA3E3AD8h>4Dc<4A1=c=1@SA6A44d<3Df>CA2A3Pg=TDf=30g@D4==3<a<T@`
A3TcA3I3>C53ADDeAD51<c95@SDf>4E4>44g<DI1@CPa>CE2@CM6@SPf=SU4@cU4
>313>DE13D8`=SLg=cTb=c4b=495<c8`AS95<C4a<c52A34f=CA2>38gACI1AC4f
=353<T8a>D52>CP`@C14<CHb=@dh@CE6@d@g<cT`A48e=C8b<cDa<3Lb@dDPCT@=
;eQ1<R0P<CT`8594838dAD=2A30e<dE2>3Le<d=1=4@fASLa<SP`>C<i@CLg=c4a
@T8b=TI3<cDe<S92<3E5<T51@C=3@c95<@e6>D95=d<c<TI3<dHfAT@g@C@d=D54
ATA6=cPh<SPi@S=5@d8`=S0h<4H`<C<g=TE5<SHc=48a<30b@S<=<34b=TA6@c0`
@d<fA30dASE6>456@cLe<cA6=D<b>DDa<cI2<dDd=T94@S93<S<fA44d>DI6ACTf
A3923C<hADA6AS0gAS4f=CLc>CI5<dA1ACE1=C<f=SE1@c4f<S8e@d4i@C@e@CU5
<c0c=CDe<D4e@S4c<SLh<0d`=TI5@TI6>30dASDc=dA2@cHf@dE2A3M6=3E1<3=1
<TE4@D8`<d91ACU5<4Hh>C0e<C15@d94=S0hA3@==S93<S@d<THf=cE2AC0f<34g
>D4d<T=4AS4i@d52=dE3<3<`=355AT94AD8h@S8e=C<f@c4c=S0eA38`3C@b=TDg
=S@i>C8a=S0h@D<`A38b84i43BmH@C<P834e<R1BA20b=4E3@T@`=C=5@SPg=C=3
@CA4=T@dAS11<T8f<SDi=48h<C8h>DE5<cLf@S@c=SA2ASHh=CDd<cLc=cL=<T4`
ACA4@DDdACPb>C56<S53>CU5=D@h>454<3Lg=DHc<SDc<d4e@S<g=3<i=T=3>352
=48c<3Dg@c4e3DE1=3Di<cU3>3=4<S@dACLa<D@i<3Dc<3E3<3E1>C0`@cU3@C4a
<48`>DHbA44gAT92AD<f=3I5=c@a<@df<d4`<3E6>3@a<T@g<CU3@CQ3@c=1@cPc
<S8bA3A6<cI3A34`=C8g<d4e>3Tg<4@e<D8gACDfAS@f<CP=>3M1<CE3<S8a>3M3
ADDe@d@g=SE3>4<i@S54<c<hAS0e<cLg<CA6AT55AD@dA3@`@d53@T<e@d93A3L`
3DE4ASDPCT@=;eQ1=20P<c<e8594838dAD=2A30e<dE2>3Le<d=1=4@fASLiAT96
>CP`<CQ4A48e@T8d@CDb@CTi=CA4A3Db@cD`ASI3@D=3@`e5<S14<d8g>48h>453
=DE4=CLe<c51=CTg<DA6<3@hA48dA3M1@DDe>D56>4@c<4=1=3I1@C4fASLd=TH=
=4<`>4Dg>4A6A3DiA30f=CTb>C12<SA4AT55=S<bASI5=d@dACQ4=T@b@C8a<S<d
@DD`>C52<4@e<3@e3C51>3DeAT<d<d8`<TDc<D8c>C@b=38`<C91AD8g>D8h>3A3
<D94ATE4<TD`@d@h<c<b>C54=T<iA3Tg<Pdd<C8fATH`>30a=D8d<cM5@STdASU6
>38eASM6AS16@d@a<4I2<48b=4E4=3Pb=cA4ACI5@CA6@DE4=d<=@D4fAT8c@c15
<T8c<cE5>315<cD`=394>DE2AD92=S<bACLe@SI2@DI1AD=1>DE2>3<a=3M1>D@d
<4=63C<f>394=SPdAS=6<D@b@S8h=C=2=4<h@dH`<C8c<SLe=cD`@SDaA3T`=SDi
AS<b@dI1=SPg@S@eAD4h=`e4=C4hACDeA3E6=c8`=TI3A4=3=34g=CDb=30d<S@i
@TI1@c<e=SHfA3E1A34c<C@d<3Q6AS0d=cPaAST=<C52=T4h<c@b>D94=d91>CM5
A3L`>4E2=393AD8fA3=4ACA6@STf=S=4ADDb@c0`=cLiAT@g=C@b>CDh3CPi=C16
=S8h>CDc<D<fASLf<CPe<CPcA453AT53AT8bACDh<d91=S8iA30d=3Hf>C=1=c@h
<SDb=3Hg@@dg=T4`=T92=cLe<T4a=T8cAS4i@D=2=cLg>CI5>CM1=S=2@cDiAT<i
AD4b=4De@D@h<d8`@CU6=d8b=3H=>CU1ATDb<C8f@b1>A0d_F44e820a<34PDT@P
<SA5@d94<3DcAD8h=cDc@d4dA3I6>4I6@S=6=d4`@S0g@D94<3=4<D4e<c0d>DE3
@d@c=4=3<CA3<C@h3CU6<C<aACA5>D53A38g=44c@SHf>4DaA48eACM1<D<`<48g
@c91ACDh=T@i<3U3>DA2>C0c<T<d<T@i<`dh<d8c@dHeA3D`=T8d>34i@c4a<cDi
@c@i<d8d>CA4@cA1ASDh=DI1A3LfASDcA30e=S<dA34eASU5=D<==T8a<d8d@S@d
ADE6A3=1=C@e=34d<R1>A0d_F44f820g=b1BA20b=4E3@T@`=C=5@SPg=C=3@CA4
=THgA3Lh@S4d>D8a=SA5AD@d<3@g<D=5=TDhA3A2<3Dd=S<`=3Dh>CP=@D@a<CHg
A48a>3Ld<D=6ADDaAD8b=d92@D@f=3E2ACH`>4E6=c<b=S8g@d8b>C=3AT4f<dHb
=DDc<3Hg3CLh>C@c@CM5AC<cASE1<SHiAD=6A30a<dE6=CDe@D<h<T8PCT@=;eQ1
=b0P<S@e8594838dAD=2A30e<dE2>D=2<STg<T=2<TA6>48dA4A6>D4a@S=6=4=4
=c8c<T4i@T96=T<i@SI2>4I5A44`<`dc@CDf@SM4A4I5=3Le<CQ5=DHd@cDe@TA4
>C0`<SH`ADHa=3<`=TDb=3E1@S56AT8gAC92=3I2=4Db<ST=A4@c<d@b>CLb@CQ3
=34g=DE2ACU2=DHc@SHi@SA6@C92=T<f=3Lb=3M4<c@c@cE5=C8g=T8i@CU2=CDh
3C8bA3E2>4@g=453>3I5<4@`@dDc>3@g=494<d4f=c8g>4Dg<cE1=3Di>3Lh@T8e
AT53<T8bA3@`>C4c@`dh@DA3ASTf<cQ4<dDc>CTc=455>4De@CM5<DI2@d94@dI5
@c<e@SHfA396=d4c@CDc>CHh=T=5<dDh=CP=<SE5>395<c=2@CA2=T=4@S8a@D8h
@CE6=3M4>DE6=d4cAS54A38f<S95>DE4ATI2@c53=d@f<SU4@d<e3CI4A3<e<TA5
=d@`=CTc=34b=S4e<C<bA3U5=TI2=cE2ATDc=4I3ATI1ACHg@CPc<SU4@T8h<d=3
@S<`APdi=TE4>394AC<e@TDf=DHi@SLe<CQ6AS=1=d8eAC0b>DHi=DHfA354@d4g
@cDh<S@e<T51=cE5>311=S0=>4I5>C8i<CDhA21>A0d_F44h820c<C@PDT@P<SA5
@d94<3DcAD92@cHe@c0e>D<gAC8c<4DiA3U3<355<C=3@dA1ADDa<S8g=T4f=D=2
<S=1<30b=4=33CHc<3U1@DA3<D@`=CE3=T92A3U5=c8g>4D`<d4a=D53<CA3AD51
<D51ASPdA313<T<g@D<`ACE2<3Pi<@e6@C@f=cI4AS<i<d4d=SQ5=DI4<CHf=CHc
<cM6<S@e<dHd<C4bAC0b=c4i<S92<c4a>C0gAD@`<3M4=TD=>DHc<T@aAS=4<3Db
=SE3>C4`@D@e@d8d<38`>3Q5<S8h@T8f<CLg=30b<SPdASDe=CI4ACHd>DH`>3Lc
3C@f@CHg@T<`=TA2@CQ6A48e=4Hc=4@h>3@f<THg=SL`@SPeA3Ta<S@a@cU2<3Ld
=CA1A3@bA4HaAT8i=Pe3=c4`<dA2>CI6=CPc>D52>3HdADDh>C8c@cQ4<CDg@c92
=cQ5AS8g@c8h<DDg>DA5@S<e=c<dAS0dA4H=@C0f<S13@d51=T4a<d4d=3U4AT8a
@c53=3Lg<TE2=SHd<d<fA316>DI1A44hACP`=4E5@S4f@cA3@c0`3CP`>495@c12
A34i>3He<T8`AS@f=3Ph=dA4@C4eAC4c=cPc=38bASM6AT<`=TD`A4E1@cM3<D<b
>4E6<`e6=34h@dHi<4<`@c93@TE3A34c>4@h=T@d@S56>4A3<C@e<T8a@S91>CTd
ACPa@TH`@cA6=CQ6>3Pe<c4==c<h<3A3<S51<34bA4HhA34g@cLg>CHi<S8g<cI4
@d53<4=6<S<c=d=6@S4a=4I5@dA4=SPg@dDc>44f3D=6=SPb=DE3=c8h<T<b=dI1
=S4f=3He@SE3>D@PCT@=;eQ1>B0P<SPi8594838dAD=2A30e<dE2@T<f=D<`=CU3
=dE3A4HiAT4h<3Td<c0a<cLd=3HdA4I2=CT`=DDe=d8i@d92>CM1A@d`ASLh>3Pa
>3<c>C96>38`ACPh@cU5<cLi<d8g@d@f<cPe@CQ1ACHcA3Q3>3<f>3@c=3TeASPg
ACE5@SD==THb>4I2>CLb=453AS<f<CA4@SU2<SLh<3M2=48fADI2AS@h<SHaASDf
=cLi<c=1@d=6<c0aA3H`@c8h3CTh<4Hh=C4a=TD`=CHg<cDeACLgA493=DDi@cD`
AT@a=3A1=T54<S8a=C8h>C8gA3Q5@C8eA491=3E6APe6=3<iADI3AT8h@cHc=T95
<THh@C4c=3I2>D@a<3PbA44c>356<d<iA3Hi=3U6>CTf>D4c<cHg<S8hAC<=@CPb
=S@e@D54=T8b@C4i<311<c8fACDcA3M5>38h@S12=CTe@S93=D8d<cU6@SQ2<T<b
=SDh=D<hA3Di3DDh>393>CTh>4I1A3Dh<T@h=SPe=T=4@CLf=38f=T8f@CHiA4@e
=3@dASHg=3I3@S54@T@`AD94=C@eA0db@c0`AC8`=S<a=T<gA4=4=d@a<SM3=SI5
<c15>34e@TE2=dE4>C0d<CU4>CA1@CU3=S@f@SE2AC<h<C<=>3E6<c8d@cHa@DE1
=S8d=d<i<3I1AC4d@S8d=48g>3U5@d@h<3DcA44a=30f<3Tb=CTc>D@b@d92<cHa
3C8eASDf=c@i<S4d@cHc@CLh=cLd>44dA4@iAD8h=34gA3Ti=3Hc84i43BmH@D4P
83P`8594838dAD=2A30e<dE2>4@`>DHfA44d@c4h@TA1>C4`<cTe=d4gAD4bAT<e
>C4g<CHf=S@b@C8`=4=4AC@h@`e3>C=3AS=5>DA2AT4c<CHb>CQ6@c@d=dHeAT@e
<C@e>DDf=c4g>4De=DHc=TA2AT<b<dDcAS12A34d@cH==4<e@SA2<4=3AC8a>DA5
<4@b=4DcADHh<391@CDe@D4g@S<e@T=4<b1>A0d_F452820c<B1BA20b=4E3@T@`
=C=5@SU3@S8i=c93@S0iATDi=C8d@STh=S0c@C4d<cDi=S<e=CQ1A3Lf>D93A3He
=c14<TD=<dHPCT@=;eQ1@b0P<cLPDT@P<SA5@d94<3DcAD8i@d8b>CLb@d8`>D<b
AS=3<4I1>C<h>4=2@T8b=SDfAT=5>3E4<38g=CI1@D<d=d<f3C56<c8c<TE5=3Li
=SM584i43BmH@D@P83La8594838dAD=2A30e<dE2>3Le<d=1=4@fASM5A4A1<SI5
=C4`@c<e>353=dA3@cLgAT=6<T4g<d@d@c<bASQ6<0dd>CTe=D<e@cM6@SDi<S0e
<4E5=d96>3U6>3Hh@cM4<C8`<dDhA4Db<DI2=d4fASA1@cDd>C<i@CU3<4<=A4@e
<395AD4`=C92@c0`@THiAS0aAB1>A0d_F455820g>21BA20b=4E3@T@`=C=5@T92
<CI6@TDb=3Tf>34e=CM6<CE1=C<d@cQ2@d4d<4<i@c0b=SA3<CE1<SM2=34i<C<=
>44h=CHf>4E2@c=3@d96<T8h@TE4@c12>48c>38b=453=d4d@STf<S@g=CLf<c4f
@C@h>D=2=CA5>C8i3CTe=c=5>CTh=C@a>C@`=4Dg@SPb<dE6>C<f=d8g<DE4A3Ha
=21>A0d_F456820b<3<PDT@P<SA5@d94<3DcAD8h<SU5=3@d@S0e=STe@cTi=d95
<T94ADHi>34iASTf<STiASD`@d55@D94A4A5=3Df3CA1=S@e@cTg>C0a=D=3>D@e
<3P`>DE3=d54=3E1=cLg=d92<352=d<b>3M2A4H`>CTa=T@i>C<i=3@f=Pdf<4A1
<c0eA3L`A4HcASLb=dHi@C0c@S0e<453ACTc<C0b<4@b@D8eAC@d<38e=CQ4>3Li
<T=1=T@eA30==D=1AT8c@S4`=dI5>D8e=CH`>351=3U1<S91@C8f=dI6>C8`=cE4
<3Hf>CTcAC4c@D4i<SLbA3Q4AC133D92<DA5ASQ1<D<`>4E6AS<d<D=6=d92=4A6
<CTg<C91@c4h<4A2ASM4ASDhA3U4@ST`=3Q2=S8f<S=3<`dg=D4c@c0b>314<SHc
@S0i=d=5>352<3=3>3DdACHi@S55@d4cADE4A4@b<4<i>CE6ASTe@D8f=CHa>D8=
@DDa<STc@cI4=44b<C4i<30c=D@dAD94>DA4@TI1@SDiA3A5ACDd@D=6=4E1@B1>
A0d_F48`820b=3HPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6>316<c8e>4@c@cDf
@THb=C<a<3Db=T8a@d8a@DI3ADHf=cM5A3<a3CM1A4=1<dHg@cM4=30e<TE6A4H`
ATDe>CDb<3Td<30a@S4aAS14=cA2>D@b=dA5<S@c=4E2=d4`<CDf<0df=3Ti@dDf
=TD`@CPi@T=5=D56<d<d=34g=4<b<cQ2@S<d>D95@CLc=TH`ASTb>34c@S4d@C8e
A3U6<3P=@T8hATHg@D=2=T4d=S<aATHi=SA2ASM5=TE5=SM2<3La>CL`=dI5<T52
@S<i=d<b>44b@CTe@cTaAD@g3D<d<CHi=CPc>CLb=c8i@cLe<SE1AD@g>DA6A356
ACPh@TI2<DDf@cI6@SPf<TI1<d95<38d=cI4=S=5A0e4=4E1=T4g@D<b>DHh<3Le
AT8i@C=6<CTc@cA6@cPi<D4g=3Tg<38cA3M2AC0d<491>CM1<3Hd@CE5AD@=<CPi
=cDb=4<`>494<S0c@C52=D=1<3Lf@c<d@CTc<D95@T8b=cLaA30gAC@a@CDfA391
ASE5@C=2=C133C53@SQ2>30e<4Da<D55AC0cAD4h=d=5>492@CE2ACHf@S<d>3I2
@C<b=4I5=dE1=3Q3=3Lc<315=TE5=Pde<cTbAC<b=CT`<T8PCT@=;eQ2<B0P=S<P
DT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=dE4A3Db@d@g=3<f=3L`>3Q4=cPh<S4`
<38c=THi=3Ti@d55<4923CLd>C4iACPa>DA4>3A1=C0hAD4i@d4d@T56=d4d=4Dh
=C<f=cPa<S4cACDfASE3AD54>CHh=T53ASHd@`db>495=T4PCT@=;eQ2<R0P=CDP
DT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=dE4A3A3A4E6>38eAT4i=CDi=3@b<3E1
ASE1<4H`=C4e<c=6=SI63C51@SDbADHe@S<a>3Dd<TDd<C<c<D4i@dE6>4<b<CDi
<CI4@D@b@SHh>4<fAD96=c8e84i43BmH@S<P83Dd8594838dAD=2A30e<dE2>3Le
<d=1=4@f@cLi<STd>44`@CLd=S51A3Ph>453@c8f=SPh=3@hASA5>494>3=5APdi
=391@CP`<dDa=CPeAT4`ASQ6=TDaASTb>314A3Dc@T4`AD55=c0c<S=1<d54AC8P
CT@=;eQ2=20P>3<PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=c0i=38g<4A1<C<d
<48e=356=CDd=d@i=D92<D8d=3M2@cDc@CTe3CE4<TI3@dA6>34g<T92>D<d>3<i
>D@e>4@e=DI6ASTa>D=6ACTg@cA1<4<a>D@a@TDb@T54=DDd=STc<0e1ATHiASHc
@cDd=S96<CD`<c4hASHh>4Hi@c4f@T@h=351<S@i<3Pd@SLbAS<`84i43BmH@SDP
834a<R1BA20b=4E3@T@`=C=5@SU3@S8i=c93@S<c<dI6=3U3=d4iAS0b@C11=30c
=TDg<STd>48b>D4h>4<g<SU6>C0=@CA2=3@dA4<d=d96>CLe<dE3AD<`ASI1<3=2
@TI4ACQ2=DDb=THh@CI6@D=3A4Dg=c11>3U5<S@a@CPb3C95A48e=CU4ATA2<44g
@TH`AS0c>CPh=D4`A4De=356=cPe@d8`>4I2=4<`@D<g<C8g>C@h<S<`<3<h<`db
=c4gA44g@D92=3<g@d54AS8c>C16<cI1<d8dAS8f=DHg<T8e@DA2A3E2=21>A0d_
F48f820b<3@PDT@P<SA5@d94<3DcAD8h=3Dg<44b<3U6=S53=SI5=T53ADE5>4E5
=C0b=4E1<3@d<4@g@S95=dDe=cHg>D943CDg<34b<48cA4@b=4Hc<3TiA30h<TH`
AC0d=CLb<48hAS8g=cU5<dHi@cI6>DHa=3@c>DI5<CPd@S@f@`dd=4A4ACDhA4<d
<SDbA34cAS0g=4A1@S8gAS11<3HbA3P`<356<S4cAD<c=C4d@c<`<CLf=D54@d@b
@T8==S96@d<a<3@a<4<iACHa<CA5ADDe=3I5<THa=D53>3@a=SLi<CLgASA3<TDh
@S94AC<e=C4d<T4g@S963DHd<d4b>34dA34i=3He>D4iA4De@d54=3La@d@f=CHh
>3@f=D4cAD53@CM5<d8dADA4<C=6>3=3=4Dg=@d`@T@d@DHh@D4f@c91>3=6@cI2
@S@g@CA1ACTc=4D`AS@b<C<d=SPi>CPaA354A4DgA3Te@T8g<30aACD=ASTe<S8i
<4HhACPc<S94=c8e@c<g@T52>3Pa=c=5ASLiASA4<T8b<C=5@T@h@D9584i43BmH
@SLP83Dg8594838dAD=2A30e<dE2>DA1<c0b<C@b<dA5=T4d@c0fADI6=3@`002Q
0<0ood@i<T8d=dE6>D95A4<h=451>3Tb=D95@T<=@T=6=3Dg<D4e<SU4=C4c=S@c
<3M1AC52@cU4<T<f=314AD8`=D4h>3Pi>4Hb>3Q1@C0`@THf84i43BmH@SPP83@g
8594838dAD=2A30e<dE2>4E4ASTg@dDe>DHaAC15=TDi>3U1@SM4=D<f>C0`=cA3
=T<h=dHe=3A1<T53@dI2A@dc=S<a=d92>C4`A4I6<3Te@c4`=d4h>D@f<C0`<3Lc
=C1384i43BmH@STP83Pi8594838dAD=2A30e<dE2>356A3@f@S0e=cDiA3@f>CI4
=454=3Q6A4A3<SI2=d55>4HiAS=3<dI1<S0d@cM1=`e2AC8hA34f<CLb@SPi>D52
=C<aA3@`<4A1>C<d<3Ph@dD`<4E2@cQ6<CPiASM1@S4e<T8bAT91=3U6ASL=@c11
>CA5AT=4=STc=T=2<4HcAC8f=311>312=D8c@CTb<4HcA3Hb<T8hAD@e@c=4=d4h
=d<b<3@iAR1>A0d_F491820b<CHPDT@P<SA5@d94<3DcAD8i@SL`>CT`<CA6=CM3
=c91A44`ACHh=4HdAT@hA3L`<S@c<CPbA3M5@cH`=d8a@S0d3D8`=d<g=S16<cQ6
@SPa<THd@T8e<DA1ASDe<3M4<cT`>3Hc=DHe@T8d@cA6@C@h>C0c<c0i=3D`<d<d
=0di>3A3=3A3<d@f@C4`>4D`<3Th>C8g@D@g@T53>4Hd=cHaACPh@cDe<452ACU5
=SLe<S4a=d<aATHf>D<==353=DA5A44`<30d<d@a=SHe>3M3A4<c<3I1<d92@T@g
<393ACM6>454=4<aACM4@DE2@D<i<cTa<cPe3CE6=dE6=3E2=T54<D91=dA3@dDc
=D<d>CPd=c8c<c=5<D55ASI2@c15>48`=T95ADE2@TA3AS92ADDfA0df@T54<CDd
@d4iA4=5<3<`<T4`@STg<SLbATHf=cM2@S<g<351<CDc<T<f<3@`>4E3=CA2>CLf
=cA5AT8=@T=3<cHa=dA4<d4i<SA2@S8i=c<b>3A3@S53@CP`=DI6<SDb=T8f>CDa
<392<C0`AT52=CI1=c<c<T8d3C4i=c8`<c8a@c4b=R1>A0d_F492820b<C4PDT@P
<SA5@d94<3DcAD8f=D=4>D8a<C@dAC4c>315<d4a=cDc=T@f<S56A3Lf@S0c=D53
<S<h>C=2<CHi<SDe3CLf<d8a<D4g<cH`=D<a=cHf>4HcASDg@CQ4=S=2=48iAS8f
A3E6<dA4=C4e=dE4>3A1=D@a>3A3@SPi<@e3<c16A313<DA3<CTc@CHi=C8h@SDa
<CM6@dHgA34f>D91=D8c>3ThA495<3Tc>C=5<d4d=cHh>DHc=cT==3A3>4E4@TA2
=3U6<312>CDcAC<f<30gA3LcA3=3<cLb@S0f<DDb=3Pc=c54@C@e@TI3AC@hACTb
=cPg3CI1=d4f=4@a<38c>C8c<S96<4A2AC56@CHe=3@i=dDg=T8h=T8d<S16@c4h
=T@f>4<`@SPh@T<g=4D`@PdcASHi>DHa<34d>4Hi=4A6<C@h@SHhAC12=3Tg=TI6
>3<i<3Td@SD`ATHi<cTd=D<d<d4e>44eA3@f>3@=>C@g=SPe=THcASLh=d4a<CDh
<dA3<S93=D<b<S=4A3Q4=SDcAC8b<44a=DHa@cHa>CQ1@S@d=cLh=CHh3D@g84i4
3BmH@T<P834c<R1BA20b=4E3@T@`=C=5@STbASDg=c<g@C<eA4=3@cM1ATA3<cA4
=3U4A4I2>4<i=SLf=d95A356@CDgAT<cAS4=<34`<C4fAC8d@c54>4A4<30c@CP`
@c@i=c@h<T8fA396AD@h@CA3AC<cA3E4@TE6@C0b=cQ2>CTi@cHd3DHcADHf>34h
=TE2AS4`ATE1@dHg<d=3<SHh@CU2@T96<d<`AS0bAC<d<d8h=D<c<TDc<C8b<313
<TE6<Pdi<T<f>30g@SA5<CU6<C<a=cI1ACQ5A4Db@CA6@SDb=30`@d8f>C55<T52
>44i=C4cAS<c<3M5=3A3=T@=@d8i<S56<cE2=cLe<C@d@SU1@SI1@SHa84i43BmH
@T@P834g=B1BA20b=4E3@T@`=C=5@SQ5A4Hi=d=5=CU6@D@e<T<aATDa@CTgACI6
@CTe=4H`=CHhA393=C<hA3U2@dI6<CL=@TA3<cPdASU1>D@c=C@g<C4f@TDb@cHd
<38gAS=1<cU1>CTa@S4i<cLfA3Pc<C53=T8a<4I4>DA3@cA23DHf=c15<C@h=S55
<c@b@dHf<cI2@c8g@D<cAS52>C96@S52=3I5@d94<DHd<c0b=352@S0cAT8a<STh
=@e3AD8b=C=5=dA4=d4d=D<g=c<cA4<d<DA6AC0`ADA2=CI2@S8f<392=4<h@SI6
<d4g=CPf<d4f<CM1@S<=@STe@C0b@SLb=C4`=S0b>CA1@SI2<T4h>3DcATDi@d<a
A4A6ACPc@D8g<c4g=3HdAC4b=D<a=D8gAC123C54>355=cPa>C11<4I5=34i>CPg
=3Da=DHi=34a>C8iA4<d<TDa<DI4<3Di<c0d=38a84i43BmH@TDP83<f<R1BA20b
=4E3@T@`=C=5@T96<DH`=DHh=CA3<3Pc=CM6<D53=TI6@D4gA3=2<d4iA30e=cPd
>DHiA3E1AS8a@c<=@STi@SDg=SE6<3U6@CLa=cQ1=c@i<3Q6@CQ3ASTg=d=2=TE3
@C8g<T=4A394=T@h=T=1=TI2@CP`@TE53D<f=C4aA3T`=d4h=3=2=C@h<453=c0d
>3Tc>DDdA48e@C<i>CTh=dE1AC54@cHe@DDc<S4h@T51@C4`@@db=454A4<e=3I4
>4<`>C<`<cDg<4<d=456<SLcAS<fAS96ACA5@DA1@T4i<C4g>DHb=c=3AC<g<C53
<c<=>C8f<CQ2=C<d@d8f<S=3>48g@T@fAS@i<d<g@SHh<D8a@c95=CE4AC@e=CE1
=4=4@S<e@cA3=d@dASI13CE5ASDg=CTc<CPc=c0i<C0eA3Ph=d@`<4@h>CTf=SU2
@S=5<C=5AC12<S11=3<g@c8e<3=5@CE1AC0bA@df<DE2>CQ5ADDh<34`=C8b>D8f
<CPg@d=4=D91<cE3AS0b@DHg@T@i<DHi>CDdASA2<CPc=D<b@D96@c0=@S<g<STf
<THe=4A5@c92<c<fATDh<S54=dH`=c8g=cHi>C15=TA3<cU5=c0`=S@i@cLaAD=6
=313>DA23C0i<3A6ADI5>4@cA48gAD54AC0`>3A3=c<f<D<d=SDg=4Dd<STh@SLf
<D95>3U5@T55<cA4=CE6A3LcAPde=CM2A3P`=cHc>3Da@CTb<T8`=3Pf=c14@T93
=THg=d@`=T8g@S55@DDb<cA4>C=5<dI3=3@h@c@i>4@=<D=2A4@`=C<g=c@`=CHf
>394=S<h<c=3<S0`<C<f@DA1=3A5@CPi@DHa=D@i<S55=3Ta<cH`A3Hg@C933C8e
<dHf<TE4ACDdAS8a<D4b<TDe<d8h@T55=T8a=cHf=c0`>DE2>4<bA4Hb=S4e<DHd
<CL`<THb@DHf<Pe4>48`84i43BmH@THP834g>B1BA20b=4E3@T@`=C=5@SU4@C<`
<S4d<S<b=492@dA5A44eACQ5=C<bASHb>34e@SHh@SM3AC@f=48a>30eA4H=@CPf
AS4a@cLb=C<gAS<g@c0e=CU3=T91=3<g<SDe@CD`AC0e<c0e<3A2=3Ti>3Q1=SM3
<4@c<d95=CA23C92@c55<d4`=CTi>DDa<CTa=D56@CM4=CLg=CU5A3Pf@cLfA3E5
<cE1@D<e>CI3<S91@THf@TDc<T4aA0deAS16@T@b<d8bA3U2@C@i<SPd=d8`@C=5
@dDh=cLd=S=6<DHh>38f@d4f<d@h=SM1<C4a<dHg@D@b@ST=ACD`=3T`=C<b=T4i
<CLa>48f=30a=DDc@c@`@D@`A3@b=3Q1ADDeAD@gAC<h@S8e=T4`<dDf@SH`>CU3
3D4e>4De@SLd<CD`>4I2@c=3<d4h@SA2<T<e@S<e<d96>D@h>D<`=T4a@cM1@cPc
AC<e=c@d>CQ2@SPPCT@=;eQ3<20P<CLc8594838dAD=2A30e<dE2>DDd=30a<SDg
>DA4=cE4>3@iACE5@T=4@c<f<cL`<30b<STg@D@b@DE4<D<`@c8c>@dh@C@e<c8f
AS11=d8hASE1<CDc=c0f<d<a<S0f>CQ2=cU6=c8`@T=1<dE1@S94ACA2=cQ3ATHd
=d@b=4H=<48g<S@c@SA6@SU4=SHa=c4h<4I5@C<d=c92A38h=C8b=3<eACE3<S<c
A44i=D4eA3I2=3<d<SA3=c0d3C4`=STi=d94>CLf>4@fA4E2@THb=c0i@S0h=DDi
>CPi<d96>4@`>DE5ASHd=3A5<3@a<dHd<T4hAS=2>@dc>3HaA44e<44d=CT`<4@f
<S0c<C@g>30`=S13@ST`=4<e@C4d=S0iA3@h>4<e<4@g@DI4>3H`=dA3>D4=A4E4
@cE4@DHg=3Q5=3Pb@C<e=C8aA4H`@D@e@d92@CU3>3<a<3HbAT4b<3Ld@R1>A0d_
F4<a820d<R1BA20b=4E3@T@`=C=5@SHgAC<c=T51=3Lb<S92<STe>3PgA38fAC4b
<S@`<dDi<dHe@C4h<3@cA3=4A3I2<d<=@c<h@S0e>DHdAS<c@cHe<THe<TA3@S4c
84i43BmH@c8P83<c8594838dAD=2A30e<dE2>3Le<d=1=4@fASM5A4A1>DA6<30g
<S8`>452=SDi=S11>CLb@D=6@S8b@S0aA3M3@Pe3=3<b>3<PCT@=;eQ3<b0P=C0P
DT@P<SA5@d94<3DcAD92A3=3<CE4>CI3AD<eAT<gA4E3=SQ6=T56<34b>3Lg=48f
A3I5=DA6=SM4>C0c>C0a3C8cA3U4<dDb@d94>4A3=cPd>CPi<44d@d95<38c@S54
@D=6>CPb@CLPCT@=;eQ3=20P>C4PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6>3U2
=C8c>CDb<cI6=C@`<DA5>3Te>CE1A3Ld@DE4@d4d=3Pg<d@g3D<g=CHa<D<e<dE4
@T@cASU4=DHeA3=3<38c@DH`AT@a=D<f=C4eA3I2@c@c=cHeAT@fA3=5>CPd<3Q4
@@dg=4Dd<T8b=C4bACM1@D4cADHh@DI2>3Lf=c8i@DE3>C@h=34fA451ACE6<SPb
<cDf<CPg@CI5=CTh@SH==d@PCT@=;eQ3=B0P<SHe8594838dAD=2A30e<dE2>3Le
<d=1=4@f@cLi@CDi=48g<S4c>C16@C0i<T<`AC@bA3<bACDf>D<iA316>DDf@Pe2
@cPe=c0a=cThASM2>DDc<38a=dHh>3=4@cTe<4<`ADHc<3DiAT@fACI1ADHf@C8g
A456AS8c@C4aA30=@S0c@c4d=SHg<CTcAD52<cA1=S0a<SL`=CTe>D4a=3M4A3De
<CA6=C4iADI6=SA6<D4g=S@cA3PeA3@i3D4c=3Q4=CI5=c<`=d56@SD`<T51@cDd
<T4h<SPa<CM3<CPi<CHf<4Hd>CHhAD8b<4Hb=3@f@CDc@dE6<`dh<C8g@S<b@TI1
=S@e=D4aASE6@cPa@SM5<44b@THb>30b<T8e=SA2<dDa=c@h@T4i<C0i<C<e<C0f
>CP=>CTfACDa=CP`A4@`<TA2A48c@TA4=3U1@c8a<d<aA3L`@cLd=3=5<S0c=SQ3
=D92=391<D=5<cLd@SI13DA2=DA2<cI3>396=DI6@d4i@SDe>DE1A3A2@c4f@SHd
@TDf=S0e@SDd>DA1=44i=CM6<dI5=3E6A3Pi=`d`=SDa<S11A453A453ADI4<cE2
A493<T94<3A3<3Pd=c4f<4=5<456=D4a>3T`<dI4<D96=4Hi@cA3@D8=>3Ph@DHe
=T4dA4@c@c0f<S8`AS0`@T52<SDb=cPb@CLd=4=2>CLf>3Q5=3E6<c14>D<PCT@=
;eQ3=R0P=C0PDT@P<SA5@d94<3DcAD8hA30iASI4@C@iASE5@S4eA34f<CE1>CHa
AC<iACDa@C56=SU6=3Lc>4DgA3Pe=SLe3D4e=C@c<T=2<d4fAS4d=SLc>315<CA1
A48`@cDbAD=3A312=4@gA30PCT@=;eQ3=b0P=c<PDT@P<SA5@d94<3DcAD8i>38d
@C0f=3Tf>CM5>C0g@d4d@d<d>3Dh@d<e<c93@T96=S<bAT<dA38fADE1>CLe3DI5
@cDh<3A2<STd<4A1@D52<44h>C8e<DI4@T@a@TA4@CPc@C=5<C8i=3@b=3Lg@DHi
<34b<c4c@C11@PddADHa=TE5AD94=3U3@T53A3La@DE6=D93AB1>A0d_F4<h820g
<b1BA20b=4E3@T@`=C=5@STh<SA1<3Hd>CHi@c4i>C93>CE2AD@hAD=2<CU1<3A4
>4Dg@SQ3=3@h=DD`@c4c<D8=<cHi>314A3@d<TA5@C16<D8c=C4f<3Lf=S@c@TA6
@DD`=DI5<C4e>4=3>34i=CE6<cLh@cHfA356ADI23CTb=4E5<DDb>4@e@C8e<S8g
<TA5@cDb=T4g84i43BmH@cTP83Di8594838dAD=2A30e<dE2@SE6=4E1AT@f>C@b
>30f@CLd@dA4AT@c>453@D=2<S0i>30d>4A3ACDe@cPg=S8a@`e5<T@`=T4i>C4f
=d=3>34e>C51ACHi<c0f=S0e>D95@TDh=dHfA3@e=C@gASI1=493<4He=d<a>4<c
84i43BmH@d4P834b8594838dAD=2A30e<dE2>3Le<d=1=4@f<3I3=B1>A0d_F4=2
820h<21BA20b=4E3@T@`=C=5@SPc<CDa>C55AS0i<C<e=DDf<c4iA3=6>C4a<3Df
<D=5=44b@THh=THg=d@g<D8a@C<=>C=6=DDa=4E4=T<g@c=3=d<b<SU1<cM6A4Dc
=3Lh@S=3@S93<C0gATHc=c91=D<d<cHc>38a<S0c=STc3D8i=44e<D<i@THi<D4i
@T8i@c52<3Pb@SQ2@d@g@SI2@T93=CLc=c0PCT@=;eQ3@b0P<CHi8594838dAD=2
A30e<dE2>3<a=C4i<DE6<3Ta<cDeACHc<CU4<dHi<C4`=CHa@dDd@C92ASPfASLg
A3La@S51<`di<dHeAC4dAD@f@cM3<d<g@c8b>D4c=dI4AC<d=cQ2<d=2<T<a<3M6
AS<g<T4e@c@c=S<h<S4b<3<f>34=@d@c=S95<T@gADA6@cM1<c0g=S0g=S<h=4<b
<C4`=CQ3<30f=cPaASE3<48h=C0b>30d>C0c>48d>4<d3CE6A452<CE1>4Dh<DDi
AC8c<d8bAT53=cA2A3Dg>4<cADHf<dHd<SLiAT@c=3LfA4Db<S15<C@a<C4g=0e1
=4Hg=d51>34b@dD`=3Pi>496=SLi=CQ2>355@C<cA30d=3A3@CTb<3M1=c<`A4Dc
=355>3M3=CDc<3L==c14=c0b<SLi@cQ6=D8dADDf<c@b<TE1@d95=T91@SQ4<c4a
<4HPCT@=;eQ3A20P<S@d8594838dAD=2A30e<dE2>38iAC@d=48`=CU6>CE1<D@d
<DI5@c0eAD4b<T51<CU4<cA2=D4`@S=3=dDb<30a<Pe4<S53=c51>3U2@THb>C8g
>3Q3<cPb=cM6=c91=4HaADHhASD`<34eASLe<C0aADHbASU1>3Q4A30aA3T=AD51
>C55@C92AD8g<4Hb>44f<T@dACPa<C4c>353@CLi=d<f<3HhA3Lh@S0g<d4i=T4d
=DE1=3Dg<C=23D@d@S@`=492@d=5@D8b=S@d>C@e=TDc<c8i@cHa>392ADDd=TDc
@SLcAS@cAC0i@S0e<c51ADDd<d54=`deACLc<3@hAT4b<D8bAS8g<S11<C8h>C@f
>3Hc<c0a>315<CQ5<S4a<THd=SM1<C4e@CT`ACE3<3HdACH=<c8c=S0d<d4`=48g
A451=4@gASTe<STf<SHb<SE5@d53=44h<cDbASHh=S0e>CDiASDa<dHe<DE5=C51
3DHg<cE4=3<d@C0fAC8`=cTf@CPfACQ5@STh<C=3=3@c<D<a@D@a<C0h@C=6=cHf
>C@c=DHi=S94@CTbAPda<SQ4@dHg<CU3AS<h<4=6>30i<c15=C@d>3TfASPf@d=4
<TA2<S=1@S@`@cDg<CI2>3Lh@TE3ASQ5=c<==3<d=c=2<4<PCT@=;eQ3AB0P<CHh
8594838dAD=2A30e<dE2@S4b<S55<SI6@d=4>4E2>CM4@S<f<34g@dE1=48d=S4f
ATHaAT<g@cLf<c@f=T<d=Pdi=cE2<3Hd=ST`<SA5<4=2=D91>311>CDf=3E5<3Pd
ACHg<C95AS0c>44e=CHdA4Dh<T51<4Df=D=2<D4=>CDg@D4g=cTh@d8cAC4bA4@a
@c=1@dE6<T@d<C91@T@aAC=1=3<h>D4f=TA1<STbAS<e=4<i<4A1=S8b3C4a<SPa
@dDdA3Dh=C96ASI2>3Td=S@b@c8a@C<i=4E3>3A3=dD`<SPe>DDg<D4g<CPa>30g
ASM6=4I4A0dfACHg=3E5>C4aA34i>CA5=CTi=T<f>DE1=44h=D4b<4E5=SU1@CE5
<dI6A4=4=S4i<48c=CPcA4HbAC<=@DHc=T8d<SA1=CTbAS0fATHh=D4b=30a<cHg
=C8f=T4b@cHa84i43BmH@dHP838h<b1BA20b=4E3@T@`=C=5@T92A30b<3D`>D@g
<C0`=D<f@cHd@cDe@c56A38f<3I4>C<aA30c=cDi=4=1=C<iA3L==T8b>D=6@d8a
=cE4@cA4<S55=d4d>D51=3Pe@CDhACPf<S<g=34e=D8f>C8h=38a>4=1<S92=30h
=DHh3C95A3DgAD8h=4Da=SLiACPf<CP`@d=1=3@f=d@`<DI2<THa=DDc=311<T@i
=C4d@SDg@CE4=T4d@d@h=@e5<48i<3=3@SHh=C4`ASDa@cLa>44`@S0f<S0`AD<c
<C13=T91=3Da@CQ5=C<c=3M6>CHb@SQ4@dI6@C0=<3<d=THd>DA5@DDc=cPe=C4`
>DE6=SPfASM4>D54AC=6=CDf=3Hi=d@e<d4`AT<a@T<a>4Hg=D=6=3Q33CPg<cPa
@cPc<cDcAD54=4E6=CI5=cI3@d8`@SLh=c@a<cDh>311<TDc<3Pa<d@`A30d@STh
@CTc=SDc@@e3@c<g=30a<STb=DA6@S8a=cI1ACM1>456=d8f=T51<cE6A4@b=d<g
ADDa=D95<CTiA4=5AT92=c0h>4<=>3Q5<CDg>CI1@S96@CHeACU1=THf@DA1=4<b
<4@hASLi<4Hd=d@a@cM2=S4g>C0b@c<f<d=3A4Hh=THd3D=5@SI4=CLg<cHf<C<`
>3@eAT8f@CDhAC0cA3<a=TE2<d51=3=4<DA3=C8dAT<b@D<f=3Q2>3=6=d92<Pd`
@T8f<CU1>4=2@d4`@C@d<S52A456<S<f>21>A0d_F4@`820b=R1BA20b=4E3@T@`
=C=5@SU2ASM1>3M4>CU1ACM4>D<b@c4e<S=6<c8f>3U2@DI6=d=5ADA2@d=684i4
3BmHA34P838f8594838dAD=2A30e<dE2@SE6=4E1AT@f@d53<c0h=C0b<CE3@cLi
=4@g<T<d@S94AC0a=3@b=48PCT@=;eQ4<R0P<C8i8594838dAD=2A30e<dE2>D4h
ACI3>4I5>CM4=d=3AS=1AT<c@D<`<SQ1@cPd<CPh=S95AD95@c51@CHg<d@d=`da
=4@h<C<c<cQ2=TDbACU6=c0i@C4d>48g>D@iA3@a<SA6ACA6@SPbAS95@dDd=c55
>CHi<CHi=CLdACL==SE4<DA4=T91>311>3A5<3U5=CQ2>DHc@SLd=CA4@DHf<T51
A3Hi@T95=CDd<dDgAT8c@S4i=d92AS@i3CLh@C0g<SHi=D8dAS95@d4c=C95ASQ1
=SHh@SDfA3@h@C4c=d=5@D@e<S0c@cU3ACI1AC8e=D<h<S@i<Pdd@cTiATHbAC8c
@c=3<c0`>4@PCT@=;eQ4<b0P<C8h8594838dAD=2A30e<dE2>D4hACI3>4I5>4@a
=D=5>316@C12>4I5@cLi>CP`@SLi<cLe@dD`@SA2@C4e<4@f<@e3@d@a<STi@cPi
>DI3@D4g=STa<DA2<CU3<cTf>396@dDf@TDe<C14@d4a@DHh=T56<T4e<C@i<T56
>38=<S<`=D4f=DI2AT=3@cM2=44a<d@b>3Lb@SLh>4Df>3@`<cM4>4@f@d@`<C<f
>CTgADI5A3U3=352AT8c3C<a=44hAS96AD8h<dA2=cA2<CLgAC<a<S=6AC8g<dDa
<3Di<S=2=cHg=CE6=4@a@C0i<315>3Tb@CTdAPdg<dHi>3L`<CDc>D53<THe84i4
3BmHA3@P83La8594838dAD=2A30e<dE2=SM5<c<f@D4d=c4f=dHf<30cAS0f<S93
AS0g>3Tb=48i<D94=3@b=351@c0i<dDdA0d`<3Q5<4H`=DA5<cPc=cM6@S8c=3@d
@D@g@CD`ACHa>DE6AT55>3U3=S0a<THf@c16=cHf@SLhACU4>38==S8a@d<h<STa
A38`@CTh=C0eA4@h=b1>A0d_F4@e820g<21BA20b=4E3@T@`=C=5@SHgAC<c=T51
=3Hd=SPh=d55>48i=3I3@D<e<3Q5=C56>C<iAC95<CQ1<dI3<S16=D8=<CTc=c<f
>4@b=C<gA3@i<d@f@CLg<cLa<D92@c=1=d@f@d<i<CTa=S51=DA3ACE1<C<g@D4d
<C54<S0g3C0eAC91@d@e@DI3A3<f<d91>3=384i43BmHA3HP83Dc8594838dAD=2
A30e<dE2>3Le<d=1=4@fASM5A4A1>DA6<4<cAS94<C0g<3=2<T@i>D92<351<S51
=STd@S0eAPda@SLg@cP`@T<cA34c>3Pg=T8aA3Df<cA6=d4`=cTd=SA5@cTa@D=5
A454<S1484i43BmHA3LP83H`8594838dAD=2A30e<dE2>3Le<d=1=4@fASM5A4@e
=351=4I3=T<a=3Ti<C0a>DDiA356@S<`<C=2=S4dAD<eAPe6=CM1=D93ASTc>3@b
<CTgAT@g<3<f>4E4<cU5AC<h>38gA3LeAT4`<cQ6>3DgAT95A30eAD8f=T<f@D8P
CT@=;eQ4>20P<C4f8594838dAD=2A30e<dE2>DHh=S16@dE1=T<b>3A1=cTf<S0d
=S53>34g<CHf<T56>3Ph>3Hf<cU1=c12@d=5=`e5=44`<cHd>C@f=D=6ASTa@S0h
@CA2>C=3AD8e<D@a>D8e>3Te=STa@d<a@D@`=c<g=c0f=4Db=3=4@S0=>D4h@d=3
ASDg>CDb<C0f>CLc<SA3>3U6<T8h<c@hAD<h=D4b=S4h=TA3A34b<T=3A4Ha>4Dc
<4He>3Q43D@f<T8eA3Te<D<i=T@b<C4a>CP`A48hAD=6@THg>4=6=CTc=C4a=TE1
=3<d<S<gAT54A3TPCT@=;eQ4>B0P=c@PDT@P<SA5@d94<3DcAD8iA4Dg@S0f@CPg
=SDe@TD`@d92=34g>C4dA34`>DA5A4Dh>CI2@C16AD93@d<c@SDd3CPi<d96<C=2
<3Q6=SPf<48h>3@i<D92>3M1@cA1=T@eATA1=c13<TI5<d<aAC=2ACM4ASM1<CHa
=TE3=0dcADHa<CTa<STaAC8e<4I1<4<d=SLb<355A3Lb84i43BmHA44P838i8594
838dAD=2A30e<dE2<4E2<4Hc@DA5>D91<c52<d8d=c<h@C4g>3Ha@D55<cHdA3T`
AD8a<C8g@C=5>C<PCT@=;eQ4@R0P<C<i8594838dAD=2A30e<dE2>38f=c<f>CPh
>C13AD@b=DI4ACHi@dHb>CPi@T8e>D92ASPb<D94=SQ1@CTbA4<`A0dcAD8c=dDf
<44aA48b@D55<44g@c8h>CD`<c0g=30h<C8`A38f<311@CTh@C@aAC4a>CI5@CTa
<4<b@S@=@SA4<dD`@C0`@SLd<T8`<SLa@c=4=44i>DHh=c4e@T<`=CE5<DHd=c<f
=dI3@SA6A38f=4A4A3H`<dDf3CE2<TA6=cHe=d8b=T95<CPa=C4a@C54<S=3=c93
=C@b<dDf=CQ6AT@c@cA5AC0c=c=2<SHb=S0h>C4bA@de<cI3@S12@SU6A396@CM2
@DHi>CI6<3E4ASHh<CQ4ACLa<D@e=21>A0d_F4A3820d<b1BA20b=4E3@T@`=C=5
@SHf@TDa<c4c>34c<3<i<T<i=4Dd@TH`=T@i=cM3@T=4>CA6A3Hh<3=1A34gA48e
>48=<THh<SM3@C52=cM3<30f=S=5=TDfACM1AT8PCT@=;eQ4A20P=3<PDT@P<SA5
@d94<3DcAD8f=T95<C<a<cPa<c@hATE2>3<b<cP`=SM2<3Ld@SE1=dE6<3I6=dI2
=CHi<c4f<THb3D96AT55>CLc@d@d@SA6@dDf@SL`<C96>C0d84i43BmHA4DP83Ta
8594838dAD=2A30e<dE2>D<c@T<b=CU4@DHa=4Da@T95>D4i=T@e<D@a<D=6<c<e
<C8e=C8e>3@i<d92@cLbA0e6=cTb=C95@C14<cQ5>CD`=SDd@SPd>3@h<D91<3Q6
@c@h=353A392>392=D@d<T8b@c14@CM5ADH`=DD=@dE1AS51<4<d=C4`ATHa@C@b
<CHe<C4c<CHd<SE5<T@c=4<d@SH`AT=1=DHh<T8`<3Pe=C@a<38`@DI33CTf84i4
3BmHA4HP834`<21BA20b=4E3@T@`=C=5@SU3<d93<SDiA456=c<f>D4`=3E4AC<g
@d52<SLi<D54=493<D<h<T8h<cI6=SPe@C8==cA1=d4i=CM4@C<i=cM2<D92@C<c
ACA1ATHi@cA4<3P`<44i@cA2=3=5ASA4<T94<CA6@ST`>396@CH`3D4e<D<eA3De
<c96<456@dI1>C@`@d=5=4=3=c=4ACA2@D@c=T<dAT<aA3Lf@CPhATDf>4E5@CU4
@T93=0dhAS13ACTi@T<fA3Lc@T8d=SM5<B1>A0d_F4D`820h=b1BA20b=4E3@T@`
=C=5@SPg=C=3@CA4=THg<3Ha<THf<T4a=S95<cHc<T4iAC<d@CQ6=TDa<T54=3M5
<SQ1=CP=<3Hb=3@`=DI4<c16@S@d=CHhASDb<SPc=D8e>3I3A3Dh>D=4<CDi<C94
=3<`=DDe=d4gA34dAD<i>CE33CDf=c93>353<SPc=S8`<SH`=SPi<D<g<CU5<SA6
A34d>D@aACDcAC0e@CI1=cLc=30e<C=5<R1>A0d_F4Da820b>B1BA20b=4E3@T@`
=C=5@SPg=C=3@CA4=THh=4Hi=c8dAC@c@T<i=3U5=c53>3Lh@STd=SQ2<d8e=T@c
ACA484i43BmHAC8P83L`8594838dAD=2A30e<dE2=SM5<c<f@D4d=S@f@S<h@c<h
@C<f<cD`A4=3ATHgADHeA3LiA3I6<C4c@D96<3A3>0daA3M3@TA6=d<g<4=2@dI4
>38bATI3=CHi@c@a>4I3=3Pb@SHg<4DfA3Lf=c<g<dE3<C96A496<3Ti@c8==D4i
@c<bACM6@cLa=CHa<SQ2=D<PCT@=;eQ5<b0P<C8h8594838dAD=2A30e<dE2>D4h
ACI3>4I5>4@a=T<g>DE2=dHc@S4b=3Dh>DI6@DHd>CLc<d<b<SQ6<S@d=SDb@@e6
<44b=4@fAS0i>3@iA3E4<CA5=cQ6ADA5ASLeAD=2=cE6=cTh<38gA4Hd>4<a<SDa
=3Pa<T8dASE1>CP=>DHi<3@cATI6@D@h=3LhA4@c<cI3<SU4=CPc@D56AS<f=3Lg
>34h<CDd>4A5@CLe<DE6<c0h>3@d@SLg3C0d=C0b=3Q3=TA1@S0dASU3ADA5AC4c
=3A6@STg@c92=SU6A492<S<`AC<f=S8h<c13=3@b=d8g=SM5<0e2<c0f<351=C8e
A3Tc>39684i43BmHAC@P83<i<b1BA20b=4E3@T@`=C=5@TDc<393<C=4=455=D56
=C=4@SLe<4HhA44e@D8g=DDe@cA3<S96<c8e=D54=d4c@d8=<SHh>DE3AT@gASPd
=3@e<CM1<3DgA3HbATHc=c@f@CPc@cPbA4@dACTc@d55=491@cPeA3Pa=38d@TE3
3D8b<DA2AS@e=dI4@cHhAC8eA38`=cDg@c8g<CM4=S8h>C0iA3Dc@cLbAD8f<3<g
AT51=3Di>DI4=3E1A@e1<4@i@c16=CI4<C4g@S4e>4Hf<C14>353<c4b@c=1>DA6
>3@eASA2AS51<C@b>CTf>C0a>3Pi=S4f=CL=>391=S=6<4Dg@SI4@D96=D51@TI4
AS53AC14@C4c@dDe@C54>3A1<314AS4g=T@bA3<b=cTf=CM6=4943DI3<cLg<DDa
@cM2<T<`A393<SQ6<CT`<S0c=d<e=3TcAT4h@cTb=S4fAC8`=3=2>C=1@CM6A48e
@CDh=0e6<CTg=T@h=c8a@TDc<C93<SPg=T8cA44a<c@`A34d@THb@d4h>4E1=SDi
>C@c=T<`@T4f>3Hd>DE2AC<=@C56>48i=493@d@h=4A3A44a@d8f@CDd=cPhAS8f
<4Hc=D4h<TE5=THf>4@g=CHd<352>CE6@SDb=d@c3DA5AD@f<S<`>D4c@C8b=DA5
@DE6<CA3=SA5<CLc<T4d=48hA4A5<SPg@C52@d54ACQ5<CHiA4@aAS=1<Pdg@C<h
>C4e=452@c12=4E4=CI3>4@g<d<b<S<hA3Hh<4@d@TDe<3U4AC@a@SI5=3Lc=3=2
>DDc=cM1A48=<c<d=T<`A3Hg=dHd<4E2=S=6<3A1A44f=TI5=CM6=THc=SQ4AD8h
@c52>CDe@T54A3Hh@CLf<3<h=d8c3CDcACTcACHcA454>C0i@d51ACM3@SDaAT@e
A4<hAT@f=4Hh<3Da=T4d<S@f=SDh@T92@S<i@DI2=DDf<`e1>C=1=354<S<fA3I4
<THg@SI6=3A5=T8b>4E6AT4a@c94>4De<C4c<d52<cPi<CHe@DHf<S8i<d52=SH=
ACDf<D8g84i43BmHACDP83Pf8594838dAD=2A30e<dE2>3<a=C4i<DE6<3Ta<cDe
ACHc<CU4<dHi<C4`=CHa@dDd@C92ASPfASLgA3La@S51<`di<dHeAC4dAD@f@cM3
<d<g@c8b>D4c=dI4AC<d=cQ2<d=2<T<a<3M6AS<g<T4e@c@c=S<h<S4b<3<f>D<=
>C4b=cPf=TA1>4DbAD<g<DDe<S<`AS@h<dA2=SPf<cQ6>496@D@c<C16ATHa@d52
=34f<21>A0d_F4Df820g<b1BA20b=4E3@T@`=C=5@SU6@d51<3La=CA6>D92<314
>DDa@SA3<4=4<T@f<34dA4Hd<d@i<d<`AS<a@dHd<S8=A492<3Pb<C8c@CL`<3Ph
=dE6ADDaASHdADHe<T91>DA6<TA1ACLg@STeA4E1<T55@CLiA312=CTi=d=23D4a
AD=3ASPf<cU3>4<`<cU6ACE4=CE1=c<b84i43BmHACLP83P`8594838dAD=2A30e
<dE2>3<a=C4i<DE6<3Ta<cDeACHc<CU4<dHi<C4`=CHa@dDd@C92ASPfASLgA3La
@S51<`di<dHeAC4dAD@f@cM3<d<g@c8b>D4c=dI4AC<d=cQ2<d=2<T<a<3M6AS<g
<T4e@c@c=S<h<S4b<3<f>D<=AT@`A3@g>4=1>4=6>D@eASLc=cPiAT91=SP`AS@d
=S0f>CA3@cHi<b1>A0d_F4Dh820g<R1BA20b=4E3@T@`=C=5@SU6@d51<3La=CA6
>D92<314>DDa@SA3<4=4<T@f<34dA4Hd<d@i<d<`AS<a@dHd<S8=A492<3Pb<C8c
@CL`<3Ph=dE6ADDaASHdADHe<T91>DA4>D<e@cHe>C93>CPg=D8i@S13@d=6>3A1
@dHd3C53@S0`=STd@d@f>CHa<CQ5>4H`=dDc>21>A0d_F4Di820f=b1BA20b=4E3
@T@`=C=5@SU6@d51<3La=CA6>D92<314>DDa@SA3<4=4<T@f<34dA4Hd<d@i<d<`
AS<a@dHd<S8=A492<3Pb<C8c@CL`<3Ph=dE6ADDaASHdADHe<T91>DA6A34b>394
=3LdASHi@CHg>DI5=3@b<312@cLd3C4i<4@b<CDg<S@c@TI584i43BmHAD4P83@d
8594838dAD=2A30e<dE2=S=2<cDiADDd=30c<48i>44g<C16<C0g@T<f>44c=TDb
<4E1=D93<38gA3I3<S4g=@e6>3Pc=3LaAC@f=S8c<dA4<48fAS0h>3I1AT8b84i4
3BmHAD8P83D`8594838dAD=2A30e<dE2=S=2<cDiADDd=30c<48i>44g<C16<C0g
@T<f>44c=TDb<4E1=C=4=T4a>CHf<3Pd>@db>C8aASLd=TE3=3Ha<D8h=4Hf<451
A3Lh<THf<CLc=SI3A3Dg<39684i43BmHAD<P83Da8594838dAD=2A30e<dE2=S=2
<cDiADDd=30c<48i>44g<C16<C0g@T<f>44c=TDb<4E1=CHg<STc=d8hAC0iAPe2
A30dADDe=S@d>C8f@c4c=48d>496>4DiASA1@SPbATDc=3@c=T=3@c<PCT@=;eQ5
A20P=3DPDT@P<SA5@d94<3DcAD8f<d8c=CU5AC@d<3<`@STh@CLa<4Ha<3M2@cHh
@C<fAC8`AD4e=T95>4<b=dH`>3913CD`>CI6<48b<S<g=3Da@CHhA3U5<dE2<D94
@SQ6>21>A0d_F4E5820a=C@PDT@P<SA5@d94<3DcAD8h<SU5=3@d@S0e>DHi=D4a
A3@aATE3<3E5@C8b@D4a>D@c=48e@C12<d<gAC8`<34b3D@b<D<g<D4h>D92AS8i
<SLh>4<c>38g=dHg<T4dAS55ASQ6=C0`<CE6=cDa<355AS96>D4h>4A4<354>@e5
@D4i<DE1<T95@SL`AS8h@CHbA3A5>34a<C<h<D=1=cTg@cH`=SQ4=cQ2<3Lc@CTf
@C@eAD4d=CLa<d8=A3A2=30d@T93@dE1@S8f=3@i=3DfAC<c<SU3=S4h<T95AC@f
AC=2=c=6=3=5<3U2<3Dc<D55AC@c@D@g3CE5=c<`=3Q6@C8a@S96<SLb<44a<SPi
=3Hh=S<cAS0`AS0d@S8h=SDc@CQ3>CU5AD8d>493=3Da@S12<@deADE5AD4`<R1>
A0d_F4E6820a=S0PDT@P<SA5@d94<3DcAD8h<SU5=3@d@S0e>DHi=D4aA3@aATE3
<3E5@C8b@D4a>D@c=48e@C12<d<gAC8`<34b3D@b<D<g<D4h>D92AS8i<SLh>4<c
>38g=dHg<T4dAS55ASQ6=C0`<CE6=cDa<355AS96>D4h>4A4<354>@e5@D4i<DE1
<T95@SL`AS8h@CHbA3A5>34a<C<h<D=1=cTg@cH`=SQ4=cQ2<3Lc@CTf@C@eAD4d
=CLa<d8=A3A2=30d@T93@dE1@S8f=3@i=3DfAC<c<SU3=S4h<T95AC@fAC=2=c=6
=3=5<3U2<3Dc<D55AC@c@D@g3CE5=c<`=3Q6@C8a@S96<SLb<44a<SPi=3Hh=S=2
ACTh=3@f@cTf>4H`<T55=CLc<SLa<C4b=C4b=3Pf=Pe4@dI5@S4a@cE4<c<`ADA6
<T4f@B1>A0d_F4H`820b<CTPDT@P<SA5@d94<3DcAD8hAS0fA3HiAS15@cE5=4Df
@c96=S0d<STcASE2@cLf<T4f<C@i=C8aATA3=c4`=T4f3DHg@C<aA3Ti<SU6>3I1
<c4gAC16A3<g=D@e@SPeA3@`<44d=CH`A353=30fAC0i>C=3=c4e<3Le<cHdAPe5
@cA5=CU3>C@c<CQ6@d55@cDf=S<i>48`=SPaADH`AT4e<T53>DDf@S93>CDi@c4d
>C8d<CQ5ATE1=34=AS12>44c=C12<4A4@c<cA3<g@c0a@SQ1@S8d@CDhAC11>C@i
=cHg=S0gASHd>3PhAT8h@c52@D4h=dA23D@cA3Di>3PiAC=4=cU3=3<cA3D`ATDa
AC91=S95=CPcA44d=dI2ASPiASM6A4@`=cP`=C8b<cA2ACE1@@dd>3A6<3@a=dHb
A3=3@d@iASLbA3<i<SM5A3@`>CI1=C0c=CU5ADA6@C95=4<g<CTb=dE5A3@hAS51
=SP=@DH`=c55ADI3<T4gAD@cAD4a>C11<SP`=c8g@dE6A3D`@SM1>48a=D=6AC4i
@D8g<3HgA4@g=T<`=T=53C@f=S<g=cTh<48a=dA1<3M1>21>A0d_F4Ha820a=CDP
DT@P<SA5@d94<3DcAD8h<SU5=3@d@S0e>DHi=D4aA3@aATE3<3E5@C8b@D4a>D@c
=48e@C12<d<gAC8`<34b3D@b<D<g<D4h>D92AS8i<SLh>4<c>38g=dHg<T4dAS55
ASQ6=C0`<CE6=cDa<355AS96>D4h>4A4<354>@e5@D4i<DE1<T95@SL`AS8h@CHb
A3A5>34a<C<h<D=1=cTg@cH`=SQ4=cQ2<3Lc@CTf@C@eAD4d=CLa<d8=A3A2=30d
@T93@dE1@S8f=3@i=3DfAC<c<SU3=S4h<T95AC@fAC=2=c=6=3=5<3U2<3Dc<D55
AC@c@D@g3CE5=c<`=3Q6@C8a@S96<SLb<44a<SPi=3Hh=S<i@C8i@S=4=C92AT4i
@S=5<4I3=d8h=cTi>C0a=3A2<@dgA4I1<CPaAS4c84i43BmHAS8P834c=B1BA20b
=4E3@T@`=C=5@SPg=C=3@CA4=T<g>C8e<c8c=DE6=3<g<T@b<C11<DDcAC0h=SI4
>4=2A3Tb<3D`ASP=<TH`@S55=TA1<3Le=TE3>4H`<T4`>38i=3Ph@D@a=4I2=d4f
AT4i=c@d=d<e@S4a@d56=352<3Ld=S4d3D92=4I5<D91ATHh=SDc@D@d>30e@TD`
@C8f@c55@C12AT<`A34h=44iA4I5@cPeA4@g>D@gAD@b<30e=Pdi@S8e@d4bA3E4
<SM3@DA6=S4g=S15<cU4<DDd<D=3A44i=cTa>44e@SE1AC@g>CDe@S11@S8c<CM3
>44=ACDf<3Hf=cHa@d@h<TD`AS13@C8i<S91@SA4<T5584i43BmHAS<P834d<R1B
A20b=4E3@T@`=C=5@SPg=C=3@CA4=T<g>C8e<c8c=DE6=3<g<T@b<C11<DDcAC0h
=SI4>4=2A3Tb<3D`ASP=<TH`@S55=TA1<3Le=TE3>4H`<T4`>38i=3Ph@D@a=4I2
=d4fAT4i=c@d=d<e@S4a@d56=352<3Ld=S4d3D92=4I5<D91ATHh=SDc@D@d>30e
@TD`@C8f@c55@C12AT<`A34h=44iA4I5@cPeA4@g>D@gAD@b<30e=Pdi@S8e@d4b
A3E4<SM3@DA6=S4g=S15<cU4<DDd<D=3A44i=cTa>44e@SE1AC@g>CDe@S11<4Dd
=SHiACL=@C8b>CDd=S<d@dE5=T8cASE4@SU3>CU2A4I5@S8f<34h<DHh<48fASQ6
A48PCT@=;eQ6=20P<C<e8594838dAD=2A30e<dE2>3Le<d=1=4@f@cLi<SDc<S<e
ADHd<cLbA38a<44aAC=5<3Pf=T@h@d94>C8`=C16>0dbAS12<DDfA44`=cDfAD<h
AS0b@C0h<STd>3Q1A34dAT8g@CI6@CTg=3@g@cE2<C53@DHd<D8`=c@f<C@=@T8d
ATDa@T56ASPf=C=1A3@h<3E2AC11<SI3<DE1<496@c14<CPd@CU4ATE3>3E4A3Li
A3M5A38`<3Df3CU2<SE3@C94=D@b=d=1A4Hf<CLf<4Dc>D@aAC@a@d=4@CTg>C4h
@CE2=D55=3Li=CE2<3DeAS8`=S52=Pe4ADI6>4<b@S<fA452AS92@c0i<SM5=c0i
ATDe<c4PCT@=;eQ6=B0P<SHPDT@P<SA5@d94<3DcAD8f@c8aACM4=T<d>D8a<3La
>CI1ATE2>3A3<d8a>C=3>CLg<313<CDa<b1>A0d_F4Hf820c>B1BA20b=4E3@T@`
=C=5@SU3@S8i=c93@S0i=D@f<315A4=1AC<f<cE5>30b=CQ2>4E1<S12<dHi<4E1
=C8e<TD=AS13<T8fACPg<48f=34h>4He84i43BmHASLP834`<21BA20b=4E3@T@`
=C=5@SU3@S8i=c93@S0i@THf=SA5=CE6=c@h=C0a@DDf@SQ6<c16<c4h>CU4A4He
@C<`=3<==CE2ATHa@CA5=CA5A3Pi<D94<D94<cL`<3@d>C4d=DH`<T<`=CDa@c8a
AS<b@STa>3M2<D<h@dE2<CE63C=3@d96=SHf<S8g@SA6>48`A3Tg<4I2=CI5@C0i
@SA4=dA1=cTd=d94AS<`>4@b<C<b=D96=3U4>DE4=Pe4=CU6<S8f@dHi@d=6=3Ph
<dHb@R1>A0d_F4Hh820b=b1BA20b=4E3@T@`=C=5@SU3@S8i=c93@S0iA3E1=CD`
<30h>3M2=3@cA48i=S4c@T=3<C@i=4<e@T@PCT@=;eQ6>B0P>C4PDT@P<SA5@d94
<3DcAD8i@d8b>CLb@d8`>CQ3>3I6@C<b<494ASA3A451@T4b@dE4@T@h=T91AD8c
=dHcAS0h3C0f@T8bACPa<D<a=C14=T=6<cLd<C53=c52A4A6=C=6AD92=CPc<CT`
<c<b=CE5>3Tf=3Hb>3TcASHb@@dd@C8iA4De@SLc<392@SQ6@c8i=cM5A3Q1>4Hh
<3TaA3A2<3A3A4A5<DDiACPa<c8a=d4`ADHc<CTi=d4=@STPCT@=;eQ6@B0P<SDP
DT@P<SA5@d94<3DcAD8i@d8b>CLb@d8`>CHh>34i@C8eAS92=D54=THd=D@bASP`
ASTd=c@PCT@=;eQ6@R0P<C<b8594838dAD=2A30e<dE2>D=2<STg<T=2<3TeA3H`
=S<d<D51<48aASA2=S@h@S92<3Pi=c@e<cPa<cLb<C@a<0e5@cM6<CA4>3Dd=CPh
>DHi=C4a@cLb<C94A38dAD96A491<cA1ACM1=T<f=S56<DE6@T52=C0g>4@i>CP=
<3<cA3Pf<3@b=3U1>4@c@c93<d8h=c4eASPgAC8g<38h>CHg=CLg<cHd<S51<4A2
>3Hb>C4i@S<`=dHh3C4b<4@aATHc@cT`=S<d=T8d>D93=SPd<S@`<dH`A3H`AS<i
A34`=d@g@cU4@D=6>DI4>4Dc<T55@D@d@@db>C<d>CI6>C<i>CDg=C<c=DI2>CLg
A34PCT@=;eQ6@b0P>3PPDT@P<SA5@d94<3DcAD8i@d8b>CLb@d8`>C<hA38i=cLe
<T<i<cA6=SThAS<bAS4e>3I4@DA4=S53<4A4>C543C<`<SLgA30a<T=2AC13@cPe
=STfAD94<C0g<3Db=3=4<3E2=d95=c<i@T<h<T@hA4<d=S@f=C@e<cTi>@e1AC4i
@S56A492<SD`@cU4=3Tf=4=2AS95>30a@SI1<3I3@dHi@S8f=CI5ACTd@S<cASE3
>C@dAR1>A0d_F4I4820d=B1BA20b=4E3@T@`=C=5@SU3@S8i=c93@S0i=cLf>CA3
=cDa>CA4ATI4AT@h@CTa=T94ACM1AT=1<c@d<T95=dH=<dDh>3Q5@TI3<THi>C0d
>38a=THeAC<i=SLb=C=184i43BmHATDP83Pb8594838dAD=2A30e<dE2>D=2<STg
<T=2<3Hg=C<b=T<g=d4g@d52=cLeAT4f<DI6>CLf=dE1=C@d=cE6A451A0da<cHb
=DE3=S4g=dI4=SDi>3A3@D4b>@00X@300?]5=S<bAC55<S13<S0b@CQ4>34a>455
<c12<3U6<d8h>3=6<cE63C15@CA5<CPc<SDeAT@`>3Lb>DHiAS4h>3Tg=D4c=cTa
<S=4<T4c=ST`<CU384i43BmHATHP83<i8594838dAD=2A30e<dE2>D=2<STg<T=2
<3TeA3H`<3=6ACM5>D<a<c0a=TA2ACU3A4<c<S@f<S<`=c@h@DHd<`da>3<g@SDg
<dHa>CHgAT@h<CLPCT@=IFiT3FE^I0e`MG@=L7Ed3FAeL20_AVm^M4iQKFDPIfEd
86EhHfPPI6EVJFiUIVm^M21`Kg0=9BE5KVABIG=_MG9SIB0=3@00X@300J4_GemO
ATha82m7IFiUMV4P;dMUKVEfHB1TMG0PIVU^I6I_KW@PI7E`82m3J65bDgAbJFiW
Lb1[KVmgKR1kHVEWJFhP@fQQLU=dLVU^Ig<P;d5TJFEbIG=YLb1[KVmgKR1k;C4P
OG/]<GdPJFIUK7=U86E^I7dPNg1_L20]<GdPJFIUK7=U879V3C0PJF@=<B1VI0d`
838g<b1dLV5^LfaQM6D=<c0`82dc<30PLf=/J@dU9DE^I5=UM7E`80dU9D9UIfU^
D65WIE=UM7E`80e`K@dU9DE^I51QIfECIGAeL0d_A6EfJF=UDTM287=SL`d`830P
<21V<`d`;S4b=C0P<2ha<SD`87=`3B0`86aS3B0b86aZ3E@PLf4=9G1QIfDPLVES
M3XP<c4b834`<20f>CTP<cLb80ecM6d=<2hf=SPP<2hf=SPP<2hf=SPPIS<=<CL^
<cHa<20a=bhc=S4`87=`3C4a;SDPK6d=830PK6X=KW0=<C@h=2hc=SLe830PKG@=
<C@h=2hc=SLe838d<bh`=C@c86aY3FAc3G9dK@d00:40`018LgA]3C0^=SHh830^
=SHh830^=SHh86Hc3Fi`3C8g<c@^<cHa<B0`86ed3C8g<c@^<cHa<B0b=3<^<3Dd
<b1/J@eTL`ebM6d=0:40`018LgA]3C0^=SHh830^=SHh830^=SHh86Hc3Fi`3C<i
>3@^<cDd>20`86ed3C<i>3@^<cDd>20b=3<^<3Dd<b1/J@eTL`ebM6d=0:40`018
LgA]3C0^=SHh830^=SHh830^=SHh86Hc3Fi`3CDb<c@^<c@h=20`86ed3CDb<c@^
<c@h=20b=3<^<3Dd<b1/J@eTL`ebM6d=0:40`01ALgA]3C0^=SHh830^=SHh830^
=SHh86Hc3Fi`3C4d>3@^<cHg=B0d<cPc;SHe>3<PKG@=<C@h=2hc=SLe83@f<SH^
=c4b=R1/J@eTL`ebM6d=002Q0<00DG=dK@d`;SHf>20`;SHf>20`;SHf>21V<`e^
L0db=c<d;S<f<C4P=3<h<bhf=CPc86ed3C8g<c@^<cHa<B0d=S8f;SLa<SHPK6T=
I7<=LWA]3@00X@30055cM6d=<2hf=SPP<2hf=SPP<2hf=SPPIS<=KW0=<cTh=2hc
=C@h83@c>3<^=SDh<b1]M0dc>CPd;S<e=3PP=3Hb=Rhg<C8f86aY3FAc3G9dK@d0
0:40`01ALgA]3C0^=SHh830^=SHh830^=SHh86Hc3Fi`3CDb<c@^<c@h=20d<cPc
;SHe>3<PKG@==C8c=2hc=3Pd83@f<SH^=c4b=R1/J@eTL`ebM6d=002Q0<00B7=d
K@d`;SHf>20`;SHf>20`;SHf>21V<`e^L0d`834`=SL^=c0b>B1]M0db=3<^<3Dd
<b0a<3Hg;SL`<STPK6T=I7<=LWA]3@2Q0<00AW=dK@d`;SHf>20`;SHf>20`;SHf
>21V<`e^L0d`834i<34^<3<b86ed3C8d<bh`=C@c834i<34^<3<b86aY3FAc3G9d
K@d0X@3004QcM6d=<2hf=SPP<2hf=SPP<2hf=SPPIS<=KW0=<20b=c<d;S<f<C4P
KG@=<S@c;S0e=3<P<SLc=2hc=S4a86aY3FAc3G9dK@d0X@3004QcM6d=<2hf=SPP
<2hf=SPP<2hf=SPPIS<=KW0=<20c=CD`;S<b>C8PKG@=<S@c;S0e=3<P<cDe<2hc
<STb86aY3FAc3G9dK@d0X@30055cM6d=<2hf=SPP<2hf=SPP<2hf=SPPIS<=KW0=
=S@h=2hc=38a834`=SL^=c0b>B1]M0df=c8g;S<i=S@P<C0f=bhg<38i86aY3FAc
3G9dK@d00:40`01?LgA]3C0^=SHh830^=SHh830^=SHh86Hc3Fi`3CHd>3@^<c@b
<B0a>C0a;S0c<R1]M0df=c8g;S<i=S@P<CT`<Bh`<c8PK6T=I7<=LWA]3@00X@30
055cM6d=<2hf=SPP<2hf=SPP<2hf=SPPIS<=KW0==S@h=2hc=38a838g<c@^<cHa
<B1]M0df=c8g;S<i=S@P<SLc=2hc=S4a86aY3FAc3G9dK@d00:40`01ALgA]3C0^
=SHh830^=SHh830^=SHh86Hc3Fi`3CHd>3@^<c@b<B0c=CD`;S<b>C8PKG@==SLb
=bhc>CHd83<e=C0^<c8i<R1/J@eTL`ebM6d=002Q0<00OG=dK@da;R0a;R0a;R1V
<`e^L0db<cT^>3@c=R0a>C0f;S4b=C@P<C@h=bhe=cPa838g<cL^>C@h=B1bL0eT
I@d`830P<21V<`e^L0db<cT^>3@c=R0a>C0f;S4b=C@P<C@h=bhe=cPa838g<cL^
>C@h=B1bL0eTL`ebM6d=002Q0<0017=dK@d0X@3000=WL`d00:40`09kJ7<==SPa
;S@b<38P<S@e<Rhb=3@e86ed3CHh<Bhd<S0b838d>C0^<c<g<R0f=C0^<3Hh>20b
=C8a;SHh>3HP=S4a;STg=S4P<SDb<Bhf>3Pf86=d3CDg<bhh>3<c838e<S4^=SPh
=R0e=38^=C<b838d>C0^<c<g<R0e=38^=C<b838d=C8^<S@d=B1SM0de=38^=C<b
838d<C@^<CDa>20e=c<^>3Pc<b0b<cPb;SP`<3@P=S4a;STg=S4P<S<h<Rhh<30d
86=d3CHe<2h`=SPh838c>38^>30`=20f>34^=38`<R0b=34d;S4e<CPP=SPa;S@b
<38P<S@e<Rhb=3@e86=d3F=`3B0`86QS3C0P<20`86Hc3B0b86aZ3Fi`3C@h=Rhe
=3Hh838c>38^>30`=21]M0dd>3H^=C@f>20b=C8a;SHh>3HPK6T=I7<=KW0==C8a
;S8f>3PP<S<h<Rhh<30d86ed3CDb<Bhb=SPh838e<S4^=SPh=R1/J@eTL`e^L0de
=CD^>CT`>B0b<cPb;SP`<3@PKG@==CDe;STi<3TP<SDb<Bhf>3Pf86aY3FAc3Fi`
3CDi<2hg<C8i838c>38^>30`=21]M0de>C0^=c4b>B0b=C8a;SHh>3HPK6T=I7<=
KW0==S8e;S@c=B0b<cPb;SP`<3@PKG@==S8e;S@c=B0b=C8a;SHh>3HPK6T=I7<=
KW0==SH`;S4e=b0b<cPb;SP`<3@PKG@==SH`;S4e=b0b=C8a;SHh>3HPK6T=I7<=
KW0==STd;SPg>C4P<S<h<Rhh<30d86ed3CHi=2hh=cTa838e<S4^=SPh=R1/J@eT
L`eXI@d00:40`003Ig8=002Q0<00>C0P<20`86Hc3Fi`3CHi;S@d=34P=ST^=3@d
<B0f<C4^>CLf<B0b=3Db;S8d=3DPIG0=I7<=LWA]3@00X@3007mcM6d=<BhP<BhP
<BhPIS<=KW0=<C@h>Bhh<cLc834i<3H^<C8e=20b=c<g;SDg<CPP<SLc=bhi=3Pe
879`3FAU3C0P<20`86Hc3Fi`3C4d>3T^>3<g<b0a>C0f;S4b=C@P<SLc=bhe=c4h
838g<cL^>C@h=B1bL0eTL`ebM6d=002Q0<0017=dK@d0X@3000=WL`d00:40`0:M
J7<=<S@c=2hh>3<e838d=C8^<S@d=B1]M0db=3<d;SPh<cDP<S@i<2hc<cLb838d
<3<^=C<b<B0b=C8a;SHh>3HP<S<f=Bhd<cTd838e<S4^=SPh=R1SM0db<c8g;S<d
=SHP<SDb<Bhf>3Pf838b>CD^>CTe<b0b=3T`;S<c=c8P<S8i=Bhi>CDc838d=C8^
<S@d=B1SM0db<STe;STi=C<P<S@a=2ha=C4h838c<SL^<c@f=R0b<cPb;SP`<3@P
<S<f=Bhd<cTd838c>38^>30`=21SM0db=30c;SDc<S4P<S<h<Rhh<30d838d<c@^
>3Pc=B0b=34d;S4e<CPP<S@c=2hh>3<e838d=C8^<S@d=B1SM0eSL0dP<21XH`d`
830P<21V<`dP<R1/JPe^L0db=3<d;SPh<cDP<S<a>2h`<3Td86ed3C8b>CD^>CTe
<b0b<c4h;S0`>C@PK6T=I7<=KW0=<S@c=2hh>3<e838c=C8^=c<a=B1]M0db<STe
;STi=C<P<S<e<Rhg<c4e86aY3FAc3Fi`3C8d<c@^>3Pc=B0b<cPg;S@e<cDPKG@=
<S8i=Bhi>CDc838c>3L^=3Dc=B1/J@eTL`e^L0db=3<d;SPh<cDP<S@b<Rha=cDf
86ed3C8b>CD^>CTe<b0b=38b;S4g=CHPK6T=I7<=KW0=<S@c=2hh>3<e838d=CH^
>3Tg=R1]M0db<STe;STi=C<P<S@e=Rhh>CLf86aY3FAc3Fi`3C8d<c@^>3Pc=B0b
=3Ta;SHa>CHPKG@=<S8i=Bhi>CDc838d>C4^=S4i=R1/J@eTL`e^L0db=3<d;SPh
<cDP<SDb=Rhc=34g86ed3C8b>CD^>CTe<b0b=C8f;S<d<CLPK6T=I7<=J6D=002Q
0<000fMb3@00X@3003X`830P<21V<`e^L0df>Bhd=3@a83Hi;S@d=34P<S<f=Bhd
<cTd838d=C8^<S@d=B1UL0eTL`ebM6d=0:40`01oLgA]3C4^834^834^86Hc3Fi`
3C8g<cT^>3<`>B0a>C0f;S4b=C@P<cTh=bhe=SDe838g<cL^>C@h=B1bL0eTI@d`
830P<21V<`e^L0db=c<i;SPc<3TP<CT`=Rha<SDd83<i>3L^=CHe=B0b=c<g;STd
>3DPLW0=I7<=LWA]3@00X@3007mcM6d=<BhP<BhP<BhPIS<=KW0==C8c>Bhh<CPb
834i<3H^<C8e=20f=3Pg;SDe<SPP<SLc=bhi=3Pe879`3FAU3C0P<20`86Hc3Fi`
3CDb<cT^>34h<R0a>C0f;S4b=C@P=S@h=bhe=C8h838g<cL^>C@h=B1bL0eTL`eb
M6d=002Q0<0017=dK@d0X@3000=WL`d00:40`0:MJ7<==CHh<Bhc>C@h838d=C8^
<S@d=B1]M0de=SPa;S<i=3PP<S@i<2hc<cLb83Df=C0^<3@c=20b=C8a;SHh>3HP
=CHa<Bhi=C0g838e<S4^=SPh=R1SM0de=CLc;SPe=cTP<SDb<Bhf>3Pf83De=38^
=C0f=R0b=3T`;S<c=c8P=CDd<Rhe<3Hf838d=C8^<S@d=B1SM0de=C@b;SD`=SHP
<S@a=2ha=C4h83De=c<^>3Dg>B0b<cPb;SP`<3@P=CHa<Bhi=C0g838c>38^>30`
=21SM0de=SD`;S0d<c@P<S<h<Rhh<30d83Df>34^<cTd>20b=34d;S4e<CPP=CHh
<Bhc>C@h838d=C8^<S@d=B1SM0eSL0dP<21XH`d`830P<21V<`dP<R1/JPe^L0de
=3Pf;SDb<C@P<S<h<Rhh<30d86ed3CDd>3H^=C8a=20b=C8a;SHh>3HPK6T=I7<=
KW0==CDb<Bhb=3<e838c>38^>30`=21]M0de=C8a;S8d<cDP<SDb<Bhf>3Pf86aY
3FAc3Fi`3CDe=CD^>CHe=B0b<cPb;SP`<3@PKG@==CDe=Bhi=SDe838e<S4^=SPh
=R1/J@eTL`e^L0de=CT`;SHh=cDP<S<h<Rhh<30d86ed3CDe>C0^=SPg=B0b=C8a
;SHh>3HPK6T=I7<=KW0==CHb=Bhd<3Tf838c>38^>30`=21]M0de=S8e;S@`>CHP
<SDb<Bhf>3Pf86aY3FAc3Fi`3CDf=S0^<C<a=R0b<cPb;SP`<3@PKG@==CHf<2ha
<c4f838e<S4^=SPh=R1/J@eTL`e^L0de=STd;SPe<cLP<S<h<Rhh<30d86ed3CDf
>C@^>3Dc=b0b=C8a;SHh>3HPK6T=I7<=J6D=002Q0<000fMb3@00X@3003X`830P
<21V<`e^L0df>Bhd=3@a83Hi;S@d=34P=CHa<Bhi=C0g838d=C8^<S@d=B1UL0eT
L`ebM6d=0:40`01oLgA]3C4^834^834^86Hc3Fi`3C<i>3T^>38d=R0a>C0f;S4b
=C@P=C8c=bhe=CTa838g<cL^>C@h=B1bL0eTI@d`830P<21V<`e^L0dc>CPi;SPb
=3HP<CT`=Rha<SDd83Db<cL^=CDi<B0b=c<g;STd>3DPLW0=I7<=LWA]3@00X@30
00AcM6d=0:40`003Ig<=002Q0<02WFQc3C@i<c@^>3L`>20b=3Db;S8d=3DPKG@=
=3Tc=2hh=c0h838d>C0^<c<g<R0d>C0c;SDa>C@P<SDb<Bhf>3Pf83@h=SD^=38f
=b0b=C8a;SHh>3HPHg@==3Pb=bhc<c<i838e<S4^=SPh=R0d=cTe;STh<SHP<S@i
<2hc<cLb83@g>CD^>CPb=R0b=3Db;S8d=3DPHg@==3Li=Bhi>38f838d<C@^<CDa
>20d>38g;S<c<cTP<S<h<Rhh<30d83@h=SD^=38f=b0b<cPb;SP`<3@PHg@==3T`
<bhe<CTd838c>38^>30`=20d>C<d;SPg<3PP<S@a=2ha=C4h83@i<c@^>3L`>20b
=3Db;S8d=3DPHg@=Hg0=830PJ6<=<20`830PIS<=838PK6X=KW0==3Tc=2hh=c0h
838c<CP^<30i=21]M0dd=cTe;STh<SHP<S<a>2h`<3Td86aY3FAc3Fi`3C@i<c@^
>3L`>20b<cDb;SLc<CDPKG@==3Li=Bhi>38f838c=C8^=c<a=B1/J@eTL`e^L0dd
>C<d;SPg<3PP<S<h=bhd=C<e86ed3C@g>CD^>CPb=R0b<cPg;S@e<cDPK6T=I7<=
KW0==3Tc=2hh=c0h838d<S8^<CLe=R1]M0dd=cTe;STh<SHP<S@b<Rha=cDf86aY
3FAc3Fi`3C@i<c@^>3L`>20b=3Df;SPi=cHPKG@==3Li=Bhi>38f838d=CH^>3Tg
=R1/J@eTL`e^L0dd>C<d;SPg<3PP<S@i<Bhf<CTf86ed3C@g>CD^>CPb=R0b=3Ta
;SHa>CHPK6T=I7<=KW0==3Tc=2hh=c0h838e<SH^<c@a=b1]M0dd=cTe;STh<SHP
<SDb=Rhc=34g86aY3FAc3FQU3@00X@3000=WLPd00:40`00j<20`830PIS<=KW0=
=ST^=3@d<B0f>Bhd=3@a83@h=SD^=38f=b0b=3Db;S8d=3DPIG0=I7<=LWA]3@2Q
0<00mG=dK@da;R0a;R0a;R1V<`ecM6d=<Bh`<30`830^<30`<20`;S0`<30P;C4^
<30`<20`;S0`<30P;C<d>3P^>C<i>B1SL`e^L0db<cT^>3@c=R0]=c0f<2hb<CLe
834d>3L^=CLh<B0]=S8b>2hc>C@d879`3G9dK@eTI@d`830P<21V<`ecM6d=<Bh`
<30`830^<30`<20`;S0`<30P;C4^<30`<20`;S0`<30P;C<d>3P^>C<i>B1SL`e^
L0db<cT^>3@c=R0]=c0f<2hb<CLe834d>3L^=CLh<B0]=S8b>2hc>C@d879`3G9d
K@eTL`ebM6d=002Q0<0017=dK@d0X@3000=WL`d00:40`09hJ7<==SPa;S@b<38P
<c0b=Bha=CPe86ed3CHh<Bhd<S0b838i>3L^<3He>20f=C0^<3Hh>20b>CDe;SLa
=3@P=S4a;STg=S4P<STe=Bhg<C@d86=d3CDg<bhh>3<c838i=CD^=c4d=20e=38^
=C<b838i>3L^<3He>20e=38^=C<b83<`<SD^<CDh=B1SM0de=38^=C<b83<`=S<^
<SDa<b0e=c<^>3Pc<b0c<3Td;SH`<SHP=S4a;STg=S4P<c0i=2hf<38f86=d3CHe
<2h`=SPh83<`>C@^=S0b=R0f>34^=38`<R0c<3Hc;S8e<C<P=SPa;S@b<38P<c0b
=Bha=CPe86=d3F=`3B0`86QS3C0P<20`86Hc3B0b86aZ3Fi`3CHh<Bhd<S0b838i
<3P^<SPd<R1]M0de=38^=C<b838i<3P^<SPd<R1/J@eTL`e^L0df>34^=38`<R0b
>C@c;S0`=S8PKG@==C@b;SDc<R0b>C@c;S0`=S8PK6T=I7<=KW0==SPa;S@b<38P
<STg=bhg<SPc86ed3CDd<Rhe<c8P<STg=bhg<SPc86aY3FAc3Fi`3CHh<Bhd<S0b
83<`<C8^=3D`<b1]M0de=38^=C<b83<`<C8^=3D`<b1/J@eTL`e^L0df>34^=38`
<R0c<3@g;S4g<S@PKG@==C@b;SDc<R0c<3@g;S4g<S@PK6T=I7<=KW0==SPa;S@b
<38P<c0h<Bhh>C@d86ed3CDd<Rhe<c8P<c0h<Bhh>C@d86aY3FAc3Fi`3CHh<Bhd
<S0b83<a<CH^=S4f=B1]M0de=38^=C<b83<a<CH^=S4f=B1/J@eTL`eXI@d0X@30
00=WLPd00:40`01d<20`830PIS<=KW0=LgA]3C4^<30`<20`;S0`<30P<2h`<30`
82da;S0`<30P<2h`<30`82dc=3Ph;STc>CTPHg<==ST^=3@d<B0f>Bhd=3@a83Ha
<Bhi=cHa82df=C4d;S0i>3@PIG0=LWA]3FAc3G9dK@d0X@300?McM6d=<BhP<BhP
<BhPIS<=LgA]3C4^<30`<20`;S0`<30P<2h`<30`82da;S0`<30P<2h`<30`82dc
=3Ph;STc>CTPHg<=KW0=<C@h>Bhh<cLc82dg<3H`;S8a=cDP<SLc=bhe=c4h82df
<S8h;S<i=3@PLW0=LWA]3FAU3C0P<20`86Hc3G=dK@da;S0`<30P<2h`<30`830^
<30`<20]<Bh`<30`830^<30`<20]<c@h>2hi<cTi86=c3Fi`3C4d>3T^>3<g<b0]
=c0f<2hb<CLe838g<cL^=CLa>20]=S8b>2hc>C@d879`3G9dK@eTL`ebM6d=002Q
0<0017=dK@d0X@3000=WL`d00:40`0:MJ7<=<S@c=2hh>3<e83<`<SD^<CDh=B1]
M0db=3<d;SPh<cDP<STh=bh`=SDh838d<3<^=C<b<B0b>CDe;SLa=3@P<S<f=Bhd
<cTd838i=CD^=c4d=21SM0db<c8g;S<d=SHP<STe=Bhg<C@d838b>CD^>CTe<b0b
>CPg;S0f=CPP<S8i=Bhi>CDc83<`<SD^<CDh=B1SM0db<STe;STi=C<P<c0f<bhb
=C4c838c<SL^<c@f=R0c<3Td;SH`<SHP<S<f=Bhd<cTd83<`>C@^=S0b=R1SM0db
=30c;SDc<S4P<c0i=2hf<38f838d<c@^>3Pc=B0c<3Hc;S8e<C<P<S@c=2hh>3<e
83<`<SD^<CDh=B1SM0eSL0dP<21XH`d`830P<21V<`dP<R1/JPe^L0db<SDg;S<g
<C4P<c0i=2hf<38f86ed3C8b=CL^<cLa<B0b>CDe;SLa=3@PK6T=I7<=KW0=<S8i
<Rh`>C<b83<`>C@^=S0b=R1]M0db<STb;S0i<c8P<STe=Bhg<C@d86aY3FAc3Fi`
3C8c<SH^>34e<R0c<3Td;SH`<SHPKG@=<S<b=Rhh<CDb838i=CD^=c4d=21/J@eT
L`e^L0db<cHa;SDc=c<P<c0i=2hf<38f86ed3C8c=S4^=C<g<b0b>CDe;SLa=3@P
K6T=I7<=KW0=<S<i=Rhb=CTc83<`>C@^=S0b=R1]M0db<cTf;S8e>C<P<STe=Bhg
<C@d86aY3FAc3Fi`3C8d<c0^>CPa=20c<3Td;SH`<SHPKG@=<S@c<2hi>34d838i
=CD^=c4d=21/J@eTL`e^L0db=3He;SL`<c@P<c0i=2hf<38f86ed3C8d=SD^=c0c
=20b>CDe;SLa=3@PK6T=I7<=J6D=002Q0<000fMb3@00X@3007D`830P<21V<`e^
L0ecM6d=<Bh`<30`830^<30`<20`;S0`<30P;C4^<30`<20`;S0`<30P;C<d>3P^
>C<i>B1SL`df>Bhd=3@a83Hi;S@d=34P<S<f=Bhd<cTd82df=C4d;S0i>3@PIG0=
LWA]3FAc3G9dK@d00:40`03gLgA]3C4^834^834^86Hc3G=dK@da;S0`<30P<2h`
<30`830^<30`<20]<Bh`<30`830^<30`<20]<c@h>2hi<cTi86=c3Fi`3C8g<cT^
>3<`>B0]=c0f<2hb<CLe83<i>3L^=CHe=B0]=S8b>2hc>C@d879`3G9dK@eTI@d`
830P<21V<`ecM6d=<Bh`<30`830^<30`<20`;S0`<30P;C4^<30`<20`;S0`<30P
;C<d>3P^>C<i>B1SL`e^L0db=c<i;SPc<3TP;CL`=S0^<S4g=B0c>CPg;SDf=CDP
;CHb<SP^<cTd=21bL0ebM6d=I7<=LWA]3@00X@3000AcM6d=0:40`003Ig<=002Q
0<02WFQc3C<a>34^=30g=B0c<38e;S4e>3DPKG@=<c4h<Bhd<3Le838i>3L^<3He
>20c<CD`;S0e=S4P<STe=Bhg<C@d83<a<C4^>CHc=20b>CDe;SLa=3@PHg@=<c0g
<bhh=c0f838i=CD^=c4d=20c<3@b;SDa>C<P<STh=bh`=SDh83<`=38^=C4i<b0c
<38e;S4e>3DPHg@=<c0d<Rhe<CTc83<`=S<^<SDa<b0c<3Lc;SPg<3HP<c0i=2hf
<38f83<a<C4^>CHc=20c<3Td;SH`<SHPHg@=<c4e<2h`=CHa83<`>C@^=S0b=R0c
<CPa;S@`=cDP<c0f<bhb=C4c83<a>34^=30g=B0c<38e;S4e>3DPHg@=Hg0=830P
J6<=<20`830PIS<=838PK6X=KW0=<c4h<Bhd<3Le838i<3P^<SPd<R1]M0dc<3@b
;SDa>C<P<ST`>2hb>3@b86aY3FAc3Fi`3C<a>34^=30g=B0b>C@c;S0`=S8PKG@=
<c0d<Rhe<CTc838i=3<^<30f<R1/J@eTL`e^L0dc<CPa;S@`=cDP<STg=bhg<SPc
86ed3C<`=38^=C4i<b0b>CLg;SLb>3<PK6T=I7<=KW0=<c4h<Bhd<3Le83<`<C8^
=3D`<b1]M0dc<3@b;SDa>C<P<c0a<Rhd=C0c86aY3FAc3Fi`3C<a>34^=30g=B0c
<3@g;S4g<S@PKG@=<c0d<Rhe<CTc83<`=3L^<CLb=21/J@eTL`e^L0dc<CPa;S@`
=cDP<c0h<Bhh>C@d86ed3C<`=38^=C4i<b0c<3Pa;SPi=3@PK6T=I7<=KW0=<c4h
<Bhd<3Le83<a<CH^=S4f=B1]M0dc<3@b;SDa>C<P<c4a=Rhf<CHe86aY3FAc3FQU
3@00X@3000=WLPd00:40`01e<20`830PIS<=KW0=LgA]3C4^<30`<20`;S0`<30P
<2h`<30`82da;S0`<30P<2h`<30`82dc=3Ph;STc>CTPHg<==ST^=3@d<B0f>Bhd
=3@a83<a<C4^>CHc=20]=SDa=2h`>CPd86E`3G9dK@eTL`ebM6d=002Q0<00mg=d
K@da;R0a;R0a;R1V<`ecM6d=<Bh`<30`830^<30`<20`;S0`<30P;C4^<30`<20`
;S0`<30P;C<d>3P^>C<i>B1SL`e^L0de<S<i;SPa>38P;CL`=S0^<S4g=B0f=3Pg
;SDe<SPP;CHb<SP^<cTd=21bL0ebM6d=I6D=<20`830PIS<=LgA]3C4^<30`<20`
;S0`<30P<2h`<30`82da;S0`<30P<2h`<30`82dc=3Ph;STc>CTPHg<=KW0==C8c
>Bhh<CPb82dg<3H`;S8a=cDP=S@h=bhe=C8h82df<S8h;S<i=3@PLW0=LWA]3FAc
3G9dK@d00:40`004LgA]3@2Q0<000fMc3@00X@300YeXL`de=SPa;S<i=3PP<c0b
=Bha=CPe86ed3CDf>34^<cTd>20b>CPg;S0f=CPP=CHe<2h`=3<d838i=CD^=c4d
=20e=S4a;STe<3LP<STe=Bhg<C@d86=d3CDe=c<^>3Dg>B0b>CDe;SLa=3@P=CDd
<Rhe<3Hf838i>3L^<3He>20e=C@b;SD`=SHP<c0b=Bha=CPe86=d3CDe=38^=C0f
=R0c<3Hc;S8e<C<P=CDg<bhh=CLi83<`>C@^=S0b=R0e=S4a;STe<3LP<c0i=2hf
<38f86=d3CDf=C0^<3@c=20c<3Td;SH`<SHP=CHh<Bhc>C@h83<`=S<^<SDa<b0e
=SPa;S<i=3PP<c0b=Bha=CPe86=d3F=`3B0`86QS3C0P<20`86Hc3B0b86aZ3Fi`
3CDf>34^<cTd>20b>C0h;S8h=38PKG@==CDd<Rhe<3Hf838i<3P^<SPd<R1/J@eT
L`e^L0de=SPa;S<i=3PP<STd<bh`<3Hb86ed3CDe=38^=C0f=R0b>C@c;S0`=S8P
K6T=I7<=KW0==CHh<Bhc>C@h838i=cL^=c8h<b1]M0de=C@b;SD`=SHP<STg=bhg
<SPc86aY3FAc3Fi`3CDf>34^<cTd>20c<34b;S@e<3<PKG@==CDd<Rhe<3Hf83<`
<C8^=3D`<b1/J@eTL`e^L0de=SPa;S<i=3PP<c0d=bha=c8d86ed3CDe=38^=C0f
=R0c<3@g;S4g<S@PK6T=I7<=KW0==CHh<Bhc>C@h83<`>34^>3Td=21]M0de=C@b
;SD`=SHP<c0h<Bhh>C@d86aY3FAc3Fi`3CDf>34^<cTd>20c<C4f;SHa=SDPKG@=
=CDd<Rhe<3Hf83<a<CH^=S4f=B1/J@eTL`eXI@d00:40`003Ig8=002Q0<00MC0P
<20`86Hc3Fi`3G=dK@da;S0`<30P<2h`<30`830^<30`<20]<Bh`<30`830^<30`
<20]<c@h>2hi<cTi86=c3CHi;S@d=34P=ST^=3@d<B0e=S4a;STe<3LP;CHe<C@^
<3Th=21UL0ebM6d=I7<=LWA]3@00X@300?McM6d=<BhP<BhP<BhPIS<=LgA]3C4^
<30`<20`;S0`<30P<2h`<30`82da;S0`<30P<2h`<30`82dc=3Ph;STc>CTPHg<=
KW0=<cTh>Bhh<S@f82dg<3H`;S8a=cDP=C8c=bhe=CTa82df<S8h;S<i=3@PLW0=
LWA]3FAU3C0P<20`86Hc3G=dK@da;S0`<30P<2h`<30`830^<30`<20]<Bh`<30`
830^<30`<20]<c@h>2hi<cTi86=c3Fi`3C<i>3T^>38d=R0]=c0f<2hb<CLe83Db
<cL^=CDi<B0]=S8b>2hc>C@d879`3G9dK@eTL`ebM6d=002Q0<0017=dK@d0X@30
00=WL`d00:40`0:MJ7<==3Tc=2hh=c0h83<`<SD^<CDh=B1]M0dd>C<d;SPg<3PP
<STh=bh`=SDh83@i<3<^=C4i=20b>CDe;SLa=3@P=3Pf=Bhd<SHg838i=CD^=c4d
=21SM0dd>38g;S<c<cTP<STe=Bhg<C@d83@g>CD^>CPb=R0b>CPg;S0f=CPP=3Li
=Bhi>38f83<`<SD^<CDh=B1SM0dd=cTe;STh<SHP<c0f<bhb=C4c83@h<SL^<c<c
>B0c<3Td;SH`<SHP=3Pf=Bhd<SHg83<`>C@^=S0b=R1SM0dd>C0c;SDa>C@P<c0i
=2hf<38f83@i<c@^>3L`>20c<3Hc;S8e<C<P=3Tc=2hh=c0h83<`<SD^<CDh=B1S
M0eSL0dP<21XH`d`830P<21V<`dP<R1/JPe^L0dd=cDg;S<e>3@P<c0i=2hf<38f
86ed3C@g=CL^<cDh=20b>CDe;SLa=3@PK6T=I7<=KW0==3Li<Rh`>30e83<`>C@^
=S0b=R1]M0dd=cTb;S0h<3DP<STe=Bhg<C@d86aY3FAc3Fi`3C@h<SH^>30b=B0c
<3Td;SH`<SHPKG@==3Pb=Rhh<38e838i=CD^=c4d=21/J@eTL`e^L0dd>3Ha;SDb
=3HP<c0i=2hf<38f86ed3C@h=S4^=C8d=R0b>CDe;SLa=3@PK6T=I7<=KW0==3Pi
=Rhb=3Hf83<`>C@^=S0b=R1]M0dd>3Tf;S8d=SHP<STe=Bhg<C@d86aY3FAc3Fi`
3C@i<c0^>CHh=b0c<3Td;SH`<SHPKG@==3Tc<2hi=SPg838i=CD^=c4d=21/J@eT
L`e^L0dd>CHe;SHi<3LP<c0i=2hf<38f86ed3C@i=SD^=ST`=b0b>CDe;SLa=3@P
K6T=I7<=J6D=002Q0<000fMb3@00X@3007D`830P<21V<`e^L0ecM6d=<Bh`<30`
830^<30`<20`;S0`<30P;C4^<30`<20`;S0`<30P;C<d>3P^>C<i>B1SL`df>Bhd
=3@a83Hi;S@d=34P=3Pf=Bhd<SHg82df=C4d;S0i>3@PIG0=LWA]3FAc3G9dK@d0
0:40`01kLgA]3C4^834^834^86Hc3Fi`3C8c>Bhh=3<f838c>Bhd=SLb834d>3L^
=CLh<B0a<3La;S8i<3<PLW0=I6D=<20`830PIS<=KW0=<S<i;SPd<cHP<S<i;S@f
=c8P<C@h=bhe=cPa834`=c4^<ST`<b1bL0eTL`ebM6d=002Q0<0017=dK@d0X@30
00=WL`d00:40`09NJ7<==SPa;S@b<38P=cPe;SDh=S<PKG@==SPa;S@b<38P>38c
;SHg>B0f=C0^<3Hh>20h=CD^<3<`=20f<C4^>CLf<B0h=CD^<3<`=21SM0de=c<^
>3Pc<b0h=CD^<3<`=20e=38^=C<b83Pb<bhf=cTP=C@b;SDc<R0g>3D^=CPf<b1S
M0de=38^=C<b83Ld=bhd>C<f83Dg<bhh>3<c83La=Rha=38b83Ha<Bhi=cHa83La
=Rha=38b86=d3CHe<2h`=SPh83La=Rha=38b83Hh<Bhd<S0b83Ld=bhd>C<f83Hh
<Bhd<S0b83Lh=Bhe>3Hc86=d3F=`3B0`86QS3C0P<20`86Hc3B0b86aZ3Fi`3C@h
=Rhe=3Hh83La=Rha=38b86ed3C@h=Rhe=3Hh83Pe=Bh`<c0d86aY3FAc3Fi`3CDb
<Bhb=SPh83La=Rha=38b86ed3CDb<Bhb=SPh83Pe=Bh`<c0d86aY3FAc3Fi`3CDe
=Bhi>C0i83La=Rha=38b86ed3CDe=Bhi>C0i83Pe=Bh`<c0d86aY3FAc3Fi`3CDi
<2hg<C8i83La=Rha=38b86ed3CDi<2hg<C8i83Pe=Bh`<c0d86aY3FAc3Fi`3CHb
=Bhd<cDP=c4f;S4d<S8PKG@==S8e;S@c=B0h=CD^<3<`=21/J@eTL`e^L0df=S0^
<CDg83La=Rha=38b86ed3CHf<2ha=CLP>3De;S0c<3@PK6T=I7<=KW0==STd;SPg
>C4P=c4f;S4d<S8PKG@==STd;SPg>C4P>3De;S0c<3@PK6T=I7<=J6D=0:40`003
Ig8=002Q0<00>30P<20`86Hc3Fi`3CHi;S@d=34P=ST^=3@d<B0f<C4^>CLf<B0g
>3D^=CPf<b1UL0eTL`ebM6d=0:40`011LgA]3C0P<20`86Hc3Fi`3C4d>3T^>3<g
<b0b<cT^=3Hg<R0b=c<g;SDg<CPP<C0g<Bhb>C0c879`3FAc3G9dK@d00:40`01m
LgA]3C4^834^834^86Hc3Fi`3C8g<cT^>3<`>B0b<cT^=3Hg<R0c>CPg;SDf=CDP
<C0g<Bhb>C0c879`3FAU3C0P<20`86Hc3Fi`3C8g<cT^>3<`>B0b<cT^=3Hg<R0c
>CPg;SDf=CDP<C0g<Bhb>C0c879`3FAc3G9dK@d00:40`01mLgA]3C4^834^834^
86Hc3Fi`3CDb<cT^>34h<R0b<cT^=3Hg<R0f=3Pg;SDe<SPP<C0g<Bhb>C0c879`
3FAU3C0P<20`86Hc3Fi`3CDb<cT^>34h<R0b<cT^=3Hg<R0f=3Pg;SDe<SPP<C0g
<Bhb>C0c879`3FAc3G9dK@d00:40`004LgA]3@2Q0<000fMc3@00X@300X1XL`de
=SPa;S<i=3PP=cPe;SDh=S<PKG@==CHh<Bhc>C@h83Pb<bhf=cTP=CHe<2h`=3<d
83Pe=Bh`<c0d83Df<C4^>CD`=b0h=CD^<3<`=21SM0de=CLc;SPe=cTP>3De;S0c
<3@P=CDd<Rhe<3Hf83Pb<bhf=cTP=CDd<Rhe<3Hf83Lh=Bhe>3Hc86=d3CDe=38^
=C0f=R0g=3L^=3Tc=R0e=CLc;SPe=cTP=c4f;S4d<S8P=CHa<Bhi=C0g83La=Rha
=38b86=d3CDf=C0^<3@c=20g<CH^<C@b<R0e=SPa;S<i=3PP=c@g;S@i<cHP=CHh
<Bhc>C@h83Lh=Bhe>3Hc86=d3F=`3B0`86QS3C0P<20`86Hc3B0b86aZ3Fi`3CDd
>3H^=C8a=20g<CH^<C@b<R1]M0de=3Pf;SDb<C@P>3De;S0c<3@PK6T=I7<=KW0=
=CDb<Bhb=3<e83La=Rha=38b86ed3CDe<S4^<S@c=B0h=CD^<3<`=21/J@eTL`e^
L0de=CDe;STf=CDP=c4f;S4d<S8PKG@==CDe=Bhi=SDe83Pe=Bh`<c0d86aY3FAc
3Fi`3CDe>C0^=SPg=B0g<CH^<C@b<R1]M0de=CT`;SHh=cDP>3De;S0c<3@PK6T=
I7<=KW0==CHb=Bhd<3Tf83La=Rha=38b86ed3CDf<SD^=30i=R0h=CD^<3<`=21/
J@eTL`e^L0de=SH`;S4c<CHP=c4f;S4d<S8PKG@==CHf<2ha<c4f83Pe=Bh`<c0d
86aY3FAc3Fi`3CDf>C@^>3Dc=b0g<CH^<C@b<R1]M0de=STd;SPe<cLP>3De;S0c
<3@PK6T=I7<=J6D=0:40`003Ig8=002Q0<00>C0P<20`86Hc3Fi`3CHi;S@d=34P
=ST^=3@d<B0e=S4a;STe<3LP=cPe;SDh=S<PIG0=I7<=LWA]3@00X@3007ecM6d=
<BhP<BhP<BhPIS<=KW0=<cTh>Bhh<S@f838c>Bhd=SLb83Db<cL^=CDi<B0a<3La
;S8i<3<PLW0=I6D=<20`830PIS<=KW0=<cTh>Bhh<S@f838c>Bhd=SLb83Db<cL^
=CDi<B0a<3La;S8i<3<PLW0=I7<=LWA]3@00X@3000AcM6d=0:40`003Ig<=002Q
0<02P6Qc3C@i<c@^>3L`>20g>3D^=CPf<b1]M0dd>C<d;SPg<3PP>38c;SHg>B0d
>C0c;SDa>C@P>3De;S0c<3@P=3Pf=Bhd<SHg83Pe=Bh`<c0d86=d3C@h<SL^<c<c
>B0h=CD^<3<`=20d=cTe;STh<SHP>38c;SHg>B0d=cTe;STh<SHP=cPe;SDh=S<P
Hg@==3Li=Bhi>38f83Ld=bhd>C<f83@h<SL^<c<c>B0g<CH^<C@b<R0d>3He;S@b
=SLP=c4f;S4d<S8PHg@==3T`<bhe<CTd83La=Rha=38b83@i<c@^>3L`>20g=3L^
=3Tc=R0d>C<d;SPg<3PP=cPe;SDh=S<PHg@=Hg0=830PJ6<=<20`830PIS<=838P
K6X=KW0==3Tc=2hh=c0h83He<Bhc=C4b86ed3C@g>CD^>CPb=R0f=C4^<cDa<R1/
J@eTL`e^L0dd>C<d;SPg<3PP=SPf;S0g<c<PKG@==3Li=Bhi>38f83Hh=Rh`=c<c
86aY3FAc3Fi`3C@i<c@^>3L`>20g<S0^=cTe<b1]M0dd=cTe;STh<SHP=c8`;SLi
=C<PK6T=I7<=KW0==3Tc=2hh=c0h83Le=Bhe<CLd86ed3C@g>CD^>CPb=R0g=CD^
=C4g=21/J@eTL`e^L0dd>C<d;SPg<3PP=cT`;S8c>C@PKG@==3Li=Bhi>38f83Li
<2hb<cTd86aY3FAc3Fi`3C@i<c@^>3L`>20h<S@^>CHa=21]M0dd=cTe;STh<SHP
>38d;STf<C@PK6T=I7<=KW0==3Tc=2hh=c0h83Pe>Bhf>3<e86ed3C@g>CD^>CPb
=R0h=CT^=SPc=B1/J@eTL`eXI@d0X@3000=WLPd00:40`00i<20`830PIS<=KW0=
=ST^=3@d<B0f>Bhd=3@a83@h=SD^=38f=b0g>3D^=CPf<b1UL0eTL`ebM6d=002Q
0<00mG=dK@da;R0a;R0a;R1V<`ecM6d=<Bh`<30`830^<30`<20`;S0`<30P;C4^
<30`<20`;S0`<30P;C<d>3P^>C<i>B1SL`e^L0db<cT^>3@c=R0]=C<i<bhe=CTc
834d>3L^=CLh<B0]=3Df<Bhg<cHb879`3G9dK@eTI@d`830P<21V<`ecM6d=<Bh`
<30`830^<30`<20`;S0`<30P;C4^<30`<20`;S0`<30P;C<d>3P^>C<i>B1SL`e^
L0db<cT^>3@c=R0]=C<i<bhe=CTc834d>3L^=CLh<B0]=3Df<Bhg<cHb879`3G9d
K@eTL`ebM6d=002Q0<0017=dK@d0X@3000=WL`d00:40`09bJ7<==SPa;S@b<38P
<C<e>2he<30c86ed3CHh<Bhd<S0b834c<S0^=30g=R0f=C0^<3Hh>20a<SPi;S0e
=S8P=S4a;STg=S4P<C8h>Bh`=CHb86=d3CDg<bhh>3<c834b>3T^<3Df<R0e=38^
=C<b834c<S0^=30g=R0e=38^=C<b834c=CP^=C0`<b1SM0de=38^=C<b834c>CH^
=CTc83Dg<bhh>3<c834d<SL^>C@d=20f<C4^>CLf<B0a=38g;STd=3@PHg@==SD`
;S0f>3PP<C@b=bhi=3@d83Hh<Bhd<S0b834c>CH^=CTc83Hh<Bhd<S0b834c=CP^
=C0`<b1SM0eSL0dP<21XH`d`830P<21V<`dP<R1/JPe^L0df>34^=38`<R0a<S@a
;SHb=R1]M0de=38^=C<b834b=34^=S8f86aY3FAc3Fi`3CHh<Bhd<S0b834b=cH^
<c@h86ed3CDd<Rhe<c8P<C8g=Rhc=3PPK6T=I7<=KW0==SPa;S@b<38P<C<a<Bh`
=c0a86ed3CDd<Rhe<c8P<C<a<Bh`=c0a86aY3FAc3Fi`3CHh<Bhd<S0b834c=3D^
=cTb<B1]M0de=38^=C<b834c=3D^=cTb<B1/J@eTL`e^L0df>34^=38`<R0a<cP`
;SDa=38PKG@==C@b;SDc<R0a<cP`;SDa=38PK6T=I7<=KW0==SPa;S@b<38P<C@a
=Bhb<cHb86ed3CDd<Rhe<c8P<C@a=Bhb<cHb86aY3FAc3Fi`3CHh<Bhd<S0b834d
=3T^>CDh<b1]M0de=38^=C<b834d=3T^>CDh<b1/J@eTL`eXI@d0X@3000=WLPd0
0:40`01d<20`830PIS<=KW0=LgA]3C4^<30`<20`;S0`<30P<2h`<30`82da;S0`
<30P<2h`<30`82dc=3Ph;STc>CTPHg<==ST^=3@d<B0f>Bhd=3@a83Ha<Bhi=cHa
82dd>3@g;S@d<38PIG0=LWA]3FAc3G9dK@d0X@300?McM6d=<BhP<BhP<BhPIS<=
LgA]3C4^<30`<20`;S0`<30P<2h`<30`82da;S0`<30P<2h`<30`82dc=3Ph;STc
>CTPHg<=KW0=<C@h>Bhh<cLc82de<cTc;SDe>C<P<SLc=bhe=c4h82dd=CHa;SLc
=S8PLW0=LWA]3FAU3C0P<20`86Hc3G=dK@da;S0`<30P<2h`<30`830^<30`<20]
<Bh`<30`830^<30`<20]<c@h>2hi<cTi86=c3Fi`3C4d>3T^>3<g<b0]=C<i<bhe
=CTc838g<cL^=CLa>20]=3Df<Bhg<cHb879`3G9dK@eTL`ebM6d=002Q0<00mg=d
K@da;R0a;R0a;R1V<`ecM6d=<Bh`<30`830^<30`<20`;S0`<30P;C4^<30`<20`
;S0`<30P;C<d>3P^>C<i>B1SL`e^L0db=c<i;SPc<3TP;CDc>C<^=CDi<b0c>CPg
;SDf=CDP;C@e=S4^=c<f<R1bL0ebM6d=I6D=<20`830PIS<=LgA]3C4^<30`<20`
;S0`<30P<2h`<30`82da;S0`<30P<2h`<30`82dc=3Ph;STc>CTPHg<=KW0=<SLc
>Bhh<c0i82de<cTc;SDe>C<P<cTh=bhe=SDe82dd=CHa;SLc=S8PLW0=LWA]3FAc
3G9dK@d00:40`03gLgA]3C4^834^834^86Hc3G=dK@da;S0`<30P<2h`<30`830^
<30`<20]<Bh`<30`830^<30`<20]<c@h>2hi<cTi86=c3Fi`3CDb<cT^>34h<R0]
=C<i<bhe=CTc83Hd>3L^=CDb>20]=3Df<Bhg<cHb879`3G9dK@eTI@d`830P<21V
<`ecM6d=<Bh`<30`830^<30`<20`;S0`<30P;C4^<30`<20`;S0`<30P;C<d>3P^
>C<i>B1SL`e^L0de<S<i;SPa>38P;CDc>C<^=CDi<b0f=3Pg;SDe<SPP;C@e=S4^
=c<f<R1bL0ebM6d=I7<=LWA]3@00X@3000AcM6d=0:40`003Ig<=002Q0<02UfQc
3CDf>34^<cTd>20a<cDh;SD`<3<PKG@==CHh<Bhc>C@h834c<S0^=30g=R0e=SD`
;S0d<c@P<C8h>Bh`=CHb83Df<C4^>CD`=b0a<SPi;S0e=S8PHg@==CDg<bhh=CLi
834b>3T^<3Df<R0e=C@b;SD`=SHP<C<b<2hd<3Lf83De=38^=C0f=R0a<cDh;SD`
<3<PHg@==CDd<Rhe<3Hf834c>CH^=CTc83De=c<^>3Dg>B0a=38g;STd=3@P=CHa
<Bhi=C0g834d<SL^>C@d=21SM0de=SD`;S0d<c@P<C@b=bhi=3@d83Df>34^<cTd
>20a<cTf;SDi<b0e=SPa;S<i=3PP<C<e>2he<30c86=d3F=`3B0`86QS3C0P<20`
86Hc3B0b86aZ3Fi`3CDf>34^<cTd>20a<S@a;SHb=R1]M0de=C@b;SD`=SHP<C8d
<Bhf<SHPK6T=I7<=KW0==CHh<Bhc>C@h834b=cH^<c@h86ed3CDe=38^=C0f=R0a
<SLf;S<d>21/J@eTL`e^L0de=SPa;S<i=3PP<C<a<Bh`=c0a86ed3CDe=38^=C0f
=R0a<c4a;S0g<34PK6T=I7<=KW0==CHh<Bhc>C@h834c=3D^=cTb<B1]M0de=C@b
;SD`=SHP<C<d=Bhg>C8a86aY3FAc3Fi`3CDf>34^<cTd>20a<cP`;SDa=38PKG@=
=CDd<Rhe<3Hf834c>30^=C4d<R1/J@eTL`e^L0de=SPa;S<i=3PP<C@a=Bhb<cHb
86ed3CDe=38^=C0f=R0a=34e;S8c=S8PK6T=I7<=KW0==CHh<Bhc>C@h834d=3T^
>CDh<b1]M0de=C@b;SD`=SHP<C@d>Bhi=CPc86aY3FAc3FQU3@00X@3000=WLPd0
0:40`01e<20`830PIS<=KW0=LgA]3C4^<30`<20`;S0`<30P<2h`<30`82da;S0`
<30P<2h`<30`82dc=3Ph;STc>CTPHg<==ST^=3@d<B0f>Bhd=3@a83Df<C4^>CD`
=b0]=3Pd=bhd=30b86E`3G9dK@eTL`ebM6d=002Q0<00mg=dK@da;R0a;R0a;R1V
<`ecM6d=<Bh`<30`830^<30`<20`;S0`<30P;C4^<30`<20`;S0`<30P;C<d>3P^
>C<i>B1SL`e^L0dc>CPi;SPb=3HP;CDc>C<^=CDi<b0e<S<g;SDe>C4P;C@e=S4^
=c<f<R1bL0ebM6d=I6D=<20`830PIS<=LgA]3C4^<30`<20`;S0`<30P<2h`<30`
82da;S0`<30P<2h`<30`82dc=3Ph;STc>CTPHg<=KW0=<cTh>Bhh<S@f82de<cTc
;SDe>C<P=C8c=bhe=CTa82dd=CHa;SLc=S8PLW0=LWA]3FAc3G9dK@d00:40`004
LgA]3@2Q0<000fMc3@00X@300Y]XL`dd>C<d;SPg<3PP<C<e>2he<30c86ed3C@i
<c@^>3L`>20a<c8`;S@`=cHP=3T`<bhe<CTd834b>3T^<3Df<R0d>3He;S@b=SLP
<C8h>Bh`=CHb86=d3C@h<SL^<c<c>B0a<SPi;S0e=S8P=3Li=Bhi>38f834c<S0^
=30g=R0d=cTe;STh<SHP<C<e>2he<30c86=d3C@g>CD^>CPb=R0a<cTf;SDi<b0d
>38g;S<c<cTP<C@b=bhi=3@d83@h=SD^=38f=b0a=38g;STd=3@PHg@==3T`<bhe
<CTd834d<SL^>C@d=20d>C<d;SPg<3PP<C<i=Rhe>C<P=3Tc=2hh=c0h834c=CP^
=C0`<b1SM0eSL0dP<21XH`d`830P<21V<`dP<R1/JPe^L0dd=cDg;S<e>3@P<C@b
=bhi=3@d86ed3C@g=CL^<cDh=20a<SPi;S0e=S8PK6T=I7<=KW0==3Li<Rh`>30e
834d<SL^>C@d=21]M0dd=cTb;S0h<3DP<C8h>Bh`=CHb86aY3FAc3Fi`3C@h<SH^
>30b=B0a=38g;STd=3@PKG@==3Pb=Rhh<38e834b>3T^<3Df<R1/J@eTL`e^L0dd
>3Ha;SDb=3HP<C@b=bhi=3@d86ed3C@h=S4^=C8d=R0a<SPi;S0e=S8PK6T=I7<=
KW0==3Pi=Rhb=3Hf834d<SL^>C@d=21]M0dd>3Tf;S8d=SHP<C8h>Bh`=CHb86aY
3FAc3Fi`3C@i<c0^>CHh=b0a=38g;STd=3@PKG@==3Tc<2hi=SPg834b>3T^<3Df
<R1/J@eTL`e^L0dd>CHe;SHi<3LP<C@b=bhi=3@d86ed3C@i=SD^=ST`=b0a<SPi
;S0e=S8PK6T=I7<=J6D=002Q0<000fMb3@00X@3007D`830P<21V<`e^L0ecM6d=
<Bh`<30`830^<30`<20`;S0`<30P;C4^<30`<20`;S0`<30P;C<d>3P^>C<i>B1S
L`df>Bhd=3@a83Hi;S@d=34P=3Pf=Bhd<SHg82dd>3@g;S@d<38PIG0=LWA]3FAc
3G9dK@d00:40`01mLgA]3C4^834^834^86Hc3Fi`3C8c>Bhh=3<f83<e=CD^=38b
=R0a=3Pg;SDg>34P=3<h=bhb=3Dg879`3FAU3C0P<20`86Hc3Fi`3C8c>Bhh=3<f
83<e=CD^=38b=R0a=3Pg;SDg>34P=3<h=bhb=3Dg879`3FAc3G9dK@d00:40`004
LgA]3@2Q0<000fMc3@00X@300W]XL`df>34^=38`<R0d<C0a;SDd<CLPKG@==SPa
;S@b<38P=34c>Bhf<c@d83He<2h`=SPh83@a=c0^>CPe>20f<C4^>CLf<B0d<CL`
;STh=CPPHg@==CLc;SPh<c<P=34g<2hi>3Dh83Dd<Rhe<c8P=34c>Bhf<c@d83Dd
<Rhe<c8P=34`<Bhe=34g86=d3CDd<Rhe<c8P=30f<bhd=3Pi83Dg<bhh>3<c83@`
<c8^<3Tg=R0f<C4^>CLf<B0d<3<b;S0i=cHPHg@==SD`;S0f>3PP=30c<Rh`>CLf
83Hh<Bhd<S0b83@`=S<^=3@h>B0f>34^=38`<R0d<C0a;SDd<CLPHg@=Hg0=830P
J6<=<20`830PIS<=838PK6X=KW0==3Pf;SDd=SPP=30c<Rh`>CLf86ed3C@h=Rhe
=3Hh83@a=c0^>CPe>21/J@eTL`e^L0de<S4^<SHh>20d<3<b;S0i=cHPKG@==C8a
;S8f>3PP=34g<2hi>3Dh86aY3FAc3Fi`3CDe=Bhi>C0i83@`<c8^<3Tg=R1]M0de
=CD^>CT`>B0d<CL`;STh=CPPK6T=I7<=KW0==CT`;SLa<STP=30c<Rh`>CLf86ed
3CDi<2hg<C8i83@a=c0^>CPe>21/J@eTL`e^L0df<SD^=3<e83@`<c8^<3Tg=R1]
M0df<SD^=3<e83@a=c0^>CPe>21/J@eTL`e^L0df=S0^<CDg83@`<c8^<3Tg=R1]
M0df=S0^<CDg83@a=c0^>CPe>21/J@eTL`e^L0df>C@^>3Li<B0d<3<b;S0i=cHP
KG@==STd;SPg>C4P=34g<2hi>3Dh86aY3FAc3FQU3@00X@3000=WLPd00:40`00i
<20`830PIS<=KW0==ST^=3@d<B0f>Bhd=3@a83Ha<Bhi=cHa83@a<34^=C@a=b1U
L0eTL`ebM6d=002Q0<00Og=dK@da;R0a;R0a;R1V<`e^L0da=3Pi;SPc=c<P<cDe
=Bhd<S8f838g<cL^=CLa>20d<cPg;S8d=CLPLW0=I6D=<20`830PIS<=KW0=<C@h
>Bhh<cLc83<e=CD^=38b=R0b=c<g;SDg<CPP=3<h=bhb=3Dg879`3FAc3G9dK@d0
0:40`004LgA]3@2Q0<000fMc3@00X@300YeXL`db=3<d;SPh<cDP=34`<Bhe=34g
86ed3C8d<c@^>3Pc=B0d<C<i;SHc=3@P<S@`<bhe<c8a83@a=c0^>CPe>20b<cHe
;S@c>C@P=34g<2hi>3Dh86=d3C8c<SL^<c@f=R0d<CL`;STh=CPP<S8i=Bhi>CDc
83@a<cT^=S<d=20b<STe;STi=C<P=34`<Bhe=34g86=d3C8b>CD^>CTe<b0d<3Hc
;S@d>3TP<S<b=bhc=3Hf83@`<c8^<3Tg=R0b<cHe;S@c>C@P=30c<Rh`>CLf86=d
3C8d<3<^=C<b<B0d<3<b;S0i=cHP<S@c=2hh>3<e83@`=S<^=3@h>B0b=3<d;SPh
<cDP=34`<Bhe=34g86=d3F=`3B0`86QS3C0P<20`86Hc3B0b86aZ3Fi`3C8d<c@^
>3Pc=B0c>CPd;SHf=cHPKG@=<S8i=Bhi>CDc83<i>3@^=SHg=R1/J@eTL`e^L0db
=3<d;SPh<cDP=30a>Bhc>3Tg86ed3C8b>CD^>CTe<b0d<34i;S<h>CLPK6T=I7<=
KW0=<S@c=2hh>3<e83@`=C@^<C4a=b1]M0db<STe;STi=C<P=30e=2ha<C4g86aY
3FAc3Fi`3C8d<c@^>3Pc=B0d<3Ph;SPc<cPPKG@=<S8i=Bhi>CDc83@`>3P^>3<c
>21/J@eTL`e^L0db=3<d;SPh<cDP=34b<bhe=CDh86ed3C8b>CD^>CTe<b0d<C8c
;SDe=CPPK6T=I7<=KW0=<S@c=2hh>3<e83@a=CP^<SLg>B1]M0db<STe;STi=C<P
=34e>2hb=cLi86aY3FAc3Fi`3C8d<c@^>3Pc=B0d<CTb;STi>CTPKG@=<S8i=Bhi
>CDc83@a>C8^>CTi>B1/J@eTL`eXI@d00:40`003Ig8=002Q0<00>S0P<20`86Hc
3Fi`3CHi;S@d=34P=ST^=3@d<B0b<cHe;S@c>C@P=34`<Bhe=34g86E`3FAc3G9d
K@d0X@3007mcM6d=<BhP<BhP<BhPIS<=KW0=<SLc>Bhh<c0i83<e=CD^=38b=R0c
>CPg;SDf=CDP=3<h=bhb=3Dg879`3FAU3C0P<20`86Hc3Fi`3C8g<cT^>3<`>B0c
=CDe;S@b<SHP<cTh=bhe=SDe83@c>3L^<S@e=b1bL0eTL`ebM6d=002Q0<0017=d
K@d0X@3000=WL`d00:40`0:MJ7<=<c4h<Bhd<3Le83@a<34^=C@a=b1]M0dc<CPa
;S@`=cDP=34c>Bhf<c@d83<a=C0^<3Df<B0d<CL`;STh=CPP<c4a<Bhi=S<d83@a
=c0^>CPe>21SM0dc<3Lc;SPg<3HP=34g<2hi>3Dh83<`=38^=C4i<b0d<C<i;SHc
=3@P<c0d<Rhe<CTc83@a<34^=C@a=b1SM0dc<3@b;SDa>C<P=30f<bhd=3Pi83<`
=c<^>3L`=R0d<3<b;S0i=cHP<c4a<Bhi=S<d83@`<c8^<3Tg=R1SM0dc<CD`;S0e
=S4P=30c<Rh`>CLf83<a>34^=30g=B0d<3Hc;S@d>3TP<c4h<Bhd<3Le83@a<34^
=C@a=b1SM0eSL0dP<21XH`d`830P<21V<`dP<R1/JPe^L0db>CPf;SDc=34P=30c
<Rh`>CLf86ed3C8i>3H^=C<d<B0d<CL`;STh=CPPK6T=I7<=KW0=<c0b<Bhb=CHb
83@`<c8^<3Tg=R1]M0dc<38a;S8e=S8P=34g<2hi>3Dh86aY3FAc3Fi`3C<`=CD^
>CLh<R0d<3<b;S0i=cHPKG@=<c0e=Bhi=cPb83@a=c0^>CPe>21/J@eTL`e^L0dc
<3T`;SL`<38P=30c<Rh`>CLf86ed3C<`>C0^=c0`<R0d<CL`;STh=CPPK6T=I7<=
KW0=<c4b=Bhd<S8c83@`<c8^<3Tg=R1]M0dc<C8e;S@b<S<P=34g<2hi>3Dh86aY
3FAc3Fi`3C<a=S0^<C@d<b0d<3<b;S0i=cHPKG@=<c4f<2ha=3@c83@a=c0^>CPe
>21/J@eTL`e^L0dc<CTd;SPf=S@P=30c<Rh`>CLf86ed3C<a>C@^>3Hf=20d<CL`
;STh=CPPK6T=I7<=J6D=002Q0<000fMb3@00X@3003X`830P<21V<`e^L0df>Bhd
=3@a83Hi;S@d=34P<c4a<Bhi=S<d83@a<34^=C@a=b1UL0eTL`ebM6d=0:40`01o
LgA]3C4^834^834^86Hc3Fi`3CDb<cT^>34h<R0c=CDe;S@b<SHP=S@h=bhe=C8h
83@c>3L^<S@e=b1bL0eTI@d`830P<21V<`e^L0de<S<i;SPa>38P<cDe=Bhd<S8f
83Hd>3L^=CDb>20d<cPg;S8d=CLPLW0=I7<=LWA]3@00X@3000AcM6d=0:40`003
Ig<=002Q0<02WFQc3CDf>34^<cTd>20d<C0a;SDd<CLPKG@==CHh<Bhc>C@h83@a
<cT^=S<d=20e=SD`;S0d<c@P=34g<2hi>3Dh83Df<C4^>CD`=b0d<CL`;STh=CPP
Hg@==CDg<bhh=CLi83@a=c0^>CPe>20e=C@b;SD`=SHP=34c>Bhf<c@d83De=38^
=C0f=R0d<C0a;SDd<CLPHg@==CDd<Rhe<3Hf83@`=S<^=3@h>B0e=CLc;SPe=cTP
=30c<Rh`>CLf83Df<C4^>CD`=b0d<3<b;S0i=cHPHg@==CHe<2h`=3<d83@`<c8^
<3Tg=R0e=SPa;S<i=3PP=30f<bhd=3Pi83Df>34^<cTd>20d<C0a;SDd<CLPHg@=
Hg0=830PJ6<=<20`830PIS<=838PK6X=KW0==C@h=Rhe<S4d83@`<c8^<3Tg=R1]
M0de=3Pf;SDb<C@P=34g<2hi>3Dh86aY3FAc3Fi`3CDe<S4^<S@c=B0d<3<b;S0i
=cHPKG@==CDb<Bhb=3<e83@a=c0^>CPe>21/J@eTL`e^L0de=CDe;STf=CDP=30c
<Rh`>CLf86ed3CDe=CD^>CHe=B0d<CL`;STh=CPPK6T=I7<=KW0==CDi<2hf>3Le
83@`<c8^<3Tg=R1]M0de=CT`;SHh=cDP=34g<2hi>3Dh86aY3FAc3Fi`3CDf<SD^
=30i=R0d<3<b;S0i=cHPKG@==CHb=Bhd<3Tf83@a=c0^>CPe>21/J@eTL`e^L0de
=SH`;S4c<CHP=30c<Rh`>CLf86ed3CDf=S0^<C<a=R0d<CL`;STh=CPPK6T=I7<=
KW0==CHi=2hh=C<g83@`<c8^<3Tg=R1]M0de=STd;SPe<cLP=34g<2hi>3Dh86aY
3FAc3FQU3@00X@3000=WLPd00:40`00j<20`830PIS<=KW0==ST^=3@d<B0f>Bhd
=3@a83Df<C4^>CD`=b0d<C0a;SDd<CLPIG0=I7<=LWA]3@2Q0<00Og=dK@da;R0a
;R0a;R1V<`e^L0dc>CPi;SPb=3HP<cDe=Bhd<S8f83Db<cL^=CDi<B0d<cPg;S8d
=CLPLW0=I6D=<20`830PIS<=KW0=<cTh>Bhh<S@f83<e=CD^=38b=R0e<S<g;SDe
>C4P=3<h=bhb=3Dg879`3FAc3G9dK@d00:40`004LgA]3@2Q0<000fMc3@00X@30
0YeXL`dd>C<d;SPg<3PP=34`<Bhe=34g86ed3C@i<c@^>3L`>20d<C<i;SHc=3@P
=3T`<bhe<CTd83@a=c0^>CPe>20d>3He;S@b=SLP=34g<2hi>3Dh86=d3C@h<SL^
<c<c>B0d<CL`;STh=CPP=3Li=Bhi>38f83@a<cT^=S<d=20d=cTe;STh<SHP=34`
<Bhe=34g86=d3C@g>CD^>CPb=R0d<3Hc;S@d>3TP=3Pb=bhc<c<i83@`<c8^<3Tg
=R0d>3He;S@b=SLP=30c<Rh`>CLf86=d3C@i<3<^=C4i=20d<3<b;S0i=cHP=3Tc
=2hh=c0h83@`=S<^=3@h>B0d>C<d;SPg<3PP=34`<Bhe=34g86=d3F=`3B0`86QS
3C0P<20`86Hc3B0b86aZ3Fi`3C@i<c@^>3L`>20c>CPd;SHf=cHPKG@==3Li=Bhi
>38f83<i>3@^=SHg=R1/J@eTL`e^L0dd>C<d;SPg<3PP=30a>Bhc>3Tg86ed3C@g
>CD^>CPb=R0d<34i;S<h>CLPK6T=I7<=KW0==3Tc=2hh=c0h83@`=C@^<C4a=b1]
M0dd=cTe;STh<SHP=30e=2ha<C4g86aY3FAc3Fi`3C@i<c@^>3L`>20d<3Ph;SPc
<cPPKG@==3Li=Bhi>38f83@`>3P^>3<c>21/J@eTL`e^L0dd>C<d;SPg<3PP=34b
<bhe=CDh86ed3C@g>CD^>CPb=R0d<C8c;SDe=CPPK6T=I7<=KW0==3Tc=2hh=c0h
83@a=CP^<SLg>B1]M0dd=cTe;STh<SHP=34e>2hb=cLi86aY3FAc3Fi`3C@i<c@^
>3L`>20d<CTb;STi>CTPKG@==3Li=Bhi>38f83@a>C8^>CTi>B1/J@eTL`eXI@d0
0:40`003Ig8=002Q0<00>S0P<20`86Hc3Fi`3CHi;S@d=34P=ST^=3@d<B0d>3He
;S@b=SLP=34`<Bhe=34g86E`3FAc3G9dK@d0X@3002McM6d=<20`830PIS<=<2ha
<SD`830^<C8e<21cL0d`830P<21V<`d00:40`01ELgA]3C4e=Rhb=3Tb86IdL`d_
GemOATha86=fLfH=<20`830PIS<=AR1cH@dc<30^=3Lg=R0a<S8h;S8i<S@PKG@=
:2dY821cJ6mg3E@PLf4=LWA]3@00X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc
3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00?7=dK@d`830P<21V<`e6
87=Q3C8g>C4^=cPd=20a<S8h;S8i<S@PKG@=:2dY821cJ6mg3E@PLf4=LWA]3@2Q
0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P
<21V<`d00:40`00lLgA]3C0P<20`86Hc3DHPLf4==C8i<Bhg=c4g834b<SP^<STb
=21]M0dX;BTP87=XKgL=E21cH@ebM6d=0:40`004LWA]3@2Q0<009g=dK@d`830P
<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@3003]cM6d=<20`830P
IS<=AR1cH@dc<30^=3Lg=R0b<3@d;S8f<3DPKG@=:2/Y821cJ6mg3E@PLf4=LWA]
3@00X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=
<20`830PIS<=002Q0<00?7=dK@d`830P<21V<`e687=Q3C8g>C4^=cPd=20b<3@d
;S8f<3DPKG@=:2/Y821cJ6mg3E@PLf4=LWA]3@2Q0<00179dK@d0X@3002McM6d=
<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`00lLgA]3C0P
<20`86Hc3DHPLf4==C8i<Bhg=c4g838`=3@^<SH`=B1]M0dX:bTP87=XKgL=E21c
H@ebM6d=0:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`
87=`3C0P<20`86Hc3@00X@3003]cM6d=<20`830PIS<=AR1cH@dc<30^=3Lg=R0c
=SPd;SPg=c4PKG@=:2/Y821cJ6mg3E@PLf4=LWA]3@00X@3000AbM6d=0:40`00W
LgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00?7=d
K@d`830P<21V<`e687=Q3C8g>C4^=cPd=20c=SPd;SPg=c4PKG@=:2/Y821cJ6mg
3E@PLf4=LWA]3@2Q0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^
<C8e<21cL0d`830P<21V<`d00:40`00lLgA]3C0P<20`86Hc3DHPLf4==C8i<Bhg
=c4g83<f>3@^>3Lg<B1]M0dX:bTP87=XKgL=E21cH@ebM6d=0:40`004LWA]3@2Q
0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@30
03acM6d=<20`830PIS<=AR1cH@da=C@a;SLi<3PP<SPg=bhe>3Tf86ed3BP[:B0P
LfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e
<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00?7=dK@d`830P<21V<`e687=Q3C@`
=34^=cLh<B0b>3Lg;SDh>CHPKG@=:2/Y821cJ6mg3E@PLf4=LWA]3@2Q0<00179d
K@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d0
0:40`00lLgA]3C0P<20`86Hc3DHPLf4=<CDd<Bhg>C0h834b<SP^<STb=21]M0dX
:bTP87=XKgL=E21cH@ebM6d=0:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`
;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@3003acM6d=<20`830PIS<=AR1c
H@dd<3@a;SLg>34P<C8b>2hb>C8d86ed3BP[:B0PLfQ_M`eD87=Q3G9dK@d0X@30
00AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830P
IS<=002Q0<00>g=dK@d`830P<21V<`e687=Q3C<`<2hd=cLf838h=cL^=CPi=R1]
M0dX;BTP87=XKgL=E21cH@ebM6d=002Q0<00179dK@d0X@3002McM6d=<20`830P
IS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`00lLgA]3C0P<20`86Hc
3DHPLf4=<SLi<Bhg>3@d838h=cL^=CPi=R1]M0dX;BTP87=XKgL=E21cH@ebM6d=
0:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P
<20`86Hc3@00X@3003acM6d=<20`830PIS<=AR1cH@de<STa;SLg<CLP<SPg=bhe
>3Tf86ed3BP]:B0PLfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=0:40`00WLgA]3C0P
<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00>W=dK@d`830P
<21V<`e687=Q3C<`<2hd=cLf83<i=2hi=S<c86ed3BP[:B0PLfQ_M`eD87=Q3G9d
K@d0X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=
<20`830PIS<=002Q0<00>g=dK@d`830P<21V<`e687=Q3C8g>C4^=cPd=20c>C@^
>CHc<b1]M0dX:bTP87=XKgL=E21cH@ebM6d=002Q0<00179dK@d0X@3002McM6d=
<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`00kLgA]3C0P
<20`86Hc3DHPLf4==C8i<Bhg=c4g83<i=2hi=S<c86ed3BP[:B0PLfQ_M`eD87=Q
3G9dK@d00:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`
87=`3C0P<20`86Hc3@00X@3003]cM6d=<20`830PIS<=AR1cH@da=C@a;SLi<3PP
<cTd;STf<c<PKG@=:2dY821cJ6mg3E@PLf4=LWA]3@00X@3000AbM6d=0:40`00W
LgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00>g=d
K@d`830P<21V<`e687=Q3C@`=34^=cLh<B0c>C@^>CHc<b1]M0dX;BTP87=XKgL=
E21cH@ebM6d=002Q0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^
<C8e<21cL0d`830P<21V<`d00:40`00lLgA]3C0P<20`86Hc3DHPLf4=<CDd<Bhg
>C0h838`=3@^<SH`=B1]M0dX;BTP87=XKgL=E21cH@ebM6d=0:40`004LWA]3@2Q
0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@30
03acM6d=<20`830PIS<=AR1cH@dd<3@a;SLg>34P<S0d=2hb=S0e86ed3BP]:B0P
LfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e
<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00?7=dK@d`830P<21V<`e687=Q3C4e
=34^=cT`>20c=SPd;SPg=c4PKG@=:2dY821cJ6mg3E@PLf4=LWA]3@2Q0<00179d
K@d0X@3000AcM6d=0:40`003Ig<=002Q0<02Z6Qc3C<a<3@^<cHg>B0b=C8c;SPe
>3LPKG@=<c4b<Bhg<SPi838e<S<^>3Dh=b1/J@dc<C8a;SLb>3TP<SLc>2hg<34d
86aY3C<a<3@^<cHg>B0b=c<h;SL`<C@PK6T=<c4`=2hc=SLi838e<S<^>3Dh=b1/
J@eSL0dP<B1XH`d`830P<21V<`da=bhc=S4`834g;S<f<C0PLg0=838PK6X=KW0=
<c4b<Bhg<SPi838d=CH^>3Tg=R1]M0dc<C0d;S<f=cTP<S@e=Rhh>CLf86aY3FAc
3Fi`3C<a<S4^=c8h>B0b=3Ta;SHa>CHPKG@=<c4`=2hc=SLi838d>C4^=S4i=R1/
J@eTL`e^L0dc<C8a;SLb>3TP<SDb=Rhc=34g86ed3C<a<3@^<cHg>B0b=C8f;S<d
<CLPK6T=I7<=KW0=<c4b<Bhg<SPi838e=S4^<3Hc=b1]M0dc<C0d;S<f=cTP<SDf
<Bh`=S<g86aY3FAc3Fi`3C<a<S4^=c8h>B0b=CTe;SLh=CPPKG@=<c4`=2hc=SLi
838e>CD^=cPe>21/J@eTL`e^L0dc<C8a;SLb>3TP<SHc<2he<3Lh86ed3C<a<3@^
<cHg>B0b=S<`;SD`=cPPK6T=I7<=KW0=<c4b<Bhg<SPi838f=SD^<S8i>B1]M0dc
<C0d;S<f=cTP<SHf=Bhb<STi86aY3FAc3Fi`3C<a<S4^=c8h>B0b=STi;STe<CTP
KG@=<c4`=2hc=SLi838f>CT^>CDa>B1/J@eTL`e^L0dc<C8a;SLb>3TP<SLc=2hf
=c@PKG@=<c4`=2hc=SLi838g<c@^=SLd86aY3FAc3Fi`3C<a<S4^=c8h>B0b=cHi
;S<i=R1]M0dc<C0d;S<f=cTP<SLf>Bhc>CHPK6T=I7<=J6D=0:40`003Ig8=002Q
0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P
<21V<`d00:40`00lLgA]3C0P<20`86Hc3DHPLf4==30d<Bhg=cPa83<f>3@^>3Lg
<B1]M0dX;BTP87=XKgL=E21cH@ebM6d=0:40`004LWA]3@2Q0<0017=dK@d0X@30
00=WL`d00:40`0<>J7<=<c0d=Bhg=c@e838d=3D^=c<d<B1]M0dc<3@e;SLg=3DP
<S@f<bh`>CDa86aY3C8g<cL^=S4f<b0b=3Hc;S0i=C4PK6T=<SLc=bhf<CHc838d
=3D^=c<d<B1/J@dc<3@e;SLg=3DP<S@d=Bhg<c@a86aY3F=`3B0a86QS3C0P<20`
86Hc3C4g;S<f<C0P<CL^<cHa<21cL0dP<R1/JPe^L0db=SLd;S0c=CLP<S@d=Bhg
<c@a86ed3C8f=c@^<3<e=b0b=3Hc;S0i=C4PK6T=I7<=KW0=<SL`>2hg=CLg838d
=3D^=c<d<B1]M0db=c0h;SLe=cLP<S@f<bh`>CDa86aY3FAc3Fi`3C8g=3<^=3Li
>20b=3@e;SLc=34PKG@=<SLd<bhd=cTh838d=S<^<3Te<B1/J@eTL`e^L0db=cLh
;S8`<CPP<S@d=Bhg<c@a86ed3C8g=cP^<S0a>20b=3Hc;S0i=C4PK6T=I7<=KW0=
<SPa<Rhi<S<i838d=3D^=c<d<B1]M0db>34b;STb<cTP<S@f<bh`>CDa86aY3FAc
3Fi`3C8h=3L^=S@e>B0b=3@e;SLc=34PKG@=<SPd=bhf=3Di838d=S<^<3Te<B1/
J@eTL`e^L0db>3Pb;S<f>20b=3@e;SLc=34PKG@=<SPh<Rhc=SPP<S@f<bh`>CDa
86aY3FAc3Fi`3C8i<CL^<3TP<S@d=Bhg<c@a86ed3C8i<CL^<3TP<S@f<bh`>CDa
86aY3FAc3Fi`3C8i=C4^>34b<B0b=3@e;SLc=34PKG@=<STe<Bhh<C8a838d=S<^
<3Te<B1/J@eTL`e^L0db>CPf;SDc=34P<S@d=Bhg<c@a86ed3C8i>3H^=C<d<B0b
=3Hc;S0i=C4PK6T=I7<=KW0=<c0b<Bhb=CHb838d=3D^=c<d<B1]M0dc<38a;S8e
=S8P<S@f<bh`>CDa86aY3FAc3Fi`3C<`=CD^>CLh<R0b=3@e;SLc=34PKG@=<c0e
=Bhi=cPb838d=S<^<3Te<B1/J@eTL`eXI@d0X@3000=WLPd00:40`004LWA]3@2Q
0<0017=dK@d0X@3000=WL`d00:40`0J0J7<=<cHc=Rhe>C4h838a<c<^<S<e=b1]
M0dc=S<f;SDi<CPP<S4e<2he>CHg86aY3C8g<c<^<SLf<B0b<CD`;SDi=SLPK6T=
<SLc<bhb=cHa838a<c<^<S<e=b1/J@dc=S<f;SDi<CPP<S4c<bhb<cDg86aY3F=`
3B0a86QS3C0P<20`86Hc3C4g;S<f<C0P<CL^<cHa<21cL0dP<R1/JPe^L0db=SLd
;S0c=CLP<S4c<bhb<cDg86ed3C8f=c@^<3<e=b0b<CD`;SDi=SLPK6T=I7<=KW0=
<SL`>2hg=CLg838a<c<^<S<e=b1]M0db=c0h;SLe=cLP<S4e<2he>CHg86aY3FAc
3Fi`3C8g=3<^=3Li>20b<C<c;S8c=CLPKG@=<SLd<bhd=cTh838a=C0^=CTf=b1/
J@eTL`e^L0db=cLh;S8`<CPP<S4c<bhb<cDg86ed3C8g=cP^<S0a>20b<CD`;SDi
=SLPK6T=I7<=KW0=<SPa<Rhi<S<i838a<c<^<S<e=b1]M0db>34b;STb<cTP<S4e
<2he>CHg86aY3FAc3Fi`3C8h=3L^=S@e>B0b<C<c;S8c=CLPKG@=<SPd=bhf=3Di
838a=C0^=CTf=b1/J@eTL`e^L0db>3Pb;S<f>20b<C<c;S8c=CLPKG@=<SPh<Rhc
=SPP<S4e<2he>CHg86aY3FAc3Fi`3C8i<CL^<3TP<S4c<bhb<cDg86ed3C8i<CL^
<3TP<S4e<2he>CHg86aY3FAc3Fi`3C8i=C4^>34b<B0b<C<c;S8c=CLPKG@=<STe
<Bhh<C8a838a=C0^=CTf=b1/J@eTL`e^L0db>CPf;SDc=34P<S4c<bhb<cDg86ed
3C8i>3H^=C<d<B0b<CD`;SDi=SLPK6T=I7<=KW0=<c0b<Bhb=CHb838a<c<^<S<e
=b1]M0dc<38a;S8e=S8P<S4e<2he>CHg86aY3FAc3Fi`3C<`=CD^>CLh<R0b<C<c
;S8c=CLPKG@=<c0e=Bhi=cPb838a=C0^=CTf=b1/J@eTL`e^L0dc<3T`;SL`<38P
<S4c<bhb<cDg86ed3C<`>C0^=c0`<R0b<CD`;SDi=SLPK6T=I7<=KW0=<c4b=Bhd
<S8c838a<c<^<S<e=b1]M0dc<C8e;S@b<S<P<S4e<2he>CHg86aY3FAc3Fi`3C<a
=S0^<C@d<b0b<C<c;S8c=CLPKG@=<c4f<2ha=3@c838a=C0^=CTf=b1/J@eTL`e^
L0dc<CTd;SPf=S@P<S4c<bhb<cDg86ed3C<a>C@^>3Hf=20b<CD`;SDi=SLPK6T=
I7<=KW0=<c8b>Bhe>3Pd838a<c<^<S<e=b1]M0dc<S8i;SDh>3@P<S4e<2he>CHg
86aY3FAc3Fi`3C<b=S@^<c4`=B0b<C<c;S8c=CLPKG@=<c8f=2hc<C0e838a=C0^
=CTf=b1/J@eTL`e^L0dc<STi;S0c<SDP<S4c<bhb<cDg86ed3C<b>CT^<3<b=B0b
<CD`;SDi=SLPK6T=I7<=KW0=<c<c<bhg=C@f838a<c<^<S<e=b1]M0dc<c<c;SLe
=3HP<S4e<2he>CHg86aY3FAc3Fi`3C<c=SP^=3Lf=R0b<C<c;S8c=CLPKG@=<c<f
>2hd=cHf838a=C0^=CTf=b1/J@eTL`e^L0dc=30c;S4i>3LP<S4c<bhb<cDg86ed
3C<d<3<^<CTh=b0b<CD`;SDi=SLPK6T=I7<=KW0=<c@c=bhi<S0g838a<c<^<S<e
=b1]M0dc=3<g;STb<3LP<S4e<2he>CHg86aY3FAc3Fi`3C<d=c8^=S@b=b0b<C<c
;S8c=CLPKG@=<c@g<Rhf=38g838a=C0^=CTf=b1/J@eTL`e^L0dc=C0g;S<f=3PP
<S4c<bhb<cDg86ed3C<e<3L^<cHd>20b<CD`;SDi=SLPK6T=I7<=KW0=<cDd<Rh`
>3Hh838a<c<^<S<e=b1]M0dc=C@b;S0h=SPP<S4e<2he>CHg86aY3FAc3Fi`3C<e
=cH^>30h>B0b<C<c;S8c=CLPKG@=<cDg=Rhh<3Pi838a=C0^=CTf=b1/J@eTL`e^
L0dc=S4a;SDc<3TP<S4c<bhb<cDg86ed3C<f<C4^=C<`>B0b<CD`;SDi=SLPK6T=
I7<=KW0=<cHd=Rhb=C<P<S4c<bhb<cDg86ed3C<f=3H^<SDc838a=C0^=CTf=b1/
J@eTL`eXI@d0X@3000=WLPd00:40`004LWA]3@2Q0<0017=dK@d0X@3000=WL`d0
0:40`0AlJ7<=<cHg<2hg=c4c838a>CD^<3Pd<b1]M0dc=SPh;S4c<S<P<S4i=Bh`
>3@c86aY3C<f>3P^<C<b<b0b=c<f;SDc<C8PK6T=<cHg<2hg=c4c838g<cH^=C<a
<R1/J@dc=SL`;SLg<C<P<S4i=Bh`>3@c86aY3F=`3B0a86QS3C0P<20`86Hc3C4g
;S<f<C0P<CL^<cHa<21cL0dP<R1/JPe^L0dc=SPh;S4c<S<P<S4d=2hc>CTb86ed
3C<f=c0^=cLa<b0b<C@d;S<i>C8PK6T=I7<=KW0=<cHh>2ha<c8c838a=cT^<C8a
<R1]M0dc=SL`;SLg<C<P<S4g>Bha<S4b86aY3FAc3Fi`3C<f>3P^<C<b<b0b<S4c
;SPd<c<PKG@=<cHg<2hg=c4c838b<C<^>3@c<b1/J@eTL`e^L0dc=SPh;S4c<S<P
<S8d>2he=SDc86ed3C<f=c0^=cLa<b0b<S@h;SDf=C<PK6T=I7<=KW0=<cHh>2ha
<c8c838b>3<^<SPg=21]M0dc=SL`;SLg<C<P<S8h<bhb>3Ld86aY3FAc3Fi`3C<f
>3P^<C<b<b0b<c4h;S0`>C@PKG@=<cHg<2hg=c4c838c<CP^<30i=21/J@eTL`e^
L0dc=SPh;S4c<S<P<S<e<Rhg<c4e86ed3C<f=c0^=cLa<b0b<cDb;SLc<CDPK6T=
I7<=KW0=<cHh>2ha<c8c838c>3L^=3Dc=B1]M0dc=SL`;SLg<C<P<S<h=bhd=C<e
86aY3FAc3Fi`3C<f>3P^<C<b<b0b=38b;S4g=CHPKG@=<cHg<2hg=c4c838d<S8^
<CLe=R1/J@eTL`e^L0dc=SPh;S4c<S<P<S@e=Rhh>CLf86ed3C<f=c0^=cLa<b0b
=3Df;SPi=cHPK6T=I7<=KW0=<cHh>2ha<c8c838d>C4^=S4i=R1]M0dc=SL`;SLg
<C<P<S@i<Bhf<CTf86aY3FAc3Fi`3C<f>3P^<C<b<b0b=C8f;S<d<CLPKG@=<cHg
<2hg=c4c838e<SH^<c@a=b1/J@eTL`e^L0dc=SPh;S4c<S<P<SDf<Bh`=S<g86ed
3C<f=c0^=cLa<b0b=CHa;S0f<cLPK6T=I7<=KW0=<cHh>2ha<c8c838e>CD^=cPe
>21]M0dc=SL`;SLg<C<P<SDi=Bhg>3Dh86aY3FAc3Fi`3C<f>3P^<C<b<b0b=S<`
;SD`=cPPKG@=<cHg<2hg=c4c838f<c0^=C0g>21/J@eTL`e^L0dc=SPh;S4c<S<P
<SHf=Bhb<STi86ed3C<f=c0^=cLa<b0b=SHe;S8b>CTPK6T=I7<=KW0=<cHh>2ha
<c8c838f>CT^>CDa>B1]M0dc=SL`;SLg<C<P<SHi>Bhi=C4i86aY3FAc3Fi`3C<f
>3P^<C<b<b0b=c<d;SHg=21]M0dc=SL`;SLg<C<P<SLc=2hf=c@PK6T=I7<=KW0=
<cHh>2ha<c8c838g=ST^<cTf86ed3C<f=c0^=cLa<b0b=cHi;S<i=R1/J@eTL`eX
I@d0X@3000=WLPd00:40`004LWA]3@2Q0<0017=dK@d0X@3000=WL`d00:40`0:`
J7<=<c4h<Bhd<3Le838d=C8^<S@d=B1]M0dc<CPa;S@`=cDP<S@i<2hc<cLb83<a
=C0^<3Df<B0b=C8a;SHh>3HP<c4a<Bhi=S<d838e<S4^=SPh=R1SM0dc<3Lc;SPg
<3HP<SDb<Bhf>3Pf83<`=38^=C4i<b0b=3T`;S<c=c8P<c0d<Rhe<CTc838d=C8^
<S@d=B1SM0dc<3@b;SDa>C<P<S@a=2ha=C4h83<`=c<^>3L`=R0b<cPb;SP`<3@P
<c4a<Bhi=S<d838c>38^>30`=21SM0dc<CD`;S0e=S4P<S<h<Rhh<30d83<a>34^
=30g=B0b=34d;S4e<CPP<c4h<Bhd<3Le838d=C8^<S@d=B1SM0eSL0dP<21XH`d`
830P<21V<`da=bhc=S4`834g;S<f<C0PLg0=838PK6X=KW0=<STh=Rhe<c@a838c
>38^>30`=21]M0db>CPf;SDc=34P<SDb<Bhf>3Pf86aY3FAc3Fi`3C<`<S4^<SDf
<R0b<cPb;SP`<3@PKG@=<c0b<Bhb=CHb838e<S4^=SPh=R1/J@eTL`e^L0dc<3De
;STg>38P<S<h<Rhh<30d86ed3C<`=CD^>CLh<R0b=C8a;SHh>3HPK6T=I7<=KW0=
<c0i<2hg<30b838c>38^>30`=21]M0dc<3T`;SL`<38P<SDb<Bhf>3Pf86aY3FAc
3Fi`3C<a<SD^=38b<b0b<cPb;SP`<3@PKG@=<c4b=Bhd<S8c838e<S4^=SPh=R1/
J@eTL`e^L0dc<CH`;S4d=3<P<S<h<Rhh<30d86ed3C<a=S0^<C@d<b0b=C8a;SHh
>3HPK6T=I7<=KW0=<c4i=2hh=SHd838c>38^>30`=21]M0dc<CTd;SPf=S@P<SDb
<Bhf>3Pf86aY3FAc3FQU3@2Q0<000fMb3@00X@3004d`830P<21V<`da=bhc=S4`
834g;S<f<C0PLg0=KW0==ST^=3@d<B0f>Bhd=3@a83<a<C4^>CHc=20b=3Db;S8d
=3DPIG0=I7<=LWA]3@00X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21c
L0d`830P<21V<`d00:40`00lLgA]3C0P<20`86Hc3DHPLf4=<cLh<2hb=cLg838`
=cH^>34b=21]M0dXD2TP87=XKgL=E21cH@ebM6d=0:40`004LWA]3@2Q0<009g=d
K@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@3003acM6d=
<20`830PIS<=AR1cH@dc<S4f;S0d=3@P<S@d<Bhc>C<i86ed3BQA:B0PLfQ_M`eD
87=Q3G9dK@d0X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b
=C0PLg0=<20`830PIS<=002Q0<00?7=dK@d`830P<21V<`e687=Q3C<b<C4^=c0d
<R0b<C4a;SDc=3@PKG@=:7PY821cJ6mg3E@PLf4=LWA]3@2Q0<00179dK@d0X@30
02McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`00l
LgA]3C0P<20`86Hc3DHPLf4=<SPc=2ha<34i838e=cD^>C@a>21]M0dXN2TP87=X
KgL=E21cH@ebM6d=0:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P
<2ha<SD`87=`3C0P<20`86Hc3@00X@3003acM6d=<20`830PIS<=AR1cH@dc<CD`
;STd<3HP<SHd=Bhc>3Di86ed3BQi:B0PLfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=
0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q
0<00?7=dK@d`830P<21V<`e687=Q3C<g<cH^>3Le<B0b=3Hc;S0i=C4PKG@=:7TY
821cJ6mg3E@PLf4=LWA]3@2Q0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha
<SD`830^<C8e<21cL0d`830P<21V<`d00:40`00lLgA]3C0P<20`86Hc3DHPLf4=
<STb=Bhb=3Lc838f<CT^<c@d<b1]M0dXLBTP87=XKgL=E21cH@ebM6d=0:40`004
LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc
3@00X@3003acM6d=<20`830PIS<=AR1cH@dc<S<g;SLd=CLP<SHh<2ha<3Li86ed
3BQa:B0PLfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc
3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00>g=dK@d`830P<21V<`e6
87=Q3C<c<C4^=C<`<B0d=S4e;SPf<R1]M0dXN2TP87=XKgL=E21cH@ebM6d=002Q
0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P
<21V<`d00:40`00lLgA]3C0P<20`86Hc3DHPLf4=<c<h=Bhc<C@d83@f=SL^>C@e
<B1]M0dXLbTP87=XKgL=E21cH@ebM6d=0:40`004LWA]3@2Q0<009g=dK@d`830P
<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@3003acM6d=<20`830P
IS<=AR1cH@df=CHf;SLb<CTP<S@a<Bh`<C8a86ed3BQi:B0PLfQ_M`eD87=Q3G9d
K@d0X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=
<20`830PIS<=002Q0<00?7=dK@d`830P<21V<`e687=Q3CHf<c4^>38e=b0b=3La
;SLg=CLPKG@=:7<Y821cJ6mg3E@PLf4=LWA]3@2Q0<00179dK@d0X@30079cM6d=
<2he=c0c830^=CL`<b0`;SDg<3<PIS<=>2hf>30e83P^=SP`=B1cL0da=2hc86a]
3B0`86aZ3Fi`3C<f=cH^=S<d>20b<C8b;SHi=cTPKG@=<c4b>Bhg=S8e83Pc=bhi
>38b86aY3FAc3G9dK@d0X@3005=cM6d=<2he=c0c830^=CL`<b0`;SDg<3<PIS<=
KW0=<cHh=Bhc<CDc838a<c4^<cLh=21]M0db=30`;SDi>CHP>38i;S<`<CLPK6T=
I7<=LWA]3@00X@3005=cM6d=<2he=c0c830^=CL`<b0`;SDg<3<PIS<=KW0=<cHg
=Rhf<c@h838a<c4^<cLh=21]M0dc<C<h;S@d<c4P<C@a<2hh>CHPK6T=I7<=LWA]
3@00X@3005AcM6d=<2he=c0c830^=CL`<b0`;SDg<3<PIS<=KW0=<cHh=Bhc<CDc
838a<S8^=STg>B1]M0db=38f;SHd<C4P<C<i<bhe<c@i86aY3FAc3G9dK@d0X@30
00AcM6d=0:40`003Ig<=002Q0<02TfQc3C8d<c@^>3Pc=B0g>3D^=CPf<b1]M0db
=3<d;SPh<cDP>38c;SHg>B0b=30c;SDc<S4P>3De;S0c<3@P<S<f=Bhd<cTd83Pe
=Bh`<c0d86=d3C8c<SL^<c@f=R0h=CD^<3<`=20b<STe;STi=C<P>38c;SHg>B0b
<STe;STi=C<P=cPe;SDh=S<PHg@=<S8i=Bhi>CDc83Ld=bhd>C<f838c<SL^<c@f
=R0g<CH^<C@b<R0b<cHe;S@c>C@P=c4f;S4d<S8PHg@=<S@`<bhe<c8a83La=Rha
=38b838d<c@^>3Pc=B0g=3L^=3Tc=R0b=3<d;SPh<cDP=cPe;SDh=S<PHg@=Hg0=
830PJ6<=<20`830PIS<=<CL^<cHa<20a=bhc=S4`87=`3B0b86aZ3Fi`3C8d<c@^
>3Pc=B0f=C4^<cDa<R1]M0db<STe;STi=C<P=SDa;S<e<C8PK6T=I7<=KW0=<S@c
=2hh>3<e83Hh=Rh`=c<c86ed3C8b>CD^>CTe<b0f>3H^<3Lc<b1/J@eTL`e^L0db
=3<d;SPh<cDP=c8`;SLi=C<PKG@=<S8i=Bhi>CDc83Lb<2hg>CDc86aY3FAc3Fi`
3C8d<c@^>3Pc=B0g=CD^=C4g=21]M0db<STe;STi=C<P=cDe;SDa=c@PK6T=I7<=
KW0=<S@c=2hh>3<e83Li<2hb<cTd86ed3C8b>CD^>CTe<b0g>C0^<S<i=21/J@eT
L`e^L0db=3<d;SPh<cDP>38d;STf<C@PKG@=<S8i=Bhi>CDc83Pb=2hi=S4d86aY
3FAc3Fi`3C8d<c@^>3Pc=B0h=CT^=SPc=B1]M0db<STe;STi=C<P>3Di;SHh<cDP
K6T=I7<=J6D=002Q0<000fMb3@00X@3005X`830P<21V<`da=bhc=S4`834g;S<f
<C0PLg0=<C4^=B1/K@dP<21/JPe^L0df>Bhd=3@a83Hi;S@d=34P<S<f=Bhd<cTd
83Lh=Bhe>3Hc86E`3FAc3G9dK@d0X@3000AcM6d=0:40`003Ig<=002Q0<02P6Qc
3C<a>34^=30g=B0g>3D^=CPf<b1]M0dc<CPa;S@`=cDP>38c;SHg>B0c<CD`;S0e
=S4P>3De;S0c<3@P<c4a<Bhi=S<d83Pe=Bh`<c0d86=d3C<`=c<^>3L`=R0h=CD^
<3<`=20c<3@b;SDa>C<P>38c;SHg>B0c<3@b;SDa>C<P=cPe;SDh=S<PHg@=<c0d
<Rhe<CTc83Ld=bhd>C<f83<`=c<^>3L`=R0g<CH^<C@b<R0c<C4a;STf<c@P=c4f
;S4d<S8PHg@=<c4e<2h`=CHa83La=Rha=38b83<a>34^=30g=B0g=3L^=3Tc=R0c
<CPa;S@`=cDP=cPe;SDh=S<PHg@=Hg0=830PJ6<=<20`830PIS<=838PK6X=KW0=
<STh=Rhe<c@a83La=Rha=38b86ed3C8i>3H^=C<d<B0h=CD^<3<`=21/J@eTL`e^
L0dc<38a;S8e=S8P=c4f;S4d<S8PKG@=<c0b<Bhb=CHb83Pe=Bh`<c0d86aY3FAc
3Fi`3C<`=CD^>CLh<R0g<CH^<C@b<R1]M0dc<3De;STg>38P>3De;S0c<3@PK6T=
I7<=KW0=<c0i<2hg<30b83La=Rha=38b86ed3C<`>C0^=c0`<R0h=CD^<3<`=21/
J@eTL`e^L0dc<C8e;S@b<S<P=c4f;S4d<S8PKG@=<c4b=Bhd<S8c83Pe=Bh`<c0d
86aY3FAc3Fi`3C<a=S0^<C@d<b0g<CH^<C@b<R1]M0dc<CH`;S4d=3<P>3De;S0c
<3@PK6T=I7<=KW0=<c4i=2hh=SHd83La=Rha=38b86ed3C<a>C@^>3Hf=20h=CD^
<3<`=21/J@eTL`eXI@d0X@3000=WLPd00:40`00i<20`830PIS<=KW0==ST^=3@d
<B0f>Bhd=3@a83<a<C4^>CHc=20g>3D^=CPf<b1UL0eTL`ebM6d=002Q0<0017=d
K@d0X@3000=WL`d00:40`0:KJ7<=<S@c=2hh>3<e834c=CP^=C0`<b1]M0db=3<d
;SPh<cDP<C<b<2hd<3Lf838d<3<^=C<b<B0a<SPi;S0e=S8P<S<f=Bhd<cTd834b
>3T^<3Df<R1SM0db<c8g;S<d=SHP<C8h>Bh`=CHb838b>CD^>CTe<b0a<c8`;S@`
=cHP<S8i=Bhi>CDc834c=CP^=C0`<b1SM0db<STe;STi=C<P<C<i=Rhe>C<P<S<b
=bhc=3Hf834d<SL^>C@d=20b<cHe;S@c>C@P<C@b=bhi=3@d86=d3C8d<3<^=C<b
<B0a=38g;STd=3@P<S@c=2hh>3<e834c>CH^=CTc838d<c@^>3Pc=B0a<cDh;SD`
<3<PHg@=Hg0=830PJ6<=<20`830PIS<=838PK6X=KW0=<S8e=bhc=c4a834d<SL^
>C@d=21]M0db<SDg;S<g<C4P<C8h>Bh`=CHb86aY3FAc3Fi`3C8b>C8^<3Tc<R0a
=38g;STd=3@PKG@=<S8i<Rh`>C<b834b>3T^<3Df<R1/J@eTL`e^L0db<c8f;SPa
=C8P<C@b=bhi=3@d86ed3C8c<SH^>34e<R0a<SPi;S0e=S8PK6T=I7<=KW0=<S<f
<Bhe<cLc834d<SL^>C@d=21]M0db<cHa;SDc=c<P<C8h>Bh`=CHb86aY3FAc3Fi`
3C8c>CH^<SDi<b0a=38g;STd=3@PKG@=<S<i=Rhb=CTc834b>3T^<3Df<R1/J@eT
L`e^L0db=3<`;STh<C@P<C@b=bhi=3@d86ed3C8d<c0^>CPa=20a<SPi;S0e=S8P
K6T=I7<=KW0=<S@f=Bhg<3<d834d<SL^>C@d=21]M0db=3He;SL`<c@P<C8h>Bh`
=CHb86aY3FAc3FQU3@00X@3000=WLPd00:40`01e<20`830PIS<=KW0=LgA]3C4^
<30`<20`;S0`<30P<2h`<30`82da;S0`<30P<2h`<30`82dc=3Ph;STc>CTPHg<=
=ST^=3@d<B0f>Bhd=3@a838c=SD^=3<i=20]=3Pd=bhd=30b86E`3G9dK@eTL`eb
M6d=002Q0<0017=dK@d0X@3000=WL`d00:40`0:GJ7<=<c4h<Bhd<3Le834c=CP^
=C0`<b1]M0dc<CPa;S@`=cDP<C<b<2hd<3Lf83<a=C0^<3Df<B0a<SPi;S0e=S8P
<c4a<Bhi=S<d834b>3T^<3Df<R1SM0dc<3Lc;SPg<3HP<C8h>Bh`=CHb83<`=38^
=C4i<b0a<c8`;S@`=cHP<c0d<Rhe<CTc834c=CP^=C0`<b1SM0dc<3@b;SDa>C<P
<C<i=Rhe>C<P<c0g<bhh=c0f834d<SL^>C@d=20c<C4a;STf<c@P<C@b=bhi=3@d
86=d3C<a=C0^<3Df<B0a=38g;STd=3@P<c4h<Bhd<3Le834c>CH^=CTc83<a>34^
=30g=B0a<cDh;SD`<3<PHg@=Hg0=830PJ6<=<20`830PIS<=838PK6X=KW0=<c4h
<Bhd<3Le834b=34^=S8f86ed3C<`=38^=C4i<b0a<S@a;SHb=R1/J@eTL`e^L0dc
<CPa;S@`=cDP<C8g=Rhc=3PPKG@=<c0d<Rhe<CTc834b=cH^<c@h86aY3FAc3Fi`
3C<a>34^=30g=B0a<c4a;S0g<34PKG@=<c0d<Rhe<CTc834c<C4^<3L`<B1/J@eT
L`e^L0dc<CPa;S@`=cDP<C<d=Bhg>C8a86ed3C<`=38^=C4i<b0a<c@e;SLi<S4P
K6T=I7<=KW0=<c4h<Bhd<3Le834c>30^=C4d<R1]M0dc<3@b;SDa>C<P<C<h<2he
<C@b86aY3FAc3Fi`3C<a>34^=30g=B0a=34e;S8c=S8PKG@=<c0d<Rhe<CTc834d
<CD^<S<f<R1/J@eTL`e^L0dc<CPa;S@`=cDP<C@d>Bhi=CPc86ed3C<`=38^=C4i
<b0a=3@i;STe>3<PK6T=I7<=J6D=002Q0<000fMb3@00X@3007D`830P<21V<`e^
L0ecM6d=<Bh`<30`830^<30`<20`;S0`<30P;C4^<30`<20`;S0`<30P;C<d>3P^
>C<i>B1SL`df>Bhd=3@a83Hi;S@d=34P<c4a<Bhi=S<d82dd>3@g;S@d<38PIG0=
LWA]3FAc3G9dK@d00:40`01dLgA]3C0P<20`86Hc3Fi`3CHi;S@d=34P=ST^=3@d
<B0c=SP`;SDc=STP<S4c=Bhd<3Dh86E`3FAU3C0P<20`86Hc3Fi`3CHi;S@d=34P
=ST^=3@d<B0c=SP`;SDc=STP<S4c=Bhd<3Dh86E`3FAc3G9dK@d0X@3000YdIG9]
JFiQM6D=0:00_`2P0;h0VP000?n?X0000003j0?X000010000000B00004P0000@
02000`08000000000007o<Kd000000?X0nP000000nX3k0000321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0CX7o
POnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZ
POn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>POn1oi_ooJZ1oh7ofOomZX7o
POoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZPOn1omWo
oJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZ
POn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZfol0CX7o
POnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZ
POn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>POn1oi_ooJZ1oh7ofOomZX7o
POoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZPOn1omWo
oJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZ
POn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZfol0CX7o
POnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZ
POn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>POn1oi_ooJZ1oh7ofOomZX7o
POoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZPOn1omWo
oJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZ
POn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZfol0CX7o
POnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZ
POn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>POn1oi_ooJZ1oh7ofOomZX7o
POoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZPOn1omWo
oJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZ
POn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZfol0CX7o
POnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZ
POn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>POn1oi_ooJZ1oh7ofOomZX7o
POoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZPOn1omWo
oJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZ
POn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZfol0CX7o
POnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZ
POn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>POn1oi_ooJZ1oh7ofOomZX7o
POoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZPOn1omWo
oJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZ
POn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZfol0CX7o
POnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZ
POn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>POn1oi_ooJZ1oh7ofOomZX7o
POoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZPOn1omWo
oJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZ
POn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZfol0CX7o
POnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZ
POn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>POn1oi_ooJZ1oh7ofOomZX7o
POoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZPOn1omWo
oJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZ
POn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZfol0CX7o
POnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZ
POn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>POn1oi_ooJZ1oh7ofOomZX7o
POoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZPOn1omWo
oJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZ
POn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZfol0CX7o
POnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZ
POn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>POn1oi_ooJZ1oh7ofOomZX7o
POoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZPOn1omWo
oJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZ
POn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZfol0CX7o
POnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZ
POn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>POn1oi_ooJZ1oh7ofOomZX7o
POoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZPOn1omWo
oJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZ
POn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZfol0CX7o
POnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZ
POn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>POn1oi_ooJZ1oh7ofOomZX7o
POoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZPOn1omWo
oJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZ
POn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZfol0CX7o
POnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZ
POn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>POn1oi_ooJZ1oh7ofOomZX7o
POoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZPOn1omWo
oJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZ
POn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZfol0CX7o
POnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZ
POn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>POn1oi_ooJZ1oh7ofOomZX7o
POoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZPOn1omWo
oJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZ
POn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZfol0CX7o
POnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZ
POn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>POn1oi_ooJZ1oh7ofOomZX7o
POoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZPOn1omWo
oJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZ
POn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZfol0CX7o
POnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZ
POn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>POn1oi_ooJZ1oh7ofOomZX7o
POoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZPOn1omWo
oJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZ
POn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZfol0CX7o
POnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZ
POn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>POn1oi_ooJZ1oh7ofOomZX7o
POoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZPOn1omWo
oJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZ
POn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZfol0CX7o
POnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZ
POn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>POn1oi_ooJZ1oh7ofOomZX7o
POoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZPOn1omWo
oJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZ
POn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZfol0CX7o
POnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7ofOomZX7oPOoIoofZ
POn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>POn1oi_ooJZ1oh7ofOomZX7o
POoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJZ1oh7oPOoeoofZPOn1omWo
oJZ1oh7ofOomZ]_o03K5oh40P@210840P@210840e@35oh40P@210840P@210840
e@35oh40P@210840P@210840e@00=/GoP@210840P@210840P@3E0<GoP@210840
P@210840P@3E0<GoP@210840P@210840P@3E000faOn10840P@210840P@210=D0
aOn10840P@210840P@210=D0aOn10840P@210840P@210=D003K5oh40P@210840
P@210840e@35oh40P@210840P@210840e@35oh40P@210840P@210840e@00E/Go
o@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087o
POoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[o
o021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7o
o@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[o
o021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[o
o021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[o
o02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[o
o021oh7of_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087o
POoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[o
o03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087o
POoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Go
o@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087o
POoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[o
o021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7o
o@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[o
o021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[o
o021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[o
o02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[o
o021oh7of_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087o
POoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[o
o03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087o
POoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Go
o@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087o
POoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[o
o021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7o
o@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1^aOom0>[ooP21oh7om?ol087o
POoJoo`0k?on087oPOoboo`0XOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087o
POoboo`0XOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087oPOoboo`0gOl0K/Go
o@3Zooh0POn1ooCoo021oh7of_ol0>cooP21oh7ol_ol0:7oo@3Zooh0POn1ooCo
o021oh7of_ol0>cooP21oh7ol_ol0:7oo@3Zooh0POn1ooCoo021oh7of_ol0>co
oP21oh7ol_ol0=go06k5ood0j_on087oPOodoo`0POn1om[oo03/ooh0POn1oo;o
o02Qood0j_on087oPOodoo`0POn1om[oo03/ooh0POn1oo;oo02Qood0j_on087o
POodoo`0POn1om[oo03/ooh0POn1oo;oo03Mo`1^aOom0>[ooP21oh7om?ol087o
POoJoo`0k?on087oPOoboo`0XOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087o
POoboo`0XOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087oPOoboo`0gOl0K/Go
o@3Zooh0POn1ooCoo021oh7of_ol0>cooP21oh7ol_ol0:7oo@3Zooh0POn1ooCo
o021oh7of_ol0>cooP21oh7ol_ol0:7oo@3Zooh0POn1ooCoo021oh7of_ol0>co
oP21oh7ol_ol0=go06k5ood0j_on087oPOodoo`0POn1om[oo03/ooh0POn1oo;o
o02Qood0j_on087oPOodoo`0POn1om[oo03/ooh0POn1oo;oo02Qood0j_on087o
POodoo`0POn1om[oo03/ooh0POn1oo;oo03Mo`1^aOom0>[ooP21oh7om?ol087o
POoJoo`0k?on087oPOoboo`0XOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087o
POoboo`0XOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087oPOoboo`0gOl0K/Go
o@3Zooh0POn1ooCoo021oh7of_ol0>cooP21oh7ol_ol0:7oo@3Zooh0POn1ooCo
o021oh7of_ol0>cooP21oh7ol_ol0:7oo@3Zooh0POn1ooCoo021oh7of_ol0>co
oP21oh7ol_ol0=go08K5ood0j_on087oPOodoo`0m_of087oPOo`oo`0k?on087o
POoboo`0m_of0;Ooo@3Zooh0POn1ooCoo03fooH0POn1oo3oo03/ooh0POn1oo;o
o03fooH0]oom0>[ooP21oh7om?ol0?KomP21oh7ol?ol0>cooP21oh7ol_ol0?Ko
mP3co`26aOom0??ok021oh7ooOol0?KomP21oh7ol?ol0?Gok021oh7onool0?Ko
mP2good0loo/087oPOomoo`0m_of087oPOo`oo`0mOo/087oPOokoo`0m_of0;Oo
o@3con`0POn1oogoo03fooH0POn1oo3oo03eon`0POn1oo_oo03fooH0lol0Q/Go
o@3con`0POn1oogoo03fooH0POn1oo3oo03eon`0POn1oo_oo03fooH0]oom0??o
k021oh7ooOol0?KomP21oh7ol?ol0?Gok021oh7onool0?KomP2good0loo/087o
POomoo`0m_of087oPOo`oo`0mOo/087oPOokoo`0m_of0??o06k5ood0loo/087o
POomoo`0POn1om[oo03eon`0POn1oo_oo02Qood0loo/087oPOomoo`0POn1om[o
o03eon`0POn1oo_oo02Qood0loo/087oPOomoo`0POn1om[oo03eon`0POn1oo_o
o03Mo`1^aOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087oPOoboo`0XOom0>[o
oP21oh7om?ol087oPOoJoo`0k?on087oPOoboo`0XOom0>[ooP21oh7om?ol087o
POoJoo`0k?on087oPOoboo`0gOl0K/Goo@3Zooh0POn1ooCoo021oh7of_ol0>co
oP21oh7ol_ol0:7oo@3Zooh0POn1ooCoo021oh7of_ol0>cooP21oh7ol_ol0:7o
o@3Zooh0POn1ooCoo021oh7of_ol0>cooP21oh7ol_ol0=go06k5ood0j_on087o
POodoo`0POn1om[oo03/ooh0POn1oo;oo02Qood0j_on087oPOodoo`0POn1om[o
o03/ooh0POn1oo;oo02Qood0j_on087oPOodoo`0POn1om[oo03/ooh0POn1oo;o
o03Mo`1^aOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087oPOoboo`0XOom0>[o
oP21oh7om?ol087oPOoJoo`0k?on087oPOoboo`0XOom0>[ooP21oh7om?ol087o
POoJoo`0k?on087oPOoboo`0gOl0K/Goo@3Zooh0POn1ooCoo021oh7of_ol0>co
oP21oh7ol_ol0:7oo@3Zooh0POn1ooCoo021oh7of_ol0>cooP21oh7ol_ol0:7o
o@3Zooh0POn1ooCoo021oh7of_ol0>cooP21oh7ol_ol0=go06k5ood0j_on087o
POodoo`0POn1om[oo03/ooh0POn1oo;oo02Qood0j_on087oPOodoo`0POn1om[o
o03/ooh0POn1oo;oo02Qood0j_on087oPOodoo`0POn1om[oo03/ooh0POn1oo;o
o03Mo`1^aOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087oPOoboo`0XOom0>[o
oP21oh7om?ol087oPOoJoo`0k?on087oPOoboo`0XOom0>[ooP21oh7om?ol087o
POoJoo`0k?on087oPOoboo`0gOl0K/Goo@3Zooh0POn1ooCoo021oh7of_ol0>co
oP21oh7ol_ol0:7oo@3Zooh0POn1ooCoo021oh7of_ol0>cooP21oh7ol_ol0:7o
o@3Zooh0POn1ooCoo021oh7of_ol0>cooP21oh7ol_ol0=go06k5ood0j_on087o
POodoo`0POn1om[oo03/ooh0POn1oo;oo02Qood0j_on087oPOodoo`0POn1om[o
o03/ooh0POn1oo;oo02Qood0j_on087oPOodoo`0POn1om[oo03/ooh0POn1oo;o
o03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087o
POoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Go
o@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087o
POoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[o
o021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7o
o@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[o
o021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[o
o021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[o
o02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[o
o021oh7of_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087o
POoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[o
o03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087o
POoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Go
o@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087o
POoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[o
o021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7o
o@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[o
o021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[o
o021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[o
o02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[o
o021oh7of_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087o
POoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[o
o03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087o
POoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Go
o@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087o
POoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[o
o021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7o
o@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[o
o021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[o
o021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[o
o02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[o
o021oh7of_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087o
POoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[o
o03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087o
POoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Go
o@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087o
POoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[o
o021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7o
o@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[o
o021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[o
o021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[o
o02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[o
o021oh7of_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087o
POoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[o
o03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087o
POoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Go
o@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087o
POoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[o
o021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7o
o@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[o
o021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[o
o021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[o
o02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[o
o021oh7of_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087o
POoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[o
o03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087o
POoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Go
o@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087o
POoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[o
o021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7o
o@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[o
o021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[o
o021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[o
o02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[o
o021oh7of_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087o
POoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[o
o03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087o
POoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Go
o@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087o
POoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[o
o021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7o
o@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[o
o021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[o
o021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[o
o02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[o
o021oh7of_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087o
POoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[o
o03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087o
POoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Go
o@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087o
POoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[o
o021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7o
o@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[o
o021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[o
o021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[o
o02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[o
o021oh7of_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087o
POoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[o
o03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087o
POoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Go
o@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087o
POoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[o
o021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7o
o@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[o
o021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[o
o021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[o
o02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[o
o021oh7of_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087o
POoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[o
o03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087o
POoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Go
o@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087o
POoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[o
o021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7o
o@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[o
o021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[o
o021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[o
o02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[o
o021oh7of_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087o
POoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[o
o03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087o
POoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Go
o@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087o
POoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[o
o021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7o
o@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[o
o021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[o
o021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[o
o02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[o
o021oh7of_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087o
POoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[o
o03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087o
POoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Go
o@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087o
POoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[o
o021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7o
o@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[o
o021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[o
o021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[o
o02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[o
o021oh7of_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087o
POoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[o
o03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087o
POoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Go
o@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087o
POoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[o
o021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7o
o@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1LaOom087oPOoJoo`0POnbo`00
Z_ol087oPOoJoo`0XOom087oPOoJoo`0POnbo`00Z_ol087oPOoJoo`0XOom087o
POoJoo`0POnbo`00Z_ol087oPOoJoo`0gOl0J<Goo@2aoo<0POnhoo`0POnhoo<0
/Ool0;7ol`21okSoo02Qood0/Ooc087o^?ol087o^?oc0;7oo02aoo<0POnhoo`0
XOom0;7ol`21okSoo021okSol`2aoo`0/Ooc087o^?ol0=go06S5ood0/_oa087o
^Ool087o^Ooa0;;oo02boo40POnioo`0XOom0;;ol@21okWoo021okWol@2boo`0
/_oa087o^Ool0:7oo@2boo40POnioo`0POnioo40/_ol0;;ol@21okWoo03Mo`1X
aOom0;Cok@21ok_oo021ok_ok@2doo`0]?o]087o^ool0:7oo@2dond0POnkoo`0
POnkond0]?ol0;Cok@21ok_oo02Qood0]?o]087o^ool087o^oo]0;Coo02dond0
POnkoo`0gOl0J<Goo@2eonX0POnmoo`0POnlonX0]_ol0;GojP21okgoo02Qood0
]OoZ087o_Ool087o_?oZ0;Koo02eonX0POnmoo`0XOom0;GojP21okgoo021okco
jP2foo`0]OoZ087o_Ool0=go08c5ood0]oog0?gom@21okkoo021okkon@3gooT0
]ool0;Oom`3mooD0POnnoo`0XOom0;Oom`3mooD0POnnoo`0POnnooT0mooi0;Oo
o02gooL0oOoe087o__ol0:7oo@2gooL0oOoe087o__ol087o__oi0?Oon@2goo`0
]oog0?gom@21okkoo03Mo`2ZaOom0;Oom`3mood00OoonP21okooo021okoon@3e
ooX0]ool0;Oom`3mood00OoonP21okooo02Qood0]oog0?goo@01oooj087o_ool
087o_ooi0?GonP2goo`0]oog0?goo@01oooj087o_ool0:7oo@2gooL0oOom007o
ooX0POnooo`0POnoooT0mOoj0;Ooo02gooL0oOom007oooX0POnooo`0gOl0_<Go
o@2hoo/00?om0?goo@3nooX0POo0oo`0POo0ooX0lOok0;Soo02hoo/00?om0?go
o@3nooX0POo0oo`0XOom0;Son`00ood0oOom0?konP21ol3oo021ol3onP3aoo/0
^?ol0;Son`00ood0oOom0?konP21ol3oo02Qood0^?ok003oo@3mood0o_oj087o
`?ol087o`?oj0?7on`2hoo`0^?ok003oo@3mood0o_oj087o`?ol0=go0<;5ood0
^Ook007oood0oOom0?coo021ol3oo021ol3on`3_oo/0^Ool0;Won`01ooom0?go
o@3loo`0POo0oo`0XOom0;Won`01ooom0?goo@3loo`0POo0oo`0POo0oo/0kook
0;Woo02ioo/00Oooo@3mood0o?ol087o`?ol0:7oo@2ioo/00Oooo@3mood0o?ol
087o`?ol087o`?ok0>oon`2ioo`0^Ook007oood0oOom0?coo021ol3oo03Mo`2`
aOom0;Woo@3mood0oOom0?con`21ol7oo021ol7oh@2joo`0^Oom0?goo@3mood0
o?ok087o`Ool0:7oo@2iood0oOom0?goo@3loo/0POo1oo`0POo1on40^_ol0;Wo
o@3mood0oOom0?con`21ol7oo02Qood0^Oom0?goo@3mood0o?ok087o`Ool087o
`OoQ0;[oo02iood0oOom0?goo@3loo/0POo1oo`0gOl0/<Goo@2joo`0oOom0?go
o@3looX0POo2oo`0POo1on40^_ol0;[oo03mood0oOom0?conP21ol;oo02Qood0
^_ol0?goo@3mood0o?oj087o`_ol087o`OoQ0;[oo02joo`0oOom0?goo@3looX0
POo2oo`0XOom0;[oo03mood0oOom0?conP21ol;oo021ol7oh@2joo`0^_ol0?go
o@3mood0o?oj087o`_ol0=go0;35ood0^ook0?goo@3mood0o?oj087o`_ol087o
`_oO0;_oo02koo/0oOom0?goo@3looX0POo2oo`0XOom0;_on`3mood0oOom0?co
nP21ol;oo021ol;og`2koo`0^ook0?goo@3mood0o?oj087o`_ol0:7oo@2koo/0
oOom0?goo@3looX0POo2oo`0POo2oml0^ool0;_on`3mood0oOom0?conP21ol;o
o03Mo`2`aOom0;_on`3mood0oOom0?conP21ol;oo021ol?ogP2koo`0^ook0?go
o@3mood0o?oj087o`_ol0:7oo@2koo/0oOom0?goo@3looX0POo2oo`0POo3omh0
^ool0;_on`3mood0oOom0?conP21ol;oo02Qood0^ook0?goo@3mood0o?oj087o
`_ol087o`ooN0;_oo02koo/0oOom0?goo@3looX0POo2oo`0gOl0/<Goo@2koo/0
oOom0?goo@3looX0POo2oo`0POo3omh0^ool0;_on`3mood0oOom0?conP21ol;o
o02Qood0^ook0?goo@3mood0o?oj087o`_ol087o`ooN0;_oo02koo/0oOom0?go
o@3looX0POo2oo`0XOom0;_on`3mood0oOom0?conP21ol;oo021ol?ogP2koo`0
^ook0?goo@3mood0o?oj087o`_ol0=go0;c5ood0_?oj0?goo@3mood0o?oi087o
`ool087o`ool0>Ooo02loo`0_?oj0?goo@3mood0o?oi087o`ool0:7oo@2looX0
oOom0?goo@3looT0POo3oo`0POo3oo`0iool0;coo02looX0oOom0?goo@3looT0
POo3oo`0XOom0;conP3mood0oOom0?con@21ol?oo021ol?oo03Woo`0_?ol0;co
nP3mood0oOom0?con@21ol?oo03Mo`2laOom0;conP3mood0oOom0?con@21ol?o
o021ol?oo@3Voo`0_?ol0;conP3mood0oOom0?con@21ol?oo02Qood0_?oj0?go
o@3mood0o?oi087o`ool087o`oom0>Koo02loo`0_?oj0?goo@3mood0o?oi087o
`ool0:7oo@2looX0oOom0?goo@3looT0POo3oo`0POo3ood0i_ol0;coo02looX0
oOom0?goo@3looT0POo3oo`0gOl0_<Goo@2looX0oOom0?goo@3looT0POo3oo`0
POo4oo`0iOom0;coo02looX0oOom0?goo@3looT0POo3oo`0XOom0;conP3mood0
oOom0?con@21ol?oo021olCoo03Uood0_?ol0;conP3mood0oOom0?con@21ol?o
o02Qood0_?oj0?goo@3mood0o?oi087o`ool087oa?ol0>Goo@2loo`0_?oj0?go
o@3mood0o?oi087o`ool0=go0;c5ood0_Ooi0?goo@3mood0o?oh087oa?ol087o
a?ol0>Goo02moo`0_Ooi0?goo@3mood0o?oh087oa?ol0:7oo@2mooT0oOom0?go
o@3looP0POo4oo`0POo4oo`0iOol0;goo02mooT0oOom0?goo@3looP0POo4oo`0
XOom0;gon@3mood0oOom0?con021olCoo021olCoo03Uoo`0_Ool0;gon@3mood0
oOom0?con021olCoo03Mo`38aOom0;gon@3mood0oOom0?coo@00ood0POo4oo`0
POo4om/0_Ool0;gon@3mood0oOom0?coo@00ood0POo4oo`0XOom0;gon@3mood0
oOom0?coo@00ood0POo4oo`0POo4om/0_Ool0;gon@3mood0oOom0?coo@00ood0
POo4oo`0XOom0;gon@3mood0oOom0?coo@00ood0POo4oo`0POo4om/0_Ool0;go
n@3mood0oOom0?coo@00ood0POo4oo`0gOl0b<Goo@2mooT0oOom0?goo@3lood0
0?om087oa?ol087oa?oK0;goo02mooT0oOom0?goo@3lood00?om087oa?ol0:7o
o@2mooT0oOom0?goo@3lood00?om087oa?ol087oa?oK0;goo02mooT0oOom0?go
o@3lood00?om087oa?ol0:7oo@2mooT0oOom0?goo@3lood00?om087oa?ol087o
a?oK0;goo02mooT0oOom0?goo@3lood00?om087oa?ol0=go0;35ood0_Ooi0?go
o@3mood0o?oh087oa?ol087oa?oK0;goo02mooT0oOom0?goo@3looP0POo4oo`0
XOom0;gon@3mood0oOom0?con021olCoo021olCof`2moo`0_Ooi0?goo@3mood0
o?oh087oa?ol0:7oo@2mooT0oOom0?goo@3looP0POo4oo`0POo4om/0_Ool0;go
n@3mood0oOom0?con021olCoo03Mo`2`aOom0;conP3mood0oOom0?con@21ol?o
o021olCog02loo`0_?oj0?goo@3mood0o?oi087o`ool0:7oo@2looX0oOom0?go
o@3looT0POo3oo`0POo4om`0_?ol0;conP3mood0oOom0?con@21ol?oo02Qood0
_?oj0?goo@3mood0o?oi087o`ool087oa?oL0;coo02looX0oOom0?goo@3looT0
POo3oo`0gOl0_<Goo@2looX0oOom0?goo@3looT0POo3oo`0POo3ood0i_ol0;co
o02looX0oOom0?goo@3looT0POo3oo`0XOom0;conP3mood0oOom0?con@21ol?o
o021ol?oo@3Voo`0_?ol0;conP3mood0oOom0?con@21ol?oo02Qood0_?oj0?go
o@3mood0o?oi087o`ool087o`oom0>Koo02loo`0_?oj0?goo@3mood0o?oi087o
`ool0=go0;c5ood0_?oj0?goo@3mood0o?oi087o`ool087o`ool0>Ooo02loo`0
_?oj0?goo@3mood0o?oi087o`ool0:7oo@2looX0oOom0?goo@3looT0POo3oo`0
POo3oo`0iool0;coo02looX0oOom0?goo@3looT0POo3oo`0XOom0;conP3mood0
oOom0?con@21ol?oo021ol?oo03Woo`0_?ol0;conP3mood0oOom0?con@21ol?o
o03Mo`2laOom0;_on`3mood0oOom0?con@21ol?oo021ol?oo03Woo`0_?ol0;_o
n`3mood0oOom0?con@21ol?oo02Qood0^ook0?goo@3mood0o?oi087o`ool087o
`ool0>Ooo02loo`0^ook0?goo@3mood0o?oi087o`ool0:7oo@2koo/0oOom0?go
o@3looT0POo3oo`0POo3oo`0iool0;coo02koo/0oOom0?goo@3looT0POo3oo`0
gOl0_<Goo@2koo/0oOom0?goo@3looX0POo2oo`0POo3oo`0j?ol0;_oo02koo/0
oOom0?goo@3looX0POo2oo`0XOom0;_on`3mood0oOom0?conP21ol;oo021ol?o
o03Xoo`0^ool0;_on`3mood0oOom0?conP21ol;oo02Qood0^ook0?goo@3mood0
o?oj087o`_ol087o`ool0>Soo02koo`0^ook0?goo@3mood0o?oj087o`_ol0=go
0;35ood0^ook0?goo@3mood0o?oj087o`_ol087o`_oO0;_oo02koo/0oOom0?go
o@3looX0POo2oo`0XOom0;_on`3mood0oOom0?conP21ol;oo021ol;og`2koo`0
^ook0?goo@3mood0o?oj087o`_ol0:7oo@2koo/0oOom0?goo@3looX0POo2oo`0
POo2oml0^ool0;_on`3mood0oOom0?conP21ol;oo03Mo`2`aOom0;[oo03mood0
oOom0?conP21ol;oo021ol7oh@2joo`0^_ol0?goo@3mood0o?oj087o`_ol0:7o
o@2joo`0oOom0?goo@3looX0POo2oo`0POo1on40^_ol0;[oo03mood0oOom0?co
nP21ol;oo02Qood0^_ol0?goo@3mood0o?oj087o`_ol087o`OoQ0;[oo02joo`0
oOom0?goo@3looX0POo2oo`0gOl0/<Goo@2joo`0oOom0?goo@3loo/0POo1oo`0
POo1on40^_ol0;[oo03mood0oOom0?con`21ol7oo02Qood0^_ol0?goo@3mood0
o?ok087o`Ool087o`OoQ0;[oo02joo`0oOom0?goo@3loo/0POo1oo`0XOom0;[o
o03mood0oOom0?con`21ol7oo021ol7oh@2joo`0^_ol0?goo@3mood0o?ok087o
`Ool0=go0;35ood0^Ool0?koo@3mood0o?ok087o`Ool087o`?oS0;Woo02ioo`0
o_om0?goo@3loo/0POo1oo`0XOom0;Woo03nood0oOom0?con`21ol7oo021ol3o
h`2ioo`0^Ool0?koo@3mood0o?ok087o`Ool0:7oo@2ioo`0o_om0?goo@3loo/0
POo1oo`0POo0on<0^Ool0;Woo03nood0oOom0?con`21ol7oo03Mo`32aOom0;So
o001ooom0?goo@3moo/0POo0oo`0POo0oo/0l?ok0;Soo02hoo`00Oooo@3mood0
oOok087o`?ol0:7oo@2hoo`00Oooo@3mood0oOok087o`?ol087o`?ok0?3on`2h
oo`0^?ol007oood0oOom0?gon`21ol3oo02Qood0^?ol007oood0oOom0?gon`21
ol3oo021ol3on`3`oo/0^?ol0;Soo001ooom0?goo@3moo/0POo0oo`0gOl0Z/Go
o@2hooH0oOom007oooT0POo0oo`0POnoooX0looj0;Soo02hooH0oOom007oooT0
POo0oo`0XOom0;SomP3mood00Ooon@21ol3oo021okoonP3cooX0^?ol0;SomP3m
ood00Ooon@21ol3oo02Qood0^?of0?goo@01oooi087o`?ol087o_ooj0??onP2h
oo`0^?of0?goo@01oooi087o`?ol0=go08c5ood0]oog0?gom@21okkoo021okko
n@3gooT0]ool0;Oom`3mooD0POnnoo`0XOom0;Oom`3mooD0POnnoo`0POnnooT0
mooi0;Ooo02gooL0oOoe087o__ol0:7oo@2gooL0oOoe087o__ol087o__oi0?Oo
n@2goo`0]oog0?gom@21okkoo03Mo`1aaOom0;Koj@21okgoo021okgoj@01TI6h
oo`0]_oY087o_Ool0:7oo@2fonT0POnmoo`0POnmonT00I6A^?ol0;Koj@21okgo
o02Qood0]_oY087o_Ool087o_OoY006ATKSoo02fonT0POnmoo`0gOl0M<Goo@2d
on`0POnloo`0POnkon`00?onTKWoo02don`0POnloo`0XOom0;Cok021okcoo021
ok_ok000oojA^Ool0;Cok021okcoo02Qood0]?o/087o_?ol087o^oo/003ooY6i
oo`0]?o/087o_?ol0=go07C5ood0/oo_087o^_ol087o^_o_0?gooY6joo`0/oo_
087o^_ol0:7oo@2conl0POnjoo`0POnjonl0oOonTK[oo02conl0POnjoo`0XOom
0;?ok`21ok[oo021ok[ok`3moojA^_ol0;?ok`21ok[oo03Mo`1daOom0;7ol`21
okSoo021okSol`3joojA^ool0;7ol`21okSoo02Qood0/Ooc087o^?ol087o^?oc
0?[ooY6koo`0/Ooc087o^?ol0:7oo@2aoo<0POnhoo`0POnhoo<0n_onTK_oo02a
oo<0POnhoo`0gOl0K/Goo@21oh7of_ol087o/_l00?;ooY6loo`0YOonTH7o^Ool
0:7oo@21oh7of_ol087o/_l00?;ooY6loo`0YOonTH7o^Ool0:7oo@21oh7of_ol
087o/_l00?;ooY6loo`0YOonTH7o^Ool0=go06G5ood0POn1om[oo021oj7ooY6m
oo`0Y?l1TI61okWoo02Qood0POn1om[oo021oj7ooY6moo`0Y?l1TI61okWoo02Q
ood0POn1om[oo021oj7ooY6moo`0Y?l1TI61okWoo03Mo`1UaOom087oPOoJoo`0
POnPoojA__ol0:Co0I6APOnioo`0XOom087oPOoJoo`0POnPoojA__ol0:Co0I6A
POnioo`0XOom087oPOoJoo`0POnPoojA__ol0:Co0I6APOnioo`0gOl0H/Goo@21
oh7of_ol087oWoonTKooo02ToojAPOnjoo`0XOom087oPOoJoo`0POnOoojA_ool
0:CooY61ok[oo02Qood0POn1om[oo021oioooY6ooo`0Y?onTH7o^_ol0=go06G5
ood0POn1om[oo021oikooY70oo`0Xol1TI61ok[oo02Qood0POn1om[oo021oiko
oY70oo`0Xol1TI61ok[oo02Qood0POn1om[oo021oikooY70oo`0Xol1TI61ok[o
o03Mo`1RaOom087oPOoJoo`0POnMoojA`Ool0:?ooY61ok_oo02Qood0POn1om[o
o021oigooY71oo`0XoonTH7o^ool0:7oo@21oh7of_ol087oWOonTL7oo02SoojA
POnkoo`0gOl0ILGoo@21oh7of_ol087oW?onTL;oo02Ro`6ATH7o^ool0:7oo@21
oh7of_ol087oW?onTL;oo02Ro`6ATH7o^ool0:7oo@21oh7of_ol087oW?onTL;o
o02Ro`6ATH7o^ool0=go06;5ood0POn1om[oo021oi_ooY73oo`0X_onTH7o_?ol
0:7oo@21oh7of_ol087oVoonTL?oo02RoojAPOnloo`0XOom087oPOoJoo`0POnK
oojA`ool0:;ooY61okcoo03Mo`1UaOom087oPOoJoo`0POnJoojAa?ol0:7o0I6A
POnloo`0XOom087oPOoJoo`0POnJoojAa?ol0:7o0I6APOnloo`0XOom087oPOoJ
oo`0POnJoojAa?ol0:7o0I6APOnloo`0gOl0ILGoo@21oh7of_ol087oVOonTLGo
o02Qo`6ATH7o_?ol0:7oo@21oh7of_ol087oVOonTLGoo02Qo`6ATH7o_?ol0:7o
o@21oh7of_ol087oVOonTLGoo02Qo`6ATH7o_?ol0=go06;5ood0POn1om[oo021
oiSooY76oo`0XOonTH7o_Ool0:7oo@21oh7of_ol087oV?onTLKoo02QoojAPOnm
oo`0XOom087oPOoJoo`0POnHoojAa_ol0:7ooY61okgoo03Mo`1UaOom087oPOoJ
oo`0POnGoojAaool0:3o0I6APOnmoo`0XOom087oPOoJoo`0POnGoojAaool0:3o
0I6APOnmoo`0XOom087oPOoJoo`0POnGoojAaool0:3o0I6APOnmoo`0gOl0H/Go
o@21oh7of_ol087oU_onTLSoo02PoojAPOnnoo`0XOom087oPOoJoo`0POnFoojA
b?ol0:3ooY61okkoo02Qood0POn1om[oo021oiKooY78oo`0X?onTH7o__ol0=go
06G5ood0POn1om[oo021oiGooY79oo`0Wol1TI61okkoo02Qood0POn1om[oo021
oiGooY79oo`0Wol1TI61okkoo02Qood0POn1om[oo021oiGooY79oo`0Wol1TI61
okkoo03Mo`1RaOom087oPOoJoo`0POnDoojAb_ol09oooY61okooo02Qood0POn1
om[oo021oiCooY7:oo`0WoonTH7o_ool0:7oo@21oh7of_ol087oU?onTL[oo02O
oojAPOnooo`0gOl0ILGoo@21oh7of_ol087oToonTL_oo02No`6ATH7o_ool0:7o
o@21oh7of_ol087oToonTL_oo02No`6ATH7o_ool0:7oo@21oh7of_ol087oToon
TL_oo02No`6ATH7o_ool0=go06G5ood0POn1om[oo021oi;ooY7<oo`0W_l1TI61
okooo02Qood0POn1om[oo021oi;ooY7<oo`0W_l1TI61okooo02Qood0POn1om[o
o021oi;ooY7<oo`0W_l1TI61okooo03Mo`1RaOom087oPOoJoo`0POnAoojAcOol
09kooY61ol3oo02Qood0POn1om[oo021oi7ooY7=oo`0W_onTH7o`?ol0:7oo@21
oh7of_ol087oTOonTLgoo02NoojAPOo0oo`0gOl0ILGoo@21oh7of_ol087oT?on
TLkoo02Mo`6ATH7o`?ol0:7oo@21oh7of_ol087oT?onTLkoo02Mo`6ATH7o`?ol
0:7oo@21oh7of_ol087oT?onTLkoo02Mo`6ATH7o`?ol0=go06;5ood0POn1om[o
o021ohoooY7?oo`0WOonTH7o`Ool0:7oo@21oh7of_ol087oSoonTLooo02MoojA
POo1oo`0XOom087oPOoJoo`0POn?oojAcool09gooY61ol7oo03Mo`1UaOom087o
POoJoo`0POn>oojAd?ol09co0I6APOo1oo`0XOom087oPOoJoo`0POn>oojAd?ol
09co0I6APOo1oo`0XOom087oPOoJoo`0POn>oojAd?ol09co0I6APOo1oo`0gOl0
H/Goo@21oh7of_ol087oSOonTM7oo02LoojAPOo2oo`0XOom087oPOoJoo`0POn=
oojAdOol09cooY61ol;oo02Qood0POn1om[oo021ohgooY7Aoo`0W?onTH7o`_ol
0=go06G5ood0POn1om[oo021ohcooY7Boo`0Vol1TI61ol;oo02Qood0POn1om[o
o021ohcooY7Boo`0Vol1TI61ol;oo02Qood0POn1om[oo021ohcooY7Boo`0Vol1
TI61ol;oo03Mo`1XaOom087oPOoJoo`0POn;o`6ATM;oo02Ko`6ATH7o`_ol0:7o
o@21oh7of_ol087oRol1TI7Boo`0Vol1TI61ol;oo02Qood0POn1om[oo021oh_o
0I6Ad_ol09_o0I6APOo2oo`0gOl0ILGoo@21oh7of_ol087oR_l1TI7Coo`0Voon
TH7o`ool0:7oo@21oh7of_ol087oR_l1TI7Coo`0VoonTH7o`ool0:7oo@21oh7o
f_ol087oR_l1TI7Coo`0VoonTH7o`ool0=go06S5ood0POn1om[oo021ohWo0I6A
e?ol09[o0I6APOo3oo`0XOom087oPOoJoo`0POn9o`6ATMCoo02Jo`6ATH7o`ool
0:7oo@21oh7of_ol087oROl1TI7Doo`0V_l1TI61ol?oo03Mo`1UaOom087oPOoJ
oo`0POn8o`6ATMGoo02JoojAPOo4oo`0XOom087oPOoJoo`0POn8o`6ATMGoo02J
oojAPOo4oo`0XOom087oPOoJoo`0POn8o`6ATMGoo02JoojAPOo4oo`0gOl0J<Go
o@21oh7of_ol087oQol1TI7Foo`0VOl1TI61olCoo02Qood0POn1om[oo021ohOo
0I6Ae_ol09Wo0I6APOo4oo`0XOom087oPOoJoo`0POn7o`6ATMKoo02Io`6ATH7o
a?ol0=go06G5ood0POn1om[oo021ohKo0I6Aeool09WooY61olGoo02Qood0POn1
om[oo021ohKo0I6Aeool09WooY61olGoo02Qood0POn1om[oo021ohKo0I6Aeool
09WooY61olGoo03Mo`1XaOom087oPOoJoo`0POn5o`6ATMSoo02Ho`6ATH7oaOol
0:7oo@21oh7of_ol087oQOl1TI7Hoo`0V?l1TI61olGoo02Qood0POn1om[oo021
ohGo0I6Af?ol09So0I6APOo5oo`0gOl0J<Goo@21oh7of_ol087oQ?l1TI7Ioo`0
V?l1TI61olGoo02Qood0POn1om[oo021ohCo0I6AfOol09So0I6APOo5oo`0XOom
087oPOoJoo`0POn4o`6ATMWoo02Ho`6ATH7oaOol0=go06G5ood0POn1om[oo021
oh?o0I6Af_ol09SooY61olKoo02Qood0POn1om[oo021oh?o0I6Af_ol09SooY61
olKoo02Qood0POn1om[oo021oh?o0I6Af_ol09SooY61olKoo03Mo`1XaOom087o
POoJoo`0POn2o`6ATM_oo02Go`6ATH7oa_ol0:7oo@21oh7of_ol087oP_l1TI7K
oo`0Uol1TI61olKoo02Qood0POn1om[oo021oh;o0I6Afool09Oo0I6APOo6oo`0
gOl0H/Goo@21oh7of_ol087oP_onTMcoo02GoojAPOo7oo`0XOom087oPOoJoo`0
POn2oojAg?ol09OooY61olOoo02Qood0POn1om[oo021oh;ooY7Loo`0UoonTH7o
aool0=go06G5ood0POn1om[oo021oh7ooY7Moo`0U_l1TI61olOoo02Qood0POn1
om[oo021oh7ooY7Moo`0U_l1TI61olOoo02Qood0POn1om[oo021oh7ooY7Moo`0
U_l1TI61olOoo03Mo`1XaOom087oPOoJoo`0POn1o`3ooY7Noo`0U_onTH7ob?ol
0:7oo@21oh7of_ol087oPOl0oojAg_ol09KooY61olSoo02Qood0POn1om[oo021
oh7o0?onTMkoo02FoojAPOo8oo`0gOl0K/Goo@21oh7of_ol087oPOl1ooonTMoo
o02Eo`6ATH7ob?ol0:7oo@21oh7of_ol087oPOl1ooonTMooo02Eo`6ATH7ob?ol
0:7oo@21oh7of_ol087oPOl1ooonTMooo02Eo`6ATH7ob?ol0=go06_5ood0POn1
om[oo021oh7oo_onTN3oo02Eo`6ATH7ob?ol0:7oo@21oh7of_ol087oPOonoojA
h?ol09Go0I6APOo8oo`0XOom087oPOoJoo`0POn1ookooY7Poo`0UOl1TI61olSo
o03Mo`1XaOom087oPOoJoo`0POn1oogooY7Qoo`0UOonTH7obOol0:7oo@21oh7o
f_ol087oPOomoojAhOol09GooY61olWoo02Qood0POn1om[oo021oh7ooOonTN7o
o02EoojAPOo9oo`0gOl0JlGoo@21oh7of_ol087oPOoloojAh_ol09Co0I6APOo9
oo`0XOom087oPOoJoo`0POn1oocooY7Roo`0U?l1TI61olWoo02Qood0POn1om[o
o021oh7oo?onTN;oo02Do`6ATH7obOol0=go06S5ood0POn1om[oo021oh7onoon
TN?oo02DoojAPOo:oo`0XOom087oPOoJoo`0POn1oo_ooY7Soo`0U?onTH7ob_ol
0:7oo@21oh7of_ol087oPOokoojAhool09CooY61ol[oo03Mo`1[aOom087oPOoJ
oo`0POn1oo[ooY7Too`0Tol1TI61ol[oo02Qood0POn1om[oo021oh7on_onTNCo
o02Co`6ATH7ob_ol0:7oo@21oh7of_ol087oPOojoojAi?ol09?o0I6APOo:oo`0
gOl0J<Goo@21oh7of_ol087oPOoioojAiOol09?ooY61ol_oo02Qood0POn1om[o
o021oh7onOonTNGoo02CoojAPOo;oo`0XOom087oPOoJoo`0POn1ooWooY7Uoo`0
ToonTH7obool0=go06_5ood0POn1om[oo021oh7on?onTNKoo02Bo`6ATH7obool
0:7oo@21oh7of_ol087oPOohoojAi_ol09;o0I6APOo;oo`0XOom087oPOoJoo`0
POn1ooSooY7Voo`0T_l1TI61ol_oo03Mo`1[aOom087oPOoJoo`0POn1ooOooY7W
oo`0T_l1TI61ol_oo02Qood0POn1om[oo021oh7omoonTNOoo02Bo`6ATH7obool
0:7oo@21oh7of_ol087oPOogoojAiool09;o0I6APOo;oo`0gOl0J<Goo@21oh7o
f_ol087oPOofoojAj?ol09;ooY61olcoo02Qood0POn1om[oo021oh7om_onTNSo
o02BoojAPOo<oo`0XOom087oPOoJoo`0POn1ooKooY7Xoo`0T_onTH7oc?ol0=go
06_5ood0POn1om[oo021oh7omOonTNWoo02Ao`6ATH7oc?ol0:7oo@21oh7of_ol
087oPOoeoojAjOol097o0I6APOo<oo`0XOom087oPOoJoo`0POn1ooGooY7Yoo`0
TOl1TI61olcoo03Mo`1^oOo9Z_d0POn1om[oo021oh7om?onTN[oo02AoojAPOo=
oo`0fOo9Z_d0POn1om[oo021oh7om?onTN[oo02AoojAPOo=oo`0fOo9Z_d0POn1
om[oo021oh7om?onTN[oo02AoojAPOo=oo`0gOl0DOgobJZ10840P@210<<0oY61
0?D00I6AP@2T0?gobJZ10840P@210<<0oY610?D00I6AP@2T0?gobJZ10840P@21
0<<0oY610?D00I6AP@2T001>oOo9ZX40P@210840`P3nTH40mP3nTH40Y@3molVZ
P@210840P@320?jAP@3f0?jAP@2U0?gobJZ10840P@210<80oY610?H0oY610:D0
057molVZP@210840P@310?jAP@3f006ATH40Y@3molVZP@210840P@310?jAP@3f
006ATH40Y@3molVZP@210840P@310?jAP@3f006ATH40Y@00BlGoP@210840P@30
0?jAP@3g006ATH40Y@35oh40P@210840`03nTH40m`01TI610:D0aOn10840P@21
0<00oY610?L00I6AP@2U0018aOn10840P@210;l0oY610?P0oY610:H0aOn10840
P@210;l0oY610?P0oY610:H0aOn10840P@210;l0oY610?P0oY610:H006_5ood0
POn1om[oo021oh7ok_onTO3oo02>o`6ATH7ocool0:7oo@21oh7of_ol087oPOo^
oojAl?ol08ko0I6APOo?oo`0XOom087oPOoJoo`0POn1onkooY7`oo`0S_l1TI61
olooo03Mo`1XaOom087oPOoJoo`0POn1ongooY7aoo`0S_onTH7od?ol0:7oo@21
oh7of_ol087oPOo]oojAlOol08kooY61om3oo02Qood0POn1om[oo021oh7okOon
TO7oo02>oojAPOo@oo`0gOl0JlGoo@21oh7of_ol087oPOo/oojAl_ol08go0I6A
POo@oo`0XOom087oPOoJoo`0POn1oncooY7boo`0SOl1TI61om3oo02Qood0POn1
om[oo021oh7ok?onTO;oo02=o`6ATH7od?ol0=go06S5ood0POn1om[oo021oh7o
joonTO?oo02=oojAPOoAoo`0XOom087oPOoJoo`0POn1on_ooY7coo`0SOonTH7o
dOol0:7oo@21oh7of_ol087oPOo[oojAlool08gooY61om7oo03Mo`1[aOom087o
POoJoo`0POn1on[ooY7doo`0S?l1TI61om7oo02Qood0POn1om[oo021oh7oj_on
TOCoo02<o`6ATH7odOol0:7oo@21oh7of_ol087oPOoZoojAm?ol08co0I6APOoA
oo`0gOl0JlGoo@21oh7of_ol087oPOoYoojAmOol08co0I6APOoAoo`0XOom087o
POoJoo`0POn1onWooY7eoo`0S?l1TI61om7oo02Qood0POn1om[oo021oh7ojOon
TOGoo02<o`6ATH7odOol0=go06S5ood0POn1om[oo021oh7oj?onTOKoo02<oojA
POoBoo`0XOom087oPOoJoo`0POn1onSooY7foo`0S?onTH7od_ol0:7oo@21oh7o
f_ol087oPOoXoojAm_ol08cooY61om;oo03Mo`1[aOom087oPOoJoo`0POn1onOo
oY7goo`0Rol1TI61om;oo02Qood0POn1om[oo021oh7oioonTOOoo02;o`6ATH7o
d_ol0:7oo@21oh7of_ol087oPOoWoojAmool08_o0I6APOoBoo`0gOl0J<Goo@21
oh7of_ol087oPOoVoojAn?ol08_ooY61om?oo02Qood0POn1om[oo021oh7oi_on
TOSoo02;oojAPOoCoo`0XOom087oPOoJoo`0POn1onKooY7hoo`0RoonTH7odool
0=go06_5ood0POn1om[oo021oh7oiOonTOWoo02:o`6ATH7odool0:7oo@21oh7o
f_ol087oPOoUoojAnOol08[o0I6APOoCoo`0XOom087oPOoJoo`0POn1onGooY7i
oo`0R_l1TI61om?oo03Mo`1XaOom087oPOoJoo`0POn1onCooY7joo`0R_onTH7o
e?ol0:7oo@21oh7of_ol087oPOoToojAn_ol08[ooY61omCoo02Qood0POn1om[o
o021oh7oi?onTO[oo02:oojAPOoDoo`0gOl0JlGoo@21oh7of_ol087oPOoSoojA
nool08Wo0I6APOoDoo`0XOom087oPOoJoo`0POn1on?ooY7koo`0ROl1TI61omCo
o02Qood0POn1om[oo021oh7ohoonTO_oo029o`6ATH7oe?ol0=go06_5ood0POn1
om[oo021oh7oh_onTOcoo029o`6ATH7oe?ol0:7oo@21oh7of_ol087oPOoRoojA
o?ol08Wo0I6APOoDoo`0XOom087oPOoJoo`0POn1on;ooY7loo`0ROl1TI61omCo
o03Mo`1XaOom087oPOoJoo`0POn1on7ooY7moo`0ROonTH7oeOol0:7oo@21oh7o
f_ol087oPOoQoojAoOol08WooY61omGoo02Qood0POn1om[oo021oh7ohOonTOgo
o029oojAPOoEoo`0gOl0PlGoo@21oh7of_ol0>cooP21oh7on?onTOkoo028o`6A
TH7oeOol0>cooP2iood0POn1om[oo03/ooh0POn1ooSooY7noo`0R?l1TI61omGo
o03/ooh0^Oom087oPOoJoo`0k?on087oPOohoojAo_ol08So0I6APOoEoo`0k?on
0?Go08?5ood0POn1om[oo03/ooh0POn1ooOooY41oool08SooY61omKoo03/ooh0
^Oom087oPOoJoo`0k?on087oPOogoojA0Oooo028oojAPOoFoo`0k?on0;Woo@21
oh7of_ol0>cooP21oh7omoonT@7ooo`0R?onTH7oe_ol0>cooP3eo`23aOom087o
POoJoo`0k?on087oPOofoojA0?ol08Oo0I6APOoFoo`0k?on0;Woo@21oh7of_ol
0>cooP21oh7om_onT@3oo027o`6ATH7oe_ol0>cooP2iood0POn1om[oo03/ooh0
POn1ooKooY40oo`0Qol1TI61omKoo03/ooh0mOl0N/Goo@21oh7of_ol0>cooP21
oh7omOonTO`0QoonTH7oeool0>cooP2iood0POn1om[oo03/ooh0POn1ooGooY7l
08OooY61omOoo03/ooh0^Oom087oPOoJoo`0k?on087oPOoeoojAo027oojAPOoG
oo`0k?on0?Go07g5ood0POn1om[oo03/ooh0POn1ooCooY7m08Ko0I6APOoGoo`0
k?on0;Woo@21oh7of_ol0>cooP21oh7om?onTOd0Q_l1TI61omOoo03/ooh0^Oom
087oPOoJoo`0k?on087oPOodoojAo@26o`6ATH7oeool0>cooP3eo`1maOom087o
POoJoo`0k?on087oPOocoojAoP26o`6ATH7oeool0>cooP2iood0POn1om[oo03/
ooh0POn1oo?ooY7n08Ko0I6APOoGoo`0k?on0;Woo@21oh7of_ol0>cooP21oh7o
loonTOh0Q_l1TI61omOoo03/ooh0mOl0OLGoo@21oh7of_ol0>cooP21oh7ol_on
T@4008KooY61omSoo03/ooh0^Oom087oPOoJoo`0k?on087oPOoboojA0@00Q_on
TH7of?ol0>cooP2iood0POn1om[oo03/ooh0POn1oo;ooY410026oojAPOoHoo`0
k?on0?Go08?5ood0POn1om[oo03/ooh0POn1oo;o003nT@00QOl1TI61omSoo03/
ooh0^Oom087oPOoJoo`0k?on087oPOobo`00oY4008Go0I6APOoHoo`0k?on0;Wo
o@21oh7of_ol0>cooP21oh7ol_l00?jA0025o`6ATH7of?ol0>cooP3eo`2EaOom
0?ComP21oh7ol_ol0>cooP21oh7ol_l1003nTOKomP2KoojAPOoIoo`0k?on0;Wo
o@3dooH0POn1oo;oo03/ooh0POn1oo;o0@00oY7fooH0VoonTH7ofOol0>cooP2i
ood0m?of087oPOoboo`0k?on087oPOobo`400?jAm_of09_ooY61omWoo03/ooh0
mOl0ULGoo@3dooH0POn1oo;oo03eon`0POn1oo_ooP3nTOOomP2Jo`6ATH7ofOol
0?Gok032ood0m?of087oPOoboo`0mOo/087oPOokooh0oY7gooH0V_l1TI61omWo
o03eon`0`_om0?ComP21oh7ol_ol0?Gok021oh7onoon0?jAmoof09[o0I6APOoI
oo`0mOo/0?ko09;5ood0m?of087oPOoboo`0mOo/087oPOokood0oY7hooH0V_on
TH7of_ol0?Gok032ood0m?of087oPOoboo`0mOo/087oPOokood0oY7hooH0V_on
TH7of_ol0?Gok032ood0m?of087oPOoboo`0mOo/087oPOokood0oY7hooH0V_on
TH7of_ol0?Gok03no`1maOom087oPOoJoo`0mOo/087oPOokoo`0oY66o`6ATH7o
f_ol0?Gok032ood0POn1om[oo03eon`0POn1oo_oo03nTHKo0I6APOoJoo`0mOo/
0<;oo@21oh7of_ol0?Gok021oh7onool0?jAQ_l1TI61om[oo03eon`0o_l0PlGo
o@21oh7of_ol0>cooP21oh7ol_ol003ooY67o`6ATH7of_ol0>cooP2iood0POn1
om[oo03/ooh0POn1oo;oo000oojAQol1TI61om[oo03/ooh0^Oom087oPOoJoo`0
k?on087oPOoboo`00?onTHOo0I6APOoJoo`0k?on0?Go08?5ood0POn1om[oo03/
ooh0POn1oo;oo001ooonTHSooY61om_oo03/ooh0^Oom087oPOoJoo`0k?on087o
POoboo`00OoooY68oojAPOoKoo`0k?on0;Woo@21oh7of_ol0>cooP21oh7ol_ol
007ooojAR?onTH7ofool0>cooP3eo`23aOom087oPOoJoo`0k?on087oPOoboo`0
o_onTHSo0I6APOoKoo`0k?on0;Woo@21oh7of_ol0>cooP21oh7ol_ol0?kooY68
o`6ATH7ofool0>cooP2iood0POn1om[oo03/ooh0POn1oo;oo03noojAR?l1TI61
om_oo03/ooh0mOl0P<Goo@21oh7of_ol0>cooP21oh7ol_ol0?gooY69oojAPOoL
oo`0k?on0;Woo@21oh7of_ol0>cooP21oh7ol_ol0?gooY69oojAPOoLoo`0k?on
0;Woo@21oh7of_ol0>cooP21oh7ol_ol0?gooY69oojAPOoLoo`0k?on0?Go08?5
ood0POn1om[oo03/ooh0POn1oo;oo03loojAROl1TI61omcoo03/ooh0^Oom087o
POoJoo`0k?on087oPOoboo`0o?onTHWo0I6APOoLoo`0k?on0;Woo@21oh7of_ol
0>cooP21oh7ol_ol0?cooY69o`6ATH7og?ol0>cooP3eo`20aOom087oPOoJoo`0
k?on087oPOoboo`0noonTH[ooY61omgoo03/ooh0^Oom087oPOoJoo`0k?on087o
POoboo`0noonTH[ooY61omgoo03/ooh0^Oom087oPOoJoo`0k?on087oPOoboo`0
noonTH[ooY61omgoo03/ooh0mOl0PlGoo@21oh7of_ol0>cooP21oh7ol_ol0?[o
oY6:o`6ATH7ogOol0>cooP2iood0POn1om[oo03/ooh0POn1oo;oo03joojAR_l1
TI61omgoo03/ooh0^Oom087oPOoJoo`0k?on087oPOoboo`0n_onTH[o0I6APOoM
oo`0k?on0?Go08K5ood0POn1om[oo03/ooh0POn1oo;oo03io`6ATH[o0I6APOoM
oo`0k?on0;Woo@21oh7of_ol0>cooP21oh7ol_ol0?Wo0I6AR_l1TI61omgoo03/
ooh0^Oom087oPOoJoo`0k?on087oPOoboo`0nOl1TI6:o`6ATH7ogOol0>cooP3e
o`23aOom087oPOoJoo`0k?on087oPOoboo`0n?l1TI6;oojAPOoNoo`0k?on0;Wo
o@21oh7of_ol0>cooP21oh7ol_ol0?So0I6ARoonTH7og_ol0>cooP2iood0POn1
om[oo03/ooh0POn1oo;oo03ho`6ATH_ooY61omkoo03/ooh0mOl0K/Goo@21oh7o
f_ol087oPOoJoo`0mol1TI6;o`6ATH7og_ol0:7oo@21oh7of_ol087oPOoJoo`0
mol1TI6;o`6ATH7og_ol0:7oo@21oh7of_ol087oPOoJoo`0mol1TI6;o`6ATH7o
g_ol0=go06_5ood0POn1om[oo021oh7of_ol0?Ko0I6AS?onTH7ogool0:7oo@21
oh7of_ol087oPOoJoo`0m_l1TI6<oojAPOoOoo`0XOom087oPOoJoo`0POn1om[o
o03fo`6ATHcooY61omooo03Mo`1^aOom087oPOoJoo`0POn1om[oo03eo`6ATHco
0I6APOoOoo`0XOom087oPOoJoo`0POn1om[oo03eo`6ATHco0I6APOoOoo`0XOom
087oPOoJoo`0POn1om[oo03eo`6ATHco0I6APOoOoo`0gOl0JlGoo@21oh7of_ol
087oPOoJoo`0m?l1TI6=oojAPOoPoo`0XOom087oPOoJoo`0POn1om[oo03do`6A
THgooY61on3oo02Qood0POn1om[oo021oh7of_ol0?Co0I6ASOonTH7oh?ol0=go
06k5ood0POn1om[oo021oh7of_ol0??o0I6ASOl1TI61on3oo02Qood0POn1om[o
o021oh7of_ol0??o0I6ASOl1TI61on3oo02Qood0POn1om[oo021oh7of_ol0??o
0I6ASOl1TI61on3oo03Mo`1^aOom087oPOoJoo`0POn1om[oo03bo`6ATHko0I6A
POoPoo`0XOom087oPOoJoo`0POn1om[oo03bo`6ATHko0I6APOoPoo`0XOom087o
POoJoo`0POn1om[oo03bo`6ATHko0I6APOoPoo`0gOl0JlGoo@21oh7of_ol087o
POoJoo`0lOl1TI6?oojAPOoQoo`0XOom087oPOoJoo`0POn1om[oo03ao`6ATHoo
oY61on7oo02Qood0POn1om[oo021oh7of_ol0?7o0I6ASoonTH7ohOol0=go06k5
ood0POn1om[oo021oh7of_ol0?3o0I6ASol1TI61on7oo02Qood0POn1om[oo021
oh7of_ol0?3o0I6ASol1TI61on7oo02Qood0POn1om[oo021oh7of_ol0?3o0I6A
Sol1TI61on7oo03Mo`1[aOom087oPOoJoo`0POn1om[oo03_o`6ATI3ooY61on;o
o02Qood0POn1om[oo021oh7of_ol0>oo0I6AT?onTH7oh_ol0:7oo@21oh7of_ol
087oPOoJoo`0kol1TI6@oojAPOoRoo`0gOl0K/Goo@21oh7of_ol087oPOoJoo`0
k_l1TI6@o`6ATH7oh_ol0:7oo@21oh7of_ol087oPOoJoo`0k_l1TI6@o`6ATH7o
h_ol0:7oo@21oh7of_ol087oPOoJoo`0k_l1TI6@o`6ATH7oh_ol0=go06_5ood0
POn1om[oo021oh7of_ol0>go0I6ATOonTH7ohool0:7oo@21oh7of_ol087oPOoJ
oo`0kOl1TI6AoojAPOoSoo`0XOom087oPOoJoo`0POn1om[oo03]o`6ATI7ooY61
on?oo03Mo`1^aOom087oPOoJoo`0POn1om[oo03/o`6ATI7o0I6APOoSoo`0XOom
087oPOoJoo`0POn1om[oo03/o`6ATI7o0I6APOoSoo`0XOom087oPOoJoo`0POn1
om[oo03/o`6ATI7o0I6APOoSoo`0gOl0M<Goo@21oh7of_ol087o/_l00:[oo03[
o`6ATI;o0I6APOoSoo`0XOom087oPOoJoo`0POnbo`00Z_ol0>_o0I6AT_l1TI61
on?oo02Qood0POn1om[oo021ok;o002Zoo`0jol1TI6Bo`6ATH7ohool0=go08?5
ood0[Ooj087o]Ool087o]Ooi0:koo03Zo`6ATLKonP3EoojAPOoToo`0XOom0:go
nP21okGoo021okGon@2^oo`0j_l1TI76ooX0eOonTH7oi?ol0:7oo@2]ooX0POne
oo`0POneooT0[_ol0>[o0I6Aa_oj0=GooY61onCoo03Mo`26aOom0;;ol@21okWo
o021okWol@2boo`0jOl1TI7<oo40f?l1TI61onCoo02Qood0/_oa087o^Ool087o
^Ooa0;;oo03Yo`6ATLcol@3Ho`6ATH7oi?ol0:7oo@2boo40POnioo`0POnioo40
/_ol0>Wo0I6Ac?oa0=So0I6APOoToo`0gOl0PlGoo@2conl0POnjoo`0POnjonl0
/ool0>So0I6Ac_o_0=WooY61onGoo02Qood0/oo_087o^_ol087o^_o_0;?oo03X
o`6ATLkok`3IoojAPOoUoo`0XOom0;?ok`21ok[oo021ok[ok`2coo`0j?l1TI7>
onl0fOonTH7oiOol0=go08K5ood0]?o/087o_?ol087o^oo/0;Goo03Wo`6ATM3o
k03Jo`6ATH7oiOol0:7oo@2don`0POnloo`0POnkon`0]Ool0>Oo0I6Ad?o/0=[o
0I6APOoUoo`0XOom0;Cok021okcoo021ok_ok02eoo`0iol1TI7@on`0f_l1TI61
onGoo03Mo`23aOom0;Koj@21okgoo021okgoj@2foo`0i_l1TI7ConT0foonTH7o
i_ol0:7oo@2fonT0POnmoo`0POnmonT0]_ol0>Ko0I6AdooY0=_ooY61onKoo02Q
ood0]_oY087o_Ool087o_OoY0;Koo03Vo`6ATM?oj@3KoojAPOoVoo`0gOl0XLGo
o@2gonH0POnooo`0POnoooP00Oooo@3mooT0]ool0>Go0I6AeOoV0=co0I6APOoV
oo`0XOom0;OoiP21okooo021okoon001ooom0?gon@2goo`0iOl1TI7EonH0g?l1
TI61onKoo02Qood0]ooV087o_ool087o_ooh007oood0oOoi0;Ooo03Uo`6ATMGo
iP3Lo`6ATH7oi_ol0=go09k5ood0^?oT087o`?ol087o_ooj0?goo@3mooP0^?ol
0>Co0I6AeooT0=go0I6APOoVoo`0XOom0;Soi021ol3oo021okoonP3mood0oOoh
0;Soo03To`6ATMOoi03Mo`6ATH7oi_ol0:7oo@2hon@0POo0oo`0POnoooX0oOom
0?gon02hoo`0i?l1TI7Gon@0gOl1TI61onKoo03Mo`2KaOom0;Soi021ol3oo021
ol3on@3mood0oOoh0;Soo03So`6ATMSoi03MoojAPOoWoo`0XOom0;Soi021ol3o
o021ol3on@3mood0oOoh0;Soo03So`6ATMSoi03MoojAPOoWoo`0XOom0;Soi021
ol3oo021ol3on@3mood0oOoh0;Soo03So`6ATMSoi03MoojAPOoWoo`0gOl0Z/Go
o@2ion80POo1oo`0POo0ooT0oOom0?goo@00oo`0^Ool0>;o0I6Af_oR0=go0I6A
POoWoo`0XOom0;WohP21ol7oo021ol3on@3mood0oOom003oo02ioo`0h_l1TI7J
on80gOl1TI61onOoo02Qood0^OoR087o`Ool087o`?oi0?goo@3mood00?ol0;Wo
o03Ro`6ATM[ohP3Mo`6ATH7oiool0=go0<;5ood0^_ol0>_oo021ol7oo021ol7o
n03mood0oOom007ooo`0^_ol0>7o0I6Ag?ol0>_oo03MoojAPOoXoo`0XOom0;[o
o03[oo`0POo1oo`0POo1ooP0oOom0?goo@01oool0;[oo03Qo`6ATMcoo03[oo`0
gOonTH7oj?ol0:7oo@2joo`0jool087o`Ool087o`Ooh0?goo@3mood00Oooo02j
oo`0hOl1TI7Loo`0jool0=gooY61onSoo03Mo`3>aOom0;[oo@3Yoo`0POo2oo`0
POo1ood00?om0?goo@3mood00Oooo02joo`0hOonTMgoo@3Yoo`0gOl1TI61onSo
o02Qood0^_om0>Woo021ol;oo021ol7oo@00ood0oOom0?goo@01oool0;[oo03Q
oojAgOom0>Woo03Mo`6ATH7oj?ol0:7oo@2jood0jOol087o`_ol087o`Oom003o
o@3mood0oOom007ooo`0^_ol0>7ooY7Mood0jOol0=go0I6APOoXoo`0gOl0b<Go
o@2koo`0j?om087o`_ol087o`ook003oo@3mood0oOom0?koo02koo`0h?onTMoo
o03Xood0gOonTH7ojOol0:7oo@2koo`0j?om087o`_ol087o`ook003oo@3mood0
oOom0?koo02koo`0h?onTMooo03Xood0gOonTH7ojOol0:7oo@2koo`0j?om087o
`_ol087o`ook003oo@3mood0oOom0?koo02koo`0h?onTMooo03Xood0gOonTH7o
jOol0=go0<k5ood0^oom0>Ooo@21ol;oo021ol?oo001ooom0?goo@3mood0oOom
0;_oo03OoojAh?om0>Ooo@3Lo`6ATH7ojOol0:7oo@2kood0ioom087o`_ol087o
`ool007oood0oOom0?goo@3mood0^ool0=oooY7Pood0ioom0=co0I6APOoYoo`0
XOom0;_oo@3Wood0POo2oo`0POo3oo`00Oooo@3mood0oOom0?goo@2koo`0goon
TN3oo@3Wood0g?l1TI61onWoo03Mo`2faOom0;cog@21ol?oo021ol?oo001ooom
0?goo@3mood0oOol0;coo03NoojAh_oM0=go0I6APOoYoo`0XOom0;cog@21ol?o
o021ol?oo001ooom0?goo@3mood0oOol0;coo03NoojAh_oM0=go0I6APOoYoo`0
XOom0;cog@21ol?oo021ol?oo001ooom0?goo@3mood0oOol0;coo03NoojAh_oM
0=go0I6APOoYoo`0gOl0/<Goo@2lomd0POo3oo`0POo3ood0o_om0?goo@3mood0
oOol0;coo03MoojAhooM0=gooY61on[oo02Qood0_?oM087o`ool087o`oom0?ko
o@3mood0oOom0?goo02loo`0gOonTN?og@3MoojAPOoZoo`0XOom0;cog@21ol?o
o021ol?oo@3nood0oOom0?goo@3moo`0_?ol0=gooY7Somd0gOonTH7oj_ol0=go
0;?5ood0_?oM087o`ool087oa?ol0?koo@3mood0oOom0?coo@2loo`0g?onTNCo
g@3Lo`6ATH7oj_ol0:7oo@2lomd0POo3oo`0POo4oo`0o_om0?goo@3mood0o?om
0;coo03LoojAi?oM0=co0I6APOoZoo`0XOom0;cog@21ol?oo021olCoo03nood0
oOom0?goo@3lood0_?ol0=cooY7Tomd0g?l1TI61on[oo03Mo`2`aOom0;cog021
olCoo021olCoo03nood0oOom0?goo@3loo`0_Ool0=_ooY7Uom`0gOonTH7ojool
0:7oo@2lom`0POo4oo`0POo4oo`0o_om0?goo@3mood0o?ol0;goo03KoojAiOoL
0=gooY61on_oo02Qood0_?oL087oa?ol087oa?ol0?koo@3mood0oOom0?coo02m
oo`0foonTNGog03MoojAPOo[oo`0gOl0blGoo@2moo`0i?om087oa?ol087oa?ol
0?koo@3mood0oOom0?coo02moo`0f_onTNOoo03Tood0g?l1TI61on_oo02Qood0
_Ool0>Coo@21olCoo021olCoo03nood0oOom0?goo@3loo`0_Ool0=[ooY7Woo`0
i?om0=co0I6APOo[oo`0XOom0;goo03Tood0POo4oo`0POo4oo`0o_om0?goo@3m
ood0o?ol0;goo03JoojAiool0>Coo@3Lo`6ATH7ojool0=go0<S5ood0_Oom0>?o
o@21olCoo021olCoo@3mood0oOom0?goo@3loo`0_Ool0=WooY7Xood0hoom0=co
oY61oncoo02Qood0_Oom0>?oo@21olCoo021olCoo@3mood0oOom0?goo@3loo`0
_Ool0=WooY7Xood0hoom0=cooY61oncoo02Qood0_Oom0>?oo@21olCoo021olCo
o@3mood0oOom0?goo@3loo`0_Ool0=WooY7Xood0hoom0=cooY61oncoo03Mo`3;
aOom0;goo@3Sood0POo4oo`0POo4ood0oOom0?goo@3mood0o?ol0;goo03HoojA
jOom0>?oo@3Ko`6ATH7ok?ol0:7oo@2mood0hoom087oa?ol087oa?om0?goo@3m
ood0oOom0?coo02moo`0f?onTNWoo@3Sood0fol1TI61oncoo02Qood0_Oom0>?o
o@21olCoo021olCoo@3mood0oOom0?goo@3loo`0_Ool0=SooY7Yood0hoom0=_o
0I6APOo/oo`0gOl0blGoo@2moo`0iOol087oa?ol087oa?ol0?koo@3mood0oOom
0?coo02moo`0eoonTN[oo03Uoo`0fol1TI61oncoo02Qood0_Ool0>Goo021olCo
o021olCoo03nood0oOom0?goo@3loo`0_Ool0=OooY7Zoo`0iOol0=_o0I6APOo/
oo`0XOom0;goo03Uoo`0POo4oo`0POo4oo`0o_om0?goo@3mood0o?ol0;goo03G
oojAj_ol0>Goo03Ko`6ATH7ok?ol0=go0;35ood0_?oM087o`ool087oa?ol0?ko
o@3mood0oOom0?coo@2loo`0e_onTN[og@3JoojAPOo]oo`0XOom0;cog@21ol?o
o021olCoo03nood0oOom0?goo@3lood0_?ol0=KooY7Zomd0f_onTH7okOol0:7o
o@2lomd0POo3oo`0POo4oo`0o_om0?goo@3mood0o?om0;coo03FoojAj_oM0=[o
oY61ongoo03Mo`2caOom0;cog@21ol?oo021ol?oo@3nood0oOom0?goo@3moo`0
_?ol0=GooY7[omd0fOl1TI61ongoo02Qood0_?oM087o`ool087o`oom0?koo@3m
ood0oOom0?goo02loo`0eOonTN_og@3Io`6ATH7okOol0:7oo@2lomd0POo3oo`0
POo3ood0o_om0?goo@3mood0oOol0;coo03EoojAjooM0=Wo0I6APOo]oo`0gOl0
/lGoo@2lomd0POo3oo`0POo3oo`00Oooo@3mood0oOom0?goo02loo`0e?onTNco
g@3IoojAPOo^oo`0XOom0;cog@21ol?oo021ol?oo001ooom0?goo@3mood0oOol
0;coo03DoojAk?oM0=WooY61onkoo02Qood0_?oM087o`ool087o`ool007oood0
oOom0?goo@3moo`0_?ol0=CooY7/omd0fOonTH7ok_ol0=go0;K5ood0^ooO087o
`_ol087o`ool007oood0oOom0?goo@3mood0^ool0=?ooY7/oml0eol1TI61onko
o02Qood0^ooO087o`_ol087o`ool007oood0oOom0?goo@3mood0^ool0=?ooY7/
oml0eol1TI61onkoo02Qood0^ooO087o`_ol087o`ool007oood0oOom0?goo@3m
ood0^ool0=?ooY7/oml0eol1TI61onkoo03Mo`2caOom0;_og`21ol;oo021ol;o
o@01ooom0?goo@3mood0o_ol0;_oo03BoojAkOoO0=OooY61onooo02Qood0^ooO
087o`_ol087o`_om007oood0oOom0?goo@3noo`0^ool0=;ooY7]oml0eoonTH7o
kool0:7oo@2koml0POo2oo`0POo2ood00Oooo@3mood0oOom0?koo02koo`0d_on
TNgog`3GoojAPOo_oo`0gOl0blGoo@2koo`0jOol087o`_ol087o`_ol003oo@3m
ood0oOom0?koo02koo`0dOonTNkoo03Yoo`0e_l1TI61onooo02Qood0^ool0>Wo
o021ol;oo021ol;oo000ood0oOom0?goo@3noo`0^ool0=7ooY7^oo`0jOol0=Ko
0I6APOo_oo`0XOom0;_oo03Yoo`0POo2oo`0POo2oo`00?om0?goo@3mood0o_ol
0;_oo03AoojAk_ol0>Woo03Fo`6ATH7okool0=go0<S5ood0^_ol0>[oo@21ol7o
o021ol7on03mood0oOom007ooo`0096koo`0d?onTNkoo03Zood0eOl1TI61onoo
o02Qood0^_ol0>[oo@21ol7oo021ol7on03mood0oOom007ooo`0096koo`0d?on
TNkoo03Zood0eOl1TI61onooo02Qood0^_ol0>[oo@21ol7oo021ol7on03mood0
oOom007ooo`0096koo`0d?onTNkoo03Zood0eOl1TI61onooo03Mo`35aOom0;Wo
o@3[oo`0POo1oo`0POo1ooP0oOom0?goo@01ooom0?jA_?ol0<oooY7^ood0jool
0=GooY61oo3oo02Qood0^Oom0>_oo021ol7oo021ol7on03mood0oOom007oood0
oY6loo`0coonTNkoo@3[oo`0eOonTH7ol?ol0:7oo@2iood0jool087o`Ool087o
`Ooh0?goo@3mood00Oooo@3nTKcoo03?oojAk_om0>_oo03EoojAPOo`oo`0gOl0
_lGoo@2hoo`0k_ol087o`?ol087o`?oi0?goo@3mooL00?omTKkoo03>oojAk_ol
0>koo03Co`6ATH7ol?ol0:7oo@2hoo`0k_ol087o`?ol087o`?oi0?goo@3mooL0
0?omTKkoo03>oojAk_ol0>koo03Co`6ATH7ol?ol0:7oo@2hoo`0k_ol087o`?ol
087o`?oi0?goo@3mooL00?omTKkoo03>oojAk_ol0>koo03Co`6ATH7ol?ol0=go
0:C5ood0^?oT087o`?ol087o_ooj0?goo@3mooP0o_olTL3oo03=oojAkooT0=?o
oY61oo7oo02Qood0^?oT087o`?ol087o_ooj0?goo@3mooP0o_olTL3oo03=oojA
kooT0=?ooY61oo7oo02Qood0^?oT087o`?ol087o_ooj0?goo@3mooP0o_olTL3o
o03=oojAkooT0=?ooY61oo7oo03Mo`2WaOom0;Ooi`21okkoo021okkonP3nood0
oOoi0?_oo972oo`0c?onTNooi`3@o`6ATH7olOol0:7oo@2gonL0POnnoo`0POnn
ooX0o_om0?gon@3koobA`_ol0<cooY7_onL0d?l1TI61oo7oo02Qood0]ooW087o
__ol087o__oj0?koo@3mooT0noolTL;oo03<oojAkooW0=3o0I6APOoaoo`0gOl0
YlGoo@2gonL0POnnoo`0POnnooT00Oooo@3mooT0nOomTL?oo03;oojAl?oW0=3o
oY61oo;oo02Qood0]ooW087o__ol087o__oi007oood0oOoi0?WooI73oo`0boon
TO3oi`3@oojAPOoboo`0XOom0;Ooi`21okkoo021okkon@01ooom0?gon@3ioofA
`ool0<_ooY7`onL0d?onTH7ol_ol0=go08o5ood0]Oo[087o_?ol087o_?o[0?Go
oI75oo`0b_onTNooj`3=o`6ATH7ol_ol0:7oo@2eon/0POnloo`0POnlon/0mOom
TLGoo03:oojAkoo[0<go0I6APOoboo`0XOom0;Goj`21okcoo021okcoj`3eoofA
aOol0<[ooY7_on/0cOl1TI61oo;oo03Mo`2?aOom0;?okP21ok_oo021ok[okP3c
oobAaool0<WooY7^onh0c?l1TI61oo;oo02Qood0/oo^087o^ool087o^_o^0??o
o977oo`0bOonTNkokP3<o`6ATH7ol_ol0:7oo@2conh0POnkoo`0POnjonh0lool
TLOoo039oojAk_o^0<co0I6APOoboo`0gOl0V<Goo@2boo40POnioo`0POnioo40
koolTLWoo038oojAk_oa00;oTI7=oojAPOocoo`0XOom0;;ol@21okWoo021okWo
l@3_oobAbOol0<SooY7^oo400_nATLgooY61oo?oo02Qood0/_oa087o^Ool087o
^Ooa0>ooo979oo`0b?onTNkol@02oi6AcOonTH7olool0=go09_5ood0/Ooc087o
^?ol087o^?oc0>cooI7:oo`0aoonTNkol`3no`2Ac?l1TI61oo?oo02Qood0/Ooc
087o^?ol087o^?oc0>cooI7:oo`0aoonTNkol`3no`2Ac?l1TI61oo?oo02Qood0
/Ooc087o^?ol087o^?oc0>cooI7:oo`0aoonTNkol`3no`2Ac?l1TI61oo?oo03M
o`1maOom087oPOoJoo`0POnCoofAc?ol0<KooY7No`6ATLgooY61ooCoo02Qood0
POn1om[oo021oi?ooI7<oo`0a_onTMko0I6AcOonTH7om?ol0:7oo@21oh7of_ol
087oToomTLcoo036oojAg_l1TI7=oojAPOodoo`0gOl0P<Goo@21oh7of_ol087o
T_olTLkoo035oojAg_l1TI7=o`6ATH7om?ol0:7oo@21oh7of_ol087oT_olTLko
o035oojAg_l1TI7=o`6ATH7om?ol0:7oo@21oh7of_ol087oT_olTLkoo035oojA
g_l1TI7=o`6ATH7om?ol0=go07g5ood0POn1om[oo021oi3ooI7?oo`0a?onTMko
0I6Ac_onTH7omOol0:7oo@21oh7of_ol087oT?omTLooo034oojAg_l1TI7>oojA
POoeoo`0XOom087oPOoJoo`0POn@oofAcool0<CooY7No`6ATLkooY61ooGoo03M
o`1maOom087oPOoJoo`0POn>oofAdOol0<?ooY7No`2AcOl1TI61ooGoo02Qood0
POn1om[oo021ohkooI7Aoo`0`oonTMko097=o`6ATH7omOol0:7oo@21oh7of_ol
087oS_omTM7oo033oojAg_l0TLgo0I6APOoeoo`0gOl0P<Goo@21oh7of_ol087o
SOolTM?oo032oojAgol1TI7>o`6ATH7omOol0:7oo@21oh7of_ol087oSOolTM?o
o032oojAgol1TI7>o`6ATH7omOol0:7oo@21oh7of_ol087oSOolTM?oo032oojA
gol1TI7>o`6ATH7omOol0=go07g5ood0POn1om[oo021oh_oo97Eoo`0`OonTMoo
0I6AcoonTH7om_ol0:7oo@21oh7of_ol087oRoolTMGoo031oojAgol1TI7?oojA
POofoo`0XOom087oPOoJoo`0POn;oobAeOol0<7ooY7Oo`6ATLoooY61ooKoo03M
o`20aOom087oPOoJoo`0POn9oofAe_ol0<3ooY7Oo`6ATLoo0I6APOofoo`0XOom
087oPOoJoo`0POn9oofAe_ol0<3ooY7Oo`6ATLoo0I6APOofoo`0XOom087oPOoJ
oo`0POn9oofAe_ol0<3ooY7Oo`6ATLoo0I6APOofoo`0gOl0N/Goo@21oh7of_ol
087oQoomTMSoo02ooojAgol0TLoooY61ooOoo02Qood0POn1om[oo021ohOooI7H
oo`0_oonTMoo097?oojAPOogoo`0XOom087oPOoJoo`0POn7oofAf?ol0;oooY7O
o`2AcoonTH7omool0=go0835ood0POn1om[oo021ohKoo97Joo`0__onTN3o0I6A
col1TI61ooOoo02Qood0POn1om[oo021ohKoo97Joo`0__onTN3o0I6Acol1TI61
ooOoo02Qood0POn1om[oo021ohKoo97Joo`0__onTN3o0I6Acol1TI61ooOoo03M
o`1maOom087oPOoJoo`0POn4oobAg?ol0;gooY7Po`6ATM3ooY61ooSoo02Qood0
POn1om[oo021ohCoo97Loo`0_OonTN3o0I6Ad?onTH7on?ol0:7oo@21oh7of_ol
087oQ?olTMcoo02moojAh?l1TI7@oojAPOohoo`0gOl0PlGoo@21oh7of_ol087o
P_omTMgoo02lo`6ATMoo0I6Ad?l1TI61ooSoo02Qood0POn1om[oo021oh;ooI7M
oo`0_?l1TI7Oo`6ATM3o0I6APOohoo`0XOom087oPOoJoo`0POn2oofAgOol0;co
0I6Agol1TI7@o`6ATH7on?ol0=go08K5ood0POn1om[oo021oh7o0?omTMooo02k
o`6ATMoo097@o`6ATH7on?ol0:7oo@21oh7of_ol087oPOl0oofAgool0;_o0I6A
gol0TM3o0I6APOohoo`0XOom087oPOoJoo`0POn1o`3ooI7Ooo`0^ol1TI7Oo`2A
d?l1TI61ooSoo03Mo`29aOom087oPOoJoo`0POn1o`7ooobAhOol0;[o0I6Ah?l1
TI7AoojAPOoioo`0XOom087oPOoJoo`0POn1o`7ooobAhOol0;[o0I6Ah?l1TI7A
oojAPOoioo`0XOom087oPOoJoo`0POn1o`7ooobAhOol0;[o0I6Ah?l1TI7AoojA
POoioo`0gOl0RLGoo@21oh7of_ol087oPOomoofAh_ol0;Wo0I6Ah?l1TI7Ao`6A
TH7onOol0:7oo@21oh7of_ol087oPOomoofAh_ol0;Wo0I6Ah?l1TI7Ao`6ATH7o
nOol0:7oo@21oh7of_ol087oPOomoofAh_ol0;Wo0I6Ah?l1TI7Ao`6ATH7onOol
0=go08K5ood0POn1om[oo021oh7onoomTNCoo02ho`6ATN3o0I6Ad_onTH7on_ol
0:7oo@21oh7of_ol087oPOokoofAi?ol0;So0I6Ah?l1TI7BoojAPOojoo`0XOom
087oPOoJoo`0POn1oo_ooI7Too`0^?l1TI7Po`6ATM;ooY61oo[oo03Mo`26aOom
087oPOoJoo`0POn1oo[oo97Voo`0]ol1TI7Po`2AdOl1TI61oo[oo02Qood0POn1
om[oo021oh7on_olTNKoo02go`6ATN3o097Ao`6ATH7on_ol0:7oo@21oh7of_ol
087oPOojoobAi_ol0;Oo0I6Ah?l0TM7o0I6APOojoo`0gOl0Q/Goo@21oh7of_ol
087oPOohoobAj?ol0;Ko0I6AhOl1TI7BoojAPOokoo`0XOom087oPOoJoo`0POn1
ooSoo97Xoo`0]_l1TI7Qo`6ATM;ooY61oo_oo02Qood0POn1om[oo021oh7on?ol
TNSoo02fo`6ATN7o0I6Ad_onTH7onool0=go08W5ood0POn1om[oo021oh7om_om
TNWoo02eo`6ATN7o0I6Ad_l1TI61oo_oo02Qood0POn1om[oo021oh7om_omTNWo
o02eo`6ATN7o0I6Ad_l1TI61oo_oo02Qood0POn1om[oo021oh7om_omTNWoo02e
o`6ATN7o0I6Ad_l1TI61oo_oo03Mo`29aOom087oPOoJoo`0POn1ooCooI7[oo`0
]?l1TI7Qo`6ATM?o0I6APOokoo`0XOom087oPOoJoo`0POn1ooCooI7[oo`0]?l1
TI7Qo`6ATM?o0I6APOokoo`0XOom087oPOoJoo`0POn1ooCooI7[oo`0]?l1TI7Q
o`6ATM?o0I6APOokoo`0gOl0PlGoo@21oh7of_ol087oPOocoobAkOol0;?o0I6A
hOl0TM?ooY61oocoo02Qood0POn1om[oo021oh7oloolTNgoo02co`6ATN7o097C
oojAPOoloo`0XOom087oPOoJoo`0POn1oo?oo97]oo`0/ol1TI7Qo`2AdoonTH7o
o?ol0=go08W5ood0POn1om[oo021oh7olOolTNooo02bo`6ATN;o0I6Adol1TI61
oocoo02Qood0POn1om[oo021oh7olOolTNooo02bo`6ATN;o0I6Adol1TI61ooco
o02Qood0POn1om[oo021oh7olOolTNooo02bo`6ATN;o0I6Adol1TI61oocoo03M
o`26aOom087oPOoJoo`0POn1onoooI7`oo`0/Ol1TI7Ro`6ATMCooY61oogoo02Q
ood0POn1om[oo021oh7okoomTO3oo02ao`6ATN;o0I6Ae?onTH7ooOol0:7oo@21
oh7of_ol087oPOo_oofAl?ol0;7o0I6Ah_l1TI7DoojAPOomoo`0gOl0RLGoo@21
oh7of_ol087oPOo]oofAl_ol0;3o0I6Ah_l1TI7Do`6ATH7ooOol0:7oo@21oh7o
f_ol087oPOo]oofAl_ol0;3o0I6Ah_l1TI7Do`6ATH7ooOol0:7oo@21oh7of_ol
087oPOo]oofAl_ol0;3o0I6Ah_l1TI7Do`6ATH7ooOol0=go08?5ood0POn1om[o
o021oh7ok?olTOCoo02_o`6ATN;o097DoojAPOonoo`0XOom087oPOoJoo`0POn1
oncoo97doo`0[ol1TI7Ro`2Ae?onTH7oo_ol0:7oo@21oh7of_ol087oPOo/oobA
m?ol0:oo0I6Ah_l0TMCooY61ookoo03Mo`29aOom087oPOoJoo`0POn1on[ooI7e
oo`0[_l1TI7So`6ATMCo0I6APOonoo`0XOom087oPOoJoo`0POn1on[ooI7eoo`0
[_l1TI7So`6ATMCo0I6APOonoo`0XOom087oPOoJoo`0POn1on[ooI7eoo`0[_l1
TI7So`6ATMCo0I6APOonoo`0gOl0RLGoo@21oh7of_ol087oPOoXoofAmool0:go
0I6Ahol1TI7Eo`6ATH7oo_ol0:7oo@21oh7of_ol087oPOoXoofAmool0:go0I6A
hol1TI7Eo`6ATH7oo_ol0:7oo@21oh7of_ol087oPOoXoofAmool0:go0I6Ahol1
TI7Eo`6ATH7oo_ol0=go08W5ood0POn1om[oo021oh7oioolTOWoo02/o`6ATN?o
0I6Ae_onTH7o0Oooo02Qood0POn1om[oo021oh7oioolTOWoo02/o`6ATN?o0I6A
e_onTH7o0Oooo02Qood0POn1om[oo021oh7oioolTOWoo02/o`6ATN?o0I6Ae_on
TH7o0Oooo03Mo`29aOom087oPOoJoo`0POn1onGoo97koo`0Zol1TI7So`2AeOl1
TI61o`7ooo`0XOom087oPOoJoo`0POn1onGoo97koo`0Zol1TI7So`2AeOl1TI61
o`7ooo`0XOom087oPOoJoo`0POn1onGoo97koo`0Zol1TI7So`2AeOl1TI61o`7o
oo`0gOl0Q/Goo@21oh7of_ol087oPOoSoofAo?ol0:[o0I6Ai?l1TI7FoojAPOl0
oo`0XOom087oPOoJoo`0POn1on?ooI7loo`0Z_l1TI7To`6ATMKooY61o`3oo02Q
ood0POn1om[oo021oh7ohoomTOcoo02Zo`6ATNCo0I6Ae_onTH7o0?ol0=go08W5
ood0POn1om[oo021oh7ohOomTOkoo02Yo`6ATNCo0I6Ae_l1TI61o`3oo02Qood0
POn1om[oo021oh7ohOomTOkoo02Yo`6ATNCo0I6Ae_l1TI61o`3oo02Qood0POn1
om[oo021oh7ohOomTOkoo02Yo`6ATNCo0I6Ae_l1TI61o`3oo03Mo`20aOom087o
POoJoo`0POn1on3oo940oo`0Z?l1TI7To`6ATMOooY61oo`0XOom087oPOoJoo`0
POn1on3oo940oo`0Z?l1TI7To`6ATMOooY61oo`0XOom087oPOoJoo`0POn1on3o
o940oo`0Z?l1TI7To`6ATMOooY61oo`0gOl0N/Goo@21oh7of_ol087oPOoNoofA
o02Wo`6ATNCo097Fo`6ATH7oo02Qood0POn1om[oo021oh7og_omTO`0Yol1TI7T
o`2Ae_l1TI61oo`0XOom087oPOoJoo`0POn1omkooI7l0:Oo0I6Ai?l0TMKo0I6A
POol0=go07g5ood0POn1om[oo021oh7og?omTOh0Y_l1TI7Uo`6ATMOo0I6APOol
0:7oo@21oh7of_ol087oPOoLoofAoP2Vo`6ATNGo0I6Aeol1TI61oo`0XOom087o
POoJoo`0POn1omcooI7n0:Ko0I6AiOl1TI7Go`6ATH7oo03Mo`1jaOom087oPOoJ
oo`0POn1om_oo9400:Go0I6AiOl1TI7HoojAP_ol0:7oo@21oh7of_ol087oPOoK
oobA002Uo`6ATNGo0I6Af?onTH;oo02Qood0POn1om[oo021oh7ofoolT@00YOl1
TI7Uo`6ATMSooY62oo`0gOl0OLGoo@21oh7of_ol087oPOoJo`00o96Uo`6ATNGo
0I6Af?l1TI62oo`0XOom087oPOoJoo`0POn1om[o003lTJGo0I6AiOl1TI7Ho`6A
TH;oo02Qood0POn1om[oo021oh7of_l00?bAYOl1TI7Uo`6ATMSo0I6AP_ol0=go
07O5ood0POn1om[oo021oh7of_on0?fAYOl1TI7Uo`2Af?onTH?oo02Qood0POn1
om[oo021oh7of_on0?fAYOl1TI7Uo`2Af?onTH?oo02Qood0POn1om[oo021oh7o
f_on0?fAYOl1TI7Uo`2Af?onTH?oo03Mo`1maOom087oPOoJoo`0POn1om[oo03m
TJKo0I6Ai_l1TI7Ho`6ATH?oo02Qood0POn1om[oo021oh7of_ol0?fAY_l1TI7V
o`6ATMSo0I6APool0:7oo@21oh7of_ol087oPOoJoo`0oI6Vo`6ATNKo0I6Af?l1
TI63oo`0gOl0P<Goo@21oh7of_ol087oPOoJoo`00?olTJOo0I6Ai_l1TI7IoojA
Q?ol0:7oo@21oh7of_ol087oPOoJoo`00?olTJOo0I6Ai_l1TI7IoojAQ?ol0:7o
o@21oh7of_ol087oPOoJoo`00?olTJOo0I6Ai_l1TI7IoojAQ?ol0=go08?5ood0
POn1om[oo021oh7of_ol0?koo96Xo`6ATNKo0I6AfOl1TI64oo`0XOom087oPOoJ
oo`0POn1om[oo03noobAZ?l1TI7Vo`6ATMWo0I6AQ?ol0:7oo@21oh7of_ol087o
POoJoo`0o_olTJSo0I6Ai_l1TI7Io`6ATHCoo03Mo`20aOom087oPOoJoo`0POn1
om[oo03loofAZ?l1TI7Vo`2AfOl1TI64oo`0XOom087oPOoJoo`0POn1om[oo03l
oofAZ?l1TI7Vo`2AfOl1TI64oo`0XOom087oPOoJoo`0POn1om[oo03loofAZ?l1
TI7Vo`2AfOl1TI64oo`0gOl0P<Goo@21oh7of_ol087oPOoJoo`0n_omTJWo0I6A
iol1TI7JoojAQOol0:7oo@21oh7of_ol087oPOoJoo`0n_omTJWo0I6Aiol1TI7J
oojAQOol0:7oo@21oh7of_ol087oPOoJoo`0n_omTJWo0I6Aiol1TI7JoojAQOol
0=go08?5ood0POn1om[oo021oh7of_ol0?Woo96Zo`6ATNOo0I6Af_l1TI65oo`0
XOom087oPOoJoo`0POn1om[oo03ioobAZ_l1TI7Wo`6ATM[o0I6AQOol0:7oo@21
oh7of_ol087oPOoJoo`0nOolTJ[o0I6Aiol1TI7Jo`6ATHGoo03Mo`20aOom087o
POoJoo`0POn1om[oo03goofAZ_l1TI7Wo`6ATM_ooY66oo`0XOom087oPOoJoo`0
POn1om[oo03goofAZ_l1TI7Wo`6ATM_ooY66oo`0XOom087oPOoJoo`0POn1om[o
o03goofAZ_l1TI7Wo`6ATM_ooY66oo`0gOl0P<Goo@21oh7of_ol087oPOoJoo`0
mOomTJ_o0I6Aiol0TM[o0I6AQ_ol0:7oo@21oh7of_ol087oPOoJoo`0mOomTJ_o
0I6Aiol0TM[o0I6AQ_ol0:7oo@21oh7of_ol087oPOoJoo`0mOomTJ_o0I6Aiol0
TM[o0I6AQ_ol0=go0835ood0POn1om[oo021oh7of_ol0?Coo96/o`6ATNSo0I6A
foonTHOoo02Qood0POn1om[oo021oh7of_ol0?Coo96/o`6ATNSo0I6AfoonTHOo
o02Qood0POn1om[oo021oh7of_ol0?Coo96/o`6ATNSo0I6AfoonTHOoo03Mo`23
aOom087oPOoJoo`0POn1om[oo03boobA[Ol1TI7Xo`6ATM_o0I6AQool0:7oo@21
oh7of_ol087oPOoJoo`0l_olTJgo0I6Aj?l1TI7Ko`6ATHOoo02Qood0POn1om[o
o021oh7of_ol0?;oo96]o`6ATNSo0I6Afol1TI67oo`0gOl0PlGoo@21oh7of_ol
087oPOoJoo`0l?omTJgo0I6Aj?l1TI7Lo`6ATHOoo02Qood0POn1om[oo021oh7o
f_ol0?3ooI6]o`6ATNSo0I6Ag?l1TI67oo`0XOom087oPOoJoo`0POn1om[oo03`
oofA[Ol1TI7Xo`6ATMco0I6AQool0=go07g5ood0POn1om[oo021oh7of_ol0>ko
oI6^o`6ATNSo097LoojAR?ol0:7oo@21oh7of_ol087oPOoJoo`0k_omTJko0I6A
j?l0TMcooY68oo`0XOom087oPOoJoo`0POn1om[oo03^oofA[_l1TI7Xo`2Ag?on
THSoo03Mo`23aOom087oPOoJoo`0POn1om[oo03]oobA[ol1TI7Yo`6ATMco0I6A
R?ol0:7oo@21oh7of_ol087oPOoJoo`0kOolTJoo0I6AjOl1TI7Lo`6ATHSoo02Q
ood0POn1om[oo021oh7of_ol0>goo96_o`6ATNWo0I6Ag?l1TI68oo`0gOl0P<Go
o@21oh7of_ol087oPOoJoo`0joolTK3o0I6AjOl1TI7MoojAROol0:7oo@21oh7o
f_ol087oPOoJoo`0joolTK3o0I6AjOl1TI7MoojAROol0:7oo@21oh7of_ol087o
POoJoo`0joolTK3o0I6AjOl1TI7MoojAROol0=go08?5ood0POn1om[oo021oh7o
f_ol0>WooI6`o`6ATNWo0I6AgOl1TI69oo`0XOom087oPOoJoo`0POn1om[oo03Y
oofA/?l1TI7Yo`6ATMgo0I6AROol0:7oo@21oh7of_ol087oPOoJoo`0jOomTK3o
0I6AjOl1TI7Mo`6ATHWoo03Mo`1jaOom087oPOoJoo`0POn1om[oo03WoofA/_on
TNWo097MoojAR_ol0:7oo@21oh7of_ol087oPOoJoo`0ioomTK;ooY7Yo`2AgOon
TH[oo02Qood0POn1om[oo021oh7of_ol0>OooI6boojAjOl0TMgooY6:oo`0gOl0
P<Goo@21oh7of_ol087oPOoJoo`0i_olTK?ooY7Zo`6ATMgo0I6AR_ol0:7oo@21
oh7of_ol087oPOoJoo`0i_olTK?ooY7Zo`6ATMgo0I6AR_ol0:7oo@21oh7of_ol
087oPOoJoo`0i_olTK?ooY7Zo`6ATMgo0I6AR_ol0=go0835ood0POn1om[oo021
oh7of_ol0>CooI6coojAj_l1TI7No`6ATH[oo02Qood0POn1om[oo021oh7of_ol
0>CooI6coojAj_l1TI7No`6ATH[oo02Qood0POn1om[oo021oh7of_ol0>CooI6c
oojAj_l1TI7No`6ATH[oo03Mo`1jaOom087oPOoJoo`0POn1om[oo03RoofA]?on
TN[o097NoojARool0:7oo@21oh7of_ol087oPOoJoo`0h_omTKCooY7Zo`2Ag_on
TH_oo02Qood0POn1om[oo021oh7of_ol0>;ooI6doojAj_l0TMkooY6;oo`0gOl0
P<Goo@21oh7of_ol087oPOoJoo`0hOolTKGooY7[o`6ATMko0I6ARool0:7oo@21
oh7of_ol087oPOoJoo`0hOolTKGooY7[o`6ATMko0I6ARool0:7oo@21oh7of_ol
087oPOoJoo`0hOolTKGooY7[o`6ATMko0I6ARool0=go07g5ood0POn1om[oo021
oh7of_ol0=ooo96foojAjol1TI7OoojAS?ol0:7oo@21oh7of_ol087oPOoJoo`0
goolTKKooY7[o`6ATMoooY6<oo`0XOom087oPOoJoo`0POn1om[oo03OoobA]_on
TN_o0I6AgoonTHcoo03Mo`20aOom087oPOoJoo`0POn1om[oo03MoofA]_onTN_o
0I6Agol1TI6<oo`0XOom087oPOoJoo`0POn1om[oo03MoofA]_onTN_o0I6Agol1
TI6<oo`0XOom087oPOoJoo`0POn1om[oo03MoofA]_onTN_o0I6Agol1TI6<oo`0
gOl0N/Goo@21oh7of_ol087oPOoJoo`0foomTKOooY7[o`2AgoonTHgoo02Qood0
POn1om[oo021oh7of_ol0=_ooI6goojAjol0TMoooY6=oo`0XOom087oPOoJoo`0
POn1om[oo03KoofA]oonTN_o097OoojASOol0=go0835ood0POn1om[oo021oh7o
f_ol0=[oo96hoojAk?l1TI7Oo`6ATHgoo02Qood0POn1om[oo021oh7of_ol0=[o
o96hoojAk?l1TI7Oo`6ATHgoo02Qood0POn1om[oo021oh7of_ol0=[oo96hoojA
k?l1TI7Oo`6ATHgoo03Mo`20aOom087oPOoJoo`0POn1om[oo03HoobA^OonTNco
0I6Ah?l1TI6=oo`0XOom087oPOoJoo`0POn1om[oo03HoobA^OonTNco0I6Ah?l1
TI6=oo`0XOom087oPOoJoo`0POn1om[oo03HoobA^OonTNco0I6Ah?l1TI6=oo`0
gOl0OLGoo@21oh7of_ol087oPOoJoo`0e_omTKWooY7/o`6ATN7ooY6>oo`0XOom
087oPOoJoo`0POn1om[oo03FoofA^OonTNco0I6AhOonTHkoo02Qood0POn1om[o
o021oh7of_ol0=KooI6ioojAk?l1TI7QoojAS_ol0=go07g5ood0POn1om[oo021
oh7of_ol0=CooI6joojAk?l0TN3o0I6AS_ol0:7oo@21oh7of_ol087oPOoJoo`0
e?omTK[ooY7/o`2Ah?l1TI6>oo`0XOom087oPOoJoo`0POn1om[oo03DoofA^_on
TNco097Po`6ATHkoo03Mo`1maOom087oPOoJoo`0POn1om[oo03CoobA^oonTNgo
0I6AhOonTHooo02Qood0POn1om[oo021oh7of_ol0=?oo96koojAkOl1TI7QoojA
Sool0:7oo@21oh7of_ol087oPOoJoo`0doolTK_ooY7]o`6ATN7ooY6?oo`0gOl0
P<Goo@21oh7of_ol087oPOoJoo`0dOomTK_ooY7]o`6ATN7o0I6ASool0:7oo@21
oh7of_ol087oPOoJoo`0dOomTK_ooY7]o`6ATN7o0I6ASool0:7oo@21oh7of_ol
087oPOoJoo`0dOomTK_ooY7]o`6ATN7o0I6ASool0=go07g5ood0POn1om[oo021
oh7of_ol0<oooI6loojAkOl1TI7RoojAT?ol0:7oo@21oh7of_ol087oPOoJoo`0
coomTKcooY7]o`6ATN;ooY6@oo`0XOom087oPOoJoo`0POn1om[oo03?oofA_?on
TNgo0I6Ah_onTI3oo03Mo`1maOom087oPOoJoo`0POn1om[oo03>oobA_OonTNgo
097Qo`6ATI3oo02Qood0POn1om[oo021oh7of_ol0<koo96moojAkOl0TN7o0I6A
T?ol0:7oo@21oh7of_ol087oPOoJoo`0c_olTKgooY7]o`2AhOl1TI6@oo`0gOl0
P<Goo@21oh7of_ol087oPOoJoo`0c?olTKkooY7^o`6ATN;o0I6AT?ol0:7oo@21
oh7of_ol087oPOoJoo`0c?olTKkooY7^o`6ATN;o0I6AT?ol0:7oo@21oh7of_ol
087oPOoJoo`0c?olTKkooY7^o`6ATN;o0I6AT?ol0=go07g5ood0POn1om[oo021
oh7of_ol0<[ooI6noojAk_l1TI7SoojATOol0:7oo@21oh7of_ol087oPOoJoo`0
b_omTKkooY7^o`6ATN?ooY6Aoo`0XOom087oPOoJoo`0POn1om[oo03:oofA__on
TNko0I6AhoonTI7oo03Mo`20aOom087oPOoJoo`0POn1om[oo038oofA_oonTNko
0I6Ahol1TI6Aoo`0XOom087oPOoJoo`0POn1om[oo038oofA_oonTNko0I6Ahol1
TI6Aoo`0XOom087oPOoJoo`0POn1om[oo038oofA_oonTNko0I6Ahol1TI6Aoo`0
gOl0N/Goo@21oh7of_ol087oPOoJoo`0aoolTL3ooY7^o`2AhoonTI;oo02Qood0
POn1om[oo021oh7of_ol0<Ooo970oojAk_l0TN?ooY6Boo`0XOom087oPOoJoo`0
POn1om[oo037oobA`?onTNko097SoojAT_ol0=go0835ood0POn1om[oo021oh7o
f_ol0<Goo971oojAkol1TI7So`6ATI;oo02Qood0POn1om[oo021oh7of_ol0<Go
o971oojAkol1TI7So`6ATI;oo02Qood0POn1om[oo021oh7of_ol0<Goo971oojA
kol1TI7So`6ATI;oo03Mo`1maOom087oPOoJoo`0POn1om[oo033oofA`OonTNoo
0I6Ai?onTI?oo02Qood0POn1om[oo021oh7of_ol0<?ooI71oojAkol1TI7ToojA
Tool0:7oo@21oh7of_ol087oPOoJoo`0`oomTL7ooY7_o`6ATNCooY6Coo`0gOl0
PlGoo@21oh7of_ol087oPOoJoo`0`OomTL;o0I6Ak_l1TI7To`6ATI?oo02Qood0
POn1om[oo021oh7of_ol0<7ooI72o`6ATNko0I6Ai?l1TI6Coo`0XOom087oPOoJ
oo`0POn1om[oo031oofA`_l1TI7^o`6ATNCo0I6ATool0=go0835ood0POn1om[o
o021oh7of_ol0<3oo973o`6ATNko097To`6ATI?oo02Qood0POn1om[oo021oh7o
f_ol0<3oo973o`6ATNko097To`6ATI?oo02Qood0POn1om[oo021oh7of_ol0<3o
o973o`6ATNko097To`6ATI?oo03Mo`20aOom087oPOoJoo`0POn1om[oo02noofA
`ol1TI7_o`6ATNGooY6Doo`0XOom087oPOoJoo`0POn1om[oo02noofA`ol1TI7_
o`6ATNGooY6Doo`0XOom087oPOoJoo`0POn1om[oo02noofA`ol1TI7_o`6ATNGo
oY6Doo`0gOl0PlGoo@21oh7of_ol087oPOoJoo`0_?omTLCo0I6Akol1TI7Uo`6A
TICoo02Qood0POn1om[oo021oh7of_ol0;cooI74o`6ATNoo0I6AiOl1TI6Doo`0
XOom087oPOoJoo`0POn1om[oo02loofAa?l1TI7_o`6ATNGo0I6AU?ol0=go0835
ood0POn1om[oo021oh7of_ol0;_oo975o`6ATNoo0I6Ai_onTIGoo02Qood0POn1
om[oo021oh7of_ol0;_oo975o`6ATNoo0I6Ai_onTIGoo02Qood0POn1om[oo021
oh7of_ol0;_oo975o`6ATNoo0I6Ai_onTIGoo03Mo`20aOom087oPOoJoo`0POn1
om[oo02ioobAa_l1TI7_o`2AiOl1TI6Eoo`0XOom087oPOoJoo`0POn1om[oo02i
oobAa_l1TI7_o`2AiOl1TI6Eoo`0XOom087oPOoJoo`0POn1om[oo02ioobAa_l1
TI7_o`2AiOl1TI6Eoo`0gOl0P<Goo@21oh7of_ol087oPOoJoo`0]oomTLKo0I6A
l?l1TI7VoojAU_ol0:7oo@21oh7of_ol087oPOoJoo`0]oomTLKo0I6Al?l1TI7V
oojAU_ol0:7oo@21oh7of_ol087oPOoJoo`0]oomTLKo0I6Al?l1TI7VoojAU_ol
0=go08?5ood0POn1om[oo021oh7of_ol0;GooI77o`6ATO3o0I6Ai_l1TI6Foo`0
XOom087oPOoJoo`0POn1om[oo02eoofAaol1TI7`o`6ATNKo0I6AU_ol0:7oo@21
oh7of_ol087oPOoJoo`0]OomTLOo0I6Al?l1TI7Vo`6ATIKoo03Mo`23aOom087o
POoJoo`0POn1om[oo02doobAb?l1TI7`o`6ATNOo0I6AU_ol0:7oo@21oh7of_ol
087oPOoJoo`0]?olTLSo0I6Al?l1TI7Wo`6ATIKoo02Qood0POn1om[oo021oh7o
f_ol0;Coo978o`6ATO3o0I6Aiol1TI6Foo`0gOl0OLGoo@21oh7of_ol087oPOoJ
oo`0/_omTLSo0I6Al?l0TNOooY6Goo`0XOom087oPOoJoo`0POn1om[oo02boofA
b?l1TI7`o`2AioonTIOoo02Qood0POn1om[oo021oh7of_ol0;;ooI78o`6ATO3o
097WoojAUool0=go08?5ood0POn1om[oo021oh7of_ol0;3ooI79o`6ATO7o0I6A
iol1TI6Goo`0XOom087oPOoJoo`0POn1om[oo02`oofAbOl1TI7ao`6ATNOo0I6A
Uool0:7oo@21oh7of_ol087oPOoJoo`0/?omTLWo0I6AlOl1TI7Wo`6ATIOoo03M
o`20aOom087oPOoJoo`0POn1om[oo02_oobAb_l1TI7ao`6ATNSooY6Hoo`0XOom
087oPOoJoo`0POn1om[oo02_oobAb_l1TI7ao`6ATNSooY6Hoo`0XOom087oPOoJ
oo`0POn1om[oo02_oobAb_l1TI7ao`6ATNSooY6Hoo`0gOl0PlGoo@21oh7of_ol
087oPOoJoo`0[OolTL_o0I6AlOl1TI7Xo`6ATISoo02Qood0POn1om[oo021oh7o
f_ol0:goo97;o`6ATO7o0I6Aj?l1TI6Hoo`0XOom087oPOoJoo`0POn1om[oo02]
oobAbol1TI7ao`6ATNSo0I6AV?ol0=go07g5ood0POn1om[oo021oh7of_ol0:_o
oI7;o`6ATO7o097XoojAVOol0:7oo@21oh7of_ol087oPOoJoo`0ZoomTL_o0I6A
lOl0TNSooY6Ioo`0XOom087oPOoJoo`0POn1om[oo02[oofAbol1TI7ao`2Aj?on
TIWoo03Mo`23aOom087oPOoJoo`0POn1om[oo02YoofAc?l1TI7bo`6ATNSo0I6A
VOol0:7oo@21oh7of_ol087oPOoJoo`0ZOomTLco0I6Al_l1TI7Xo`6ATIWoo02Q
ood0POn1om[oo021oh7of_ol0:WooI7<o`6ATO;o0I6Aj?l1TI6Ioo`0gOl0PlGo
o@21oh7of_ol087oPOoJoo`0Z?olTLgo0I6Al_l1TI7Yo`6ATIWoo02Qood0POn1
om[oo021oh7of_ol0:Soo97=o`6ATO;o0I6AjOl1TI6Ioo`0XOom087oPOoJoo`0
POn1om[oo02XoobAcOl1TI7bo`6ATNWo0I6AVOol0=go0835ood0POn1om[oo021
oh7of_ol0:Koo97>o`6ATO;o0I6Aj_onTI[oo02Qood0POn1om[oo021oh7of_ol
0:Koo97>o`6ATO;o0I6Aj_onTI[oo02Qood0POn1om[oo021oh7of_ol0:Koo97>
o`6ATO;o0I6Aj_onTI[oo03Mo`20aOom087oPOoJoo`0POn1om[oo02ToofAc_l1
TI7bo`2AjOl1TI6Joo`0XOom087oPOoJoo`0POn1om[oo02ToofAc_l1TI7bo`2A
jOl1TI6Joo`0XOom087oPOoJoo`0POn1om[oo02ToofAc_l1TI7bo`2AjOl1TI6J
oo`0gOl0P<Goo@21oh7of_ol087oPOoJoo`0X_omTLoo0I6Alol1TI7ZoojAVool
0:7oo@21oh7of_ol087oPOoJoo`0X_omTLoo0I6Alol1TI7ZoojAVool0:7oo@21
oh7of_ol087oPOoJoo`0X_omTLoo0I6Alol1TI7ZoojAVool0=go08?5ood0POn1
om[oo021oh7of_ol0:7oo97@o`6ATO?o0I6Aj_l1TI6Koo`0XOom087oPOoJoo`0
POn1om[oo02QoobAd?l1TI7co`6ATN[o0I6AVool0:7oo@21oh7of_ol087oPOoJ
oo`0XOolTM3o0I6Alol1TI7Zo`6ATI_oo03Mo`20aOom087oPOoJoo`0POn1om[o
o02OoofAd?l1TI7co`6ATN_ooY6Loo`0XOom087oPOoJoo`0POn1om[oo02OoofA
d?l1TI7co`6ATN_ooY6Loo`0XOom087oPOoJoo`0POn1om[oo02OoofAd?l1TI7c
o`6ATN_ooY6Loo`0gOl0P<Goo@21oh7of_ol087oPOoJoo`0WOomTM7o0I6Alol0
TN[o0I6AW?ol0:7oo@21oh7of_ol087oPOoJoo`0WOomTM7o0I6Alol0TN[o0I6A
W?ol0:7oo@21oh7of_ol087oPOoJoo`0WOomTM7o0I6Alol0TN[o0I6AW?ol0=go
08?5ood0POn1om[oo021oh7of_ol09coo97Bo`6ATOCo0I6Ajol1TI6Loo`0XOom
087oPOoJoo`0POn1om[oo02LoobAd_l1TI7do`6ATN_o0I6AW?ol0:7oo@21oh7o
f_ol087oPOoJoo`0W?olTM;o0I6Am?l1TI7[o`6ATIcoo03Mo`20aOom087oPOoJ
oo`0POn1om[oo02JoobAdol1TI7do`6ATNcooY6Moo`0XOom087oPOoJoo`0POn1
om[oo02JoobAdol1TI7do`6ATNcooY6Moo`0XOom087oPOoJoo`0POn1om[oo02J
oobAdol1TI7do`6ATNcooY6Moo`0gOl0PlGoo@21oh7of_ol087oPOoJoo`0V?om
TM?o0I6Am?l1TI7/o`6ATIgoo02Qood0POn1om[oo021oh7of_ol09SooI7Co`6A
TOCo0I6Ak?l1TI6Moo`0XOom087oPOoJoo`0POn1om[oo02HoofAdol1TI7do`6A
TNco0I6AWOol0=go07g5ood0POn1om[oo021oh7of_ol09KooI7Do`6ATOCo097/
oojAW_ol0:7oo@21oh7of_ol087oPOoJoo`0U_omTMCo0I6Am?l0TNcooY6Noo`0
XOom087oPOoJoo`0POn1om[oo02FoofAe?l1TI7do`2Ak?onTIkoo03Mo`23aOom
087oPOoJoo`0POn1om[oo02EoobAeOl1TI7eo`6ATNco0I6AW_ol0:7oo@21oh7o
f_ol087oPOoJoo`0UOolTMGo0I6AmOl1TI7/o`6ATIkoo02Qood0POn1om[oo021
oh7of_ol09Goo97Eo`6ATOGo0I6Ak?l1TI6Noo`0gOl0P<Goo@21oh7of_ol087o
POoJoo`0ToolTMKo0I6AmOl1TI7]oojAWool0:7oo@21oh7of_ol087oPOoJoo`0
ToolTMKo0I6AmOl1TI7]oojAWool0:7oo@21oh7of_ol087oPOoJoo`0ToolTMKo
0I6AmOl1TI7]oojAWool0=go08?5ood0POn1om[oo021oh7of_ol097ooI7Fo`6A
TOGo0I6AkOl1TI6Ooo`0XOom087oPOoJoo`0POn1om[oo02AoofAe_l1TI7eo`6A
TNgo0I6AWool0:7oo@21oh7of_ol087oPOoJoo`0TOomTMKo0I6AmOl1TI7]o`6A
TIooo03Mo`20aOom087oPOoJoo`0POn1om[oo02?oofAeol1TI7eo`2AkOl1TI6O
oo`0XOom087oPOoJoo`0POn1om[oo02?oofAeol1TI7eo`2AkOl1TI6Ooo`0XOom
087oPOoJoo`0POn1om[oo02?oofAeol1TI7eo`2AkOl1TI6Ooo`0gOl0P<Goo@21
oh7of_ol087oPOoJoo`0S_olTMSo0I6Am_l1TI7^oojAX?ol0:7oo@21oh7of_ol
087oPOoJoo`0S_olTMSo0I6Am_l1TI7^oojAX?ol0:7oo@21oh7of_ol087oPOoJ
oo`0S_olTMSo0I6Am_l1TI7^oojAX?ol0=go08?5ood0POn1om[oo021oh7of_ol
08cooI7Ho`6ATOKo0I6Ak_l1TI6Poo`0XOom087oPOoJoo`0POn1om[oo02<oofA
f?l1TI7fo`6ATNko0I6AX?ol0:7oo@21oh7of_ol087oPOoJoo`0S?omTMSo0I6A
m_l1TI7^o`6ATJ3oo03Mo`20aOom087oPOoJoo`0POn1om[oo02:oofAfOl1TI7f
o`6ATNoooY6Qoo`0XOom087oPOoJoo`0POn1om[oo02:oofAfOl1TI7fo`6ATNoo
oY6Qoo`0XOom087oPOoJoo`0POn1om[oo02:oofAfOl1TI7fo`6ATNoooY6Qoo`0
gOl0P<Goo@21oh7of_ol087oPOoJoo`0ROolTM[o0I6Am_l0TNko0I6AXOol0:7o
o@21oh7of_ol087oPOoJoo`0ROolTM[o0I6Am_l0TNko0I6AXOol0:7oo@21oh7o
f_ol087oPOoJoo`0ROolTM[o0I6Am_l0TNko0I6AXOol0=go0835ood0POn1om[o
o021oh7of_ol08Ooo97Ko`6ATOOo0I6AkoonTJ;oo02Qood0POn1om[oo021oh7o
f_ol08Ooo97Ko`6ATOOo0I6AkoonTJ;oo02Qood0POn1om[oo021oh7of_ol08Oo
o97Ko`6ATOOo0I6AkoonTJ;oo03Mo`23aOom087oPOoJoo`0POn1om[oo025oofA
fol1TI7go`6ATNoo0I6AX_ol0:7oo@21oh7of_ol087oPOoJoo`0QOomTM_o0I6A
mol1TI7_o`6ATJ;oo02Qood0POn1om[oo021oh7of_ol08GooI7Ko`6ATOOo0I6A
kol1TI6Roo`0gOl0ROgobJ[m087oPOoJoo`0POn1om[oo023oofAg?l1TI7go`6A
TO3o0I6AX_ol0=WobJ[m087oPOoJoo`0POn1om[oo023oofAg?l1TI7go`6ATO3o
0I6AX_ol0=WobJ[m087oPOoJoo`0POn1om[oo023oofAg?l1TI7go`6ATO3o0I6A
X_ol0=go06WmolVZP@210840P@210:H0o97M006ATOL0097`0?jAP@3j0?gobJZ1
0840P@210840YP3lTMd00I6Am`00TO00oY610?X0oOo9ZX40P@210840P@2V0?bA
g@01TI7g002Al03nTH40nP00KogobJZ10840P@210840Y03lTMh00I6An001TI7`
006ATH40nP3molVZP@210840P@210:@0o97N006ATOP00I6Al001TI610?X0oOo9
ZX40P@210840P@2T0?bAgP01TI7h006ATO000I6AP@3j001/oOo9ZX40P@210840
P@2R0?fAgP01TI7h006ATO40oY610?/0oOo9ZX40P@210840P@2R0?fAgP01TI7h
006ATO40oY610?/0oOo9ZX40P@210840P@2R0?fAgP01TI7h006ATO40oY610?/0
06K5oh40P@210840P@2P0?fAg`01TI7h002Al001TI610?/0aOn10840P@210840
X03mTMl00I6An000TO000I6AP@3k0<GoP@210840P@210:00oI7O006ATOP0097`
006ATH40n`00I/GoP@210840P@2109l0o97P006ATOT00I6Al@3nTH40o035oh40
P@210840P@2O0?bAh001TI7i006ATO40oY610?`0aOn10840P@210840W`3lTN00
0I6An@01TI7a0?jAP@3l0029aOom087oPOoJoo`0POn1om[oo021ooWooI7Po`6A
TOWo0I6AlOl1TI6Uoo`0XOom087oPOoJoo`0POn1om[oo021ooWooI7Po`6ATOWo
0I6AlOl1TI6Uoo`0XOom087oPOoJoo`0POn1om[oo021ooWooI7Po`6ATOWo0I6A
lOl1TI6Uoo`0gOl0RLGoo@21oh7of_ol087oPOoJoo`0POogoofAhOl1TI7io`6A
TO;o0I6AYOol0:7oo@21oh7of_ol087oPOoJoo`0POogoofAhOl1TI7io`6ATO;o
0I6AYOol0:7oo@21oh7of_ol087oPOoJoo`0POogoofAhOl1TI7io`6ATO;o0I6A
YOol0=go08?5ood0POn1om[oo021oh7of_ol087om_olTN;o0I6AnOl0TO;ooY6V
oo`0XOom087oPOoJoo`0POn1om[oo021ooKoo97Ro`6ATOWo097boojAY_ol0:7o
o@21oh7of_ol087oPOoJoo`0POofoobAh_l1TI7io`2Al_onTJKoo03Mo`29aOom
087oPOoJoo`0POn1om[oo021ooCoo97So`6ATO[o0I6Al_l1TI6Voo`0XOom087o
POoJoo`0POn1om[oo021ooCoo97So`6ATO[o0I6Al_l1TI6Voo`0XOom087oPOoJ
oo`0POn1om[oo021ooCoo97So`6ATO[o0I6Al_l1TI6Voo`0gOl0Q/Goo@21oh7o
f_ol087oPOoJoo`0POoboofAhol1TI7jo`6ATO?ooY6Woo`0XOom087oPOoJoo`0
POn1om[oo021oo;ooI7So`6ATO[o0I6AloonTJOoo02Qood0POn1om[oo021oh7o
f_ol087ol_omTN?o0I6An_l1TI7coojAYool0=go08W5ood0POn1om[oo021oh7o
f_ol087ol?omTNCo0I6An_l1TI7co`6ATJOoo02Qood0POn1om[oo021oh7of_ol
087ol?omTNCo0I6An_l1TI7co`6ATJOoo02Qood0POn1om[oo021oh7of_ol087o
l?omTNCo0I6An_l1TI7co`6ATJOoo03Mo`23aOom087oPOoJoo`0POn1om[oo021
onooo97Uo`6ATO[o097coojAZ?ol0:7oo@21oh7of_ol087oPOoJoo`0POo_oobA
iOl1TI7jo`2AloonTJSoo02Qood0POn1om[oo021oh7of_ol087okoolTNGo0I6A
n_l0TO?ooY6Xoo`0gOl0RLGoo@21oh7of_ol087oPOoJoo`0POo]oobAi_l1TI7k
o`6ATO?o0I6AZ?ol0:7oo@21oh7of_ol087oPOoJoo`0POo]oobAi_l1TI7ko`6A
TO?o0I6AZ?ol0:7oo@21oh7of_ol087oPOoJoo`0POo]oobAi_l1TI7ko`6ATO?o
0I6AZ?ol0=go08W5ood0POn1om[oo021oh7of_ol087ojoomTNKo0I6Anol1TI7d
o`6ATJSoo02Qood0POn1om[oo021oh7of_ol087ojoomTNKo0I6Anol1TI7do`6A
TJSoo02Qood0POn1om[oo021oh7of_ol087ojoomTNKo0I6Anol1TI7do`6ATJSo
o03Mo`26aOom087oPOoJoo`0POn1om[oo021onWooI7Wo`6ATO_o0I6AmOonTJWo
o02Qood0POn1om[oo021oh7of_ol087ojOomTNOo0I6Anol1TI7eoojAZOol0:7o
o@21oh7of_ol087oPOoJoo`0POoYoofAiol1TI7ko`6ATOGooY6Yoo`0gOl0W/Go
o@3Zooh0POn1ooCoo021oh7of_ol0>cooP21o`3oo97Xo`6ATO_o097do`6ATJWo
o02Qood0j_on087oPOodoo`0POn1om[oo03/ooh0POl0oobAj?l1TI7ko`2Am?l1
TI6Yoo`0XOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087o0?olTNSo0I6Anol0
TOCo0I6AZOol0=go0:[5ood0j_on087oPOodoo`0POn1om[oo03/ooh0POonoofA
j?l1TI7lo`6ATOGooY7Goo@0hOol0:7oo@3Zooh0POn1ooCoo021oh7of_ol0>co
oP21ookooI7Xo`6ATOco0I6AmOonTMOom03Qoo`0XOom0>[ooP21oh7om?ol087o
POoJoo`0k?on087oo_omTNSo0I6Ao?l1TI7eoojAeood0>7oo03Mo`2]aOom0>[o
oP21oh7om?ol087oPOoJoo`0k?on087oo?omTNWo0I6Ao?l1TI7eo`6ATMOolP3S
oo`0XOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087oo?omTNWo0I6Ao?l1TI7e
o`6ATMOolP3Soo`0XOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087oo?omTNWo
0I6Ao?l1TI7eo`6ATMOolP3Soo`0gOl0Z/Goo@3Zooh0POn1ooCoo021oh7of_ol
0>cooP21oo_oo97Zo`6ATOco0I6Am_onTMSol@3Too`0XOom0>[ooP21oh7om?ol
087oPOoJoo`0k?on087onoolTN[o0I6Ao?l1TI7foojAf?oa0>Coo02Qood0j_on
087oPOodoo`0POn1om[oo03/ooh0POokoobAj_l1TI7lo`6ATOKooY7Hoo40i?ol
0=go0;?5ood0j_on087oPOodoo`0POn1om[oo03/ooh0POoioobAk?onTOco097e
o`6ATMSooP3hoo`0iOol0:7oo@3Zooh0POn1ooCoo021oh7of_ol0>cooP21ooWo
o97/oojAo?l0TOGo0I6Af?on0?Soo03Uoo`0XOom0>[ooP21oh7om?ol087oPOoJ
oo`0k?on087onOolTNcooY7lo`2AmOl1TI7Hooh0n?ol0>Goo03Mo`2faOom0>[o
oP21oh7om?ol087oPOoJoo`0k?on087omoomTNcooY7mo`6ATOKo0I6Af?on0?Ko
oP3Uoo`0XOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087omoomTNcooY7mo`6A
TOKo0I6Af?on0?KooP3Uoo`0XOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087o
moomTNcooY7mo`6ATOKo0I6Af?on0?KooP3Uoo`0gOl0/lGoo@3Zooh0POn1ooCo
o021oh7of_ol0>cooP21ooGooI7]oojAoOl1TI7goojAfOon0?Koo@3Voo`0XOom
0>[ooP21oh7om?ol087oPOoJoo`0k?on087omOomTNgooY7mo`6ATOOooY7Iooh0
m_om0>Koo02Qood0j_on087oPOodoo`0POn1om[oo03/ooh0POoeoofAkOonTOgo
0I6AmoonTMWooP3food0i_ol0=go0;K5ood0j_on087oPOodoo`0POn1om[oo03/
ooh0POodoobAk_onTOgo0I6Amol1TI7Iooh0mOon0>Koo02Qood0j_on087oPOod
oo`0POn1om[oo03/ooh0POodoobAk_onTOgo0I6Amol1TI7Iooh0mOon0>Koo02Q
ood0j_on087oPOodoo`0POn1om[oo03/ooh0POodoobAk_onTOgo0I6Amol1TI7I
ooh0mOon0>Koo03Mo`38aOom0>[ooP21oh7om?ol0?KomP21oh7ol?ol0>cooP21
oo;oo97_oojAoOl0TOOooY7Jooh0mOon0>Koo03fooH0]oom0>[ooP21oh7om?ol
0?KomP21oh7ol?ol0>cooP21oo;oo97_oojAoOl0TOOooY7Jooh0mOon0>Koo03f
ooH0]oom0>[ooP21oh7om?ol0?KomP21oh7ol?ol0>cooP21oo;oo97_oojAoOl0
TOOooY7Jooh0mOon0>Koo03fooH0lol0c/Goo@3con`0POn1oogoo03fooH0POn1
oo3oo03eon`0POoioofAkoonTOko0I6Amol1TI7Jooh0mOon0>Koo03fooH0]oom
0??ok021oh7ooOol0?KomP21oh7ol?ol0?Gok021ooWooI7_oojAo_l1TI7go`6A
TM[ooP3eooh0i_ol0?KomP2good0loo/087oPOomoo`0m_of087oPOo`oo`0mOo/
087onOomTNoooY7no`6ATOOo0I6Af_on0?GooP3Voo`0m_of0??o0<k5ood0loo/
087oPOomoo`0m_of087oPOo`oo`0mOo/087omoomTO3o0I6AoOl1TI7hoojAfoon
0?GooP3Voo`0m_of0;Ooo@3con`0POn1oogoo03fooH0POn1oo3oo03eon`0POog
oofAl?l1TI7mo`6ATOSooY7Kooh0mOon0>Koo03fooH0]oom0??ok021oh7ooOol
0?KomP21oh7ol?ol0?Gok021ooOooI7`o`6ATOgo0I6An?onTM_ooP3eooh0i_ol
0?KomP3co`2iaOom0??ok021oh7ooOol087oPOoJoo`0mOo/087om_olTO7o0I6A
oOl1TI7ho`6ATM_ooP3food0i_ol0:7oo@3con`0POn1oogoo021oh7of_ol0?Go
k021ooKoo97ao`6ATOgo0I6An?l1TI7Kooh0m_om0>Koo02Qood0loo/087oPOom
oo`0POn1om[oo03eon`0POofoobAlOl1TI7mo`6ATOSo0I6Afoon0?Koo@3Voo`0
gOl0]/Goo@3Zooh0POn1ooCoo021oh7of_ol0>cooP21on_ooI7ao`6ATOgo097h
o`6ATM_ooP3fooh0iOol0:7oo@3Zooh0POn1ooCoo021oh7of_ol0>cooP21on_o
oI7ao`6ATOgo097ho`6ATM_ooP3fooh0iOol0:7oo@3Zooh0POn1ooCoo021oh7o
f_ol0>cooP21on_ooI7ao`6ATOgo097ho`6ATM_ooP3fooh0iOol0=go0;K5ood0
j_on087oPOodoo`0POn1om[oo03/ooh0POoYoofAl_l1TI7no`6ATOWooY7Looh0
moom0>Goo02Qood0j_on087oPOodoo`0POn1om[oo03/ooh0POoYoofAl_l1TI7n
o`6ATOWooY7Looh0moom0>Goo02Qood0j_on087oPOodoo`0POn1om[oo03/ooh0
POoYoofAl_l1TI7no`6ATOWooY7Looh0moom0>Goo03Mo`2iaOom0>[ooP21oh7o
m?ol087oPOoJoo`0k?on087oj?olTO?o0I6Ao_l1TI7io`6ATMcooP3ioo`0i?ol
0:7oo@3Zooh0POn1ooCoo021oh7of_ol0>cooP21onSoo97co`6ATOko0I6AnOl1
TI7Looh0nOol0>Coo02Qood0j_on087oPOodoo`0POn1om[oo03/ooh0POoXoobA
lol1TI7no`6ATOWo0I6Ag?on0?Woo03Too`0gOl0Z/Goo@3Zooh0POn1ooCoo021
oh7of_ol0>cooP21onKoo97do`6ATOko0I6An_onTMgolP3Soo`0XOom0>[ooP21
oh7om?ol087oPOoJoo`0k?on087oi_olTOCo0I6Ao_l1TI7joojAgOob0>?oo02Q
ood0j_on087oPOodoo`0POn1om[oo03/ooh0POoVoobAm?l1TI7no`6ATO[ooY7M
oo80hool0=go0:[5ood0j_on087oPOodoo`0POn1om[oo03/ooh0POoToofAm?l1
TI7no`2AnOl1TI7Moo<0h_ol0:7oo@3Zooh0POn1ooCoo021oh7of_ol0>cooP21
onCooI7do`6ATOko097io`6ATMgol`3Roo`0XOom0>[ooP21oh7om?ol087oPOoJ
oo`0k?on087oi?omTOCo0I6Ao_l0TOWo0I6AgOoc0>;oo03Mo`2iaOom0>[ooP21
oh7om?ol087oPOoJoo`0k?on0:Woo@3good0c?omTOGo1I6AoonATO[ooY7NooH0
gool0:7oo@3Zooh0POn1ooCoo021oh7of_ol0>cooP2Yood0moom0<cooI7eo`FA
TOooTI7joojAg_of0=ooo02Qood0j_on087oPOodoo`0POn1om[oo03/ooh0ZOom
0?Ooo@3<oofAmOl5TI7ooi6An_onTMkomP3Ooo`0gOl0_<Goo@3Zooh0POn1ooCo
o021oh7of_ol0>cooP2Xood0nOom0<[oo97fo`FATOooTI7jo`6ATMkooP3Goo`0
XOom0>[ooP21oh7om?ol087oPOoJoo`0k?on0:Soo@3iood0b_olTOKo1I6AoonA
TO[o0I6Ag_on0=Ooo02Qood0j_on087oPOodoo`0POn1om[oo03/ooh0Z?om0?Wo
o@3:oobAm_l5TI7ooi6An_l1TI7Nooh0eool0=go0;c5ood0j_on087oPOodoo`0
POn1om[oo03/ooh0Yoon0?WooP37oofAm_l5TI7ooi6Anol1TI7Nooh0eool0:7o
o@3Zooh0POn1ooCoo021oh7of_ol0>cooP2Wooh0nOon0<OooI7fo`FATOooTI7k
o`6ATMkooP3Goo`0XOom0>[ooP21oh7om?ol087oPOoJoo`0k?on0:OooP3iooh0
aoomTOKo1I6AoonATO_o0I6Ag_on0=Ooo03Mo`2faOom0>[ooP21oh7om?ol087o
POoJoo`0k?on0:KooP3kooh0a?omTOOo196AoonAnoonTMoooP3Goo`0XOom0>[o
oP21oh7om?ol087oPOoJoo`0k?on0:KooP3kooh0a?omTOOo196AoonAnoonTMoo
oP3Goo`0XOom0>[ooP21oh7om?ol087oPOoJoo`0k?on0:KooP3kooh0a?omTOOo
196AoonAnoonTMoooP3Goo`0gOl0XLGoo@21oh7of_ol087oPOoJoo`0S_om0?go
o@33oobAn?l4TI7oTI7ko`6ATMoooP3Goo`0XOom087oPOoJoo`0POn1om[oo02>
ood0oOom0<?oo97ho`BATOnATO_o0I6Agoon0=Ooo02Qood0POn1om[oo021oh7o
f_ol08koo@3mood0`oolTOSo196Aoi6Anol1TI7Oooh0eool0=go09k5ood0POn1
om[oo021oh7of_ol08gooP3mooh0`?olTOWo196Aoi6Ao?onTN3ooP3Goo`0XOom
087oPOoJoo`0POn1om[oo02=ooh0oOon0<3oo97io`BATOnATOcooY7Pooh0eool
0:7oo@21oh7of_ol087oPOoJoo`0SOon0?gooP30oobAnOl4TI7oTI7loojAh?on
0=Ooo03Mo`2TaOom087oPOoJoo`0POn1om[oo02<ooh00OoooP2moofAnOl4TI7o
TI7lo`6ATN3ooP3Goo`0XOom087oPOoJoo`0POn1om[oo02<ooh00OoooP2moofA
nOl4TI7oTI7lo`6ATN3ooP3Goo`0XOom087oPOoJoo`0POn1om[oo02<ooh00Ooo
oP2moofAnOl4TI7oTI7lo`6ATN3ooP3Goo`0gOl0VlGoo@21oh7of_ol087oPOoJ
oo`0S?oi0;_ooI7jo`>ATOnAo?onTOco003Wooh0eool0:7oo@21oh7of_ol087o
POoJoo`0S?oi0;_ooI7jo`>ATOnAo?onTOco003Wooh0eool0:7oo@21oh7of_ol
087oPOoJoo`0S?oi0;_ooI7jo`>ATOnAo?onTOco003Wooh0eool0=go08K5ood0
POn1om[oo021oh7of_ol08_on`2ioobAnoomTOcolP3^ooh0eool0:7oo@21oh7o
f_ol087oPOoJoo`0Rook0;Woo97koofAo?ob0>kooP3Goo`0XOom087oPOoJoo`0
POn1om[oo02;oo/0^OolTO_ooI7loo80k_on0=Ooo03Mo`26aOom087oPOoJoo`0
POn1om[oo02:ood0]_olTOcooI7moo80k_on0=Ooo02Qood0POn1om[oo021oh7o
f_ol08[oo@2foobAo?omTOgolP3^ooh0eool0:7oo@21oh7of_ol087oPOoJoo`0
R_om0;Koo97loofAoOob0>kooP3Goo`0gOl0Q/Goo@21oh7of_ol087oPOoJoo`0
R_om0;CooI7loofA0?o^0?3ooP3Goo`0XOom087oPOoJoo`0POn1om[oo02:ood0
]?omTOcooI40onh0l?on0=Ooo02Qood0POn1om[oo021oh7of_ol08[oo@2doofA
o?omT@3okP3`ooh0eool0=go0835ood0POn1om[oo021oh7of_ol08_on`2coofA
oOonTN/0l_on0=Ooo02Qood0POn1om[oo021oh7of_ol08_on`2coofAoOonTN/0
l_on0=Ooo02Qood0POn1om[oo021oh7of_ol08_on`2coofAoOonTN/0l_on0=Oo
o03Mo`1aaOom087oPOoJoo`0POn1om[oo02<ooT0/oolT@7oonH0aool0:7oo@21
oh7of_ol087oPOoJoo`0S?oi0;?oo941oooV0<Ooo02Qood0POn1om[oo021oh7o
f_ol08con@2coobA0OooiP37oo`0gOl0OLGoo@21oh7of_ol087oPOoJoo`0S?on
007oooh0/OomT@3oiP37oo`0XOom087oPOoJoo`0POn1om[oo02<ooh00OoooP2a
oofA0?oV0<Ooo02Qood0POn1om[oo021oh7of_ol08cooP01ooon0;7ooI40onH0
aool0=go07O5ood0POn1om[oo021oh7of_ol08gooP3mooh0/?l1TI7T0<Soo02Q
ood0POn1om[oo021oh7of_ol08gooP3mooh0/?l1TI7T0<Soo02Qood0POn1om[o
o021oh7of_ol08gooP3mooh0/?l1TI7T0<Soo03Mo`1^aOom087oPOoJoo`0POn1
om[oo02>ood0oOom0;3ohP39oo`0XOom087oPOoJoo`0POn1om[oo02>ood0oOom
0;3ohP39oo`0XOom087oPOoJoo`0POn1om[oo02>ood0oOom0;3ohP39oo`0gOl0
K/Goo@21oh7of_ol087oPOoJoo`0S_on0?_ooP2`on40b_ol0:7oo@21oh7of_ol
087oPOoJoo`0S_on0?_ooP2`on40b_ol0:7oo@21oh7of_ol087oPOoJoo`0S_on
0?_ooP2`on40b_ol0=go06k5ood0POn1om[oo021oh7of_ol08oooP3iooh0/_oP
0<[oo02Qood0POn1om[oo021oh7of_ol08oooP3iooh0/_oP0<[oo02Qood0POn1
om[oo021oh7of_ol08oooP3iooh0/_oP0<[oo03Mo`1^aOom087oPOoJoo`0POn1
om[oo02@ood0nOom0;CogP3;oo`0XOom087oPOoJoo`0POn1om[oo02@ood0nOom
0;CogP3;oo`0XOom087oPOoJoo`0POn1om[oo02@ood0nOom0;CogP3;oo`0gOl0
K/Goo@21oh7of_ol087oPOoJoo`0TOom0?Ooo@2eomh0bool0:7oo@21oh7of_ol
087oPOoJoo`0TOom0?Ooo@2eomh0bool0:7oo@21oh7of_ol087oPOoJoo`0TOom
0?Ooo@2eomh0bool0=go05c5ood0POn1om[oo021oh7of_ol087o/ooN0<_oo02Q
ood0POn1om[oo021oh7of_ol087o/ooN0<_oo02Qood0POn1om[oo021oh7of_ol
087o/ooN0<_oo03Mo`1LaOom087oPOoJoo`0POn1om[oo021ok?ogP3;oo`0XOom
087oPOoJoo`0POn1om[oo021ok?ogP3;oo`0XOom087oPOoJoo`0POn1om[oo021
ok?ogP3;oo`0gOl0G<Goo@21oh7of_ol087oPOoJoo`0POncomd0c?ol0:7oo@21
oh7of_ol087oPOoJoo`0POncomd0c?ol0:7oo@21oh7of_ol087oPOoJoo`0POnc
omd0c?ol0=go05c5ood0POn1om[oo021oh7of_ol087o]?oL0<coo02Qood0POn1
om[oo021oh7of_ol087o]?oL0<coo02Qood0POn1om[oo021oh7of_ol087o]?oL
0<coo03Mo`1LaOom087oPOoJoo`0POn1om[oo021okCog03<oo`0XOom087oPOoJ
oo`0POn1om[oo021okCog03<oo`0XOom087oPOoJoo`0POn1om[oo021okCog03<
oo`0gOl1M/Goo@21oh7of_ol087oPOoJoo/0oOom0?goo@3lood0oOom0?goo@3l
ood0oOom0?goo@3lood0oOom0?goo@3lood0oOom0?goo@3lood0oOom0?goo@3l
ood0oOom0?goo@3lood0oOom0?goo@3lood0oOoL0<coo02Qood0POn1om[oo021
oh7of_ok0?goo@3mood0o?om0?goo@3mood0o?om0?goo@3mood0o?om0?goo@3m
ood0o?om0?goo@3mood0o?om0?goo@3mood0o?om0?goo@3mood0o?om0?goo@3m
ood0o?om0?gog03<oo`0XOom087oPOoJoo`0POn1om[on`3mood0oOom0?coo@3m
ood0oOom0?coo@3mood0oOom0?coo@3mood0oOom0?coo@3mood0oOom0?coo@3m
ood0oOom0?coo@3mood0oOom0?coo@3mood0oOom0?coo@3mom`0c?ol0=go0GK5
ood0POn1om[oo021oh7of_ok0?goo@3mood0o?om0?goo@3mood0o?om0?goo@3m
ood0o?om0?goo@3mood0o?om0?goo@3mood0o?om0?goo@3mood0o?om0?goo@3m
ood0o?om0?goo@3mood0o?om0?gog03<oo`0XOom087oPOoJoo`0POn1om[on`3m
ood0oOom0?coo@3mood0oOom0?coo@3mood0oOom0?coo@3mood0oOom0?coo@3m
ood0oOom0?coo@3mood0oOom0?coo@3mood0oOom0?coo@3mood0oOom0?coo@3m
om`0c?ol0:7oo@21oh7of_ol087oPOoJoo/0oOom0?goo@3lood0oOom0?goo@3l
ood0oOom0?goo@3lood0oOom0?goo@3lood0oOom0?goo@3lood0oOom0?goo@3l
ood0oOom0?goo@3lood0oOom0?goo@3lood0oOoL0<coo03Mo`5faOom087oPOoJ
oo`0POn1om[on`3mood0oOom0?coo@3mood0oOom0?coo@3mood0oOom0?coo@3m
ood0oOom0?coo@3mood0oOom0?coo@3mood0oOom0?coo@3mood0oOom0?coo@3m
ood0oOom0?coo@3mom`0c?ol0:7oo@21oh7of_ol087oPOoJoo/0oOom0?goo@3l
ood0oOom0?goo@3lood0oOom0?goo@3lood0oOom0?goo@3lood0oOom0?goo@3l
ood0oOom0?goo@3lood0oOom0?goo@3lood0oOom0?goo@3lood0oOoL0<coo02Q
ood0POn1om[oo021oh7of_ok0?goo@3mood0o?om0?goo@3mood0o?om0?goo@3m
ood0o?om0?goo@3mood0o?om0?goo@3mood0o?om0?goo@3mood0o?om0?goo@3m
ood0o?om0?goo@3mood0o?om0?gog03<oo`0gOl1M/Goo@21oh7of_ol087oPOoJ
oo/0oOom0?goo@3lood0oOom0?goo@3lood0oOom0?goo@3lood0oOom0?goo@3l
ood0oOom0?goo@3lood0oOom0?goo@3lood0oOom0?goo@3lood0oOom0?goo@3l
ood0oOoL0<coo02Qood0POn1om[oo021oh7of_ok0?goo@3mood0o?om0?goo@3m
ood0o?om0?goo@3mood0o?om0?goo@3mood0o?om0?goo@3mood0o?om0?goo@3m
ood0o?om0?goo@3mood0o?om0?goo@3mood0o?om0?gog03<oo`0XOom087oPOoJ
oo`0POn1om[on`3mood0oOom0?coo@3mood0oOom0?coo@3mood0oOom0?coo@3m
ood0oOom0?coo@3mood0oOom0?coo@3mood0oOom0?coo@3mood0oOom0?coo@3m
ood0oOom0?coo@3mom`0c?ol0=go05c5ood0POn1om[oo021oh7of_ol087o/ooM
0<coo02Qood0POn1om[oo021oh7of_ol087o/ooM0<coo02Qood0POn1om[oo021
oh7of_ol087o/ooM0<coo03Mo`1LaOom087oPOoJoo`0POn1om[oo021ok?ogP3;
oo`0XOom087oPOoJoo`0POn1om[oo021ok?ogP3;oo`0XOom087oPOoJoo`0POn1
om[oo021ok?ogP3;oo`0gOl0G<Goo@21oh7of_ol087oPOoJoo`0POncomh0bool
0:7oo@21oh7of_ol087oPOoJoo`0POncomh0bool0:7oo@21oh7of_ol087oPOoJ
oo`0POncomh0bool0=go05c5ood0POn1om[oo021oh7of_ol087o/ooN0<_oo02Q
ood0POn1om[oo021oh7of_ol087o/ooN0<_oo02Qood0POn1om[oo021oh7of_ol
087o/ooN0<_oo03Mo`1LaOom087oPOoJoo`0POn1om[oo021ok?ogP3;oo`0XOom
087oPOoJoo`0POn1om[oo021ok?ogP3;oo`0XOom087oPOoJoo`0POn1om[oo021
ok?ogP3;oo`0gOl0G<Goo@21oh7of_ol087oPOoJoo`0POnbon00b_ol0:7oo@21
oh7of_ol087oPOoJoo`0POnbon00b_ol0:7oo@21oh7of_ol087oPOoJoo`0POnb
on00b_ol0=go05c5ood0POn1om[oo021oh7of_ol087o/_oP0<[oo02Qood0POn1
om[oo021oh7of_ol087o/_oP0<[oo02Qood0POn1om[oo021oh7of_ol087o/_oP
0<[oo03Mo`1LaOom087oPOoJoo`0POn1om[oo021ok7ohP39oo`0XOom087oPOoJ
oo`0POn1om[oo021ok7ohP39oo`0XOom087oPOoJoo`0POn1om[oo021ok7ohP39
oo`0gOl0G<Goo@21oh7of_ol087oPOoJoo`0POn`on@0b?ol0:7oo@21oh7of_ol
087oPOoJoo`0POn`on@0b?ol0:7oo@21oh7of_ol087oPOoJoo`0POn`on@0b?ol
0=go05c5ood0POn1om[oo021oh7of_ol087o/?oT0<Soo02Qood0POn1om[oo021
oh7of_ol087o/?oT0<Soo02Qood0POn1om[oo021oh7of_ol087o/?oT0<Soo03M
o`1LaOom087oPOoJoo`0POn1om[oo021ojkoj036oo`0XOom087oPOoJoo`0POn1
om[oo021ojkoj036oo`0XOom087oPOoJoo`0POn1om[oo021ojkoj036oo`0gOl0
G<Goo@21oh7of_ol087oPOoJoo`0POn]onX0aOol0:7oo@21oh7of_ol087oPOoJ
oo`0POn]onX0aOol0:7oo@21oh7of_ol087oPOoJoo`0POn]onX0aOol0=go05c5
ood0POn1om[oo021oh7of_ol087oZoo]0<Coo02Qood0POn1om[oo021oh7of_ol
087oZoo]0<Coo02Qood0POn1om[oo021oh7of_ol087oZoo]0<Coo03Mo`1LaOom
087oPOoJoo`0POn1om[oo021oj[ol032oo`0XOom087oPOoJoo`0POn1om[oo021
oj[ol032oo`0XOom087oPOoJoo`0POn1om[oo021oj[ol032oo`0gOl0G<Goo@21
oh7of_ol087oPOoJoo`0POnXoo@0`?ol0:7oo@21oh7of_ol087oPOoJoo`0POnX
oo@0`?ol0:7oo@21oh7of_ol087oPOoJoo`0POnXoo@0`?ol0=go05c5ood0POn1
om[oo021oh7of_ol087oY?om0;_oo02Qood0POn1om[oo021oh7of_ol087oY?om
0;_oo02Qood0POn1om[oo021oh7of_ol087oY?om0;_oo03Mo`1LaOom087oPOoJ
oo`0POn1om[oo021ojCoo@2koo`0XOom087oPOoJoo`0POn1om[oo021ojCoo@2k
oo`0XOom087oPOoJoo`0POn1om[oo021ojCoo@2koo`0gOl0G<Goo@21oh7of_ol
087oPOoJoo`0POnTood0^ool0:7oo@21oh7of_ol087oPOoJoo`0POnTood0^ool
0:7oo@21oh7of_ol087oPOoJoo`0POnTood0^ool0=go05K5ood0POn1om[oo021
oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21
oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021
oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021
oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Q
ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021
oh7of_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJ
oo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03M
o`1LaOom087oPOoJoo`0POn1om[oo021ojCoo@2koo`0XOom087oPOoJoo`0POn1
om[oo021ojCoo@2koo`0XOom087oPOoJoo`0POn1om[oo021ojCoo@2koo`0gOl0
G<Goo@21oh7of_ol087oPOoJoo`0POnTood0^ool0:7oo@21oh7of_ol087oPOoJ
oo`0POnTood0^ool0:7oo@21oh7of_ol087oPOoJoo`0POnTood0^ool0=go05c5
ood0POn1om[oo021oh7of_ol087oY?om0;_oo02Qood0POn1om[oo021oh7of_ol
087oY?om0;_oo02Qood0POn1om[oo021oh7of_ol087oY?om0;_oo03Mo`1LaOom
087oPOoJoo`0POn1om[oo021ojCoo@2koo`0XOom087oPOoJoo`0POn1om[oo021
ojCoo@2koo`0XOom087oPOoJoo`0POn1om[oo021ojCoo@2koo`0gOl0E/Goo@21
oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJ
oo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021
oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21
oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021
oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021
oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Q
ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021
oh7of_ol0=go05c5ood0POn1om[oo021oh7of_ol087oY?om0;_oo02Qood0POn1
om[oo021oh7of_ol087oY?om0;_oo02Qood0POn1om[oo021oh7of_ol087oY?om
0;_oo03Mo`1LaOom087oPOoJoo`0POn1om[oo021ojCoo@2koo`0XOom087oPOoJ
oo`0POn1om[oo021ojCoo@2koo`0XOom087oPOoJoo`0POn1om[oo021ojCoo@2k
oo`0gOl0G<Goo@21oh7of_ol087oPOoJoo`0POnTood0^ool0:7oo@21oh7of_ol
087oPOoJoo`0POnTood0^ool0:7oo@21oh7of_ol087oPOoJoo`0POnTood0^ool
0=go05c5ood0POn1om[oo021oh7of_ol087oY?om0;_oo02Qood0POn1om[oo021
oh7of_ol087oY?om0;_oo02Qood0POn1om[oo021oh7of_ol087oY?om0;_oo03M
o`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJ
oo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21
oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJ
oo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021
oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21
oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021
oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021
oh7of_ol087oPOoJoo`0gOl0G<Goo@21oh7of_ol087oPOoJoo`0POnTood0^ool
0:7oo@21oh7of_ol087oPOoJoo`0POnTood0^ool0:7oo@21oh7of_ol087oPOoJ
oo`0POnTood0^ool0=go05c5ood0POn1om[oo021oh7of_ol087oY?om0;_oo02Q
ood0POn1om[oo021oh7of_ol087oY?om0;_oo02Qood0POn1om[oo021oh7of_ol
087oY?om0;_oo03Mo`1LaOom087oPOoJoo`0POn1om[oo021ojCoo@2koo`0XOom
087oPOoJoo`0POn1om[oo021ojCoo@2koo`0XOom087oPOoJoo`0POn1om[oo021
ojCoo@2koo`0gOl0G<Goo@21oh7of_ol087oPOoJoo`0POnTood0^ool0:7oo@21
oh7of_ol087oPOoJoo`0POnTood0^ool0:7oo@21oh7of_ol087oPOoJoo`0POnT
ood0^ool0=go06;5ood0POn1om[oo021oh7of_ol08OonP2Uood0^ool0:7oo@21
oh7of_ol087oPOoJoo`0Qooj0:Goo@2koo`0XOom087oPOoJoo`0POn1om[oo027
ooX0YOom0;_oo03Mo`1LaOom087oPOoJoo`0POn1om[oo029ooH0POoMoo`0XOom
087oPOoJoo`0POn1om[oo029ooH0POoMoo`0XOom087oPOoJoo`0POn1om[oo029
ooH0POoMoo`0gOl0G<Goo@21oh7of_ol087oPOoJoo`0Roob087ogool0:7oo@21
oh7of_ol087oPOoJoo`0Roob087ogool0:7oo@21oh7of_ol087oPOoJoo`0Roob
087ogool0=go06S5ood0POn1om[oo021oh7of_ol08con`3loo/0POoPoo`0XOom
087oPOoJoo`0POn1om[oo02<oo/0o?ok087oh?ol0:7oo@21oh7of_ol087oPOoJ
oo`0S?ok0?con`21on3oo03Mo`1XaOom087oPOoJoo`0POn1om[oo02<ood0n?om
087oh?ol0:7oo@21oh7of_ol087oPOoJoo`0S?om0?Soo@21on3oo02Qood0POn1
om[oo021oh7of_ol08coo@3hood0POoPoo`0gOl0K/Goo@21oh7of_ol087oPOoJ
oo`0SOom0?Koo@2[ood0^ool0:7oo@21oh7of_ol087oPOoJoo`0SOom0?Koo@2[
ood0^ool0:7oo@21oh7of_ol087oPOoJoo`0SOom0?Koo@2[ood0^ool0=go06k5
ood0POn1om[oo021oh7of_ol08koo@3dood0[?om0;_oo02Qood0POn1om[oo021
oh7of_ol08koo@3dood0[?om0;_oo02Qood0POn1om[oo021oh7of_ol08koo@3d
ood0[?om0;_oo03Mo`1^aOom087oPOoJoo`0POn1om[oo02>ooh0l_on0:coo@2k
oo`0XOom087oPOoJoo`0POn1om[oo02>ooh0l_on0:coo@2koo`0XOom087oPOoJ
oo`0POn1om[oo02>ooh0l_on0:coo@2koo`0gOl0K/Goo@21oh7of_ol087oPOoJ
oo`0S_on0?;ooP2/ood0^ool0:7oo@21oh7of_ol087oPOoJoo`0S_on0?;ooP2/
ood0^ool0:7oo@21oh7of_ol087oPOoJoo`0S_on0?;ooP2/ood0^ool0=go06S5
ood0POn1om[oo021oh7of_ol08ooo@3bood0POoSoo`0XOom087oPOoJoo`0POn1
om[oo02?ood0l_om087ohool0:7oo@21oh7of_ol087oPOoJoo`0Soom0?;oo@21
on?oo03Mo`1XaOom087oPOoJoo`0POn1om[oo02?ooh0l?on087ohool0:7oo@21
oh7of_ol087oPOoJoo`0Soon0?3ooP21on?oo02Qood0POn1om[oo021oh7of_ol
08oooP3`ooh0POoSoo`0gOl0J<Goo@21oh7of_ol087oPOoJoo`0Soon0?3ooP21
on?oo02Qood0POn1om[oo021oh7of_ol08oooP3`ooh0POoSoo`0XOom087oPOoJ
oo`0POn1om[oo02?ooh0l?on087ohool0=go06k5ood0POn1om[oo021ok;o002Z
oo`0Soon0?3ooP21on?oo02Qood0POn1om[oo021ok;o002Zoo`0Soon0?3ooP21
on?oo02Qood0POn1om[oo021ok;o002Zoo`0Soon0?3ooP21on?oo03Mo`2NaOom
0;7ol`21okSoo021okSol`2aoo`0/Ooc0>gooP3`ooh0[Oom0?GooP3dooh0f_ol
0:7oo@2aoo<0POnhoo`0POnhoo<0/Ool0;7ol`3]ooh0l?on0:goo@3eooh0m?on
0=[oo02Qood0/Ooc087o^?ol087o^?oc0;7oo02aoo<0kOon0?3ooP2]ood0mOon
0?CooP3Joo`0gOl0W/Goo@2boo40POnioo`0POnioo40/_ol0;;ol@3^ooh0l?on
0:goo@3dooh0m_on0=Woo02Qood0/_oa087o^Ool087o^Ooa0;;oo02boo40k_on
0?3ooP2]ood0m?on0?KooP3Ioo`0XOom0;;ol@21okWoo021okWol@2boo`0/_oa
0>kooP3`ooh0[Oom0?CooP3fooh0fOol0=go09k5ood0]?o]087o^ool087o^oo]
0;Coo02dond0l?on0?3ooP2]ood0m?on0?KooP3Ioo`0XOom0;Cok@21ok_oo021
ok_ok@2doo`0]?o]0?3ooP3`ooh0[Oom0?CooP3fooh0fOol0:7oo@2dond0POnk
oo`0POnkond0]?ol0;Cok@3`ooh0l?on0:goo@3dooh0m_on0=Woo03Mo`2NaOom
0;GojP21okgoo021okcojP2foo`0]OoZ0?;ooP3`ooh0[Oom0??ooP3hood0fOol
0:7oo@2eonX0POnmoo`0POnlonX0]_ol0;GojP3booh0l?on0:goo@3cooh0n?om
0=Woo02Qood0]OoZ087o_Ool087o_?oZ0;Koo02eonX0l_on0?3ooP2]ood0loon
0?Soo@3Ioo`0gOl0]/Goo@2gooL0oOoe087o__ol087o__oi0?Oon@2goo`0]oog
0?gom@3cooh0l?on09_ooP3hooh0f?ol0:7oo@2gooL0oOoe087o__ol087o__oi
0?Oon@2goo`0]oog0?gom@3cooh0l?on09_ooP3hooh0f?ol0:7oo@2gooL0oOoe
087o__ol087o__oi0?Oon@2goo`0]oog0?gom@3cooh0l?on09_ooP3hooh0f?ol
0=go0=C5ood0]oog0?goo@01oooj087o_ool087o_ooi0?GonP2goo`0]oog0?go
o@01oooj0?Coo@3bood0Voom0?WooP3Hoo`0XOom0;Oom`3mood00OoonP21okoo
o021okoon@3eooX0]ool0;Oom`3mood00OoonP3dood0l_om09_oo@3iooh0f?ol
0:7oo@2gooL0oOom007oooX0POnooo`0POnoooT0mOoj0;Ooo02gooL0oOom007o
ooX0m?om0?;oo@2Kood0nOon0=Soo03Mo`3VaOom0;Son`00ood0oOom0?konP21
ol3oo021ol3onP3aoo/0^?ol0;Son`00ood0oOom0?konP3dooh0l_on09WooP3j
ooh0eool0:7oo@2hoo/00?om0?goo@3nooX0POo0oo`0POo0ooX0lOok0;Soo02h
oo/00?om0?goo@3nooX0m?on0?;ooP2Iooh0n_on0=Ooo02Qood0^?ok003oo@3m
ood0o_oj087o`?ol087o`?oj0?7on`2hoo`0^?ok003oo@3mood0o_oj0?CooP3b
ooh0VOon0?[ooP3Goo`0gOl0k<Goo@2ioo/00Oooo@3mood0o?ol087o`?ol087o
`?ok0>oon`2ioo`0^Ook007oood0oOom0?coo03dooh0l_on09Woo@3kooh0eool
0:7oo@2ioo/00Oooo@3mood0o?ol087o`?ol087o`?ok0>oon`2ioo`0^Ook007o
ood0oOom0?coo03dooh0l_on09Woo@3kooh0eool0:7oo@2ioo/00Oooo@3mood0
o?ol087o`?ol087o`?ok0>oon`2ioo`0^Ook007oood0oOom0?coo03dooh0l_on
09Woo@3kooh0eool0=go0>K5ood0^Oom0?goo@3mood0o?ok087o`Ool087o`OoQ
0;[oo02iood0oOom0?goo@3loo/0mOom0?Coo@2/ood0lOon0?_ooP3Goo`0XOom
0;Woo@3mood0oOom0?con`21ol7oo021ol7oh@2joo`0^Oom0?goo@3mood0o?ok
0?Goo@3dood0[?om0?7ooP3kooh0eool0:7oo@2iood0oOom0?goo@3loo/0POo1
oo`0POo1on40^_ol0;Woo@3mood0oOom0?con`3eood0m?om0:coo@3aooh0noon
0=Ooo03Mo`3VaOom0;[oo03mood0oOom0?conP21ol;oo021ol7oh@2joo`0^_ol
0?goo@3mood0o?oj0?Goo@3food0Zoom0?7oo@3mooh0e_ol0:7oo@2joo`0oOom
0?goo@3looX0POo2oo`0POo1on40^_ol0;[oo03mood0oOom0?conP3eood0m_om
0:_oo@3aood0oOon0=Koo02Qood0^_ol0?goo@3mood0o?oj087o`_ol087o`OoQ
0;[oo02joo`0oOom0?goo@3looX0mOom0?Koo@2[ood0lOom0?gooP3Foo`0gOl0
i/Goo@2koo/0oOom0?goo@3looX0POo2oo`0POo2oml0^ool0;_on`3mood0oOom
0?conP3eoo`0n?ol0:_oo@3`ooh0oOon0=Koo02Qood0^ook0?goo@3mood0o?oj
087o`_ol087o`_oO0;_oo02koo/0oOom0?goo@3looX0mOol0?Soo02[ood0l?on
0?gooP3Foo`0XOom0;_on`3mood0oOom0?conP21ol;oo021ol;og`2koo`0^ook
0?goo@3mood0o?oj0?Goo03hoo`0Zoom0?3ooP3mooh0e_ol0=go0>K5ood0^ook
0?goo@3mood0o?oj087o`_ol087o`ooN0;_oo02koo/0oOom0?goo@3looX0m?ok
0?con`2Zood0l?on0?koo@3Foo`0XOom0;_on`3mood0oOom0?conP21ol;oo021
ol?ogP2koo`0^ook0?goo@3mood0o?oj0?Con`3loo/0Z_om0?3ooP3nood0e_ol
0:7oo@2koo/0oOom0?goo@3looX0POo2oo`0POo3omh0^ool0;_on`3mood0oOom
0?conP3doo/0o?ok0:[oo@3`ooh0o_om0=Koo03Mo`3MaOom0;_on`3mood0oOom
0?conP21ol;oo021ol?ogP2koo`0^ook0?goo@3mood0o?oj0??olP2Yood0koon
007oooh0eOol0:7oo@2koo/0oOom0?goo@3looX0POo2oo`0POo3omh0^ool0;_o
n`3mood0oOom0?conP3coo80ZOom0>oooP01ooon0=Goo02Qood0^ook0?goo@3m
ood0o?oj087o`_ol087o`ooN0;_oo02koo/0oOom0?goo@3looX0loob0:Woo@3_
ooh00OoooP3Eoo`0gOl0gLGoo@2looX0oOom0?goo@3looT0POo3oo`0POo3oo`0
iool0;coo02looX0oOom0?goo@3looT0l_of097ooP01ooon0=Goo02Qood0_?oj
0?goo@3mood0o?oi087o`ool087o`ool0>Ooo02loo`0_?oj0?goo@3mood0o?oi
0?;omP2Aooh00OoooP3Eoo`0XOom0;conP3mood0oOom0?con@21ol?oo021ol?o
o03Woo`0_?ol0;conP3mood0oOom0?con@3booH0TOon007oooh0eOol0=go0<k5
ood0_?oj0?goo@3mood0o?oi087o`ool087o`oom0>Koo02loo`0_?oj0?goo@3m
ood0o?oi0?3onP2>oo/0e?ol0:7oo@2looX0oOom0?goo@3looT0POo3oo`0POo3
ood0i_ol0;coo02looX0oOom0?goo@3looT0l?oj08kon`3Doo`0XOom0;conP3m
ood0oOom0?con@21ol?oo021ol?oo@3Voo`0_?ol0;conP3mood0oOom0?con@3`
ooX0S_ok0=Coo03Mo`3>aOom0;conP3mood0oOom0?con@21ol?oo021olCoo03U
ood0_?ol0;conP3mood0oOom0?con@3/ooh0S_ok0=Coo02Qood0_?oj0?goo@3m
ood0o?oi087o`ool087oa?ol0>Goo@2loo`0_?oj0?goo@3mood0o?oi0>cooP2>
oo/0e?ol0:7oo@2looX0oOom0?goo@3looT0POo3oo`0POo4oo`0iOom0;coo02l
ooX0oOom0?goo@3looT0k?on08kon`3Doo`0gOl1;/Goo@2mooT0oOom0?goo@3l
ooP0POo4oo`0POo4oo`0iOol0;gon`3mood0oOom0?coo@3mood0oOom0?coo@3m
ood0oOom003on@3mood0oOom0?con03/ooh0Sook0=Coo02Qood0_Ooi0?goo@3m
ood0o?oh087oa?ol087oa?ol0>Goo02moo/0oOom0?goo@3lood0oOom0?goo@3l
ood0oOom0?goo@00ooT0oOom0?goo@3looP0k?on08oon`3Doo`0XOom0;gon@3m
ood0oOom0?con021olCoo021olCoo03Uoo`0_Ook0?goo@3mood0o?om0?goo@3m
ood0o?om0?goo@3mood00?oi0?goo@3mood0o?oh0>cooP2?oo/0e?ol0=go0E;5
ood0_Ooi0?goo@3mood0o?om003oo@21olCoo021olCof`2moo/0oOom0?goo@3l
ood0oOom0?goo@3lood0oOom0?goo@00ooT0oOom0?goo@3lood00?om0>_oo03k
o`00/?om0>goo@3Coo`0XOom0;gon@3mood0oOom0?coo@00ood0POo4oo`0POo4
om/0_Ook0?goo@3mood0o?om0?goo@3mood0o?om0?goo@3mood00?oi0?goo@3m
ood0o?om003oo@3[oo`0nol00;3oo@3]ood0dool0:7oo@2mooT0oOom0?goo@3l
ood00?om087oa?ol087oa?oK0;gon`3mood0oOom0?coo@3mood0oOom0?coo@3m
ood0oOom003on@3mood0oOom0?coo@00ood0jool0?_o002`ood0kOom0=?oo03M
o`56aOom0;gon@3mood0oOom0?coo@00ood0POo4oo`0POo4om/0_Ook0?goo@3m
ood0o?om0?goo@3mood0o?om0?goo@3mood00?oi0?goo@3mood0o?om003oo@3Z
ooH0/?om0>goo@3Coo`0XOom0;gon@3mood0oOom0?coo@00ood0POo4oo`0POo4
om/0_Ook0?goo@3mood0o?om0?goo@3mood0o?om0?goo@3mood00?oi0?goo@3m
ood0o?om003oo@3ZooH0/?om0>goo@3Coo`0XOom0;gon@3mood0oOom0?coo@00
ood0POo4oo`0POo4om/0_Ook0?goo@3mood0o?om0?goo@3mood0o?om0?goo@3m
ood00?oi0?goo@3mood0o?om003oo@3ZooH0/?om0>goo@3Coo`0gOl1;/Goo@2m
ooT0oOom0?goo@3looP0POo4oo`0POo4om/0_Ook0?goo@3mood0o?om0?goo@3m
ood0o?om0?goo@3mood00?oi0?goo@3mood0o?oh0>Son02`ood0kOon0=;oo02Q
ood0_Ooi0?goo@3mood0o?oh087oa?ol087oa?oK0;gon`3mood0oOom0?coo@3m
ood0oOom0?coo@3mood0oOom003on@3mood0oOom0?con03XooP0/?om0>gooP3B
oo`0XOom0;gon@3mood0oOom0?con021olCoo021olCof`2moo/0oOom0?goo@3l
ood0oOom0?goo@3lood0oOom0?goo@00ooT0oOom0?goo@3looP0j?oh0;3oo@3]
ooh0d_ol0=go0<k5ood0_?oj0?goo@3mood0o?oi087o`ool087oa?oL0;coo02l
ooX0oOom0?goo@3looT0iOoj0;3oo@3]ooh0d_ol0:7oo@2looX0oOom0?goo@3l
ooT0POo3oo`0POo4om`0_?ol0;conP3mood0oOom0?con@3UooX0/?om0>gooP3B
oo`0XOom0;conP3mood0oOom0?con@21ol?oo021olCog02loo`0_?oj0?goo@3m
ood0o?oi0>GonP2`ood0kOon0=;oo03Mo`38aOom0;conP3mood0oOom0?con@21
ol?oo021ol?oo@3Voo`0_?ol0;conP3mood0oOom0?con@21ooKooP3Aoo`0XOom
0;conP3mood0oOom0?con@21ol?oo021ol?oo@3Voo`0_?ol0;conP3mood0oOom
0?con@21ooKooP3Aoo`0XOom0;conP3mood0oOom0?con@21ol?oo021ol?oo@3V
oo`0_?ol0;conP3mood0oOom0?con@21ooKooP3Aoo`0gOl0b<Goo@2looX0oOom
0?goo@3looT0POo3oo`0POo3oo`0iool0;coo02looX0oOom0?goo@3looT0POof
ooh0dOol0:7oo@2looX0oOom0?goo@3looT0POo3oo`0POo3oo`0iool0;coo02l
ooX0oOom0?goo@3looT0POofooh0dOol0:7oo@2looX0oOom0?goo@3looT0POo3
oo`0POo3oo`0iool0;coo02looX0oOom0?goo@3looT0POofooh0dOol0=go0<S5
ood0^ook0?goo@3mood0o?oi087o`ool087o`ool0>Ooo02loo`0^ook0?goo@3m
ood0o?oi087omoon0=3oo02Qood0^ook0?goo@3mood0o?oi087o`ool087o`ool
0>Ooo02loo`0^ook0?goo@3mood0o?oi087omoon0=3oo02Qood0^ook0?goo@3m
ood0o?oi087o`ool087o`ool0>Ooo02loo`0^ook0?goo@3mood0o?oi087omoon
0=3oo03Mo`38aOom0;_on`3mood0oOom0?conP21ol;oo021ol?oo03Xoo`0^ool
0;_on`3mood0oOom0?conP21ooOoo@3@oo`0XOom0;_on`3mood0oOom0?conP21
ol;oo021ol?oo03Xoo`0^ool0;_on`3mood0oOom0?conP21ooOoo@3@oo`0XOom
0;_on`3mood0oOom0?conP21ol;oo021ol?oo03Xoo`0^ool0;_on`3mood0oOom
0?conP21ooOoo@3@oo`0gOl0`/Goo@2koo/0oOom0?goo@3looX0POo2oo`0POo2
oml0^ool0;_on`3mood0oOom0?conP2<ood0mOoi0<ooo02Qood0^ook0?goo@3m
ood0o?oj087o`_ol087o`_oO0;_oo02koo/0oOom0?goo@3looX0S?om0?Gon@3?
oo`0XOom0;_on`3mood0oOom0?conP21ol;oo021ol;og`2koo`0^ook0?goo@3m
ood0o?oj08coo@3eooT0cool0=go0<;5ood0^_ol0?goo@3mood0o?oj087o`_ol
087o`OoQ0;[oo02joo`0oOom0?goo@3looX0S?om0?GonP3>oo`0XOom0;[oo03m
ood0oOom0?conP21ol;oo021ol7oh@2joo`0^_ol0?goo@3mood0o?oj08coo@3e
ooX0c_ol0:7oo@2joo`0oOom0?goo@3looX0POo2oo`0POo1on40^_ol0;[oo03m
ood0oOom0?conP2<ood0mOoj0<koo03Mo`3JaOom0;[oo03mood0oOom0?con`21
ol7oo021ol7oh@2joo`0k?om0?Ooo@3Qoo`0oOom0?goo@3loo/0Room0?Goo03<
oo`0XOom0;[oo03mood0oOom0?con`21ol7oo021ol7oh@2joo`0k?om0?Ooo@3Q
oo`0oOom0?goo@3loo/0Room0?Goo03<oo`0XOom0;[oo03mood0oOom0?con`21
ol7oo021ol7oh@2joo`0k?om0?Ooo@3Qoo`0oOom0?goo@3loo/0Room0?Goo03<
oo`0gOl0c/Goo@2ioo`0o_om0?goo@3loo/0POo1oo`0POo0on<0^Ool0>_oo@3i
ood0gool0?koo@3mood0o?ok08_oo@2koo`0XOom0;Woo03nood0oOom0?con`21
ol7oo021ol3oh`2ioo`0joom0?Woo@3Ooo`0o_om0?goo@3loo/0Room0;_oo02Q
ood0^Ool0?koo@3mood0o?ok087o`Ool087o`?oS0;Woo03[ood0nOom0=ooo03n
ood0oOom0?con`2;ood0^ool0=go0=[5ood0^?ol007oood0oOom0?gon`21ol3o
o021ol3on`3`oo/0^?ol0>[ooP3iooh0gOol007oood0oOom0?gon`21ol3oo02Q
ood0^?ol007oood0oOom0?gon`21ol3oo021ol3on`3`oo/0^?ol0>[ooP3iooh0
gOol007oood0oOom0?gon`21ol3oo02Qood0^?ol007oood0oOom0?gon`21ol3o
o021ol3on`3`oo/0^?ol0>[ooP3iooh0gOol007oood0oOom0?gon`21ol3oo03M
o`32aOom0;SomP3mood00Ooon@21ol3oo021okoonP3cooX0^?ol0>WooP3kooh0
g?of0?goo@01oooi087o`?ol0:7oo@2hooH0oOom007oooT0POo0oo`0POnoooX0
looj0;Soo03Yooh0noon0=comP3mood00Ooon@21ol3oo02Qood0^?of0?goo@01
oooi087o`?ol087o_ooj0??onP2hoo`0jOon0?_ooP3LooH0oOom007oooT0POo0
oo`0gOl0Y<Goo@2gooL0oOoe087o__ol087o__oi0?Oon@2goo`0jOom0?goo@3K
ooL0oOoe087o__ol0:7oo@2gooL0oOoe087o__ol087o__oi0?Oon@2goo`0jOom
0?goo@3KooL0oOoe087o__ol0:7oo@2gooL0oOoe087o__ol087o__oi0?Oon@2g
oo`0jOom0?goo@3KooL0oOoe087o__ol0=go0835ood0]_oY087o_Ool087o_OoY
0;Koo03Xooh0oOon0=Woj@21okgoo02Qood0]_oY087o_Ool087o_OoY0;Koo03X
ooh0oOon0=Woj@21okgoo02Qood0]_oY087o_Ool087o_OoY0;Koo03Xooh0oOon
0=Woj@21okgoo03Mo`29aOom0;Cok021okcoo021ok_ok02eoo`0ioon007oooh0
e_o/08Koo@2koo`0XOom0;Cok021okcoo021ok_ok02eoo`0ioon007oooh0e_o/
08Koo@2koo`0XOom0;Cok021okcoo021ok_ok02eoo`0ioon007oooh0e_o/08Ko
o@2koo`0gOl0N/Goo@2conl0POnjoo`0POnjonl0/ool0>Oon@3Eonl0Q?om0;_o
o02Qood0/oo_087o^_ol087o^_o_0;?oo03WooT0eOo_08Coo@2koo`0XOom0;?o
k`21ok[oo021ok[ok`2coo`0iooi0=Gok`24ood0^ool0=go07[5ood0/Ooc087o
^?ol087o^?oc0;7oo03Voo/0d_oc08;oo@2koo`0XOom0;7ol`21okSoo021okSo
l`2aoo`0i_ok0=;ol`22ood0^ool0:7oo@2aoo<0POnhoo`0POnhoo<0/Ool0>Ko
n`3Boo<0P_om0;_oo03Mo`1daOom087oPOoJoo`0POn1om[oo03Uood0c?om087o
oOom0;_oo02Qood0POn1om[oo021oh7of_ol0>Goo@3<ood0POomood0^ool0:7o
o@21oh7of_ol087oPOoJoo`0iOom0<coo@21oogoo@2koo`0gOl0M<Goo@21oh7o
f_ol087oPOoJoo`0iOom0<coo@21oogoo@2koo`0XOom087oPOoJoo`0POn1om[o
o03Uood0c?om087ooOom0;_oo02Qood0POn1om[oo021oh7of_ol0>Goo@3<ood0
POomood0^ool0=go07C5ood0POn1om[oo021oh7of_ol0>Kon`3`oo`0oOon087o
V?ol0:7oo@21oh7of_ol087oPOoJoo`0i_ok0?3oo03mooh0POnHoo`0XOom087o
POoJoo`0POn1om[oo03Voo/0l?ol0?gooP21oiSoo03Mo`1gaOom087oPOoJoo`0
POn1om[oo03WooT0looh007oooh0POnHoo`0XOom087oPOoJoo`0POn1om[oo03W
ooT0looh007oooh0POnHoo`0XOom087oPOoJoo`0POn1om[oo03WooT0looh007o
ooh0POnHoo`0gOl0PlGoo@21oh7of_ol087oPOoJoo`0ioon007oooh0m?of003o
oP21oiSoo02Qood0POn1om[oo021oh7of_ol0>OooP01ooon0?ComP00ooh0POnH
oo`0XOom087oPOoJoo`0POn1om[oo03Wooh00OoooP3dooH00?on087oV?ol0=go
0835ood0POn1om[oo021oh7of_ol0>SooP3mooh0m_ol0?con`21oiSoo02Qood0
POn1om[oo021oh7of_ol0>SooP3mooh0m_ol0?con`21oiSoo02Qood0POn1om[o
o021oh7of_ol0>SooP3mooh0m_ol0?con`21oiSoo03Mo`2HaOom087oPOoJoo`0
POn1om[oo03Yood0oOom0?Soo@3ioo`0j_om087ooOom0;_oo02Qood0POn1om[o
o021oh7of_ol0>Woo@3mood0n?om0?Woo03Zood0POomood0^ool0:7oo@21oh7o
f_ol087oPOoJoo`0jOom0?goo@3hood0nOol0>[oo@21oogoo@2koo`0gOl0V<Go
o@21oh7of_ol087oPOoJoo`0jOon0?_ooP3hooh0moom0>[oo@21oogoo@2koo`0
XOom087oPOoJoo`0POn1om[oo03Yooh0noon0?SooP3good0j_om087ooOom0;_o
o02Qood0POn1om[oo021oh7of_ol0>WooP3kooh0n?on0?Ooo@3Zood0POomood0
^ool0=go0:[5ood0POn1om[oo021oh7of_ol0>[ooP3iooh0n_om0?Ooo@3Zood0
n_on0?CooP2Good0^ool0:7oo@21oh7of_ol087oPOoJoo`0j_on0?WooP3jood0
moom0>[oo@3jooh0m?on09Ooo@2koo`0XOom087oPOoJoo`0POn1om[oo03Zooh0
nOon0?[oo@3good0j_om0?[ooP3dooh0Uoom0;_oo03Mo`2ZaOom087oPOoJoo`0
POn1om[oo03[ood0nOom0?_ooP3eooh0j_om0?WooP3fooh0U_om0;_oo02Qood0
POn1om[oo021oh7of_ol0>_oo@3iood0noon0?GooP3Zood0nOon0?KooP2Food0
^ool0:7oo@21oh7of_ol087oPOoJoo`0joom0?Woo@3kooh0mOon0>[oo@3iooh0
m_on09Koo@2koo`0gOl0V<Goo@21oh7of_ol087oPOoJoo`0k?om0?Ooo@3looh0
mOon0=kooP3fooh0POo<oo`0XOom087oPOoJoo`0POn1om[oo03/ood0moom0?co
oP3eooh0g_on0?KooP21olcoo02Qood0POn1om[oo021oh7of_ol0>coo@3good0
o?on0?GooP3Nooh0m_on087oc?ol0=go0835ood0POn1om[oo021oh7of_ol0=Go
oP3eooh0gOon0?Soo@21olcoo02Qood0POn1om[oo021oh7of_ol0=GooP3eooh0
gOon0?Soo@21olcoo02Qood0POn1om[oo021oh7of_ol0=GooP3eooh0gOon0?So
o@21olcoo03Mo`20aOom087oPOoJoo`0POn1om[oo03Eooh0mOon0=gooP3hooh0
POo;oo`0XOom087oPOoJoo`0POn1om[oo03Eooh0mOon0=gooP3hooh0POo;oo`0
XOom087oPOoJoo`0POn1om[oo03Eooh0mOon0=gooP3hooh0POo;oo`0gOl0P<Go
o@21oh7of_ol087oPOoJoo`0eOon0?GooP3Mood0nOon087obool0:7oo@21oh7o
f_ol087oPOoJoo`0eOon0?GooP3Mood0nOon087obool0:7oo@21oh7of_ol087o
POoJoo`0eOon0?GooP3Mood0nOon087obool0=go09;5ood0POn1om[oo021oh7o
f_ol0=GooP3eooh0j_om0?OooP3jooh0U?om0;_oo02Qood0POn1om[oo021oh7o
f_ol0=GooP3eooh0j_om0?OooP3jooh0U?om0;_oo02Qood0POn1om[oo021oh7o
f_ol0=GooP3eooh0j_om0?OooP3jooh0U?om0;_oo03Mo`2BaOom087oPOoJoo`0
POn1om[oo03Eood0moom0>[oo@3good0noon09Coo@2koo`0XOom087oPOoJoo`0
POn1om[oo03Eood0moom0>[oo@3good0noon09Coo@2koo`0XOom087oPOoJoo`0
POn1om[oo03Eood0moom0>[oo@3good0noon09Coo@2koo`0gOl0Z/Goo@21oh7o
f_ol087oPOoJoo`0e?on0?Ooo@3Zood0m_on0?_ooP3doo`0oOon0:goo@2koo`0
XOom087oPOoJoo`0POn1om[oo03Dooh0moom0>[oo@3fooh0noon0?Coo03mooh0
[Oom0;_oo02Qood0POn1om[oo021oh7of_ol0=CooP3good0j_om0?KooP3kooh0
m?ol0?gooP2]ood0^ool0=go0:g5ood0POn1om[oo021oh7of_ol0=Coo@3ioo`0
j_om0?Koo@3mooh0mOoh007oooh0[Oom0;_oo02Qood0POn1om[oo021oh7of_ol
0=Coo@3ioo`0j_om0?Koo@3mooh0mOoh007oooh0[Oom0;_oo02Qood0POn1om[o
o021oh7of_ol0=Coo@3ioo`0j_om0?Koo@3mooh0mOoh007oooh0[Oom0;_oo03M
o`2HaOom087oPOoJoo`0POn1om[oo03Coo`0oOoj0=[ooP3mooh0m_of003ooP21
on?oo02Qood0POn1om[oo021oh7of_ol0=?oo03mooX0f_on0?gooP3fooH00?on
087ohool0:7oo@21oh7of_ol087oPOoJoo`0dool0?gonP3Jooh0oOon0?KomP00
ooh0POoSoo`0gOl0V<Goo@21oh7of_ol087oPOoJoo`0d_of003ooP3Jooh0o_om
0?Ooo03loo/0POoSoo`0XOom087oPOoJoo`0POn1om[oo03BooH00?on0=[ooP3n
ood0mool0?con`21on?oo02Qood0POn1om[oo021oh7of_ol0=;omP00ooh0f_on
0?koo@3goo`0o?ok087ohool0=go09k5ood0POn1om[oo021oh7of_ol0=7on001
ooon0=WooP01ooon0?Ooo@3ioo`0POoSoo`0XOom087oPOoJoo`0POn1om[oo03A
ooP00OoooP3Iooh00OoooP3good0nOol087ohool0:7oo@21oh7of_ol087oPOoJ
oo`0dOoh007oooh0fOon007oooh0moom0?Woo021on?oo03Mo`2KaOom087oPOoJ
oo`0POn1om[oo03?oo`0oOon0=WooP01ooon0?OooP3good0POoSoo`0XOom087o
POoJoo`0POn1om[oo03?oo`0oOon0=WooP01ooon0?OooP3good0POoSoo`0XOom
087oPOoJoo`0POn1om[oo03?oo`0oOon0=WooP01ooon0?OooP3good0POoSoo`0
gOl0T/Goo@21oh7of_ol087oPOoJoo`0a_on0>[oo@3coo/0moom0?Ooo@2]ood0
^ool0:7oo@21oh7of_ol087oPOoJoo`0a_on0>[oo@3coo/0moom0?Ooo@2]ood0
^ool0:7oo@21oh7of_ol087oPOoJoo`0a_on0>[oo@3coo/0moom0?Ooo@2]ood0
^ool0=go09;5ood0POn1om[oo021oh7of_ol0<KooP3Zood0look0?OooP3eooh0
[Oom0;_oo02Qood0POn1om[oo021oh7of_ol0<KooP3Zood0look0?OooP3eooh0
[Oom0;_oo02Qood0POn1om[oo021oh7of_ol0<KooP3Zood0look0?OooP3eooh0
[Oom0;_oo03Mo`2BaOom087oPOoJoo`0POn1om[oo036ooh0j_om0??on`3gooh0
mOon0:goo@2koo`0XOom087oPOoJoo`0POn1om[oo036ooh0j_om0??on`3gooh0
mOon0:goo@2koo`0XOom087oPOoJoo`0POn1om[oo036ooh0j_om0??on`3gooh0
mOon0:goo@2koo`0gOl0T/Goo@21oh7of_ol087oPOoJoo`0a_on0>[oo@3bood0
m_on0?GooP2]ood0^ool0:7oo@21oh7of_ol087oPOoJoo`0a_on0>[oo@3bood0
m_on0?GooP2]ood0^ool0:7oo@21oh7of_ol087oPOoJoo`0a_on0>[oo@3bood0
m_on0?GooP2]ood0^ool0=go09;5ood0POn1om[oo021oh7of_ol0<KooP3Zood0
l_om0?KooP3eooh0[Oom0;_oo02Qood0POn1om[oo021oh7of_ol0<KooP3Zood0
l_om0?KooP3eooh0[Oom0;_oo02Qood0POn1om[oo021oh7of_ol0<KooP3Zood0
l_om0?KooP3eooh0[Oom0;_oo03Mo`20aOom087oPOoJoo`0POn1om[oo036ooh0
eoon0?GooP3eooh0POoSoo`0XOom087oPOoJoo`0POn1om[oo036ooh0eoon0?Go
oP3eooh0POoSoo`0XOom087oPOoJoo`0POn1om[oo036ooh0eoon0?GooP3eooh0
POoSoo`0gOl0P<Goo@21oh7of_ol087oPOoJoo`0a_on0=OooP3eooh0mOon087o
hool0:7oo@21oh7of_ol087oPOoJoo`0a_on0=OooP3eooh0mOon087ohool0:7o
o@21oh7of_ol087oPOoJoo`0a_on0=OooP3eooh0mOon087ohool0=go0835ood0
POn1om[oo021oh7of_ol0<KooP3Hooh0m?om0?Ooo@21on?oo02Qood0POn1om[o
o021oh7of_ol0<KooP3Hooh0m?om0?Ooo@21on?oo02Qood0POn1om[oo021oh7o
f_ol0<KooP3Hooh0m?om0?Ooo@21on?oo03Mo`1daOom087oPOoJoo`0POn1om[o
o02Jooh0loon0?Ooo@21on?oo02Qood0POn1om[oo021oh7of_ol09[ooP3cooh0
moom087ohool0:7oo@21oh7of_ol087oPOoJoo`0V_on0??ooP3good0POoSoo`0
gOl0Q/Goo@21oh7of_ol087oPOoJoo`0[?om0?CooP3bood0nOol0:goo@2koo`0
XOom087oPOoJoo`0POn1om[oo02/ood0m?on0?;oo@3ioo`0[Oom0;_oo02Qood0
POn1om[oo021oh7of_ol0:coo@3dooh0l_om0?Woo02]ood0^ool0=go08K5ood0
POn1om[oo021oh7of_ol0:coo@3eood0lOol0?gonP2]ood0^ool0:7oo@21oh7o
f_ol087oPOoJoo`0[?om0?Goo@3aoo`0oOoj0:goo@2koo`0XOom087oPOoJoo`0
POn1om[oo02/ood0mOom0?7oo03mooX0[Oom0;_oo03Mo`26aOom087oPOoJoo`0
POn1om[oo02/ood0n_oi0>oomP00ooh0[Oom0;_oo02Qood0POn1om[oo021oh7o
f_ol0:coo@3jooT0koof003ooP2]ood0^ool0:7oo@21oh7of_ol087oPOoJoo`0
[?om0?[on@3_ooH00?on0:goo@2koo`0gOl0RLGoo@21oh7of_ol087oPOoJoo`0
[?om0?[onP3]ooP00OoooP2]ood0^ool0:7oo@21oh7of_ol087oPOoJoo`0[?om
0?[onP3]ooP00OoooP2]ood0^ool0:7oo@21oh7of_ol087oPOoJoo`0[?om0?[o
nP3]ooP00OoooP2]ood0^ool0=go07C5ood0POn1om[oo021oh7of_ol0:7oo03Y
oo`0oOon087ohool0:7oo@21oh7of_ol087oPOoJoo`0XOol0>Woo03mooh0POoS
oo`0XOom087oPOoJoo`0POn1om[oo02Qoo`0jOol0?gooP21on?oo03Mo`1RaOom
087oPOoJoo`0POn1om[oo021oo_ooP21on?oo02Qood0POn1om[oo021oh7of_ol
087onoon087ohool0:7oo@21oh7of_ol087oPOoJoo`0POokooh0POoSoo`0gOl0
H/Goo@21oh7of_ol087oPOoJoo`0POokooh0POoSoo`0XOom087oPOoJoo`0POn1
om[oo021oo_ooP21on?oo02Qood0POn1om[oo021oh7of_ol087onoon087ohool
0=go06;5ood0POn1om[oo021oh7of_ol087onoon087ohool0:7oo@21oh7of_ol
087oPOoJoo`0POokooh0POoSoo`0XOom087oPOoJoo`0POn1om[oo021oo_ooP21
on?oo03Mo`1^aOom087oPOoJoo`0POn1om[oo02/ood0e?on0:goo@2koo`0XOom
087oPOoJoo`0POn1om[oo02/ood0e?on0:goo@2koo`0XOom087oPOoJoo`0POn1
om[oo02/ood0e?on0:goo@2koo`0gOl0K/Goo@21oh7of_ol087oPOoJoo`0[?om
0=CooP2]ood0^ool0:7oo@21oh7of_ol087oPOoJoo`0[?om0=CooP2]ood0^ool
0:7oo@21oh7of_ol087oPOoJoo`0[?om0=CooP2]ood0^ool0=go06k5ood0POn1
om[oo021oh7of_ol0:coo@3Dooh0[Oom0;_oo02Qood0POn1om[oo021oh7of_ol
0:coo@3Dooh0[Oom0;_oo02Qood0POn1om[oo021oh7of_ol0:coo@3Dooh0[Oom
0;_oo03Mo`1^aOom087oPOoJoo`0POn1om[oo02/ood0e?on0:goo@2koo`0XOom
087oPOoJoo`0POn1om[oo02/ood0e?on0:goo@2koo`0XOom087oPOoJoo`0POn1
om[oo02/ood0e?on0:goo@2koo`0gOl0H/Goo@21oh7of_ol087oPOoJoo`0POok
ooh0POoSoo`0XOom087oPOoJoo`0POn1om[oo021oo_ooP21on?oo02Qood0POn1
om[oo021oh7of_ol087onoon087ohool0=go05K5ood0POn1om[oo021oh7of_ol
087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol
087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol
0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol
087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1
om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol
0=go06kmolVZo@21oh7of_ol087oPOoJoo`0[?om087ooOom0;_oo03IolVZo@21
oh7of_ol087oPOoJoo`0[?om087ooOom0;_oo03IolVZo@21oh7of_ol087oPOoJ
oo`0[?om087ooOom0;_oo03Mo`0loOo9ZX40P@210840P@210840e@3molVZP@21
0840P@210840P@3E0?gobJZ10840P@210840P@210=D003cmolVZP@210840P@21
0840P@3E0?gobJZ10840P@210840P@210=D0oOo9ZX40P@210840P@210840e@00
??gobJZ10840P@210840P@210=D0oOo9ZX40P@210840P@210840e@3molVZP@21
0840P@210840P@3E000faOn10840P@210840P@210=D0aOn10840P@210840P@21
0=D0aOn10840P@210840P@210=D003K5oh40P@210840P@210840e@35oh40P@21
0840P@210840e@35oh40P@210840P@210840e@00E/Goo@21oh7of_ol087oPOoJ
oo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJ
oo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJ
oo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJ
oo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21
oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJ
oo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021
oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5
ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021
oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJ
oo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Q
ood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJ
oo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJ
oo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJ
oo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJ
oo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21
oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJ
oo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021
oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go06k5
ood0POn1om[oo03/ooh0POn1oo;oo021oh7of_ol0>cooP2iood0POn1om[oo03/
ooh0POn1oo;oo021oh7of_ol0>cooP2iood0POn1om[oo03/ooh0POn1oo;oo021
oh7of_ol0>cooP3eo`1^aOom087oPOoJoo`0k?on087oPOoboo`0POn1om[oo03/
ooh0^Oom087oPOoJoo`0k?on087oPOoboo`0POn1om[oo03/ooh0^Oom087oPOoJ
oo`0k?on087oPOoboo`0POn1om[oo03/ooh0mOl0K/Goo@21oh7of_ol0>cooP21
oh7ol_ol087oPOoJoo`0k?on0;Woo@21oh7of_ol0>cooP21oh7ol_ol087oPOoJ
oo`0k?on0;Woo@21oh7of_ol0>cooP21oh7ol_ol087oPOoJoo`0k?on0?Go06k5
ood0POn1om[oo03/ooh0POn1oo;oo021oh7of_ol0>cooP2iood0POn1om[oo03/
ooh0POn1oo;oo021oh7of_ol0>cooP2iood0POn1om[oo03/ooh0POn1oo;oo021
oh7of_ol0>cooP3eo`1^aOom087oPOoJoo`0k?on087oPOoboo`0POn1om[oo03/
ooh0^Oom087oPOoJoo`0k?on087oPOoboo`0POn1om[oo03/ooh0^Oom087oPOoJ
oo`0k?on087oPOoboo`0POn1om[oo03/ooh0mOl0K/Goo@21oh7of_ol0>cooP21
oh7ol_ol087oPOoJoo`0k?on0;Woo@21oh7of_ol0>cooP21oh7ol_ol087oPOoJ
oo`0k?on0;Woo@21oh7of_ol0>cooP21oh7ol_ol087oPOoJoo`0k?on0?Go06k5
ood0POn1om[oo03/ooh0POn1oo;oo021oh7of_ol0>cooP2iood0POn1om[oo03/
ooh0POn1oo;oo021oh7of_ol0>cooP2iood0POn1om[oo03/ooh0POn1oo;oo021
oh7of_ol0>cooP3eo`1^aOom087oPOoJoo`0k?on087oPOoboo`0POn1om[oo03/
ooh0^Oom087oPOoJoo`0k?on087oPOoboo`0POn1om[oo03/ooh0^Oom087oPOoJ
oo`0k?on087oPOoboo`0POn1om[oo03/ooh0mOl0Q/Goo@3dooH0POn1oo;oo03/
ooh0POn1oo;oo03fooH0POn1oo3oo03/ooh0^Oom0?ComP21oh7ol_ol0>cooP21
oh7ol_ol0?KomP21oh7ol?ol0>cooP2iood0m?of087oPOoboo`0k?on087oPOob
oo`0m_of087oPOo`oo`0k?on0?Go08K5ood0m?of087oPOoboo`0mOo/087oPOok
oo`0m_of087oPOo`oo`0mOo/0<;oo@3dooH0POn1oo;oo03eon`0POn1oo_oo03f
ooH0POn1oo3oo03eon`0`_om0?ComP21oh7ol_ol0?Gok021oh7onool0?KomP21
oh7ol?ol0?Gok03no`26aOom0?ComP21oh7ol_ol0?Gok021oh7onool0?KomP21
oh7ol?ol0?Gok032ood0m?of087oPOoboo`0mOo/087oPOokoo`0m_of087oPOo`
oo`0mOo/0<;oo@3dooH0POn1oo;oo03eon`0POn1oo_oo03fooH0POn1oo3oo03e
on`0o_l0K/Goo@21oh7of_ol0?Gok021oh7onool087oPOoJoo`0mOo/0<;oo@21
oh7of_ol0?Gok021oh7onool087oPOoJoo`0mOo/0<;oo@21oh7of_ol0?Gok021
oh7onool087oPOoJoo`0mOo/0?ko06k5ood0POn1om[oo03/ooh0POn1oo;oo021
oh7of_ol0>cooP2iood0POn1om[oo03/ooh0POn1oo;oo021oh7of_ol0>cooP2i
ood0POn1om[oo03/ooh0POn1oo;oo021oh7of_ol0>cooP3eo`1^aOom087oPOoJ
oo`0k?on087oPOoboo`0POn1om[oo03/ooh0^Oom087oPOoJoo`0k?on087oPOob
oo`0POn1om[oo03/ooh0^Oom087oPOoJoo`0k?on087oPOoboo`0POn1om[oo03/
ooh0mOl0K/Goo@21oh7of_ol0>cooP21oh7ol_ol087oPOoJoo`0k?on0;Woo@21
oh7of_ol0>cooP21oh7ol_ol087oPOoJoo`0k?on0;Woo@21oh7of_ol0>cooP21
oh7ol_ol087oPOoJoo`0k?on0?Go06k5ood0POn1om[oo03/ooh0POn1oo;oo021
oh7of_ol0>cooP2iood0POn1om[oo03/ooh0POn1oo;oo021oh7of_ol0>cooP2i
ood0POn1om[oo03/ooh0POn1oo;oo021oh7of_ol0>cooP3eo`1^aOom087oPOoJ
oo`0k?on087oPOoboo`0POn1om[oo03/ooh0^Oom087oPOoJoo`0k?on087oPOob
oo`0POn1om[oo03/ooh0^Oom087oPOoJoo`0k?on087oPOoboo`0POn1om[oo03/
ooh0mOl0K/Goo@21oh7of_ol0>cooP21oh7ol_ol087oPOoJoo`0k?on0;Woo@21
oh7of_ol0>cooP21oh7ol_ol087oPOoJoo`0k?on0;Woo@21oh7of_ol0>cooP21
oh7ol_ol087oPOoJoo`0k?on0?Go06k5ood0POn1om[oo03/ooh0POn1oo;oo021
oh7of_ol0>cooP2iood0POn1om[oo03/ooh0POn1oo;oo021oh7of_ol0>cooP2i
ood0POn1om[oo03/ooh0POn1oo;oo021oh7of_ol0>cooP3eo`1^aOom087oPOoJ
oo`0k?on087oPOoboo`0POn1om[oo03/ooh0^Oom087oPOoJoo`0k?on087oPOob
oo`0POn1om[oo03/ooh0^Oom087oPOoJoo`0k?on087oPOoboo`0POn1om[oo03/
ooh0mOl0K/Goo@21oh7of_ol0>cooP21oh7ol_ol087oPOoJoo`0k?on0;Woo@21
oh7of_ol0>cooP21oh7ol_ol087oPOoJoo`0k?on0;Woo@21oh7of_ol0>cooP21
oh7ol_ol087oPOoJoo`0k?on0?Go05K5ood0POn1om[oo021oh7of_ol087oPOoJ
oo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJ
oo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21
oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJ
oo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021
oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5
ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021
oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJ
oo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Q
ood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJ
oo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJ
oo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJ
oo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJ
oo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21
oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJ
oo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021
oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5
ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021
oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJ
oo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Q
ood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJ
oo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJ
oo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJ
oo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJ
oo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21
oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJ
oo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021
oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5
ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021
oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1LaOom087oPOoJ
oo`0POnbo`00Z_ol087oPOoJoo`0XOom087oPOoJoo`0POnbo`00Z_ol087oPOoJ
oo`0XOom087oPOoJoo`0POnbo`00Z_ol087oPOoJoo`0gOl0J<Goo@2]ooX0POne
oo`0POneooT0[_ol0:gonP21okGoo02Qood0[Ooj087o]Ool087o]Ooi0:koo02]
ooX0POneoo`0XOom0:gonP21okGoo021okGon@2^oo`0[Ooj087o]Ool0=go06S5
ood0/_oa087o^Ool087o^Ooa0;;oo02boo40POnioo`0XOom0;;ol@21okWoo021
okWol@2boo`0/_oa087o^Ool0:7oo@2boo40POnioo`0POnioo40/_ol0;;ol@21
okWoo03Mo`1XaOom0;?ok`21ok[oo021ok[ok`2coo`0/oo_087o^_ol0:7oo@2c
onl0POnjoo`0POnjonl0/ool0;?ok`21ok[oo02Qood0/oo_087o^_ol087o^_o_
0;?oo02conl0POnjoo`0gOl0J<Goo@2don`0POnloo`0POnkon`0]Ool0;Cok021
okcoo02Qood0]?o/087o_?ol087o^oo/0;Goo02don`0POnloo`0XOom0;Cok021
okcoo021ok_ok02eoo`0]?o/087o_?ol0=go06S5ood0]_oY087o_Ool087o_OoY
0;Koo02fonT0POnmoo`0XOom0;Koj@21okgoo021okgoj@2foo`0]_oY087o_Ool
0:7oo@2fonT0POnmoo`0POnmonT0]_ol0;Koj@21okgoo03Mo`23aOom0;OoiP21
okooo021okoon001ooom0?gon@2goo`0]ooV087o_ool0:7oo@2gonH0POnooo`0
POnoooP00Oooo@3mooT0]ool0;OoiP21okooo02Qood0]ooV087o_ool087o_ooh
007oood0oOoi0;Ooo02gonH0POnooo`0gOl0P<Goo@2hon@0POo0oo`0POnoooX0
oOom0?gon02hoo`0^?oT087o`?ol0:7oo@2hon@0POo0oo`0POnoooX0oOom0?go
n02hoo`0^?oT087o`?ol0:7oo@2hon@0POo0oo`0POnoooX0oOom0?gon02hoo`0
^?oT087o`?ol0=go0835ood0^?oT087o`?ol087o`?oi0?goo@3mooP0^?ol0;So
i021ol3oo02Qood0^?oT087o`?ol087o`?oi0?goo@3mooP0^?ol0;Soi021ol3o
o02Qood0^?oT087o`?ol087o`?oi0?goo@3mooP0^?ol0;Soi021ol3oo03Mo`2<
aOom0;WohP21ol7oo021ol3on@3mood0oOom003oo02ioo`0^OoR087o`Ool0:7o
o@2ion80POo1oo`0POo0ooT0oOom0?goo@00oo`0^Ool0;WohP21ol7oo02Qood0
^OoR087o`Ool087o`?oi0?goo@3mood00?ol0;Woo02ion80POo1oo`0gOl0YlGo
o@2joo`0jool087o`Ool087o`Ooh0?goo@3mood00Oooo02joo`0^_ol0>_oo021
ol7oo02Qood0^_ol0>_oo021ol7oo021ol7on03mood0oOom007ooo`0^_ol0;[o
o03[oo`0POo1oo`0XOom0;[oo03[oo`0POo1oo`0POo1ooP0oOom0?goo@01oool
0;[oo02joo`0jool087o`Ool0=go0;?5ood0^_om0>Woo021ol;oo021ol7oo@00
ood0oOom0?goo@01oool0;[oo02jood0jOol087o`_ol0:7oo@2jood0jOol087o
`_ol087o`Oom003oo@3mood0oOom007ooo`0^_ol0;[oo@3Yoo`0POo2oo`0XOom
0;[oo@3Yoo`0POo2oo`0POo1ood00?om0?goo@3mood00Oooo02joo`0^_om0>Wo
o021ol;oo03Mo`2`aOom0;_oo03Xood0POo2oo`0POo3oo/00?om0?goo@3mood0
o_ol0;_oo02koo`0j?om087o`_ol0:7oo@2koo`0j?om087o`_ol087o`ook003o
o@3mood0oOom0?koo02koo`0^ool0>Soo@21ol;oo02Qood0^ool0>Soo@21ol;o
o021ol?on`00ood0oOom0?goo@3noo`0^ool0;_oo03Xood0POo2oo`0gOl0/lGo
o@2kood0ioom087o`_ol087o`ool007oood0oOom0?goo@3mood0^ool0;_oo@3W
ood0POo2oo`0XOom0;_oo@3Wood0POo2oo`0POo3oo`00Oooo@3mood0oOom0?go
o@2koo`0^oom0>Ooo@21ol;oo02Qood0^oom0>Ooo@21ol;oo021ol?oo001ooom
0?goo@3mood0oOom0;_oo02kood0ioom087o`_ol0=go09_5ood0_?oM087o`ool
087o`ool007oood0oOom0?goo@3moo`0_?ol0;cog@21ol?oo02Qood0_?oM087o
`ool087o`ool007oood0oOom0?goo@3moo`0_?ol0;cog@21ol?oo02Qood0_?oM
087o`ool087o`ool007oood0oOom0?goo@3moo`0_?ol0;cog@21ol?oo03Mo`2H
aOom0;cog@21ol?oo021ol?oo@3nood0oOom0?goo@3moo`0_?ol0;cog@21ol?o
o02Qood0_?oM087o`ool087o`oom0?koo@3mood0oOom0?goo02loo`0_?oM087o
`ool0:7oo@2lomd0POo3oo`0POo3ood0o_om0?goo@3mood0oOol0;coo02lomd0
POo3oo`0gOl0V<Goo@2lomd0POo3oo`0POo4oo`0o_om0?goo@3mood0o?om0;co
o02lomd0POo3oo`0XOom0;cog@21ol?oo021olCoo03nood0oOom0?goo@3lood0
_?ol0;cog@21ol?oo02Qood0_?oM087o`ool087oa?ol0?koo@3mood0oOom0?co
o@2loo`0_?oM087o`ool0=go09S5ood0_?oL087oa?ol087oa?ol0?koo@3mood0
oOom0?coo02moo`0_?oL087oa?ol0:7oo@2lom`0POo4oo`0POo4oo`0o_om0?go
o@3mood0o?ol0;goo02lom`0POo4oo`0XOom0;cog021olCoo021olCoo03nood0
oOom0?goo@3loo`0_Ool0;cog021olCoo03Mo`2`aOom0;goo03Tood0POo4oo`0
POo4oo`0o_om0?goo@3mood0o?ol0;goo02moo`0i?om087oa?ol0:7oo@2moo`0
i?om087oa?ol087oa?ol0?koo@3mood0oOom0?coo02moo`0_Ool0>Coo@21olCo
o02Qood0_Ool0>Coo@21olCoo021olCoo03nood0oOom0?goo@3loo`0_Ool0;go
o03Tood0POo4oo`0gOl0/<Goo@2mood0hoom087oa?ol087oa?om0?goo@3mood0
oOom0?coo02moo`0_Oom0>?oo@21olCoo02Qood0_Oom0>?oo@21olCoo021olCo
o@3mood0oOom0?goo@3loo`0_Ool0;goo@3Sood0POo4oo`0XOom0;goo@3Sood0
POo4oo`0POo4ood0oOom0?goo@3mood0o?ol0;goo02mood0hoom087oa?ol0=go
0;35ood0_Oom0>?oo@21olCoo021olCoo@3mood0oOom0?goo@3loo`0_Ool0;go
o@3Sood0POo4oo`0XOom0;goo@3Sood0POo4oo`0POo4ood0oOom0?goo@3mood0
o?ol0;goo02mood0hoom087oa?ol0:7oo@2mood0hoom087oa?ol087oa?om0?go
o@3mood0oOom0?coo02moo`0_Oom0>?oo@21olCoo03Mo`2`aOom0;goo03Uoo`0
POo4oo`0POo4oo`0o_om0?goo@3mood0o?ol0;goo02moo`0iOol087oa?ol0:7o
o@2moo`0iOol087oa?ol087oa?ol0?koo@3mood0oOom0?coo02moo`0_Ool0>Go
o021olCoo02Qood0_Ool0>Goo021olCoo021olCoo03nood0oOom0?goo@3loo`0
_Ool0;goo03Uoo`0POo4oo`0gOl0V<Goo@2lomd0POo3oo`0POo4oo`0o_om0?go
o@3mood0o?om0;coo02lomd0POo3oo`0XOom0;cog@21ol?oo021olCoo03nood0
oOom0?goo@3lood0_?ol0;cog@21ol?oo02Qood0_?oM087o`ool087oa?ol0?ko
o@3mood0oOom0?coo@2loo`0_?oM087o`ool0=go09S5ood0_?oM087o`ool087o
`oom0?koo@3mood0oOom0?goo02loo`0_?oM087o`ool0:7oo@2lomd0POo3oo`0
POo3ood0o_om0?goo@3mood0oOol0;coo02lomd0POo3oo`0XOom0;cog@21ol?o
o021ol?oo@3nood0oOom0?goo@3moo`0_?ol0;cog@21ol?oo03Mo`2KaOom0;co
g@21ol?oo021ol?oo001ooom0?goo@3mood0oOol0;coo02lomd0POo3oo`0XOom
0;cog@21ol?oo021ol?oo001ooom0?goo@3mood0oOol0;coo02lomd0POo3oo`0
XOom0;cog@21ol?oo021ol?oo001ooom0?goo@3mood0oOol0;coo02lomd0POo3
oo`0gOl0VlGoo@2koml0POo2oo`0POo3oo`00Oooo@3mood0oOom0?goo@2koo`0
^ooO087o`_ol0:7oo@2koml0POo2oo`0POo3oo`00Oooo@3mood0oOom0?goo@2k
oo`0^ooO087o`_ol0:7oo@2koml0POo2oo`0POo3oo`00Oooo@3mood0oOom0?go
o@2koo`0^ooO087o`_ol0=go09_5ood0^ooO087o`_ol087o`_om007oood0oOom
0?goo@3noo`0^ool0;_og`21ol;oo02Qood0^ooO087o`_ol087o`_om007oood0
oOom0?goo@3noo`0^ool0;_og`21ol;oo02Qood0^ooO087o`_ol087o`_om007o
ood0oOom0?goo@3noo`0^ool0;_og`21ol;oo03Mo`2`aOom0;_oo03Yoo`0POo2
oo`0POo2oo`00?om0?goo@3mood0o_ol0;_oo02koo`0jOol087o`_ol0:7oo@2k
oo`0jOol087o`_ol087o`_ol003oo@3mood0oOom0?koo02koo`0^ool0>Woo021
ol;oo02Qood0^ool0>Woo021ol;oo021ol;oo000ood0oOom0?goo@3noo`0^ool
0;_oo03Yoo`0POo2oo`0gOl0YlGoo@2joo`0j_om087o`Ool087o`Ooh0?goo@3m
ood00Oooo02joo`0^_ol0>[oo@21ol7oo02Qood0^_ol0>[oo@21ol7oo021ol7o
n03mood0oOom007ooo`0^_ol0;[oo03Zood0POo1oo`0XOom0;[oo03Zood0POo1
oo`0POo1ooP0oOom0?goo@01oool0;[oo02joo`0j_om087o`Ool0=go0:O5ood0
^Oom0>_oo021ol7oo021ol7on03mood0oOom007oood0^Ool0;Woo@3[oo`0POo1
oo`0XOom0;Woo@3[oo`0POo1oo`0POo1ooP0oOom0?goo@01ooom0;Woo02iood0
jool087o`Ool0:7oo@2iood0jool087o`Ool087o`Ooh0?goo@3mood00Oooo@2i
oo`0^Oom0>_oo021ol7oo03Mo`2HaOom0;Soo03^oo`0POo0oo`0POo0ooT0oOom
0?gom`2ioo`0^?ol0>koo021ol3oo02Qood0^?ol0>koo021ol3oo021ol3on@3m
ood0oOog0;Woo02hoo`0k_ol087o`?ol0:7oo@2hoo`0k_ol087o`?ol087o`?oi
0?goo@3mooL0^Ool0;Soo03^oo`0POo0oo`0gOl0P<Goo@2hon@0POo0oo`0POno
ooX0oOom0?gon02hoo`0^?oT087o`?ol0:7oo@2hon@0POo0oo`0POnoooX0oOom
0?gon02hoo`0^?oT087o`?ol0:7oo@2hon@0POo0oo`0POnoooX0oOom0?gon02h
oo`0^?oT087o`?ol0=go0835ood0]ooW087o__ol087o__oj0?koo@3mooT0]ool
0;Ooi`21okkoo02Qood0]ooW087o__ol087o__oj0?koo@3mooT0]ool0;Ooi`21
okkoo02Qood0]ooW087o__ol087o__oj0?koo@3mooT0]ool0;Ooi`21okkoo03M
o`23aOom0;Ooi`21okkoo021okkon@01ooom0?gon@2goo`0]ooW087o__ol0:7o
o@2gonL0POnnoo`0POnnooT00Oooo@3mooT0]ool0;Ooi`21okkoo02Qood0]ooW
087o__ol087o__oi007oood0oOoi0;Ooo02gonL0POnnoo`0gOl0J<Goo@2eon/0
POnloo`0POnlon/0]Ool0;Goj`21okcoo02Qood0]Oo[087o_?ol087o_?o[0;Go
o02eon/0POnloo`0XOom0;Goj`21okcoo021okcoj`2eoo`0]Oo[087o_?ol0=go
06S5ood0/oo^087o^ool087o^_o^0;Coo02conh0POnkoo`0XOom0;?okP21ok_o
o021ok[okP2doo`0/oo^087o^ool0:7oo@2conh0POnkoo`0POnjonh0]?ol0;?o
kP21ok_oo03Mo`1XaOom0;;ol@21okWoo021okWol@2boo`0/_oa087o^Ool0:7o
o@2boo40POnioo`0POnioo40/_ol0;;ol@21okWoo02Qood0/_oa087o^Ool087o
^Ooa0;;oo02boo40POnioo`0gOl0J<Goo@2aoo<0POnhoo`0POnhoo<0/Ool0;7o
l`21okSoo02Qood0/Ooc087o^?ol087o^?oc0;7oo02aoo<0POnhoo`0XOom0;7o
l`21okSoo021okSol`2aoo`0/Ooc087o^?ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05cmolVZo@21oh7of_ol087oPOoJoo`0POn1om[oo03IolVZo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03IolVZo@21oh7of_ol087oPOoJoo`0POn1om[o
o03Mo`0loOo9ZX40P@210840P@210840e@3molVZP@210840P@210840P@3E0?go
bJZ10840P@210840P@210=D003cmolVZP@210840P@210840P@3E0?gobJZ10840
P@210840P@210=D0oOo9ZX40P@210840P@210840e@00??gobJZ10840P@210840
P@210=D0oOo9ZX40P@210840P@210840e@3molVZP@210840P@210840P@3E000f
aOn10840P@210840P@210=D0aOn10840P@210840P@210=D0aOn10840P@210840
P@210=D003K5oh40P@210840P@210840e@35oh40P@210840P@210840e@35oh40
P@210840P@210840e@00E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1^
aOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087oPOoboo`0XOom0>[ooP21oh7o
m?ol087oPOoJoo`0k?on087oPOoboo`0XOom0>[ooP21oh7om?ol087oPOoJoo`0
k?on087oPOoboo`0gOl0K/Goo@3Zooh0POn1ooCoo021oh7of_ol0>cooP21oh7o
l_ol0:7oo@3Zooh0POn1ooCoo021oh7of_ol0>cooP21oh7ol_ol0:7oo@3Zooh0
POn1ooCoo021oh7of_ol0>cooP21oh7ol_ol0=go06k5ood0j_on087oPOodoo`0
POn1om[oo03/ooh0POn1oo;oo02Qood0j_on087oPOodoo`0POn1om[oo03/ooh0
POn1oo;oo02Qood0j_on087oPOodoo`0POn1om[oo03/ooh0POn1oo;oo03Mo`1^
aOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087oPOoboo`0XOom0>[ooP21oh7o
m?ol087oPOoJoo`0k?on087oPOoboo`0XOom0>[ooP21oh7om?ol087oPOoJoo`0
k?on087oPOoboo`0gOl0K/Goo@3Zooh0POn1ooCoo021oh7of_ol0>cooP21oh7o
l_ol0:7oo@3Zooh0POn1ooCoo021oh7of_ol0>cooP21oh7ol_ol0:7oo@3Zooh0
POn1ooCoo021oh7of_ol0>cooP21oh7ol_ol0=go06k5ood0j_on087oPOodoo`0
POn1om[oo03/ooh0POn1oo;oo02Qood0j_on087oPOodoo`0POn1om[oo03/ooh0
POn1oo;oo02Qood0j_on087oPOodoo`0POn1om[oo03/ooh0POn1oo;oo03Mo`1^
aOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087oPOoboo`0XOom0>[ooP21oh7o
m?ol087oPOoJoo`0k?on087oPOoboo`0XOom0>[ooP21oh7om?ol087oPOoJoo`0
k?on087oPOoboo`0gOl0K/Goo@3Zooh0POn1ooCoo021oh7of_ol0>cooP21oh7o
l_ol0:7oo@3Zooh0POn1ooCoo021oh7of_ol0>cooP21oh7ol_ol0:7oo@3Zooh0
POn1ooCoo021oh7of_ol0>cooP21oh7ol_ol0=go08K5ood0j_on087oPOodoo`0
m_of087oPOo`oo`0k?on087oPOoboo`0m_of0;Ooo@3Zooh0POn1ooCoo03fooH0
POn1oo3oo03/ooh0POn1oo;oo03fooH0]oom0>[ooP21oh7om?ol0?KomP21oh7o
l?ol0>cooP21oh7ol_ol0?KomP3co`26aOom0??ok021oh7ooOol0?KomP21oh7o
l?ol0?Gok021oh7onool0?KomP2good0loo/087oPOomoo`0m_of087oPOo`oo`0
mOo/087oPOokoo`0m_of0;Ooo@3con`0POn1oogoo03fooH0POn1oo3oo03eon`0
POn1oo_oo03fooH0lol0Q/Goo@3con`0POn1oogoo03fooH0POn1oo3oo03eon`0
POn1oo_oo03fooH0]oom0??ok021oh7ooOol0?KomP21oh7ol?ol0?Gok021oh7o
nool0?KomP2good0loo/087oPOomoo`0m_of087oPOo`oo`0mOo/087oPOokoo`0
m_of0??o06k5ood0loo/087oPOomoo`0POn1om[oo03eon`0POn1oo_oo02Qood0
loo/087oPOomoo`0POn1om[oo03eon`0POn1oo_oo02Qood0loo/087oPOomoo`0
POn1om[oo03eon`0POn1oo_oo03Mo`1^aOom0>[ooP21oh7om?ol087oPOoJoo`0
k?on087oPOoboo`0XOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087oPOoboo`0
XOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087oPOoboo`0gOl0K/Goo@3Zooh0
POn1ooCoo021oh7of_ol0>cooP21oh7ol_ol0:7oo@3Zooh0POn1ooCoo021oh7o
f_ol0>cooP21oh7ol_ol0:7oo@3Zooh0POn1ooCoo021oh7of_ol0>cooP21oh7o
l_ol0=go06k5ood0j_on087oPOodoo`0POn1om[oo03/ooh0POn1oo;oo02Qood0
j_on087oPOodoo`0POn1om[oo03/ooh0POn1oo;oo02Qood0j_on087oPOodoo`0
POn1om[oo03/ooh0POn1oo;oo03Mo`1^aOom0>[ooP21oh7om?ol087oPOoJoo`0
k?on087oPOoboo`0XOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087oPOoboo`0
XOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087oPOoboo`0gOl0K/Goo@3Zooh0
POn1ooCoo021oh7of_ol0>cooP21oh7ol_ol0:7oo@3Zooh0POn1ooCoo021oh7o
f_ol0>cooP21oh7ol_ol0:7oo@3Zooh0POn1ooCoo021oh7of_ol0>cooP21oh7o
l_ol0=go06k5ood0j_on087oPOodoo`0POn1om[oo03/ooh0POn1oo;oo02Qood0
j_on087oPOodoo`0POn1om[oo03/ooh0POn1oo;oo02Qood0j_on087oPOodoo`0
POn1om[oo03/ooh0POn1oo;oo03Mo`1^aOom0>[ooP21oh7om?ol087oPOoJoo`0
k?on087oPOoboo`0XOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087oPOoboo`0
XOom0>[ooP21oh7om?ol087oPOoJoo`0k?on087oPOoboo`0gOl0K/Goo@3Zooh0
POn1ooCoo021oh7of_ol0>cooP21oh7ol_ol0:7oo@3Zooh0POn1ooCoo021oh7o
f_ol0>cooP21oh7ol_ol0:7oo@3Zooh0POn1ooCoo021oh7of_ol0>cooP21oh7o
l_ol0=go06k5ood0j_on087oPOodoo`0POn1om[oo03/ooh0POn1oo;oo02Qood0
j_on087oPOodoo`0POn1om[oo03/ooh0POn1oo;oo02Qood0j_on087oPOodoo`0
POn1om[oo03/ooh0POn1oo;oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1L
aOom087oPOoJoo`0POnbo`00Z_ol087oPOoJoo`0XOom087oPOoJoo`0POnbo`00
Z_ol087oPOoJoo`0XOom087oPOoJoo`0POnbo`00Z_ol087oPOoJoo`0gOl0J<Go
o@2boo40POnioo`0POnioo40/_ol0;;ol@21okWoo02Qood0/_oa087o^Ool087o
^Ooa0;;oo02boo40POnioo`0XOom0;;ol@21okWoo021okWol@2boo`0/_oa087o
^Ool0=go06S5ood0/oo_087o^_ol087o^_o_0;?oo02conl0POnjoo`0XOom0;?o
k`21ok[oo021ok[ok`2coo`0/oo_087o^_ol0:7oo@2conl0POnjoo`0POnjonl0
/ool0;?ok`21ok[oo03Mo`1XaOom0;Cok021okcoo021ok_ok02eoo`0]?o/087o
_?ol0:7oo@2don`0POnloo`0POnkon`0]Ool0;Cok021okcoo02Qood0]?o/087o
_?ol087o^oo/0;Goo02don`0POnloo`0gOl0J<Goo@2fonT0POnmoo`0POnmonT0
]_ol0;Koj@21okgoo02Qood0]_oY087o_Ool087o_OoY0;Koo02fonT0POnmoo`0
XOom0;Koj@21okgoo021okgoj@2foo`0]_oY087o_Ool0=go0835ood0]oog0?go
m@21okkoo021okkoi`2goo`0]oog0?gom@21okkoo02Qood0]oog0?gom@21okko
o021okkoi`2goo`0]oog0?gom@21okkoo02Qood0]oog0?gom@21okkoo021okko
i`2goo`0]oog0?gom@21okkoo03Mo`2NaOom0;Oom`3mood00OoonP21okooo021
okooiP2goo`0]oog0?goo@01oooj087o_ool0:7oo@2gooL0oOom007oooX0POno
oo`0POnoonH0]ool0;Oom`3mood00OoonP21okooo02Qood0]oog0?goo@01oooj
087o_ool087o_ooV0;Ooo02gooL0oOom007oooX0POnooo`0gOl0/<Goo@2hoo/0
0?om0?goo@3nooX0POo0oo`0POo0on@0^?ol0;Son`00ood0oOom0?konP21ol3o
o02Qood0^?ok003oo@3mood0o_oj087o`?ol087o`?oT0;Soo02hoo/00?om0?go
o@3nooX0POo0oo`0XOom0;Son`00ood0oOom0?konP21ol3oo021ol3oi02hoo`0
^?ok003oo@3mood0o_oj087o`?ol0=go0;K5ood0^Ook007oood0oOom0?coo021
ol3oo021ol3oh`2ioo`0^Ook007oood0oOom0?coo021ol3oo02Qood0^Ook007o
ood0oOom0?coo021ol3oo021ol3oh`2ioo`0^Ook007oood0oOom0?coo021ol3o
o02Qood0^Ook007oood0oOom0?coo021ol3oo021ol3oh`2ioo`0^Ook007oood0
oOom0?coo021ol3oo03Mo`2laOom0;Woo@3mood0oOom0?con`21ol7oo021ol7o
o03[oo`0^_ol0;Woo@3mood0oOom0?con`21ol7oo02Qood0^Oom0?goo@3mood0
o?ok087o`Ool087o`Ool0>_oo02joo`0^Oom0?goo@3mood0o?ok087o`Ool0:7o
o@2iood0oOom0?goo@3loo/0POo1oo`0POo1oo`0jool0;[oo02iood0oOom0?go
o@3loo/0POo1oo`0gOl0_<Goo@2joo`0oOom0?goo@3looX0POo2oo`0POo1ood0
j_ol0;[oo02joo`0oOom0?goo@3looX0POo2oo`0XOom0;[oo03mood0oOom0?co
nP21ol;oo021ol7oo@3Zoo`0^_ol0;[oo03mood0oOom0?conP21ol;oo02Qood0
^_ol0?goo@3mood0o?oj087o`_ol087o`Oom0>[oo02joo`0^_ol0?goo@3mood0
o?oj087o`_ol0=go0;c5ood0^ook0?goo@3mood0o?oj087o`_ol087o`_ol0>Wo
o02koo`0^ook0?goo@3mood0o?oj087o`_ol0:7oo@2koo/0oOom0?goo@3looX0
POo2oo`0POo2oo`0jOol0;_oo02koo/0oOom0?goo@3looX0POo2oo`0XOom0;_o
n`3mood0oOom0?conP21ol;oo021ol;oo03Yoo`0^ool0;_on`3mood0oOom0?co
nP21ol;oo03Mo`2laOom0;_on`3mood0oOom0?conP21ol;oo021ol?oo03Wood0
^ool0;_on`3mood0oOom0?conP21ol;oo02Qood0^ook0?goo@3mood0o?oj087o
`_ol087o`ool0>Ooo@2koo`0^ook0?goo@3mood0o?oj087o`_ol0:7oo@2koo/0
oOom0?goo@3looX0POo2oo`0POo3oo`0ioom0;_oo02koo/0oOom0?goo@3looX0
POo2oo`0gOl0/<Goo@2koo/0oOom0?goo@3looX0POo2oo`0POo3omh0^ool0;_o
n`3mood0oOom0?conP21ol;oo02Qood0^ook0?goo@3mood0o?oj087o`_ol087o
`ooN0;_oo02koo/0oOom0?goo@3looX0POo2oo`0XOom0;_on`3mood0oOom0?co
nP21ol;oo021ol?ogP2koo`0^ook0?goo@3mood0o?oj087o`_ol0=go0;35ood0
_?oj0?goo@3mood0o?oi087o`ool087o`ooM0;coo02looX0oOom0?goo@3looT0
POo3oo`0XOom0;conP3mood0oOom0?con@21ol?oo021ol?og@2loo`0_?oj0?go
o@3mood0o?oi087o`ool0:7oo@2looX0oOom0?goo@3looT0POo3oo`0POo3omd0
_?ol0;conP3mood0oOom0?con@21ol?oo03Mo`2`aOom0;conP3mood0oOom0?co
n@21ol?oo021ol?og@2loo`0_?oj0?goo@3mood0o?oi087o`ool0:7oo@2looX0
oOom0?goo@3looT0POo3oo`0POo3omd0_?ol0;conP3mood0oOom0?con@21ol?o
o02Qood0_?oj0?goo@3mood0o?oi087o`ool087o`ooM0;coo02looX0oOom0?go
o@3looT0POo3oo`0gOl0/<Goo@2looX0oOom0?goo@3looT0POo3oo`0POo4om`0
_?ol0;conP3mood0oOom0?con@21ol?oo02Qood0_?oj0?goo@3mood0o?oi087o
`ool087oa?oL0;coo02looX0oOom0?goo@3looT0POo3oo`0XOom0;conP3mood0
oOom0?con@21ol?oo021olCog02loo`0_?oj0?goo@3mood0o?oi087o`ool0=go
0<S5ood0_Ooi0?goo@3mood0o?om003oo@21olCoo021olCof`2moo`0_Ooi0?go
o@3mood0o?om003oo@21olCoo02Qood0_Ooi0?goo@3mood0o?om003oo@21olCo
o021olCof`2moo`0_Ooi0?goo@3mood0o?om003oo@21olCoo02Qood0_Ooi0?go
o@3mood0o?om003oo@21olCoo021olCof`2moo`0_Ooi0?goo@3mood0o?om003o
o@21olCoo03Mo`3DaOom0;gon@3mood0oOom0?coo@00ood0POo4oo`0POo4ood0
i?ol0;goo02mooT0oOom0?goo@3lood00?om087oa?ol0:7oo@2mooT0oOom0?go
o@3lood00?om087oa?ol087oa?om0>Coo02moo`0_Ooi0?goo@3mood0o?om003o
o@21olCoo02Qood0_Ooi0?goo@3mood0o?om003oo@21olCoo021olCoo@3Too`0
_Ool0;gon@3mood0oOom0?coo@00ood0POo4oo`0gOl0e<Goo@2mooT0oOom0?go
o@3lood00?om087oa?ol087oa?om0>Coo02moo`0_Ooi0?goo@3mood0o?om003o
o@21olCoo02Qood0_Ooi0?goo@3mood0o?om003oo@21olCoo021olCoo@3Too`0
_Ool0;gon@3mood0oOom0?coo@00ood0POo4oo`0XOom0;gon@3mood0oOom0?co
o@00ood0POo4oo`0POo4ood0i?ol0;goo02mooT0oOom0?goo@3lood00?om087o
a?ol0=go0;c5ood0_Ooi0?goo@3mood0o?oh087oa?ol087oa?ol0>Goo02moo`0
_Ooi0?goo@3mood0o?oh087oa?ol0:7oo@2mooT0oOom0?goo@3looP0POo4oo`0
POo4oo`0iOol0;goo02mooT0oOom0?goo@3looP0POo4oo`0XOom0;gon@3mood0
oOom0?con021olCoo021olCoo03Uoo`0_Ool0;gon@3mood0oOom0?con021olCo
o03Mo`2laOom0;conP3mood0oOom0?con@21ol?oo021olCoo03Uood0_?ol0;co
nP3mood0oOom0?con@21ol?oo02Qood0_?oj0?goo@3mood0o?oi087o`ool087o
a?ol0>Goo@2loo`0_?oj0?goo@3mood0o?oi087o`ool0:7oo@2looX0oOom0?go
o@3looT0POo3oo`0POo4oo`0iOom0;coo02looX0oOom0?goo@3looT0POo3oo`0
gOl0/<Goo@2looX0oOom0?goo@3looT0POo3oo`0POo3omd0_?ol0;conP3mood0
oOom0?con@21ol?oo02Qood0_?oj0?goo@3mood0o?oi087o`ool087o`ooM0;co
o02looX0oOom0?goo@3looT0POo3oo`0XOom0;conP3mood0oOom0?con@21ol?o
o021ol?og@2loo`0_?oj0?goo@3mood0o?oi087o`ool0=go0;35ood0_?oj0?go
o@3mood0o?oi087o`ool087o`ooM0;coo02looX0oOom0?goo@3looT0POo3oo`0
XOom0;conP3mood0oOom0?con@21ol?oo021ol?og@2loo`0_?oj0?goo@3mood0
o?oi087o`ool0:7oo@2looX0oOom0?goo@3looT0POo3oo`0POo3omd0_?ol0;co
nP3mood0oOom0?con@21ol?oo03Mo`2`aOom0;_on`3mood0oOom0?conP21ol;o
o021ol?ogP2koo`0^ook0?goo@3mood0o?oj087o`_ol0:7oo@2koo/0oOom0?go
o@3looX0POo2oo`0POo3omh0^ool0;_on`3mood0oOom0?conP21ol;oo02Qood0
^ook0?goo@3mood0o?oj087o`_ol087o`ooN0;_oo02koo/0oOom0?goo@3looX0
POo2oo`0gOl0/<Goo@2koo/0oOom0?goo@3looX0POo2oo`0POo3omh0^ool0;_o
n`3mood0oOom0?conP21ol;oo02Qood0^ook0?goo@3mood0o?oj087o`_ol087o
`ooN0;_oo02koo/0oOom0?goo@3looX0POo2oo`0XOom0;_on`3mood0oOom0?co
nP21ol;oo021ol?ogP2koo`0^ook0?goo@3mood0o?oj087o`_ol0=go0;c5ood0
^ook0?goo@3mood0o?oj087o`_ol087o`_ol0>Woo02koo`0^ook0?goo@3mood0
o?oj087o`_ol0:7oo@2koo/0oOom0?goo@3looX0POo2oo`0POo2oo`0jOol0;_o
o02koo/0oOom0?goo@3looX0POo2oo`0XOom0;_on`3mood0oOom0?conP21ol;o
o021ol;oo03Yoo`0^ool0;_on`3mood0oOom0?conP21ol;oo03Mo`2laOom0;[o
o03mood0oOom0?con`21ol7oo021ol7oo03[oo`0^_ol0;[oo03mood0oOom0?co
n`21ol7oo02Qood0^_ol0?goo@3mood0o?ok087o`Ool087o`Ool0>_oo02joo`0
^_ol0?goo@3mood0o?ok087o`Ool0:7oo@2joo`0oOom0?goo@3loo/0POo1oo`0
POo1oo`0jool0;[oo02joo`0oOom0?goo@3loo/0POo1oo`0gOl0_<Goo@2iood0
oOom0?goo@3loo/0POo1oo`0POo1oo`0joom0;Woo02iood0oOom0?goo@3loo/0
POo1oo`0XOom0;Woo@3mood0oOom0?con`21ol7oo021ol7oo03[ood0^Ool0;Wo
o@3mood0oOom0?con`21ol7oo02Qood0^Oom0?goo@3mood0o?ok087o`Ool087o
`Ool0>_oo@2ioo`0^Oom0?goo@3mood0o?ok087o`Ool0=go0;c5ood0^?om0?ko
o@3mood0o?ol087o`?ol087o`?ol0>goo02ioo`0^?om0?koo@3mood0o?ol087o
`?ol0:7oo@2hood0o_om0?goo@3loo`0POo0oo`0POo0oo`0kOol0;Woo02hood0
o_om0?goo@3loo`0POo0oo`0XOom0;Soo@3nood0oOom0?coo021ol3oo021ol3o
o03]oo`0^Ool0;Soo@3nood0oOom0?coo021ol3oo03Mo`2J0000ohX@000000?X
0X@00004000000180000B0000100800300P00000000000Ola_@000000nP2O@00
0n`3jPIU0000887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ooGo0221oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOoeo`0PPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7omOl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ooGo
02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1
ooomZX7oPOn1oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZPOn1
oh7oPOn1oofZPOn1oh7oPOn1oofZPOn1oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7o
oJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1ooomZX7oPOn1oh7oPOomZX7oPOn1
oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZPOn1oh7oPOn1oofZPOn1oh7oPOn1oofZ
POn1oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol0
9h7oPOl1ooomZX7oPOn1oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3o`0WPOn1o`7o
oofZPOn1oh7oPOn1oofZPOn1oh7oPOn1oofZPOn1oh?o02N1oh7o0OoooJZ1oh7o
POn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1ooomZX7oPOn1oh7oPOom
ZX7oPOn1oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZPOn1oh7oPOn1oofZPOn1oh7o
POn1oofZPOn1oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1
oh7oPol09h7oPOl1ooomZX7oPOn1oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3o`0W
POn1o`7ooofZPOn1oh7oPOn1oofZPOn1oh7oPOn1oofZPOn1oh?o02N1oh7o0Ooo
oJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1ooomZX7oPOn1
oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZPOn1oh7oPOn1oofZ
POn1oh7oPOn1oofZPOn1oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1
oh7ooJZ1oh7oPol09h7oPOl1ooomZX7oPOn1oh7oPOomZX7oPOn1oh7oPOomZX7o
POn3o`0WPOn1o`7ooofZPOn1oh7oPOn1oofZPOn1oh7oPOn1oofZPOn1oh?o02N1
oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1ooom
ZX7oPOn1oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZPOn1oh7o
POn1oofZPOn1oh7oPOn1oofZPOn1oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1
oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1ooomZX7oPOn1oh7oPOomZX7oPOn1oh7o
POomZX7oPOn3o`0WPOn1o`7ooofZPOn1oh7oPOn1oofZPOn1oh7oPOn1oofZPOn1
oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7o
POl1ooomZX7oPOn1oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZ
POn1oh7oPOn1oofZPOn1oh7oPOn1oofZPOn1oh?o02N1oh7o0OoooJZ1oh7oPOn1
oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1ooomZX7oPOn1oh7oPOomZX7o
POn1oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZPOn1oh7oPOn1oofZPOn1oh7oPOn1
oofZPOn1oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7o
Pol09h7oPOl1ooomZX7oPOn1oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3o`0WPOn1
o`7ooofZPOn1oh7oPOn1oofZPOn1oh7oPOn1oofZPOn1oh?o02N1oh7o0OoooJZ1
oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1ooomZX7oPOn1oh7o
POomZX7oPOn1oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZPOn1oh7oPOn1oofZPOn1
oh7oPOn1oofZPOn1oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7o
oJZ1oh7oPol09h7oPOl1ooomZX7oPOn1oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3
o`0WPOn1o`7ooofZPOn1oh7oPOn1oofZPOn1oh7oPOn1oofZPOn1oh?o02N1oh7o
0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1ooomZX7o
POn1oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZPOn1oh7oPOn1
oofZPOn1oh7oPOn1oofZPOn1oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7o
POn1oh7ooJZ1oh7oPol09h7oPOl1ooomZX7oPOn1oh7oPOomZX7oPOn1oh7oPOom
ZX7oPOn3o`0WPOn1o`7ooofZPOn1oh7oPOn1oofZPOn1oh7oPOn1oofZPOn1oh?o
02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1
ooomZX7oPOn1oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZPOn1
oh7oPOn1oofZPOn1oh7oPOn1oofZPOn1oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7o
oJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1ooomZX7oPOn1oh7oPOomZX7oPOn1
oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZPOn1oh7oPOn1oofZPOn1oh7oPOn1oofZ
POn1oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol0
9h7oPOl1ooomZX7oPOn1oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3o`0TP@210840
P@3>0;3oP@210840P@3>0;3oP@210840P@3>0;3o02B10840P@210<h0/?n10840
P@210<h0/?n10840P@210<h0/?l09840P@210840cP2`oh40P@210840cP2`oh40
P@210840cP2`o`0TP@210840P@3>0;3oP@210840P@3>0;3oP@210840P@3>0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0?X7oPOonoo`0k?on087oPOobood0POn1ojgoo03/ooh0POn1oo;o
o@21oh7o[Ool0>cooP21oh7ol_om0;3o03j1oh7oo_ol0>cooP21oh7ol_om087o
POn]oo`0k?on087oPOobood0POn1ojgoo03/ooh0POn1oo;oo@2`o`0nPOn1ooko
o03/ooh0POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om087oPOn]oo`0k?on087o
POobood0/?l0?X7oPOonoo`0k?on087oPOobood0POn1ojgoo03/ooh0POn1oo;o
o@21oh7o[Ool0>cooP21oh7ol_om0;3o03j1oh7oo_ol0>cooP21oh7ol_om087o
POn]oo`0k?on087oPOobood0POn1ojgoo03/ooh0POn1oo;oo@2`o`0nPOn1ooko
o03/ooh0POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om087oPOn]oo`0k?on087o
POobood0/?l0?X7oPOonoo`0k?on087oPOobood0POn1ojgoo03/ooh0POn1oo;o
o@21oh7o[Ool0>cooP21oh7ol_om0;3o03j1oh7oo_ol0>cooP21oh7ol_om087o
POn]oo`0k?on087oPOobood0POn1ojgoo03/ooh0POn1oo;oo@2`o`0nPOn1ooko
o03/ooh0POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om087oPOn]oo`0k?on087o
POobood0/?l0?X7oPOonoo`0mOo/087oPOokood0POn1ojgoo03eon`0POn1oo_o
o@21oh7o[Ool0?Gok021oh7onoom0;3o03j1oh7oo_ol0?Gok021oh7onoom087o
POn]oo`0mOo/087oPOokood0POn1ojgoo03eon`0POn1oo_oo@2`o`0nPOn1ooko
o03eon`0POn1oo_oo@21oh7o[Ool0?Gok021oh7onoom087oPOn]oo`0mOo/087o
POokood0/?l0?X7oPOonoo`0k?on087oPOobood0POn1ojgoo03/ooh0POn1oo;o
o@21oh7o[Ool0>cooP21oh7ol_om0;3o03j1oh7oo_ol0>cooP21oh7ol_om087o
POn]oo`0k?on087oPOobood0POn1ojgoo03/ooh0POn1oo;oo@2`o`0nPOn1ooko
o03/ooh0POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om087oPOn]oo`0k?on087o
POobood0/?l0?X7oPOonoo`0k?on087oPOobood0POn1ojgoo03/ooh0POn1oo;o
o@21oh7o[Ool0>cooP21oh7ol_om0;3o03j1oh7oo_ol0>cooP21oh7ol_om087o
POn]oo`0k?on087oPOobood0POn1ojgoo03/ooh0POn1oo;oo@2`o`0nPOn1ooko
o03/ooh0POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om087oPOn]oo`0k?on087o
POobood0/?l0?X7oPOonoo`0k?on087oPOobood0POn1ojgoo03/ooh0POn1oo;o
o@21oh7o[Ool0>cooP21oh7ol_om0;3o03j1oh7oo_ol0>cooP21oh7ol_om087o
POn]oo`0k?on087oPOobood0POn1ojgoo03/ooh0POn1oo;oo@2`o`0nPOn1ooko
o03/ooh0POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om087oPOn]oo`0k?on087o
POobood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0>87oe_l00:[oo021oh7of_om087oQOl00:[o
o021oh7of_om087oQOl00:[oo021oh7of_om0;3o03j1omcol`2aoo`0/Ooc087o
^?om087oRooc0;7oo02aoo<0POnhood0POn;oo<0/Ool0;7ol`21okSoo@2`o`0n
POoMoo40/_ol0;;ol@21okWoo@21ohcol@2boo`0/_oa087o^Oom087oS?oa0;;o
o02boo40POniood0/?l0?X7ogoo]0;Coo02dond0POnkood0POn>ond0]?ol0;Co
k@21ok_oo@21ohkok@2doo`0]?o]087o^oom0;3o03j1on3ojP2foo`0]OoZ087o
_Oom087oSooZ0;Koo02eonX0POnmood0POn?onX0]_ol0;GojP21okgoo@2`o`1F
POoRooT0mooi0;Ooo02gooL0oOoe087o__om087oTOoi0?Oon@2goo`0]oog0?go
m@21okkoo@21oi7on@3gooT0]ool0;Oom`3mooD0POnnood0/?l0IH7ohooi0?Go
nP2goo`0]oog0?goo@01oooj087o_oom087oT_oi0?GonP2goo`0]oog0?goo@01
oooj087o_oom087oT_oi0?GonP2goo`0]oog0?goo@01oooj087o_oom0;3o06j1
onConP3aoo/0^?ol0;Son`00ood0oOom0?konP21ol3oo@21oi?onP3aoo/0^?ol
0;Son`00ood0oOom0?konP21ol3oo@21oi?onP3aoo/0^?ol0;Son`00ood0oOom
0?konP21ol3oo@2`o`1aPOoToo/0kook0;Woo02ioo/00Oooo@3mood0o?ol087o
`?om087oTook0>oon`2ioo`0^Ook007oood0oOom0?coo021ol3oo@21oi?on`3_
oo/0^Ool0;Won`01ooom0?goo@3loo`0POo0ood0/?l0HX7oiOoQ0;[oo02iood0
oOom0?goo@3loo/0POo1ood0POnDon40^_ol0;Woo@3mood0oOom0?con`21ol7o
o@21oiCoh@2joo`0^Oom0?goo@3mood0o?ok087o`Oom0;3o06:1onGoh@2joo`0
^_ol0?goo@3mood0o?oj087o`_om087oU?oQ0;[oo02joo`0oOom0?goo@3looX0
POo2ood0POnDon40^_ol0;[oo03mood0oOom0?conP21ol;oo@2`o`1RPOoVoml0
^ool0;_on`3mood0oOom0?conP21ol;oo@21oiGog`2koo`0^ook0?goo@3mood0
o?oj087o`_om087oUOoO0;_oo02koo/0oOom0?goo@3looX0POo2ood0/?l0HX7o
iooN0;_oo02koo/0oOom0?goo@3looX0POo2ood0POnFomh0^ool0;_on`3mood0
oOom0?conP21ol;oo@21oiKogP2koo`0^ook0?goo@3mood0o?oj087o`_om0;3o
06:1onOogP2koo`0^ook0?goo@3mood0o?oj087o`_om087oU_oN0;_oo02koo/0
oOom0?goo@3looX0POo2ood0POnFomh0^ool0;_on`3mood0oOom0?conP21ol;o
o@2`o`1^POoWoo`0iool0;coo02looX0oOom0?goo@3looT0POo3ood0POnFoo`0
iool0;coo02looX0oOom0?goo@3looT0POo3ood0POnFoo`0iool0;coo02looX0
oOom0?goo@3looT0POo3ood0/?l0KX7oioom0>Koo02loo`0_?oj0?goo@3mood0
o?oi087o`oom087oU_om0>Koo02loo`0_?oj0?goo@3mood0o?oi087o`oom087o
U_om0>Koo02loo`0_?oj0?goo@3mood0o?oi087o`oom0;3o06j1onSoo03Uood0
_?ol0;conP3mood0oOom0?con@21ol?oo@21oiOoo03Uood0_?ol0;conP3mood0
oOom0?con@21ol?oo@21oiOoo03Uood0_?ol0;conP3mood0oOom0?con@21ol?o
o@2`o`1^POoXoo`0iOol0;goo02mooT0oOom0?goo@3looP0POo4ood0POnGoo`0
iOol0;goo02mooT0oOom0?goo@3looP0POo4ood0POnGoo`0iOol0;goo02mooT0
oOom0?goo@3looP0POo4ood0/?l0KX7oj?oK0;goo02mooT0oOom0?goo@3lood0
0?om087oa?om087oUooK0;goo02mooT0oOom0?goo@3lood00?om087oa?om087o
UooK0;goo02mooT0oOom0?goo@3lood00?om087oa?om0;3o06j1onSof`2moo`0
_Ooi0?goo@3mood0o?om003oo@21olCoo@21oiOof`2moo`0_Ooi0?goo@3mood0
o?om003oo@21olCoo@21oiOof`2moo`0_Ooi0?goo@3mood0o?om003oo@21olCo
o@2`o`1RPOoXom/0_Ool0;gon@3mood0oOom0?con021olCoo@21oiOof`2moo`0
_Ooi0?goo@3mood0o?oh087oa?om087oUooK0;goo02mooT0oOom0?goo@3looP0
POo4ood0/?l0HX7oj?oL0;coo02looX0oOom0?goo@3looT0POo3ood0POnGom`0
_?ol0;conP3mood0oOom0?con@21ol?oo@21oiOog02loo`0_?oj0?goo@3mood0
o?oi087o`oom0;3o06j1onOoo@3Voo`0_?ol0;conP3mood0oOom0?con@21ol?o
o@21oiKoo@3Voo`0_?ol0;conP3mood0oOom0?con@21ol?oo@21oiKoo@3Voo`0
_?ol0;conP3mood0oOom0?con@21ol?oo@2`o`1^POoWoo`0iool0;coo02looX0
oOom0?goo@3looT0POo3ood0POnFoo`0iool0;coo02looX0oOom0?goo@3looT0
POo3ood0POnFoo`0iool0;coo02looX0oOom0?goo@3looT0POo3ood0/?l0KX7o
iool0>Ooo02loo`0^ook0?goo@3mood0o?oi087o`oom087oU_ol0>Ooo02loo`0
^ook0?goo@3mood0o?oi087o`oom087oU_ol0>Ooo02loo`0^ook0?goo@3mood0
o?oi087o`oom0;3o06j1onOoo03Xoo`0^ool0;_on`3mood0oOom0?conP21ol;o
o@21oiKoo03Xoo`0^ool0;_on`3mood0oOom0?conP21ol;oo@21oiKoo03Xoo`0
^ool0;_on`3mood0oOom0?conP21ol;oo@2`o`1RPOoVoml0^ool0;_on`3mood0
oOom0?conP21ol;oo@21oiGog`2koo`0^ook0?goo@3mood0o?oj087o`_om087o
UOoO0;_oo02koo/0oOom0?goo@3looX0POo2ood0/?l0HX7oiOoQ0;[oo02joo`0
oOom0?goo@3looX0POo2ood0POnDon40^_ol0;[oo03mood0oOom0?conP21ol;o
o@21oiCoh@2joo`0^_ol0?goo@3mood0o?oj087o`_om0;3o06:1onGoh@2joo`0
^_ol0?goo@3mood0o?ok087o`Oom087oU?oQ0;[oo02joo`0oOom0?goo@3loo/0
POo1ood0POnDon40^_ol0;[oo03mood0oOom0?con`21ol7oo@2`o`1RPOoTon<0
^Ool0;Woo03nood0oOom0?con`21ol7oo@21oi?oh`2ioo`0^Ool0?koo@3mood0
o?ok087o`Oom087oTooS0;Woo02ioo`0o_om0?goo@3loo/0POo1ood0/?l0LH7o
i?ok0?3on`2hoo`0^?ol007oood0oOom0?gon`21ol3oo@21oi?on`3`oo/0^?ol
0;Soo001ooom0?goo@3moo/0POo0ood0POnCoo/0l?ok0;Soo02hoo`00Oooo@3m
ood0oOok087o`?om0;3o06F1on?onP3cooX0^?ol0;SomP3mood00Ooon@21ol3o
o@21oi;onP3cooX0^?ol0;SomP3mood00Ooon@21ol3oo@21oi;onP3cooX0^?ol
0;SomP3mood00Ooon@21ol3oo@2`o`1FPOoRooT0mooi0;Ooo02gooL0oOoe087o
__om087oTOoi0?Oon@2goo`0]oog0?gom@21okkoo@21oi7on@3gooT0]ool0;Oo
m`3mooD0POnnood0/?l0?X7ohOoY0;Koo02fonT0POnmood0POn@onT0]_ol0;Ko
j@21okgoo@21oi3oj@2foo`0]_oY087o_Oom0;3o03j1omook02eoo`0]?o/087o
_?om087oS_o/0;Goo02don`0POnlood0POn>on`0]Ool0;Cok021okcoo@2`o`0n
POoNonl0/ool0;?ok`21ok[oo@21ohgok`2coo`0/oo_087o^_om087oSOo_0;?o
o02conl0POnjood0/?l0?X7og?oc0;7oo02aoo<0POnhood0POn;oo<0/Ool0;7o
l`21okSoo@21oh_ol`2aoo`0/Ooc087o^?om0;3o03R1omKo002Zoo`0POn1om[o
o@21ohGo002Zoo`0POn1om[oo@21ohGo002Zoo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0>87oPOonoo`0POn1om[o
o@39ZX7oPOoUoo`0POn1om[oo@39ZX7oPOoUoo`0POn1om[oo@39Z^So02Z10840
P@210<h0bJ[Xoh40P@210840cP39Z^SoP@210840P@3>0<VZj?l0:X40P@210840
cP39Z^SoP@210840P@3>0<VZj?n10840P@210<h0bJ[Xo`0ZP@210840P@3>0<VZ
j?n10840P@210<h0bJ[Xoh40P@210840cP39Z^So02B10840P@210<h0/?n10840
P@210<h0/?n10840P@210<h0/?l09840P@210840cP2`oh40P@210840cP2`oh40
P@210840cP2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o
[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0
POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7o
f_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0
POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o
[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0
POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7o
f_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0
POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7o
o_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0b
POn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0
/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7o
f_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0
POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o
[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0
POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7o
f_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0
POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o
[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0
POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7o
f_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0
POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7o
o_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0b
POn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0
/?l0?X7oPOonoo`0m_of087oPOo`ood0POn1ojgoo03fooH0POn1oo3oo@21oh7o
[Ool0?KomP21oh7ol?om0;3o03j1oh7oo_ol0?KomP21oh7ol?om087oPOn]oo`0
m_of087oPOo`ood0POn1ojgoo03fooH0POn1oo3oo@2`o`0nPOn1ookoo03fooH0
POn1oo3oo@21oh7o[Ool0?KomP21oh7ol?om087oPOn]oo`0m_of087oPOo`ood0
/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7o
f_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0
POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o
[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0
POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7o
f_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0
POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o
[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0
POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7o
f_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0
POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7o
o_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0b
POn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0
/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7o
f_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0
POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o
[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0
POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7o
f_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0
POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o
[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0
POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7o
f_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0
POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03R1omKo
002Zoo`0POn1om[oo@21ohGo002Zoo`0POn1om[oo@21ohGo002Zoo`0POn1om[o
o@2`o`0nPOoIooT0[_ol0:gonP21okGoo@21ohSon@2^oo`0[Ooj087o]Oom087o
R?oi0:koo02]ooX0POneood0/?l0?X7ogOoa0;;oo02boo40POniood0POn<oo40
/_ol0;;ol@21okWoo@21ohcol@2boo`0/_oa087o^Oom0;3o03j1omkok`2coo`0
/oo_087o^_om087oSOo_0;?oo02conl0POnjood0POn=onl0/ool0;?ok`21ok[o
o@2`o`0nPOoOon`0]Ool0;Cok021okcoo@21ohkok02eoo`0]?o/087o_?om087o
S_o/0;Goo02don`0POnlood0/?l0?X7ohOoY0;Koo02fonT0POnmood0POn@onT0
]_ol0;Koj@21okgoo@21oi3oj@2foo`0]_oY087o_Oom0;3o05V1on?on001ooom
0?gon@2goo`0]ooV087o_oom087oT_oh007oood0oOoi0;Ooo02gonH0POnoood0
POnBooP00Oooo@3mooT0]ool0;OoiP21okooo@2`o`1FPOoSooX0oOom0?gon02h
oo`0^?oT087o`?om087oT_oj0?goo@3mooP0^?ol0;Soi021ol3oo@21oi;onP3m
ood0oOoh0;Soo02hon@0POo0ood0/?l0EX7oi?oi0?goo@3mooP0^?ol0;Soi021
ol3oo@21oi?on@3mood0oOoh0;Soo02hon@0POo0ood0POnCooT0oOom0?gon02h
oo`0^?oT087o`?om0;3o06:1onCon@3mood0oOom003oo02ioo`0^OoR087o`Oom
087oTooi0?goo@3mood00?ol0;Woo02ion80POo1ood0POnCooT0oOom0?goo@00
oo`0^Ool0;WohP21ol7oo@2`o`1aPOoUooP0oOom0?goo@01oool0;[oo02joo`0
jool087o`Oom087oU?oh0?goo@3mood00Oooo02joo`0^_ol0>_oo021ol7oo@21
oiCon03mood0oOom007ooo`0^_ol0;[oo03[oo`0POo1ood0/?l0OH7oiOom003o
o@3mood0oOom007ooo`0^_ol0;[oo@3Yoo`0POo2ood0POnDood00?om0?goo@3m
ood00Oooo02joo`0^_om0>Woo021ol;oo@21oiCoo@00ood0oOom0?goo@01oool
0;[oo02jood0jOol087o`_om0;3o07Z1onOon`00ood0oOom0?goo@3noo`0^ool
0;_oo03Xood0POo2ood0POnFoo/00?om0?goo@3mood0o_ol0;_oo02koo`0j?om
087o`_om087oU_ok003oo@3mood0oOom0?koo02koo`0^ool0>Soo@21ol;oo@2`
o`1mPOoWoo`00Oooo@3mood0oOom0?goo@2koo`0^oom0>Ooo@21ol;oo@21oiKo
o001ooom0?goo@3mood0oOom0;_oo02kood0ioom087o`_om087oU_ol007oood0
oOom0?goo@3mood0^ool0;_oo@3Wood0POo2ood0/?l0LH7oiool007oood0oOom
0?goo@3moo`0_?ol0;cog@21ol?oo@21oiKoo001ooom0?goo@3mood0oOol0;co
o02lomd0POo3ood0POnFoo`00Oooo@3mood0oOom0?goo02loo`0_?oM087o`oom
0;3o06j1onOoo@3nood0oOom0?goo@3moo`0_?ol0;cog@21ol?oo@21oiKoo@3n
ood0oOom0?goo@3moo`0_?ol0;cog@21ol?oo@21oiKoo@3nood0oOom0?goo@3m
oo`0_?ol0;cog@21ol?oo@2`o`1^POoXoo`0o_om0?goo@3mood0o?om0;coo02l
omd0POo3ood0POnGoo`0o_om0?goo@3mood0o?om0;coo02lomd0POo3ood0POnG
oo`0o_om0?goo@3mood0o?om0;coo02lomd0POo3ood0/?l0KX7oj?ol0?koo@3m
ood0oOom0?coo02moo`0_?oL087oa?om087oUool0?koo@3mood0oOom0?coo02m
oo`0_?oL087oa?om087oUool0?koo@3mood0oOom0?coo02moo`0_?oL087oa?om
0;3o07Z1onSoo03nood0oOom0?goo@3loo`0_Ool0;goo03Tood0POo4ood0POnG
oo`0o_om0?goo@3mood0o?ol0;goo02moo`0i?om087oa?om087oUool0?koo@3m
ood0oOom0?coo02moo`0_Ool0>Coo@21olCoo@2`o`1jPOoXood0oOom0?goo@3m
ood0o?ol0;goo02mood0hoom087oa?om087oUoom0?goo@3mood0oOom0?coo02m
oo`0_Oom0>?oo@21olCoo@21oiOoo@3mood0oOom0?goo@3loo`0_Ool0;goo@3S
ood0POo4ood0/?l0NX7oj?om0?goo@3mood0oOom0?coo02moo`0_Oom0>?oo@21
olCoo@21oiOoo@3mood0oOom0?goo@3loo`0_Ool0;goo@3Sood0POo4ood0POnG
ood0oOom0?goo@3mood0o?ol0;goo02mood0hoom087oa?om0;3o07Z1onSoo03n
ood0oOom0?goo@3loo`0_Ool0;goo03Uoo`0POo4ood0POnGoo`0o_om0?goo@3m
ood0o?ol0;goo02moo`0iOol087oa?om087oUool0?koo@3mood0oOom0?coo02m
oo`0_Ool0>Goo021olCoo@2`o`1^POoXoo`0o_om0?goo@3mood0o?om0;coo02l
omd0POo3ood0POnGoo`0o_om0?goo@3mood0o?om0;coo02lomd0POo3ood0POnG
oo`0o_om0?goo@3mood0o?om0;coo02lomd0POo3ood0/?l0KX7oioom0?koo@3m
ood0oOom0?goo02loo`0_?oM087o`oom087oU_om0?koo@3mood0oOom0?goo02l
oo`0_?oM087o`oom087oU_om0?koo@3mood0oOom0?goo02loo`0_?oM087o`oom
0;3o0761onOoo001ooom0?goo@3mood0oOol0;coo02lomd0POo3ood0POnFoo`0
0Oooo@3mood0oOom0?goo02loo`0_?oM087o`oom087oU_ol007oood0oOom0?go
o@3moo`0_?ol0;cog@21ol?oo@2`o`1aPOoWoo`00Oooo@3mood0oOom0?goo@2k
oo`0^ooO087o`_om087oU_ol007oood0oOom0?goo@3mood0^ool0;_og`21ol;o
o@21oiKoo001ooom0?goo@3mood0oOom0;_oo02koml0POo2ood0/?l0LH7oi_om
007oood0oOom0?goo@3noo`0^ool0;_og`21ol;oo@21oiGoo@01ooom0?goo@3m
ood0o_ol0;_oo02koml0POo2ood0POnEood00Oooo@3mood0oOom0?koo02koo`0
^ooO087o`_om0;3o07Z1onKoo000ood0oOom0?goo@3noo`0^ool0;_oo03Yoo`0
POo2ood0POnEoo`00?om0?goo@3mood0o_ol0;_oo02koo`0jOol087o`_om087o
UOol003oo@3mood0oOom0?koo02koo`0^ool0>Woo021ol;oo@2`o`1aPOoUooP0
oOom0?goo@01oool0;[oo02joo`0j_om087o`Oom087oU?oh0?goo@3mood00Ooo
o02joo`0^_ol0>[oo@21ol7oo@21oiCon03mood0oOom007ooo`0^_ol0;[oo03Z
ood0POo1ood0/?l0LH7oiOoh0?goo@3mood00Oooo@2ioo`0^Oom0>_oo021ol7o
o@21oiCon03mood0oOom007oood0^Ool0;Woo@3[oo`0POo1ood0POnDooP0oOom
0?goo@01ooom0;Woo02iood0jool087o`Oom0;3o06:1onCon@3mood0oOog0;Wo
o02hoo`0k_ol087o`?om087oTooi0?goo@3mooL0^Ool0;Soo03^oo`0POo0ood0
POnCooT0oOom0?gom`2ioo`0^?ol0>koo021ol3oo@2`o`1FPOoSooX0oOom0?go
n02hoo`0^?oT087o`?om087oT_oj0?goo@3mooP0^?ol0;Soi021ol3oo@21oi;o
nP3mood0oOoh0;Soo02hon@0POo0ood0/?l0EX7oh_oj0?koo@3mooT0]ool0;Oo
i`21okkoo@21oi7onP3nood0oOoi0;Ooo02gonL0POnnood0POnAooX0o_om0?go
n@2goo`0]ooW087o__om0;3o05V1on;on@01ooom0?gon@2goo`0]ooW087o__om
087oTOoi007oood0oOoi0;Ooo02gonL0POnnood0POnAooT00Oooo@3mooT0]ool
0;Ooi`21okkoo@2`o`0nPOoPon/0]Ool0;Goj`21okcoo@21ohooj`2eoo`0]Oo[
087o_?om087oSoo[0;Goo02eon/0POnlood0/?l0?X7og_o^0;Coo02conh0POnk
ood0POn=onh0]?ol0;?okP21ok_oo@21ohgokP2doo`0/oo^087o^oom0;3o03j1
omgol@2boo`0/_oa087o^Oom087oS?oa0;;oo02boo40POniood0POn<oo40/_ol
0;;ol@21okWoo@2`o`0nPOoLoo<0/Ool0;7ol`21okSoo@21oh_ol`2aoo`0/Ooc
087o^?om087oRooc0;7oo02aoo<0POnhood0/?l0<X7oPOonoo`0POn1om[oo@21
oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJ
ood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021
oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOon
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1
oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`
o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021
oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]
oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21
oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021
oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21
oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJ
ood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021
oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOon
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1
oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`
o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021
oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]
oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21
oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021
oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21
oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJ
ood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021
oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOon
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1
oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`
o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021
oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]
oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21
oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021
oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21
oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJ
ood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021
oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOon
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1
oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`
o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021
oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]
oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21
oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021
oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21
oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJ
ood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021
oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOon
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1
oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`
o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021
oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]
oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21
oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021
oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21
oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJ
ood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021
oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOon
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1
oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`
o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021
oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]
oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21
oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021
oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21
oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJ
ood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021
oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOon
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1
oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`
o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021
oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]
oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21
oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021
oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21
oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJ
ood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021
oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOon
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1
oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`
o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021
oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]
oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21
oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021
oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21
oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJ
ood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021
oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOon
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1
oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`
o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021
oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]
oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21
oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021
oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21
oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03R1oh7oo_ol087oPOoJ
ood0bJZ1oh7oiOol087oPOoJood0bJZ1oh7oiOol087oPOoJood0bJ[Xo`0ZP@21
0840P@3>0<VZj?n10840P@210<h0bJ[Xoh40P@210840cP39Z^So02Z10840P@21
0<h0bJ[Xoh40P@210840cP39Z^SoP@210840P@3>0<VZj?l0:X40P@210840cP39
Z^SoP@210840P@3>0<VZj?n10840P@210<h0bJ[Xo`0TP@210840P@3>0;3oP@21
0840P@3>0;3oP@210840P@3>0;3o02B10840P@210<h0/?n10840P@210<h0/?n1
0840P@210<h0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1
ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om
087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1
om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool
087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1
ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om
087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1
om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol
087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1
ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0
<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om
0;3o03j1oh7oo_ol0>cooP21oh7ol_om087oPOn]oo`0k?on087oPOobood0POn1
ojgoo03/ooh0POn1oo;oo@2`o`0nPOn1ookoo03/ooh0POn1oo;oo@21oh7o[Ool
0>cooP21oh7ol_om087oPOn]oo`0k?on087oPOobood0/?l0?X7oPOonoo`0k?on
087oPOobood0POn1ojgoo03/ooh0POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om
0;3o03j1oh7oo_ol0>cooP21oh7ol_om087oPOn]oo`0k?on087oPOobood0POn1
ojgoo03/ooh0POn1oo;oo@2`o`0nPOn1ookoo03/ooh0POn1oo;oo@21oh7o[Ool
0>cooP21oh7ol_om087oPOn]oo`0k?on087oPOobood0/?l0?X7oPOonoo`0k?on
087oPOobood0POn1ojgoo03/ooh0POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om
0;3o03j1oh7oo_ol0>cooP21oh7ol_om087oPOn]oo`0k?on087oPOobood0POn1
ojgoo03/ooh0POn1oo;oo@2`o`0nPOn1ookoo03/ooh0POn1oo;oo@21oh7o[Ool
0>cooP21oh7ol_om087oPOn]oo`0k?on087oPOobood0/?l0?X7oPOonoo`0k?on
087oPOobood0POn1ojgoo03/ooh0POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om
0;3o03j1oh7oo_ol0?Gok021oh7onoom087oPOn]oo`0mOo/087oPOokood0POn1
ojgoo03eon`0POn1oo_oo@2`o`0nPOn1ookoo03eon`0POn1oo_oo@21oh7o[Ool
0?Gok021oh7onoom087oPOn]oo`0mOo/087oPOokood0/?l0?X7oPOonoo`0mOo/
087oPOokood0POn1ojgoo03eon`0POn1oo_oo@21oh7o[Ool0?Gok021oh7onoom
0;3o03j1oh7oo_ol0>cooP21oh7ol_om087oPOn]oo`0k?on087oPOobood0POn1
ojgoo03/ooh0POn1oo;oo@2`o`0nPOn1ookoo03/ooh0POn1oo;oo@21oh7o[Ool
0>cooP21oh7ol_om087oPOn]oo`0k?on087oPOobood0/?l0?X7oPOonoo`0k?on
087oPOobood0POn1ojgoo03/ooh0POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om
0;3o03j1oh7oo_ol0>cooP21oh7ol_om087oPOn]oo`0k?on087oPOobood0POn1
ojgoo03/ooh0POn1oo;oo@2`o`0nPOn1ookoo03/ooh0POn1oo;oo@21oh7o[Ool
0>cooP21oh7ol_om087oPOn]oo`0k?on087oPOobood0/?l0?X7oPOonoo`0k?on
087oPOobood0POn1ojgoo03/ooh0POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om
0;3o03j1oh7oo_ol0>cooP21oh7ol_om087oPOn]oo`0k?on087oPOobood0POn1
ojgoo03/ooh0POn1oo;oo@2`o`0nPOn1ookoo03/ooh0POn1oo;oo@21oh7o[Ool
0>cooP21oh7ol_om087oPOn]oo`0k?on087oPOobood0/?l0?X7oPOonoo`0k?on
087oPOobood0POn1ojgoo03/ooh0POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om
0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1
om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool
087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1
ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om
087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1
om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool
087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1
ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om
087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1
om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol
087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1
ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0
<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om
0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1
om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool
087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1
ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om
087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1
om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool
087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1
ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om
087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1
om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol
087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1
ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0
<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om
0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1
om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool
087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1
ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om
087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1
om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool
087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1
ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om
087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1
om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol
087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1
ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0
<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om
0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1
om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool
087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1
ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om
087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1
om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool
087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1
ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om
087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1
om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol
087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1
ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0
<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om
0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1
om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool
087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1
ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om
087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1
om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool
087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1
ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om
087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1
om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol
087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1
ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0
<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om
0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1
om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool
087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1
ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om
087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1
om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool
087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1
ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om
087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0BX7oPOonoo`0POn1
om[oo@3`ooh0m?on087oPOoAoo`0POn1om[oo@3`ooh0m?on087oPOoAoo`0POn1
om[oo@3`ooh0m?on0=Co04Z1oh7oo_ol087oPOoJood0koon0?KooP21oh7od?ol
087oPOoJood0koon0?KooP21oh7od?ol087oPOoJood0koon0?KooP3Co`1:POn1
ookoo021oh7of_om0>oooP3fooh0POn1om3oo021oh7of_om0>oooP3fooh0POn1
om3oo021oh7of_om0>oooP3fooh0dol0BX7oPOonoo`0POn1om[oo@3^ooh0n?om
087oPOo@oo`0POn1om[oo@3^ooh0n?om087oPOo@oo`0POn1om[oo@3^ooh0n?om
0=?o04Z1oh7oo_ol087oPOoJood0k_on0?SooP21oh7ocool087oPOoJood0k_on
0?SooP21oh7ocool087oPOoJood0k_on0?SooP3Bo`1:POn1ookoo021oh7of_om
0>koo@3iooh0POn1olooo021oh7of_om0>koo@3iooh0POn1olooo021oh7of_om
0>koo@3iooh0d_l0BX7oPOonoo`0POn1om[oo@3]ooh0n_on087oPOo>oo`0POn1
om[oo@3]ooh0n_on087oPOo>oo`0POn1om[oo@3]ooh0n_on0=7o04Z1oh7oo_ol
087oPOoJood0kOom0?_ooP21oh7oc_ol087oPOoJood0kOom0?_ooP21oh7oc_ol
087oPOoJood0kOom0?_ooP3Ao`1:POn1ookoo021oh7of_om0>cooP3kooh0POn1
olkoo021oh7of_om0>cooP3kooh0POn1olkoo021oh7of_om0>cooP3kooh0dOl0
BX7oPOonoo`0POn1om[oo@3/ood0oOon087oPOo=oo`0POn1om[oo@3/ood0oOon
087oPOo=oo`0POn1om[oo@3/ood0oOon0=3o04Z1oh7oo_ol087oPOoJood0joon
0?gooP21oh7ocOol087oPOoJood0joon0?gooP21oh7ocOol087oPOoJood0joon
0?gooP3@o`1@POoFo`00Z_ol087oPOoJood0joon0?koo@21ojGo002Zoo`0POn1
om[oo@3[ooh0o_om087oYOl00:[oo021oh7of_om0>_ooP3nood0d?l0FH7og?oc
0;7oo02aoo<0POnhood0j_on007oooh0POnZoo<0/Ool0;7ol`21okSoo@3Zooh0
0OoooP21oj[ol`2aoo`0/Ooc087o^?om0>[ooP01ooon0<oo05V1omgol@2boo`0
/_oa087o^Oom0>[ooP01ooon087oZooa0;;oo02boo40POniood0j_on007oooh0
POn[oo40/_ol0;;ol@21okWoo@3Zooh00OoooP3?o`1FPOoOond0]?ol0;Cok@21
ok_oo@3Yoo/0n?oj087o_?o]0;Coo02dond0POnkood0jOok0?SonP21okcok@2d
oo`0]?o]087o^oom0>Won`3hooX0g_l0EX7oh?oZ0;Koo02eonX0POnmood0jOok
0?_om@21okoojP2foo`0]OoZ087o_Oom0>Won`3kooD0POnoonX0]_ol0;GojP21
okgoo@3Yoo/0nooe0>3o06j1on;on@3gooT0]ool0;Oom`3mooD0POnnood0jOok
0?col`21ol;on@3gooT0]ool0;Oom`3mooD0POnnood0jOok0?col`21ol;on@3g
ooT0]ool0;Oom`3mooD0POnnood0jOok0?col`3Qo`29POoSooT0mOoj0;Ooo02g
ooL0oOom007oooX0POnoood0j?om0?_oo@3jood0POo4ooT0mOoj0;Ooo02gooL0
oOom007oooX0POnoood0j?om0?_oo@3jood0POo4ooT0mOoj0;Ooo02gooL0oOom
007oooX0POnoood0j?om0?_oo@3jood0h_l0TX7oi?oj0?7on`2hoo`0^?ok003o
o@3mood0o_oj087o`?om0>Soo@3looh0moon087oaOoj0?7on`2hoo`0^?ok003o
o@3mood0o_oj087o`?om0>Soo@3looh0moon087oaOoj0?7on`2hoo`0^?ok003o
o@3mood0o_oj087o`?om0>Soo@3looh0moon0>;o08V1onCon`3_oo/0^Ool0;Wo
n`01ooom0?goo@3loo`0POo0ood0j?on0?_ooP21okSon`3_oo/0^Ool0;Won`01
ooom0?goo@3loo`0POo0ood0j?on0?_ooP21okSon`3_oo/0^Ool0;Won`01ooom
0?goo@3loo`0POo0ood0j?on0?_ooP3Eo`1jPOoUon40^_ol0;Woo@3mood0oOom
0?con`21ol7oo@3Xooh0noon087o^OoQ0;[oo02iood0oOom0?goo@3loo/0POo1
ood0j?on0?_ooP21okWoh@2joo`0^Oom0?goo@3mood0o?ok087o`Oom0>SooP3k
ooh0eOl0NX7oiOoQ0;[oo02joo`0oOom0?goo@3looX0POo2ood0jOon0?Woo@21
ok_oh@2joo`0^_ol0?goo@3mood0o?oj087o`_om0>WooP3iood0POnkon40^_ol
0;[oo03mood0oOom0?conP21ol;oo@3Yooh0nOom0=Oo07Z1onKog`2koo`0^ook
0?goo@3mood0o?oj087o`_om0>WooP3iooT0POo0oml0^ool0;_on`3mood0oOom
0?conP21ol;oo@3Yooh0nOoi087o`?oO0;_oo02koo/0oOom0?goo@3looX0POo2
ood0jOon0?Won@3Ko`1jPOoWomh0^ool0;_on`3mood0oOom0?conP21ol;oo@3Z
ooh0m_og087oaOoN0;_oo02koo/0oOom0?goo@3looX0POo2ood0j_on0?Kom`21
olGogP2koo`0^ook0?goo@3mood0o?oj087o`_om0>[ooP3fooL0gol0NX7oiooN
0;_oo02koo/0oOom0?goo@3looX0POo2ood0joom0??on@21olKogP2koo`0^ook
0?goo@3mood0o?oj087o`_om0>_oo@3cooT0POo6omh0^ool0;_on`3mood0oOom
0?conP21ol;oo@3[ood0looi0>3o08J1onOoo03Woo`0_?ol0;conP3mood0oOom
0?con@21ol?oo@3`ooT0k_ol087oaool0>Ooo02loo`0_?oj0?goo@3mood0o?oi
087o`oom0?3on@3^oo`0POo7oo`0iool0;coo02looX0oOom0?goo@3looT0POo3
ood0l?oi0>koo03Qo`26POoWood0i_ol0;coo02looX0oOom0?goo@3looT0POo3
ood0l?oj0>_oo@21olSoo@3Voo`0_?ol0;conP3mood0oOom0?con@21ol?oo@3`
ooX0joom087ob?om0>Koo02loo`0_?oj0?goo@3mood0o?oi087o`oom0?3onP3[
ood0h_l0QX7oj?ol0>Goo@2loo`0_?oj0?goo@3mood0o?oi087o`oom0?3oo03X
ooh0POo9oo`0iOom0;coo02looX0oOom0?goo@3looT0POo3ood0l?ol0>SooP21
olWoo03Uood0_?ol0;conP3mood0oOom0?con@21ol?oo@3`oo`0j?on0>;o07Z1
onSoo03Uoo`0_Ool0;gon@3mood0oOom0?con021olCoo@3Booh0POo9oo`0iOol
0;goo02mooT0oOom0?goo@3looP0POo4ood0d_on087obOol0>Goo02moo`0_Ooi
0?goo@3mood0o?oh087oa?om0=;ooP3Ro`26POoXom/0_Ool0;gon@3mood0oOom
0?coo@00ood0POo4ood0goon0?Soo@21olWof`2moo`0_Ooi0?goo@3mood0o?om
003oo@21olCoo@3Oooh0n?om087obOoK0;goo02mooT0oOom0?goo@3lood00?om
087oa?om0=oooP3hood0h_l0QX7oj?oK0;goo02mooT0oOom0?goo@3lood00?om
087oa?om0=ooo@3jood0POo8om/0_Ool0;gon@3mood0oOom0?coo@00ood0POo4
ood0goom0?[oo@21olSof`2moo`0_Ooi0?goo@3mood0o?om003oo@21olCoo@3O
ood0n_om0>7o06j1onSof`2moo`0_Ooi0?goo@3mood0o?oh087oa?om0=kol`21
olSof`2moo`0_Ooi0?goo@3mood0o?oh087oa?om0=kol`21olSof`2moo`0_Ooi
0?goo@3mood0o?oh087oa?om0=kol`3Qo`1^POoXom`0_?ol0;conP3mood0oOom
0?con@21ol?oo@3MooH0POo6om`0_?ol0;conP3mood0oOom0?con@21ol?oo@3M
ooH0POo6om`0_?ol0;conP3mood0oOom0?con@21ol?oo@3MooH0gol0NX7oioom
0>Koo02loo`0_?oj0?goo@3mood0o?oi087o`oom0=_onP21ol?oo@3Voo`0_?ol
0;conP3mood0oOom0?con@21ol?oo@3KooX0POo3ood0i_ol0;coo02looX0oOom
0?goo@3looT0POo3ood0fooj0=go06j1onOoo03Woo`0_?ol0;conP3mood0oOom
0?con@21ol?oo@21oiKoo03Woo`0_?ol0;conP3mood0oOom0?con@21ol?oo@21
oiKoo03Woo`0_?ol0;conP3mood0oOom0?con@21ol?oo@2`o`1^POoWoo`0iool
0;coo02koo/0oOom0?goo@3looT0POo3ood0POnFoo`0iool0;coo02koo/0oOom
0?goo@3looT0POo3ood0POnFoo`0iool0;coo02koo/0oOom0?goo@3looT0POo3
ood0/?l0KX7oiool0>Soo02koo`0^ook0?goo@3mood0o?oj087o`_om087oU_ol
0>Soo02koo`0^ook0?goo@3mood0o?oj087o`_om087oU_ol0>Soo02koo`0^ook
0?goo@3mood0o?oj087o`_om0;3o06:1onKog`2koo`0^ook0?goo@3mood0o?oj
087o`_om087oUOoO0;_oo02koo/0oOom0?goo@3looX0POo2ood0POnEoml0^ool
0;_on`3mood0oOom0?conP21ol;oo@2`o`1RPOoUon40^_ol0;[oo03mood0oOom
0?conP21ol;oo@21oiCoh@2joo`0^_ol0?goo@3mood0o?oj087o`_om087oU?oQ
0;[oo02joo`0oOom0?goo@3looX0POo2ood0/?l0HX7oiOoQ0;[oo02joo`0oOom
0?goo@3loo/0POo1ood0POnDon40^_ol0;[oo03mood0oOom0?con`21ol7oo@21
oiCoh@2joo`0^_ol0?goo@3mood0o?ok087o`Oom0;3o06:1onCoh`2ioo`0^Ool
0?koo@3mood0o?ok087o`Oom087oTooS0;Woo02ioo`0o_om0?goo@3loo/0POo1
ood0POnCon<0^Ool0;Woo03nood0oOom0?con`21ol7oo@2`o`1aPOoToo/0l?ok
0;Soo02hoo`00Oooo@3mood0oOok087o`?om087oTook0?3on`2hoo`0^?ol007o
ood0oOom0?gon`21ol3oo@21oi?on`3`oo/0^?ol0;Soo001ooom0?goo@3moo/0
POo0ood0/?l0IH7ohooj0??onP2hoo`0^?of0?goo@01oooi087o`?om087oT_oj
0??onP2hoo`0^?of0?goo@01oooi087o`?om087oT_oj0??onP2hoo`0^?of0?go
o@01oooi087o`?om0;3o05J1on;on@3gooT0]ool0;Oom`3mooD0POnnood0POnA
ooT0mooi0;Ooo02gooL0oOoe087o__om087oTOoi0?Oon@2goo`0]oog0?gom@21
okkoo@2`o`0nPOoQonT0]_ol0;Koj@21okgoo@21oi3oj@2foo`0]_oY087o_Oom
087oT?oY0;Koo02fonT0POnmood0/?l0?X7ogoo/0;Goo02don`0POnlood0POn>
on`0]Ool0;Cok021okcoo@21ohkok02eoo`0]?o/087o_?om0;3o03j1omkok`2c
oo`0/oo_087o^_om087oSOo_0;?oo02conl0POnjood0POn=onl0/ool0;?ok`21
ok[oo@2`o`0nPOoLoo<0/Ool0;7ol`21okSoo@21oh_ol`2aoo`0/Ooc087o^?om
087oRooc0;7oo02aoo<0POnhood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool
087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1
ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om
087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1
om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol
087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1
ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0
<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om
0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1
om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool
087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1
ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om
087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1
om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool
087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1
ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om
087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1
om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol
087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1
ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0
<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om
0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1
om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool
087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1
ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om
087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1
om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool
087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1
ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om
087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1
om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol
087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1
ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0
<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om
0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1
om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool
087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1
ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om
087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1
om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool
087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1
ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om
087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1
om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol
087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1
ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0
<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om
0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1
om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool
087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1
ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om
087oPOn]oo`0POn1om[oo@2`o`0hPOn1ookoo021oh7of_om0<VZPOn1onGoo021
oh7of_om0<VZPOn1onGoo021oh7of_om0<VZj?l0:X40P@210840cP39Z^SoP@21
0840P@3>0<VZj?n10840P@210<h0bJ[Xo`0ZP@210840P@3>0<VZj?n10840P@21
0<h0bJ[Xoh40P@210840cP39Z^So02Z10840P@210<h0bJ[Xoh40P@210840cP39
Z^SoP@210840P@3>0<VZj?l09840P@210840cP2`oh40P@210840cP2`oh40P@21
0840cP2`o`0TP@210840P@3>0;3oP@210840P@3>0;3oP@210840P@3>0;3o03:1
oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`
o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021
oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]
oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21
oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021
oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21
oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJ
ood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021
oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOon
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1
oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`
o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021
oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]
oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21
oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0POn1ojgoo021oh7of_om0;3o03j1oh7oo_ol0?KomP21oh7ol?om087oPOn]
oo`0m_of087oPOo`ood0POn1ojgoo03fooH0POn1oo3oo@2`o`0nPOn1ookoo03f
ooH0POn1oo3oo@21oh7o[Ool0?KomP21oh7ol?om087oPOn]oo`0m_of087oPOo`
ood0/?l0?X7oPOonoo`0m_of087oPOo`ood0POn1ojgoo03fooH0POn1oo3oo@21
oh7o[Ool0?KomP21oh7ol?om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021
oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21
oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJ
ood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021
oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOon
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1
oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`
o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021
oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]
oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21
oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021
oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21
oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJ
ood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021
oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOon
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1
oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`
o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021
oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]
oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21
oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJ
ood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021
oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]
oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0>87oe_l00:[oo021oh7of_om
087oQOl00:[oo021oh7of_om087oQOl00:[oo021oh7of_om0;3o03j1omWon@2^
oo`0[Ooj087o]Oom087oR?oi0:koo02]ooX0POneood0POn8ooT0[_ol0:gonP21
okGoo@2`o`0nPOoMoo40/_ol0;;ol@21okWoo@21ohcol@2boo`0/_oa087o^Oom
087oS?oa0;;oo02boo40POniood0/?l0?X7og_o_0;?oo02conl0POnjood0POn=
onl0/ool0;?ok`21ok[oo@21ohgok`2coo`0/oo_087o^_om0;3o03j1omook02e
oo`0]?o/087o_?om087oS_o/0;Goo02don`0POnlood0POn>on`0]Ool0;Cok021
okcoo@2`o`0nPOoQonT0]_ol0;Koj@21okgoo@21oi3oj@2foo`0]_oY087o_Oom
087oT?oY0;Koo02fonT0POnmood0/?l0FH7ohooh007oood0oOoi0;Ooo02gonH0
POnoood0POnBooP00Oooo@3mooT0]ool0;OoiP21okooo@21oi;on001ooom0?go
n@2goo`0]ooV087o_oom0;3o05J1on?onP3mood0oOoh0;Soo02hon@0POo0ood0
POnBooX0oOom0?gon02hoo`0^?oT087o`?om087oT_oj0?goo@3mooP0^?ol0;So
i021ol3oo@2`o`1FPOoTooT0oOom0?gon02hoo`0^?oT087o`?om087oTooi0?go
o@3mooP0^?ol0;Soi021ol3oo@21oi?on@3mood0oOoh0;Soo02hon@0POo0ood0
/?l0HX7oi?oi0?goo@3mood00?ol0;Woo02ion80POo1ood0POnCooT0oOom0?go
o@00oo`0^Ool0;WohP21ol7oo@21oi?on@3mood0oOom003oo02ioo`0^OoR087o
`Oom0;3o0761onGon03mood0oOom007ooo`0^_ol0;[oo03[oo`0POo1ood0POnD
ooP0oOom0?goo@01oool0;[oo02joo`0jool087o`Oom087oU?oh0?goo@3mood0
0Oooo02joo`0^_ol0>_oo021ol7oo@2`o`1mPOoUood00?om0?goo@3mood00Ooo
o02joo`0^_om0>Woo021ol;oo@21oiCoo@00ood0oOom0?goo@01oool0;[oo02j
ood0jOol087o`_om087oU?om003oo@3mood0oOom007ooo`0^_ol0;[oo@3Yoo`0
POo2ood0/?l0NX7oiook003oo@3mood0oOom0?koo02koo`0^ool0>Soo@21ol;o
o@21oiKon`00ood0oOom0?goo@3noo`0^ool0;_oo03Xood0POo2ood0POnFoo/0
0?om0?goo@3mood0o_ol0;_oo02koo`0j?om087o`_om0;3o07f1onOoo001ooom
0?goo@3mood0oOom0;_oo02kood0ioom087o`_om087oU_ol007oood0oOom0?go
o@3mood0^ool0;_oo@3Wood0POo2ood0POnFoo`00Oooo@3mood0oOom0?goo@2k
oo`0^oom0>Ooo@21ol;oo@2`o`1aPOoWoo`00Oooo@3mood0oOom0?goo02loo`0
_?oM087o`oom087oU_ol007oood0oOom0?goo@3moo`0_?ol0;cog@21ol?oo@21
oiKoo001ooom0?goo@3mood0oOol0;coo02lomd0POo3ood0/?l0KX7oioom0?ko
o@3mood0oOom0?goo02loo`0_?oM087o`oom087oU_om0?koo@3mood0oOom0?go
o02loo`0_?oM087o`oom087oU_om0?koo@3mood0oOom0?goo02loo`0_?oM087o
`oom0;3o06j1onSoo03nood0oOom0?goo@3lood0_?ol0;cog@21ol?oo@21oiOo
o03nood0oOom0?goo@3lood0_?ol0;cog@21ol?oo@21oiOoo03nood0oOom0?go
o@3lood0_?ol0;cog@21ol?oo@2`o`1^POoXoo`0o_om0?goo@3mood0o?ol0;go
o02lom`0POo4ood0POnGoo`0o_om0?goo@3mood0o?ol0;goo02lom`0POo4ood0
POnGoo`0o_om0?goo@3mood0o?ol0;goo02lom`0POo4ood0/?l0NX7oj?ol0?ko
o@3mood0oOom0?coo02moo`0_Ool0>Coo@21olCoo@21oiOoo03nood0oOom0?go
o@3loo`0_Ool0;goo03Tood0POo4ood0POnGoo`0o_om0?goo@3mood0o?ol0;go
o02moo`0i?om087oa?om0;3o07Z1onSoo@3mood0oOom0?goo@3loo`0_Ool0;go
o@3Sood0POo4ood0POnGood0oOom0?goo@3mood0o?ol0;goo02mood0hoom087o
a?om087oUoom0?goo@3mood0oOom0?coo02moo`0_Oom0>?oo@21olCoo@2`o`1j
POoXood0oOom0?goo@3mood0o?ol0;goo02mood0hoom087oa?om087oUoom0?go
o@3mood0oOom0?coo02moo`0_Oom0>?oo@21olCoo@21oiOoo@3mood0oOom0?go
o@3loo`0_Ool0;goo@3Sood0POo4ood0/?l0NX7oj?ol0?koo@3mood0oOom0?co
o02moo`0_Ool0>Goo021olCoo@21oiOoo03nood0oOom0?goo@3loo`0_Ool0;go
o03Uoo`0POo4ood0POnGoo`0o_om0?goo@3mood0o?ol0;goo02moo`0iOol087o
a?om0;3o06j1onSoo03nood0oOom0?goo@3lood0_?ol0;cog@21ol?oo@21oiOo
o03nood0oOom0?goo@3lood0_?ol0;cog@21ol?oo@21oiOoo03nood0oOom0?go
o@3lood0_?ol0;cog@21ol?oo@2`o`1^POoWood0o_om0?goo@3mood0oOol0;co
o02lomd0POo3ood0POnFood0o_om0?goo@3mood0oOol0;coo02lomd0POo3ood0
POnFood0o_om0?goo@3mood0oOol0;coo02lomd0POo3ood0/?l0LH7oiool007o
ood0oOom0?goo@3moo`0_?ol0;cog@21ol?oo@21oiKoo001ooom0?goo@3mood0
oOol0;coo02lomd0POo3ood0POnFoo`00Oooo@3mood0oOom0?goo02loo`0_?oM
087o`oom0;3o0761onOoo001ooom0?goo@3mood0oOom0;_oo02koml0POo2ood0
POnFoo`00Oooo@3mood0oOom0?goo@2koo`0^ooO087o`_om087oU_ol007oood0
oOom0?goo@3mood0^ool0;_og`21ol;oo@2`o`1aPOoVood00Oooo@3mood0oOom
0?koo02koo`0^ooO087o`_om087oUOom007oood0oOom0?goo@3noo`0^ool0;_o
g`21ol;oo@21oiGoo@01ooom0?goo@3mood0o_ol0;_oo02koml0POo2ood0/?l0
NX7oi_ol003oo@3mood0oOom0?koo02koo`0^ool0>Woo021ol;oo@21oiGoo000
ood0oOom0?goo@3noo`0^ool0;_oo03Yoo`0POo2ood0POnEoo`00?om0?goo@3m
ood0o_ol0;_oo02koo`0jOol087o`_om0;3o0761onGon03mood0oOom007ooo`0
^_ol0;[oo03Zood0POo1ood0POnDooP0oOom0?goo@01oool0;[oo02joo`0j_om
087o`Oom087oU?oh0?goo@3mood00Oooo02joo`0^_ol0>[oo@21ol7oo@2`o`1a
POoUooP0oOom0?goo@01ooom0;Woo02iood0jool087o`Oom087oU?oh0?goo@3m
ood00Oooo@2ioo`0^Oom0>_oo021ol7oo@21oiCon03mood0oOom007oood0^Ool
0;Woo@3[oo`0POo1ood0/?l0HX7oi?oi0?goo@3mooL0^Ool0;Soo03^oo`0POo0
ood0POnCooT0oOom0?gom`2ioo`0^?ol0>koo021ol3oo@21oi?on@3mood0oOog
0;Woo02hoo`0k_ol087o`?om0;3o05J1on?onP3mood0oOoh0;Soo02hon@0POo0
ood0POnBooX0oOom0?gon02hoo`0^?oT087o`?om087oT_oj0?goo@3mooP0^?ol
0;Soi021ol3oo@2`o`1FPOoRooX0o_om0?gon@2goo`0]ooW087o__om087oTOoj
0?koo@3mooT0]ool0;Ooi`21okkoo@21oi7onP3nood0oOoi0;Ooo02gonL0POnn
ood0/?l0FH7oh_oi007oood0oOoi0;Ooo02gonL0POnnood0POnAooT00Oooo@3m
ooT0]ool0;Ooi`21okkoo@21oi7on@01ooom0?gon@2goo`0]ooW087o__om0;3o
03j1on3oj`2eoo`0]Oo[087o_?om087oSoo[0;Goo02eon/0POnlood0POn?on/0
]Ool0;Goj`21okcoo@2`o`0nPOoNonh0]?ol0;?okP21ok_oo@21ohgokP2doo`0
/oo^087o^oom087oSOo^0;Coo02conh0POnkood0/?l0?X7ogOoa0;;oo02boo40
POniood0POn<oo40/_ol0;;ol@21okWoo@21ohcol@2boo`0/_oa087o^Oom0;3o
03j1omcol`2aoo`0/Ooc087o^?om087oRooc0;7oo02aoo<0POnhood0POn;oo<0
/Ool0;7ol`21okSoo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0hPOn1ookoo021oh7of_om0<VZPOn1onGoo021oh7of_om0<VZPOn1onGo
o021oh7of_om0<VZj?l0:X40P@210840cP39Z^SoP@210840P@3>0<VZj?n10840
P@210<h0bJ[Xo`0ZP@210840P@3>0<VZj?n10840P@210<h0bJ[Xoh40P@210840
cP39Z^So02Z10840P@210<h0bJ[Xoh40P@210840cP39Z^SoP@210840P@3>0<VZ
j?l09840P@210840cP2`oh40P@210840cP2`oh40P@210840cP2`o`0TP@210840
P@3>0;3oP@210840P@3>0;3oP@210840P@3>0;3o03:1oh7oo_ol087oPOoJood0
POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7o
f_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0
POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7o
o_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0b
POn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0
/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7o
f_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0
POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o
[Ool087oPOoJood0/?l0?X7oPOonoo`0k?on087oPOobood0POn1ojgoo03/ooh0
POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om0;3o03j1oh7oo_ol0>cooP21oh7o
l_om087oPOn]oo`0k?on087oPOobood0POn1ojgoo03/ooh0POn1oo;oo@2`o`0n
POn1ookoo03/ooh0POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om087oPOn]oo`0
k?on087oPOobood0/?l0?X7oPOonoo`0k?on087oPOobood0POn1ojgoo03/ooh0
POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om0;3o03j1oh7oo_ol0>cooP21oh7o
l_om087oPOn]oo`0k?on087oPOobood0POn1ojgoo03/ooh0POn1oo;oo@2`o`0n
POn1ookoo03/ooh0POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om087oPOn]oo`0
k?on087oPOobood0/?l0?X7oPOonoo`0k?on087oPOobood0POn1ojgoo03/ooh0
POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om0;3o03j1oh7oo_ol0>cooP21oh7o
l_om087oPOn]oo`0k?on087oPOobood0POn1ojgoo03/ooh0POn1oo;oo@2`o`0n
POn1ookoo03/ooh0POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om087oPOn]oo`0
k?on087oPOobood0/?l0?X7oPOonoo`0mOo/087oPOokood0POn1ojgoo03eon`0
POn1oo_oo@21oh7o[Ool0?Gok021oh7onoom0;3o03j1oh7oo_ol0?Gok021oh7o
noom087oPOn]oo`0mOo/087oPOokood0POn1ojgoo03eon`0POn1oo_oo@2`o`0n
POn1ookoo03eon`0POn1oo_oo@21oh7o[Ool0?Gok021oh7onoom087oPOn]oo`0
mOo/087oPOokood0/?l0?X7oPOonoo`0k?on087oPOobood0POn1ojgoo03/ooh0
POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om0;3o03j1oh7oo_ol0>cooP21oh7o
l_om087oPOn]oo`0k?on087oPOobood0POn1ojgoo03/ooh0POn1oo;oo@2`o`0n
POn1ookoo03/ooh0POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om087oPOn]oo`0
k?on087oPOobood0/?l0?X7oPOonoo`0k?on087oPOobood0POn1ojgoo03/ooh0
POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om0;3o03j1oh7oo_ol0>cooP21oh7o
l_om087oPOn]oo`0k?on087oPOobood0POn1ojgoo03/ooh0POn1oo;oo@2`o`0n
POn1ookoo03/ooh0POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om087oPOn]oo`0
k?on087oPOobood0/?l0?X7oPOonoo`0k?on087oPOobood0POn1ojgoo03/ooh0
POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om0;3o03j1oh7oo_ol0>cooP21oh7o
l_om087oPOn]oo`0k?on087oPOobood0POn1ojgoo03/ooh0POn1oo;oo@2`o`0n
POn1ookoo03/ooh0POn1oo;oo@21oh7o[Ool0>cooP21oh7ol_om087oPOn]oo`0
k?on087oPOobood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0
POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7o
f_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0
POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o
[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0
POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7o
f_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0
POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7o
o_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0b
POn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0
/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7o
f_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0
POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o
[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0
POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7o
f_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0
POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o
[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0
POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7o
f_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0
POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7o
o_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0b
POn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0
/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7o
f_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0
POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o
[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0
POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7o
f_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0
POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o
[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0
POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7o
f_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0
POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7o
o_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0b
POn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0
/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7o
f_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0
POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o
[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0
POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7o
f_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0
POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o
[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0
POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7o
f_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0
POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7o
o_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0b
POn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0
/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7o
f_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0
POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o
[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0
POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7o
f_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0
POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o
[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0
POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7o
f_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0
POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7o
o_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0b
POn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0
/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7o
f_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0
POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o
[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0
POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7o
f_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0
POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o
[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0
POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7o
f_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0
POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7o
o_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0b
POn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0
/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7o
f_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0
POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o
[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0
POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7o
f_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0
POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o
[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0
POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7o
f_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0
POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7o
o_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0b
POn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0
/?l0>87oe_l00:[oo021oh7of_om087oQOl00:[oo021oh7of_om087oQOl00:[o
o021oh7of_om0;3o03j1omgol@2boo`0/_oa087o^Oom087oS?oa0;;oo02boo40
POniood0POn<oo40/_ol0;;ol@21okWoo@2`o`0nPOoNonl0/ool0;?ok`21ok[o
o@21ohgok`2coo`0/oo_087o^_om087oSOo_0;?oo02conl0POnjood0/?l0?X7o
goo/0;Goo02don`0POnlood0POn>on`0]Ool0;Cok021okcoo@21ohkok02eoo`0
]?o/087o_?om0;3o03j1on7oj@2foo`0]_oY087o_Oom087oT?oY0;Koo02fonT0
POnmood0POn@onT0]_ol0;Koj@21okgoo@2`o`1:POoRonL0]ool0;Oom`3mooD0
POnnood0POnAonL0]ool0;Oom`3mooD0POnnood0POnAonL0]ool0;Oom`3mooD0
POnnood0/?l0FH7ohooV0;Ooo02gooL0oOom007oooX0POnoood0POnBonH0]ool
0;Oom`3mood00OoonP21okooo@21oi;oiP2goo`0]oog0?goo@01oooj087o_oom
0;3o06:1onCoi02hoo`0^?ok003oo@3mood0o_oj087o`?om087oTooT0;Soo02h
oo/00?om0?goo@3nooX0POo0ood0POnCon@0^?ol0;Son`00ood0oOom0?konP21
ol3oo@2`o`1UPOoTon<0^Ool0;Won`01ooom0?goo@3loo`0POo0ood0POnCon<0
^Ool0;Won`01ooom0?goo@3loo`0POo0ood0POnCon<0^Ool0;Won`01ooom0?go
o@3loo`0POo0ood0/?l0KX7oiOol0>_oo02joo`0^Oom0?goo@3mood0o?ok087o
`Oom087oU?ol0>_oo02joo`0^Oom0?goo@3mood0o?ok087o`Oom087oU?ol0>_o
o02joo`0^Oom0?goo@3mood0o?ok087o`Oom0;3o06j1onGoo@3Zoo`0^_ol0;[o
o03mood0oOom0?conP21ol;oo@21oiCoo@3Zoo`0^_ol0;[oo03mood0oOom0?co
nP21ol;oo@21oiCoo@3Zoo`0^_ol0;[oo03mood0oOom0?conP21ol;oo@2`o`1^
POoVoo`0jOol0;_oo02koo/0oOom0?goo@3looX0POo2ood0POnEoo`0jOol0;_o
o02koo/0oOom0?goo@3looX0POo2ood0POnEoo`0jOol0;_oo02koo/0oOom0?go
o@3looX0POo2ood0/?l0KX7oiool0>Ooo@2koo`0^ook0?goo@3mood0o?oj087o
`_om087oU_ol0>Ooo@2koo`0^ook0?goo@3mood0o?oj087o`_om087oU_ol0>Oo
o@2koo`0^ook0?goo@3mood0o?oj087o`_om0;3o06:1onOogP2koo`0^ook0?go
o@3mood0o?oj087o`_om087oU_oN0;_oo02koo/0oOom0?goo@3looX0POo2ood0
POnFomh0^ool0;_on`3mood0oOom0?conP21ol;oo@2`o`1RPOoWomd0_?ol0;co
nP3mood0oOom0?con@21ol?oo@21oiKog@2loo`0_?oj0?goo@3mood0o?oi087o
`oom087oU_oM0;coo02looX0oOom0?goo@3looT0POo3ood0/?l0HX7oiooM0;co
o02looX0oOom0?goo@3looT0POo3ood0POnFomd0_?ol0;conP3mood0oOom0?co
n@21ol?oo@21oiKog@2loo`0_?oj0?goo@3mood0o?oi087o`oom0;3o06:1onSo
g02loo`0_?oj0?goo@3mood0o?oi087o`oom087oUooL0;coo02looX0oOom0?go
o@3looT0POo3ood0POnGom`0_?ol0;conP3mood0oOom0?con@21ol?oo@2`o`1^
POoXom/0_Ool0;gon@3mood0oOom0?coo@00ood0POo4ood0POnGom/0_Ool0;go
n@3mood0oOom0?coo@00ood0POo4ood0POnGom/0_Ool0;gon@3mood0oOom0?co
o@00ood0POo4ood0/?l0NX7oj?om0>Coo02moo`0_Ooi0?goo@3mood0o?om003o
o@21olCoo@21oiOoo@3Too`0_Ool0;gon@3mood0oOom0?coo@00ood0POo4ood0
POnGood0i?ol0;goo02mooT0oOom0?goo@3lood00?om087oa?om0;3o07Z1onSo
o@3Too`0_Ool0;gon@3mood0oOom0?coo@00ood0POo4ood0POnGood0i?ol0;go
o02mooT0oOom0?goo@3lood00?om087oa?om087oUoom0>Coo02moo`0_Ooi0?go
o@3mood0o?om003oo@21olCoo@2`o`1^POoXoo`0iOol0;goo02mooT0oOom0?go
o@3looP0POo4ood0POnGoo`0iOol0;goo02mooT0oOom0?goo@3looP0POo4ood0
POnGoo`0iOol0;goo02mooT0oOom0?goo@3looP0POo4ood0/?l0KX7oj?ol0>Go
o@2loo`0_?oj0?goo@3mood0o?oi087o`oom087oUool0>Goo@2loo`0_?oj0?go
o@3mood0o?oi087o`oom087oUool0>Goo@2loo`0_?oj0?goo@3mood0o?oi087o
`oom0;3o06:1onOog@2loo`0_?oj0?goo@3mood0o?oi087o`oom087oU_oM0;co
o02looX0oOom0?goo@3looT0POo3ood0POnFomd0_?ol0;conP3mood0oOom0?co
n@21ol?oo@2`o`1RPOoWomd0_?ol0;conP3mood0oOom0?con@21ol?oo@21oiKo
g@2loo`0_?oj0?goo@3mood0o?oi087o`oom087oU_oM0;coo02looX0oOom0?go
o@3looT0POo3ood0/?l0HX7oiooN0;_oo02koo/0oOom0?goo@3looX0POo2ood0
POnFomh0^ool0;_on`3mood0oOom0?conP21ol;oo@21oiKogP2koo`0^ook0?go
o@3mood0o?oj087o`_om0;3o06:1onOogP2koo`0^ook0?goo@3mood0o?oj087o
`_om087oU_oN0;_oo02koo/0oOom0?goo@3looX0POo2ood0POnFomh0^ool0;_o
n`3mood0oOom0?conP21ol;oo@2`o`1^POoVoo`0jOol0;_oo02koo/0oOom0?go
o@3looX0POo2ood0POnEoo`0jOol0;_oo02koo/0oOom0?goo@3looX0POo2ood0
POnEoo`0jOol0;_oo02koo/0oOom0?goo@3looX0POo2ood0/?l0KX7oiOol0>_o
o02joo`0^_ol0?goo@3mood0o?ok087o`Oom087oU?ol0>_oo02joo`0^_ol0?go
o@3mood0o?ok087o`Oom087oU?ol0>_oo02joo`0^_ol0?goo@3mood0o?ok087o
`Oom0;3o06j1onGoo03[ood0^Ool0;Woo@3mood0oOom0?con`21ol7oo@21oiCo
o03[ood0^Ool0;Woo@3mood0oOom0?con`21ol7oo@21oiCoo03[ood0^Ool0;Wo
o@3mood0oOom0?con`21ol7oo@2`o`1^POoToo`0kOol0;Woo02hood0o_om0?go
o@3loo`0POo0ood0POnCoo`0kOol0;Woo02hood0o_om0?goo@3loo`0POo0ood0
POnCoo`0kOol0;Woo02hood0o_om0?goo@3loo`0POo0ood0/?l0VP000?n?X000
0000R`?X000010000000B00004P0000@02000`08000000000007o<Kd0000002;
0nP3jP0017<3k0000;K5ood0^?ol007oood0oOom0?gon`21ol3oo021okooi@2h
oo`0^?ol007oood0oOom0?gon`21ol3oo02Qood0^?ol007oood0oOom0?gon`21
ol3oo021okooi@2hoo`0^?ol007oood0oOom0?gon`21ol3oo02Qood0^?ol007o
ood0oOom0?gon`21ol3oo021okooi@2hoo`0^?ol007oood0oOom0?gon`21ol3o
o03Mo`2NaOom0;Oom`3mood00OoonP21okooo021okooiP2goo`0]oog0?goo@01
oooj087o_ool0:7oo@2gooL0oOom007oooX0POnooo`0POnoonH0]ool0;Oom`3m
ood00OoonP21okooo02Qood0]oog0?goo@01oooj087o_ool087o_ooV0;Ooo02g
ooL0oOom007oooX0POnooo`0gOl0P<Goo@2gooL0oOoe087o__ol087o__oW0;Oo
o02gooL0oOoe087o__ol0:7oo@2gooL0oOoe087o__ol087o__oW0;Ooo02gooL0
oOoe087o__ol0:7oo@2gooL0oOoe087o__ol087o__oW0;Ooo02gooL0oOoe087o
__ol0=go06S5ood0]_oY087o_Ool087o_OoY0;Koo02fonT0POnmoo`0XOom0;Ko
j@21okgoo021okgoj@2foo`0]_oY087o_Ool0:7oo@2fonT0POnmoo`0POnmonT0
]_ol0;Koj@21okgoo03Mo`1XaOom0;Cok021okcoo021ok_ok02eoo`0]?o/087o
_?ol0:7oo@2don`0POnloo`0POnkon`0]Ool0;Cok021okcoo02Qood0]?o/087o
_?ol087o^oo/0;Goo02don`0POnloo`0gOl0J<Goo@2conl0POnjoo`0POnjonl0
/ool0;?ok`21ok[oo02Qood0/oo_087o^_ol087o^_o_0;?oo02conl0POnjoo`0
XOom0;?ok`21ok[oo021ok[ok`2coo`0/oo_087o^_ol0=go06S5ood0/Ooc087o
^?ol087o^?oc0;7oo02aoo<0POnhoo`0XOom0;7ol`21okSoo021okSol`2aoo`0
/Ooc087o^?ol0:7oo@2aoo<0POnhoo`0POnhoo<0/Ool0;7ol`21okSoo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`1F
aOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0
POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0gOl0E/Goo@21oh7o
f_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7of_ol087oPOoJoo`0
XOom087oPOoJoo`0POn1om[oo021oh7of_ol0=go05K5ood0POn1om[oo021oh7o
f_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7of_ol0:7oo@21oh7o
f_ol087oPOoJoo`0POn1om[oo03Mo`1FaOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0POn1om[oo021oh7o
f_ol087oPOoJoo`0gOl0E/Goo@21oh7of_ol087oPOoJoo`0POn1om[oo02Qood0
POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0POn1om[oo021oh7o
f_ol0=go05K5ood0POn1om[oo021oh7of_ol087oPOoJoo`0XOom087oPOoJoo`0
POn1om[oo021oh7of_ol0:7oo@21oh7of_ol087oPOoJoo`0POn1om[oo03Mo`0f
aOn10840P@210840P@210=D0aOn10840P@210840P@210=D0aOn10840P@210840
P@210=D003K5oh40P@210840P@210840e@35oh40P@210840P@210840e@35oh40
P@210840P@210840e@00=/GoP@210840P@210840P@3E0<GoP@210840P@210840
P@3E0<GoP@210840P@210840P@3E000faOn10840P@210840P@210=D0aOn10840
P@210840P@210=D0aOn10840P@210840P@210=D004j1oh7oVoomZX7oPOoIoofZ
POn1omWooJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7o
fOomZX7oPOoIoofZfol0CX7oPOnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGo
oJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>
POn1oi_ooJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWo
oJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZ
POn1omWooJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7o
fOomZX7oPOoIoofZfol0CX7oPOnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGo
oJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>
POn1oi_ooJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWo
oJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZ
POn1omWooJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7o
fOomZX7oPOoIoofZfol0CX7oPOnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGo
oJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>
POn1oi_ooJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWo
oJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZ
POn1omWooJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7o
fOomZX7oPOoIoofZfol0CX7oPOnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGo
oJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>
POn1oi_ooJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWo
oJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZ
POn1omWooJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7o
fOomZX7oPOoIoofZfol0CX7oPOnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGo
oJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>
POn1oi_ooJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWo
oJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZ
POn1omWooJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7o
fOomZX7oPOoIoofZfol0CX7oPOnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGo
oJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>
POn1oi_ooJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWo
oJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZ
POn1omWooJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7o
fOomZX7oPOoIoofZfol0CX7oPOnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGo
oJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>
POn1oi_ooJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWo
oJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZ
POn1omWooJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7o
fOomZX7oPOoIoofZfol0CX7oPOnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGo
oJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>
POn1oi_ooJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWo
oJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZ
POn1omWooJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7o
fOomZX7oPOoIoofZfol0CX7oPOnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGo
oJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>
POn1oi_ooJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWo
oJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZ
POn1omWooJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7o
fOomZX7oPOoIoofZfol0CX7oPOnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGo
oJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>
POn1oi_ooJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWo
oJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZ]_o04j1oh7oVoomZX7oPOoIoofZ
POn1omWooJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGooJZ1oh7o
fOomZX7oPOoIoofZfol0CX7oPOnKoofZPOn1omWooJZ1oh7ofOomZX7oPOn1ooGo
oJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWooJ[Ko`1>
POn1oi_ooJZ1oh7ofOomZX7oPOoIoofZPOn1oh7omOomZX7oPOoIoofZPOn1omWo
oJZ1oh7oPOoeoofZPOn1omWooJZ1oh7ofOomZ]_o06J1oh7oVoomZX7oPOoIoofZ
POogood0moom087omOomZX7oPOn1ooGooJZ1oh7ofOomZX7omoom0?Ooo@21ooGo
oJZ1oh7oPOoeoofZPOn1omWooJZ1ooOoo@3good0POoeoofZfol0IX7oPOnKoofZ
POn1omWooJZ1ooKoo@3iood0POodoofZPOn1oh7omOomZX7oPOoIoofZPOofood0
nOom087om?omZX7oPOn1ooGooJZ1oh7ofOomZX7om_om0?Woo@21ooCooJ[Ko`1V
POn1oi_ooJZ1oh7ofOomZX7omOon0?WooP21oo?ooJZ1oh7oPOoeoofZPOn1omWo
oJZ1ooGooP3iooh0POocoofZPOn1oh7omOomZX7oPOoIoofZPOoeooh0nOon087o
loomZ]_o06J1oh7oVoomZX7oPOoIoofZPOodooh0noon087ol_omZX7oPOn1ooGo
oJZ1oh7ofOomZX7om?on0?_ooP21oo;ooJZ1oh7oPOoeoofZPOn1omWooJZ1ooCo
oP3kooh0POoboofZfol0IX7oPOnKoofZPOn1omWooJZ1ooCoo@3mood0POoboofZ
POn1oh7omOomZX7oPOoIoofZPOodood0oOom087ol_omZX7oPOn1ooGooJZ1oh7o
fOomZX7om?om0?goo@21oo;ooJ[Ko`1VPOn1oi_ooJZ1oh7ofOomZX7oloon0?go
oP21oo7ooJZ1oh7oPOoeoofZPOn1omWooJZ1oo?ooP3mooh0POoaoofZPOn1oh7o
mOomZX7oPOoIoofZPOocooh0oOon087olOomZ]_o06V1oh7oVoomZX7oPOoIoofZ
POobooh00OoooP21oo3ooJZ1oh7oPOoeoofZPOn1omWooJZ1oo;ooP01ooon087o
l?omZX7oPOn1ooGooJZ1oh7ofOomZX7ol_on007oooh0POo`oofZfol0FX7oPOnK
oofZPOn1omWooJZ1oo;on@21oo3ooJZ1oh7oPOoeoofZPOn1omWooJZ1oo;on@21
oo3ooJZ1oh7oPOoeoofZPOn1omWooJZ1oo;on@21oo3ooJ[Ko`1JPOn1oi_ooJZ1
oh7ofOomZX7olOok087okoomZX7oPOn1ooGooJZ1oh7ofOomZX7olOok087okoom
ZX7oPOn1ooGooJZ1oh7ofOomZX7olOok087okoomZ]_o05Z1oh7oVoomZX7oPOoI
oofZPOo`ood0POo^oofZPOn1oh7omOomZX7oPOoIoofZPOo`ood0POo^oofZPOn1
oh7omOomZX7oPOoIoofZPOo`ood0POo^oofZfol0FX7oPOnKoofZPOn1omWooJZ1
oo3oo@21onkooJZ1oh7oPOoeoofZPOn1omWooJZ1oo3oo@21onkooJZ1oh7oPOoe
oofZPOn1omWooJZ1oo3oo@21onkooJ[Ko`1JPOn1oi_ooJZ1oh7ofOomZX7olOok
087okoomZX7oPOn1ooGooJZ1oh7ofOomZX7olOok087okoomZX7oPOn1ooGooJZ1
oh7ofOomZX7olOok087okoomZ]_o06J1oh7oVoomZX7oPOoIoofZPOobooT0n?oj
087o0?omZX7oPOn1ooGooJZ1oh7ofOomZX7ol_oi0?SonP21o`3ooJZ1oh7oPOoe
oofZPOn1omWooJZ1oo;on@3hooX0POl0oofZfol0Kh7oPOnKoofZPOn1omWooJZ1
oo;ooP01ooon0?_om@22oofZPOn1oh7omOomZX7oPOoIoofZPOobooh00OoooP3k
ooD0P_omZX7oPOn1ooGooJZ1oh7ofOomZX7ol_on007oooh0nooe08;ooJ[Ko`1/
POn1oi_ooJZ1oh7ofOomZX7oloon0?gooP3moo<0PoomZX7oPOn1ooGooJZ1oh7o
fOomZX7oloon0?gooP3moo<0PoomZX7oPOn1ooGooJZ1oh7ofOomZX7oloon0?go
oP3moo<0PoomZ]_o07R1oh7oVoomZX7oPOoIoofZPOodood0oOom0?koo@3jood0
Q?omZX7oPOn1ooGooJZ1oh7ofOomZX7om?om0?goo@3nood0n_om08CooJZ1oh7o
POoeoofZPOn1omWooJZ1ooCoo@3mood0o_om0?[oo@24oofZfol0Nh7oPOnKoofZ
POn1omWooJZ1ooCooP3kooh00OoooP3gooh0Q?omZX7oPOn1ooGooJZ1oh7ofOom
ZX7om?on0?_ooP01ooon0?OooP24oofZPOn1oh7omOomZX7oPOoIoofZPOodooh0
noon007oooh0moon08CooJ[Ko`1bPOn1oi_ooJZ1oh7ofOomZX7omOon0?WooP00
ooh0POogoofZPOn1oh7omOomZX7oPOoIoofZPOoeooh0nOon003ooP21ooOooJZ1
oh7oPOoeoofZPOn1omWooJZ1ooGooP3iooh00?on087omoomZ]_o06J1oh7oVoom
ZX7oPOoIoofZPOofood0nOoj087omoomZX7oPOn1ooGooJZ1oh7ofOomZX7om_om
0?WonP21ooOooJZ1oh7oPOoeoofZPOn1omWooJZ1ooKoo@3iooX0POogoofZfol0
IX7oPOnKoofZPOn1omWooJZ1ooOoo@3gooT0POoioofZPOn1oh7omOomZX7oPOoI
oofZPOogood0mooi087onOomZX7oPOn1ooGooJZ1oh7ofOomZX7omoom0?Oon@21
ooWooJ[Ko`1JPOn1oi_ooJZ1oh7ofOomZX7oiOoi087ooOomZX7oPOn1ooGooJZ1
oh7ofOomZX7oiOoi087ooOomZX7oPOn1ooGooJZ1oh7ofOomZX7oiOoi087ooOom
Z]_o05B1oh7oVoomZX7oPOoIoofZPOoSooL0POomZX7oPOn1ooGooJZ1oh7ofOom
ZX7ohoog087ooJZ1oh7oPOoeoofZPOn1omWooJZ1on?om`21oofZfol0E87oPOnK
oofZPOn1omWooJZ1on3on@22oofZPOn1oh7omOomZX7oPOoIoofZPOoPooT0P_om
ZX7oPOn1ooGooJZ1oh7ofOomZX7oh?oi08;ooJ[Ko`0hPOn1oh7oPOn1oh7oa_ol
087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087ofOl0>87oPOn1
oh7oPOn1olCoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21
om[o03R1oh7oPOn1oh7oPOo3ooh0POn1oh7oPOn1oh7oPOnLooh0POn1oh7oPOn1
oh7oPOnLooh0POoJo`0hPOn1oh7oPOn1oh7o`oon087oPOn1oh7oPOn1oh7oW?on
087oPOn1oh7oPOn1oh7oW?on087of_l0A87oPOn1oh7oPOn1om3ooP3hood0POn1
oh7oPOn1oh7oPOnYooh0n?om087oPOn1oh7oPOn1oh7oZOon0?Soo@21om[o04B1
oh7oPOn1oh7oPOo@ood0n_om087oPOn1oh7oPOn1oh7oZ?om0?[oo@21oh7oPOn1
oh7oPOn1ojSoo@3jood0POoIo`0hPOn1oh7oPOn1oh7ocooc087oPOn1oh7oPOn1
oh7oYooc087oPOn1oh7oPOn1oh7oYooc087ofOl0>87oPOn1oh7oPOn1olkomP21
oh7oPOn1oh7oPOn1ojComP21oh7oPOn1oh7oPOn1ojComP21omOo03R1oh7oPOn1
oh7oPOo<ooX0POn1oh7oPOn1oh7oPOnPooX0POn1oh7oPOn1oh7oPOnPooX0POoE
o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`00VP000?n:40000000R`:4
000010000000B00004P0000@02000`08000000000007o<Kd0000002;0Wd3jP?/
17<6I@0006F1on?oi@2hoo`0^?ol007oood0oOom0?gon`21ol3oo@21oi;oi@2h
oo`0^?ol007oood0oOom0?gon`21ol3oo@21oi;oi@2hoo`0^?ol007oood0oOom
0?gon`21ol3oo@2`o`1IPOoSonH0]ool0;Oom`3mood00OoonP21okooo@21oi;o
iP2goo`0]oog0?goo@01oooj087o_oom087oT_oV0;Ooo02gooL0oOom007oooX0
POnoood0/?l0BX7oh_oW0;Ooo02gooL0oOoe087o__om087oTOoW0;Ooo02gooL0
oOoe087o__om087oTOoW0;Ooo02gooL0oOoe087o__om0;3o03j1on7oj@2foo`0
]_oY087o_Oom087oT?oY0;Koo02fonT0POnmood0POn@onT0]_ol0;Koj@21okgo
o@2`o`0nPOoOon`0]Ool0;Cok021okcoo@21ohkok02eoo`0]?o/087o_?om087o
S_o/0;Goo02don`0POnlood0/?l0?X7og_o_0;?oo02conl0POnjood0POn=onl0
/ool0;?ok`21ok[oo@21ohgok`2coo`0/oo_087o^_om0;3o03j1omcol`2aoo`0
/Ooc087o^?om087oRooc0;7oo02aoo<0POnhood0POn;oo<0/Ool0;7ol`21okSo
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087o
POoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgo
o021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087o
POn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087oPOn]oo`0POn1om[o
o@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[oo@21oh7o[Ool087o
POoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087oPOoJood0POn1ojgo
o021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ookoo021oh7of_om087o
POn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7oPOonoo`0POn1om[o
o@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o03:1oh7oo_ol087o
POoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[oo@2`o`0bPOn1ooko
o021oh7of_om087oPOn]oo`0POn1om[oo@21oh7o[Ool087oPOoJood0/?l0<X7o
POonoo`0POn1om[oo@21oh7o[Ool087oPOoJood0POn1ojgoo021oh7of_om0;3o
03:1oh7oo_ol087oPOoJood0POn1ojgoo021oh7of_om087oPOn]oo`0POn1om[o
o@2`o`0TP@210840P@3>0;3oP@210840P@3>0;3oP@210840P@3>0;3o02B10840
P@210<h0/?n10840P@210<h0/?n10840P@210<h0/?l09840P@210840cP2`oh40
P@210840cP2`oh40P@210840cP2`o`0TP@210840P@3>0;3oP@210840P@3>0;3o
P@210840P@3>0;3o02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1
oh7oPol09h7oPOl1ooomZX7oPOn1oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3o`0W
POn1o`7ooofZPOn1oh7oPOn1oofZPOn1oh7oPOn1oofZPOn1oh?o02N1oh7o0Ooo
oJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1ooomZX7oPOn1
oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZPOn1oh7oPOn1oofZ
POn1oh7oPOn1oofZPOn1oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1
oh7ooJZ1oh7oPol09h7oPOl1ooomZX7oPOn1oh7oPOomZX7oPOn1oh7oPOomZX7o
POn3o`0WPOn1o`7ooofZPOn1oh7oPOn1oofZPOn1oh7oPOn1oofZPOn1oh?o02N1
oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1ooom
ZX7oPOn1oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZPOn1oh7o
POn1oofZPOn1oh7oPOn1oofZPOn1oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1
oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1ooomZX7oPOn1oh7oPOomZX7oPOn1oh7o
POomZX7oPOn3o`0WPOn1o`7ooofZPOn1oh7oPOn1oofZPOn1oh7oPOn1oofZPOn1
oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7o
POl1ooomZX7oPOn1oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZ
POn1oh7oPOn1oofZPOn1oh7oPOn1oofZPOn1oh?o02N1oh7o0OoooJZ1oh7oPOn1
oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1ooomZX7oPOn1oh7oPOomZX7o
POn1oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZPOn1oh7oPOn1oofZPOn1oh7oPOn1
oofZPOn1oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7o
Pol09h7oPOl1ooomZX7oPOn1oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3o`0WPOn1
o`7ooofZPOn1oh7oPOn1oofZPOn1oh7oPOn1oofZPOn1oh?o02N1oh7o0OoooJZ1
oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1ooomZX7oPOn1oh7o
POomZX7oPOn1oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZPOn1oh7oPOn1oofZPOn1
oh7oPOn1oofZPOn1oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7o
oJZ1oh7oPol09h7oPOl1ooomZX7oPOn1oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3
o`0WPOn1o`7ooofZPOn1oh7oPOn1oofZPOn1oh7oPOn1oofZPOn1oh?o02N1oh7o
0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1ooomZX7o
POn1oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZPOn1oh7oPOn1
oofZPOn1oh7oPOn1oofZPOn1oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7o
POn1oh7ooJZ1oh7oPol09h7oPOl1ooomZX7oPOn1oh7oPOomZX7oPOn1oh7oPOom
ZX7oPOn3o`0WPOn1o`7ooofZPOn1oh7oPOn1oofZPOn1oh7oPOn1oofZPOn1oh?o
02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1
ooomZX7oPOn1oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZPOn1
oh7oPOn1oofZPOn1oh7oPOn1oofZPOn1oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7o
oJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1ooomZX7oPOn1oh7oPOomZX7oPOn1
oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZPOn1oh7oPOn1oofZPOn1oh7oPOn1oofZ
POn1oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol0
9h7oPOl1ooomZX7oPOn1oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3o`0WPOn1o`7o
oofZPOn1oh7oPOn1oofZPOn1oh7oPOn1oofZPOn1oh?o02N1oh7o0OoooJZ1oh7o
POn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1ooomZX7oPOn1oh7oPOom
ZX7oPOn1oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZPOn1oh7oPOn1oofZPOn1oh7o
POn1oofZPOn1oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1
oh7oPol09h7oPOl1ooomZX7oPOn1oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3o`0W
POn1o`7ooofZPOn1oh7oPOn1oofZPOn1oh7oPOn1oofZPOn1oh?o02N1oh7o0Ooo
oJZ1oh7oPOn1oh7ooJZ1oh7oPOn1oh7ooJZ1oh7oPol09h7oPOl1ooomZX7oPOn1
oh7oPOomZX7oPOn1oh7oPOomZX7oPOn3o`0WPOn1o`7ooofZPOn1oh7oPOn1oofZ
POn1oh7oPOn1oofZPOn1oh?o02N1oh7o0OoooJZ1oh7oPOn1oh7ooJZ1oh7oPOn1
oh7ooJZ1oh7oPol09h7oPOl1ooomZX7oPOn1oh7oPOomZX7oPOn1oh7oPOomZX7o
POn3o`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7omOl0887oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ooGo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOoeo`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7omOl0887o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ooGo0221oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOoeo`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
mOl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ooGo0221oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOoeo`0PPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7omOl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ooGo0221oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOoeo`0PPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7omOl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ooGo
0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOoeo`0PPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7omOl0887oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ooGo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOoeo`0PPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7omOl0887oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ooGo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOoeo`0P
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7omOl0887oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ooGo0221oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POoeo`2P0;l0o`\>"], "NumberedFigure",
  ImageSize->{392, 273},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Figure 6.  'Mirror Cabinet' of a charge and its images in a 2 \
\[Dash] dimensional box, the indicated group of 4 charges constitutes a term \
(n\[NonBreakingSpace]=\[NonBreakingSpace]0, m\[NonBreakingSpace]=\
\[NonBreakingSpace]1) in the sum below \
\>", "Caption"],

Cell[TextData[{
  "The summation and reordering of all terms then gives the potential \
function at the point x, y within the box as a closed expression:\n\n\[Phi] \
(x,y) = ",
  Cell[BoxData[
      \(TraditionalForm\`\(Q\/\(2  \[Pi]\ \(\[Epsilon]\_0\) l\)\) \(f(x, y, 
            x\_s, y\_s, x\_q, y\_q)\)\  + k\)]],
  ", where \n\n",
  Cell[BoxData[
      \(f = \(\[CapitalSigma]\+\(m, n = \ \(-\[Infinity]\)\)\%\[Infinity]\) 
          ln \((\(\(\@\(\((2  n\ x\_s - \ x + \ x\_q)\)\^2 + \((2  m\ y\_s - \
\ y - \ y\_q)\)\^2\)\) \@\(\((2  n\ x\_s - \ x - \ x\_q)\)\^2 + \((2  m\ y\_s \
- \ y + \ y\_q)\)\^2\)\)\/\(\(\@\(\((2  n\ x\_s - \ x + \ x\_q)\)\^2 + \((2  \
m\ y\_s - \ y + \ y\_q)\)\^2\)\) \@\(\((2  n\ x\_s - \ x - \ x\_q)\)\^2 + \
\((2  m\ y\_s - \ y - \ y\_q)\)\^2\)\))\)\)], "Text"],
  ","
}], "Text"],

Cell[TextData[{
  "and k is a reference point of the potential on the border. Indices m,n = 0 \
denote the term in the middle next to the original charge, each square root \
represents the distance of a charge to the point P. The meaning of the \
variables is explained in Fig. 6. The double sum converges well, only a few \
tens of terms are needed in x and y direction. In addition  the correct \
boundary conditions \[Phi] (0, y) = \[Phi] (",
  Cell[BoxData[
      \(TraditionalForm\`x\_s\)]],
  ", y) = \[Phi] (x, 0) = \[Phi] (x, ",
  Cell[BoxData[
      \(TraditionalForm\`y\_s\)]],
  ") = k are fulfilled at the edges of the box. For the x \[Dash] direction \
this can be seen by writing out a few terms of the sum in the index n: at x = \
",
  Cell[BoxData[
      \(TraditionalForm\`x\_s\)]],
  "terms n=0 and n=1 cancel, then n=-1 and n=2 and so on, at x = 0 the parts \
of term n=0 cancel, then -1 and 1, -2 and 2 etc. A similar argument is valid \
for the y \[Dash] direction. The boundary conditions are also evident from \
the symmetry in Fig. 6 with respect to (x = 0 or x = ",
  Cell[BoxData[
      \(TraditionalForm\`x\_s\)]],
  ") or (y = 0 or y = ",
  Cell[BoxData[
      \(TraditionalForm\`y\_s\)]],
  ")."
}], "Text"],

Cell[TextData[{
  "\tThe above double infinite sum is equal to (",
  StyleBox["Ref. 10",
    FontWeight->"Bold"],
  ")\n\t\nf = ",
  Cell[BoxData[
      \(1\/2\ ln \((\(\(\[VerticalSeparator]\)\(\(\[CurlyTheta]\_1\) \((\[Pi] \
\((\(x + xq\)\/\(2  xs\) + \[ImaginaryI] \( ys\/xs\) \(y - yq\)\/\(2  \
ys\))\), \[ExponentialE]\^\(\(-\[Pi]\)\ ys/xs\))\)\)\( \[VerticalSeparator] \
\^2\)\(\(*\)\(\ \)\(\(\[VerticalSeparator]\)\(\(\[CurlyTheta]\_1\) \((\[Pi] \
\((\(x - xq\)\/\(2  xs\) + \[ImaginaryI] \( ys\/xs\) \(y + yq\)\/\(2  \
ys\))\), \[ExponentialE]\^\(\(-\[Pi]\)\ ys/xs\))\)\)\( \[VerticalSeparator] \
\^2\)\)\)\)\/\(\(\[VerticalSeparator]\)\(\(\[CurlyTheta]\_1\) \((\[Pi] \((\(x \
+ xq\)\/\(2  xs\) + \[ImaginaryI] \( ys\/xs\) \(y + yq\)\/\(2  ys\))\), \
\[ExponentialE]\^\(\(-\[Pi]\)\ ys/xs\))\)\)\( \[VerticalSeparator] \^2\)\(\(*\
\)\(\ \)\(\(\[VerticalSeparator]\)\(\(\[CurlyTheta]\_1\) \((\[Pi] \((\(x - xq\
\)\/\(2  xs\) + \[ImaginaryI] \( ys\/xs\) \(y - yq\)\/\(2  ys\))\), \
\[ExponentialE]\^\(\(-\[Pi]\)\ ys/xs\))\)\)\( \[VerticalSeparator] \
\^2\)\)\)\))\)\)]],
  ",\n\nwith the first elliptic theta function defined as (",
  StyleBox["Ref. 8",
    FontWeight->"Bold"],
  ", p.778)\n",
  Cell[BoxData[
      \(\(\(\(\[CurlyTheta]\_1\) \((u, q)\)\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`2 \(\[Sum]\+\(n = \
0\)\%\[Infinity]\(\((\(-1\))\)\^n\) \(q\^\(\((n + 1/2)\)\^2\)\) 
            sin[\((2  n + 1)\) u]\)\)]],
  ". (The sum converges ",
  StyleBox["very",
    FontSlant->"Italic"],
  " fast...)"
}], "Text",
  PageBreakAbove->True],

Cell["\<\
A control plot of f displays the typical double periodic behaviour \
(as in Fig. 6) :\
\>", "Text",
  PageBreakAbove->False],

Cell[CellGroupData[{

Cell[BoxData[{
    \(xs = 20; ys = 30; xq = 5.1; yq = 4.1; 
    q = Exp[\(-\ \[Pi]\)\ ys/xs];\), "\[IndentingNewLine]", 
    \(ContourPlot[
      1/2  Log[Chop[\[IndentingNewLine]\((EllipticTheta[
                    1, \[Pi] \((\(x + xq\)\/\(2\ xs\) + 
                          I\ \(y - yq\)\/\(2\ xs\))\), q] 
                  EllipticTheta[
                    1, \[Pi] \((\(x + xq\)\/\(2\ xs\) - 
                          I\ \(y - yq\)\/\(2\ xs\))\), q] 
                  EllipticTheta[
                    1, \[Pi] \((\(x - xq\)\/\(2\ xs\) + 
                          I\ \(y + yq\)\/\(2\ xs\))\), q] 
                  EllipticTheta[
                    1, \[Pi] \((\(x - xq\)\/\(2\ xs\) - 
                          I\ \(y + yq\)\/\(2\ xs\))\), q])\)/\((EllipticTheta[
                    1, \[Pi] \((\(x + xq\)\/\(2\ xs\) + 
                          I\ \(y + yq\)\/\(2\ xs\))\), q] 
                  EllipticTheta[
                    1, \[Pi] \((\(x + xq\)\/\(2\ xs\) - 
                          I\ \(y + yq\)\/\(2\ xs\))\), q] 
                  EllipticTheta[
                    1, \[Pi] \((\(x - xq\)\/\(2\ xs\) + 
                          I\ \(y - yq\)\/\(2\ xs\))\), q] 
                  EllipticTheta[
                    1, \[Pi] \((\(x - xq\)\/\(2\ xs\) - 
                          I\ \(y - yq\)\/\(2\ xs\))\), q])\)]], {x, \(-65\), 
        65}, {y, \(-65\), 65}, \[IndentingNewLine]PlotPoints \[Rule] 100, 
      ContourShading -> False]\)}], "Input",
  CellFrame->True,
  PageBreakAbove->False,
  Background->GrayLevel[0.849989]],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000B500029Q000`40O003h00Oogooogooogooogoo
RGoo003oOoooOoooOoooOon9Ool00?mooomooomooomoohUoo`00ogooogooogooogooRGoo003oOooo
OoooOoooOon9Ool00?mooomooomooomoohUoo`00ogooogooogooogooRGoo003oOoooOoooOoooOon9
Ool00?mooomooomooomoohUoo`00ogooogooogooogooRGoo003oOoooOoooOoooOon9Ool00?mooomo
oomooomoohUoo`00ogooogooogooogooRGoo003oOoooOoooOoooOon9Ool00?mooomooomooomoohUo
o`00ogooogooogooogooRGoo003oOoooOoooOoooOon9Ool00?mooomooomooomoohUoo`00ogooogoo
dgoo1000B7oo1P00?goo2P002goo1000=Goo2P002Goo1P00<goo30002goo1000KWoo003oOoooOooA
Ool80014Ool:000mOol:0009Ool8000cOol:0007Ool:000aOol<0009Ool8001/Ool00?mooomoom5o
o`8000Aoo`8004Aoo`<000Eoo`<0041oo`8000eoo`8000Aoo`8003Moo`8000]oo`<000Eoo`<0035o
o`<000Ioo`8000Uoo`8000Aoo`8006aoo`00ogooogood7oo0P001Woo0P00C7oo0P00@7oo0P0037oo
0P001Woo0P00=Woo0P0057oo0P00<Woo0`003goo0P001Woo0P00Jgoo003oOoooOoo@Ool20006Ool2
001=Ool2000oOol2000<Ool20006Ool2000fOol2000EOol2000bOol3000>Ool20006Ool2001[Ool0
0?mooomoolmoo`8000Qoo`8004aoo`8003moo`8000]oo`8000Qoo`8003Eoo`8001Eoo`8003=oo`<0
00aoo`8000Qoo`8006Yoo`00ogooogoocgoo0P0027oo0P00C7oo0P00?goo0P002goo0P0027oo0P00
=Goo0P005Goo0P00=7oo0`002goo0P0027oo0P00JWoo003oOoooOoo?Ool20008Ool2001<Ool2000o
Ool2000;Ool20008Ool2000eOol2000EOol2000eOol3000:Ool20008Ool2001ZOol00?mooomoolmo
o`8000Qoo`8004aoo`8003moo`8000]oo`8000Qoo`8003Eoo`8001Eoo`8003Ioo`<000Uoo`8000Qo
o`8006Yoo`00ogooogoocgoo0P0027oo0P00Bgoo0P00@7oo0P002goo0P0027oo0P00=Goo0P0057oo
0P00>7oo0`0027oo0P0027oo0P00JWoo003oOoooOoo?Ool20008Ool20013Ool20005Ool30010Ool2
000;Ool20008Ool2000eOol2000<Ool20005Ool3000iOol20008Ool20008Ool2001ZOol00?mooomo
olmoo`8000Qoo`8004=oo`T0045oo`8000]oo`8000Qoo`8003Eoo`8000aoo`T003]oo`8000Moo`80
00Qoo`8006Yoo`00ogooogoocgoo0P0027oo0P00@goo0P0000=oo`0000000`00@Woo0P002goo0P00
27oo0P00=Goo0P0037oo0P0000=oo`0000000`00?7oo0P001goo0P0027oo0P00JWoo003oOoooOoo@
Ool20006Ool20014Ool20018Ool2000<Ool20006Ool2000fOol2000<Ool2000iOol20007Ool20008
Ool20006Ool2001[Ool0071oo`D000eoo`@002moo`L000Yoo`@002Yoo``000]oo`@002ioo`@003=o
o``000]oo`@0031oo`L000Yoo`@002ioo`D000eoo`@00;Ioo`8000Ioo`8004Aoo`8004Qoo`8000ao
o`8000Ioo`8003Ioo`8000aoo`8003Uoo`<000Ioo`8000Qoo`8000Ioo`8006]oo`00KWoo20002Woo
2000;Goo1`0027oo2000:7oo30002Goo2000:Woo2000<Goo30002Goo2000;Woo1`0027oo2000:Woo
20002Woo2000]Goo0P0017oo0P00AGoo0P00A7oo0`0000=oo`0000003Goo0P0017oo0P00<goo0`00
00=oo`00000037oo0P00>Goo100017oo0P002Woo0P0017oo0P00K7oo001^Ool20004Ool30009Ool2
0004Ool2000`Ool2000:Ool20004Ool2000YOol30006Ool20009Ool20004Ool2000ZOol20004Ool2
000bOol30006Ool20009Ool20004Ool2000aOol2000:Ool20004Ool2000ZOol20004Ool30009Ool2
0004Ool2002eOol80015Ool:000lOol6000=Ool8000cOol6000<Ool:000bOol8000;Ool8001/Ool0
06eoo`8000Ioo`<000Moo`8000Ioo`8002moo`8000Uoo`8000Ioo`8002Uoo`<000moo`8000Ioo`80
02Qoo`8000Ioo`80039oo`<000moo`8000Ioo`80031oo`8000Uoo`8000Ioo`8002Qoo`8000Ioo`<0
00Moo`8000Ioo`800;Ioo`@004Moo`X003moo`<000moo`@003Qoo`<000aoo`X003Aoo`D000ioo`@0
06ioo`00K7oo0P0027oo0P001goo0P001Woo0P00;goo0P002Goo0P001Woo0P00:Woo0`003Woo0P00
1Woo0P00:7oo0P001Woo0P00<goo0`003Woo0P001Woo0P00<7oo0P002Goo0P001Woo0P009goo0P00
27oo0P001goo0P001Woo0P00ogooogooK7oo001IOol=0006Ool20008Ool20006Ool20008Ool2000C
Ool=0006Ool<0006Ool20008Ool2000DOol=0009Ool3000<Ool20008Ool2000VOol20008Ool2000c
Ool3000<Ool20008Ool2000WOol<0006Ool20008Ool2000VOol20008Ool20006Ool20008Ool2003o
OoooOom[Ool005Uoo`d000Ioo`8000Qoo`8000Ioo`8000Qoo`8001=oo`d000Ioo``000Ioo`8000Qo
o`8001Aoo`d000Yoo`<000]oo`8000Qoo`8002Ioo`8000Qoo`8003Aoo`<000]oo`8000Qoo`8002Mo
o``000Ioo`8000Qoo`8002Ioo`8000Qoo`8000Ioo`8000Qoo`800?mooomoof]oo`00FGoo3@001Woo
0P0027oo0P001Woo0P0027oo0P004goo3@001Woo0P001Woo0P0000=oo`00Ool01Goo0P0027oo0P00
57oo3@002goo0`002Woo0P0027oo0P009Woo0P0027oo0P00=Goo0`002Woo0P0027oo0P009goo0P00
1Woo0P0000=oo`00Ool01Goo0P0027oo0P009Woo0P0027oo0P001Woo0P0027oo0P00ogooogooJgoo
001/Ool30006Ool30006Ool20008Ool2000WOol20005Ool20008Ool20008Ool2000]Ool30009Ool2
0008Ool2000VOol20008Ool2000fOol30009Ool20008Ool2000XOol20005Ool20008Ool20008Ool2
000VOol30006Ool30006Ool20008Ool2003oOoooOom[Ool006aoo`@000Aoo`<000Moo`8000Qoo`80
02Moo`<000Aoo`8000Qoo`8000Qoo`8002ioo`<000Qoo`8000Qoo`8002Ioo`8000Qoo`8003Moo`<0
00Qoo`8000Qoo`8002Qoo`<000Aoo`8000Qoo`8000Qoo`8002Ioo`@000Aoo`<000Moo`8000Qoo`80
0?mooomoof]oo`00K7oo0P0000=oo`0000001@0027oo0P0027oo0P00:7oo0P0017oo0P0027oo0P00
27oo0P00;goo0P0027oo0P0027oo0P009Woo0P0027oo0P00>7oo0P0027oo0P0027oo0P00:Goo0P00
17oo0P0027oo0P0027oo0P009Woo0P0000=oo`0000001@0027oo0P0027oo0P00ogooogooJgoo001]
Ool00`00Oomoo`050009Ool20008Ool2000YOol20003Ool20008Ool20008Ool2000`Ool20007Ool2
0008Ool2000VOol20008Ool2000iOol20007Ool20008Ool2000ZOol20003Ool20008Ool20008Ool2
000WOol00`00Oomoo`050009Ool20008Ool2003oOoooOom[Ool006eoo`8000moo`8000Qoo`8002Uo
o`<0009oo`8000Qoo`8000Qoo`80031oo`8000Moo`8000Qoo`8002Ioo`8000Qoo`8003Uoo`8000Mo
o`8000Qoo`8002Yoo`<0009oo`8000Qoo`8000Qoo`8002Moo`8000moo`8000Qoo`800;5oool004L0
079oo`00KGoo0`003goo0P001Woo0P00:goo0P000Woo0P002Goo0P001Woo0P00:7oo0P001goo0P00
27oo0P001Woo0P00:7oo0P001Woo0P00<Goo0P001goo0P0027oo0P001Woo0P00;7oo0P000Woo0P00
2Goo0P001Woo0P00:7oo0`003goo0P001Woo0P00/Woo00<007ooOol00goo00<007ooOol03Goo00<0
07ooOol037oo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol03Goo00<0
07ooOol03Goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol037oo00<0
07ooOol03Goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol037oo00<0
07ooOol03Goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol00goo00<0
07ooOol0L7oo001^Ool3000>Ool20006Ool2000/Ool200000goo00000009Ool20006Ool2000XOol3
0006Ool20008Ool20006Ool2000XOol20006Ool2000aOol30006Ool20008Ool20006Ool2000]Ool2
00000goo00000009Ool20006Ool2000YOol3000>Ool20006Ool2002bOol00`00Oomoo`03Ool00`00
Oomoo`1;Ool00`00Oomoo`1<Ool00`00Oomoo`1;Ool00`00Oomoo`1;Ool00`00Oomoo`03Ool00`00
Oomoo`1`Ool006moo`<000ioo`8000Aoo`8002ioo`@000Yoo`8000Aoo`8002Uoo`@000Aoo`8000Yo
o`8000Aoo`8002Yoo`8000Aoo`80039oo`@000Aoo`8000Yoo`8000Aoo`8002moo`@000Yoo`8000Ao
o`8002]oo`<000ioo`8000Aoo`800:Aoo`@000]oo`03001oogoo0?mood=oo`03001oogoo071oo`00
L7oo200027oo2000;Woo10002Woo2000:Woo20002goo2000:Woo2000<goo20002goo2000;goo1000
2Woo2000;7oo200027oo2000XWoo20002Goo00<007ooOol0ogoo@goo00<007ooOol0L7oo001bOol6
000:Ool4000aOol3000<Ool4000^Ool5000>Ool4000^Ool4000gOol5000>Ool4000bOol3000<Ool4
000`Ool6000:Ool4002TOol20004Ool20009Ool00`00Oomoo`3oOom3Ool00`00Oomoo`1`Ool00?mo
oomookeoo`8000Ioo`8000Qoo`03001oogoo0?mood=oo`03001oogoo071oo`00ogooogoo_Goo0P00
1Woo0P0027oo00<007ooOol0ogoo@goo00<007ooOol0L7oo003oOoooOonlOol20008Ool20007Ool0
0`00Oomoo`3oOom3Ool00`00Oomoo`1`Ool00?mooomookaoo`8000Qoo`8000Moo`03001oogoo0?mo
od=oo`03001oogoo071oo`00ogooogoo_7oo0P0027oo0P001goo0`001Wooo`0050009goo0`00LWoo
003oOoooOonlOol20008Ool20007Ool00`00Oomoo`06Ool00`00Oomoo`0bOolm002QOolC000FOol0
0`00Oomoo`1`Ool00?mooomookaoo`8000Qoo`8000Moo`03001oogoo00Eoo`03001oogoo021ooa<0
03eooaT009]oo`H0011oo`03001oogoo071oo`00ogooogoo_7oo0P0027oo0P001goo00<007ooOol0
1Goo00<007ooOol05Woo2P00JGoo4000TGoo0P003Woo00<007ooOol0L7oo003oOoooOonlOol20008
Ool20007Ool00`00Oomoo`04Ool00`00Oomoo`0AOol6000`OolA0012Ool=0026Ool2000<Ool00`00
Oomoo`1`Ool00?mooomookaoo`8000Qoo`8000Moo`03001oogoo00Aoo`03001oogoo00ioo`<002=o
oa<0015ooa<003aoo``007aoo`03001oogoo00Uoo`03001oogoo071oo`00F7ooo`00d@00Tgoo0P00
1Woo0P0027oo00<007ooOol017oo00<007ooOol02goo0`0087oo1P00=goo3000?7oo2P00LWoo00<0
07ooOol02Goo00<007ooOol0L7oo001HOol00`00Oomoo`06Ool00`00Oomoo`0>Ool00`00Oomoo`0>
Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`0>
Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>
Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>
Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`0>
Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`06
Ool00`00Oomoo`2AOol20006Ool20008Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`0J
Ool70019Ool:000lOol6001]Ool00`00Oomoo`08Ool00`00Oomoo`1`Ool005Qoo`03001oogoo01Mo
o`03001oogoo045oo`03001oogoo049oo`03001oogoo045oo`03001oogoo049oo`03001oogoo049o
o`03001oogoo045oo`03001oogoo01Moo`03001oogoo099oo`8000Aoo`8000Uoo`03001oogoo00=o
o`03001oogoo00Uoo`8001Moo`H005Yoo`H003aoo`H006Moo`03001oogoo00Qoo`03001oogoo071o
o`00F7oo00<007ooOol0ogoocGoo00<007ooOol0TWoo20002Goo00<007ooOol00goo00<007ooOol0
27oo00<007ooOol057oo0`00IWoo1P00?7oo1`00HGoo00<007ooOol01goo00<007ooOol0L7oo001H
Ool00`00Oomoo`3oOoo=Ool00`00Oomoo`2DOol4000;Ool00`00Oomoo`03Ool00`00Oomoo`08Ool0
0`00Oomoo`0AOol3001_Ool4000oOol6001KOol00`00Oomoo`07Ool00`00Oomoo`1`Ool005Qoo`03
001oogoo0?mooleoo`03001oogoo0:=oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo015o
o`03001oogoo02=oob40031oo`H003moo`<005Uoo`03001oogoo00Ioo`03001oogoo071oo`00F7oo
00<007ooOol0ogoocGoo00<007ooOol0Xgoo00<007ooOol00goo00<007ooOol01goo00<007ooOol0
3Woo0`0087oo1P008Goo1P00<7oo0`00?goo1`00DWoo00<007ooOol01Woo00<007ooOol0L7oo001H
Ool00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomo
o`0=Ool2000MOol6000]Ool7000/Ool50011Ool3001?Ool00`00Oomoo`06Ool00`00Oomoo`1`Ool0
05Qoo`03001oogoo0?mooleoo`03001oogoo0:=oo`03001oogoo00=oo`03001oogoo00Eoo`03001o
ogoo00aoo`8001aoo`<003Yoo`H002]oo`@0041oo`<004aoo`03001oogoo00Ioo`03001oogoo071o
o`00F7oo0`001goo00<007ooOol01goo00<007ooOol02Goo00<007ooOol01goo00<007ooOol017oo
00<007ooOol00Woo00D007ooOomoo`0001ioo`<00003Ool0000000<00003Ool0000001ioo`05001o
ogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`07Ool2
0005Ool00`00Oomoo`02Ool01@00Oomoogoo00007Woo0`0000=oo`0000000`0000=oo`0000007Woo
00D007ooOomoo`0000Aoo`03001oogoo00=oo`8000Uoo`03001oogoo00Uoo`03001oogoo00Moo`03
001oogoo00Aoo`03001oogoo009oo`05001oogooOol0000NOol200000goo00000003000017oo0000
00007Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Uoo`03
001oogoo00Moo`03001oogoo00Eoo`<00:Eoo`8000Aoo`03001oogoo00Eoo`03001oogoo00]oo`03
001oogoo01Uoo`<004=oo`<002aoo`@003moo`<004Uoo`03001oogoo00Eoo`80079oo`00F7oo00<0
07ooOol01Woo00<007ooOol027oo00<007ooOol02Goo00<007ooOol01goo00<007ooOol017oo00<0
07ooOol00Woo00D007ooOomoo`0001ioo`<00003Ool0000000<00003Ool0000001ioo`05001oogoo
Ool00003Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo00007Woo0`0000=oo`0000000`0000=oo`000000
7Woo00D007ooOomoo`0000Aoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00Uoo`03001o
ogoo00Moo`03001oogoo00Eoo`05001oogooOol00003Ool00`00Oomoo`0LOol200000goo00000003
000017oo000000007Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00Moo`03001o
ogoo00Uoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo0:=oo`03001oogoo00=oo`03001o
ogoo00Aoo`03001oogoo00]oo`03001oogoo01Ioo`@004Uoo`<002eoo`<003moo`<004Ioo`03001o
ogoo00Ioo`03001oogoo071oo`00F7oo00<007ooOol047oo00<007ooOol02goo00<007ooOol01goo
00<007ooOol017oo00<007ooOol00Woo00@007ooOol001ioo`<00003Ool0000000<00003Ool00000
01eoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00
Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`007Woo0`0000=oo`0000000`00
00=oo`0000007Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00]o
o`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol0000MOol200000goo
00000003000017oo000000007Woo00@007ooOol000Aoo`03001oogoo00Aoo`03001oogoo00Moo`03
001oogoo00]oo`03001oogoo011oo`03001oogoo0:=oo`03001oogoo00=oo`03001oogoo00=oo`03
001oogoo00]oo`03001oogoo01Aoo`<0051oo`@002aoo`<003moo`<004Aoo`03001oogoo00Eoo`03
001oogoo071oo`00F7oo00<007ooOol047oo00<007ooOol02goo00<007ooOol027oo00<007ooOol0
17oo00D007ooOomoo`00009oo`03001oogoo01aoo`<00003Ool0000000800004Ool00000000MOol0
1@00Oomoogoo00000goo00<007ooOol017oo00<007ooOol027oo00<007ooOol02goo00<007ooOol0
27oo00<007ooOol017oo00D007ooOomoo`0000=oo`03001oogoo01]oo`<00003Ool0000000800004
Ool00000000MOol01@00Oomoogoo00000goo00<007ooOol017oo00<007ooOol027oo00<007ooOol0
2goo00<007ooOol027oo00<007ooOol017oo00D007ooOomoo`0000=oo`03001oogoo01]oo`<00003
Ool0000000800004Ool00000000NOol01000Oomoo`000goo00<007ooOol017oo00<007ooOol027oo
00<007ooOol02goo00<007ooOol047oo00<007ooOol0Xgoo00<007ooOol00goo00<007ooOol00goo
00<007ooOol02Woo00<007ooOol04goo0P007Goo5`008goo0P00;Goo0P00@7oo0`00@Goo00<007oo
Ool01Goo00<007ooOol0L7oo001HOol00`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`08Ool0
0`00Oomoo`04Ool01@00Oomoogoo00000Woo00<007ooOol06goo0`0000=oo`0000000P0000Aoo`00
000001eoo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`08Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo00<007ooOol06goo0`0000=oo`000000
0P0000Aoo`00000001eoo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomo
o`0=Ool00`00Oomoo`08Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo00<007ooOol06goo0`00
00=oo`0000000P0000Aoo`00000001eoo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`08
Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`0:Ool00`00Oomoo`0BOol2000GOol7000GOol6000OOol4000[Ool4000oOol4000m
Ool00`00Oomoo`05Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00moo`03001oogoo00eoo`03001o
ogoo00Qoo`03001oogoo00Aoo`05001oogooOol00003Ool00`00Oomoo`0JOol300000goo00000002
000017oo0000000077oo00@007ooOol000Aoo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo
00eoo`03001oogoo00Qoo`03001oogoo00Aoo`05001oogooOol00003Ool00`00Oomoo`0JOol30000
0goo00000002000017oo0000000077oo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo
00Qoo`03001oogoo00eoo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
000LOol300000goo00000002000017oo0000000077oo00D007ooOomoo`0000=oo`03001oogoo00Ao
o`03001oogoo00Qoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo0:=oo`03001oogoo00=o
o`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo011oo`<001Ioo`<002Aoo`H001eoo`<002ao
o`<0041oo`8003]oo`03001oogoo00Eoo`03001oogoo071oo`00F7oo00<007ooOol03goo00<007oo
Ool03Woo00<007ooOol027oo00<007ooOol017oo00D007ooOomoo`0000=oo`03001oogoo01Qoo`05
001oo`00001oo`0400001Goo000007oo00006Woo00@007ooOol000Aoo`03001oogoo00Aoo`03001o
ogoo00Qoo`03001oogoo00moo`03001oogoo00Qoo`03001oogoo00Aoo`05001oogooOol00003Ool0
0`00Oomoo`0IOol4000017oo000007oo10006goo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03
001oogoo00Qoo`03001oogoo00moo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo009oo`04
001oogoo000JOol01@00Ool00000Ool0100000Eoo`00001oo`0001Yoo`05001oogooOol00003Ool0
0`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`2SOol0
0`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`0@Ool00`00Oomoo`0DOol3
000]Ool4000LOol2000]Ool3000oOol00`00Oomoo`0hOol00`00Oomoo`05Ool00`00Oomoo`1`Ool0
05Qoo`03001oogoo00ioo`03001oogoo00moo`03001oogoo00Uoo`03001oogoo00Aoo`05001oogoo
Ool00003Ool00`00Oomoo`0GOol01P00Ool007oo001oo`800003Ool007oo00<001Uoo`04001oogoo
0004Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`0@Ool00`00Oomoo`08Ool00`00Oomo
o`04Ool01@00Oomoogoo00000Woo00<007ooOol067oo0`0000=oo`00Ool00P0000=oo`00Ool00`00
6Woo00@007ooOol000=oo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo011oo`03001oogoo
00Uoo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo000IOol300000goo001oo`0200001Woo
001oo`00Ool001Uoo`05001oogooOol00003Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomo
o`0?Ool00`00Oomoo`0>Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`08Ool00`00Oomoo`0?Ool2000DOol3000dOol3000KOol00`00Oomoo`0]Ool00`00Oomoo`0mOol3
000gOol00`00Oomoo`05Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00eoo`03001oogoo015oo`03
001oogoo00Uoo`03001oogoo00Aoo`05001oogooOol00003Ool00`00Oomoo`0FOol300000goo001o
o`0200000goo001oo`03000HOol01@00Oomoogoo00000goo00<007ooOol017oo00<007ooOol02Goo
00<007ooOol04Goo00<007ooOol02Goo00<007ooOol017oo00D007ooOomoo`00009oo`03001oogoo
01Moo`<00003Ool007oo00800003Ool007oo00<001Uoo`04001oogoo0003Ool00`00Oomoo`04Ool0
0`00Oomoo`09Ool00`00Oomoo`0AOol00`00Oomoo`09Ool00`00Oomoo`04Ool01@00Oomoogoo0000
0goo00<007ooOol05Woo0`0000=oo`00Ool00P0000=oo`00Ool00`0067oo00D007ooOomoo`0000=o
o`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo015oo`03001oogoo00eoo`03001oogoo0:=o
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00moo`03001oogoo015o
o`<003Yoo`<001Uoo`@002aoo`<003moo`8003Eoo`03001oogoo00Eoo`03001oogoo071oo`00F7oo
00<007ooOol02goo0P005Goo0P002Woo0P001Goo0P000Woo1@005Woo100000=oo`00Ool00P0000=o
o`00Ool00P0000=oo`00Ool05Goo0P0000=oo`0000000Woo0P0017oo0`002Woo0P005Goo00<007oo
Ool02Goo0`0017oo0P000Woo1@005Goo0P0000Ioo`00001oo`00Ool200000goo001oo`0200000goo
0000000EOol50002Ool20005Ool2000;Ool00`00Oomoo`0COol2000:Ool30004Ool3000017oo0000
07oo0P005Woo00L007oo000007oo001oo`0200000goo001oo`04000FOol200000goo00000002Ool2
0005Ool2000:Ool2000EOol2000=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`07Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0nOol2000KOol2000]Ool3
000nOol00`00Oomoo`0bOol00`00Oomoo`05Ool00`00Oomoo`1`Ool003Eoo`D000eoo`@000eoo`03
001oogoo00Uoo`8001Uoo`03001oogoo00Uoo`<000Aoo`8000=oo`@001=oo`800006Ool00000Ool0
07oo0P0000Aoo`00Oomoo`800003Ool00000015oo`<0009oo`03001oo`00008000Aoo`8000]oo`80
01Qoo`8000aoo`8000Aoo`<0009oo`04001oo`00000BOol02@00Ool00000Ool007oo001oo`020000
1Goo001oo`00Ool00P0000=oo`00Ool04Goo0P0000Aoo`00Oomoo`<000Aoo`<000]oo`8001Qoo`80
00]oo`8000Eoo`800004Ool007ooOol3000AOol200000goo00000002Ool01`00Ool00000Ool007oo
00800003Ool0000001=oo`D0009oo`8000Aoo`<000]oo`03001oogoo01Moo`8000]oo`03001oogoo
0:=oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00moo`03001oogoo
00moo`8004=oo`03001oogoo01Yoo`03001oogoo02eoo`8003eoo`80039oo`03001oogoo00Eoo`03
001oogoo071oo`00<goo20002Woo20002goo00<007ooOol01goo0P0077oo0P0037oo0P0017oo0`00
0Woo10003goo0`0000Eoo`00Oomoo`00009oo`80009oo`03001oogoo0080009oo`<000aoo`80009o
o`D000Eoo`8000]oo`8001aoo`<000]oo`8000Eoo`800004Ool007ooOol3000>Ool30002Ool00`00
Ool00002Ool20002Ool00`00Ool00002Ool3000>Ool30002Ool01000Ool000001Goo0P002goo0`00
77oo0P002goo0P001Goo1P0000=oo`00000037oo0`000Woo0P000Woo00<007ooOol00P000Woo00D0
07ooOol007oo00<000moo`@0009oo`<000Aoo`8000aoo`8001aoo`8000Uoo`03001oogoo0:=oo`03
001oogoo00=oo`05001oogooOol00009Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool30016Ool3000J
Ool3000^Ool00`00Oomoo`0lOol00`00Oomoo`0`Ool00`00Oomoo`04Ool00`00Oomoo`1`Ool003=o
o`8000Aoo`<000Uoo`8000Aoo`8000]oo`03001oogoo00Ioo`03001oogoo01ioo`<000]oo`8000Eo
o`80009oo`D000Yoo`@00005Ool007ooOol00002Ool01000Oomoo`000Woo00<007ooOol010000Woo
0`001goo0P0000Eoo`00000007oo008000Aoo`<000]oo`80025oo`8000]oo`<000Aoo`H00004Ool0
00000008Ool40002Ool200001Goo001oogoo00000Woo00D007ooOol007oo0080009oo`@000Qoo`<0
009oo`D000Eoo`8000]oo`80025oo`8000]oo`<000Aoo`80009oo`800003Ool0000000Moo`<000=o
o`<0009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007oo00000`002Woo1@000Woo0P001Goo
0P002goo0`0087oo00<007ooOol01Woo00<007ooOol0Xgoo00<007ooOol00goo00D007ooOomoo`00
00Uoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo01Yoo`d002=oo`8001]oo`03001oogoo
02aoo`8003eoo`80031oo`03001oogoo00Aoo`03001oogoo071oo`00<Woo0P001Woo0`001goo0P00
1Woo0P002Woo00<007ooOol0:Woo0`002Woo10000goo0P000Woo4P0000=oo`0000000Woo0P000Woo
0P000Woo0P0000=oo`00000040000Woo0P000goo0`002goo0`009Goo0P0037oo0P0017oo4`0000=o
o`0000000Woo00D007ooOomoo`00009oo`05001oogooOol00002OolF0004Ool3000;Ool2000UOol4
000:Ool30003Ool300000goo0000000@00000goo00000002Ool20002Ool20002Ool200000goo0000
000@0002Ool20003Ool4000:Ool3000/Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01@00Oomoogoo
000027oo00<007ooOol037oo0P003Woo0P006Goo10003Goo1`007Woo0P006Woo0P00;Woo00<007oo
Ool0?7oo0P00;Woo00<007ooOol017oo00<007ooOol0L7oo000aOol20008Ool20007Ool20006Ool2
000:Ool00`00Oomoo`0]Ool50009Ool400000goo0000000>0003Ool20003Ool00`00Oomoo`04Ool0
1@00Oomoogoo000017oo400000=oo`0000000P002Goo1@00:Woo10002Woo600000Aoo`000000009o
o`8000Aoo`80009oo`@00003Ool0000001D000]oo`<002]oo`@000Uoo`D00003Ool0000000h000=o
o`05001oogooOol00006Ool01000Oomoogoo0P000goo400000=oo`0000000P002Woo1000;goo00<0
07ooOol0Xgoo00<007ooOol00goo00D007ooOomoo`0000Qoo`03001oogoo00aoo`03001oogoo00ao
o`03001oogoo01Ioo`<001Qoo`<001eoo`8001Yoo`8002eoo`<003eoo`03001oogoo02]oo`03001o
ogoo00Aoo`03001oogoo071oo`007Woo3@001Woo0P0027oo0P001Woo0P0027oo0P002Goo00<007oo
Ool0<Woo2@0017oo50000Woo0`0027oo0`0000=oo`0000004`0017oo2@00<goo2@002Goo4@000goo
0P0027oo0P0017oo4@002Goo2@00<Woo2@001Goo500000Aoo`00000000Qoo`@00003Ool000000180
00Eoo`T003=oo`03001oogoo0:=oo`03001oogoo00=oo`05001oogooOol00007Ool00`00Oomoo`0<
Ool00`00Oomoo`0<Ool00`00Oomoo`0DOol3000NOol3000LOol00`00Oomoo`0IOol00`00Oomoo`0]
Ool3000kOol00`00Oomoo`0ZOol00`00Oomoo`04Ool00`00Oomoo`1`Ool001ioo`d000Ioo`8000Qo
o`8000Ioo`8000Qoo`8000Uoo`03001oogoo03]ooaX000iooaX004Eooad000aooah004AooaX000mo
oaX003aoo`03001oogoo0:=oo`8000Aoo`05001oogooOol00007Ool00`00Oomoo`0;Ool00`00Oomo
o`0<Ool00`00Oomoo`0BOol3000TOol3000JOol2000JOol2000`Ool00`00Oomoo`0iOol00`00Oomo
o`0YOol00`00Oomoo`03Ool2001bOol001ioo`d000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Uoo`@0
03eooaH0011ooaP004YooaH0019ooaH004YooaP0011ooaH003eoo`@00:Eoo`03001oogoo00=oo`05
001oogooOol00007Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0AOol2000ZOol2000J
Ool00`00Oomoo`0IOol00`00Oomoo`0^Ool00`00Oomoo`0iOol00`00Oomoo`0XOol00`00Oomoo`04
Ool00`00Oomoo`1`Ool0035oo`<000Ioo`<000Ioo`8000Qoo`8000Uoo`03001oogoo035oob0000=o
o`@000Qoo`@000=ooa<00003Ool0000000X003Eoo`X000AooaH000YooaL000=oo`X003Eoo``0009o
oa<0009oo`@000Qoo`@000=oob40039oo`03001oogoo0:=oo`03001oogoo00=oo`05001oogooOol0
0006Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool2000^Ool2000IOol2000JOol2
000_Ool2000jOol00`00Oomoo`0WOol00`00Oomoo`04Ool00`00Oomoo`1`Ool0035oo`@000Aoo`<0
00Moo`8000Qoo`8000Uoo`03001oogoo02aoo`D000Uoo`@000Eooa4000=oo`03001oogoo00Ioo`03
001oogoo018000Eoo`@000Uoo`D002aoo`@000UooaH0009oo`800003Ool0000000Ioo`800005Ool0
0000001oo`0F0009Ool5000/Ool40009Ool50004OolB0002Ool00`00Oomoo`06Ool01000Oomoogoo
4P0017oo1@002Goo1000;Woo00<007ooOol0Xgoo00<007ooOol00goo00D007ooOomoo`0000Ioo`03
001oogoo00]oo`03001oogoo00Yoo`03001oogoo00moo`80039oo`8001Uoo`03001oogoo01Uoo`03
001oogoo02ioo`8003Uoo`03001oogoo02Ioo`03001oogoo00Aoo`03001oogoo071oo`00<Goo0P00
00=oo`0000001@0027oo0P0027oo0P002Goo00<007ooOol0:Goo0`002Woo100017oo6@0000=oo`00
Ool01Goo00<007oo00001@0000=oo`000000400017oo0`002goo0`0097oo1@002Goo100000=oo`00
00000P0000=oo`0000004@0000Eoo`00Oomoo`0000Aoo`05001oogoo001oo`0C0002Ool300000goo
000000030009Ool4000TOol4000:Ool30005OolA0002Ool500000goo001oo`05Ool00`00Ool0000H
0005Ool3000:Ool3000[Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01000Oomoo`001goo00<007oo
Ool02Woo00<007ooOol02goo00<007ooOol03Woo00<007ooOol0=7oo00<007ooOol05goo00<007oo
Ool06Goo00<007ooOol0;goo00<007ooOol0=goo00<007ooOol09Goo00<007ooOol017oo00<007oo
Ool0L7oo000bOol00`00Oomoo`050009Ool20008Ool20009Ool00`00Oomoo`06Ool2000NOol3000;
Ool20005Ool300000goo000000060006Ool600001goo001oogoo001oo`0000Aoo`05001oo`00Ool0
0002Ool60006Ool8000017oo0000000017oo0`002goo0P007goo0`002Woo10000goo0P000Woo1P00
2Goo0P000Woo00P007ooOol007oo001oo`0017oo00D007oo001oo`00009oo`03001oogoo008000Uo
o`H0009oo`8000Aoo`<000Yoo`<001moo`8000]oo`<000Aoo`@00003Ool0000000H000Eoo`H0009o
o`05001oo`00Ool00004Ool00`00Ool00002Ool00`00Ool000060005Ool400001Goo00000000Ool0
0`001Goo0P002goo0P007goo0P0027oo00<007ooOol0Xgoo00<007ooOol00goo00@007ooOol000Io
o`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00ioo`03001oogoo03Ioo`8001Qoo`03001o
ogoo01Uoo`03001oogoo02moo`03001oogoo03Ioo`03001oogoo02Eoo`03001oogoo00Aoo`03001o
ogoo071oo`00<Woo0P003goo0P0027oo0P002Goo00<007ooOol027oo0P006goo00<007ooOol02Woo
0P001Goo0P000Woo1P003Woo00D007oo001oo`00009oo`03001oo`00009oo`05001oo`00Ool00002
Ool3000>Ool300000goo00000002Ool20005Ool2000;Ool2000KOol2000;Ool20005Ool20002Ool2
00000goo0000000>Ool60002Ool00`00Ool00002Ool00`00Ool00002Ool6000>Ool50002Ool20005
Ool2000;Ool3000JOol2000;Ool20005Ool20002Ool6000>Ool30002Ool01@00Ool007oo00000Woo
00<007oo00000Woo00<007oo00000P003Woo1P000Woo0`0017oo0P002goo0P006goo0P002Woo00<0
07ooOol0Xgoo00<007ooOol00goo00@007ooOol000Ioo`03001oogoo00Yoo`03001oogoo00Yoo`03
001oogoo00ioo`03001oogoo03Uoo`03001oogoo01Ioo`03001oogoo01Uoo`03001oogoo02moo`03
001oogoo03Ioo`03001oogoo02Aoo`03001oogoo00Aoo`03001oogoo071oo`00<Woo0`003goo0P00
1Woo0P002Woo00<007ooOol02Woo00<007ooOol05goo00<007ooOol02Goo0P001Goo0P000Woo0P00
00=oo`00Ool04Woo0P000Woo00D007oo001oo`00009oo`05001oo`00Ool00002Ool00`00Oomoo`0A
Ool200000goo00000002Ool20005Ool2000;Ool2000GOol2000;Ool20004Ool30002Ool200000goo
0000000COol00`00Ool00002Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool0000DOol01000
Ool000000Woo0`0017oo0P0037oo00<007ooOol05Goo0P002goo0P001Goo0P000Woo0P0000=oo`00
00004goo00P007ooOol007oo001oo`000Woo00D007oo001oo`00009oo`8001=oo`04001oo`000003
Ool00`00Oomoo`03Ool2000;Ool00`00Oomoo`0GOol00`00Oomoo`0:Ool00`00Oomoo`2SOol00`00
Oomoo`03Ool01000Oomoo`001Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol03Woo00<0
07ooOol057oo4@005Woo0P005goo00<007ooOol06Goo0`00;goo00<007ooOol0=Woo0P0097oo00<0
07ooOol017oo00<007ooOol0L7oo000cOol3000>Ool20006Ool2000:Ool00`00Oomoo`0;Ool00`00
Oomoo`0EOol00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`020002Ool00`00Oomoo`0BOol0
0`00Ool00002Ool200001Woo001oogoo001oo`80009oo`8001Eoo`04001oogoo0003Ool20005Ool0
0`00Oomoo`0:Ool00`00Oomoo`0DOol00`00Oomoo`08Ool20005Ool00`00Oomoo`02Ool01000Oomo
o`005Woo0`0000Aoo`00Ool0009oo`04001oo`00Ool3000FOol01000Oomoo`0017oo00<007ooOol0
0goo0P002Woo00<007ooOol057oo00<007ooOol02Woo00<007ooOol00goo0P000goo00@007ooOol0
01Eoo`80009oo`800006Ool007ooOol007oo0P000Woo00<007oo000057oo00<007ooOol00P000Woo
00<007ooOol017oo00<007ooOol02Goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol0Xgoo
00<007ooOol00goo00@007ooOol000Ioo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00eo
o`03001oogoo019oo`<0015oo`8001Ioo`03001oogoo01Eoo`03001oogoo01]oo`03001oogoo02eo
o`8003Moo`03001oogoo029oo`03001oogoo00Aoo`03001oogoo071oo`00=7oo0`003Woo0P0017oo
0P002goo00<007ooOol037oo00<007ooOol04goo00<007ooOol02Goo00<007ooOol017oo00@007oo
Ool000=oo`03001oogoo01Aoo`08001oo`00Ool007oo001oo`800005Ool007oo001oo`02000GOol0
1000Oomoo`0017oo00<007ooOol00goo00<007ooOol02Woo00<007ooOol04Woo00<007ooOol027oo
00<007ooOol01Goo00D007ooOomoo`00009oo`03001oogoo01Ioo`<00003Ool007oo00800003Ool0
07oo00<001Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`0BOol0
0`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`005goo0P0000Eoo`00Ool0
07oo00800008Ool007oo001oo`00Ool001Ioo`05001oogooOol00002Ool00`00Oomoo`04Ool00`00
Oomoo`09Ool00`00Oomoo`0COol00`00Oomoo`0<Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01000
Oomoo`001Woo00<007ooOol027oo00<007ooOol02Woo00<007ooOol03Goo00<007ooOol03goo1000
5Woo00<007ooOol057oo00<007ooOol05Goo00<007ooOol06goo00<007ooOol0;Woo00<007ooOol0
=Goo00<007ooOol08Goo00<007ooOol017oo00<007ooOol0L7oo000eOol80008Ool8000;Ool00`00
Oomoo`0=Ool00`00Oomoo`0AOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`000goo00<0
07ooOol05Woo0P000Woo0P0000Aoo`00001oo`800004Ool007oo000HOol01000Oomoo`0017oo00<0
07ooOol00goo00<007ooOol02Goo00<007ooOol04Goo00<007ooOol027oo00<007ooOol01Goo00D0
07ooOomoo`00009oo`03001oogoo01Moo`<00003Ool007oo00800003Ool007oo00<001Uoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`0AOol00`00Oomoo`09Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`0067oo00@007oo001oo`800004Ool00000Ool20002
Ool2000HOol01@00Oomoogoo00000Woo00<007ooOol017oo00<007ooOol02Goo00<007ooOol04Goo
00<007ooOol03Goo00<007ooOol0Xgoo00<007ooOol00goo00@007ooOol000Ioo`03001oogoo00Qo
o`03001oogoo00Uoo`03001oogoo00eoo`03001oogoo00ioo`8001]oo`<001Aoo`03001oogoo01Eo
o`8001aoo`03001oogoo02ioo`03001oogoo03Eoo`03001oogoo021oo`03001oogoo00Aoo`03001o
ogoo071oo`00=goo1P002Woo10003Goo00<007ooOol03Woo00<007ooOol03goo00<007ooOol02Goo
00<007ooOol017oo00D007ooOomoo`00009oo`03001oogoo01Qoo`800004Ool00000Ool200001Woo
00000000Ool001Yoo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`0?
Ool00`00Oomoo`09Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo00<007ooOol067oo00<007oo
00000P0000Aoo`00001oo`<00003Ool007oo01Uoo`04001oogoo0003Ool00`00Oomoo`04Ool00`00
Oomoo`09Ool00`00Oomoo`0?Ool00`00Oomoo`09Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo
00<007ooOol067oo00<007oo00000P0000Aoo`00001oo`800003Ool0000001Yoo`04001oogoo0003
Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`2S
Ool00`00Oomoo`03Ool01000Oomoo`001Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol0
3Goo00<007ooOol03Goo0P0087oo00<007ooOol04Woo00<007ooOol05Woo00<007ooOol06Woo00<0
07ooOol0;Woo0P00=Woo00<007ooOol07goo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00
Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000
Oomoo`006Woo00<007oo00000P0000Aoo`00001oo`<00003Ool007oo01Uoo`04001oogoo0004Ool0
0`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`09Ool00`00Oomoo`03Ool0
1@00Oomoogoo00000goo00<007ooOol067oo00<007oo00000P0000Aoo`00001oo`<00003Ool007oo
01Uoo`05001oogooOol00003Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`0?Ool00`00
Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`006Woo00<007oo00000P0000Ao
o`00001oo`<00003Ool007oo01Uoo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`08Ool0
0`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01000Oomoo`001Goo
00<007ooOol027oo00<007ooOol02Goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol08Goo
00<007ooOol04Woo00<007ooOol05Woo00<007ooOol06Woo00<007ooOol0;goo00<007ooOol0<goo
00<007ooOol07goo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`0?Ool00`00Oomo
o`0=Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`006goo00<007oo
00000P0000Aoo`00001oo`<00003Ool007oo01Yoo`04001oogoo0004Ool00`00Oomoo`04Ool00`00
Oomoo`08Ool00`00Oomoo`0=Ool00`00Oomoo`09Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo
00<007ooOol06Goo00<007oo00000P0000Aoo`00001oo`<00003Ool007oo01Yoo`05001oogooOol0
0003Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`0=Ool00`00Oomoo`08Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool01000Oomoo`006goo00<007oo00000P0000Aoo`00001oo`<00003Ool0
07oo01Yoo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01000Oomoo`001Goo00<007ooOol027oo00<0
07ooOol02Goo00<007ooOol037oo00<007ooOol037oo00<007ooOol08goo00<007ooOol04Goo00<0
07ooOol05goo00<007ooOol06Goo00<007ooOol0<7oo00<007ooOol0<Woo00<007ooOol07goo00<0
07ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomoo`08
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`007Goo0`0000=oo`0000000`0000=oo`00
00007Goo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00eoo`03001o
ogoo00Qoo`03001oogoo00=oo`03001oogoo009oo`04001oogoo000MOol300000goo000000030000
0goo0000000MOol01000Oomoo`0017oo00<007ooOol00goo00<007ooOol027oo00<007ooOol03Goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol00Woo00@007ooOol001eoo`800003Ool00000
00<00004Ool00000000MOol01000Oomoo`0017oo00<007ooOol00goo00<007ooOol027oo00<007oo
Ool037oo00<007ooOol047oo00<007ooOol0Xgoo00<007ooOol00goo00@007ooOol000Aoo`03001o
ogoo00Qoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo02Eoo`80019o
o`03001oogoo01Ioo`03001oogoo01Yoo`03001oogoo02moo`03001oogoo03=oo`03001oogoo01io
o`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<007ooOol047oo00<007ooOol02goo00<007oo
Ool027oo00<007ooOol00goo00<007ooOol00Woo00@007ooOol001ioo`<00003Ool0000000<00003
Ool0000001ioo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool0
0`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`007Woo0`0000=oo`000000
0`0000=oo`0000007Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo
00]oo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo009oo`04001oogoo000NOol200000goo
00000003000017oo000000007Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00Qoo`03
001oogoo00]oo`03001oogoo011oo`03001oogoo0:=oo`03001oogoo00=oo`04001oogoo0004Ool0
0`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0XOol0
0`00Oomoo`0@Ool00`00Oomoo`0FOol00`00Oomoo`0JOol00`00Oomoo`0_Ool00`00Oomoo`0cOol0
0`00Oomoo`0MOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo009oo`04001oogoo
000NOol300000goo0000000300000goo0000000NOol01000Oomoo`0017oo00<007ooOol00goo00<0
07ooOol027oo00<007ooOol02goo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00@0
07ooOol001ioo`<00003Ool0000000<00003Ool0000001ioo`04001oogoo0004Ool00`00Oomoo`04
Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool01000Oomoo`007Woo0P0000=oo`0000000`0000Aoo`00000001ioo`04001oogoo0004Ool00`00
Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00
Oomoo`2SOol20004Ool01000Oomoo`0017oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
2goo00<007ooOol037oo00<007ooOol0:Woo00<007ooOol047oo0P005goo0P006goo0P00<7oo0P00
=7oo00<007ooOol077oo00<007ooOol00goo0P00LWoo001HOol00`00Oomoo`06Ool00`00Oomoo`07
Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo
00007Woo0`0000=oo`0000000`0000=oo`0000007Woo00D007ooOomoo`0000=oo`03001oogoo00Ao
o`03001oogoo00Moo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009o
o`04001oogoo000NOol300000goo0000000300000goo0000000NOol01000Oomoo`0017oo00<007oo
Ool017oo00<007ooOol01goo00<007ooOol02goo00<007ooOol01goo00<007ooOol017oo00D007oo
Oomoo`0000=oo`03001oogoo01aoo`800003Ool0000000<00004Ool00000000NOol01@00Oomoogoo
000017oo00<007ooOol00goo00<007ooOol01goo00<007ooOol02goo00<007ooOol01goo00<007oo
Ool01Woo00<007ooOol0Xgoo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo02Yoo`80019oo`03001oogoo01Io
o`03001oogoo01Yoo`03001oogoo02moo`03001oogoo039oo`03001oogoo01aoo`03001oogoo00Ao
o`03001oogoo071oo`00F7oo0`001goo00<007ooOol01goo00<007ooOol02Goo00<007ooOol027oo
00<007ooOol00goo00<007ooOol00Woo00@007ooOol001moo`<00003Ool0000000800004Ool00000
000OOol01000Oomoo`000goo00<007ooOol017oo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool01goo00<007ooOol017oo00<007ooOol00Woo00@007ooOol001moo`<00003Ool0000000800004
Ool00000000OOol01000Oomoo`0017oo00<007ooOol017oo00<007ooOol01goo00<007ooOol02Goo
00<007ooOol027oo00<007ooOol017oo00D007ooOomoo`00009oo`03001oogoo01eoo`<00003Ool0
000000800004Ool00000000OOol01000Oomoo`0017oo00<007ooOol00goo00<007ooOol027oo00<0
07ooOol02Goo00<007ooOol01goo00<007ooOol01Goo0`00YGoo00<007ooOol00goo00@007ooOol0
00Aoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Yoo`03001oogoo00aoo`03001oogoo
02eoo`03001oogoo011oo`03001oogoo01Ioo`03001oogoo01Yoo`03001oogoo02moo`03001oogoo
035oo`03001oogoo01aoo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol02Goo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00@0
07ooOol001moo`<00003Ool0000000800004Ool00000000OOol01000Oomoo`0017oo00<007ooOol0
17oo00<007ooOol01goo00<007ooOol02Goo00<007ooOol01goo00<007ooOol017oo00<007ooOol0
0Woo00@007ooOol001moo`<00003Ool0000000800004Ool00000000OOol01000Oomoo`0017oo00<0
07ooOol017oo00<007ooOol01goo00<007ooOol02Goo00<007ooOol01goo00<007ooOol017oo00<0
07ooOol00Woo00@007ooOol001moo`<00003Ool0000000800004Ool00000000OOol01000Oomoo`00
17oo00<007ooOol017oo00<007ooOol01goo00<007ooOol02Goo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol0Xgoo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo00Moo`03001oogoo
00Qoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo02moo`03001oogoo011oo`03001oogoo
01Ioo`03001oogoo01Yoo`03001oogoo02moo`03001oogoo035oo`03001oogoo01]oo`03001oogoo
00Aoo`03001oogoo071oo`00F7oo00<007ooOol01goo00<007ooOol01goo00<007ooOol02Goo00<0
07ooOol01goo00<007ooOol017oo00<007ooOol00Woo00@007ooOol001moo`<00003Ool000000080
0004Ool00000000OOol01000Oomoo`0017oo00<007ooOol017oo00<007ooOol01goo00<007ooOol0
2Goo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00@007ooOol001moo`<00003Ool0
000000800004Ool00000000OOol01000Oomoo`0017oo00<007ooOol017oo00<007ooOol01goo00<0
07ooOol02Goo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00@007ooOol001moo`<0
0003Ool0000000800004Ool00000000OOol01000Oomoo`0017oo00<007ooOol017oo00<007ooOol0
1goo00<007ooOol02Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0Xgoo00<007ooOol0
0goo00@007ooOol000Aoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00]oo`03001oogoo
00]oo`03001oogoo031oo`03001oogoo011oo`03001oogoo01Eoo`03001oogoo01]oo`03001oogoo
02moo`03001oogoo031oo`03001oogoo01]oo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol02Goo00<007ooOol01goo00<007ooOol017oo00<0
07ooOol00Woo00@007ooOol001moo`<00003Ool0000000800004Ool00000000OOol01000Oomoo`00
17oo00<007ooOol017oo00<007ooOol01goo00<007ooOol02Goo00<007ooOol01goo00<007ooOol0
17oo00<007ooOol00Woo00@007ooOol001moo`<00003Ool0000000800004Ool00000000OOol01000
Oomoo`0017oo00<007ooOol017oo00<007ooOol01goo00<007ooOol02Goo00<007ooOol01goo00<0
07ooOol017oo00<007ooOol00Woo00@007ooOol001moo`<00003Ool0000000800004Ool00000000O
Ool01000Oomoo`0017oo00<007ooOol017oo00<007ooOol01goo00<007ooOol02Goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol0Xgoo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo
00Moo`03001oogoo00Qoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo035oo`03001oogoo
011oo`03001oogoo01Ioo`03001oogoo01]oo`03001oogoo02moo`03001oogoo031oo`03001oogoo
01Yoo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<007ooOol027oo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol06goo00<007oo00000P0000Aoo`00001oo`<00003Ool007oo01aoo`03001oogoo009oo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Moo`03
001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01]oo`800004Ool00000Ool2
000017oo000007oo0P007Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol06goo00<007oo00000P0000Aoo`00001oo`<00003Ool007oo01aoo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Qoo`03001oogoo0:=oo`03001oogoo00=oo`04001oogoo0004Ool00`00
Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0aOol00`00
Oomoo`0@Ool00`00Oomoo`0FOol00`00Oomoo`0KOol00`00Oomoo`0`Ool00`00Oomoo`0_Ool00`00
Oomoo`0JOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00Qoo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009o
o`03001oogoo01]oo`03001oo`0000800004Ool00000Ool200000goo0000000MOol00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0KOol2000017oo0000
07oo0P0000Aoo`00001oo`8001eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo009oo`03001oogoo01]oo`800004Ool00000Ool200001Woo00000000Ool001eoo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Qoo`03001oogoo0:=oo`03001oogoo00=oo`04001oogoo0004Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0DOol6000I
Ool00`00Oomoo`0@Ool00`00Oomoo`0FOol00`00Oomoo`0KOol00`00Oomoo`0`Ool00`00Oomoo`0_
Ool00`00Oomoo`0IOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00Qoo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo01]oo`800004Ool00000Ool2000017oo000007oo0P007Goo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol06goo0P0000Aoo`00
001oo`800004Ool00000Ool2000MOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`0KOol2000017oo000007oo0P0000Aoo`00001oo`8001eoo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Qoo`03001oogoo0:=oo`03001oogoo00=oo`03001oo`0000Eoo`03001o
ogoo00Ioo`03001oogoo00Qoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo019oo`<000Io
o`03001oogoo01Ioo`03001oogoo015oo`03001oogoo01Ioo`03001oogoo01]oo`03001oogoo031o
o`03001oogoo02moo`03001oogoo01Qoo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<007oo
Ool027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol017oo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol06goo0P0000Aoo`00001oo`800004Ool00000Ool2000M
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0K
Ool2000017oo000007oo0P0000Aoo`00001oo`8001eoo`03001oogoo009oo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`03
001oogoo009oo`03001oogoo009oo`03001oogoo01]oo`800004Ool00000Ool2000017oo000007oo
0P007Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol0Xgoo00<007ooOol00goo00<007oo
00001Goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol02Woo00<007oo
Ool04Woo00<007ooOol027oo0P005goo00<007ooOol04Goo00<007ooOol05Woo00<007ooOol06goo
00<007ooOol0<7oo00<007ooOol0;Woo00<007ooOol067oo00<007ooOol017oo00<007ooOol0L7oo
001HOol00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`04Ool00`00Oomoo`03Ool01@00Oomoogoo000077oo00@007oo001oo`800006Ool00000Ool007oo
0P0000=oo`00Ool06goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol06Woo00@007oo001oo`800004Ool00000Ool2000017oo001oo`0077oo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol06Woo00L007oo
000007oo001oo`0200001goo000007oo001oo`0001aoo`05001oogooOol00005Ool00`00Oomoo`04
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`2S
Ool00`00Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0:
Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0;Ool00`00Oomoo`0EOol00`00Oomoo`0@
Ool00`00Oomoo`0FOol00`00Oomoo`0LOol00`00Oomoo`0_Ool00`00Oomoo`0^Ool00`00Oomoo`0H
Ool00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00Qoo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00=oo`05001oogooOol0000KOol0
2000Ool007oo001oo`00Ool200001Goo001oo`00Ool00P006goo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol017oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
17oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol06Goo0P0000Eoo`00Ool007oo00800005
Ool007oo001oo`02000KOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`0IOol200001Goo001oo`00Ool00P0000Qoo`00Ool007oo001oo`006goo00D0
07ooOomoo`0000Eoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Qoo`03001oogoo0:=oo`03001oogoo00=oo`03001oo`0000Eoo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo00ao
o`03001oogoo01Aoo`03001oogoo011oo`03001oogoo01Ioo`03001oogoo01eoo`03001oogoo02mo
o`03001oogoo02ioo`03001oogoo01Moo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<007oo
Ool027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol017oo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol05goo00T007ooOol007oo001oo`00Ool00P0000Qoo`00
Ool007oo001oo`006Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01goo00<007ooOol017oo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol067oo00P007oo001oo`00Ool007oo0P0000Qoo`00Ool007oo001oo`006Woo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol067oo00P0
07oo001oo`00Ool007oo0P0000Ioo`00Ool007oo0002Ool00`00Oomoo`0GOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Ool00004Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool0
0`00Oomoo`0COol00`00Oomoo`0@Ool00`00Oomoo`0GOol00`00Oomoo`0LOol00`00Oomoo`0_Ool0
0`00Oomoo`0^Ool00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo
00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo01Moo`09001oogoo001oo`00Ool007oo00800006Ool007oo
001oo`000Woo00<007ooOol05goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol017oo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol017oo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol05goo00T007ooOol007oo001oo`00Ool00P0000Ioo`00Ool007oo0002
Ool00`00Oomoo`0GOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`0GOol02@00Oomoo`00Ool007oo001oo`0200001Woo001oo`00Ool0009oo`03001o
ogoo01Moo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo0:=oo`03001oogoo00=oo`03001o
o`0000Aoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Yoo`03001o
ogoo015oo`03001oogoo00ioo`03001oogoo01Aoo`03001oogoo011oo`03001oogoo01Ioo`03001o
ogoo01eoo`03001oogoo02moo`03001oogoo02eoo`03001oogoo01Moo`03001oogoo00Aoo`03001o
ogoo071oo`00F7oo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo
00<007ooOol017oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol05Goo00H007ooOol007oo
0002Ool01P00Ool00000Ool0009oo`03001oo`00009oo`03001oogoo01Eoo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01Eoo`06001oogoo001oo`00
0Woo00H007oo000007oo0002Ool00`00Ool00002Ool00`00Oomoo`0EOol00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0EOol01P00Oomoo`00Ool0009o
o`06001oo`00001oo`000Woo00<007oo00000Woo00<007ooOol05Goo00<007ooOol00Woo00<007oo
Ool017oo00<007ooOol017oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool027oo00<007ooOol0Xgoo00<007ooOol00goo00<007oo000017oo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol047oo00<007ooOol047oo00<007oo
Ool04goo00<007ooOol047oo00<007ooOol05goo00<007ooOol077oo00<007ooOol0<7oo00<007oo
Ool0;Goo00<007ooOol05Woo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool00`00Oomoo`0COol01000Oomoo`000Woo00D007oo001oo`00009oo`07001oo`00
Ool007oo00000goo00<007ooOol04goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo
00<007ooOol00goo00<007ooOol04goo00@007ooOol0009oo`05001oo`00Ool00002Ool01@00Ool0
07oo00000Woo00@007ooOol001Eoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Eoo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03
001oogoo009oo`03001oogoo01=oo`0;001oogooOol007oo001oo`00Ool00002Ool01@00Ool007oo
00000Woo00@007ooOol001Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo0:=oo`8000Ao
o`03001oo`0000Aoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo011oo`03001oogoo011oo`03001oogoo01=oo`03001oogoo011oo`03001oogoo01Mo
o`03001oogoo01aoo`03001oogoo031oo`03001oogoo02eoo`03001oogoo01Ioo`03001oogoo00=o
o`80079oo`00F7oo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol00goo00<007ooOol04Goo00@007ooOol000=o
o`05001oo`00Ool00002Ool01@00Ool007oo00000Woo00D007ooOomoo`0001=oo`03001oogoo00=o
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo019oo`04001oogoo0002
Ool01@00Ool007oo00000Woo00D007oo001oo`00009oo`04001oogoo000DOol00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0AOol01@00Oomoogoo0000
0Woo00D007oo001oo`00009oo`05001oo`00Ool00003Ool01000Oomoo`004goo00<007ooOol00goo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo
00<007ooOol027oo00<007ooOol0Xgoo00<007ooOol00goo00<007oo000017oo00<007ooOol01goo
00<007ooOol01goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol047oo00<007ooOol047oo
00<007ooOol04goo00<007ooOol04Goo00<007ooOol05goo00<007ooOol077oo00<007ooOol0<7oo
00<007ooOol0;7oo00<007ooOol05Woo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomo
o`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`05Ool20006Ool0
0`00Oomoo`03Ool2000?Ool20003Ool01000Oomoo`000Woo00<007oo00000Woo00<007oo00000Woo
00@007ooOol000=oo`8000moo`8000Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00=o
o`80011oo`80009oo`04001oogoo0002Ool00`00Ool00002Ool00`00Ool00002Ool01000Oomoo`00
0Woo0`003goo0P001Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00goo0P003goo0P00
0goo00@007ooOol0009oo`03001oo`00009oo`03001oo`00009oo`04001oogoo0003Ool2000?Ool2
0005Ool00`00Oomoo`04Ool20007Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Ool00004Ool00`00Oomoo`06Ool0
0`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0?Ool00`00Oomoo`0AOol0
0`00Oomoo`0DOol00`00Oomoo`0@Ool00`00Oomoo`0GOol00`00Oomoo`0MOol00`00Oomoo`0_Ool0
0`00Oomoo`0]Ool00`00Oomoo`0EOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo
00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo
00Aoo`03001oogoo00Eoo`8000Yoo`<000Aoo`05001oogooOol00002Ool00`00Ool00002Ool01P00
Oomoo`00Ool000=oo`03001oogoo009oo`8000Yoo`<000Ioo`03001oogoo00Eoo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Eo
o`03001oogoo00Aoo`8000]oo`<000=oo`05001oogooOol00002Ool00`00Ool00002Ool00`00Ool0
0002Ool01@00Oomoogoo000017oo0P002goo0P001Woo00<007ooOol01Goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Goo00<0
07ooOol017oo0`002Woo0P0017oo00L007ooOomoo`00Ool00002Ool01P00Oomoo`00Ool0009oo`05
001oogooOol00004Ool3000:Ool20007Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`2SOol00`00Oomoo`03
Ool00`00Ool00004Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`0?Ool00`00Oomoo`0AOol00`00Oomoo`0DOol00`00Oomoo`0@Ool00`00Oomoo`0H
Ool00`00Oomoo`0LOol00`00Oomoo`0`Ool00`00Oomoo`0/Ool00`00Oomoo`0EOol00`00Oomoo`04
Ool00`00Oomoo`1`Ool005Qoo`<000Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Aoo`8000Moo`@000=oo`<000Ioo`05001oogooOol00002Ool0
1000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00005Ool40003Ool30008Ool00`00Oomo
o`05Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`05Ool00`00Oomoo`05Ool30005Ool30004Ool20003Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0003Ool20004Ool30005Ool30007Ool00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00
Oomoo`05Ool00`00Oomoo`06Ool30004Ool30005Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0002Ool01@00Oomoogoo00001Woo0`0017oo0`001goo0P001Woo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01Goo0`00YGoo00<007oo
Ool00goo00<007oo000017oo00<007ooOol01Woo00<007ooOol01goo00<007ooOol02Woo00<007oo
Ool02Woo00<007ooOol03goo00<007ooOol04Goo00<007ooOol057oo00<007ooOol04Goo00<007oo
Ool05goo00<007ooOol07Goo00<007ooOol0<7oo00<007ooOol0:goo00<007ooOol05Goo00<007oo
Ool017oo00<007ooOol0L7oo001HOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`09Ool0
0`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`08Ool30008Ool01@00Oomo
ogoo00000goo00@007ooOol0009oo`07001oogooOol007oo000017oo00<007ooOol01Woo0`002Woo
00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol02Goo00<007ooOol01goo
00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01goo1@001Woo00<007ooOol00Woo00D007oo
Oomoo`00009oo`04001oogoo0002Ool01@00Oomoogoo000017oo00<007ooOol017oo1@002Goo00<0
07ooOol01Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol02Goo00<007ooOol01goo00<0
07ooOol01Woo00<007ooOol01Woo00<007ooOol027oo10001goo00<007ooOol00Woo00<007oo0000
0goo00@007ooOol0009oo`05001oogooOol00003Ool00`00Oomoo`06Ool40009Ool00`00Oomoo`06
Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Ool00004Ool00`00Oomoo`06Ool00`00Oomoo`07
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0?Ool00`00Oomoo`0AOol00`00Oomoo`0D
Ool00`00Oomoo`0AOol00`00Oomoo`0GOol00`00Oomoo`0MOol00`00Oomoo`0`Ool00`00Oomoo`0[
Ool00`00Oomoo`0EOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00Ioo`03001o
ogoo00Qoo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`80015o
o`8000=oo`05001oogooOol00003Ool01000Oomoo`000goo00<007ooOol00P000goo0P004Woo00<0
07ooOol01Woo00<007ooOol01Woo00<007ooOol027oo00<007ooOol02Goo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01Woo0P004Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`04001o
ogoo0003Ool01@00Oomoogoo000017oo00<007ooOol03goo0P0027oo00<007ooOol01Woo00<007oo
Ool027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool047oo0P000goo0P000Woo00D007ooOomoo`00009oo`05001oogooOol00003Ool01000Oomoogoo
0P004Goo0P0027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol02Goo00<007ooOol027oo
00<007ooOol01Woo00<007ooOol0Xgoo00<007ooOol00goo00<007oo000017oo00<007ooOol01Woo
00<007ooOol01goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol047oo00<007ooOol03goo
00<007ooOol05Goo00<007ooOol04Goo00<007ooOol067oo00<007ooOol07Goo00<007ooOol0;goo
00<007ooOol0:goo00<007ooOol05Goo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomo
o`06Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`08Ool2000<Ool30005Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00005
Ool2000?Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool2000=Ool20005Ool01@00Oomoogoo00000goo
00@007ooOol000=oo`05001oogooOol00005Ool2000=Ool2000:Ool00`00Oomoo`06Ool00`00Oomo
o`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`0=Ool20005Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00005Ool3000<
Ool2000:Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00
Oomoo`06Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Ool00004Ool00`00Oomoo`06Ool00`00
Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00
Oomoo`0EOol00`00Oomoo`0BOol00`00Oomoo`0GOol00`00Oomoo`0MOol00`00Oomoo`0`Ool00`00
Oomoo`0[Ool00`00Oomoo`0DOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00Io
o`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Uo
o`8000Moo`<000Moo`05001oogooOol00004Ool01000Oomoo`0017oo00D007ooOomoo`0000Ioo`@0
00Qoo`<000Uoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03
001oogoo00Moo`03001oogoo00Uoo`@000Ioo`<000Ioo`03001oogoo009oo`05001oogooOol00002
Ool01@00Oomoogoo000017oo00<007ooOol017oo0`001goo0`002goo00<007ooOol01goo00<007oo
Ool027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo100027oo
0`001Woo00D007ooOomoo`0000Aoo`04001oogoo0004Ool01@00Oomoogoo00001goo0`001goo0P00
2goo00<007ooOol01goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
1Woo00<007ooOol0Xgoo00<007ooOol00goo00<007oo000017oo00<007ooOol01Woo00<007ooOol0
1goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol03Woo00<007ooOol0
5Goo00<007ooOol04Woo00<007ooOol05goo00<007ooOol07Woo00<007ooOol0;goo00<007ooOol0
:goo00<007ooOol057oo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`0AOol00`00
Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool70009Ool00`00Oomoo`02
Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Moo`P000]oo`03001oogoo
00Moo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00aoo`H000Qoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo1`003Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo
00<007ooOol01goo00<007ooOol02Woo200027oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05
001oogooOol00004Ool00`00Oomoo`07Ool7000<Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`09Ool00`00Oomoo`0AOol00`00Oomoo`2BOol6000;Ool00`00Oomoo`03Ool00`00Ool00004
Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0B
Ool2000<Ool2000HOol00`00Oomoo`0BOol00`00Oomoo`0HOol00`00Oomoo`0MOol00`00Oomoo`0`
Ool00`00Oomoo`0ZOol00`00Oomoo`0DOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001o
ogoo015oo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo01Qoo`03001o
ogoo00=oo`05001oogooOol00004Ool01@00Oomoogoo00001Goo00<007ooOol067oo00<007ooOol0
27oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
67oo00<007ooOol00goo00D007ooOomoo`0000Aoo`05001oogooOol00005Ool00`00Oomoo`0HOol0
0`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool0
0`00Oomoo`0HOol00`00Oomoo`03Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Eoo`03001o
ogoo01Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo015oo`03001o
ogoo091oo`X000Uoo`03001oogoo00=oo`03001oo`0000Aoo`03001oogoo00Ioo`03001oogoo00Mo
o`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo01Aoo`03001oogoo00Qoo`03001oogoo01Qo
o`03001oogoo019oo`03001oogoo01Qoo`03001oogoo01eoo`03001oogoo031oo`03001oogoo02Yo
o`03001oogoo01Aoo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<007ooOol04Goo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol05Goo0P001Goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo0P005Woo0P002goo00<007ooOol02Goo
00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo0P005goo00<007ooOol00goo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol05Goo0P002goo
00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo0P005Woo0P001Goo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo0P005goo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol04Goo00<007ooOol0T7oo0`001Goo
0`0027oo00<007ooOol00goo00<007oo000017oo00<007ooOol01Woo00<007ooOol01goo00<007oo
Ool02Woo00<007ooOol02Woo00<007ooOol05Goo0`001Goo0P006goo00<007ooOol04Woo00<007oo
Ool067oo00<007ooOol07Woo00<007ooOol0<7oo00<007ooOol0:Goo00<007ooOol057oo00<007oo
Ool017oo00<007ooOol0L7oo001HOol00`00Oomoo`0AOol00`00Oomoo`09Ool00`00Oomoo`0:Ool0
0`00Oomoo`09Ool00`00Oomoo`0BOol20007Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`05Ool00`00Oomoo`0BOol00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool2000DOol00`00Oomoo`04Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0BOol2000=Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`0BOol00`00Oomo
o`05Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool2000DOol0
0`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0AOol00`00Oomoo`2IOol2
0008Ool00`00Oomoo`03Ool00`00Ool00004Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0GOol5000LOol00`00Oomoo`0COol00`00Oomoo`0IOol0
0`00Oomoo`0MOol00`00Oomoo`0`Ool00`00Oomoo`0ZOol00`00Oomoo`0COol00`00Oomoo`04Ool0
0`00Oomoo`1`Ool005Qoo`03001oogoo015oo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo
00Yoo`80015oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo00Eoo`03001oogoo00moo`8000eoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
00Yoo`03001oogoo00aoo`03001oogoo00moo`8000Ioo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo00Aoo`80015oo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo00Yoo`03001oogoo00]oo`80015oo`03001oogoo00Eoo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00moo`8000aoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo015oo`03001oogoo09Yoo`8000Moo`03001oogoo00=oo`03
001oo`0000Aoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00]oo`03
001oogoo03Qoo`03001oogoo01=oo`03001oogoo01Uoo`03001oogoo01ioo`03001oogoo031oo`03
001oogoo02Uoo`03001oogoo01=oo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<007ooOol0
47oo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo0`002goo0`0027oo00<007ooOol0
0goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol01Woo10002goo0P003Woo00<007ooOol0
2Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol037oo0`002goo0`001goo00<007ooOol0
0goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol01Woo0`002goo0`003Woo00<007ooOol0
2Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol037oo0P0037oo0`0027oo00<007ooOol0
0Woo00<007ooOol017oo00<007ooOol00goo00<007ooOol01Woo0`002goo0`003Goo00<007ooOol0
2Woo00<007ooOol02goo00<007ooOol047oo00<007ooOol0VWoo0P001goo00<007ooOol00goo00<0
07oo000017oo00<007ooOol01Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol02goo00<0
07ooOol0>7oo00<007ooOol04goo00<007ooOol06Goo00<007ooOol07Woo00<007ooOol0<7oo00<0
07ooOol0:Goo00<007ooOol04goo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`0@
Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool40002Ool5000:Ool00`00Oomoo`04
Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`09Ool500000goo00000003000?Ool00`00
Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0>Ool50002Ool40009Ool00`00
Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`08Ool40002Ool5000@Ool00`00
Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool50002Ool5000:Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`08Ool50002Ool4000?Ool00`00
Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`2JOol20007Ool00`00Oomoo`03
Ool00`00Ool00004Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`0<
Ool00`00Oomoo`0gOol00`00Oomoo`0COol00`00Oomoo`0IOol00`00Oomoo`0OOol00`00Oomoo`0`
Ool00`00Oomoo`0XOol00`00Oomoo`0COol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001o
ogoo011oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo015oo`8000moo`03001oogoo00Ao
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo019oo`03001oogoo00]o
o`03001oogoo00]oo`03001oogoo00]oo`03001oogoo01=oo`8000eoo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo00Aoo`03001oogoo00]oo`8001Eoo`03001oogoo00]oo`03001oogoo00]o
o`03001oogoo00]oo`03001oogoo019oo`8000ioo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo00eoo`8001=oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo011o
o`03001oogoo09Yoo`8000Moo`<000=oo`03001oo`0000Aoo`03001oogoo00Ioo`03001oogoo00Qo
o`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo03Ioo`03001oogoo01Aoo`03001oogoo01Yo
o`03001oogoo01ioo`03001oogoo031oo`03001oogoo02Uoo`03001oogoo019oo`03001oogoo009o
o`<0079oo`00F7oo00<007ooOol047oo00<007ooOol02goo00<007ooOol037oo00<007ooOol087oo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol087oo00<007ooOol037oo
00<007ooOol02goo00<007ooOol037oo00<007ooOol087oo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol087oo00<007ooOol037oo00<007ooOol02goo00<007ooOol037oo
00<007ooOol087oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol087oo
00<007ooOol037oo00<007ooOol02goo00<007ooOol047oo00<007ooOol0VWoo0P001goo00<007oo
Ool00goo00<007oo000017oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol02Woo00<007oo
Ool02goo00<007ooOol0=Woo00<007ooOol057oo00<007ooOol06Woo00<007ooOol07Woo00<007oo
Ool0<Goo00<007ooOol0:7oo00<007ooOol04Woo00<007ooOol017oo00<007ooOol0L7oo001HOol0
0`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0NOol00`00Oomoo`05Ool0
0`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`0NOol00`00Oomoo`0<Ool00`00Oomoo`0=Ool0
0`00Oomoo`0<Ool00`00Oomoo`0OOol00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool0
0`00Oomoo`0OOol00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0NOol0
0`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`0NOol00`00Oomoo`0<Ool0
0`00Oomoo`0=Ool00`00Oomoo`0?Ool00`00Oomoo`2IOol20008Ool00`00Oomoo`03Ool00`00Ool0
0004Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomo
o`0eOol00`00Oomoo`0DOol00`00Oomoo`0JOol00`00Oomoo`0OOol00`00Oomoo`0`Ool00`00Oomo
o`0XOol00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00moo`03
001oogoo00eoo`03001oogoo00eoo`03001oogoo01eoo`03001oogoo00Eoo`03001oogoo00Ioo`03
001oogoo00Ioo`03001oogoo01aoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00eoo`03
001oogoo01eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo01eoo`03
001oogoo00eoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo01aoo`03001oogoo00Ioo`03
001oogoo00Ioo`03001oogoo00Eoo`03001oogoo01eoo`03001oogoo00eoo`03001oogoo00eoo`03
001oogoo00moo`03001oogoo095oo`8000Eoo`<000Qoo`03001oogoo00=oo`03001oo`0000Aoo`03
001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Yoo`03001oogoo00aoo`03001oogoo03Eoo`03
001oogoo01Aoo`03001oogoo01Yoo`03001oogoo01moo`03001oogoo031oo`03001oogoo02Qoo`03
001oogoo019oo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<007ooOol03goo00<007ooOol0
3Goo00<007ooOol03Woo0P006Woo0`0027oo00<007ooOol01Woo00<007ooOol01Woo0P006goo0P00
47oo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol06Woo0P0027oo00<007ooOol01Woo00<0
07ooOol01Woo0P0077oo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol03Woo0P006goo0P00
27oo00<007ooOol01Woo00<007ooOol01Woo0`006Woo0P0047oo00<007ooOol03Goo00<007ooOol0
3goo00<007ooOol0TGoo2@002Goo00<007ooOol00goo00<007oo000017oo00<007ooOol01Woo00<0
07ooOol027oo00<007ooOol02Woo00<007ooOol03Goo00<007ooOol0<goo00<007ooOol05Goo00<0
07ooOol06Woo00<007ooOol07goo00<007ooOol0<7oo00<007ooOol0:7oo00<007ooOol04Woo00<0
07ooOol017oo00<007ooOol0L7oo001HOol3000?Ool00`00Oomoo`0=Ool00`00Oomoo`0@Ool00`00
Oomoo`0FOol00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0GOol00`00
Oomoo`0@Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool2000HOol2000:Ool00`00Oomoo`06Ool00`00
Oomoo`08Ool2000HOol2000AOol00`00Oomoo`0=Ool00`00Oomoo`0@Ool00`00Oomoo`0GOol00`00
Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0FOol00`00Oomoo`0@Ool00`00
Oomoo`0=Ool00`00Oomoo`0=Ool3002COol200000goo00000003000:Ool00`00Oomoo`03Ool00`00
Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00
Oomoo`0bOol00`00Oomoo`0EOol00`00Oomoo`0LOol00`00Oomoo`0OOol00`00Oomoo`0`Ool00`00
Oomoo`0WOol00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo015oo`8001Eoo`03001oogoo00Yoo`03001oogoo00Ioo`03001o
ogoo00Uoo`03001oogoo01Aoo`8001=oo`03001oogoo00eoo`03001oogoo015oo`03001oogoo01=o
o`8000aoo`03001oogoo00Ioo`03001oogoo00Yoo`8001Eoo`03001oogoo015oo`03001oogoo00eo
o`03001oogoo015oo`8001Ioo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Yoo`03001o
ogoo01=oo`8001=oo`03001oogoo00eoo`03001oogoo00moo`03001oogoo095oo`80011oo`03001o
ogoo00=oo`03001oo`0000Aoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00]oo`03001o
ogoo00eoo`03001oogoo035oo`03001oogoo01Eoo`03001oogoo01aoo`03001oogoo01moo`03001o
ogoo031oo`03001oogoo02Moo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo071oo`00F7oo
00<007ooOol03Woo00<007ooOol03goo00<007ooOol04Woo0P004Goo0P003Goo00<007ooOol01goo
00<007ooOol02Goo0`004Goo0P0057oo00<007ooOol03goo00<007ooOol04Goo00<007ooOol04Goo
00<007ooOol02goo00<007ooOol027oo00<007ooOol02goo00<007ooOol04Goo00<007ooOol04Goo
00<007ooOol03goo00<007ooOol04Woo0P004Goo0`002goo00<007ooOol01goo00<007ooOol02goo
0P004Goo0P0057oo00<007ooOol03goo00<007ooOol03Woo00<007ooOol0TGoo0P0047oo00<007oo
Ool00goo00<007oo000017oo00<007ooOol01goo00<007ooOol01goo00<007ooOol02goo00<007oo
Ool03Goo00<007ooOol0<7oo00<007ooOol05Woo00<007ooOol077oo00<007ooOol07goo00<007oo
Ool0<7oo00<007ooOol09goo00<007ooOol04Woo00<007ooOol017oo00<007ooOol0L7oo001HOol0
0`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`0DOol00`00Oomoo`0<Ool2000>Ool00`00Oomo
o`08Ool00`00Oomoo`0<Ool2000>Ool00`00Oomoo`0DOol00`00Oomoo`0?Ool00`00Oomoo`0BOol5
000;Ool3000>Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool4000;Ool4000DOol00`00Oomoo`0?Ool0
0`00Oomoo`0DOol00`00Oomoo`0<Ool2000>Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool2000>Ool0
0`00Oomoo`0DOol00`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`2AOol2000@Ool00`00Oomo
o`03Ool00`00Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomo
o`0>Ool00`00Oomoo`0_Ool00`00Oomoo`0FOol00`00Oomoo`0LOol00`00Oomoo`0OOol00`00Oomo
o`0`Ool00`00Oomoo`0WOol00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03
001oogoo00ioo`03001oogoo00moo`03001oogoo01Aoo`@000Qoo`<0011oo`03001oogoo00Qoo`03
001oogoo00ioo`<000Qoo`<001Moo`03001oogoo00moo`03001oogoo01Moo`<000Aoo`@0015oo`03
001oogoo00Qoo`03001oogoo011oo`@000=oo`@001Qoo`03001oogoo00moo`03001oogoo01Eoo`<0
00Qoo`<0011oo`03001oogoo00Qoo`03001oogoo00ioo`@000Qoo`<001Ioo`03001oogoo00moo`03
001oogoo00ioo`03001oogoo095oo`X000Qoo`03001oogoo00=oo`03001oo`0000Aoo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00aoo`03001oogoo00ioo`03001oogoo02ioo`03001oogoo
01Ioo`03001oogoo01aoo`03001oogoo01moo`03001oogoo035oo`03001oogoo02Ioo`03001oogoo
019oo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<007ooOol03Goo00<007ooOol04Goo00<0
07ooOol05goo20004Woo00<007ooOol02Woo00<007ooOol047oo20006Goo00<007ooOol04Goo00<0
07ooOol06Goo10005Goo00<007ooOol027oo00<007ooOol057oo0`006goo00<007ooOol04Goo00<0
07ooOol05goo20004Woo00<007ooOol02Woo00<007ooOol04Goo200067oo00<007ooOol04Goo00<0
07ooOol03Goo00<007ooOol0TGoo2P0027oo00<007ooOol00goo00<007oo00001Goo00<007ooOol0
1Woo00<007ooOol027oo00<007ooOol02goo00<007ooOol03goo00<007ooOol0;7oo00<007ooOol0
5goo00<007ooOol077oo00<007ooOol087oo00<007ooOol0<7oo00<007ooOol09goo00<007ooOol0
4Goo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`0=Ool00`00Oomoo`0AOol00`00
Oomoo`0aOol00`00Oomoo`0:Ool00`00Oomoo`0aOol00`00Oomoo`0AOol00`00Oomoo`0aOol00`00
Oomoo`0:Ool00`00Oomoo`0aOol00`00Oomoo`0AOol00`00Oomoo`0aOol00`00Oomoo`0:Ool00`00
Oomoo`0aOol00`00Oomoo`0AOol00`00Oomoo`0=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00
Ool00005Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomoo`0?Ool00`00
Oomoo`0[Ool00`00Oomoo`0GOol00`00Oomoo`0MOol00`00Oomoo`0POol00`00Oomoo`0`Ool00`00
Oomoo`0WOol00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00eo
o`03001oogoo019oo`03001oogoo031oo`03001oogoo00Yoo`03001oogoo035oo`03001oogoo015o
o`03001oogoo035oo`03001oogoo00Yoo`03001oogoo035oo`03001oogoo015oo`03001oogoo035o
o`03001oogoo00Yoo`03001oogoo031oo`03001oogoo019oo`03001oogoo00eoo`03001oogoo0:=o
o`03001oogoo00=oo`03001oo`0000Eoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00ao
o`03001oogoo00moo`8002Uoo`8001Yoo`03001oogoo01eoo`03001oogoo021oo`03001oogoo031o
o`03001oogoo02Moo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<007oo
Ool037oo00<007ooOol04goo00<007ooOol0;goo00<007ooOol037oo00<007ooOol0;goo00<007oo
Ool04goo00<007ooOol0;goo00<007ooOol037oo00<007ooOol0;goo00<007ooOol04goo00<007oo
Ool0;goo00<007ooOol037oo00<007ooOol0;goo00<007ooOol04goo00<007ooOol037oo00<007oo
Ool0Xgoo00<007ooOol00goo00<007oo00001Goo00<007ooOol01Woo00<007ooOol02Goo00<007oo
Ool02goo00<007ooOol04Goo00<007ooOol09Goo00<007ooOol06Woo00<007ooOol07Goo00<007oo
Ool087oo00<007ooOol0<7oo00<007ooOol09goo00<007ooOol04Goo00<007ooOol017oo00<007oo
Ool0L7oo001HOol00`00Oomoo`0<Ool00`00Oomoo`0COol00`00Oomoo`0_Ool00`00Oomoo`0<Ool0
0`00Oomoo`0_Ool00`00Oomoo`0COol00`00Oomoo`0_Ool00`00Oomoo`0<Ool00`00Oomoo`0_Ool0
0`00Oomoo`0COol00`00Oomoo`0_Ool00`00Oomoo`0<Ool00`00Oomoo`0_Ool00`00Oomoo`0COol0
0`00Oomoo`0<Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`06Ool0
0`00Oomoo`09Ool00`00Oomoo`0<Ool00`00Oomoo`0AOol00`00Oomoo`0SOol00`00Oomoo`0JOol0
0`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0`Ool00`00Oomoo`0WOol00`00Oomoo`0AOol0
0`00Oomoo`04Ool00`00Oomoo`1`Ool003Ioo`L000Yoo`@000eoo`03001oogoo00]oo`03001oogoo
01Eoo`03001oogoo02eoo`03001oogoo00eoo`03001oogoo02ioo`03001oogoo01Eoo`03001oogoo
02eoo`03001oogoo00ioo`03001oogoo02eoo`03001oogoo01Eoo`03001oogoo02ioo`03001oogoo
00eoo`03001oogoo02eoo`03001oogoo01Eoo`03001oogoo00]oo`03001oogoo0:=oo`8000Aoo`04
001oogoo0004Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`0BOol0
0`00Oomoo`0POol2000MOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0aOol00`00Oomo
o`0VOol00`00Oomoo`0BOol00`00Oomoo`02Ool2001bOol003Ioo`L000Qoo`P000]oo`03001oogoo
00Yoo`03001oogoo01Ioo`03001oogoo02eoo`03001oogoo00ioo`03001oogoo02eoo`03001oogoo
01Eoo`03001oogoo02eoo`03001oogoo00ioo`03001oogoo02eoo`03001oogoo01Eoo`03001oogoo
02eoo`03001oogoo00ioo`03001oogoo02eoo`03001oogoo01Ioo`03001oogoo00Yoo`03001oogoo
0:=oo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomo
o`0=Ool00`00Oomoo`0BOol4000MOol00`00Oomoo`0LOol00`00Oomoo`0OOol00`00Oomoo`0QOol0
0`00Oomoo`0`Ool00`00Oomoo`0VOol00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`1`Ool0
03Uoo`8000Yoo`8000Aoo`8000]oo`03001oogoo00Yoo`03001oogoo01Moo`03001oogoo02]oo`03
001oogoo00moo`8002eoo`03001oogoo01Moo`03001oogoo02]oo`03001oogoo011oo`03001oogoo
02]oo`03001oogoo01Moo`03001oogoo02]oo`80015oo`03001oogoo02]oo`03001oogoo01Moo`03
001oogoo00Yoo`03001oogoo0:=oo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`0=Ool00`00Oomoo`0FOol2000IOol2000OOol00`00Oomoo`0OOol0
0`00Oomoo`0QOol00`00Oomoo`0`Ool00`00Oomoo`0VOol00`00Oomoo`0BOol00`00Oomoo`03Ool0
0`00Oomoo`1`Ool003Uoo`8000Uoo`8000Ioo`8000Yoo`03001oogoo00Yoo`03001oogoo01Moo`03
001oogoo02]oo`03001oogoo011oo`03001oogoo02]oo`03001oogoo01Moo`03001oogoo02]oo`03
001oogoo011oo`03001oogoo02]oo`03001oogoo01Moo`03001oogoo02]oo`03001oogoo011oo`03
001oogoo02]oo`03001oogoo01Moo`03001oogoo00Yoo`03001oogoo0:=oo`03001oogoo00=oo`04
001oogoo0004Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`0=Ool00`00Oomoo`0GOol0
0`00Oomoo`0COol3000QOol00`00Oomoo`0OOol00`00Oomoo`0QOol00`00Oomoo`0`Ool00`00Oomo
o`0VOol00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`1`Ool003Uoo`8000Uoo`8000Ioo`80
00Yoo`03001oogoo00Uoo`03001oogoo01Uoo`03001oogoo02Uoo`03001oogoo019oo`03001oogoo
02Uoo`03001oogoo01Uoo`03001oogoo02Uoo`03001oogoo019oo`03001oogoo02Uoo`03001oogoo
01Uoo`03001oogoo02Uoo`03001oogoo019oo`03001oogoo02Uoo`03001oogoo01Uoo`03001oogoo
00Uoo`03001oogoo0:=oo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`0>Ool00`00Oomoo`0GOol3000?Ool3000TOol00`00Oomoo`0NOol00`00Oomo
o`0ROol00`00Oomoo`0aOol00`00Oomoo`0VOol00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomo
o`1`Ool001ioo`d000Ioo``000Ioo`8000Qoo`8000Uoo`03001oogoo00Qoo`03001oogoo01Yoo`03
001oogoo02Qoo`03001oogoo01Aoo`03001oogoo02Moo`03001oogoo01]oo`03001oogoo02Moo`03
001oogoo01Aoo`03001oogoo02Moo`03001oogoo01]oo`03001oogoo02Moo`03001oogoo01Aoo`03
001oogoo02Qoo`03001oogoo01Yoo`03001oogoo00Qoo`03001oogoo0:=oo`03001oogoo00=oo`04
001oogoo0004Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`0IOol6
0002Ool7000VOol00`00Oomoo`0OOol00`00Oomoo`0ROol00`00Oomoo`0aOol00`00Oomoo`0VOol0
0`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`1`Ool001ioo`d000Ioo``000Ioo`8000Qoo`80
00Uoo`03001oogoo00Moo`03001oogoo01aoo`03001oogoo02Moo`03001oogoo01Aoo`03001oogoo
02Ioo`03001oogoo01aoo`03001oogoo02Moo`03001oogoo01Aoo`03001oogoo02Moo`03001oogoo
01]oo`03001oogoo02Moo`03001oogoo01Aoo`03001oogoo02Moo`03001oogoo01aoo`03001oogoo
00Moo`03001oogoo0:=oo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`08Ool00`00Oomo
o`09Ool00`00Oomoo`0>Ool00`00Oomoo`0OOol2000/Ool00`00Oomoo`0POol00`00Oomoo`0ROol0
0`00Oomoo`0aOol00`00Oomoo`0VOol00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`1`Ool0
01ioo`d000Ioo`8000Ioo`800003Ool007oo00Eoo`8000Qoo`8000Uoo`@000Eoo`03001oogoo01io
o`8002Ioo`03001oogoo01Ioo`03001oogoo02Aoo`03001oogoo01ioo`8002Ioo`03001oogoo01Io
o`03001oogoo02Aoo`8001moo`03001oogoo02Eoo`03001oogoo01Ioo`03001oogoo02Aoo`80021o
o`03001oogoo00=oo`@00:Eoo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`08Ool00`00
Oomoo`09Ool00`00Oomoo`0?Ool00`00Oomoo`1<Ool00`00Oomoo`0POol00`00Oomoo`0ROol00`00
Oomoo`0aOol00`00Oomoo`0VOol00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`1`Ool0039o
o`8000Eoo`8000Qoo`8000Qoo`8000Uoo`03001oogoo00Ioo`03001oogoo021oo`03001oogoo025o
o`8001Yoo`03001oogoo02=oo`03001oogoo021oo`03001oogoo029oo`03001oogoo01Qoo`03001o
ogoo029oo`03001oogoo021oo`03001oogoo029oo`8001Yoo`8002=oo`03001oogoo021oo`03001o
ogoo00Ioo`03001oogoo0:=oo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`08Ool00`00
Oomoo`0:Ool00`00Oomoo`0?Ool00`00Oomoo`1:Ool00`00Oomoo`0QOol00`00Oomoo`0ROol00`00
Oomoo`0aOol00`00Oomoo`0VOol00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`1`Ool0039o
o`<000Aoo`8000Qoo`8000Qoo`8000Uoo`03001oogoo02Yoo`03001oogoo01moo`03001oogoo01]o
o`03001oogoo025oo`03001oogoo029oo`03001oogoo021oo`03001oogoo01Yoo`03001oogoo021o
o`03001oogoo029oo`03001oogoo021oo`03001oogoo01aoo`03001oogoo01moo`03001oogoo02Yo
o`03001oogoo0:=oo`03001oogoo00=oo`04001oogoo0005Ool00`00Oomoo`07Ool00`00Oomoo`0:
Ool00`00Oomoo`0@Ool00`00Oomoo`19Ool00`00Oomoo`0POol00`00Oomoo`0SOol00`00Oomoo`0b
Ool00`00Oomoo`0UOol00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`1`Ool003=oo`8000Ao
o`8000Qoo`8000Qoo`8000Uoo`03001oogoo02]oo`03001oogoo01eoo`03001oogoo01eoo`03001o
ogoo01ioo`8002Ioo`03001oogoo01eoo`8001ioo`03001oogoo01ioo`03001oogoo02Aoo`8001mo
o`03001oogoo01ioo`03001oogoo01eoo`03001oogoo02]oo`03001oogoo0:=oo`03001oogoo00=o
o`04001oogoo0005Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`0@Ool00`00Oomoo`18
Ool00`00Oomoo`0QOol00`00Oomoo`0SOol00`00Oomoo`0bOol00`00Oomoo`0UOol00`00Oomoo`0A
Ool00`00Oomoo`03Ool00`00Oomoo`1`Ool003Aoo`8000=oo`8000Qoo`8000Qoo`8000Uoo`03001o
ogoo02aoo`03001oogoo01]oo`03001oogoo01moo`03001oogoo01]oo`8002Uoo`8001aoo`03001o
ogoo01moo`8001aoo`8002Uoo`8001aoo`03001oogoo021oo`03001oogoo01]oo`03001oogoo02ao
o`03001oogoo0:=oo`03001oogoo00=oo`04001oogoo0005Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`0AOol00`00Oomoo`15Ool2000TOol00`00Oomoo`0SOol00`00Oomoo`0bOol00`00
Oomoo`0UOol00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`1`Ool003Aoo`<0009oo`8000Qo
o`8000Qoo`8000Uoo`03001oogoo02eoo`03001oogoo01Qoo`8002=oo`8001Yoo`03001oogoo02Uo
o`04001oo`00000IOol00`00Oomoo`0ROol00`00Oomoo`0GOol3000/Ool00`00Oomoo`0HOol2000S
Ool2000JOol00`00Oomoo`0]Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01000Oomoo`001Goo00<0
07ooOol027oo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol0@goo00<007ooOol097oo00<0
07ooOol08goo00<007ooOol0<Woo00<007ooOol09Goo00<007ooOol04Goo00<007ooOol00goo00<0
07ooOol0L7oo000eOol20002Ool20009Ool20006Ool2000:Ool00`00Oomoo`0^Ool2000GOol00`00
Oomoo`0UOol3000EOol2000`Ool00`00Oomoo`0EOol00`00Oomoo`0TOol00`00Oomoo`0EOol00`00
Oomoo`0^Ool2000EOol3000WOol00`00Oomoo`0EOol2000`Ool00`00Oomoo`2SOol00`00Oomoo`03
Ool01000Oomoo`001Goo00<007ooOol027oo00<007ooOol02Woo00<007ooOol04Woo00<007ooOol0
@Woo00<007ooOol08goo00<007ooOol097oo00<007ooOol0<Woo00<007ooOol09Goo00<007ooOol0
4Goo00<007ooOol00goo00<007ooOol0L7oo000fOol200000goo00000009Ool20006Ool2000:Ool0
0`00Oomoo`0`Ool3000COol00`00Oomoo`0YOol2000AOol2000cOol2000BOol3000XOol3000BOol2
000cOol2000AOol2000[Ool00`00Oomoo`0AOol3000bOol00`00Oomoo`2SOol00`00Oomoo`03Ool0
1000Oomoo`001Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol04Woo00<007ooOol0@7oo
00<007ooOol097oo00<007ooOol097oo00<007ooOol0<Woo00<007ooOol09Goo00<007ooOol04Goo
00<007ooOol00goo00<007ooOol0L7oo000gOol4000:Ool20004Ool2000;Ool00`00Oomoo`0cOol3
000=Ool3000^Ool2000<Ool3000gOol2000=Ool3000^Ool4000<Ool2000gOol3000<Ool2000^Ool4
000<Ool3000eOol00`00Oomoo`2SOol00`00Oomoo`03Ool01000Oomoo`001Goo00<007ooOol02Goo
00<007ooOol02Woo00<007ooOol04goo00<007ooOol0?Woo00<007ooOol09Goo00<007ooOol097oo
00<007ooOol0<Woo00<007ooOol09Goo00<007ooOol04Goo00<007ooOol00goo00<007ooOol0L7oo
000gOol4000:Ool8000;Ool00`00Oomoo`0fOol=000cOol<000lOol=000eOol<000lOol<000dOol<
000hOol00`00Oomoo`2SOol20004Ool01000Oomoo`001Goo00<007ooOol02Goo00<007ooOol02goo
00<007ooOol04goo00<007ooOol0?7oo00<007ooOol09Woo00<007ooOol097oo00<007ooOol0<Woo
00<007ooOol09Goo00<007ooOol04Goo00<007ooOol00Woo0P00LWoo000hOol3000<Ool4000=Ool0
0`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01000Oomoo`001Goo00<007ooOol0
2Goo00<007ooOol02goo00<007ooOol057oo00<007ooOol0>Woo00<007ooOol09goo00<007ooOol0
97oo00<007ooOol0<Woo00<007ooOol09Goo00<007ooOol04Goo00<007ooOol00goo00<007ooOol0
L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01000Oomoo`001Goo
00<007ooOol02Goo00<007ooOol037oo00<007ooOol057oo00<007ooOol0>7oo00<007ooOol09goo
00<007ooOol09Goo00<007ooOol0<Woo00<007ooOol09Goo00<007ooOol04Goo00<007ooOol00goo
00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01000
Oomoo`001Woo00<007ooOol02Goo00<007ooOol02goo00<007ooOol05Goo0`00=Goo0P00:Woo00<0
07ooOol09Goo00<007ooOol0<goo00<007ooOol09Goo00<007ooOol047oo00<007ooOol00goo00<0
07ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01000Oomo
o`001Woo00<007ooOol02Goo00<007ooOol037oo00<007ooOol05goo00<007ooOol0<Goo00<007oo
Ool0:Goo00<007ooOol09Woo00<007ooOol0<goo00<007ooOol09Goo00<007ooOol047oo00<007oo
Ool00goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03
Ool01000Oomoo`001Woo00<007ooOol02Goo00<007ooOol037oo00<007ooOol05goo0P00<7oo0P00
;7oo00<007ooOol09Woo00<007ooOol0<goo00<007ooOol09Goo00<007ooOol047oo00<007ooOol0
0goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool0
1000Oomoo`001Woo00<007ooOol02Goo00<007ooOol03Goo00<007ooOol067oo00<007ooOol0;7oo
00<007ooOol0:goo00<007ooOol09goo00<007ooOol0<goo00<007ooOol09Goo00<007ooOol047oo
00<007ooOol00goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00
Oomoo`03Ool01000Oomoo`001Woo00<007ooOol02Goo00<007ooOol03Goo00<007ooOol06Goo0`00
:Goo0P00;Woo00<007ooOol09Woo00<007ooOol0=7oo00<007ooOol09Goo00<007ooOol047oo00<0
07ooOol00goo00<007ooOol0L7oo001HOol3003oOoo;Ool3002UOol00`00Oomoo`03Ool01000Oomo
o`001Woo00<007ooOol02Woo00<007ooOol03Goo00<007ooOol06goo0`008goo0`00;goo00<007oo
Ool09goo00<007ooOol0=7oo00<007ooOol09Goo00<007ooOol047oo00<007ooOol00goo00<007oo
Ool0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01000Oomoo`00
1Woo00<007ooOol02Woo00<007ooOol03Woo00<007ooOol07Goo10007Goo0P00<Woo00<007ooOol0
9goo00<007ooOol0=7oo00<007ooOol09Goo00<007ooOol047oo00<007ooOol00goo00<007ooOol0
L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01000Oomoo`001Woo
00<007ooOol02Woo00<007ooOol03Woo00<007ooOol08Goo0`0067oo0P00=7oo00<007ooOol09goo
00<007ooOol0=7oo00<007ooOol09Goo00<007ooOol047oo00<007ooOol00goo00<007ooOol0L7oo
001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01000Oomoo`001Woo00<0
07ooOol02goo00<007ooOol03Woo00<007ooOol08goo0`003goo1P00=Goo00<007ooOol0:7oo00<0
07ooOol0=7oo00<007ooOol09Goo00<007ooOol047oo00<007ooOol00goo00<007ooOol0L7oo001H
Ool00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01000Oomoo`001goo00<007oo
Ool02Woo00<007ooOol03Woo00<007ooOol09Woo3`00>goo00<007ooOol09goo00<007ooOol0=Goo
00<007ooOol09Goo00<007ooOol047oo00<007ooOol00goo00<007ooOol0L7oo001HOol00`00Oomo
o`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01000Oomoo`001goo00<007ooOol02Woo00<0
07ooOol03goo00<007ooOol0KWoo00<007ooOol0:7oo00<007ooOol0=Goo00<007ooOol09Goo00<0
07ooOol047oo00<007ooOol00goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomo
o`2SOol00`00Oomoo`03Ool01000Oomoo`001goo00<007ooOol02goo00<007ooOol03goo00<007oo
Ool0K7oo00<007ooOol0:Goo00<007ooOol0=Goo00<007ooOol09Goo00<007ooOol047oo00<007oo
Ool00goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03
Ool01000Oomoo`001goo00<007ooOol02goo00<007ooOol03goo00<007ooOol0K7oo00<007ooOol0
:Goo00<007ooOol0=Goo00<007ooOol09Goo00<007ooOol047oo00<007ooOol00goo00<007ooOol0
L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol20004Ool01000Oomoo`001goo00<007oo
Ool02goo00<007ooOol047oo00<007ooOol0JWoo00<007ooOol0:Woo00<007ooOol0=Goo00<007oo
Ool09Goo00<007ooOol047oo00<007ooOol00Woo0P00LWoo001HOol00`00Oomoo`3oOoo=Ool00`00
Oomoo`2SOol00`00Oomoo`03Ool01@00Oomoogoo00001goo00<007ooOol02goo00<007ooOol03goo
00<007ooOol0JWoo00<007ooOol0:Goo00<007ooOol0=Woo00<007ooOol09Goo00<007ooOol047oo
00<007ooOol00goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00
Oomoo`03Ool01@00Oomoogoo00001goo00<007ooOol02goo00<007ooOol047oo00<007ooOol0J7oo
00<007ooOol0:Woo00<007ooOol0=Woo00<007ooOol09Goo00<007ooOol047oo00<007ooOol00goo
00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01@00
Oomoogoo00001goo00<007ooOol037oo00<007ooOol047oo0P00Igoo00<007ooOol0:goo00<007oo
Ool0=Woo00<007ooOol09Goo00<007ooOol047oo00<007ooOol00goo00<007ooOol0L7oo001HOol0
0`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01@00Oomoogoo00001goo00<007oo
Ool037oo00<007ooOol04Woo00<007ooOol0I7oo00<007ooOol0:goo00<007ooOol0=Woo00<007oo
Ool09Goo00<007ooOol047oo00<007ooOol00goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=
Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01@00Oomoogoo00001goo00<007ooOol03Goo00<007oo
Ool04Woo00<007ooOol0HWoo00<007ooOol0:goo00<007ooOol0=goo00<007ooOol09Goo00<007oo
Ool047oo00<007ooOol00goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2S
Ool00`00Oomoo`03Ool01@00Oomoogoo00001goo00<007ooOol03Goo00<007ooOol04goo00<007oo
Ool0Ggoo0P00;Woo00<007ooOol0=Woo00<007ooOol09Woo00<007ooOol047oo00<007ooOol00goo
00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01@00
Oomoogoo00001goo00<007ooOol03Woo00<007ooOol04goo00<007ooOol0GGoo00<007ooOol0;Woo
00<007ooOol0=Woo00<007ooOol09Woo00<007ooOol047oo00<007ooOol00goo00<007ooOol0L7oo
001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01@00Oomoogoo00001goo
00<007ooOol03Woo00<007ooOol057oo00<007ooOol0G7oo00<007ooOol0;Woo00<007ooOol0=Woo
00<007ooOol09Woo00<007ooOol047oo00<007ooOol00goo00<007ooOol0L7oo001HOol3003oOoo;
Ool3002UOol00`00Oomoo`03Ool01@00Oomoogoo000027oo00<007ooOol03Woo00<007ooOol057oo
00<007ooOol0FWoo00<007ooOol0;Woo00<007ooOol0=goo00<007ooOol09Woo00<007ooOol047oo
00<007ooOol00goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00
Oomoo`03Ool01@00Oomoogoo000027oo00<007ooOol03Woo00<007ooOol05Goo00<007ooOol0F7oo
00<007ooOol0;goo00<007ooOol0=goo00<007ooOol09Woo00<007ooOol047oo00<007ooOol00goo
00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01@00
Oomoogoo000027oo00<007ooOol03Woo00<007ooOol05Woo00<007ooOol0EWoo00<007ooOol0<7oo
00<007ooOol0=goo00<007ooOol09Woo00<007ooOol047oo00<007ooOol00goo00<007ooOol0L7oo
001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01@00Oomoogoo000027oo
00<007ooOol03goo00<007ooOol05Woo00<007ooOol0Dgoo0P00<Woo00<007ooOol0>7oo00<007oo
Ool09Woo00<007ooOol047oo00<007ooOol00goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=
Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01@00Oomoogoo000027oo00<007ooOol047oo00<007oo
Ool05Woo0P00DWoo00<007ooOol0<Woo00<007ooOol0>7oo00<007ooOol09Woo00<007ooOol047oo
00<007ooOol00goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00
Oomoo`03Ool01@00Oomoogoo000027oo00<007ooOol047oo00<007ooOol067oo00<007ooOol0CWoo
00<007ooOol0<Woo00<007ooOol0>Goo00<007ooOol09Woo00<007ooOol047oo00<007ooOol00goo
00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol20004Ool01@00Oomoogoo
00002Goo00<007ooOol03goo00<007ooOol06Goo00<007ooOol0C7oo00<007ooOol0<goo00<007oo
Ool0>Goo00<007ooOol09Woo00<007ooOol047oo00<007ooOol00Woo0P00LWoo001HOol00`00Oomo
o`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01@00Oomoogoo00002Goo00<007ooOol047oo
00<007ooOol06Goo00<007ooOol0BWoo00<007ooOol0=7oo00<007ooOol0>Goo00<007ooOol09Woo
00<007ooOol047oo00<007ooOol00goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00
Oomoo`2SOol00`00Oomoo`03Ool01@00Oomoogoo00002Goo00<007ooOol047oo00<007ooOol06Woo
00<007ooOol0AWoo0`00=Woo00<007ooOol0>Woo00<007ooOol09Woo00<007ooOol047oo00<007oo
Ool00goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03
Ool01@00Oomoogoo00002Goo00<007ooOol04Goo00<007ooOol06Woo0P00AGoo00<007ooOol0=goo
00<007ooOol0>Woo00<007ooOol09Woo00<007ooOol047oo00<007ooOol00goo00<007ooOol0L7oo
001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool01@00Oomoogoo00002Goo
00<007ooOol04Woo00<007ooOol06goo00<007ooOol0@7oo0P00>Goo00<007ooOol0>goo00<007oo
Ool09Woo00<007ooOol047oo00<007ooOol00goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=
Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0A
Ool00`00Oomoo`0LOol3000nOol00`00Oomoo`0iOol00`00Oomoo`0jOol00`00Oomoo`0VOol00`00
Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`1`Ool005Qoo`03001oogoo0?mooleoo`03001oogoo
0:=oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Moo`03001oogoo019oo`03001oogoo
01ioo`8003]oo`03001oogoo03Yoo`03001oogoo03Yoo`03001oogoo02Ioo`03001oogoo015oo`03
001oogoo00=oo`03001oogoo071oo`00F7oo00<007ooOol0ogoocGoo00<007ooOol0Xgoo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol04Woo00<007ooOol07goo0`00=goo
0P00?7oo00<007ooOol0>goo00<007ooOol09Woo00<007ooOol04Goo00<007ooOol00goo00<007oo
Ool0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`07Ool00`00Oomoo`0BOol00`00Oomoo`0ROol3000aOol3000nOol00`00Oomoo`0k
Ool00`00Oomoo`0VOol00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`1`Ool005Qoo`03001o
ogoo0?mooleoo`03001oogoo07moo`X000]oo`@000]oo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo00Qoo`03001oogoo019oo`03001oogoo02Aoo`<002]oo`<0041oo`03001oogoo03aoo`03
001oogoo02Ioo`03001oogoo015oo`03001oogoo00=oo`03001oogoo071oo`00F7oo00<007ooOol0
ogoocGoo00<007ooOol0Ogoo2P002Goo20002Goo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool027oo00<007ooOol04goo00<007ooOol09Woo0`009Goo0`00@Woo00<007ooOol0?7oo00<007oo
Ool09goo00<007ooOol04Goo00<007ooOol00goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=
Ool00`00Oomoo`23Ool2000=Ool20004Ool20009Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`08Ool00`00Oomoo`0DOol00`00Oomoo`0XOol3000OOol30014Ool00`00Oomoo`0mOol00`00
Oomoo`0WOol00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`1`Ool005Qoo`<00?mool]oo`<0
08Eoo`8000aoo`8000Ioo`8000Qoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Qoo`03
001oogoo01Aoo`03001oogoo02]oo`<001Uoo`<004Moo`03001oogoo03eoo`03001oogoo02Moo`03
001oogoo015oo`03001oogoo00=oo`03001oogoo071oo`00F7oo00<007ooOol0ogoocGoo00<007oo
Ool0Pgoo0P0037oo0P001Woo0P0027oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol027oo
00<007ooOol05Goo00<007ooOol0;Goo1`002goo1`00BWoo00<007ooOol0?Goo00<007ooOol09goo
00<007ooOol04Goo00<007ooOol00goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00
Oomoo`23Ool2000;Ool20008Ool20007Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`09
Ool00`00Oomoo`0EOol00`00Oomoo`0cOol;001@Ool00`00Oomoo`0mOol00`00Oomoo`0XOol00`00
Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`1`Ool005Qoo`03001oogoo0?mooleoo`03001oogoo
08=oo`8000]oo`8000Qoo`8000Moo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Uoo`03
001oogoo01Eoo`03001oogoo08eoo`03001oogoo03ioo`03001oogoo02Qoo`03001oogoo015oo`03
001oogoo00=oo`03001oogoo071oo`00F7oo00<007ooOol0ogoocGoo00<007ooOol0Pgoo0P002goo
0P0027oo0P001goo0`000goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol05Woo00<007oo
Ool0Rgoo00<007ooOol0?goo00<007ooOol0:7oo00<007ooOol04Goo00@007ooOomoo`<0079oo`00
F7oo00<007ooOol0ogoocGoo00<007ooOol0Pgoo0P002goo0P0027oo0P001goo00<007ooOol00goo
00<007ooOol00Woo00<007ooOol02Goo00<007ooOol05Woo00<007ooOol0RWoo00<007ooOol0@7oo
00<007ooOol0:7oo00<007ooOol04Goo00<007ooOol00goo00<007ooOol0L7oo001HOol00`00Oomo
o`3oOoo=Ool00`00Oomoo`23Ool2000;Ool20008Ool20007Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`0:Ool00`00Oomoo`0FOol00`00Oomoo`29Ool00`00Oomoo`10Ool00`00Oomoo`0X
Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`1`Ool005Qoo`03001oogoo03Yoo`D003Yo
o`D004=oo`D003ioo`H0049oo`H003Uoo`H003]oo`03001oogoo08=oo`8000]oo`8000Qoo`8000Mo
o`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo01Moo`03001oogoo08Mo
o`03001oogoo045oo`03001oogoo02Qoo`03001oogoo015oo`03001oogoo00=oo`03001oogoo071o
o`00F7oo00<007ooOol0=Goo1@001Goo1@00<7oo1@001Goo1@00>Woo10001Goo2000;Woo20001Woo
0`00>goo10001Woo1000<Goo10001Woo1000=goo00<007ooOol0Pgoo0P002goo0P0027oo0P001goo
00<007ooOol00goo00<007ooOol00goo00<007ooOol02Goo00<007ooOol067oo00<007ooOol0QWoo
00<007ooOol0@Goo00<007ooOol0:7oo00<007ooOol04Goo00<007ooOol00goo00<007ooOol0L7oo
001HOol00`00Oomoo`0bOol3000?Ool3000ZOol3000?Ool3000eOol2000AOol2000ZOol2000AOol2
000eOol4000>Ool3000ZOol4000>Ool3000dOol00`00Oomoo`23Ool2000;Ool20008Ool20007Ool0
0`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`0HOol20025Ool00`00Oomo
o`11Ool00`00Oomoo`0YOol00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`1`Ool0031oo``0
00]oo`@000eoo`03001oogoo02moo`<001Eoo`03001oogoo02Eoo`8001Eoo`80035oo`8001Eoo`03
001oogoo02Ioo`03001oogoo01=oo`<0031oo`8001Eoo`8002Moo`03001oogoo01=oo`<0035oo`03
001oogoo08=oo`8000aoo`8000Ioo`8000Qoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
00Yoo`03001oogoo01Yoo`03001oogoo085oo`03001oogoo049oo`03001oogoo02Uoo`03001oogoo
015oo`03001oogoo00=oo`03001oogoo071oo`00<7oo30002Goo20002goo00<007ooOol0;Goo0P00
6Goo00<007ooOol08goo00<007ooOol05goo0`00:goo0`0067oo0P0097oo0P006Goo0P00:goo0`00
6Goo00<007ooOol08goo00<007ooOol05Woo0`00;goo00<007ooOol0Pgoo0P0037oo0P001Woo0P00
27oo00<007ooOol00goo00<007ooOol00goo00<007ooOol02Woo00<007ooOol06Woo00<007ooOol0
PGoo00<007ooOol0@Woo00<007ooOol0:Goo00<007ooOol04Goo00<007ooOol00goo00<007ooOol0
L7oo000aOol30006Ool20009Ool20004Ool2000;Ool00`00Oomoo`0/Ool00`00Oomoo`0JOol2000Q
Ool2000MOol00`00Oomoo`0WOol00`00Oomoo`0KOol2000POol2000MOol00`00Oomoo`0WOol00`00
Oomoo`0KOol2000QOol2000LOol00`00Oomoo`0/Ool00`00Oomoo`1oOol300000goo0000000=Ool2
0004Ool20009Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`0KOol0
0`00Oomoo`1oOol00`00Oomoo`12Ool00`00Oomoo`0YOol00`00Oomoo`0BOol00`00Oomoo`03Ool0
0`00Oomoo`1`Ool0039oo`<000moo`8000Ioo`8000Yoo`03001oogoo02]oo`03001oogoo01eoo`80
01ioo`03001oogoo01ioo`03001oogoo02Eoo`03001oogoo01ioo`03001oogoo01aoo`03001oogoo
01ioo`03001oogoo02Eoo`03001oogoo01ioo`03001oogoo01aoo`8001moo`03001oogoo02]oo`03
001oogoo07moo`H000eoo`P000Uoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00]oo`03
001oogoo01Yoo`03001oogoo07ioo`03001oogoo04=oo`03001oogoo02Uoo`03001oogoo019oo`03
001oogoo00=oo`03001oogoo071oo`00<goo0`003Woo0P001Woo0P002Woo00<007ooOol0:Woo00<0
07ooOol087oo00<007ooOol06Woo00<007ooOol087oo00<007ooOol08goo00<007ooOol087oo00<0
07ooOol06Woo00<007ooOol087oo00<007ooOol08goo00<007ooOol087oo00<007ooOol06Woo00<0
07ooOol087oo00<007ooOol0:Woo00<007ooOol0PWoo0`003goo10002goo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol02goo00<007ooOol06goo0P00OGoo00<007ooOol0A7oo00<007ooOol0
:Goo00<007ooOol04Woo00<007ooOol00goo00<007ooOol0L7oo000NOol=0009Ool3000<Ool20008
Ool20009Ool00`00Oomoo`0YOol00`00Oomoo`0ROol00`00Oomoo`0HOol00`00Oomoo`0ROol00`00
Oomoo`0QOol00`00Oomoo`0ROol00`00Oomoo`0HOol00`00Oomoo`0ROol00`00Oomoo`0QOol00`00
Oomoo`0ROol00`00Oomoo`0HOol00`00Oomoo`0ROol00`00Oomoo`0YOol00`00Oomoo`2SOol00`00
Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`0MOol00`00Oomoo`1iOol00`00
Oomoo`15Ool00`00Oomoo`0YOol00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`1`Ool001io
o`d000Yoo`<000]oo`8000Qoo`8000Uoo`03001oogoo00Ioo`03001oogoo021oo`03001oogoo029o
o`03001oogoo01Qoo`03001oogoo029oo`03001oogoo025oo`03001oogoo029oo`03001oogoo01Qo
o`03001oogoo029oo`03001oogoo025oo`03001oogoo029oo`03001oogoo01Qoo`03001oogoo029o
o`03001oogoo021oo`03001oogoo00Ioo`03001oogoo0:=oo`03001oogoo00=oo`03001oogoo00=o
o`03001oogoo00aoo`03001oogoo01eoo`03001oogoo07Moo`03001oogoo04Ioo`03001oogoo02Uo
o`03001oogoo019oo`03001oogoo00=oo`03001oogoo071oo`007Woo3@002goo0`002Woo0P0027oo
0P002Goo10001Goo00<007ooOol07goo00<007ooOol097oo00<007ooOol05goo00<007ooOol08goo
00<007ooOol07goo00<007ooOol097oo00<007ooOol05Woo00<007ooOol097oo00<007ooOol07goo
00<007ooOol08goo00<007ooOol05goo00<007ooOol097oo00<007ooOol07goo00<007ooOol00goo
1000YGoo00<007ooOol00goo00<007ooOol00goo00<007ooOol037oo00<007ooOol07Woo00<007oo
Ool0MGoo00<007ooOol0AWoo00<007ooOol0:Woo00<007ooOol04Goo00<007ooOol017oo00<007oo
Ool0L7oo000gOol30009Ool20008Ool20009Ool00`00Oomoo`07Ool00`00Oomoo`0MOol00`00Oomo
o`0VOol00`00Oomoo`0EOol00`00Oomoo`0UOol00`00Oomoo`0MOol00`00Oomoo`0VOol00`00Oomo
o`0DOol00`00Oomoo`0VOol00`00Oomoo`0MOol00`00Oomoo`0UOol00`00Oomoo`0EOol00`00Oomo
o`0VOol00`00Oomoo`0MOol00`00Oomoo`07Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Oomo
o`04Ool00`00Oomoo`0<Ool00`00Oomoo`0NOol00`00Oomoo`1cOol00`00Oomoo`17Ool00`00Oomo
o`0ZOol00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`1`Ool003Qoo`<000Qoo`8000Qoo`80
00Uoo`03001oogoo00Qoo`03001oogoo01]oo`03001oogoo02Moo`03001oogoo01Aoo`03001oogoo
02Moo`03001oogoo01]oo`03001oogoo02Moo`03001oogoo01Aoo`03001oogoo02Moo`03001oogoo
01]oo`03001oogoo02Moo`03001oogoo01Aoo`03001oogoo02Moo`03001oogoo01]oo`03001oogoo
00Qoo`03001oogoo0:=oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo
01moo`03001oogoo075oo`03001oogoo04Qoo`03001oogoo02Yoo`03001oogoo015oo`03001oogoo
00Aoo`03001oogoo071oo`00>Goo0P0027oo0P0027oo0P002Goo00<007ooOol02Goo00<007ooOol0
6Goo00<007ooOol0:Goo00<007ooOol04Woo00<007ooOol0:Goo00<007ooOol06Goo00<007ooOol0
:Goo00<007ooOol04Woo00<007ooOol0:Goo00<007ooOol06Goo00<007ooOol0:Goo00<007ooOol0
4Woo00<007ooOol0:Goo00<007ooOol06Goo00<007ooOol02Goo00<007ooOol0Xgoo0P0017oo00<0
07ooOol017oo00<007ooOol037oo00<007ooOol087oo00<007ooOol0Kgoo00<007ooOol0BGoo00<0
07ooOol0:Woo00<007ooOol04Goo00<007ooOol00goo0P00LWoo000jOol20007Ool20008Ool20009
Ool00`00Oomoo`09Ool00`00Oomoo`0IOol00`00Oomoo`0YOol00`00Oomoo`0AOol00`00Oomoo`0Z
Ool00`00Oomoo`0IOol00`00Oomoo`0YOol00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`0I
Ool00`00Oomoo`0ZOol00`00Oomoo`0AOol00`00Oomoo`0YOol00`00Oomoo`0IOol00`00Oomoo`09
Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`0Q
Ool00`00Oomoo`1]Ool00`00Oomoo`1:Ool00`00Oomoo`0ZOol00`00Oomoo`0AOol00`00Oomoo`04
Ool00`00Oomoo`1`Ool003Yoo`8000Moo`8000Qoo`8000Uoo`03001oogoo00Yoo`03001oogoo01Mo
o`03001oogoo02]oo`03001oogoo00moo`03001oogoo02aoo`03001oogoo01Moo`03001oogoo02]o
o`03001oogoo011oo`03001oogoo02]oo`03001oogoo01Moo`03001oogoo02aoo`03001oogoo00mo
o`03001oogoo02]oo`03001oogoo01Moo`03001oogoo00Yoo`03001oogoo0:=oo`03001oogoo00=o
o`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo025oo`03001oogoo06]oo`03001oogoo04Yo
o`03001oogoo02]oo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo071oo`00<Goo0P001goo
0P0027oo0P001Woo0P002Woo00<007ooOol02Woo00<007ooOol05goo00<007ooOol0;7oo00<007oo
Ool03Woo00<007ooOol0;7oo00<007ooOol05Woo00<007ooOol0;Goo00<007ooOol03Woo00<007oo
Ool0;Goo00<007ooOol05Woo00<007ooOol0;7oo00<007ooOol03Woo00<007ooOol0;7oo00<007oo
Ool05goo00<007ooOol02Woo00<007ooOol0Xgoo00<007ooOol00goo00<007ooOol017oo00<007oo
Ool03Goo00<007ooOol08Woo0P00JGoo0P00CGoo00<007ooOol0:goo00<007ooOol04Goo00<007oo
Ool017oo00<007ooOol0L7oo000aOol30006Ool20008Ool20006Ool2000:Ool00`00Oomoo`0;Ool0
0`00Oomoo`0EOol00`00Oomoo`0^Ool00`00Oomoo`0<Ool00`00Oomoo`0^Ool00`00Oomoo`0EOol0
0`00Oomoo`0^Ool00`00Oomoo`0<Ool00`00Oomoo`0^Ool00`00Oomoo`0EOol00`00Oomoo`0^Ool0
0`00Oomoo`0<Ool00`00Oomoo`0^Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`2SOol0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`0TOol00`00Oomoo`1UOol0
0`00Oomoo`1=Ool00`00Oomoo`0[Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`1`Ool0
035oo`@000Aoo`8000Yoo`8000Aoo`8000]oo`03001oogoo00]oo`03001oogoo01Eoo`03001oogoo
02ioo`03001oogoo00aoo`03001oogoo02ioo`03001oogoo01Eoo`03001oogoo02ioo`03001oogoo
00aoo`03001oogoo02ioo`03001oogoo01Eoo`03001oogoo02ioo`03001oogoo00aoo`03001oogoo
02ioo`03001oogoo01Eoo`03001oogoo00]oo`03001oogoo0:=oo`03001oogoo00=oo`03001oogoo
00Aoo`03001oogoo00ioo`03001oogoo02Aoo`03001oogoo06=oo`03001oogoo04eoo`03001oogoo
02aoo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo071oo`00<Woo20002goo20002goo00<0
07ooOol037oo00<007ooOol04goo00<007ooOol0<7oo00<007ooOol02Woo00<007ooOol0<7oo00<0
07ooOol04goo00<007ooOol0<7oo00<007ooOol02Woo00<007ooOol0<7oo00<007ooOol04goo00<0
07ooOol0<7oo00<007ooOol02Woo00<007ooOol0<7oo00<007ooOol04goo00<007ooOol037oo00<0
07ooOol0Xgoo00<007ooOol00goo00<007ooOol01Goo00<007ooOol03Goo00<007ooOol09Goo00<0
07ooOol0HGoo00<007ooOol0CWoo00<007ooOol0:goo00<007ooOol04Woo00<007ooOol017oo00<0
07ooOol0L7oo000dOol5000>Ool4000=Ool00`00Oomoo`0<Ool00`00Oomoo`0COol00`00Oomoo`0`
Ool00`00Oomoo`0:Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00Oomoo`0`Ool00`00Oomoo`0:
Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00Oomoo`0`Ool00`00Oomoo`0:Ool00`00Oomoo`0`
Ool00`00Oomoo`0COol00`00Oomoo`0<Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Oomoo`05
Ool00`00Oomoo`0=Ool00`00Oomoo`0VOol00`00Oomoo`1OOol00`00Oomoo`1?Ool00`00Oomoo`0[
Ool00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00aoo`03001o
ogoo01=oo`03001oogoo031oo`03001oogoo00Yoo`03001oogoo035oo`03001oogoo019oo`03001o
ogoo031oo`03001oogoo00Yoo`03001oogoo031oo`03001oogoo019oo`03001oogoo035oo`03001o
ogoo00Yoo`03001oogoo031oo`03001oogoo01=oo`03001oogoo00aoo`03001oogoo0:=oo`03001o
ogoo00=oo`03001oogoo00Eoo`03001oogoo00ioo`03001oogoo02Ioo`<005]oo`<0055oo`03001o
ogoo02aoo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<007ooOol03Goo
00<007ooOol04Goo00<007ooOol05Woo2P004Woo00<007ooOol027oo00<007ooOol047oo2P0067oo
00<007ooOol04Goo00<007ooOol067oo2@004Goo00<007ooOol027oo00<007ooOol03goo2@006Woo
00<007ooOol04Goo00<007ooOol05Woo2P004Woo00<007ooOol027oo00<007ooOol04Goo2P005goo
00<007ooOol04Goo00<007ooOol03Goo00<007ooOol0Xgoo00<007ooOol00goo00<007ooOol01Goo
00<007ooOol03Woo00<007ooOol0:Goo00<007ooOol0Egoo00<007ooOol0DWoo00<007ooOol0;7oo
00<007ooOol04Woo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`0=Ool00`00Oomo
o`0AOol00`00Oomoo`0BOol4000:Ool3000?Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool3000:Ool3
000EOol00`00Oomoo`0AOol00`00Oomoo`0DOol40009Ool2000?Ool00`00Oomoo`08Ool00`00Oomo
o`0=Ool20009Ool5000EOol00`00Oomoo`0AOol00`00Oomoo`0COol3000:Ool3000?Ool00`00Oomo
o`08Ool00`00Oomoo`0=Ool4000:Ool3000DOol00`00Oomoo`0AOol00`00Oomoo`0=Ool00`00Oomo
o`2SOol00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`0>Ool00`00Oomoo`0ZOol2001EOol2
001DOol00`00Oomoo`0]Ool00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03
001oogoo00ioo`03001oogoo00moo`03001oogoo019oo`03001oogoo00moo`8000eoo`03001oogoo
00Qoo`03001oogoo00Yoo`<0011oo`<001=oo`03001oogoo00moo`03001oogoo015oo`@000moo`80
00eoo`03001oogoo00Qoo`03001oogoo00]oo`80011oo`<001=oo`03001oogoo00moo`03001oogoo
015oo`<0011oo`<000aoo`03001oogoo00Qoo`03001oogoo00]oo`80015oo`03001oogoo019oo`03
001oogoo00moo`03001oogoo00ioo`03001oogoo0:=oo`03001oogoo00=oo`03001oogoo00Eoo`03
001oogoo00moo`03001oogoo02]oo`03001oogoo055oo`03001oogoo05Aoo`03001oogoo02eoo`03
001oogoo019oo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<007ooOol03Woo00<007ooOol0
3goo00<007ooOol04Goo00<007ooOol04Woo0`002goo00<007ooOol01Woo00<007ooOol02Goo0P00
5Woo00<007ooOol047oo00<007ooOol03goo00<007ooOol047oo00<007ooOol04goo0`002goo00<0
07ooOol01Woo00<007ooOol02Goo0`005Goo00<007ooOol047oo00<007ooOol03goo00<007ooOol0
47oo00<007ooOol057oo0P002goo00<007ooOol01Woo00<007ooOol02Woo0P0057oo00<007ooOol0
4Goo00<007ooOol03goo00<007ooOol03Woo00<007ooOol0Xgoo00<007ooOol00goo00<007ooOol0
1Goo00<007ooOol047oo00<007ooOol0:goo0`00CWoo0P00EWoo00<007ooOol0;Woo00<007ooOol0
4Woo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool3000HOol00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0G
Ool00`00Oomoo`0@Ool00`00Oomoo`0=Ool00`00Oomoo`0@Ool00`00Oomoo`0GOol00`00Oomoo`08
Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0GOol00`00Oomoo`0@Ool00`00Oomoo`0=
Ool00`00Oomoo`0@Ool00`00Oomoo`0GOol00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`08
Ool2000GOol3000AOol00`00Oomoo`0=Ool00`00Oomoo`0?Ool00`00Oomoo`2SOol00`00Oomoo`03
Ool00`00Oomoo`05Ool00`00Oomoo`0@Ool00`00Oomoo`0^Ool2001;Ool00`00Oomoo`1FOol00`00
Oomoo`0^Ool00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`<000moo`03001o
ogoo00eoo`03001oogoo00ioo`03001oogoo01Yoo`03001oogoo00Moo`03001oogoo00Ioo`03001o
ogoo00Qoo`03001oogoo01Qoo`03001oogoo00moo`03001oogoo00eoo`03001oogoo00moo`03001o
ogoo01Qoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo01Qoo`03001o
ogoo00moo`03001oogoo00eoo`03001oogoo00moo`03001oogoo01Qoo`03001oogoo00Qoo`03001o
ogoo00Ioo`03001oogoo00Moo`03001oogoo01Yoo`03001oogoo00ioo`03001oogoo00eoo`03001o
ogoo00eoo`<00:Eoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo015oo`03001oogoo02mo
o`03001oogoo04Ioo`8005Uoo`03001oogoo02ioo`03001oogoo019oo`03001oogoo00Aoo`03001o
ogoo071oo`00F7oo00<007ooOol03goo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol077oo
00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol06Woo00<007ooOol03Woo
00<007ooOol03Goo00<007ooOol03Woo00<007ooOol06Woo00<007ooOol01goo00<007ooOol01Woo
00<007ooOol01goo00<007ooOol06Woo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol03Woo
00<007ooOol06Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol077oo
00<007ooOol03Goo00<007ooOol03Goo00<007ooOol03goo00<007ooOol0Xgoo0P0017oo00<007oo
Ool01Woo00<007ooOol047oo00<007ooOol0<7oo0`00@Woo0`00FWoo00<007ooOol0;Woo00<007oo
Ool04goo00<007ooOol00goo0P00LWoo001HOol00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomo
o`0=Ool00`00Oomoo`0MOol00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomo
o`0LOol00`00Oomoo`0>Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0LOol00`00Oomo
o`07Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`0LOol00`00Oomoo`0=Ool00`00Oomo
o`0<Ool00`00Oomoo`0>Ool00`00Oomoo`0LOol00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomo
o`07Ool00`00Oomoo`0MOol00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomo
o`2SOol00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`0@Ool00`00Oomoo`0cOol2000oOol0
0`00Oomoo`1KOol00`00Oomoo`0^Ool00`00Oomoo`0COol00`00Oomoo`04Ool00`00Oomoo`1`Ool0
05Qoo`03001oogoo011oo`03001oogoo00]oo`03001oogoo00eoo`03001oogoo01ioo`03001oogoo
00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo01ioo`03001oogoo00eoo`03001oogoo
00aoo`03001oogoo00aoo`03001oogoo01ioo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo
00Ioo`03001oogoo01ioo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo
01ioo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo01ioo`03001oogoo
00eoo`03001oogoo00]oo`03001oogoo011oo`03001oogoo0:=oo`03001oogoo00=oo`03001oogoo
00Ioo`03001oogoo015oo`03001oogoo03Aoo`03001oogoo03Qoo`@005ioo`03001oogoo02ioo`03
001oogoo01=oo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<007ooOol047oo00<007ooOol0
2goo00<007ooOol037oo00<007ooOol087oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol087oo00<007ooOol037oo00<007ooOol02goo00<007ooOol037oo00<007ooOol0
87oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol087oo00<007ooOol0
37oo00<007ooOol02goo00<007ooOol037oo00<007ooOol087oo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol087oo00<007ooOol037oo00<007ooOol02goo00<007ooOol0
47oo00<007ooOol0Xgoo00<007ooOol00goo00<007ooOol01Woo00<007ooOol04Goo00<007ooOol0
=Goo0`00=Goo0P00HGoo00<007ooOol0;goo00<007ooOol04goo00<007ooOol017oo00<007ooOol0
L7oo001HOol00`00Oomoo`0@Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0>Ool90009
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`08Ool9000@Ool00`00
Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0>Ool9000:Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`09Ool9000@Ool00`00Oomoo`0;Ool00`00
Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool8000:Ool00`00Oomoo`04Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`07Ool9000@Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00
Oomoo`0@Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00
Oomoo`0gOol4000^Ool3001SOol00`00Oomoo`0_Ool00`00Oomoo`0COol00`00Oomoo`04Ool00`00
Oomoo`1`Ool005Qoo`03001oogoo011oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00ao
o`<000Uoo`8000Qoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Io
o`<000Uoo`<000ioo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00ao
o`8000Uoo`<000Qoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Mo
o`<000Uoo`8000ioo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00ao
o`@000Qoo`<000Qoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Io
o`8000Uoo`<000ioo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo011oo`03001oogoo0:=o
o`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo03]oo`<002Qoo`<006Io
o`03001oogoo02moo`03001oogoo01=oo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<007oo
Ool047oo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02Woo0`003Woo0`001Woo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo0P003goo0P003Goo00<007oo
Ool02goo00<007ooOol02Goo00<007ooOol02goo00<007ooOol02goo0P003Woo0`001Woo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo0`003Woo0`0037oo00<007oo
Ool02goo00<007ooOol02Goo00<007ooOol02goo00<007ooOol02goo0P003goo0P001goo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol01Goo0P003Woo0`0037oo00<007oo
Ool02goo00<007ooOol02Woo00<007ooOol047oo00<007ooOol0Xgoo00<007ooOol00goo00<007oo
Ool01Woo00<007ooOol04Woo00<007ooOol0?Woo1P007goo0`00J7oo00<007ooOol0<7oo00<007oo
Ool04goo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`0@Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0AOol2000<Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool2000COol00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0BOol0
0`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool2
000COol00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`04Ool2000COol00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0@Ool0
0`00Oomoo`2SOol00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`0COol00`00Oomoo`13Ool6
000BOol7001[Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00Oomoo`04Ool00`00Oomoo`1`Ool0
05Qoo`03001oogoo011oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
01Aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo
00Aoo`03001oogoo01Aoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo01Aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo01Aoo`03001oogoo00Uoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo01Aoo`03001oogoo
00=oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
01Aoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo011oo`03001oogoo
0:=oo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo01=oo`03001oogoo04Uooa80079oo`03
001oogoo031oo`03001oogoo01=oo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<007ooOol0
47oo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol027oo00<007ooOol05Woo00<007ooOol0
0goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Ioo`03001oogoo01Ioo`03001o
ogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001o
ogoo01Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00006Ool0
0`00Oomoo`0FOol00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`0FOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0FOol00`00Oomoo`08Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`0@Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Oomoo`07Ool0
0`00Oomoo`0COol00`00Oomoo`3;Ool00`00Oomoo`0aOol00`00Oomoo`0COol00`00Oomoo`04Ool0
0`00Oomoo`1`Ool005Qoo`03001oogoo015oo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo
00Qoo`03001oogoo01Qoo`03001oogoo00=oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomo
o`03Ool00`00Oomoo`0HOol00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool50009Ool00`00Oomoo`03Ool01@00Oomoogoo0000
17oo00D007ooOomoo`0000Eoo`03001oogoo00Moo`H000]oo`03001oogoo00Qoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo01Qoo`03001oogoo00=o
o`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0AOol00`00Oomoo`2SOol00`00Oomoo`03
Ool00`00Oomoo`07Ool00`00Oomoo`0COol00`00Oomoo`3:Ool00`00Oomoo`0aOol00`00Oomoo`0D
Ool00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo015oo`03001oogoo00Uoo`03001o
ogoo00Uoo`03001oogoo00Moo`03001oogoo00Uoo``000Eoo`03001oogoo009oo`03001oogoo009o
o`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`06Ool9000;Ool00`00Oomoo`07Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`07Ool40005
Ool40006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<0
07ooOol01Goo0`001Woo0`002Goo00<007ooOol01goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol01goo00<007ooOol02Goo2P001goo00<007ooOol00Woo00<007ooOol0
0Woo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo00=oo`d000Yoo`03001oogoo00Moo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo015oo`03001oogoo0:=oo`03001oogoo00=oo`03
001oogoo00Moo`03001oogoo01Aoo`03001oogoo0<Uoo`03001oogoo035oo`03001oogoo01Aoo`03
001oogoo00Aoo`03001oogoo071oo`00F7oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol0
2Goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01Woo100037oo0P0017oo00<007ooOol0
0Woo00D007ooOomoo`00009oo`05001oogooOol00004Ool00`00Oomoo`02Ool50009Ool40008Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`0;Ool20005Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00D0
07ooOomoo`0000Aoo`03001oogoo00=oo`<000aoo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Ioo`@000Yo
o`@000Aoo`03001oogoo009oo`05001oogooOol00002Ool01@00Oomoogoo000017oo00<007ooOol0
0Woo0P003Goo0`0027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol0
27oo00<007ooOol01Woo00<007ooOol0Xgoo00<007ooOol00goo00<007ooOol01goo00<007ooOol0
57oo00<007ooOol0b7oo00<007ooOol0<Woo00<007ooOol057oo00<007ooOol017oo00<007ooOol0
L7oo001HOol00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00
Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`0@Ool01@00Oomoogoo000017oo00D007ooOomoo`00
009oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`05Ool00`00
Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00
Oomoo`06Ool00`00Oomoo`0>Ool20003Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00D007oo
Oomoo`0000Aoo`04001oogooOol2000@Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`0@
Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00@007ooOol000=oo`03001oogoo009oo`05001o
ogooOol0000BOol00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Oomoo`07Ool0
0`00Oomoo`0DOol00`00Oomoo`38Ool00`00Oomoo`0bOol00`00Oomoo`0DOol00`00Oomoo`04Ool0
0`00Oomoo`1`Ool005Qoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo
00Qoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo019oo`80009oo`03001oogoo009oo`04
001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOomoo`8001Aoo`03001oogoo00Eoo`03001o
ogoo00Ioo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Ioo`03001o
ogoo00Eoo`8001=oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000=o
o`05001oogooOol0000COol20007Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`0BOol20003Ool01000Oomo
o`000goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo008001Aoo`03001oogoo00Eoo`03
001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Ioo`03
001oogoo0:=oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo0<Ioo`03
001oogoo03=oo`03001oogoo01Aoo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01Woo00<007ooOol0
1Goo00<007ooOol027oo2@0017oo00@007ooOol000=oo`04001oogoo0002Ool01000Oomoo`000goo
00@007ooOol000Qoo`D000Yoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Moo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`X000Ao
o`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00005Ool9
0008Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`08Ool60007Ool01000Oomoo`000goo
00@007ooOol0009oo`04001oogoo0003Ool01000Oomoo`001Goo2@002Goo00<007ooOol01Goo00<0
07ooOol01Woo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol0Xgoo00<007ooOol00goo00<007ooOol027oo00<007ooOol05Goo00<007ooOol0aGoo00<0
07ooOol0<Woo00<007ooOol05Goo00<007ooOol017oo00<007ooOol0L7oo001HOol30007Ool00`00
Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool50009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`0017oo1@001Goo1@001Woo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool017oo0`002Woo0P000goo0P000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
0Woo0P000goo0`002Goo0P001goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01goo00<0
07ooOol02Goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo1@00
1Woo100017oo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Ao
o`8000Uoo`@000Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo00Qo
o`03001oogoo00Moo`03001oogoo00Eoo`<00:Eoo`8000Aoo`03001oogoo00Qoo`03001oogoo01Eo
o`03001oogoo0<Aoo`03001oogoo03=oo`03001oogoo01Eoo`03001oogoo00=oo`80079oo`00F7oo
00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol00goo00<007ooOol03Goo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol0000?Ool00`00Oomoo`03Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool2000>Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`0000ioo`8000Ioo`03
001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Moo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00eoo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00003goo00<0
07ooOol00goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol0Xgoo00<007ooOol00goo00<007ooOol027oo00<0
07ooOol05Goo00<007ooOol0a7oo00<007ooOol0<goo00<007ooOol05Goo00<007ooOol017oo00<0
07ooOol0L7oo001HOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool20002Ool01P00
Oomoo`00Ool0009oo`04001oogoo0002Ool00`00Ool00002Ool00`00Oomoo`02000AOol00`00Oomo
o`03Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool01@00Oomo
ogoo00000Woo00<007oo00000Woo00@007ooOol0009oo`03001oo`00009oo`05001oogooOol0000A
Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`09
Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0?
Ool20002Ool01P00Oomoo`00Ool0009oo`04001oogoo0002Ool00`00Ool00002Ool00`00Oomoo`02
000AOol00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Oomo
o`08Ool00`00Oomoo`0FOol00`00Oomoo`33Ool00`00Oomoo`0cOol00`00Oomoo`0EOol00`00Oomo
o`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo019oo`03
001oo`00009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<007oo00000Woo00<007ooOol0
4Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00goo00<007ooOol0
4Goo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00003Ool0
0`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
0`00Oomoo`0BOol01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oo`00009oo`06001oogoo
001oo`0057oo00<007ooOol00goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol0Xgoo00<007ooOol00goo00<0
07ooOol027oo00<007ooOol05goo00<007ooOol0`Goo00<007ooOol0=7oo00<007ooOol05Goo00<0
07ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0D
Ool01@00Ool007oo00000Woo00<007oo00000Woo00<007oo00000Woo00D007oo001oo`0001Ioo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo01=oo`80
0009Ool007ooOol007oo001oo`00009oo`05001oo`00Ool00002Ool01000Ool000005Goo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol057oo00D007oo
001oo`00009oo`03001oo`00009oo`03001oo`00009oo`05001oo`00Ool0000FOol00`00Oomoo`02
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`08Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`0G
Ool00`00Oomoo`31Ool00`00Oomoo`0dOol00`00Oomoo`0EOol00`00Oomoo`04Ool00`00Oomoo`1`
Ool005Qoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01Ioo`09001oo`00Ool007oo001o
o`00009oo`09001oo`00Ool007oo001oo`0001Qoo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo00Eoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Eoo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo01Ioo`09001oo`00Ool007oo001oo`00009oo`09001o
o`00Ool007oo001oo`0001Qoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo01Ioo`09001oo`00Ool007oo001oo`00009oo`09001oo`00Ool007oo001o
o`0001Qoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo0:=oo`03001oogoo00=oo`03001o
ogoo00Qoo`03001oogoo01Qoo`03001oogoo0;moo`03001oogoo03Eoo`03001oogoo01Eoo`03001o
ogoo00Aoo`03001oogoo071oo`00F7oo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol05Woo
00T007oo001oo`00Ool007oo00000Woo00T007oo001oo`00Ool007oo000067oo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo
00<007ooOol01Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol05Woo00T007oo001oo`00
Ool007oo00000Woo00T007oo001oo`00Ool007oo000067oo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol01Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Goo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol05Woo00T007oo001oo`00Ool007oo00000Woo
00T007oo001oo`00Ool007oo000067oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol0Xgoo
00<007ooOol00goo00<007ooOol027oo00<007ooOol067oo00<007ooOol0_goo00<007ooOol0=Goo
00<007ooOol05Goo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`0GOol01@00Oomoo`00Ool00P0000Ioo`00Oomoo`00Ool2000017oo001oo`00
6Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00D007ooOomoo`0001Yoo`08001o
o`00001oo`00Ool0009oo`08001oo`00001oo`00Ool001Yoo`05001oogooOol00005Ool00`00Oomo
o`05Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0HOol01000Ool007oo0P0000Ioo`00Oomoo`00Ool20000
1Goo001oogoo00006Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol0Xgoo00<007ooOol0
0goo00<007ooOol027oo00<007ooOol06Goo00<007ooOol0_Goo00<007ooOol0=Woo00<007ooOol0
5Goo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`08Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`03Ool01@00Oomoogoo00006goo
00P007oo001oo`00Ool007oo0P0000Qoo`00Ool007oo001oo`006Woo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol017oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool017oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol067oo00P007oo001oo`00Ool007oo
0P0000Qoo`00Ool007oo001oo`006Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol017oo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol017oo00<007ooOol00goo
00<007ooOol00Woo00<007ooOol067oo00P007oo001oo`00Ool007oo0P0000Qoo`00Ool007oo001o
o`006goo00D007ooOomoo`0000Eoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Qoo`03001oogoo0:=oo`03001oogoo00=oo`03001oogoo00Uoo`03
001oogoo01Uoo`03001oogoo0;aoo`03001oogoo03Ioo`03001oogoo01Eoo`03001oogoo00Aoo`03
001oogoo071oo`00F7oo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol017oo00<007ooOol00goo00D007ooOomoo`0001aoo`07001oo`00001oo`00Ool0
0P0000Moo`00001oo`00Ool0000LOol01@00Oomoogoo00001Goo00<007ooOol017oo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01goo00<007ooOol017oo00<007ooOol00goo00D007ooOomo
o`0001aoo`07001oo`00001oo`00Ool00P0000Moo`00001oo`00Ool0000LOol01@00Oomoogoo0000
1Goo00<007ooOol017oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
17oo00<007ooOol00goo00D007ooOomoo`0001aoo`04001oo`00Ool200001Woo000007oo001oo`80
0003Ool007oo01]oo`05001oogooOol00005Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Oomo
o`09Ool00`00Oomoo`0IOol00`00Oomoo`2kOol00`00Oomoo`0fOol00`00Oomoo`0FOol00`00Oomo
o`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Aoo`03001oogoo00=oo`05001oogooOol0000LOol01`00Ool00000
Ool007oo00800007Ool00000Ool007oo000077oo00D007ooOomoo`0000Eoo`03001oogoo00Aoo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00=oo`05
001oogooOol0000MOol300000goo001oo`02000017oo000007oo0P007Goo00D007ooOomoo`0000Eo
o`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ao
o`03001oogoo00=oo`05001oogooOol0000LOol01000Ool007oo0P0000Ioo`00001oo`00Ool20000
0goo001oo`0KOol01@00Oomoogoo00001Goo00<007ooOol017oo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol027oo00<007ooOol0Xgoo00<007ooOol00goo00<007ooOol0
2Goo00<007ooOol06Woo00<007ooOol0^Goo00<007ooOol0=goo00<007ooOol05Woo00<007ooOol0
17oo00<007ooOol0L7oo001HOol00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`03Ool01@00Oomoogoo00007Goo0`0000=oo`00Ool0
0P0000Aoo`00001oo`8001eoo`05001oogooOol00005Ool00`00Oomoo`04Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`03Ool01@00Oomoogoo0000
7Goo0`0000=oo`00Ool00P0000Aoo`00001oo`8001eoo`05001oogooOol00005Ool00`00Oomoo`04
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`03
Ool01@00Oomoogoo00007Goo0P0000Aoo`00001oo`800003Ool007oo00<001eoo`05001oogooOol0
0005Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`08Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`0JOol00`00Oomo
o`2iOol00`00Oomoo`0gOol00`00Oomoo`0FOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03
001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Aoo`03
001oogoo009oo`05001oogooOol0000NOol01@00Ool00000Ool0100000Eoo`00001oo`0001ioo`05
001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo00007Woo00<007oo00000P0000Aoo`00
001oo`<00003Ool007oo01eoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`06Ool0
0`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo0000
7Woo00D007oo000007oo00@00005Ool00000Ool0000NOol01@00Oomoogoo000017oo00<007ooOol0
17oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol0
Xgoo00<007ooOol00goo00<007ooOol02Goo00<007ooOol06goo00<007ooOol0]goo00<007ooOol0
>7oo00<007ooOol05Woo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`08Ool00`00
Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00
Oomoogoo00007Woo00D007oo000007oo00@00005Ool00000Ool0000NOol01@00Oomoogoo000017oo
00<007ooOol017oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol017oo
00<007ooOol00Woo00D007ooOomoo`0001moo`<00003Ool0000000800004Ool00000000OOol01@00
Oomoogoo000017oo00<007ooOol017oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo
00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0001ioo`05001oo`00001oo`0400001Goo
000007oo00007Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo
00Uoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo0:=oo`03001oogoo00=oo`03001oogoo
00Yoo`03001oogoo01]oo`03001oogoo0;Ioo`03001oogoo03Moo`03001oogoo01Moo`03001oogoo
00Aoo`03001oogoo071oo`00F7oo00<007ooOol027oo00<007ooOol01Woo00<007ooOol02Goo00<0
07ooOol01Woo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0001moo`<00003Ool00000
00800004Ool00000000OOol01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol01Woo00<0
07ooOol02Goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0001mo
o`<00003Ool0000000800004Ool00000000OOol01@00Oomoogoo000017oo00<007ooOol017oo00<0
07ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00Woo00D0
07ooOomoo`0001moo`<00003Ool0000000800004Ool00000000OOol01@00Oomoogoo000017oo00<0
07ooOol017oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol027oo00<0
07ooOol0Xgoo00<007ooOol00goo00<007ooOol02Woo00<007ooOol06goo00<007ooOol0]Goo00<0
07ooOol0>7oo00<007ooOol05goo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`08
Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01@00Oomoogoo00007goo0`0000=oo`0000000P0000Aoo`00000001moo`05001oogooOol00004
Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool01@00Oomoogoo00007goo0`0000=oo`0000000P0000Aoo`00000001moo`05
001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo00007goo0`0000=oo`0000000P0000Ao
o`00000001moo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`09
Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`2SOol00`00Oomoo`03Ool00`00Oomoo`0:
Ool00`00Oomoo`0LOol00`00Oomoo`2cOol00`00Oomoo`0iOol00`00Oomoo`0GOol00`00Oomoo`04
Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Uoo`03001o
ogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo000OOol300000goo000000020000
17oo000000007goo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo
00Uoo`03001oogoo00Moo`03001oogoo00Aoo`05001oogooOol00003Ool00`00Oomoo`0MOol30000
0goo00000002000017oo000000007goo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo
00Moo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Aoo`05001oogooOol00003Ool00`00
Oomoo`0MOol300000goo00000002000017oo000000007goo00@007ooOol000Aoo`03001oogoo00Ao
o`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo0:=o
o`8000Aoo`03001oogoo00Yoo`03001oogoo01aoo`03001oogoo0;=oo`03001oogoo03Uoo`03001o
ogoo01Moo`03001oogoo00=oo`80079oo`00F7oo0`001goo00<007ooOol01Woo00<007ooOol02Woo
00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0001ioo`<00003Ool0
000000<00003Ool0000001ioo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`06Ool0
0`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo0000
7Woo0P0000=oo`000000100000=oo`0000007Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03
001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo009oo`05
001oogooOol0000NOol200000goo0000000400000goo0000000NOol01@00Oomoogoo000017oo00<0
07ooOol017oo00<007ooOol01Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol01Goo0`00
YGoo00<007ooOol00goo00<007ooOol02Woo00<007ooOol07Goo00<007ooOol0/Goo00<007ooOol0
>Woo00<007ooOol05goo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`06Ool00`00
Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`04Ool01@00Oomoogoo00000goo
00<007ooOol077oo0`0000=oo`0000000`0000=oo`0000007Woo00<007ooOol00P000goo00<007oo
Ool017oo00<007ooOol01goo00<007ooOol02goo00<007ooOol01goo00<007ooOol017oo00D007oo
Oomoo`0000=oo`03001oogoo01aoo`800003Ool0000000@00003Ool0000001ioo`05001oogooOol0
0003Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomo
o`04Ool01@00Oomoogoo00000goo00<007ooOol077oo0P0000=oo`000000100000=oo`0000007Woo
00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00]oo`03001oogoo
00Moo`03001oogoo00Ioo`03001oogoo0:=oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo
01eoo`03001oogoo0:moo`03001oogoo03Yoo`03001oogoo01Qoo`03001oogoo00Aoo`03001oogoo
071oo`00F7oo00<007ooOol01Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol027oo00<0
07ooOol017oo00D007ooOomoo`0000=oo`03001oogoo01aoo`<00003Ool0000000<00003Ool00000
01ioo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomo
o`07Ool00`00Oomoo`04Ool01@00Oomoogoo00000goo00<007ooOol077oo0P0000=oo`0000001000
00=oo`0000007Woo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo
00]oo`03001oogoo00Moo`03001oogoo00Aoo`05001oogooOol00003Ool00`00Oomoo`0LOol20000
0goo0000000400000goo0000000NOol01@00Oomoogoo00000goo00<007ooOol017oo00<007ooOol0
1goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0Xgoo00<007ooOol0
0goo00<007ooOol02goo00<007ooOol07Woo00<007ooOol0[Goo00<007ooOol0>goo00<007ooOol0
67oo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`0@Ool00`00Oomoo`0;Ool00`00
Oomoo`08Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo00<007ooOol077oo0`0000=oo`000000
0`0000=oo`0000007Goo00@007ooOol000Aoo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo
00]oo`03001oogoo00Qoo`03001oogoo00Aoo`05001oogooOol00003Ool00`00Oomoo`0KOol20000
0goo0000000400000goo0000000MOol01@00Oomoogoo00000goo00<007ooOol017oo00<007ooOol0
27oo00<007ooOol02goo00<007ooOol027oo00<007ooOol017oo00D007ooOomoo`0000=oo`03001o
ogoo01]oo`800003Ool0000000@00003Ool0000001ioo`04001oogoo0003Ool00`00Oomoo`04Ool0
0`00Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`2SOol00`00Oomoo`03Ool0
0`00Oomoo`0;Ool00`00Oomoo`0OOol00`00Oomoo`2[Ool00`00Oomoo`0lOol00`00Oomoo`0HOol0
0`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00moo`03001oogoo00aoo`03001oogoo
00Qoo`03001oogoo00Eoo`07001oogooOol007oo00007Woo100000Eoo`00000007oo00<001eoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`0=Ool00`00Oomoo`08Ool0
0`00Oomoo`03Ool01@00Oomoogoo00000goo00<007ooOol06goo100000Aoo`00001oo`@001eoo`05
001oogooOol00003Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00<007ooOol06goo0`0000Eoo`00000007oo00@0
01ioo`03001oo`0000=oo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo
00moo`03001oogoo0:=oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo01moo`03001oogoo
0:Yoo`03001oogoo03eoo`03001oogoo01Qoo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<0
07ooOol03goo00<007ooOol037oo00<007ooOol02Goo00<007ooOol017oo00D007ooOomoo`00009o
o`03001oogoo01]oo`@00005Ool00000001oo`03000LOol01@00Oomoogoo00000goo00<007ooOol0
17oo00<007ooOol027oo00<007ooOol03Goo00<007ooOol027oo00<007ooOol017oo00@007ooOol0
00=oo`03001oogoo01]oo`@00004Ool00000Ool4000MOol01@00Oomoogoo00000Woo00<007ooOol0
17oo00<007ooOol027oo00<007ooOol03Goo00<007ooOol027oo00<007ooOol017oo00D007ooOomo
o`0000=oo`03001oogoo01Yoo`<00005Ool00000001oo`04000MOol01000Oomoo`000goo00<007oo
Ool017oo00<007ooOol027oo00<007ooOol03Goo00<007ooOol03goo00<007ooOol0Xgoo00<007oo
Ool00goo00<007ooOol037oo00<007ooOol07goo00<007ooOol0ZGoo00<007ooOol0?Goo00<007oo
Ool067oo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`0?Ool00`00Oomoo`0=Ool0
0`00Oomoo`09Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo00<007ooOol06Woo100000Eoo`00
000007oo00<001aoo`04001oogoo0003Ool00`00Oomoo`03Ool2000;Ool00`00Oomoo`0=Ool00`00
Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`020002Ool00`00Oomoo`0JOol4000017oo000007oo
100077oo00<007ooOol00P000Woo00<007ooOol017oo00<007ooOol02Goo00<007ooOol03Goo00<0
07ooOol02Goo0P001Goo00D007ooOomoo`00009oo`03001oogoo01Yoo`<00005Ool00000001oo`04
000LOol01000Oomoo`000goo00<007ooOol017oo00<007ooOol02Goo00<007ooOol03Goo00<007oo
Ool03goo00<007ooOol0Xgoo00<007ooOol00goo00<007ooOol037oo00<007ooOol087oo00<007oo
Ool0Ygoo00<007ooOol0?Woo00<007ooOol067oo00<007ooOol017oo00<007ooOol0L7oo001HOol0
0`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`09Ool00`00Oomoo`04Ool200000goo001oo`02
Ool00`00Oomoo`0IOol400001Goo00000000Ool00`006goo00@007ooOol000Aoo`03001oogoo009o
o`03001oogoo00]oo`03001oogoo00ioo`03001oogoo00Uoo`8000Eoo`05001oogooOol00002Ool2
000JOol4000017oo000007oo10006Woo0P000Woo00D007ooOomoo`0000Eoo`8000]oo`03001oogoo
00ioo`03001oogoo00]oo`03001oogoo009oo`03001oogoo009oo`04001oogoo000KOol300001Goo
00000000Ool010006goo00H007ooOomoo`00Ool20006Ool00`00Oomoo`09Ool00`00Oomoo`0?Ool0
0`00Oomoo`0>Ool00`00Oomoo`1oOol:0009Ool6000;Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool0
0`00Oomoo`0QOol00`00Oomoo`2UOol00`00Oomoo`0nOol2000JOol00`00Oomoo`04Ool00`00Oomo
o`1`Ool005Qoo`03001oogoo00eoo`03001oogoo015oo`03001oogoo00Uoo`03001oogoo00Eoo`04
001oo`000002Ool00`00Oomoo`0GOol2000017oo000007oo0`0000=oo`00Ool00P006Goo00@007oo
000000=oo`8000Aoo`03001oogoo00]oo`03001oogoo011oo`03001oogoo00Yoo`03001oogoo00=o
o`05001oogooOol00003Ool00`00Oomoo`0FOol2000017oo000007oo0P0000Aoo`00001oo`8001Qo
o`05001oogooOol00003Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`0@Ool00`00Oomoo`0;Ool0
0`00Oomoo`02Ool20003Ool200000goo001oo`0HOol200000goo001oo`03000017oo000007oo0P00
6Goo00<007ooOol00P0000=oo`00Ool01Woo00<007ooOol02Goo00<007ooOol04Goo00<007ooOol0
3Goo00<007ooOol0Ogoo2P001goo2P002Goo00<007ooOol00goo00<007ooOol037oo00<007ooOol0
8Goo00<007ooOol0Y7oo00<007ooOol0@7oo00<007ooOol067oo00<007ooOol017oo00<007ooOol0
L7oo001HOol00`00Oomoo`0<Ool00`00Oomoo`0COol00`00Oomoo`09Ool20006Ool00`00Oomoo`02
00000goo0000000FOol00`00Ool0000200001goo001oo`00Ool007oo00800003Ool007oo01Eoo`80
0003Ool007oo009oo`8000Aoo`8000aoo`8001Aoo`03001oogoo00Yoo`03001oogoo00=oo`80009o
o`05001oogooOol0000FOol400000goo00000002Ool200000goo00000002000FOol01@00Oomoogoo
00000Woo0P0017oo00<007ooOol02goo00<007ooOol04Woo0P0037oo0P0017oo0P000goo00@007oo
000001Ioo`0;001oo`00001oo`00Ool007oo001oo`0300000goo001oo`0EOol200000goo00000002
Ool00`00Oomoo`04Ool2000;Ool00`00Oomoo`0COol00`00Oomoo`0<Ool00`00Oomoo`23Ool2000;
Ool30005Ool30008Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`0ROol00`00Oomoo`2S
Ool00`00Oomoo`10Ool00`00Oomoo`0HOol00`00Oomoo`04Ool00`00Oomoo`1`Ool004Moo`@000eo
o`03001oogoo00]oo`03001oogoo01Eoo`03001oogoo00Yoo`8000Eoo`05001oogooOol00002Ool0
0`00Oomoo`0BOol6000037oo001oo`00Ool007oo001oo`00Ool001=oo`80009oo`05001oogooOol0
0005Ool00`00Oomoo`0:Ool2000GOol2000;Ool00`00Oomoo`04Ool200001Goo00000000Ool00P00
4Woo100000Eoo`00001oo`00009oo`800003Ool007oo00@0019oo`800005Ool00000001oo`020005
Ool00`00Oomoo`0:Ool2000GOol2000<Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo0P004goo
00`007oo001oo`00Ool007oo001oo`00Ool6000DOol01000Oomoo`000goo00<007ooOol00goo0P00
37oo00<007ooOol05Goo00<007ooOol02goo00<007ooOol0Pgoo0P0057oo0P0027oo00<007ooOol0
17oo00<007ooOol02goo00<007ooOol08goo00<007ooOol0XGoo00<007ooOol0@7oo00<007ooOol0
6Goo00<007ooOol017oo00<007ooOol0L7oo0015Ool8000;Ool00`00Oomoo`09Ool2000IOol00`00
Oomoo`0;Ool00`00Oomoo`02Ool20003Ool200000goo001oo`0@Ool300002goo001oogoo001oo`00
Ool007oo00000Woo00<007oo00000P004Goo00<007ooOol00P000Woo0P001Goo00<007ooOol02Woo
00<007ooOol06Goo0P002Woo0P001Woo00D007ooOomoo`00009oo`8000moo`<0009oo`05001oo`00
Ool00002Ool01@00Ool007oo00000Woo0`003goo0P000Woo00D007ooOomoo`0000Ioo`8000Yoo`80
01]oo`03001oogoo00Yoo`03001oogoo00=oo`80009oo`80009oo`03001oogoo00moo`<0000;Ool0
07ooOol007oo001oo`00Ool00002Ool00`00Ool00002000AOol01000Ool000000goo0P0017oo00<0
07ooOol02goo00<007ooOol05goo0P002goo00<007ooOol0Pgoo0P005Goo0P001goo00<007ooOol0
17oo00<007ooOol02goo00<007ooOol097oo00<007ooOol0Wgoo00<007ooOol0@Goo00<007ooOol0
6Goo00<007ooOol017oo00<007ooOol0L7oo0015Ool20004Ool2000;Ool00`00Oomoo`07Ool2000L
Ool2000<Ool30003Ool30002Ool6000;Ool400001Goo001oogoo00000Woo00H007ooOol007oo0002
Ool00`00Ool00004000;Ool60002Ool20005Ool2000;Ool2000NOol00`00Oomoo`09Ool20005Ool2
0002Ool20002Ool00`00Oomoo`09Ool40002Ool200001Goo001oogoo00000Woo00D007ooOol007oo
0080009oo`@000]oo`03001oogoo0080009oo`8000Eoo`8000]oo`03001oogoo01aoo`8000]oo`80
00Eoo`80009oo`H000]oo`D00007Ool007ooOol007oo00000Woo00@007ooOol0009oo`03001oo`00
00<000aoo`D0009oo`<000=oo`<000aoo`8001aoo`8000Uoo`03001oogoo08=oo`8001Eoo`8000Mo
o`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo02Eoo`03001oogoo09eoo`03001oogoo049o
o`03001oogoo01Uoo`03001oogoo00Aoo`03001oogoo071oo`00A7oo0P001Woo0P002Woo00<007oo
Ool01Woo00<007ooOol07Woo0`0037oo0`000goo0`0000=oo`0000001P0017oo1@000Woo00<007oo
Ool00P0000=oo`00Ool00Woo00<007ooOol00P0000Aoo`00Oomoo`H000Aoo`L0009oo`<000Aoo`<0
00]oo`80025oo`<000Yoo`@000=oo`80009ooa@0009oo`04001oogoo0004Ool01000Oomoo`000Woo
50000Woo0P0017oo0`002Woo0`008Goo0P002goo0`0017oo100000=oo`0000001P000goo1P000Woo
00@007oo0000009oo`06001oogooOol007oo0P000Woo00<007ooOol01P000goo200000Aoo`000000
00=oo`<000aoo`<0021oo`03001oogoo00Ioo`03001oogoo08=oo`8001Eoo`8000Moo`03001oogoo
00Aoo`03001oogoo00]oo`03001oogoo02Eoo`03001oogoo09eoo`03001oogoo049oo`03001oogoo
01Uoo`03001oogoo00Aoo`03001oogoo071oo`00A7oo0P001Woo0P002Woo00<007ooOol0:Woo0`00
37oo0`000goo400000Eoo`00000007oo008000=oo`05001oogooOol00004Ool600000goo0000000>
0004Ool3000;Ool3000VOol4000:Ool400000goo0000000200000goo0000000900000goo00000003
Ool20003Ool00`00Oomoo`02Ool01000Oomoogoo0P000goo3P000Woo0`0000=oo`0000000`002Goo
10009Woo10002Woo0`001Goo3`000Woo1@0017oo00D007ooOomoo`0000=oo`800005Ool00000001o
o`0@0003Ool3000<Ool3000/Ool00`00Oomoo`23Ool2000EOol20007Ool30004Ool00`00Oomoo`0<
Ool00`00Oomoo`0UOol00`00Oomoo`2KOol00`00Oomoo`13Ool00`00Oomoo`0IOol00`00Oomoo`02
Ool3001bOol004=oo`8000Qoo`8000Uoo`03001oogoo02eoo`T000IooaP000Aoo`8000Aoo`8000Ao
oaT000Eoo`T002eoo`D000Uooa8000=oo`8000=oo`<000Aoo`<000=oo`<000=ooa4000Uoo`D002io
o`T000AooaT000Aoo`8000Aoo`8000AooaP000Ioo`T002moo`03001oogoo08=oo`8001Eoo`8000Mo
o`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo02Ioo`03001oogoo09Uoo`03001oogoo04=o
o`03001oogoo01Yoo`03001oogoo00Aoo`03001oogoo071oo`00@goo0P0027oo0P002Goo00<007oo
Ool0=Woo2@001Goo500027oo50001Goo2@00>goo7P0000=oo`0000000P002Woo1@0000=oo`000000
6`00?7oo2@0017oo500027oo5@0017oo2@00>7oo00<007ooOol0Pgoo0P0057oo0P0027oo00<007oo
Ool017oo00<007ooOol037oo00<007ooOol09goo00<007ooOol0Ugoo00<007ooOol0A7oo00<007oo
Ool06Woo00<007ooOol017oo00<007ooOol0L7oo0013Ool20008Ool20009Ool4000nOolA000HOolA
001BOolA000COolA001BOolA000GOolA000nOol40025Ool2000<Ool20005Ool30008Ool00`00Oomo
o`04Ool00`00Oomoo`0<Ool00`00Oomoo`0XOol00`00Oomoo`2EOol00`00Oomoo`15Ool00`00Oomo
o`0JOol00`00Oomoo`04Ool00`00Oomoo`1`Ool004=oo`8000Qoo`8000Uoo`03001oogoo03Eoob40
00aoob4003ioob0000Qoob4003ioob0000eoob0003Moo`03001oogoo08=oo`8000aoo`T000Uoo`03
001oogoo00Aoo`03001oogoo00aoo`03001oogoo02Uoo`03001oogoo09=oo`03001oogoo04Ioo`03
001oogoo01Yoo`03001oogoo00Aoo`03001oogoo071oo`00@goo0P0027oo0P002Goo00<007ooOol0
;goo1P0027oo600000=oo`0000000P0017oo100000=oo`0000005P0027oo1@00;goo2P0017oo6@00
0goo0P0017oo0P000goo6@001Goo2@00;goo1P001goo600000=oo`0000000P0017oo7@0027oo1P00
<Goo00<007ooOol0Pgoo0P0037oo0P0000=oo`0000000`002Woo00<007ooOol017oo00<007ooOol0
3Goo00<007ooOol0:Goo00<007ooOol0T7oo0P00BGoo00<007ooOol06Woo00<007ooOol017oo00<0
07ooOol0L7oo0013Ool20008Ool20009Ool00`00Oomoo`0/Ool3000;Ool30002OolC0003Ool20002
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo4`0000Aoo`00000000Yoo`@002Qoo`<000]oo`<0
00Eoo`<00003Ool0000000P00003Ool0000000=oo`05001oogooOol00004Ool01@00Oomoogoo0000
0goo3@0000=oo`0000000P0017oo0`002goo0`00:Goo0`002Woo0`000Woo4`000goo00D007ooOomo
o`0000Aoo`03001oogoo008000=ooa<0009oo`@000Yoo`<002ioo`03001oogoo08=oo`8000aoo`80
011oo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo02Yoo`03001oogoo08ioo`03001oogoo
04Qoo`03001oogoo01]oo`03001oogoo00Aoo`03001oogoo071oo`00@goo0P0027oo0P002Goo00<0
07ooOol01Woo0P008Goo0`002Woo10000goo1P0000=oo`0000003P000goo00<007oo00000goo00H0
07ooOomoo`00OolA000017oo000000000Woo0`0000Aoo`00000000]oo`@0029oo`8000]oo`<000=o
oaX000=oo`03001oogoo009oo`05001oogoo001oo`0I0003Ool3000;Ool2000ROol5000:Ool30000
0goo0000000200001Goo00000000Ool04@0000=oo`00Ool00Woo00L007ooOomoo`00Ool00003Ool@
0002Ool50004Ool3000:Ool3000QOol20008Ool00`00Oomoo`23Ool2000<Ool2000@Ool00`00Oomo
o`04Ool00`00Oomoo`0>Ool00`00Oomoo`0ZOol2002=Ool00`00Oomoo`19Ool00`00Oomoo`0KOol0
0`00Oomoo`04Ool00`00Oomoo`1`Ool004=oo`8000Qoo`8000Uoo`03001oogoo00Qoo`03001oogoo
01]oo`<000]oo`8000Eoo`@0009oo`<000aoo`H00005Ool007ooOol00002Ool02@00Oomoo`00Ool0
07oo001oo`02000<Ool20002Ool30002Ool01000Oomoogoo0`0037oo0`007Goo0P002goo0P000goo
0`0000=oo`0000000P0000Aoo`00000000Yoo`D00003Ool00000009oo`03001oogoo009oo`06001o
o`00Ool007oo1@002Woo0`000Woo0`0000Aoo`00000000=oo`8000]oo`8001eoo`<000aoo`<000=o
o`03001oogoo00<0009oo`8000aoo`800006Ool007oo001oo`000Woo00@007ooOol0009oo`03001o
o`0000D000aoo`<0009oo`@000Eoo`8000]oo`<001eoo`03001oogoo00Qoo`03001oogoo07moo`<0
0003Ool0000000aoo`80011oo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo02]oo`03001o
ogoo08Yoo`8004Yoo`03001oogoo01aoo`03001oogoo00Aoo`03001oogoo071oo`00A7oo0P001Woo
0P002Woo00<007ooOol02Goo00<007ooOol067oo0P0037oo0P0017oo0`0000Aoo`00Oomoo`80015o
o`09001oo`00Ool007oo001oo`00009oo`09001oo`00Ool007oo001oo`00011oo`<0009oo`04001o
ogoo0005Ool2000=Ool00`00Oomoo`0GOol3000;Ool20004Ool01@00Oomoogoo00000Woo0`0047oo
00@007oo001oo`80009oo`0<001oogoo001oo`00Ool007oo001oo`0047oo0`000Woo00D007ooOomo
o`0000Aoo`8000]oo`<001Uoo`03001oogoo00]oo`8000Eoo`04001oogoo0003Ool2000@Ool02@00
Ool007oo001oo`00Ool00002Ool02@00Ool007oo001oo`00Ool0000AOol20002Ool00`00Ool00002
0004Ool3000;Ool2000JOol00`00Oomoo`09Ool00`00Oomoo`1oOol6000<Ool:0008Ool00`00Oomo
o`04Ool00`00Oomoo`0>Ool00`00Oomoo`0/Ool00`00Oomoo`28Ool00`00Oomoo`1:Ool00`00Oomo
o`0LOol00`00Oomoo`04Ool00`00Oomoo`1`Ool004Aoo`8000Ioo`8000Yoo`03001oogoo00Yoo`80
01Moo`03001oogoo00Uoo`<000Aoo`80009oo`800003Ool0000001Aoo`04001oo`00Ool2000037oo
001oo`00Ool007oo001oo`00Ool001Aoo`800004Ool00000Ool30004Ool2000<Ool00`00Oomoo`0E
Ool00`00Oomoo`09Ool30004Ool20003Ool01000Oomoo`0057oo0`0000Eoo`00001oo`00009oo`80
0003Ool007oo00<001Aoo`04001oogoo0003Ool20004Ool2000<Ool00`00Oomoo`0EOol00`00Oomo
o`0:Ool20004Ool3000017oo000007oo0`004goo00`007oo001oo`00Ool007oo001oo`00Ool20000
17oo001oo`0057oo0P0000=oo`0000000Woo0P001Goo0P002goo00<007ooOol05Goo0P0037oo00<0
07ooOol0PWoo0`0037oo2P0027oo00<007ooOol017oo00<007ooOol03goo00<007ooOol0;7oo0P00
Qgoo00<007ooOol0Bgoo00<007ooOol077oo00<007ooOol017oo00<007ooOol0L7oo0015Ool20004
Ool2000;Ool00`00Oomoo`0<Ool00`00Oomoo`0COol00`00Oomoo`09Ool00`00Oomoo`04Ool01@00
Oomoogoo00000Woo00<007ooOol057oo00@007oo001oo`80000<Ool007oo001oo`00Ool007oo001o
o`005Woo00@007ooOol000=oo`03001oogoo00=oo`8000]oo`03001oogoo01=oo`03001oogoo00Uo
o`03001oogoo00Aoo`04001oogooOol20002Ool00`00Oomoo`0EOol01P00Ool00000Ool0009oo`80
0004Ool007oo000GOol00`00Oomoo`020003Ool00`00Oomoo`03Ool2000;Ool00`00Oomoo`0COol0
0`00Oomoo`09Ool20005Ool01@00Oomoogoo00000Woo00<007ooOol057oo00`007oo001oo`00Ool0
07oo001oo`00Ool2000017oo001oo`005Woo00@007ooOol000=oo`03001oogoo00Aoo`03001oogoo
00Uoo`03001oogoo01=oo`03001oogoo00aoo`03001oogoo0:=oo`03001oogoo00Aoo`03001oogoo
00moo`03001oogoo02ioo`03001oogoo08=oo`03001oogoo04]oo`03001oogoo01eoo`03001oogoo
00Aoo`03001oogoo071oo`00AGoo20002goo00<007ooOol03Goo00<007ooOol04Goo00<007ooOol0
2Goo00<007ooOol017oo00D007ooOomoo`00009oo`03001oogoo01Ioo`03001oo`0000800007Ool0
07oo001oo`00Ool00P0000=oo`00Ool05goo00@007ooOol000=oo`03001oogoo00Aoo`03001oogoo
00Uoo`03001oogoo015oo`03001oogoo00Uoo`03001oogoo00Aoo`05001oogooOol00003Ool00`00
Oomoo`0FOol300000goo00000002Ool2000017oo0000000067oo00D007ooOomoo`0000=oo`03001o
ogoo00Aoo`03001oogoo00Uoo`03001oogoo015oo`03001oogoo00Uoo`03001oogoo00Aoo`05001o
ogooOol00002Ool00`00Oomoo`0FOol02`00Ool00000Ool007oo001oo`00Ool00`0000=oo`00Ool0
5goo00@007ooOol000=oo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo015oo`03001oogoo
00eoo`03001oogoo0:=oo`03001oogoo00Aoo`03001oogoo00moo`03001oogoo02moo`03001oogoo
081oo`8004ioo`03001oogoo01eoo`03001oogoo00Aoo`03001oogoo071oo`00Agoo10003Goo00<0
07ooOol03Woo00<007ooOol03goo00<007ooOol02Goo00<007ooOol017oo00D007ooOomoo`00009o
o`03001oogoo01Qoo`800004Ool00000Ool300000goo001oo`02000JOol01000Oomoo`000goo00<0
07ooOol017oo00<007ooOol02Goo00<007ooOol03goo00<007ooOol02Goo00<007ooOol017oo00D0
07ooOomoo`0000=oo`03001oogoo01Qoo`05001oo`00001oo`0200001Goo000007oo00006Woo00D0
07ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo00moo`03001oogoo00Uo
o`03001oogoo00Aoo`05001oogooOol00002Ool00`00Oomoo`0HOol200000goo001oo`03000017oo
000007oo0P006Woo00@007ooOol000=oo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo00mo
o`03001oogoo00ioo`03001oogoo0:=oo`03001oogoo00Aoo`03001oogoo00moo`03001oogoo031o
o`8007moo`03001oogoo04ioo`03001oogoo01eoo`03001oogoo00Aoo`03001oogoo071oo`00F7oo
00<007ooOol03goo00<007ooOol03Goo00<007ooOol02Goo00<007ooOol017oo00D007ooOomoo`00
009oo`03001oogoo01Yoo`@00005Ool00000001oo`03000LOol01000Oomoo`000goo00<007ooOol0
17oo00<007ooOol02Goo00<007ooOol03Goo00<007ooOol02Goo00<007ooOol017oo00D007ooOomo
o`00009oo`8001]oo`@00004Ool00000Ool4000KOol20002Ool01@00Oomoogoo00001Woo00<007oo
Ool02Goo00<007ooOol03Goo00<007ooOol02Goo00<007ooOol017oo00D007ooOomoo`00009oo`03
001oogoo01Yoo`<00005Ool00000001oo`04000LOol01000Oomoo`000goo00<007ooOol017oo00<0
07ooOol02Goo00<007ooOol03Goo00<007ooOol03goo00<007ooOol0Xgoo00<007ooOol017oo00<0
07ooOol03goo00<007ooOol0<Woo00<007ooOol0Ngoo00<007ooOol0Cgoo00<007ooOol07Goo00<0
07ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`09
Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo00<007ooOol06Woo100000Eoo`00000007oo00<0
01aoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00Oomo
o`09Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00<007ooOol06Woo100000Aoo`00001oo`@0
01aoo`05001oogooOol00003Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`0=Ool00`00
Oomoo`08Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00<007ooOol06Woo0`0000Eoo`000000
07oo00@001aoo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`0=Ool0
0`00Oomoo`0?Ool00`00Oomoo`2SOol00`00Oomoo`04Ool00`00Oomoo`0?Ool00`00Oomoo`0cOol0
0`00Oomoo`1iOol00`00Oomoo`1?Ool00`00Oomoo`0NOol00`00Oomoo`04Ool00`00Oomoo`1`Ool0
05Qoo`03001oogoo00moo`03001oogoo00aoo`03001oogoo00Uoo`03001oogoo00Aoo`05001oogoo
Ool00002Ool00`00Oomoo`0KOol400001Goo00000000Ool00`007Goo00@007ooOol000=oo`03001o
ogoo00Aoo`03001oogoo00Qoo`03001oogoo00eoo`03001oogoo00Qoo`03001oogoo00Aoo`05001o
ogooOol00002Ool00`00Oomoo`0KOol4000017oo000007oo10007Goo00@007ooOol000=oo`03001o
ogoo00Aoo`03001oogoo00Qoo`03001oogoo00eoo`03001oogoo00Qoo`03001oogoo00Aoo`05001o
ogooOol00002Ool00`00Oomoo`0KOol300001Goo00000000Ool010007Goo00@007ooOol000=oo`03
001oogoo00Aoo`03001oogoo00Qoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo0:=oo`80
00Eoo`03001oogoo011oo`03001oogoo03=oo`03001oogoo07Moo`03001oogoo051oo`03001oogoo
01ioo`03001oogoo00=oo`80079oo`00F7oo00<007ooOol03goo00<007ooOol037oo00<007ooOol0
2Goo00<007ooOol00goo00D007ooOomoo`0000=oo`03001oogoo01]oo`<00003Ool0000000<00003
Ool0000001eoo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool0
0`00Oomoo`07Ool00`00Oomoo`04Ool01@00Oomoogoo00000goo00<007ooOol06goo0P0000=oo`00
0000100000=oo`0000007Goo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo00Moo`03
001oogoo00aoo`03001oogoo00Qoo`03001oogoo00Aoo`05001oogooOol00003Ool00`00Oomoo`0K
Ool200000goo0000000400000goo0000000MOol01@00Oomoogoo00000goo00<007ooOol00goo00<0
07ooOol02Goo00<007ooOol037oo00<007ooOol03goo00<007ooOol0Xgoo00<007ooOol017oo00<0
07ooOol047oo00<007ooOol0=7oo0P00MGoo0P00Dgoo00<007ooOol07Woo00<007ooOol017oo00<0
07ooOol0L7oo001HOol00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`08
Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo00<007ooOol077oo0`0000=oo`0000000`0000=o
o`0000007Goo00@007ooOol000Aoo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo00]oo`03
001oogoo00Qoo`03001oogoo00Aoo`05001oogooOol00003Ool00`00Oomoo`0KOol200000goo0000
000400000goo0000000MOol01@00Oomoogoo00000goo00<007ooOol017oo00<007ooOol027oo00<0
07ooOol02goo00<007ooOol027oo00<007ooOol017oo00D007ooOomoo`0000=oo`03001oogoo01]o
o`800003Ool0000000@00003Ool0000001ioo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomo
o`08Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`2SOol00`00Oomo
o`04Ool00`00Oomoo`0@Ool00`00Oomoo`0fOol00`00Oomoo`1`Ool2001EOol00`00Oomoo`0NOol0
0`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo
00Yoo`03001oogoo00Qoo`03001oogoo00Aoo`05001oogooOol00003Ool00`00Oomoo`0LOol30000
0goo0000000300000goo0000000NOol01000Oomoo`0017oo00<007ooOol017oo00<007ooOol01goo
00<007ooOol02goo00<007ooOol01goo00<007ooOol017oo00D007ooOomoo`0000=oo`03001oogoo
01aoo`800003Ool0000000@00003Ool0000001ioo`05001oogooOol00003Ool00`00Oomoo`04Ool0
0`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`04Ool01@00Oomoogoo0000
0goo00<007ooOol077oo0P0000=oo`000000100000=oo`0000007Woo00D007ooOomoo`0000=oo`03
001oogoo00Aoo`03001oogoo00Moo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Ioo`03
001oogoo0:=oo`03001oogoo00Aoo`03001oogoo011oo`03001oogoo03Moo`03001oogoo06ioo`03
001oogoo05Eoo`03001oogoo01ioo`03001oogoo00Aoo`03001oogoo071oo`00F7oo0`001Woo00<0
07ooOol01goo00<007ooOol02Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol00Woo00D0
07ooOomoo`0001ioo`<00003Ool0000000<00003Ool0000001ioo`05001oogooOol00003Ool00`00
Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`04Ool01@00
Oomoogoo00000goo00<007ooOol077oo0P0000=oo`000000100000=oo`0000007Woo00D007ooOomo
o`0000=oo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00]oo`03001oogoo00Moo`03001o
ogoo00Aoo`05001oogooOol00003Ool00`00Oomoo`0LOol200000goo0000000400000goo0000000N
Ool01@00Oomoogoo000017oo00<007ooOol00goo00<007ooOol01goo00<007ooOol02goo00<007oo
Ool01goo00<007ooOol017oo0`00YGoo00<007ooOol017oo00<007ooOol04Goo00<007ooOol0=goo
0P00KGoo00<007ooOol0EGoo00<007ooOol07goo00<007ooOol017oo00<007ooOol0L7oo001HOol0
0`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool01@00Oomoogoo00007Woo0`0000=oo`0000000`0000=oo`0000007Woo00D007oo
Oomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03
001oogoo00Aoo`03001oogoo009oo`05001oogooOol0000NOol200000goo0000000400000goo0000
000NOol01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol01Woo00<007ooOol02goo00<0
07ooOol01Woo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0001ioo`800003Ool00000
00@00003Ool0000001ioo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00
Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`2SOol00`00Oomoo`04Ool00`00
Oomoo`0AOol00`00Oomoo`0iOol00`00Oomoo`1YOol00`00Oomoo`1FOol00`00Oomoo`0OOol00`00
Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Uo
o`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00=oo`04001oogoo000OOol300000goo0000
0002000017oo000000007goo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo00Moo`03
001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Aoo`05001oogooOol00003Ool00`00Oomoo`0M
Ool300000goo00000002000017oo000000007goo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03
001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Aoo`05001oogooOol00003
Ool00`00Oomoo`0MOol300000goo00000002000017oo000000007goo00@007ooOol000Eoo`03001o
ogoo00=oo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo0:=oo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo03Yoo`8006Ioo`<005Uoo`03001o
ogoo01moo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<007ooOol027oo00<007ooOol01Woo
00<007ooOol02Goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`00
01moo`<00003Ool0000000800004Ool00000000OOol01@00Oomoogoo000017oo00<007ooOol017oo
00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00Woo
00D007ooOomoo`0001moo`<00003Ool0000000800004Ool00000000OOol01@00Oomoogoo000017oo
00<007ooOol017oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol017oo
00<007ooOol00Woo00D007ooOomoo`0001moo`<00003Ool0000000800004Ool00000000OOol01@00
Oomoogoo000017oo00<007ooOol017oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo
00<007ooOol027oo00<007ooOol0Xgoo00<007ooOol017oo00<007ooOol04Goo00<007ooOol0?7oo
00<007ooOol0HGoo0P00G7oo00<007ooOol07goo00<007ooOol017oo00<007ooOol0L7oo001HOol0
0`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool01@00Oomoogoo00007goo0`0000=oo`0000000P0000Aoo`00000001moo`05001o
ogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo00007goo0`0000=oo`0000000P0000Aoo`00
000001moo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`09Ool0
0`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo00007goo0`0000=oo`00
00000P0000Aoo`00000001moo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`06Ool0
0`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`2SOol00`00Oomoo`04Ool0
0`00Oomoo`0AOol00`00Oomoo`0mOol3001NOol2001NOol00`00Oomoo`0OOol00`00Oomoo`04Ool0
0`00Oomoo`1`Ool005Qoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo
00Ioo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol0000NOol01@00Ool00000Ool01000
00Eoo`00001oo`0001ioo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00
Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo00007goo
0`0000=oo`0000000P0000Aoo`00000001moo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00
Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00
Oomoogoo00007Woo00D007oo000007oo00@00005Ool00000Ool0000NOol01@00Oomoogoo000017oo
00<007ooOol017oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol027oo
00<007ooOol0Xgoo00<007ooOol017oo00<007ooOol04Woo00<007ooOol0?goo0`00FWoo00<007oo
Ool0GGoo00<007ooOol087oo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
1@00Oomoogoo00007Goo00H007oo001oo`00Ool2000017oo000007oo0P007Goo00D007ooOomoo`00
00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo
00Aoo`03001oogoo00=oo`05001oogooOol0000MOol300000goo001oo`02000017oo000007oo0P00
7Goo00D007ooOomoo`0000Eoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Qoo`03001o
ogoo00Ioo`03001oogoo00Aoo`03001oogoo00=oo`05001oogooOol0000MOol2000017oo000007oo
0P0000Ioo`00Ool007oo000MOol01@00Oomoogoo00001Goo00<007ooOol017oo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol0Xgoo00<007ooOol017oo
00<007ooOol04Woo00<007ooOol0@Woo00<007ooOol0E7oo0`00H7oo00<007ooOol087oo00<007oo
Ool017oo00<007ooOol0L7oo001HOol00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`03Ool01@00Oomoogoo00007Goo0`0000=oo`00
Ool00P0000Aoo`00001oo`8001eoo`05001oogooOol00005Ool00`00Oomoo`04Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`03Ool01@00Oomoogoo
00007Goo0`0000=oo`00Ool00P0000Aoo`00001oo`8001eoo`05001oogooOol00005Ool00`00Oomo
o`04Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomo
o`03Ool01@00Oomoogoo00007Goo0P0000Aoo`00001oo`800003Ool007oo00<001eoo`05001oogoo
Ool00005Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`08Ool00`00Oomoo`2SOol00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`13Ool3001A
Ool2001SOol00`00Oomoo`0POol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00Qo
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00=o
o`05001oogooOol0000LOol01`00Ool00000Ool007oo00800007Ool00000Ool007oo000077oo00D0
07ooOomoo`0000Eoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Aoo`03001oogoo00=oo`05001oogooOol0000LOol01`00Ool00000Ool007oo0080
0007Ool00000Ool007oo000077oo00D007ooOomoo`0000Eoo`03001oogoo00Aoo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00=oo`05001oogooOol0
000LOol01000Ool007oo0P0000Ioo`00001oo`00Ool200000goo001oo`0KOol01@00Oomoogoo0000
1Goo00<007ooOol017oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
27oo00<007ooOol0Xgoo00<007ooOol017oo00<007ooOol04goo00<007ooOol0AGoo0P00CWoo00<0
07ooOol0HWoo00<007ooOol08Goo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`08
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`03
Ool01@00Oomoogoo000077oo00L007oo000007oo001oo`0200000goo001oo`0200000goo001oo`0K
Ool01@00Oomoogoo00001Goo00<007ooOol017oo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol017oo00<007ooOol00goo00D007ooOomoo`0001aoo`07001oo`00001oo`00
Ool00P0000Moo`00001oo`00Ool0000LOol01@00Oomoogoo00001Goo00<007ooOol017oo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol017oo00<007ooOol00goo00D007oo
Oomoo`0001aoo`07001oo`00001oo`00Ool00P0000=oo`00Ool00P0000=oo`00Ool06goo00D007oo
Oomoo`0000Eoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Qoo`03001oogoo0:=oo`03001oogoo00Aoo`03001oogoo01=oo`03001oogoo04Moo`03
001oogoo04Uoo`8006Eoo`03001oogoo025oo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol017oo00<0
07ooOol00goo00D007ooOomoo`0001]oo`08001oo`00Ool007oo001oo`800008Ool007oo001oo`00
Ool001Yoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo01Qoo`08001oo`00Ool007oo001oo`800008Ool007oo001oo`00Ool001Yoo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01Qoo`08001oo`00Ool0
07oo001oo`800008Ool007oo001oo`00Ool001]oo`05001oogooOol00005Ool00`00Oomoo`04Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`2SOol0
0`00Oomoo`04Ool00`00Oomoo`0COol00`00Oomoo`18Ool30015Ool3001WOol00`00Oomoo`0QOol0
0`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`05001oogooOol0000IOol01@00
Oomoo`00Ool00P0000Qoo`00Oomoo`00Ool007oo0P0000=oo`00Ool06Goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol01Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol01Goo00<007ooOol00goo00D007ooOomoo`0001Yoo`08001oo`00001oo`00Ool0009oo`08
001oo`00001oo`00Ool001Yoo`05001oogooOol00005Ool00`00Oomoo`05Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`0HOol02000Ool00000Ool007oo0002Ool01P00Ool00000Ool0009oo`03001oogoo01Mo
o`05001oogooOol00005Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`2SOol00`00Oomoo`04Ool00`00Oomoo`0DOol00`00Oomo
o`1:Ool3000nOol4001YOol00`00Oomoo`0ROol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03
001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Eoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo01Ioo`09001oo`00Ool007oo001oo`00009oo`08
001oo`00Ool007oo001oo`8001Moo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo01Ioo`09001oo`00Ool007oo001oo`00009oo`09001oo`00Ool007oo
001oo`0001Qoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo01Eoo`800008Ool007oo001oo`00Ool0009oo`09001oo`00Ool007oo001oo`0001Qoo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Qoo`03001oogoo0:=oo`8000Eoo`03001oogoo01Aoo`03001oogoo
04eoo`<003Qoo`<006eoo`03001oogoo029oo`03001oogoo00=oo`80079oo`00F7oo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol0
0goo00<007ooOol00goo00<007ooOol057oo00X007ooOol007oo001oo`00Ool0009oo`07001oo`00
Ool007oo00000goo00<007ooOol04goo00<007ooOol00goo00<007ooOol00goo00<007ooOol01Goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo
00<007ooOol00goo00<007ooOol057oo00X007ooOol007oo001oo`00Ool0009oo`07001oo`00Ool0
07oo00000Woo00<007ooOol057oo00<007ooOol00goo00<007ooOol00goo00<007ooOol01Goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol04goo00/007ooOomoo`00Ool007oo001oo`00009oo`07001oo`00Ool0
07oo00000Woo00<007ooOol057oo00<007ooOol00goo00<007ooOol00goo00<007ooOol01Goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol0Xgoo00<0
07ooOol017oo00<007ooOol057oo00<007ooOol0D7oo1000<Goo0`00L7oo00<007ooOol08Woo00<0
07ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0B
Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oo`00009oo`03001oo`0000=oo`03001o
ogoo015oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00=oo`03001o
ogoo015oo`80009oo`08001oogoo001oo`00Ool0009oo`05001oo`00Ool00002Ool00`00Oomoo`02
000COol00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomo
o`0AOol01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03001oo`00009o
o`03001oogoo019oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo0:=oo`03001oogoo00Ao
o`03001oogoo01Eoo`03001oogoo05=oo`<002]oo`<0079oo`03001oogoo02=oo`03001oogoo00Ao
o`03001oogoo071oo`00F7oo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol00goo00<007ooOol047oo00@007oo
Ool0009oo`03001oo`00009oo`04001oogoo0002Ool01@00Ool007oo000017oo00<007ooOol03goo
00<007ooOol00goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01goo00<007ooOol027oo
00<007ooOol027oo00<007ooOol01Goo00<007ooOol00goo00<007ooOol017oo00<007ooOol03goo
00D007ooOomoo`00009oo`03001oo`00009oo`04001oogoo0002Ool00`00Ool00002Ool01@00Oomo
ogoo00004Goo00<007ooOol017oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01goo00<0
07ooOol02Goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00goo00<0
07ooOol03goo00<007ooOol00Woo00D007oo001oo`00009oo`04001oogoo0002Ool00`00Ool00002
Ool01000Oomoo`004Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
27oo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol0Xgoo00<007ooOol0
17oo00<007ooOol05Goo00<007ooOol0EWoo1P007goo1P00MGoo00<007ooOol08goo00<007ooOol0
17oo00<007ooOol0L7oo001HOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool20003
Ool01P00Oomoo`00Ool0009oo`04001oogoo0002Ool00`00Ool00002Ool00`00Oomoo`02Ool00`00
Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00
Oomoo`0=Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`04001oogoo0002Ool00`00Ool00002
Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`04001o
ogoo0002Ool00`00Ool00002Ool01000Oomoogoo0P003goo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo
00<007ooOol0Xgoo00<007ooOol017oo00<007ooOol05Goo00<007ooOol0G7oo2P003Woo1`00Ngoo
00<007ooOol08goo00<007ooOol017oo00<007ooOol0L7oo001HOol30007Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool2
000;Ool20003Ool20002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool20003
Ool2000;Ool20006Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool40008Ool30003
Ool20002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool20003Ool40007Ool4
0006Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomo
o`07Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool3000:Ool20003Ool20002Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool20003Ool3000:Ool20006Ool00`00
Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00
Oomoo`05Ool3002UOol00`00Oomoo`04Ool00`00Oomoo`0EOol00`00Oomoo`1VOol>0022Ool00`00
Oomoo`0SOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo00Eoo`8000Moo`/000Ao
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo
009oo`/000Ioo`8000Qoo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Moo`P000Eoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Aoo`L000Uoo`03001o
ogoo00Ioo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Moo`03001o
ogoo00Eoo`03001oogoo00Ioo`8000Moo`X000Aoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00=oo`X000Moo`8000Moo`03001oogoo00Eoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo0:=oo`03
001oogoo00Aoo`03001oogoo01Ioo`03001oogoo0?Aoo`03001oogoo02Aoo`03001oogoo00Aoo`03
001oogoo071oo`00F7oo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol01Woo00<007ooOol01Woo0P004Woo0P0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01@00Oomoogoo000017oo0P004Woo00<007ooOol01goo00<007ooOol01Woo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool04Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01@00Oomoogoo0000
17oo00<007ooOol04Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0
2Goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol047oo0P0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01@00Oomoogoo000017oo0P004Woo0P0027oo00<007oo
Ool01Woo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool0Xgoo00<007ooOol017oo00<007ooOol05Woo00<007ooOol0m7oo00<007ooOol097oo00<007oo
Ool017oo00<007ooOol0L7oo001HOol00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool0
1@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00005Ool00`00Oomoo`0>Ool00`00
Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00
Oomoo`06Ool00`00Oomoo`06Ool2000AOol00`00Oomoo`02Ool01@00Oomoogoo00000goo00@007oo
Ool000=oo`05001oogooOol00004Ool00`00Oomoo`0?Ool20008Ool00`00Oomoo`06Ool00`00Oomo
o`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`0>Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00005
Ool00`00Oomoo`0>Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`2SOol00`00Oomoo`04Ool00`00Oomoo`0F
Ool00`00Oomoo`3dOol00`00Oomoo`0TOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001o
ogoo00Ioo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Moo`03001o
ogoo00Moo`<000]oo`8000Eoo`03001oogoo009oo`05001oogooOol00002Ool01@00Oomoogoo0000
17oo00<007ooOol00goo00<007ooOol02Woo0`002Goo00<007ooOol01goo00<007ooOol027oo00<0
07ooOol02Goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo0P002goo100017oo00<0
07ooOol00Woo00D007ooOomoo`00009oo`05001oogooOol00004Ool00`00Oomoo`02Ool5000:Ool2
0009Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool3000<Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0Woo00D007ooOomoo`0000Aoo`03001oogoo00=oo`8000]oo`<000Uoo`03001oogoo00Moo`03001o
ogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo0:=oo`03001o
ogoo00Aoo`03001oogoo01Moo`03001oogoo0?9oo`03001oogoo02Eoo`03001oogoo00Aoo`03001o
ogoo071oo`00F7oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo
00<007ooOol027oo00<007ooOol02Goo00<007ooOol01Goo0`001goo00<007ooOol00Woo00D007oo
Oomoo`00009oo`05001oogooOol00005Ool00`00Oomoo`03Ool40006Ool2000<Ool00`00Oomoo`07
Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`09
Ool40003Ool40007Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000Eoo`03
001oogoo00Ioo`<000Aoo`<000]oo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Uoo`03
001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Yoo`8000Moo`<000Eoo`03001oogoo00=oo`05
001oogooOol00002Ool01@00Oomoogoo000017oo00<007ooOol01Goo0`001goo00<007ooOol02Goo
00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol01Woo
00<007ooOol0Xgoo00<007ooOol017oo00<007ooOol05goo00<007ooOol0lWoo00<007ooOol09Goo
00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`0AOol00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool70009Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
1000Oomoo`0017oo00<007ooOol00goo00<007ooOol01Woo1P0037oo0P002Goo00<007ooOol02Goo
00<007ooOol02Goo00<007ooOol02Goo00<007ooOol01goo00<007ooOol037oo0`002Woo00<007oo
Ool00goo00D007ooOomoo`0000Aoo`05001oogooOol00005Ool00`00Oomoo`08Ool4000=Ool00`00
Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`07Ool2000<
Ool70007Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<0
07ooOol01goo1`002goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
4Goo00<007ooOol0Xgoo00<007ooOol017oo00<007ooOol067oo00<007ooOol0l7oo00<007ooOol0
9Woo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`0@Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0GOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool01@00Oomoogoo00001Woo00<007ooOol05Woo00<007ooOol02Goo00<007ooOol02Goo
00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol05goo00<007ooOol017oo
00D007ooOomoo`0000Aoo`05001oogooOol00006Ool00`00Oomoo`0GOol00`00Oomoo`08Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0FOol00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`0GOol00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0@Ool00`00
Oomoo`2SOol00`00Oomoo`04Ool00`00Oomoo`0HOol00`00Oomoo`3`Ool00`00Oomoo`0VOol00`00
Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo011oo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Yoo`03001oogoo01Aoo`8000Eoo`03001oogoo009oo`03001oogoo009oo`05001o
ogooOol00007Ool00`00Oomoo`0DOol00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool2000FOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0DOol2000;Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0DOol00`00Oomoo`04Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool2000FOol00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0@Ool00`00Oomoo`2SOol00`00Oomo
o`04Ool00`00Oomoo`0IOol00`00Oomoo`3^Ool00`00Oomoo`0WOol00`00Oomoo`04Ool00`00Oomo
o`1`Ool005Qoo`03001oogoo011oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`80
019oo`8000Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Eoo`80
01=oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo
00Yoo`80019oo`8000Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo
00Eoo`80019oo`8000aoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo015oo`8000Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo00Aoo`<0015oo`8000aoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo011oo`03
001oogoo0:=oo`03001oogoo00Aoo`03001oogoo01Uoo`03001oogoo0>ioo`03001oogoo02Moo`03
001oogoo00Aoo`03001oogoo071oo`00F7oo00<007ooOol047oo00<007ooOol02Woo00<007ooOol0
2Woo00<007ooOol037oo0`0037oo0`0027oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol01Woo0P003Woo0`003Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
2Woo00<007ooOol037oo00<007ooOol037oo0`0027oo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol01Woo0`003Woo00<007ooOol037oo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol02Woo00<007ooOol02goo0`003Woo0P0027oo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol01goo0P0037oo0`003Woo00<007ooOol02Woo00<007ooOol0
2Woo00<007ooOol047oo00<007ooOol0Xgoo0P001Goo00<007ooOol06Goo00<007ooOol0kWoo00<0
07ooOol09goo00<007ooOol00goo0P00LWoo001HOol00`00Oomoo`0@Ool00`00Oomoo`0:Ool00`00
Oomoo`0;Ool00`00Oomoo`0>Ool30007Ool2000:Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool00`00Oomoo`07Ool30007Ool4000?Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00
Oomoo`0;Ool00`00Oomoo`0<Ool30008Ool3000:Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool00`00Oomoo`08Ool30008Ool3000>Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00
Oomoo`0;Ool00`00Oomoo`0=Ool50006Ool30009Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool00`00Oomoo`08Ool20007Ool3000@Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00
Oomoo`0@Ool00`00Oomoo`2SOol00`00Oomoo`04Ool00`00Oomoo`0JOol00`00Oomoo`3/Ool00`00
Oomoo`0XOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo011oo`03001oogoo00]o
o`03001oogoo00]oo`03001oogoo011oo`L000]oo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo00Uoo`L0019oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yo
o`03001oogoo00moo`P000aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo00Yoo`P0015oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo015o
o`H000]oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Uoo`L0019o
o`03001oogoo00]oo`03001oogoo00]oo`03001oogoo011oo`03001oogoo0:=oo`03001oogoo00Ao
o`03001oogoo01Yoo`03001oogoo0>aoo`03001oogoo02Qoo`03001oogoo00Aoo`03001oogoo071o
o`00F7oo00<007ooOol047oo00<007ooOol02goo00<007ooOol037oo00<007ooOol087oo00<007oo
Ool01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol087oo00<007ooOol037oo00<007oo
Ool02goo00<007ooOol02goo0P008Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol087oo0P003Goo00<007ooOol02goo00<007ooOol037oo00<007ooOol087oo00<007oo
Ool01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol087oo00<007ooOol037oo00<007oo
Ool02goo00<007ooOol047oo00<007ooOol0Xgoo00<007ooOol017oo00<007ooOol06Woo00<007oo
Ool0jgoo00<007ooOol0:Goo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`0@Ool0
0`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0POol00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`05Ool00`00Oomoo`0OOol00`00Oomoo`0=Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool0
0`00Oomoo`0OOol00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0OOol0
0`00Oomoo`0=Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00Oomoo`0OOol00`00Oomoo`05Ool0
0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0POol00`00Oomoo`0<Ool00`00Oomoo`0;Ool0
0`00Oomoo`0@Ool00`00Oomoo`2SOol00`00Oomoo`04Ool00`00Oomoo`0JOol00`00Oomoo`3[Ool0
0`00Oomoo`0YOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03001oogoo011oo`03001oogoo
00]oo`03001oogoo00eoo`8001moo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03
001oogoo01eoo`03001oogoo00ioo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo01eoo`03
001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo01eoo`03001oogoo00eoo`03
001oogoo00aoo`03001oogoo00ioo`03001oogoo01eoo`03001oogoo00Ioo`03001oogoo00Aoo`03
001oogoo00Ioo`03001oogoo01eoo`8000moo`03001oogoo00]oo`03001oogoo011oo`03001oogoo
0:=oo`03001oogoo00Aoo`03001oogoo01]oo`03001oogoo0>Uoo`03001oogoo02Yoo`03001oogoo
00Aoo`03001oogoo071oo`00F7oo00<007ooOol03goo00<007ooOol03Goo00<007ooOol03Woo00<0
07ooOol06goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol06goo00<0
07ooOol03Woo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol06goo00<007ooOol01Woo00<0
07ooOol01Woo00<007ooOol01Woo00<007ooOol06goo00<007ooOol03Woo00<007ooOol03Goo00<0
07ooOol03Woo00<007ooOol06goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<0
07ooOol06goo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol03goo00<007ooOol0Xgoo00<0
07ooOol017oo00<007ooOol077oo00<007ooOol0j7oo00<007ooOol0:Woo00<007ooOol017oo00<0
07ooOol0L7oo001HOol00`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool00`00Oomoo`0I
Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0IOol00`00Oomoo`0?
Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool00`00Oomoo`0IOol00`00Oomoo`07Ool00`00Oomoo`06
Ool00`00Oomoo`07Ool00`00Oomoo`0IOol00`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0?
Ool00`00Oomoo`0IOol00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0I
Ool00`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool00`00Oomoo`2SOol00`00Oomoo`04
Ool00`00Oomoo`0LOol00`00Oomoo`3XOol00`00Oomoo`0ZOol00`00Oomoo`04Ool00`00Oomoo`1`
Ool005Qoo`<000moo`03001oogoo00eoo`03001oogoo011oo`03001oogoo01Ioo`8000Yoo`03001o
ogoo00Ioo`03001oogoo00Qoo`8001Qoo`03001oogoo011oo`03001oogoo00eoo`03001oogoo011o
o`8001Moo`8000Yoo`03001oogoo00Ioo`03001oogoo00Qoo`8001Moo`80019oo`03001oogoo00eo
o`03001oogoo011oo`03001oogoo01Ioo`8000Yoo`03001oogoo00Ioo`03001oogoo00Qoo`8001Qo
o`03001oogoo011oo`03001oogoo00eoo`03001oogoo00eoo`<00:Eoo`03001oogoo00Aoo`03001o
ogoo01aoo`03001oogoo0>Moo`03001oogoo02]oo`03001oogoo00Aoo`03001oogoo071oo`00F7oo
00<007ooOol03goo00<007ooOol03Goo00<007ooOol04Goo0P005Goo00<007ooOol02Woo00<007oo
Ool01Woo00<007ooOol02Woo0P0057oo0P004goo00<007ooOol03Goo00<007ooOol04Woo00<007oo
Ool04Woo0P0037oo00<007ooOol01Woo00<007ooOol02Woo0P0057oo00<007ooOol04Woo00<007oo
Ool03Goo00<007ooOol04Goo0P0057oo0P0037oo00<007ooOol01Woo00<007ooOol02Woo00<007oo
Ool04goo0P004goo00<007ooOol03Goo00<007ooOol03goo00<007ooOol0Xgoo00<007ooOol017oo
00<007ooOol077oo00<007ooOol0igoo00<007ooOol0:goo00<007ooOol017oo00<007ooOol0L7oo
001HOol00`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`0BOol2000@Ool3000=Ool00`00Oomo
o`06Ool00`00Oomoo`0<Ool3000>Ool3000DOol00`00Oomoo`0?Ool00`00Oomoo`0BOol2000AOol0
0`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool2000DOol00`00Oomo
o`0?Ool00`00Oomoo`0BOol3000>Ool3000>Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool3000@Ool2
000DOol00`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`2SOol00`00Oomoo`04Ool00`00Oomo
o`0MOol00`00Oomoo`3VOol00`00Oomoo`0[Ool00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03
001oogoo00ioo`03001oogoo00moo`03001oogoo01Aoo`@000Qoo`@000moo`03001oogoo00Qoo`03
001oogoo00ioo`<000Qoo`<001Moo`03001oogoo00moo`03001oogoo01Aoo`<000]oo`<000ioo`03
001oogoo00Qoo`03001oogoo00aoo`<000]oo`<001Ioo`03001oogoo00moo`03001oogoo01Eoo`<0
00Qoo`<0011oo`03001oogoo00Qoo`03001oogoo00eoo`D000Qoo`<001Ioo`03001oogoo00moo`03
001oogoo00ioo`03001oogoo0:=oo`03001oogoo00Aoo`03001oogoo01eoo`03001oogoo0>Ioo`03
001oogoo02]oo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<007ooOol03Goo00<007ooOol0
4Goo00<007ooOol05goo20004goo00<007ooOol027oo00<007ooOol04Goo20006Goo00<007ooOol0
4Goo00<007ooOol05Woo2`004Goo00<007ooOol027oo00<007ooOol03goo2`0067oo00<007ooOol0
4Goo00<007ooOol05goo20004goo00<007ooOol027oo00<007ooOol04Woo200067oo00<007ooOol0
4Goo00<007ooOol03Goo00<007ooOol0Xgoo00<007ooOol017oo00<007ooOol07Goo00<007ooOol0
iGoo00<007ooOol0;7oo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`0=Ool00`00
Oomoo`0AOol00`00Oomoo`0bOol00`00Oomoo`08Ool00`00Oomoo`0bOol00`00Oomoo`0AOol00`00
Oomoo`0bOol00`00Oomoo`08Ool00`00Oomoo`0bOol00`00Oomoo`0AOol00`00Oomoo`0bOol00`00
Oomoo`08Ool00`00Oomoo`0bOol00`00Oomoo`0AOol00`00Oomoo`0=Ool00`00Oomoo`2SOol00`00
Oomoo`04Ool00`00Oomoo`0NOol00`00Oomoo`3SOol00`00Oomoo`0]Ool00`00Oomoo`04Ool00`00
Oomoo`1`Ool005Qoo`03001oogoo00aoo`03001oogoo019oo`03001oogoo035oo`03001oogoo00Yo
o`03001oogoo035oo`03001oogoo019oo`03001oogoo031oo`03001oogoo00Yoo`03001oogoo031o
o`03001oogoo019oo`03001oogoo035oo`03001oogoo00Yoo`03001oogoo035oo`03001oogoo019o
o`03001oogoo00aoo`03001oogoo0:=oo`03001oogoo00Aoo`03001oogoo01moo`03001oogoo0>9o
o`03001oogoo02eoo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<007ooOol037oo00<007oo
Ool04goo00<007ooOol0<7oo00<007ooOol02Woo00<007ooOol0<Goo00<007ooOol04Woo00<007oo
Ool0<7oo00<007ooOol02Woo00<007ooOol0<7oo00<007ooOol04Woo00<007ooOol0<Goo00<007oo
Ool02Woo00<007ooOol0<7oo00<007ooOol04goo00<007ooOol037oo00<007ooOol0Xgoo00<007oo
Ool017oo00<007ooOol07goo00<007ooOol0hGoo00<007ooOol0;Woo00<007ooOol017oo00<007oo
Ool0L7oo001HOol00`00Oomoo`0<Ool00`00Oomoo`0COol00`00Oomoo`0`Ool00`00Oomoo`0:Ool0
0`00Oomoo`0`Ool00`00Oomoo`0COol00`00Oomoo`0`Ool00`00Oomoo`0:Ool00`00Oomoo`0`Ool0
0`00Oomoo`0COol00`00Oomoo`0`Ool00`00Oomoo`0:Ool00`00Oomoo`0`Ool00`00Oomoo`0COol0
0`00Oomoo`0<Ool00`00Oomoo`2SOol20005Ool00`00Oomoo`0POol00`00Oomoo`3POol00`00Oomo
o`0^Ool00`00Oomoo`03Ool2001bOol005Qoo`03001oogoo00]oo`03001oogoo01Eoo`03001oogoo
02ioo`03001oogoo00aoo`03001oogoo02ioo`03001oogoo01Eoo`03001oogoo02ioo`03001oogoo
00aoo`03001oogoo02ioo`03001oogoo01Eoo`03001oogoo02ioo`03001oogoo00aoo`03001oogoo
02ioo`03001oogoo01Eoo`03001oogoo00]oo`03001oogoo0:=oo`03001oogoo00Aoo`03001oogoo
025oo`03001oogoo0=ioo`03001oogoo02moo`03001oogoo00Aoo`03001oogoo071oo`00<7oo3000
2goo10003Goo00<007ooOol02goo00<007ooOol05Goo00<007ooOol0;Woo00<007ooOol037oo00<0
07ooOol0;Woo00<007ooOol05Goo00<007ooOol0;Woo00<007ooOol037oo00<007ooOol0;Woo00<0
07ooOol05Goo00<007ooOol0;Woo00<007ooOol037oo00<007ooOol0;Woo00<007ooOol05Goo00<0
07ooOol02goo00<007ooOol0Xgoo00<007ooOol017oo00<007ooOol08Goo00<007ooOol0gWoo00<0
07ooOol0;goo00<007ooOol017oo00<007ooOol0L7oo000`Ool<0009Ool8000;Ool00`00Oomoo`0:
Ool00`00Oomoo`0GOol00`00Oomoo`0/Ool00`00Oomoo`0>Ool00`00Oomoo`0/Ool00`00Oomoo`0F
Ool00`00Oomoo`0]Ool00`00Oomoo`0>Ool00`00Oomoo`0]Ool00`00Oomoo`0FOol00`00Oomoo`0/
Ool00`00Oomoo`0>Ool00`00Oomoo`0/Ool00`00Oomoo`0GOol00`00Oomoo`0:Ool00`00Oomoo`2S
Ool00`00Oomoo`04Ool00`00Oomoo`0ROol00`00Oomoo`3LOol00`00Oomoo`0`Ool00`00Oomoo`04
Ool00`00Oomoo`1`Ool0035oo`<000Ioo`8000Uoo`8000Aoo`8000]oo`03001oogoo00Yoo`03001o
ogoo01Moo`03001oogoo02]oo`03001oogoo011oo`03001oogoo02]oo`03001oogoo01Moo`03001o
ogoo02]oo`03001oogoo011oo`03001oogoo02]oo`03001oogoo01Moo`03001oogoo02]oo`03001o
ogoo011oo`03001oogoo02]oo`03001oogoo01Moo`03001oogoo00Yoo`03001oogoo0:=oo`03001o
ogoo00Aoo`03001oogoo029oo`03001oogoo0=aoo`03001oogoo031oo`03001oogoo00Aoo`03001o
ogoo071oo`00<Woo0`003goo0P001Woo0P002Woo00<007ooOol02Goo00<007ooOol06Goo00<007oo
Ool0:Goo00<007ooOol04Woo00<007ooOol0:Goo00<007ooOol06Goo00<007ooOol0:Goo00<007oo
Ool04Woo00<007ooOol0:Goo00<007ooOol06Goo00<007ooOol0:Goo00<007ooOol04Woo00<007oo
Ool0:Goo00<007ooOol06Goo00<007ooOol02Goo00<007ooOol0Xgoo00<007ooOol017oo00<007oo
Ool08Woo00<007ooOol0g7oo00<007ooOol0<7oo00<007ooOol017oo00<007ooOol0L7oo000cOol3
000>Ool20006Ool2000:Ool00`00Oomoo`09Ool00`00Oomoo`0IOol00`00Oomoo`0YOol00`00Oomo
o`0BOol00`00Oomoo`0XOol00`00Oomoo`0JOol00`00Oomoo`0YOol00`00Oomoo`0BOol00`00Oomo
o`0YOol00`00Oomoo`0JOol00`00Oomoo`0XOol00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomo
o`0IOol00`00Oomoo`09Ool00`00Oomoo`2SOol00`00Oomoo`04Ool00`00Oomoo`0SOol00`00Oomo
o`3JOol00`00Oomoo`0aOol00`00Oomoo`04Ool00`00Oomoo`1`Ool003Aoo`<000aoo`8000Qoo`80
00Uoo`03001oogoo00Qoo`03001oogoo01]oo`03001oogoo02Moo`03001oogoo01Aoo`03001oogoo
02Moo`03001oogoo01]oo`03001oogoo02Moo`03001oogoo01Aoo`03001oogoo02Moo`03001oogoo
01]oo`03001oogoo02Moo`03001oogoo01Aoo`03001oogoo02Moo`03001oogoo01]oo`03001oogoo
00Qoo`03001oogoo0:=oo`03001oogoo00Aoo`03001oogoo02=oo`03001oogoo0=Uoo`03001oogoo
039oo`03001oogoo00Aoo`03001oogoo071oo`00=Goo0`002goo0P0027oo0P002Goo00<007ooOol0
1goo00<007ooOol07Goo00<007ooOol09Goo00<007ooOol05Woo00<007ooOol09Goo00<007ooOol0
7Goo00<007ooOol09Woo00<007ooOol057oo00<007ooOol09Woo00<007ooOol07Goo00<007ooOol0
9Goo00<007ooOol05Woo00<007ooOol09Goo00<007ooOol07Goo00<007ooOol01goo00<007ooOol0
OGoo30002goo10002goo00<007ooOol017oo00<007ooOol097oo00<007ooOol0f7oo00<007ooOol0
<Woo00<007ooOol017oo00<007ooOol0L7oo000fOol3000:Ool20008Ool20009Ool40005Ool00`00
Oomoo`0OOol00`00Oomoo`0TOol00`00Oomoo`0FOol00`00Oomoo`0TOol00`00Oomoo`0OOol00`00
Oomoo`0TOol00`00Oomoo`0FOol00`00Oomoo`0TOol00`00Oomoo`0OOol00`00Oomoo`0TOol00`00
Oomoo`0FOol00`00Oomoo`0TOol00`00Oomoo`0OOol00`00Oomoo`03Ool4001oOol<0009Ool80009
Ool00`00Oomoo`04Ool00`00Oomoo`0TOol00`00Oomoo`3GOol00`00Oomoo`0cOol00`00Oomoo`04
Ool00`00Oomoo`1`Ool003Moo`<000Uoo`8000Qoo`8000Uoo`03001oogoo02Uoo`03001oogoo025o
o`8001Yoo`03001oogoo029oo`03001oogoo025oo`03001oogoo029oo`03001oogoo01Qoo`03001o
ogoo029oo`03001oogoo025oo`03001oogoo029oo`03001oogoo01Qoo`8002=oo`03001oogoo02Uo
o`03001oogoo07ioo`<000Ioo`8000Uoo`8000Aoo`8000Uoo`03001oogoo00Aoo`03001oogoo02Ao
o`03001oogoo0=Moo`03001oogoo03=oo`03001oogoo00Aoo`03001oogoo071oo`00>7oo0`0027oo
0P0027oo0P002Goo00<007ooOol0:Woo0P0087oo00<007ooOol06goo00<007ooOol07goo0P009Goo
00<007ooOol087oo00<007ooOol06Woo00<007ooOol087oo00<007ooOol08goo0P008Goo00<007oo
Ool06goo00<007ooOol07Woo0P00;7oo00<007ooOol0Ogoo0`003goo0P001Woo0P0027oo00<007oo
Ool017oo00<007ooOol09Goo00<007ooOol0eGoo00<007ooOol0=7oo00<007ooOol017oo00<007oo
Ool0L7oo000iOol20008Ool20008Ool20009Ool00`00Oomoo`0/Ool00`00Oomoo`0LOol00`00Oomo
o`0MOol00`00Oomoo`0MOol00`00Oomoo`0VOol00`00Oomoo`0MOol2000NOol2000OOol00`00Oomo
o`0VOol00`00Oomoo`0MOol00`00Oomoo`0MOol00`00Oomoo`0LOol00`00Oomoo`0/Ool00`00Oomo
o`20Ool3000>Ool20006Ool20008Ool00`00Oomoo`04Ool00`00Oomoo`0UOol00`00Oomoo`3DOol0
0`00Oomoo`0eOol00`00Oomoo`04Ool00`00Oomoo`1`Ool003Yoo`8000Moo`8000Qoo`8000Uoo`03
001oogoo02eoo`03001oogoo01Yoo`03001oogoo01moo`03001oogoo01]oo`03001oogoo02Qoo`80
01]oo`80029oo`8001]oo`8002Yoo`03001oogoo01]oo`03001oogoo01moo`03001oogoo01Yoo`03
001oogoo02eoo`03001oogoo085oo`<000aoo`8000Qoo`8000Moo`03001oogoo00Aoo`03001oogoo
02Ioo`03001oogoo0==oo`03001oogoo03Eoo`03001oogoo00Aoo`03001oogoo071oo`00>Woo0P00
1goo0P0027oo0P002Goo00<007ooOol0;Woo0P005goo0`008goo0`006Goo00<007ooOol0:goo0P00
67oo00<007ooOol097oo00<007ooOol05Woo0P00;Goo00<007ooOol05goo0`008goo0`005goo0P00
<7oo00<007ooOol0PWoo0`002goo0P0027oo0P001goo00<007ooOol017oo00<007ooOol09goo00<0
07ooOol0dGoo00<007ooOol0=Woo00<007ooOol017oo00<007ooOol0L7oo000aOol20007Ool20008
Ool20006Ool2000:Ool00`00Oomoo`0`Ool3000COol00`00Oomoo`0WOol2000EOol2000`Ool00`00
Oomoo`0COol2000XOol2000EOol00`00Oomoo`0^Ool2000EOol2000YOol00`00Oomoo`0AOol3000b
Ool00`00Oomoo`23Ool3000:Ool20008Ool20007Ool30004Ool00`00Oomoo`0XOol00`00Oomoo`3?
Ool00`00Oomoo`0gOol00`00Oomoo`02Ool3001bOol0035oo`<000Ioo`8000Qoo`8000Ioo`8000Yo
o`03001oogoo03=oo`8000ioo`<002aoo`<0011oo`8003=oo`<0011oo`8002aoo`80011oo`<003=o
o`80011oo`<002aoo`@000eoo`8003Eoo`03001oogoo08Aoo`<000Uoo`8000Qoo`8000Moo`03001o
ogoo00Aoo`03001oogoo02Qoo`03001oogoo0<moo`03001oogoo03Moo`03001oogoo00Aoo`03001o
ogoo071oo`00<Goo100017oo0P002Woo0P0017oo0P002goo00<007ooOol0=Goo0P001goo1@00<Woo
1@0027oo0`00>7oo1@0027oo0`00<7oo100027oo1000>7oo100027oo1000<goo10001goo0P00=goo
00<007ooOol0QGoo0`0027oo0P0027oo0P001goo00<007ooOol017oo00<007ooOol0:7oo00<007oo
Ool0cWoo00<007ooOol0>7oo00<007ooOol017oo00<007ooOol0L7oo000bOol8000;Ool8000;Ool0
0`00Oomoo`0gOol7000lOol80010Ool8000gOol80010Ool8000kOol7000iOol00`00Oomoo`26Ool2
0008Ool20008Ool20007Ool00`00Oomoo`04Ool00`00Oomoo`0YOol00`00Oomoo`3=Ool00`00Oomo
o`0hOol00`00Oomoo`04Ool00`00Oomoo`1`Ool003Aoo`D000ioo`@000eoo`03001oogoo0?mooleo
o`03001oogoo08Moo`8000Moo`8000Qoo`8000Moo`03001oogoo00Aoo`03001oogoo02Yoo`03001o
ogoo0<]oo`03001oogoo03Uoo`03001oogoo00Aoo`03001oogoo071oo`00F7oo00<007ooOol0ogoo
cGoo00<007ooOol0Qgoo0P001goo0P0027oo0P001goo00<007ooOol017oo00<007ooOol0:goo00<0
07ooOol0bGoo00<007ooOol0>Woo00<007ooOol017oo00<007ooOol0L7oo001HOol00`00Oomoo`3o
Ooo=Ool00`00Oomoo`1nOol20007Ool20008Ool20006Ool20008Ool00`00Oomoo`04Ool00`00Oomo
o`0/Ool00`00Oomoo`38Ool00`00Oomoo`0jOol00`00Oomoo`04Ool00`00Oomoo`1`Ool005Qoo`03
001oogoo0?mooleoo`03001oogoo07ioo`<000Ioo`8000Qoo`8000Ioo`8000Qoo`03001oogoo00Ao
o`03001oogoo02aoo`03001oogoo0<Moo`03001oogoo03]oo`03001oogoo00Aoo`03001oogoo071o
o`00F7oo00<007ooOol0ogoocGoo00<007ooOol0OWoo100017oo0P002Woo0P0017oo0P002Goo00<0
07ooOol017oo00<007ooOol0;Goo00<007ooOol0aWoo00<007ooOol0>Woo00<007ooOol01Goo00<0
07ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`1oOol8000;Ool80009Ool00`00Oomo
o`04Ool00`00Oomoo`0]Ool00`00Oomoo`35Ool00`00Oomoo`0kOol00`00Oomoo`05Ool00`00Oomo
o`1`Ool005Qoo`03001oogoo0?mooleoo`03001oogoo085oo`D000ioo`@000]oo`03001oogoo00Ao
o`03001oogoo02ioo`03001oogoo0<=oo`03001oogoo03aoo`03001oogoo00Eoo`03001oogoo071o
o`00F7oo0`00ogoobgoo0`00YGoo00<007ooOol017oo00<007ooOol0;goo00<007ooOol0`Woo00<0
07ooOol0?7oo00<007ooOol01Goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomo
o`2SOol00`00Oomoo`04Ool00`00Oomoo`0_Ool00`00Oomoo`31Ool00`00Oomoo`0mOol00`00Oomo
o`05Ool00`00Oomoo`1`Ool005Qoo`03001oogoo0?mooleoo`03001oogoo0:=oo`03001oogoo00Ao
o`03001oogoo031oo`03001oogoo0;moo`03001oogoo03ioo`03001oogoo00Eoo`03001oogoo071o
o`00F7oo00<007ooOol0ogoocGoo00<007ooOol0Xgoo00<007ooOol017oo00<007ooOol0<Goo00<0
07ooOol0_Goo00<007ooOol0?goo00<007ooOol01Goo00<007ooOol0L7oo001HOol00`00Oomoo`3o
Ooo=Ool00`00Oomoo`2SOol00`00Oomoo`04Ool00`00Oomoo`0bOol00`00Oomoo`2kOol00`00Oomo
o`10Ool00`00Oomoo`05Ool00`00Oomoo`1`Ool005Qoo`03001oogoo0?mooleoo`03001oogoo0:=o
o`8000Eoo`03001oogoo039oo`03001oogoo0;Yoo`03001oogoo045oo`03001oogoo00Aoo`80079o
o`00F7oo00<007ooOol0ogoocGoo00<007ooOol0Xgoo00<007ooOol017oo00<007ooOol0<goo00<0
07ooOol0^7oo00<007ooOol0@Woo00<007ooOol01Goo00<007ooOol0L7oo001HOol00`00Oomoo`3o
Ooo=Ool00`00Oomoo`2SOol00`00Oomoo`04Ool00`00Oomoo`0dOol00`00Oomoo`2fOol00`00Oomo
o`13Ool00`00Oomoo`05Ool00`00Oomoo`1`Ool005Qoo`03001oogoo0?mooleoo`03001oogoo0:=o
o`03001oogoo00Aoo`03001oogoo03Eoo`03001oogoo0;Aoo`03001oogoo04Aoo`03001oogoo00Eo
o`03001oogoo071oo`00F7oo00<007ooOol0ogoocGoo00<007ooOol0Xgoo00<007ooOol017oo00<0
07ooOol0=Goo00<007ooOol0]7oo00<007ooOol0A7oo00<007ooOol01Goo00<007ooOol0L7oo001H
Ool00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`04Ool00`00Oomoo`0fOol00`00Oomo
o`2bOol00`00Oomoo`15Ool00`00Oomoo`05Ool00`00Oomoo`1`Ool005Qoo`03001oogoo0?mooleo
o`03001oogoo0:=oo`03001oogoo00Eoo`03001oogoo03Ioo`03001oogoo0;1oo`03001oogoo04Io
o`03001oogoo00Eoo`03001oogoo071oo`00F7oo00<007ooOol0ogoocGoo00<007ooOol0Xgoo00<0
07ooOol01Goo00<007ooOol0=goo00<007ooOol0[Woo00<007ooOol0Agoo00<007ooOol01Goo00<0
07ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`05Ool00`00Oomo
o`0hOol00`00Oomoo`2/Ool00`00Oomoo`18Ool00`00Oomoo`05Ool00`00Oomoo`1`Ool005Qoo`03
001oogoo0?mooleoo`03001oogoo0:=oo`03001oogoo00Eoo`03001oogoo03Uoo`03001oogoo0:Yo
o`03001oogoo04Uoo`03001oogoo00Eoo`03001oogoo071oo`00F7oo00<007ooOol0ogoocGoo00<0
07ooOol0Xgoo00<007ooOol01Goo00<007ooOol0>Woo00<007ooOol0Z7oo00<007ooOol0BWoo00<0
07ooOol01Goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomo
o`05Ool00`00Oomoo`0kOol00`00Oomoo`2VOol00`00Oomoo`1;Ool00`00Oomoo`05Ool00`00Oomo
o`1`Ool005Qoo`<00?mool]oo`<00:Eoo`03001oogoo00Eoo`03001oogoo03aoo`03001oogoo0:Ao
o`03001oogoo04aoo`03001oogoo00Eoo`03001oogoo071oo`00F7oo00<007ooOol0ogoocGoo00<0
07ooOol0Xgoo00<007ooOol01Goo00<007ooOol0?Goo0P00Xgoo00<007ooOol0CGoo00<007ooOol0
1Goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`05Ool0
0`00Oomoo`0oOol00`00Oomoo`2OOol00`00Oomoo`1>Ool00`00Oomoo`05Ool00`00Oomoo`1`Ool0
05Qoo`03001oogoo0?mooleoo`03001oogoo0:=oo`03001oogoo00Eoo`03001oogoo041oo`03001o
ogoo09eoo`03001oogoo04moo`03001oogoo00Eoo`03001oogoo071oo`00F7oo00<007ooOol0ogoo
cGoo00<007ooOol0Xgoo0P001Woo00<007ooOol0@Goo00<007ooOol0Vgoo00<007ooOol0D7oo00<0
07ooOol017oo0P00LWoo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`05Ool0
0`00Oomoo`11Ool00`00Oomoo`2JOol00`00Oomoo`1AOol00`00Oomoo`05Ool00`00Oomoo`1`Ool0
05Qoo`03001oogoo0?mooleoo`03001oogoo0:=oo`03001oogoo00Eoo`03001oogoo049oo`8009Uo
o`03001oogoo059oo`03001oogoo00Eoo`03001oogoo071oo`00F7oo00<007ooOol0ogoocGoo00<0
07ooOol0Xgoo00<007ooOol01Goo00<007ooOol0A7oo00<007ooOol0U7oo0P00EGoo00<007ooOol0
1Goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`05Ool0
0`00Oomoo`15Ool00`00Oomoo`2AOol2001GOol00`00Oomoo`05Ool00`00Oomoo`1`Ool005Qoo`03
001oogoo0?mooleoo`03001oogoo0:=oo`03001oogoo00Eoo`03001oogoo04Ioo`03001oogoo08mo
o`03001oogoo05Moo`03001oogoo00Eoo`03001oogoo071oo`00F7oo00<007ooOol0ogoocGoo00<0
07ooOol0Xgoo00<007ooOol01Goo00<007ooOol0Agoo0P00SWoo00<007ooOol0F7oo00<007ooOol0
1Goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`05Ool0
0`00Oomoo`19Ool00`00Oomoo`2:Ool00`00Oomoo`1IOol00`00Oomoo`05Ool00`00Oomoo`1`Ool0
05Qoo`03001oogoo0?mooleoo`03001oogoo0:=oo`03001oogoo00Eoo`03001oogoo04Yoo`8008Qo
o`8005aoo`03001oogoo00Eoo`03001oogoo071oo`00F7oo00<007ooOol0ogoocGoo00<007ooOol0
Xgoo00<007ooOol01Goo00<007ooOol0C7oo00<007ooOol0Q7oo00<007ooOol0G7oo00<007ooOol0
1Goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`05Ool0
0`00Oomoo`1=Ool20022Ool2001OOol00`00Oomoo`05Ool00`00Oomoo`1`Ool005Qoo`03001oogoo
0?mooleoo`03001oogoo0:=oo`03001oogoo00Eoo`03001oogoo04moo`03001oogoo07ioo`03001o
ogoo05moo`03001oogoo00Eoo`03001oogoo071oo`00F7oo00<007ooOol0ogoocGoo00<007ooOol0
Xgoo00<007ooOol01Goo00<007ooOol0D7oo0P00O7oo0P00HWoo00<007ooOol01Goo00<007ooOol0
L7oo001HOol3003oOoo;Ool3002UOol00`00Oomoo`05Ool00`00Oomoo`1BOol2001gOol3001TOol0
0`00Oomoo`05Ool00`00Oomoo`1`Ool005Qoo`03001oogoo0?mooleoo`03001oogoo0:=oo`03001o
ogoo00Eoo`03001oogoo05Aoo`8007Aoo`03001oogoo06Eoo`03001oogoo00Eoo`03001oogoo071o
o`00F7oo00<007ooOol0ogoocGoo00<007ooOol0Xgoo0P001Woo00<007ooOol0EWoo00<007ooOol0
Kgoo0P00J7oo00<007ooOol017oo0P00LWoo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol0
0`00Oomoo`05Ool00`00Oomoo`1GOol3001/Ool2001ZOol00`00Oomoo`05Ool00`00Oomoo`1`Ool0
05Qoo`03001oogoo0?mooleoo`03001oogoo0:=oo`03001oogoo00Eoo`03001oogoo05Yoo`8006Qo
o`8006aoo`03001oogoo00Eoo`03001oogoo071oo`00F7oo00<007ooOol0ogoocGoo00<007ooOol0
Xgoo00<007ooOol01Goo00<007ooOol0G7oo00<007ooOol0HWoo0`00KWoo00<007ooOol01Goo00<0
07ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomoo`05Ool00`00Oomo
o`1MOol3001POol00`00Oomoo`1_Ool00`00Oomoo`05Ool00`00Oomoo`1`Ool005Qoo`03001oogoo
0?mooleoo`03001oogoo0:=oo`03001oogoo00Eoo`03001oogoo061oo`8005aoo`80079oo`03001o
ogoo00Eoo`03001oogoo071oo`00F7oo00<007ooOol0=Goo3@00<goo3P00?7oo3@00<goo3000?7oo
3P00<goo3@00=goo00<007ooOol0Xgoo00<007ooOol01Goo00<007ooOol0HWoo1000EGoo0`00M7oo
00<007ooOol01Goo00<007ooOol0L7oo001HOol00`00Oomoo`0bOol3000=Ool3000^Ool2000>Ool3
000fOol3000=Ool2000^Ool3000<Ool3000fOol3000>Ool2000^Ool3000=Ool3000dOol00`00Oomo
o`2SOol00`00Oomoo`05Ool00`00Oomoo`1VOol4001>Ool3001gOol00`00Oomoo`05Ool00`00Oomo
o`1`Ool003Ioo`L000Yoo`@000eoo`03001oogoo031oo`8001=oo`8002Yoo`8001=oo`80035oo`<0
019oo`8002Yoo`80019oo`<0035oo`8001=oo`8002Yoo`8001=oo`80039oo`03001oogoo0:=oo`03
001oogoo00Eoo`03001oogoo06Yoo`<004Moo`@007Yoo`03001oogoo00Eoo`03001oogoo071oo`00
=Woo1`0027oo20002goo00<007ooOol0;goo00<007ooOol05Goo0P009Goo0`005goo0P00;Goo0P00
5goo0P009Woo0P005goo0P00;Goo0P005goo0`009Goo0P005goo00<007ooOol0;goo00<007ooOol0
Xgoo00<007ooOol01Goo00<007ooOol0KGoo0`00@Goo0`00OGoo00<007ooOol01Woo00<007ooOol0
L7oo000iOol2000:Ool20004Ool2000;Ool00`00Oomoo`0]Ool2000JOol00`00Oomoo`0QOol00`00
Oomoo`0JOol00`00Oomoo`0YOol00`00Oomoo`0IOol00`00Oomoo`0QOol2000KOol00`00Oomoo`0Y
Ool00`00Oomoo`0JOol00`00Oomoo`0QOol00`00Oomoo`0HOol2000_Ool00`00Oomoo`2SOol00`00
Oomoo`05Ool00`00Oomoo`1`Ool3000jOol40020Ool00`00Oomoo`06Ool00`00Oomoo`1`Ool003Uo
o`8000Uoo`8000Ioo`8000Yoo`03001oogoo02aoo`03001oogoo01]oo`80021oo`03001oogoo01ao
o`03001oogoo02Moo`03001oogoo01]oo`80021oo`03001oogoo01aoo`03001oogoo02Moo`03001o
ogoo01]oo`80021oo`8001eoo`03001oogoo02aoo`03001oogoo0:=oo`03001oogoo00Eoo`03001o
ogoo07=oo`<0039oo`D008Aoo`03001oogoo00Ioo`03001oogoo071oo`00>Goo0P002Goo0P001Woo
0P002Woo00<007ooOol0:goo00<007ooOol07Woo00<007ooOol077oo00<007ooOol07Woo00<007oo
Ool09Goo00<007ooOol07Woo00<007ooOol077oo00<007ooOol07Woo00<007ooOol09Goo00<007oo
Ool07Woo00<007ooOol077oo00<007ooOol07Woo00<007ooOol0:goo00<007ooOol0Xgoo00<007oo
Ool01Goo00<007ooOol0MWoo1`0097oo1`00RGoo00<007ooOol01Woo00<007ooOol0L7oo000aOol<
0006Ool20008Ool20009Ool00`00Oomoo`0YOol2000ROol00`00Oomoo`0JOol00`00Oomoo`0POol0
0`00Oomoo`0SOol00`00Oomoo`0POol00`00Oomoo`0JOol00`00Oomoo`0POol00`00Oomoo`0ROol2
000ROol00`00Oomoo`0JOol00`00Oomoo`0POol2000[Ool00`00Oomoo`2SOol00`00Oomoo`05Ool0
0`00Oomoo`1mOol9000BOol9002@Ool00`00Oomoo`06Ool00`00Oomoo`1`Ool0035oo``000Ioo`80
00Qoo`8000Uoo`03001oogoo02Qoo`03001oogoo02=oo`03001oogoo01Qoo`03001oogoo029oo`03
001oogoo025oo`03001oogoo029oo`03001oogoo01Qoo`03001oogoo029oo`03001oogoo021oo`03
001oogoo02=oo`03001oogoo01Qoo`03001oogoo02=oo`03001oogoo02Qoo`03001oogoo0:=oo`03
001oogoo00Eoo`03001oogoo08Iooa8009Uoo`03001oogoo00Ioo`03001oogoo071oo`00<Goo0P00
1Woo0P0000=oo`00Ool01Goo0P0027oo0P002Goo10001Goo00<007ooOol07Woo00<007ooOol09Goo
00<007ooOol05Woo00<007ooOol097oo00<007ooOol07Woo0P009Woo00<007ooOol05Woo00<007oo
Ool097oo0P007goo00<007ooOol09Goo00<007ooOol05Woo00<007ooOol09Goo00<007ooOol07Woo
00<007ooOol00goo1000YGoo00<007ooOol01Goo00<007ooOol0ogoo<Woo00<007ooOol01Woo00<0
07ooOol0L7oo000bOol20005Ool20008Ool20008Ool20009Ool00`00Oomoo`06Ool00`00Oomoo`0N
Ool00`00Oomoo`0UOol00`00Oomoo`0FOol00`00Oomoo`0TOol00`00Oomoo`0NOol00`00Oomoo`0U
Ool00`00Oomoo`0FOol00`00Oomoo`0UOol00`00Oomoo`0MOol00`00Oomoo`0UOol00`00Oomoo`0F
Ool00`00Oomoo`0UOol00`00Oomoo`0NOol00`00Oomoo`06Ool00`00Oomoo`2SOol20006Ool00`00
Oomoo`3oOolbOol00`00Oomoo`05Ool2001bOol0039oo`<000Aoo`8000Qoo`8000Qoo`8000Uoo`03
001oogoo00Moo`03001oogoo01aoo`03001oogoo02Moo`03001oogoo01Aoo`03001oogoo02Ioo`03
001oogoo01aoo`03001oogoo02Moo`03001oogoo01Aoo`03001oogoo02Moo`03001oogoo01]oo`03
001oogoo02Moo`03001oogoo01Aoo`03001oogoo02Moo`03001oogoo01aoo`03001oogoo00Moo`03
001oogoo0:=oo`03001oogoo00Eoo`03001oogoo0?mooc9oo`03001oogoo00Ioo`03001oogoo071o
o`00<goo0P0017oo0P0027oo0P0027oo0P002Goo00<007ooOol027oo00<007ooOol06Woo00<007oo
Ool0:Goo00<007ooOol04Woo00<007ooOol0:7oo00<007ooOol06Woo00<007ooOol0:7oo00<007oo
Ool057oo00<007ooOol0:7oo00<007ooOol06Woo00<007ooOol0:7oo00<007ooOol04Woo00<007oo
Ool0:Goo00<007ooOol06Woo00<007ooOol027oo00<007ooOol0Xgoo00<007ooOol01Woo00<007oo
Ool0ogoo<Goo00<007ooOol01Woo00<007ooOol0L7oo000dOol20003Ool20008Ool20008Ool20009
Ool00`00Oomoo`09Ool00`00Oomoo`0IOol00`00Oomoo`0YOol00`00Oomoo`0BOol00`00Oomoo`0Y
Ool00`00Oomoo`0IOol00`00Oomoo`0YOol00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`0I
Ool00`00Oomoo`0YOol00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`0IOol00`00Oomoo`09
Ool00`00Oomoo`2SOol00`00Oomoo`06Ool00`00Oomoo`3oOolaOol00`00Oomoo`06Ool00`00Oomo
o`1`Ool003Aoo`<0009oo`8000Qoo`8000Qoo`8000Uoo`03001oogoo00Yoo`03001oogoo01Moo`03
001oogoo02]oo`03001oogoo011oo`03001oogoo02]oo`03001oogoo01Moo`03001oogoo02]oo`03
001oogoo011oo`03001oogoo02]oo`03001oogoo01Moo`03001oogoo02]oo`03001oogoo011oo`03
001oogoo02]oo`03001oogoo01Moo`03001oogoo00Yoo`03001oogoo0:=oo`03001oogoo00Ioo`03
001oogoo0?mooc5oo`03001oogoo00Ioo`03001oogoo071oo`00=Goo0P000Woo0P002Goo0P001Woo
0P002Woo00<007ooOol02Woo00<007ooOol05goo00<007ooOol0:goo00<007ooOol03goo00<007oo
Ool0;7oo00<007ooOol05goo00<007ooOol0:goo00<007ooOol047oo00<007ooOol0:goo00<007oo
Ool05goo00<007ooOol0;7oo00<007ooOol03goo00<007ooOol0:goo00<007ooOol05goo00<007oo
Ool02Woo00<007ooOol0Xgoo00<007ooOol01Woo00<007ooOol0ogoo<Goo00<007ooOol01Woo00<0
07ooOol0L7oo000fOol200000goo00000009Ool20006Ool2000:Ool00`00Oomoo`0:Ool00`00Oomo
o`0FOol00`00Oomoo`0]Ool00`00Oomoo`0>Ool00`00Oomoo`0]Ool00`00Oomoo`0EOol00`00Oomo
o`0]Ool00`00Oomoo`0>Ool00`00Oomoo`0]Ool00`00Oomoo`0EOol00`00Oomoo`0]Ool00`00Oomo
o`0>Ool00`00Oomoo`0]Ool00`00Oomoo`0FOol00`00Oomoo`0:Ool00`00Oomoo`2SOol00`00Oomo
o`06Ool00`00Oomoo`3oOolaOol00`00Oomoo`06Ool00`00Oomoo`1`Ool003Moo`@000Yoo`8000Ao
o`8000]oo`03001oogoo00]oo`03001oogoo01Eoo`03001oogoo02eoo`03001oogoo00eoo`03001o
ogoo02ioo`03001oogoo01Eoo`03001oogoo02eoo`03001oogoo00ioo`03001oogoo02eoo`03001o
ogoo01Eoo`03001oogoo02ioo`03001oogoo00eoo`03001oogoo02eoo`03001oogoo01Eoo`03001o
ogoo00]oo`03001oogoo0:=oo`03001oogoo00Ioo`03001oogoo0?mooc5oo`03001oogoo00Ioo`03
001oogoo071oo`00=goo10002Woo20002goo00<007ooOol037oo00<007ooOol04goo00<007ooOol0
;goo00<007ooOol037oo00<007ooOol0;goo00<007ooOol04goo00<007ooOol0;goo00<007ooOol0
37oo00<007ooOol0;goo00<007ooOol04goo00<007ooOol0;goo00<007ooOol037oo00<007ooOol0
;goo00<007ooOol04goo00<007ooOol037oo00<007ooOol0Xgoo00<007ooOol01Woo00<007ooOol0
ogoo<Goo00<007ooOol01Woo00<007ooOol0L7oo000hOol3000<Ool4000=Ool00`00Oomoo`0<Ool0
0`00Oomoo`0COol00`00Oomoo`0_Ool00`00Oomoo`0<Ool00`00Oomoo`0_Ool00`00Oomoo`0COol0
0`00Oomoo`0`Ool00`00Oomoo`0:Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00Oomoo`0_Ool0
0`00Oomoo`0<Ool00`00Oomoo`0_Ool00`00Oomoo`0COol00`00Oomoo`0<Ool00`00Oomoo`1mOol<
0009Ool6000;Ool00`00Oomoo`06Ool00`00Oomoo`3oOolaOol00`00Oomoo`06Ool00`00Oomoo`1`
Ool005Qoo`03001oogoo00eoo`03001oogoo015oo`03001oogoo035oo`03001oogoo00Yoo`03001o
ogoo035oo`03001oogoo015oo`03001oogoo035oo`03001oogoo00Yoo`03001oogoo035oo`03001o
ogoo015oo`03001oogoo035oo`03001oogoo00Yoo`03001oogoo035oo`03001oogoo015oo`03001o
ogoo00eoo`03001oogoo07eoo``000Moo`X000Uoo`03001oogoo00Ioo`03001oogoo0?mooc5oo`03
001oogoo00Ioo`03001oogoo071oo`00F7oo00<007ooOol03Goo00<007ooOol04Goo00<007ooOol0
<Goo00<007ooOol02Woo00<007ooOol0<Goo00<007ooOol04Goo00<007ooOol067oo1P004goo00<0
07ooOol02Woo00<007ooOol04Woo1@006Woo00<007ooOol04Goo00<007ooOol0<Goo00<007ooOol0
2Woo00<007ooOol0<Goo00<007ooOol04Goo00<007ooOol03Goo00<007ooOol0OWoo0`001Woo0P00
1goo0`001Goo0`0027oo00<007ooOol01Woo00<007ooOol0ogoo<Goo00<007ooOol01Woo00<007oo
Ool0L7oo001HOol00`00Oomoo`0=Ool00`00Oomoo`0AOol00`00Oomoo`0FOol=000>Ool00`00Oomo
o`0:Ool00`00Oomoo`0<Ool=000IOol00`00Oomoo`0@Ool00`00Oomoo`0EOol30006Ool4000@Ool0
0`00Oomoo`08Ool00`00Oomoo`0?Ool40005Ool4000FOol00`00Oomoo`0@Ool00`00Oomoo`0GOol<
000?Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool>000GOol00`00Oomoo`0AOol00`00Oomoo`0=Ool0
0`00Oomoo`1oOol3000GOol20008Ool00`00Oomoo`06Ool00`00Oomoo`3oOolaOol00`00Oomoo`06
Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00ioo`03001oogoo00moo`03001oogoo01=oo`@000eo
o`8000eoo`03001oogoo00Qoo`03001oogoo00]oo`8000eoo`@001Eoo`03001oogoo00moo`03001o
ogoo01=oo`<000eoo`<000eoo`03001oogoo00Qoo`03001oogoo00]oo`@000eoo`8001Eoo`03001o
ogoo00moo`03001oogoo01=oo`@000aoo`8000ioo`03001oogoo00Qoo`03001oogoo00]oo`8000io
o`<001Eoo`03001oogoo00moo`03001oogoo00ioo`03001oogoo081oo`<001Moo`8000Moo`03001o
ogoo00Ioo`03001oogoo0?mooc5oo`03001oogoo00Ioo`03001oogoo071oo`00F7oo00<007ooOol0
3Woo00<007ooOol03goo00<007ooOol04Goo0P004goo0P002goo00<007ooOol027oo00<007ooOol0
2Woo00<007ooOol04Goo0P004goo00<007ooOol03goo00<007ooOol04Goo0P004goo0P002goo00<0
07ooOol027oo00<007ooOol02Goo0P004goo0P004goo00<007ooOol03goo00<007ooOol04Goo0P00
4Woo0P0037oo00<007ooOol027oo00<007ooOol02Goo0P004goo0P004goo00<007ooOol03goo00<0
07ooOol03Woo00<007ooOol0PGoo0`005Woo0P001goo00<007ooOol01Woo00<007ooOol0ogoo<Goo
00<007ooOol01Woo00<007ooOol0L7oo001HOol00`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomo
o`0?Ool2000GOol00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`08Ool2000FOol2000AOol0
0`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0EOol00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`0EOol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool2
000FOol2000:Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`0EOol2000AOol00`00Oomo
o`0?Ool00`00Oomoo`0>Ool00`00Oomoo`22Ool3000EOol20007Ool00`00Oomoo`06Ool00`00Oomo
o`3oOolaOol00`00Oomoo`06Ool00`00Oomoo`1`Ool005Qoo`<000moo`03001oogoo00eoo`03001o
ogoo00moo`03001oogoo01Qoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Moo`8001Yo
o`03001oogoo00moo`03001oogoo00eoo`03001oogoo011oo`03001oogoo01Moo`8000Uoo`03001o
ogoo00Ioo`03001oogoo00Moo`8001Uoo`03001oogoo011oo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo01Qoo`8000Uoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo01Qoo`03001o
ogoo00moo`03001oogoo00eoo`03001oogoo00eoo`<008Eoo`<001Aoo`8000Moo`<000Ioo`03001o
ogoo0?mooc1oo`03001oogoo00Eoo`<0079oo`00F7oo00<007ooOol03goo00<007ooOol03Goo00<0
07ooOol03Woo00<007ooOol06Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Woo00<0
07ooOol06goo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol03Woo0P0077oo00<007ooOol0
1Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol06Woo0P0047oo00<007ooOol03Goo00<0
07ooOol03Woo00<007ooOol06goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01goo00<0
07ooOol06Woo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol03goo00<007ooOol0Q7oo0`00
4goo0P001goo00<007ooOol01Woo00<007ooOol0ogoo<7oo00<007ooOol01goo00<007ooOol0L7oo
001HOol00`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0LOol00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0KOol00`00Oomoo`0>Ool00`00Oomo
o`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0LOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`0LOol00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomo
o`0KOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0LOol00`00Oomo
o`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool00`00Oomoo`25Ool3000AOol20008Ool00`00Oomo
o`06Ool00`00Oomoo`3oOol`Ool00`00Oomoo`07Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00aoo`03001oogoo01eoo`03001oogoo00Ioo`03001oogoo00Io
o`03001oogoo00Eoo`03001oogoo01eoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00ao
o`03001oogoo01ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo01io
o`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo01eoo`03001oogoo00Eo
o`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo01eoo`03001oogoo00aoo`03001oogoo00eo
o`03001oogoo00moo`03001oogoo08Ioo`8000Uoo`8000Eoo`<000Qoo`03001oogoo00Ioo`03001o
ogoo0?mooc1oo`03001oogoo00Moo`03001oogoo071oo`00F7oo00<007ooOol047oo00<007ooOol0
2goo00<007ooOol03Goo00<007ooOol07Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol07goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol02goo00<007ooOol0
87oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol087oo00<007ooOol0
2goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol07goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Woo00<007ooOol07Woo00<007ooOol03Goo00<007ooOol02goo00<007ooOol0
47oo00<007ooOol0Qgoo0P0027oo2@002Goo00<007ooOol01Woo00<007ooOol0ogoo<7oo00<007oo
Ool01goo00<007ooOol0L7oo001HOol00`00Oomoo`0@Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool0
0`00Oomoo`0POol00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0QOol0
0`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0QOol00`00Oomoo`05Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0ROol00`00Oomoo`0;Ool00`00Oomoo`0;Ool0
0`00Oomoo`0<Ool00`00Oomoo`0QOol00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`05Ool0
0`00Oomoo`0POol00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`27Ool2
0008Ool200000goo00000003000:Ool00`00Oomoo`06Ool00`00Oomoo`3oOol`Ool00`00Oomoo`07
Ool00`00Oomoo`1`Ool005Qoo`03001oogoo011oo`03001oogoo00]oo`03001oogoo00]oo`03001o
ogoo00moo`X000Uoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Uo
o``000ioo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00eoo`/000Yo
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Yoo`X000moo`03001o
ogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00aoo``000]oo`03001oogoo00=o
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Moo`/0011oo`03001oogoo00]oo`03001o
ogoo00]oo`03001oogoo011oo`03001oogoo07ioo`8000Moo`8000Qoo`80011oo`03001oogoo00Io
o`03001oogoo0?mooc1oo`03001oogoo00Moo`03001oogoo071oo`00F7oo00<007ooOol047oo00<0
07ooOol02goo00<007ooOol02goo00<007ooOol037oo0`002Woo0`001goo00<007ooOol00goo00<0
07ooOol017oo00<007ooOol00goo00<007ooOol01Woo0`0037oo0P0037oo00<007ooOol02goo00<0
07ooOol02goo00<007ooOol02goo00<007ooOol02Woo0`002goo0P0027oo00<007ooOol017oo00<0
07ooOol017oo00<007ooOol00goo00<007ooOol01goo0`002Woo0`0037oo00<007ooOol02goo00<0
07ooOol02goo00<007ooOol02goo00<007ooOol02Woo0P0037oo0`0027oo00<007ooOol00goo00<0
07ooOol017oo00<007ooOol00goo00<007ooOol01Goo0`002goo0P003Woo00<007ooOol02goo00<0
07ooOol02goo00<007ooOol047oo00<007ooOol0OWoo0`001Woo0P0027oo0P0047oo00<007ooOol0
1Woo00<007ooOol0ogoo<7oo00<007ooOol01goo00<007ooOol0L7oo001HOol00`00Oomoo`0@Ool0
0`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool3000@Ool20005Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`05Ool2000AOol2000;Ool00`00Oomoo`0:Ool0
0`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool2000@Ool30006Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`05Ool3000@Ool2000;Ool00`00Oomoo`0:Ool0
0`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool2000AOol20007Ool00`00Oomoo`02Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool2000@Ool3000<Ool00`00Oomoo`0:Ool0
0`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`1nOol40004Ool20009Ool2000@Ool00`00Oomo
o`06Ool00`00Oomoo`3oOol`Ool00`00Oomoo`07Ool00`00Oomoo`1`Ool005Qoo`03001oogoo015o
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`8001Eoo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`8001Eoo`03001oogoo00Uo
o`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo01=o
o`8000Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`8001Eo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo01=oo`8000Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo01=oo`8000]oo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo015o
o`03001oogoo07moo`P000Yoo`X000Qoo`03001oogoo00Ioo`03001oogoo0?mooc1oo`03001oogoo
00Moo`03001oogoo071oo`00F7oo00<007ooOol04Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol05Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol05Woo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol05Woo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol05Woo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol05Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol05Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol04Goo00<007ooOol0PGoo1@002goo2P0027oo00<007ooOol01goo00<007ooOol0ogoo;goo
00<007ooOol01goo00<007ooOol0L7oo001HOol00`00Oomoo`0AOol00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`08Ool00`00Oomoo`0GOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0GOol00`00Oomoo`08Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0FOol00`00Oomo
o`04Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Ioo`03001oogoo01Ioo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo01Mo
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo01Moo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo015o
o`03001oogoo0:=oo`03001oogoo00Moo`03001oogoo0?moobmoo`03001oogoo00Moo`03001oogoo
071oo`00F7oo00<007ooOol04Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol02Goo2@001goo00<007ooOol00goo00D007ooOomoo`0000Aoo`05001oogooOol00005Ool0
0`00Oomoo`05Ool8000<Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool80006Ool00`00Oomoo`03Ool01@00Oomoogoo0000
17oo00D007ooOomoo`0000Eoo`03001oogoo00Aoo`T000]oo`03001oogoo00Qoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Yoo`T000Ioo`03001o
ogoo00=oo`05001oogooOol00004Ool01@00Oomoogoo00001Goo00<007ooOol01Goo2@002goo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol04Goo00<007ooOol0Xgoo00<0
07ooOol01goo00<007ooOol0ogoo;goo00<007ooOol01goo00<007ooOol0L7oo001HOol00`00Oomo
o`06Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool20009Ool30005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007oo
Ool00Woo00<007ooOol00Woo100027oo0`002Goo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo100027oo0`0017oo00<007oo
Ool00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`02Ool30009Ool30009
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`07Ool30009Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`00
17oo00<007ooOol00Woo00<007ooOol00goo0`002Goo0P002Goo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol0Xgoo00<007ooOol0
1goo00<007ooOol0ogoo;goo00<007ooOol01goo00<007ooOol0L7oo001HOol00`00Oomoo`06Ool0
0`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool2
000>Ool30003Ool01@00Oomoogoo000017oo00@007ooOol000Aoo`05001oogooOol00003Ool2000?
Ool20008Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00
Oomoo`07Ool00`00Oomoo`06Ool2000?Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo
00000Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo00eoo`8000Qoo`03001oogoo
00Moo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo
00Ioo`8000moo`8000=oo`05001oogooOol00004Ool01000Oomoo`0017oo00D007ooOomoo`0000=o
o`<000ioo`8000Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qo
o`03001oogoo00Ioo`03001oogoo0:=oo`03001oogoo00Moo`03001oogoo0?moobmoo`03001oogoo
00Moo`03001oogoo071oo`00F7oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol02Goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01Goo0P004goo00D007ooOomoo`0000=oo`05001o
ogooOol00002Ool01@00Oomoogoo00000goo00D007ooOomoo`0001=oo`03001oogoo00Ioo`03001o
ogoo00Ioo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Ioo`03001oogoo011oo`03001oogoo009oo`05001oogooOol00003Ool01000Oomoo`000goo
00D007ooOomoo`0000Aoo`03001oogoo011oo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo
00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo
015oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000=oo`05001oogoo
Ool0000COol20007Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`08
Ool00`00Oomoo`06Ool00`00Oomoo`2SOol20008Ool00`00Oomoo`3oOol^Ool00`00Oomoo`07Ool2
001bOol005Qoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Qoo`D000Moo`04001oogoo0003Ool01@00Oomo
ogoo00000Woo00D007ooOomoo`00009oo`04001oogooOol20006Ool50009Ool00`00Oomoo`05Ool0
0`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`05Ool00`00Oomoo`0BOol01@00Oomoogoo00000goo00D007ooOomoo`00009oo`05001o
ogooOol00003Ool01@00Oomoogoo000057oo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol0
27oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol0
1goo1P001Goo0P000goo00@007ooOol000=oo`04001oogoo0003Ool01@00Oomoogoo00000Woo00<0
07ooOol01Goo1P002Goo00<007ooOol017oo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
2Goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol0Xgoo00<007ooOol01goo00<007ooOol0
ogoo;Woo00<007ooOol027oo00<007ooOol0L7oo001HOol30007Ool00`00Oomoo`07Ool00`00Oomo
o`09Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool40005Ool3
0005Ool01000Oomoo`000goo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoo`0017oo1000
1Goo0`001goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol02Goo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo2P0017oo00D007ooOomo
o`0000=oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000Eoo`X000Moo`03001o
ogoo00Eoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Moo`03001o
ogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`<000Ioo`<000Aoo`04001oogoo0003Ool01000
Oomoo`000Woo00@007ooOol000=oo`04001oogoo0005Ool30006Ool30007Ool00`00Oomoo`04Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`05Ool3
002UOol00`00Oomoo`07Ool00`00Oomoo`3oOol^Ool00`00Oomoo`08Ool00`00Oomoo`1`Ool005Qo
o`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Aoo`03001oogoo00=oo`8000aoo`<000=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0003Ool2000<Ool30005Ool00`00Oomoo`04Ool00`00Oomo
o`06Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`04Ool00`00Oomoo`03Ool4000:Ool400000goo00000002Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0002Ool20002Ool4000:Ool30005Ool00`00Oomoo`04Ool00`00Oomoo`06Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool3000<Ool20003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`000goo0`0037oo0P001Goo00<007ooOol017oo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol0Xgoo00<007ooOol0
1goo00<007ooOol0ogoo;Woo00<007ooOol027oo00<007ooOol0L7oo001HOol00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`0?Ool01@00Oomoogoo00000Woo00H007ooOol007oo0002Ool00`00
Ool00002Ool01000Oomoo`000goo00<007ooOol03goo00<007ooOol00goo00<007ooOol017oo00<0
07ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol017oo00<007ooOol00goo00<007ooOol047oo00@007ooOol0009oo`06001oogoo001oo`00
0Woo00<007oo00000Woo00@007ooOol0009oo`80015oo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00moo`05001oogooOol00002Ool01P00Oomoo`00
Ool0009oo`03001oo`00009oo`04001oogoo0003Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`08Ool00`00Oomoo`2SOol00`00Oomoo`07Ool00`00Oomoo`3oOol^Ool00`00Oomoo`08Ool0
0`00Oomoo`1`Ool005Qoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00moo`05001oogoo
Ool00002Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oo`0000=oo`03001oogoo011o
o`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo011o
o`04001oogoo0002Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`04001oogoo0002Ool00`00
Oomoo`0@Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00
Oomoo`0@Ool01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oo`00009oo`04001oogoo
0003Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`2SOol00`00Oomo
o`07Ool00`00Oomoo`3oOol^Ool00`00Oomoo`08Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00Qo
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00=oo`03001oogoo015oo`04001oogoo0003Ool01@00Ool007oo00000Woo00D007oo
001oo`00009oo`04001oogoo000DOol00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`05Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`0BOol01000Oomoo`000Woo00D007oo001oo`00009oo`05001oo`00
Ool00002Ool01000Oomoo`0057oo00<007ooOol00goo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol00goo00<007ooOol04Woo00@007ooOol0009oo`05001oo`00Ool00002Ool01@00Ool007oo
00000goo00@007ooOol001=oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo0:=oo`03001o
ogoo00Moo`03001oogoo0?moobioo`03001oogoo00Qoo`03001oogoo071oo`00F7oo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol0
0goo00<007ooOol00goo00<007ooOol04goo00@007ooOol0009oo`05001oogoo001oo`0200001goo
001oogoo001oo`00009oo`03001oogoo01Aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
00Eoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo
00=oo`03001oogoo00=oo`03001oogoo01Aoo`06001oogoo001oo`000Woo00H007oo000007oo0002
Ool00`00Ool00002Ool00`00Oomoo`0DOol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`05
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`0DOol01P00Oomoo`00Ool0009oo`06001oo`00001oo`000Woo
00@007ooOol0009oo`03001oogoo01=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Eo
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo0:=o
o`03001oogoo00Moo`03001oogoo0?moobioo`03001oogoo00Qoo`03001oogoo071oo`00F7oo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol017oo00<0
07ooOol017oo00<007ooOol00Woo00<007ooOol05Goo00H007ooOol007oo0002Ool01P00Ool00000
Ool0009oo`05001oo`00Ool0000HOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`05Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`0FOol01@00Ool007oo00000Woo00H007oo000007oo0002Ool01@00
Ool007oo000067oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol05Woo00D007oo001oo`00009oo`06001oo`00001oo`000Woo00<007oo00000Woo00<0
07ooOol05Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol017oo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol0Xgoo00<007ooOol01goo00<0
07ooOol0ogoo;Woo00<007ooOol027oo00<007ooOol0L7oo001HOol00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`0GOol02@00Oomoo`00Ool007oo001oo`02000027oo001oo`00Ool007oo000J
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0H
Ool02000Ool007oo001oo`00Ool2000027oo001oo`00Ool007oo000JOol00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0HOol02000Ool007oo001oo`00
Ool200001Woo001oo`00Ool0009oo`03001oogoo01Moo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03
001oogoo0:=oo`03001oogoo00Qoo`03001oogoo0?moobeoo`03001oogoo00Qoo`03001oogoo071o
o`00F7oo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool017oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol05goo00T007ooOol007oo001oo`00
Ool00P0000Qoo`00Ool007oo001oo`006Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
17oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol017oo00<007ooOol0
0goo00<007ooOol00Woo00<007ooOol067oo00P007oo001oo`00Ool007oo0P0000Qoo`00Ool007oo
001oo`006Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol067oo00P007oo001oo`00Ool007oo0P0000Ioo`00Ool007oo0002Ool00`00Oomoo`0GOol0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`2SOol00`00Oomoo`08Ool00`00Oomoo`3oOol]
Ool00`00Oomoo`08Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00Qoo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00=oo`05001oogooOol0000KOol0
2000Ool007oo001oo`00Ool200001Goo001oo`00Ool00P006goo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol017oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
17oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol06Goo0P0000Eoo`00Ool007oo00800005
Ool007oo001oo`02000KOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`0IOol200001Goo001oo`00Ool00P0000Qoo`00Ool007oo001oo`006goo00D0
07ooOomoo`0000Eoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Qoo`03001oogoo0:=oo`03001oogoo00Qoo`03001oogoo0?moobeoo`03001oogoo
00Qoo`03001oogoo071oo`00F7oo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol017oo00<007ooOol00goo00D007ooOomoo`0001aoo`04001oo`00Ool2
00001Woo000007oo001oo`800003Ool007oo01]oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo01Yoo`04001oo`00Ool2000017oo000007oo0P0000Ao
o`00Ool001aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`03
001oogoo01Yoo`07001oo`00001oo`00Ool00P0000Moo`00001oo`00Ool0000LOol01@00Oomoogoo
00001Goo00<007ooOol017oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool027oo00<007ooOol0Xgoo00<007ooOol027oo00<007ooOol0ogoo;Goo00<007ooOol027oo00<0
07ooOol0L7oo001HOol00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0KOol2000017oo0000
07oo0P0000Aoo`00001oo`8001eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo009oo`03001oogoo01]oo`800004Ool00000Ool2000017oo000007oo0P007Goo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol06goo0P0000Ao
o`00001oo`800004Ool00000Ool2000MOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`2S
Ool00`00Oomoo`08Ool00`00Oomoo`3oOol]Ool00`00Oomoo`08Ool00`00Oomoo`1`Ool005Qoo`03
001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`03
001oogoo009oo`03001oogoo009oo`03001oogoo01]oo`800004Ool00000Ool2000017oo000007oo
0P007Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool06goo0P0000Aoo`00001oo`800004Ool00000Ool2000MOol00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0KOol2000017oo000007oo0P0000Aoo`00
001oo`8001eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo0:=oo`03001oogoo00Qoo`03
001oogoo0?moobaoo`03001oogoo00Uoo`03001oogoo071oo`00F7oo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol06goo00<007oo00000P0000Aoo`00001oo`800003Ool0000001eoo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Qoo`03001o
ogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01]oo`800004
Ool00000Ool2000017oo000007oo0P007Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
17oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol06goo0P0000Aoo`00001oo`800006Ool00000001oo`007Goo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol01goo00<007ooOol01goo
00<007ooOol01goo00<007ooOol027oo00<007ooOol0Xgoo00<007ooOol027oo00<007ooOol0ogoo
;7oo00<007ooOol02Goo00<007ooOol0L7oo001HOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`007goo0`00
00=oo`0000000P0000Aoo`00000001moo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`07
Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`00
7goo0`0000=oo`0000000P0000Aoo`00000001moo`04001oogoo0004Ool00`00Oomoo`04Ool00`00
Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000
Oomoo`007goo0`0000=oo`0000000P0000Aoo`00000001moo`04001oogoo0004Ool00`00Oomoo`04
Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`2S
Ool20009Ool00`00Oomoo`3oOol/Ool00`00Oomoo`08Ool2001bOol005Qoo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`04
001oogoo000OOol300000goo00000002000017oo000000007goo00@007ooOol000Aoo`03001oogoo
00Aoo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo
009oo`04001oogoo000OOol300000goo00000002000017oo000000007goo00@007ooOol000Aoo`03
001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Aoo`03
001oogoo009oo`04001oogoo000OOol300000goo00000002000017oo000000007goo00@007ooOol0
00Aoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo0:=oo`03001oogoo00Qoo`03001oogoo0?moobaoo`03001oogoo00Uoo`03001o
ogoo071oo`00F7oo00<007ooOol01goo00<007ooOol01goo00<007ooOol02Goo00<007ooOol01goo
00<007ooOol017oo00<007ooOol00Woo00@007ooOol001moo`<00003Ool0000000800004Ool00000
000OOol01000Oomoo`0017oo00<007ooOol017oo00<007ooOol01goo00<007ooOol02Goo00<007oo
Ool01goo00<007ooOol017oo00<007ooOol00Woo00@007ooOol001moo`<00003Ool0000000800004
Ool00000000OOol01000Oomoo`0017oo00<007ooOol017oo00<007ooOol01goo00<007ooOol02Goo
00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00@007ooOol001moo`<00003Ool00000
00800004Ool00000000OOol01000Oomoo`0017oo00<007ooOol017oo00<007ooOol01goo00<007oo
Ool02Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0Xgoo00<007ooOol027oo00<007oo
Ool0ogoo;7oo00<007ooOol02Goo00<007ooOol0L7oo001HOol00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`00
7goo0`0000=oo`0000000P0000Aoo`00000001moo`04001oogoo0004Ool00`00Oomoo`04Ool00`00
Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000
Oomoo`007goo0`0000=oo`0000000P0000Aoo`00000001moo`04001oogoo0004Ool00`00Oomoo`04
Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01000Oomoo`007goo0`0000=oo`0000000P0000Aoo`00000001moo`04001oogoo0004Ool00`00
Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`2SOol00`00Oomoo`09Ool00`00Oomoo`3oOolZOol00`00Oomoo`0:Ool00`00Oomoo`1`Ool0
05Qoo`<000Moo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00=oo`03
001oogoo009oo`04001oogoo000OOol300000goo00000002000017oo000000007goo00@007ooOol0
00=oo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo
00=oo`03001oogoo009oo`04001oogoo000OOol300000goo00000002000017oo000000007goo00@0
07ooOol000Aoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03
001oogoo00Aoo`05001oogooOol00002Ool00`00Oomoo`0MOol300000goo00000002000017oo0000
00007goo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00Uoo`03001o
ogoo00Moo`03001oogoo00Eoo`<00:Eoo`03001oogoo00Uoo`03001oogoo0?moobYoo`03001oogoo
00Yoo`03001oogoo071oo`00F7oo00<007ooOol01Woo00<007ooOol01goo00<007ooOol02goo00<0
07ooOol01goo00<007ooOol00goo00<007ooOol00goo00@007ooOol001ioo`<00003Ool0000000<0
0003Ool0000001ioo`05001oogooOol00003Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomo
o`0;Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`007Woo0`0000=o
o`0000000`0000=oo`0000007Woo00@007ooOol000Aoo`03001oogoo00Aoo`03001oogoo00Moo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo00Aoo`05001oogooOol00003Ool00`00Oomoo`0L
Ool200000goo00000003000017oo000000007Woo00@007ooOol000Eoo`03001oogoo00=oo`03001o
ogoo00Moo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo0:=oo`03001o
ogoo00Uoo`03001oogoo0?moobYoo`03001oogoo00Yoo`03001oogoo071oo`00F7oo00<007ooOol0
1Woo00<007ooOol01goo00<007ooOol02goo00<007ooOol027oo00<007ooOol00goo00<007ooOol0
0Woo00@007ooOol001ioo`<00003Ool0000000<00003Ool0000001ioo`04001oogoo0004Ool00`00
Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool01000Oomoo`007Woo0`0000=oo`0000000`0000=oo`0000007Woo00@007ooOol000Ao
o`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00=o
o`03001oogoo009oo`04001oogoo000NOol200000goo00000003000017oo000000007Woo00@007oo
Ool000Aoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00]oo`03001oogoo00Moo`03001o
ogoo00Ioo`03001oogoo0:=oo`03001oogoo00Uoo`03001oogoo0?moobYoo`03001oogoo00Yoo`03
001oogoo071oo`00F7oo00<007ooOol047oo00<007ooOol02goo00<007ooOol027oo00<007ooOol0
0goo00<007ooOol00Woo00@007ooOol001ioo`<00003Ool0000000<00003Ool0000001eoo`05001o
ogooOol00004Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`007Woo0`0000=oo`0000000`0000=oo`000000
7Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00]oo`03001oogoo
00Qoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0000MOol200000goo000000030000
17oo000000007Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00]o
o`03001oogoo011oo`03001oogoo0:=oo`03001oogoo00Uoo`03001oogoo0?moobUoo`03001oogoo
00]oo`03001oogoo071oo`00F7oo00<007ooOol03goo00<007ooOol03Goo00<007ooOol027oo00<0
07ooOol00goo00<007ooOol00Woo00@007ooOol001eoo`<00003Ool0000000<00003Ool0000001eo
o`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00Oomoo`08
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`007Goo0`0000=oo`0000000`0000=oo`00
00007Goo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00eoo`03001o
ogoo00Qoo`03001oogoo00=oo`03001oogoo009oo`04001oogoo000MOol200000goo000000030000
17oo000000007Goo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00eo
o`03001oogoo00moo`03001oogoo0:=oo`03001oogoo00Uoo`03001oogoo0?moobUoo`03001oogoo
00]oo`03001oogoo071oo`00F7oo00<007ooOol03goo00<007ooOol03Goo00<007ooOol027oo00<0
07ooOol017oo00<007ooOol00Woo00@007ooOol001]oo`03001oo`0000800004Ool00000Ool30000
0goo001oo`0JOol01000Oomoo`0017oo00<007ooOol017oo00<007ooOol027oo00<007ooOol03Goo
00<007ooOol02Goo00<007ooOol00goo00D007ooOomoo`0000=oo`03001oogoo01Uoo`03001oo`00
00800004Ool00000Ool300000goo001oo`0JOol01@00Oomoogoo00000goo00<007ooOol00goo00<0
07ooOol02Goo00<007ooOol03Goo00<007ooOol027oo00<007ooOol017oo00<007ooOol00Woo00@0
07ooOol001]oo`03001oo`0000800004Ool00000Ool300000goo001oo`0JOol01000Oomoo`0017oo
00<007ooOol017oo00<007ooOol027oo00<007ooOol03Goo00<007ooOol03goo00<007ooOol0Xgoo
00<007ooOol02Woo00<007ooOol0ogoo:7oo00<007ooOol02goo00<007ooOol0L7oo001HOol00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`09Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo
00<007ooOol06Goo00<007oo00000P0000Aoo`00001oo`<00003Ool007oo01Yoo`04001oogoo0003
Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`0=Ool00`00Oomoo`09Ool00`00Oomoo`04
Ool01@00Oomoogoo00000goo00<007ooOol067oo00<007oo00000P0000Aoo`00001oo`<00003Ool0
07oo01Uoo`05001oogooOol00003Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`0=Ool0
0`00Oomoo`09Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo00<007ooOol06Goo00<007oo0000
0P0000Aoo`00001oo`<00003Ool007oo01Yoo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomo
o`09Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool00`00Oomoo`2SOol00`00Oomoo`0:Ool00`00Oomo
o`3oOolXOol00`00Oomoo`0;Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00eoo`80015oo`03001o
ogoo00Uoo`03001oogoo00Aoo`80009oo`800003Ool0000001Uoo`800004Ool00000Ool200001Woo
00000000Ool001Yoo`04001oo`000002Ool20005Ool2000;Ool00`00Oomoo`0?Ool00`00Oomoo`09
Ool20005Ool01000Oomoogoo0P0000=oo`0000006Goo00<007oo00000P0000Aoo`00001oo`<00003
Ool007oo01Qoo`800003Ool0000000=oo`03001oogoo00=oo`8000]oo`03001oogoo00moo`03001o
ogoo00Uoo`8000Eoo`80009oo`800003Ool007oo01Uoo`03001oo`0000800004Ool00000Ool20000
0goo0000000IOol200000goo00000002Ool20006Ool00`00Oomoo`09Ool00`00Oomoo`0?Ool2000?
Ool00`00Oomoo`2SOol00`00Oomoo`0:Ool00`00Oomoo`3oOolXOol00`00Oomoo`0;Ool00`00Oomo
o`1`Ool005Qoo`03001oogoo00aoo`03001oogoo019oo`8000Yoo`03001oogoo00Eoo`04001oogoo
Ool200000goo0000000GOol2000017oo000007oo0P0000Aoo`00001oo`8001Uoo`03001oo`00009o
o`8000Ioo`03001oogoo00Uoo`8001=oo`03001oogoo00Yoo`8000Aoo`03001oogoo009oo`04001o
ogoo000GOol200001Goo00000000Ool00P0000Eoo`00000007oo008001Moo`04001oogoo0004Ool0
0`00Oomoo`02Ool2000<Ool00`00Oomoo`0AOol2000;Ool00`00Oomoo`04Ool20002Ool00`00Ool0
000IOol2000017oo000007oo0P0000Aoo`00001oo`8001Moo`800003Ool0000000=oo`03001oogoo
00Eoo`03001oogoo00Qoo`8001Aoo`03001oogoo00aoo`03001oogoo0:=oo`03001oogoo00]oo`03
001oogoo0?moobIoo`03001oogoo00aoo`03001oogoo071oo`00F7oo00<007ooOol02goo00<007oo
Ool05Goo00<007ooOol027oo0P001Woo00<007ooOol00Woo00@007ooOol001Eoo`800005Ool007oo
001oo`0200001Goo001oo`00Ool00P005Woo0P0000Eoo`00Oomoo`0000Ioo`8000Yoo`8001Ioo`03
001oogoo00]oo`03001oogoo009oo`8000=oo`800003Ool007oo01Aoo`03001oogoo00800003Ool0
07oo00800003Ool007oo0080009oo`03001oogoo01=oo`04001oo`000003Ool20004Ool00`00Oomo
o`0;Ool00`00Oomoo`0DOol2000:Ool20006Ool01@00Oomoo`00Ool00P005Woo0P0000Eoo`00Ool0
07oo00800005Ool007oo001oo`02000EOol01000Oomoo`0017oo00<007ooOol017oo0P002Woo00<0
07ooOol05Goo00<007ooOol02goo00<007ooOol0Xgoo00<007ooOol02goo00<007ooOol0ogoo9Woo
00<007ooOol037oo00<007ooOol0L7oo000eOol5000=Ool4000=Ool00`00Oomoo`09Ool2000IOol0
0`00Oomoo`09Ool30004Ool30002Ool200000goo001oo`0BOol200001Woo00000000Ool0009oo`04
001oo`000002Ool00`00Oomoo`0AOol30002Ool01000Ool000001Goo0P002goo00<007ooOol05goo
0`002goo0P0017oo0`000Woo1@004Goo00<007oo00000P0000Aoo`00Ool0009oo`04001oo`00Ool3
00000goo001oo`0AOol40002Ool30004Ool2000<Ool2000IOol00`00Oomoo`09Ool20005Ool20000
17oo001oogoo0`004goo00<007ooOol00P0000Ioo`00Oomoo`00Ool300000goo0000000COol01000
Ool000000goo0P0017oo0`002goo00<007ooOol05goo0P002goo00<007ooOol0Xgoo00<007ooOol0
2goo00<007ooOol0ogoo9Woo00<007ooOol037oo00<007ooOol0L7oo000cOol8000:Ool8000;Ool0
0`00Oomoo`07Ool2000LOol2000<Ool20005Ool20002Ool5000=Ool60002Ool00`00Ool00002Ool0
1000Ool007oo0P0000Aoo`00000000ioo`800003Ool0000000@000Eoo`8000]oo`8001eoo`8000]o
o`8000Eoo`80009oo`03001oogoo008000ioo`<00007Ool007ooOol007oo00000Woo00<007oo0000
0Woo00<007oo00000P003Woo0`0000Aoo`00Oomoo`8000Eoo`8000]oo`<001aoo`8000]oo`8000Eo
o`H00003Ool0000000eoo`@00007Ool00000Ool007oo00000Woo00<007oo00000Woo1@003Woo1@00
0Woo0`0017oo0P002goo0`0077oo0P002Goo00<007ooOol0Xgoo00<007ooOol02goo00<007ooOol0
ogoo9Woo00<007ooOol037oo00<007ooOol0L7oo000cOol20004Ool30009Ool20004Ool2000;Ool0
0`00Oomoo`06Ool00`00Oomoo`0NOol3000;Ool20005Ool20002Ool200000goo0000000:Ool00`00
Ool000020004Ool00`00Ool00002Ool00`00Oomoo`0200000goo00000004000:Ool20002Ool00`00
Oomoo`020004Ool3000;Ool2000QOol2000;Ool20005Ool6000017oo0000000027oo10000Woo0P00
00Eoo`00Oomoo`00009oo`05001oogoo001oo`020002Ool40008Ool30002Ool50005Ool2000;Ool2
000QOol20009Ool00`00Ool000020004Ool20002Ool00`00Oomoo`02000:Ool00`00Ool000030000
0goo00000002Ool01P00Oomoo`00Ool000Aoo`D000Yoo`800003Ool00000009oo`8000Eoo`8000]o
o`80025oo`03001oogoo00Ioo`03001oogoo0:=oo`8000aoo`03001oogoo0?moobIoo`03001oogoo
00]oo`80079oo`00<Woo0P001Woo0`001goo0P001Woo0P002Woo00<007ooOol0:Woo0`002Woo1000
0goo0P000Woo4@000goo0P0000=oo`00Ool00goo00H007ooOomoo`00Ool?00000goo000000040003
Ool3000;Ool3000UOol2000;Ool30004OolF0002Ool01000Oomoo`0017oo00@007ooOol0009ooaH0
00Aoo`<000]oo`8002Eoo`@000Yoo`<000=oo`H00003Ool0000000d00003Ool007oo009oo`03001o
ogoo009oo`04001oo`000003OolA0002Ool20004Ool3000:Ool3000/Ool00`00Oomoo`2SOol00`00
Oomoo`0<Ool00`00Oomoo`3oOolUOol00`00Oomoo`0<Ool00`00Oomoo`1`Ool0035oo`8000Qoo`80
00Moo`8000Ioo`8000Yoo`03001oogoo02eoo`D000Uoo`@00003Ool0000000h000=oo`<0009oo`03
001oogoo00Aoo`05001oogooOol00004Ool?0002Ool40009Ool5000ZOol4000:Ool30005Ool?0002
Ool30002Ool20004Ool20002Ool400000goo0000000>0004Ool3000;Ool3000[Ool40009Ool50000
0goo0000000>0003Ool01@00Oomoogoo00001Woo00<007ooOol00`000goo400000=oo`0000000`00
2Goo1000;goo00<007ooOol0Xgoo00<007ooOol037oo00<007ooOol0ogoo97oo00<007ooOol03Goo
00<007ooOol0L7oo000aOol20008Ool20006Ool20008Ool20009Ool00`00Oomoo`0bOol90004OolD
0003Ool20008Ool300000goo0000000C0004Ool9000cOol90004OolF0003Ool20008Ool20004OolE
0005Ool9000bOol90005OolD0002Ool20008Ool30002OolD0005Ool9000cOol00`00Oomoo`2SOol0
0`00Oomoo`0<Ool00`00Oomoo`3oOolTOol00`00Oomoo`0=Ool00`00Oomoo`1`Ool0035oo`8000Qo
o`8000Ioo`8000Qoo`8000Uoo`03001oogoo03]ooa/000eooaX004Eooad000aooah004Aooa/000eo
oa/003aoo`03001oogoo0:=oo`03001oogoo00eoo`03001oogoo0?moob9oo`03001oogoo00ioo`03
001oogoo071oo`00<Goo0P0027oo0P001Woo0P0027oo0P002Goo1000?Goo600037oo6000Bgoo6000
4Goo5`00C7oo5`003Goo5`00?Goo1000YGoo00<007ooOol03Goo00<007ooOol0ogoo8Woo00<007oo
Ool03Woo00<007ooOol0L7oo000aOol30006Ool30006Ool20008Ool20009Ool00`00Oomoo`0aOol=
0005Ool>0005Ool30006Ool30005Ool>0005Ool=000eOol90005OolA0002Ool3000:Ool400000goo
0000000@0004Ool9000eOol>0004Ool?0004Ool30006Ool40004Ool?0004Ool>000bOol00`00Oomo
o`2SOol00`00Oomoo`0>Ool00`00Oomoo`3oOolQOol00`00Oomoo`0>Ool00`00Oomoo`1`Ool0035o
o`@000Aoo`<000Moo`8000Qoo`8000Uoo`03001oogoo02aoo`D000Uooa/000Aoo`03001oogoo009o
o`03001oogoo009ooa/000Uoo`D002aoo`@000UooaT0009oo`8000Ioo`80009ooaT000Uoo`D002ao
o`@000Uooa`000=oo`03001oogoo009oo`03001oogoo009ooa/000Yoo`@002ioo`03001oogoo0:=o
o`03001oogoo00ioo`03001oogoo0?moob1oo`03001oogoo00moo`03001oogoo071oo`00<Goo0P00
00=oo`0000001@0027oo0P0027oo0P002Goo00<007ooOol0:Goo0`0037oo0P000goo5`0000=oo`00
00000goo00@007ooOol000=oo`800003Ool0000001D000=oo`<000]oo`<002=oo`H000Qoo`D00003
Ool0000000800003Ool0000000d0009oo`@0009oo`80009oo`80009oo`D00003Ool0000000d0009o
o`<00003Ool0000000@000Qoo`D002=oo`@000Yoo`<000=ooaL0009oo`05001oogooOol00002Ool0
1000Oomoogoo0P0000=oo`0000005@000goo0P0037oo0`00:goo00<007ooOol0Xgoo00<007ooOol0
3Woo00<007ooOol0ogoo7goo00<007ooOol047oo00<007ooOol0L7oo000bOol00`00Oomoo`050009
Ool20008Ool20009Ool00`00Oomoo`06Ool2000NOol3000<Ool30003Ool20002Ool20002Ool40006
Ool30002Ool00`00Ool00002Ool01000Oomoo`000Woo00@007ooOol000=oo`80009oo`<000Ioo`@0
0003Ool0000000=oo`8000Aoo`<000]oo`8001moo`8000]oo`<000Aoo`80009oo`H000Uoo`@000=o
o`8000=oo`04001oogoo0003Ool20003Ool40009Ool60002Ool20005Ool2000;Ool2000OOol2000;
Ool30004Ool20003Ool200000goo000000020006Ool30002Ool20003Ool01000Oomoo`000Woo00@0
07ooOol0009oo`03001oo`00009oo`<000Ioo`D00003Ool00000009oo`8000=oo`<000aoo`<001io
o`8000Qoo`03001oogoo0:=oo`03001oogoo00moo`03001oogoo0?mooaioo`03001oogoo011oo`03
001oogoo071oo`00<Woo0P003goo0P0027oo0P002Goo00<007ooOol027oo0P006goo00<007ooOol0
2Woo0`000goo0`000Woo1P003Goo0P0000Ioo`00Ool007oo0002Ool01000Oomoo`000Woo00<007oo
Ool01@003Goo1P000Woo0P001Goo0P002goo0P006Woo0`002goo0P001Goo0P000Woo1@003Woo1P00
00Eoo`00Oomoo`00009oo`05001oogoo001oo`06000>Ool50002Ool20005Ool2000;Ool3000JOol2
000;Ool20005Ool20002Ool6000=Ool50002Ool01000Oomoo`000Woo00T007ooOol007oo001oo`00
Ool00P003Woo1@000Woo0`000goo0`0037oo00<007ooOol06Goo0P002Woo00<007ooOol0Xgoo00<0
07ooOol047oo00<007ooOol0ogoo77oo00<007ooOol04Goo00<007ooOol0L7oo000bOol3000?Ool2
0006Ool2000:Ool00`00Oomoo`0:Ool00`00Oomoo`0GOol00`00Oomoo`09Ool20005Ool01000Oomo
ogoo0P0000=oo`00Ool04Woo00L007oo001oo`00Ool00002Ool20002Ool00`00Oomoo`03000COol2
00000goo00000002Ool20005Ool00`00Oomoo`0:Ool00`00Oomoo`0FOol00`00Oomoo`0:Ool20005
Ool20002Ool200000goo001oo`0BOol00`00Oomoo`02000017oo001oogoo0P000Woo00@007oo0000
009oo`03001oogoo015oo`04001oo`000002Ool20005Ool2000<Ool00`00Oomoo`0FOol00`00Oomo
o`0:Ool00`00Oomoo`03Ool20002Ool200000goo0000000COol30002Ool00`00Oomoo`020002Ool0
1`00Ool007oo001oo`0001=oo`04001oo`000003Ool00`00Oomoo`03Ool2000;Ool00`00Oomoo`0G
Ool00`00Oomoo`0:Ool00`00Oomoo`2SOol00`00Oomoo`0@Ool00`00Oomoo`3oOolKOol00`00Oomo
o`0BOol00`00Oomoo`1`Ool003=oo`<000ioo`8000Ioo`8000Yoo`03001oogoo00]oo`03001oogoo
01Eoo`03001oogoo00Uoo`03001oogoo00Aoo`05001oogooOol00002Ool00`00Oomoo`0COol01000
Ool007oo0P000Woo0P000Woo00H007oo000007oo000EOol01000Oomoo`000goo00<007ooOol00goo
00<007ooOol02Woo00<007ooOol05Goo00<007ooOol02Goo00<007ooOol017oo00D007ooOomoo`00
009oo`03001oogoo01=oo`06001oo`00001oo`000Woo0P000Woo00H007oo000007oo000EOol01000
Oomoo`000goo00<007ooOol017oo00<007ooOol02Goo00<007ooOol05Goo00<007ooOol02Woo00<0
07ooOol00goo00D007ooOomoo`00009oo`03001oogoo01=oo`06001oo`00001oo`000Woo0P000Woo
0P0000Aoo`00Ool001Eoo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomo
o`0EOol00`00Oomoo`0;Ool00`00Oomoo`2SOol00`00Oomoo`0AOol00`00Oomoo`3oOolIOol00`00
Oomoo`0COol00`00Oomoo`1`Ool003Aoo`<000ioo`8000Aoo`8000]oo`03001oogoo00aoo`03001o
ogoo01=oo`03001oogoo00Uoo`03001oogoo00Aoo`03001oogoo0080009oo`03001oogoo01Eoo`07
001oo`00001oo`00Ool00P0000=oo`00Ool00P0000=oo`00Ool05Woo00@007ooOol000=oo`8000Ao
o`8000]oo`8001Aoo`03001oogoo00Qoo`8000Ioo`05001oogooOol00002Ool00`00Oomoo`0EOol0
1`00Ool00000Ool007oo00800003Ool007oo00800003Ool007oo01Ioo`04001oogoo0003Ool00`00
Oomoo`04Ool2000:Ool00`00Oomoo`0BOol2000;Ool20004Ool20003Ool01000Oomoo`005goo00L0
07oo000007oo001oo`0200000goo001oo`0200000goo001oo`0FOol00`00Oomoo`020002Ool00`00
Oomoo`03Ool2000;Ool00`00Oomoo`0COol00`00Oomoo`0<Ool00`00Oomoo`2SOol00`00Oomoo`0B
Ool00`00Oomoo`3oOolGOol00`00Oomoo`0DOol00`00Oomoo`1`Ool003Eoo`P000Qoo`P000]oo`03
001oogoo00eoo`03001oogoo015oo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0003Ool0
0`00Oomoo`0FOol01`00Ool00000Ool007oo00800003Ool007oo00800003Ool007oo01Moo`04001o
ogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`07Ool00`00
Oomoo`05Ool01@00Oomoogoo00000Woo00<007ooOol05goo0`0000=oo`00Ool00P0000=oo`00Ool0
0`006Goo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo019oo`03001o
ogoo00Uoo`03001oogoo00=oo`03001oogoo009oo`04001oogoo000HOol01`00Ool00000Ool007oo
00800003Ool007oo00800003Ool007oo01Moo`05001oogooOol00002Ool00`00Oomoo`04Ool00`00
Oomoo`09Ool00`00Oomoo`0AOol00`00Oomoo`0=Ool00`00Oomoo`2SOol00`00Oomoo`0COol00`00
Oomoo`3oOolEOol00`00Oomoo`0EOol00`00Oomoo`1`Ool003Moo`H000Yoo`@000eoo`03001oogoo
00ioo`03001oogoo011oo`03001oogoo00Qoo`03001oogoo00Aoo`05001oogooOol00002Ool00`00
Oomoo`0HOol01P00Ool007oo001oo`800003Ool007oo00<001Yoo`04001oogoo0003Ool00`00Oomo
o`04Ool00`00Oomoo`09Ool00`00Oomoo`0@Ool00`00Oomoo`08Ool00`00Oomoo`04Ool01@00Oomo
ogoo00000Woo00<007ooOol067oo0`0000=oo`00Ool00P0000=oo`00Ool00`006Woo00@007ooOol0
00=oo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo011oo`03001oogoo00Uoo`03001oogoo
00Aoo`05001oogooOol00002Ool00`00Oomoo`0HOol300000goo001oo`0200001Woo001oo`00Ool0
01Yoo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0@Ool00`00Oomo
o`0>Ool00`00Oomoo`2SOol2000EOol00`00Oomoo`3oOolCOol00`00Oomoo`0EOol2001bOol005Qo
o`03001oogoo00moo`03001oogoo00ioo`03001oogoo00Qoo`03001oogoo00Aoo`05001oogooOol0
0002Ool00`00Oomoo`0IOol01@00Ool00000Ool0100000Eoo`00001oo`0001]oo`04001oogoo0003
Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`08Ool00`00Oomoo`04
Ool01@00Oomoogoo00000Woo00<007ooOol06Woo0`0000=oo`0000000P0000Aoo`00000001aoo`04
001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`08Ool0
0`00Oomoo`04Ool01@00Oomoogoo00000Woo00<007ooOol06Goo00D007oo000007oo00@00005Ool0
0000Ool0000KOol01000Oomoo`000goo00<007ooOol017oo00<007ooOol027oo00<007ooOol03Woo
00<007ooOol03goo00<007ooOol0Xgoo00<007ooOol05Goo00<007ooOol0ogoo4Goo00<007ooOol0
5goo00<007ooOol0L7oo001HOol00`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`08Ool00`00
Oomoo`04Ool01@00Oomoogoo00000Woo00<007ooOol06goo0`0000=oo`0000000P0000Aoo`000000
01eoo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00Oomo
o`08Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo00<007ooOol06goo0`0000=oo`0000000P00
00Aoo`00000001eoo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0=
Ool00`00Oomoo`08Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo00<007ooOol06goo0`0000=o
o`0000000P0000Aoo`00000001eoo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`08Ool0
0`00Oomoo`0=Ool00`00Oomoo`0?Ool00`00Oomoo`2SOol00`00Oomoo`0FOol2003oOol>Ool3000J
Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00moo`03001oogoo00eoo`03001oogoo00Qoo`03001o
ogoo00Aoo`05001oogooOol00002Ool00`00Oomoo`0KOol300000goo00000002000017oo00000000
7Goo00@007ooOol000=oo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo00eoo`03001oogoo
00Qoo`03001oogoo00Aoo`05001oogooOol00002Ool00`00Oomoo`0KOol300000goo000000020000
17oo000000007Goo00@007ooOol000=oo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo00eo
o`03001oogoo00Qoo`03001oogoo00Aoo`05001oogooOol00002Ool00`00Oomoo`0KOol300000goo
00000002000017oo000000007Goo00@007ooOol000=oo`03001oogoo00Aoo`03001oogoo00Qoo`03
001oogoo00eoo`03001oogoo00moo`03001oogoo0:=oo`03001oogoo01Qoo`03001oogoo0?moo`Yo
o`03001oogoo01]oo`03001oogoo071oo`00F7oo00<007ooOol047oo00<007ooOol02goo00<007oo
Ool027oo00<007ooOol017oo00D007ooOomoo`00009oo`03001oogoo01aoo`<00003Ool000000080
0004Ool00000000MOol01@00Oomoogoo00000goo00<007ooOol017oo00<007ooOol027oo00<007oo
Ool02goo00<007ooOol027oo00<007ooOol017oo00D007ooOomoo`0000=oo`03001oogoo01]oo`<0
0003Ool0000000800004Ool00000000MOol01@00Oomoogoo00000goo00<007ooOol017oo00<007oo
Ool027oo00<007ooOol02goo00<007ooOol027oo00<007ooOol017oo00D007ooOomoo`0000=oo`03
001oogoo01]oo`<00003Ool0000000800004Ool00000000NOol01000Oomoo`000goo00<007ooOol0
17oo00<007ooOol027oo00<007ooOol02goo00<007ooOol047oo00<007ooOol0Xgoo00<007ooOol0
6Goo0`00ogoo1goo0P007Woo00<007ooOol0L7oo001HOol00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`007Woo
0`0000=oo`0000000`0000=oo`0000007Goo00D007ooOomoo`0000=oo`03001oogoo00Eoo`03001o
ogoo00Moo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo009oo`04001o
ogoo000NOol300000goo0000000300000goo0000000NOol01000Oomoo`0017oo00<007ooOol00goo
00<007ooOol027oo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00D007ooOomoo`00
00=oo`03001oogoo01]oo`800003Ool0000000<00004Ool00000000NOol01000Oomoo`0017oo00<0
07ooOol017oo00<007ooOol01goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol0Xgoo00<007ooOol077oo0`00ogoo100087oo00<007ooOol0L7oo001HOol00`00Oomoo`06
Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01000Oomoo`007Woo0`0000=oo`0000000`0000=oo`0000007Woo00D007ooOomoo`0000=oo`03
001oogoo00Aoo`03001oogoo00Moo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Aoo`03
001oogoo009oo`04001oogoo000NOol300000goo0000000300000goo0000000NOol01000Oomoo`00
17oo00<007ooOol017oo00<007ooOol01goo00<007ooOol02goo00<007ooOol01goo00<007ooOol0
17oo00D007ooOomoo`0000=oo`03001oogoo01aoo`800003Ool0000000<00004Ool00000000NOol0
1000Oomoo`0017oo00<007ooOol017oo00<007ooOol01goo00<007ooOol02goo00<007ooOol01goo
00<007ooOol01Woo00<007ooOol0Xgoo00<007ooOol07goo00<007ooOol0nGoo0`0097oo00<007oo
Ool0L7oo001HOol30007Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool01@00Oomoogoo00007Woo0`0000=oo`0000000`0000=oo`0000007Woo
00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo
00Moo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol0000NOol300000goo000000030000
0goo0000000NOol01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol01goo00<007ooOol0
2Goo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0001ioo`800003
Ool0000000<00004Ool00000000NOol01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol0
1goo00<007ooOol02Goo00<007ooOol01goo00<007ooOol01Goo0`00YGoo00<007ooOol087oo1P00
lWoo0`009goo00<007ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`2SOol00`00Oomo
o`0VOol3003/Ool3000ZOol00`00Oomoo`1`Ool005Qoo`03001oogoo0?mooleoo`03001oogoo085o
o`D000ioo`@000]oo`03001oogoo02Uoo`H00=aoo`X002eoo`03001oogoo071oo`00F7oo00<007oo
Ool0ogoocGoo00<007ooOol0Ogoo2@002Woo20002Goo00<007ooOol0;goo2P00bGoo2@00=goo00<0
07ooOol0L7oo001HOol00`00Oomoo`3oOoo=Ool00`00Oomoo`1nOol40004Ool30009Ool20004Ool2
0009Ool00`00Oomoo`0iOol<002`Ool=0010Ool00`00Oomoo`1`Ool005Qoo`03001oogoo0?mooleo
o`03001oogoo07ioo`8000Moo`<000Moo`8000Ioo`8000Qoo`03001oogoo04EooaX007Yooa`004eo
o`03001oogoo071oo`00F7oo00<007ooOol05goo00<007ooOol0@Goo00<007ooOol0@Woo00<007oo
Ool0@Goo00<007ooOol0@Woo00<007ooOol0@Woo00<007ooOol0@Goo00<007ooOol05goo00<007oo
Ool0R7oo0P001goo0P001Woo0P0027oo00<007ooOol0GgooNP00JGoo00<007ooOol0L7oo001HOol0
0`00Oomoo`06Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool0
0`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool0
0`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool0
0`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool0
0`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool0
0`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`06Ool00`00Oomoo`28Ool20006Ool20008Ool2
0007Ool00`00Oomoo`3oOom3Ool00`00Oomoo`1`Ool005Qoo`03001oogoo00Ioo`03001oogoo00io
o`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00mo
o`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00io
o`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00moo`03001oogoo00ioo`03001oogoo00io
o`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00mo
o`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00io
o`03001oogoo00Ioo`03001oogoo08Qoo`8000Ioo`8000Qoo`8000Moo`03001oogoo0?mood=oo`03
001oogoo071oo`00F7ooo`00d@00RGoo0`001Woo0P0027oo0P001goo0`00ogoo@Goo0`00LWoo003o
OoooOonbOol30007Ool20008Ool20007Ool00`00Oomoo`3oOom3Ool00`00Oomoo`1`Ool00?mooomo
ojmoo`D000Qoo`8000Qoo`8000Moo`03001oogoo0?mood=oo`03001oogoo071oo`00ogooogoo[goo
10002Goo0P0027oo0P001goo00<007ooOol0ogoo@goo00<007ooOol0L7oo003oOoooOonbOol20008
Ool20008Ool20007Ool00`00Oomoo`3oOom3Ool00`00Oomoo`1`Ool00?mooomook=oo`8000Moo`80
00Qoo`8000Moo`03001oogoo0?mood=oo`03001oogoo071oo`00ogooogoo/goo0P0027oo0P001Woo
0P0027oo00<007ooOol0ogoo@goo00<007ooOol0L7oo003oOoooOon[Ool20006Ool20008Ool20006
Ool20008Ool00`00Oomoo`03Ool00`00Oomoo`1;Ool00`00Oomoo`1<Ool00`00Oomoo`1;Ool00`00
Oomoo`1;Ool00`00Oomoo`03Ool00`00Oomoo`1`Ool00?mooomooj]oo`<000Aoo`<000Uoo`8000Ao
o`8000Uoo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001o
ogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00aoo`03001o
ogoo00eoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00eoo`03001o
ogoo00aoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00eoo`03001o
ogoo00aoo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo071oo`00ogooogoo[7oo20002Woo
20002Gooo`00A`00LWoo003oOoooOon]Ool5000>Ool4003oOoo4Ool00?mooomooomooomoohUoo`00
ogooogooogooogooRGoo003oOoooOoooOoooOon9Ool00?mooomooomooomoohUoo`00ogooogooogoo
ogooRGoo003oOoooOoooOoooOon9Ool00?mooomooomooomoohUoo`00ogooogooogooogooRGoo003o
OoooOoooOoooOon9Ool00?mooomooomooomoohUoo`00ogooogooogooogooRGoo003oOoooOoooOooo
Oon9Ool00?mooomooomooomoohUoo`00ogooogooogooogooRGoo003oOoooOoooOoooOon9Ool00?mo
oomooomooomoohUoo`00\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{385.75, 183.5},
  ImageMargins->{{41.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
Each one of the four leaves of the \"flowers\" in the above picture \
to the left represents the exact distribution of the potential of a line \
charge inside a conducting box. The picture to the right shows a section \
containing just the central leaf, plotted is the area of the containing box \
with sides xs and ys.\
\>", "Text",
  PageBreakBelow->True],

Cell[TextData[{
  "\tThe coefficients of capacity of two wires 1 and 2 with diameter d at the \
positions cited at the beginning of this section may then be found according \
to (23) and (",
  StyleBox["Ref. 7",
    FontWeight->"Bold"],
  ", p. 118) with\n",
  Cell[BoxData[
      \(TraditionalForm\`f(x\_1, y\_1 + d/2, x\_s, y\_s, x\_1, y\_1)\  = 
        f\_11\)]],
  ", \n",
  Cell[BoxData[
      \(TraditionalForm\`f(x\_1, y\_1 + d/2, x\_s, y\_s, x\_2, y\_2)\  = 
        f\_12\)]],
  ",\n",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f(x\_2, y\_2 + d/2, x\_s, y\_s, x\_1, y\_1)\), " ", "=", 
          SubscriptBox[
            FormBox["f",
              "TraditionalForm"], "21"]}], TraditionalForm]]],
  ",\n",
  Cell[BoxData[
      \(TraditionalForm\`f(x\_2, y\_2 + d/2, x\_s, y\_s, x\_2, y\_2)\  = 
        f\_22\)]],
  "  \n from "
}], "Text",
  PageBreakAbove->Automatic],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(C\_10'\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\(2  \[Pi]\ \(\(\[Epsilon]\_0\)(f\_22 - \ f\_12)\)\)\
\/\(\(f\_11\) f\_22 - \ \(f\_12\) f\_21\)\)]],
  ",  ",
  Cell[BoxData[
      \(C\_20'\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\(2  \[Pi]\ \(\(\[Epsilon]\_0\)(f\_11 - \ f\_21)\)\)\
\/\(\(f\_11\) f\_22 - \ \(f\_12\) f\_21\)\)]],
  ",  ",
  Cell[BoxData[
      \(C\_12'\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\(2  \[Pi]\ \(\[Epsilon]\_0\) f\_12\)\/\(\(f\_11\) f\
\_22 - \ \(f\_12\) f\_21\)\)]],
  ",\t",
  Cell[BoxData[
      \(C\_21'\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\(2  \[Pi]\ \(\[Epsilon]\_0\) f\_21\)\/\(\(f\_11\) f\
\_22 - \ \(f\_12\) f\_21\)\)]],
  ": "
}], "Text",
  PageBreakAbove->Automatic],

Cell[BoxData[GridBox[{
        {
          StyleBox["d",
            FontWeight->"Bold"], 
          RowBox[{"new", " ", 
            StyleBox["formula",
              FontWeight->"Bold"]}], 
          StyleBox[\(C\_10 = \(C\_20\) \((\(num\)\(.\))\)\),
            FontWeight->"Bold"], 
          RowBox[{"new", " ", 
            StyleBox["formula",
              FontWeight->"Bold"]}], 
          StyleBox[\(C\_12 = \(C\_21\) \((\(num\)\(.\))\)\),
            FontWeight->"Bold"]},
        {
          StyleBox["2",
            FontWeight->"Bold"], \(1.2\ *\ 10\^\(-11\)\), \(1.2\ \ \ *\ 
            10\^\(-11\)\), \(1.22\ *\ 10\^\(-12\)\), \(1.15\ *\ 
            10\^\(-12\)\)},
        {
          StyleBox["4",
            FontWeight->"Bold"], \(1.41\ *\ 10\^\(-11\)\), \(1.38\ *\ 
            10\^\(-11\)\), \(1.76\ *\ 10\^\(-12\)\), \(1.58\ *\ 
            10\^\(-12\)\)},
        {
          StyleBox["6",
            FontWeight->"Bold"], \(1.56\ *\ 10\^\(-11\)\), \(1.56\ *\ 
            10\^\(-11\)\), \(2.26\ *\ 10\^\(-12\)\), \(2.06*\ 10\^\(-12\)\)}
        },
      GridFrame->True,
      RowLines->True,
      ColumnLines->True]], "Text"],

Cell["\<\
Table 2.  Analytical (zero at boundary of the box) and numerical \
capacities of a pair of wires  [F/m]\
\>", "Caption"],

Cell["\<\
The agreement (cf. Table 2) is much better for the stray capacities \
and reasonable for the mutual capacity.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coefficients of inductance of a pair of wires:", "Subsubsection"],

Cell[TextData[{
  "If the current flowing through a circuit is kept constant the magnetic \
field is insensitive to whether the vector potential has its zero boundary at \
infinity or at the border of a box, because the rotation of the vector \
potential doesn't change \[Dash] in contrast to the gradient of the electric \
potential. This is accounted for in the relaxation calculation by the \
necessary readjustment of the vector potential (42) at the edge of the \
conductors so that the current stays at 1. Then the formula for the \
self-inductance (l = ",
  Cell[BoxData[
      \(\((\[Mu]\_0/\[Pi])\) Log[a/r]\)]],
  ") and mutual inductance (",
  Cell[BoxData[
      \(TraditionalForm\`l\_12\)]],
  StyleBox[" = ",
    FontVariations->{"CompatibilityType"->0}],
  Cell[BoxData[
      \(\[Mu]\_0/\((2  \[Pi])\) Log[r\_14\ r\_23/\((r\_13\ r\_24)\)]\)], 
    "Input",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  ") from the textbook (",
  StyleBox["Ref. 7",
    FontWeight->"Bold"],
  ", p.316, 325) can be directly compared to the numerical computation. The \
calculation was done on a grid of 120 * 90 points, the positions of the \
conductors 1 to 4 lying at (60, 50), (50, 50) and (60, 40), (70, 40) \
respectively. The loop integrals (42) were taken with radii ranging from 4 to \
6 in steps of 0.2, then their mean was used to determine the current. The \
results for ",
  Cell[BoxData[
      \(TraditionalForm\`l\_1\)]],
  ", the self-",
  "inductance",
  " of circuit 1, (one circuit at current 1, the other at current zero \
\[Dash] as if not present \[Dash]), ",
  Cell[BoxData[
      \(TraditionalForm\`l\_2\)]],
  "and ll (both circuits at current 1) are given below together with the \
corresponding values of the vector potential."
}], "Text"],

Cell[TextData[{
  "r = 1   \tl   = 9.21*10^-7 [H/m]:\n\t",
  Cell[BoxData[
      \(TraditionalForm\`l\_1\)]],
  " = 9.19*10^-7;   v1 = 0.370859;    v2 = -0.3628862;  v3 = -0.06284042;  v4 \
= -0.03036495;\n\t",
  Cell[BoxData[
      \(TraditionalForm\`l\_2\)]],
  " = 9.16*10^-7;   v1 = 0.0259072;  v2 =  0.0579781;  v3 =   0.352414;      \
v4 = -0.381698;\n\tll  = 1.758*10^-6; v1 = 0.396796;    v2 = -0.3049608;  v3 \
=   0.289506       v4 = -0.4120585;\nr = 2\tl   = 6.44*10^-7 [H/m]:\n\t",
  Cell[BoxData[
      \(TraditionalForm\`l\_1\)]],
  " = 6.65*10^-7;    v1 = 0.2702775;  v2 = -0.2609418;  v3 = -0.0589633;   v4 \
= -0.0294141;\n\t",
  Cell[BoxData[
      \(TraditionalForm\`l\_2\)]],
  " = 6.64*10^-7;    v1 = 0.024736;    v2 =  0.053704;    v3 =   0.250446;    \
 v4 = -0.281441;\n\tll  = 1.26*10^-6;    v1 = 0.294926;    v2 = -0.2073;      \
  v3 =  0.191429;      v4 = -0.310924;\nr = 3",
  StyleBox["\t",
    FontWeight->"Bold"],
  "l   = 4.82*10^-7 [H/m]:\n\t",
  Cell[BoxData[
      \(TraditionalForm\`l\_1\)]],
  " = 4.67*10^-7;     v1 = 0.193345;     v2 = -0.179803;  v3 = -0.0505313;  \
v4 = -0.0272583;\n\t",
  Cell[BoxData[
      \(TraditionalForm\`l\_2\)]],
  " = 4.66*10^-7;     v1 = 0.02257533; v2 =  0.045243;  v3 =   0.1695425;  v4 \
= -0.203956;\n\tll  = 8.798*10^-7;   v1 = 0.215993;     v2 = -0.134556;  v3 = \
 0.118963;     v4 = -0231246;"
}], "Text",
  PageBreakBelow->Automatic],

Cell["\<\
The formula for the mutual inductance had to be modified to include \
the dependence on the wire radius:\
\>", "Text",
  PageBreakAbove->True],

Cell[BoxData[
    \(\(l\_12\) \((r)\)\  = \ \(\[Mu]\_0\/\(2  \[Pi]\)\) \(\(Log[\(\((r\_14 - \
r)\) \((r\_23 + r)\)\)\/\(\((r\_13 + r)\) \((r\_24 - r)\)\)]\)\(.\)\(\
\[IndentingNewLine]\)\)\)], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(r\_ij\)]],
  " denotes the distance of conductors i and j. Three values of the mutual ",
  "inductance",
  " for r = 1, 2, 3, calculated with relaxation, are shown as black dots, the \
thin line represents the formula :"
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P00025A000`40O003h00OogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
6Goo10003Woo0`003goo100037oo1P00ogooogooogoo47oo000GOol8000;Ool5000<Ool80008Ool:
003oOoooOoooOol>Ool001Moo`8000Aoo`8000]oo`D000aoo`8000Aoo`8000Qoo`<000Eoo`<00?mo
oomooomoo`eoo`005Woo0P001Woo0P002Woo1@002goo0P001Woo0P0047oo0P00ogooogooogoo3Goo
000FOol20006Ool2000;Ool3000<Ool20006Ool2000AOol2003oOoooOoooOol<Ool0009oo`d000Io
o`8000Qoo`8001Qoo`8000Qoo`80011oo`800?mooomooomoo`aoo`000Woo3@001Woo0P0027oo0P00
67oo0P0027oo0P0047oo0P00ogooogooogoo37oo0002Ool=0006Ool20008Ool2000HOol20008Ool2
000@Ool2000;Ool6003oOoooOoojOol001Eoo`8000Qoo`8001Qoo`8000Qoo`80011oo`8000]oo`03
001oogoo0?mooomoooeoo`005Goo0P0027oo0P0067oo0P0027oo0P003goo0P0037oo00<007ooOol0
ogooogoooGoo000EOol20008Ool2000HOol20008Ool20007Ool20005Ool3000<Ool00`00Oomoo`3o
OoooOoomOol001Eoo`8000Qoo`8001Qoo`8000Qoo`8000Moo`T000eoo`03001oogoo0?mooomoooeo
o`005Goo0P0027oo0P0067oo0P0027oo0P001goo0P0000=oo`0000000`003Woo00<007ooOol0ogoo
ogoooGoo000FOol20006Ool2000JOol20006Ool20008Ool2000DOol00`00Oomoo`3oOoooOoomOol0
01Ioo`8000Ioo`8001Yoo`8000Ioo`8000Qoo`8001Aoo`03001oogoo0?mooomoooeoo`005goo0P00
17oo0P0077oo0P0017oo0P002Goo0P0057oo00<007ooOol0ogooogoooGoo000GOol8000LOol80009
Ool:000<Ool00`00Oomoo`3oOoooOoomOol001Uoo`@0021oo`@000]oo`X000aoo`03001oogoo0?mo
oomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03
001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoom
Ool0069oo`03001oogoo0?mooomoooeoo`00HWoo1000ogooogooo7oo001ROol00`00Oomoo`3oOooo
OoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00
Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo
001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0
ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo
00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomo
ooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001o
ogoo0?mooomoooeoo`00HWoo1000ogooogooo7oo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03
001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoom
Ool0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomo
o`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001R
Ool00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogoo
ogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<0
07ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeo
o`00HWoo1000ogooogooo7oo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomo
ooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001o
ogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`0YOol3003oOooo
OooAOol0069oo`03001oogoo02aoo`@00?mooomooleoo`00HWoo00<007ooOol0<7oo0`00ogooogoo
bWoo001ROol00`00Oomoo`0cOol4003oOoooOoo6Ool0069oo`03001oogoo03Moo`@00?mooomool9o
o`00HWoo00<007ooOol0>goo0`00ogooogoo_goo001ROol00`00Oomoo`0nOol4003oOoooOonkOol0
069oo`03001oogoo049oo`@00?mooomookMoo`00HWoo00<007ooOol0AWoo0`00ogooogoo]7oo001R
Ool00`00Oomoo`19Ool4003oOoooOon`Ool0069oo`@004aoo`@00?mooomoojaoo`00HWoo00<007oo
Ool0DGoo0`00ogooogooZGoo001ROol00`00Oomoo`1DOol4003oOoooOonUOol0069oo`03001oogoo
05Qoo`@00?mooomooj5oo`00HWoo00<007ooOol0G7oo0`00ogooogooWWoo001ROol00`00Oomoo`1O
Ool4003oOoooOonJOol0069oo`03001oogoo06=oo`<00?mooomooiMoo`00HWoo00<007ooOol0IWoo
0`00ogooogooU7oo001ROol00`00Oomoo`1YOol4003oOoooOon@Ool0069oo`03001oogoo06eoo`<0
0?mooomooheoo`00HWoo00<007ooOol0L7oo1000ogooogooRGoo000IOol4000>Ool3000?Ool4000?
Ool7000;Ool00`00Oomoo`1dOol3003oOoooOon6Ool001Moo`P000]oo`D000aoo`P000eoo`L000]o
o`03001oogoo07Moo`<00?mooomooh=oo`005goo0P0017oo0P002goo1@0037oo0P0017oo0P0047oo
0P003Goo00<007ooOol0NWoo1000ogooogooOgoo000FOol20006Ool2000:Ool5000;Ool20006Ool2
000?Ool2000=Ool00`00Oomoo`1nOol4003oOoooOomkOol001Ioo`8000Ioo`8000]oo`<000aoo`80
00Ioo`8000moo`8000eoo`03001oogoo089oo`<00?mooomoogQoo`000Woo3@001Woo0P0027oo0P00
67oo0P0027oo0P001Woo30002goo00<007ooOol0QGoo1000ogooogooM7oo0002Ool=0006Ool20008
Ool2000HOol20008Ool20006Ool<000;Ool00`00Oomoo`29Ool4003oOoooOom`Ool0009oo`d000Io
o`8000Qoo`8001Qoo`8000Qoo`8000Ioo`8000Ioo`800003Ool007oo00Yoo`H008Yoo`<00?mooomo
ofeoo`005Goo0P0027oo0P0067oo0P0027oo0P001goo0P001Goo0P003Goo00<007ooOol0T7oo1000
ogooogooJGoo000EOol20008Ool2000HOol20008Ool20007Ool30004Ool2000=Ool00`00Oomoo`2D
Ool4003oOoooOomUOol001Eoo`8000Qoo`8001Qoo`8000Qoo`8000Qoo`8000Aoo`8000eoo`03001o
ogoo09Qoo`<00?mooomoof9oo`005Goo0P0027oo0P0067oo0P0027oo0P002Goo0P000goo0P003Goo
00<007ooOol0Vgoo1000ogooogooGWoo000EOol20008Ool2000HOol20008Ool20009Ool30002Ool2
000=Ool00`00Oomoo`2OOol3003oOoooOomKOol001Ioo`8000Ioo`8001Yoo`8000Ioo`8000]oo`80
009oo`8000eoo`03001oogoo0:9oo`@00?mooomooeMoo`005Woo0P001Woo0P006Woo0P001Woo0P00
37oo0P0000=oo`0000003Goo00<007ooOol0YWoo0`00:goo1P00ogooogoo8goo000GOol20004Ool2
000LOol20004Ool2000>Ool4000=Ool00`00Oomoo`2YOol4000UOol:003oOoooOolQOol001Moo`P0
01aoo`P000ioo`@000eoo`03001oogoo0:eoo`<0025oo``00?mooomoob1oo`006Goo100087oo1000
4Goo0`003Goo00<007ooOol0/7oo100077oo3P00ogooogoo7goo001ROol00`00Oomoo`2dOol4000G
Ool@003oOoooOolNOol0069oo`03001oogoo0;Qoo`<001Aooa000?mooomooaioo`00HWoo00<007oo
Ool0^goo10003goo4P00ogooogoo7Goo001ROol00`00Oomoo`2oOol4000;OolB003oOoooOolMOol0
069oo`03001oogoo0<=oo`<000Qooa800?mooomooaeoo`00HWoo00<007ooOol0aWoo100017oo4P00
ogooogoo7Goo001ROol00`00Oomoo`3:OolF003oOoooOolMOol0069oo`@00<eooa800?mooomooaeo
o`00HWoo00<007ooOol0cgoo4000ogooogoo7Woo001ROol00`00Oomoo`3?Ool@003oOoooOolNOol0
069oo`03001oogoo0=1oo`h00?mooomooamoo`00HWoo00<007ooOol0dGoo3`00ogooogoo7Goo001R
Ool00`00Oomoo`3BOol:0004Ool4003oOoooOolIOol0069oo`03001oogoo0=Aoo`H000Yoo`<00?mo
oomooaIoo`00HWoo00<007ooOol0igoo1000ogooogoo4Woo001ROol00`00Oomoo`3[Ool4003oOooo
Ool>Ool0069oo`03001oogoo0>moo`@00?mooomoo`Yoo`00HWoo00<007ooOol0lgoo1000ogooogoo
1Woo001ROol00`00Oomoo`3gOol3003oOoooOol3Ool0069oo`03001oogoo0?Yoo`@00?moooioo`00
HWoo00<007ooOol0oWoo1000ogoonWoo001ROol00`00Oomoo`3oOol3Ool4003oOoofOol0069oo`03
001oogoo0?moo`Moo`@00?mooo9oo`00HWoo00<007ooOol0ogoo2goo0`00ogookgoo001ROol00`00
Oomoo`3oOol>Ool4003oOoo[Ool0069oo`@00?mooa5oo`@00?moonMoo`00HWoo00<007ooOol0ogoo
5Woo0`00ogooi7oo001ROol00`00Oomoo`3oOolIOol4003oOooPOol0069oo`03001oogoo0?mooaeo
o`@008eoo`H00?moodUoo`00HWoo00<007ooOol0ogoo8Goo0`00R7oo2P00ogooAgoo001ROol00`00
Oomoo`3oOolTOol40023Ool<003oOom6Ool0069oo`03001oogoo0?moobQoo`<007moo`h00?moodEo
o`00HWoo00<007ooOol0ogoo:goo1000NWoo4000ogooA7oo001ROol00`00Oomoo`3oOol_Ool3001g
Ool@003oOom4Ool0069oo`03001oogoo0?mooc9oo`@0079ooa800?mood=oo`00HWoo00<007ooOol0
ogoo=Woo0`00Kgoo4P00ogoo@goo001ROol00`00Oomoo`3oOoliOol4001[OolB003oOom3Ool0069o
o`03001oogoo0?mooceoo`@006Mooa800?mood=oo`00HWoo00<007ooOol0ogoo@Goo1000Hgoo4P00
ogoo@goo001ROol00`00Oomoo`3oOom5Ool4001OOolB003oOom3Ool0069oo`03001oogoo0?moodUo
o`<005eooa000?moodAoo`00HWoo00<007ooOol0ogooC7oo1000FGoo4000ogooA7oo001ROol4003o
Oom?Ool4001FOol>003oOom5Ool0069oo`03001oogoo0?mooeAoo`@005=oo``00?moodIoo`00HWoo
00<007ooOol0ogooF7oo1000D7oo2P00ogooAgoo001ROol00`00Oomoo`3oOomLOol3001?Ool6003o
Oom9Ool0069oo`03001oogoo0?mooemoo`@00?mooiYoo`00HWoo00<007ooOol0ogooHgoo1000ogoo
UWoo001ROol00`00Oomoo`3oOomWOol3003oOonCOol0069oo`03001oogoo0?moofYoo`@00?moohmo
o`00HWoo00<007ooOol0ogooKWoo1000ogooRgoo001ROol00`00Oomoo`3oOombOol4003oOon7Ool0
069oo`03001oogoo0?moogIoo`@00?mooh=oo`00HWoo00<007ooOol0ogooNWoo1000ogooOgoo001R
Ool00`00Oomoo`3oOomnOol4003oOomkOol0069oo`03001oogoo0?mooh9oo`@00?moogMoo`00HWoo
00<007ooOol0ogooQWoo1000ogooLgoo001ROol00`00Oomoo`3oOon:Ool4003oOom_Ool0069oo`03
001oogoo0?moohioo`@00?moof]oo`00HWoo00<007ooOol0ogooTWoo0`00ogooJ7oo001ROol4003o
OonDOol4003oOomTOol0069oo`03001oogoo0?mooiUoo`@00?moof1oo`00HWoo00<007ooOol0ogoo
WGoo0`00ogooGGoo001ROol00`00Oomoo`3oOonPOol4003oOomIOol0069oo`03001oogoo0?moojAo
o`@00?mooeEoo`00HWoo00<007ooOol0ogooZ7oo1000ogooDGoo001ROol00`00Oomoo`3oOon/Ool4
003oOom=Ool0069oo`03001oogoo0?mook1oo`@00?moodUoo`00HWoo00<007ooOol0ogoo]7oo1000
ogooAGoo001ROol00`00Oomoo`3oOonhOol4003oOom1Ool0069oo`03001oogoo0?mookaoo`@00?mo
oceoo`006Goo10003Woo0`003goo10003Goo1@003goo00<007ooOol0ogoo`7oo1000ogoo>Goo000G
Ool8000;Ool5000<Ool80009Ool9000=Ool00`00Oomoo`3oOoo4Ool4003oOoleOol001Moo`8000Ao
o`8000]oo`D000aoo`8000Aoo`8000Qoo`@000Aoo`<000aoo`03001oogoo0?moolQoo`@00?mooc5o
o`005Woo0P001Woo0P002Woo1@002goo0P001Woo0P001goo0P001goo0`002goo00<007ooOol0ogoo
c7oo1000ogoo;Goo000FOol20006Ool2000;Ool3000<Ool20006Ool2000AOol2000;Ool00`00Oomo
o`3oOoo@Ool3003oOolZOol0009oo`d000Ioo`8000Qoo`8001Qoo`8000Qoo`80011oo`8000]oo`03
001oogoo0?moom=oo`@00?moobIoo`000Woo3@001Woo0P0027oo0P0067oo0P0027oo0P0047oo0P00
2goo00<007ooOol0ogooegoo1000ogoo8Woo0002Ool=0006Ool20008Ool2000HOol20008Ool2000?
Ool3000;Ool6003oOooHOol4003oOolNOol001Eoo`8000Qoo`8001Qoo`8000Qoo`8000ioo`<000ao
o`03001oogoo0?moommoo`@00?mooaYoo`005Goo0P0027oo0P0067oo0P0027oo0P002goo1@003Goo
00<007ooOol0ogoohgoo1000ogoo5Woo000EOol20008Ool2000HOol20008Ool2000;Ool4000>Ool0
0`00Oomoo`3oOooWOol4003oOolBOol001Eoo`8000Qoo`8001Qoo`8000Qoo`8000ioo`8000eoo`03
001oogoo0?moon]oo`<00?moo`moo`005Goo0P0027oo0P0067oo0P0027oo0P003goo0P0037oo00<0
07ooOol0ogookWoo1000ogoo2goo000FOol20006Ool2000JOol20006Ool2000@Ool2000<Ool00`00
Oomoo`3oOoobOol4003oOol7Ool001Ioo`8000Ioo`8001Yoo`8000Ioo`8000Qoo`8000Ioo`8000ao
o`03001oogoo0?moooIoo`@00?moo`=oo`005goo0P0017oo0P0077oo0P0017oo0P002Goo0`0017oo
0`0037oo00<007ooOol0ogoonWoo1000oWoo000GOol8000LOol8000:Ool8000=Ool00`00Oomoo`3o
OoonOol4003jOol001Uoo`@0021oo`@000eoo`D000moo`03001oogoo0?mooomoo`=oo`@00?Ioo`00
HWoo00<007ooOol0ogooogoo1goo0`00lgoo001ROol00`00Oomoo`3oOoooOol:Ool4003_Ool0069o
o`03001oogoo0?mooomoo`ioo`@00>]oo`00HWoo00<007ooOol0ogooogoo4Woo1000igoo001ROol0
0`00Oomoo`3oOoooOolFOol4003SOol0069oo`03001oogoo0?mooomooaYoo`@00=moo`00HWoo1000
ogooogoo7Goo1000fgoo001ROol00`00Oomoo`3oOoooOolROol3003HOol0069oo`03001oogoo0?mo
oomoobEoo`@00=Aoo`00HWoo00<007ooOol0ogooogoo:Goo1000d7oo001ROol00`00Oomoo`3oOooo
Ool]Ool4001GOol6001_Ool0069oo`03001oogoo0?mooomooc5oo`@0055oo`X006eoo`00HWoo00<0
07ooOol0ogooogoo=Goo1000C7oo3000K7oo001ROol00`00Oomoo`3oOoooOoliOol50016Ool>001[
Ool0069oo`03001oogoo0?mooomoocioo`@0045ooa0006Yoo`00HWoo00<007ooOol0ogooogoo@Woo
1000?Goo4000JWoo001ROol00`00Oomoo`3oOoooOom6Ool4000hOolB001YOol0069oo`03001oogoo
0?mooomoodYoo`@003Aooa8006Uoo`00HWoo00<007ooOol0ogooogooCWoo1000<7oo4P00JGoo001R
Ool00`00Oomoo`3oOoooOomBOol4000/OolB001YOol0069oo`03001oogoo0?mooomooeIoo`@002Qo
oa8006Uoo`00HWoo00<007ooOol0ogooogooFWoo0`009Goo4P00JGoo001ROol00`00Oomoo`3oOooo
OomMOol4000ROol@001ZOol0069oo`03001oogoo0?mooomoof5oo`@001iooa0006Yoo`00HWoo1000
ogooogooI7oo10006goo3P00Jgoo001ROol00`00Oomoo`3oOoooOomYOol4000HOol<001/Ool0069o
o`03001oogoo0?mooomoofeoo`<001Ioo`X006eoo`00HWoo00<007ooOol0ogooogooL7oo100057oo
1P00Kgoo001ROol00`00Oomoo`3oOoooOomdOol40025Ool0069oo`03001oogoo0?mooomoogQoo`<0
089oo`00HWoo00<007ooOol0ogooogooNgoo1000OWoo001ROol00`00Oomoo`3oOoooOomoOol4001j
Ool0069oo`03001oogoo0?mooomooh=oo`@007Ioo`00HWoo00<007ooOol0ogooogooQgoo1000LWoo
001ROol00`00Oomoo`3oOoooOon;Ool4001^Ool0069oo`03001oogoo0?mooomoohmoo`@006Yoo`00
HWoo00<007ooOol0ogooogooTgoo1000IWoo001ROol00`00Oomoo`3oOoooOonGOol4001ROol0069o
o`03001oogoo0?mooomooi]oo`@005ioo`00HWoo00<007ooOol0ogooogooWgoo1@00FGoo001ROol0
0`00Oomoo`3oOoooOonTOol4001EOol0069oo`03001oogoo0?mooomoojQoo`@0055oo`00HWoo1000
ogooogooZgoo1@00C7oo001ROol00`00Oomoo`3oOoooOonaOol40018Ool0069oo`03001oogoo0?mo
oomookEoo`8004Ioo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0
069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3o
OoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol0
0`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoo
oGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007oo
Ool0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`@00?mooomoooaoo`00HWoo00<0
07ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeo
o`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo
0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069o
o`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo000IOol4000>Ool3000?Ool4
0009Ool<000<Ool00`00Oomoo`3oOoooOoomOol001Moo`P000]oo`D000aoo`P000Moo``000aoo`03
001oogoo0?mooomoooeoo`005goo0P0017oo0P002goo1@0037oo0P0017oo0P0027oo0`001Woo0P00
37oo00<007ooOol0ogooogoooGoo000FOol20006Ool2000:Ool5000;Ool20006Ool20008Ool3000C
Ool00`00Oomoo`3oOoooOoomOol001Ioo`8000Ioo`8000]oo`<000aoo`8000Ioo`8000Uoo`<0019o
o`03001oogoo0?mooomoooeoo`000Woo3@001Woo0P0027oo0P0067oo0P0027oo0P002Goo0`004Goo
00<007ooOol0ogooogoooGoo0002Ool=0006Ool20008Ool2000HOol20008Ool2000:Ool3000@Ool0
0`00Oomoo`3oOoooOoomOol0009oo`d000Ioo`8000Qoo`8001Qoo`8000Qoo`8000]oo`<000moo`H0
0?mooomoooYoo`005Goo0P0027oo0P0067oo0P0027oo0P0037oo0`003Woo00<007ooOol0ogooogoo
oGoo000EOol20008Ool2000HOol20008Ool2000=Ool3000=Ool00`00Oomoo`3oOoooOoomOol001Eo
o`8000Qoo`8001Qoo`8000Qoo`8000ioo`8000eoo`03001oogoo0?mooomoooeoo`005Goo0P0027oo
0P0067oo0P0027oo0P003goo0P0037oo00<007ooOol0ogooogoooGoo000EOol20008Ool2000HOol2
0008Ool2000?Ool2000<Ool00`00Oomoo`3oOoooOoomOol001Ioo`8000Ioo`8001Yoo`8000Ioo`80
00Moo`8000Moo`8000aoo`03001oogoo0?mooomoooeoo`005Woo0P001Woo0P006Woo0P001Woo0P00
1goo0`001Woo0P0037oo00<007ooOol0ogooogoooGoo000GOol20004Ool2000LOol20004Ool20008
Ool40004Ool2000=Ool00`00Oomoo`3oOoooOoomOol001Moo`P001aoo`P000Uoo`P000ioo`03001o
ogoo0?mooomoooeoo`006Goo100087oo10003Goo1@003goo00<007ooOol0ogooogoooGoo001ROol0
0`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoo
oGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007oo
Ool0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`@00?mooomoooaoo`00HWoo00<0
07ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeo
o`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo
0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069o
o`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOooo
OoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00
Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo
001ROol00`00Oomoo`3oOoooOoomOol0069oo`@00?mooomoooaoo`00HWoo00<007ooOol0ogooogoo
oGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007oo
Ool0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00
HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mo
oomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03
001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoom
Ool0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol4003oOooo
OoolOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00
Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo
001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0
ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo
00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomo
ooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001o
ogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol4003oOoooOoolOol0069oo`03
001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoom
Ool0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomo
o`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001R
Ool00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`006Goo10003Woo0`003goo
10002goo2P0037oo00<007ooOol0ogooogoooGoo000GOol8000;Ool5000<Ool80009Ool:000<Ool0
0`00Oomoo`3oOoooOoomOol001Moo`8000Aoo`8000]oo`D000aoo`8000Aoo`8000eoo`80011oo`03
001oogoo0?mooomoooeoo`005Woo0P001Woo0P002Woo1@002goo0P001Woo0P0037oo0P0047oo00<0
07ooOol0ogooogoooGoo000FOol20006Ool2000;Ool3000<Ool20006Ool2000<Ool2000@Ool00`00
Oomoo`3oOoooOoomOol0009oo`d000Ioo`8000Qoo`8001Qoo`8000Qoo`8000]oo`80011oo`03001o
ogoo0?mooomoooeoo`000Woo3@001Woo0P0027oo0P0067oo0P0027oo0P002goo0P0047oo00<007oo
Ool0ogooogoooGoo0002Ool=0006Ool20008Ool2000HOol20008Ool2000;Ool2000@Ool6003oOooo
OoojOol001Eoo`8000Qoo`8001Qoo`8000Qoo`8000]oo`80011oo`03001oogoo0?mooomoooeoo`00
5Goo0P0027oo0P0067oo0P0027oo0P002goo0P0047oo00<007ooOol0ogooogoooGoo000EOol20008
Ool2000HOol20008Ool2000;Ool2000@Ool00`00Oomoo`3oOoooOoomOol001Eoo`8000Qoo`8001Qo
o`8000Qoo`8000]oo`80011oo`03001oogoo0?mooomoooeoo`005Goo0P0027oo0P0067oo0P0027oo
0P002goo0P0047oo00<007ooOol0ogooogoooGoo000FOol20006Ool2000JOol20006Ool2000<Ool2
000@Ool00`00Oomoo`3oOoooOoomOol001Ioo`8000Ioo`8001Yoo`8000Ioo`8000aoo`80011oo`03
001oogoo0?mooomoooeoo`005goo0P0017oo0P0077oo0P0017oo0P002Goo0`0000=oo`00000047oo
00<007ooOol0ogooogoooGoo000GOol8000LOol80009Ool6000@Ool00`00Oomoo`3oOoooOoomOol0
01Uoo`@0021oo`@000ioo`<0011oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoo
oGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007oo
Ool0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00
HWoo1000ogooogooo7oo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeo
o`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo
0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069o
o`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOooo
OoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00
Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo
001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo1000ogooogoo
o7oo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007oo
Ool0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00
HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mo
oomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoomOol0069oo`03
001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomoo`3oOoooOoom
Ool0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001ROol00`00Oomo
o`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo1000ogooogooo7oo001ROol00`00
Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo
001ROol00`00Oomoo`1FOol4000>Ool3000=Ool6001COol:001AOol:000;Ool3000=Ool6001AOol<
001?Ool<000;Ool3000=Ool6001EOol5001aOol0069oo`03001oogoo05Aoo`P000]oo`D000Yoo`X0
055oo`X0055oo`X000Yoo`D000Yoo`X004moo``004moo``000Yoo`D000Yoo`X0055oo`T006moo`00
HWoo00<007ooOol0E7oo0P0017oo0P002goo1@002Woo0`001Goo0`00E7oo0P00FGoo0P003Woo1@00
2Woo0`001Goo0`00Cgoo0`001Woo0P00D7oo0`001Woo0P002Woo1@002Woo0`001Goo0`00Cgoo1000
17oo0`00KWoo001ROol00`00Oomoo`1COol20006Ool2000:Ool5000COol2001DOol2001IOol2000>
Ool5000COol2001@Ool3001HOol3000AOol5000COol2001?Ool20007Ool3001]Ool0069oo`03001o
ogoo05=oo`8000Ioo`8000]oo`<001Eoo`8005=oo`8005Uoo`8000moo`<001Eoo`80051oo`<005Qo
o`<0015oo`<001Eoo`8005Qoo`8006eoo`00HWoo00<007ooOol0DWoo0P0027oo0P008Woo0P00Dgoo
0P00FGoo0P009goo0P00DGoo0`00F7oo0`00:7oo0P00F7oo0P00KGoo001ROol00`00Oomoo`1BOol2
0008Ool2000ROol2001COol2001IOol2000WOol2001BOol3001HOol3000WOol2001HOol2001]Ool0
069oo`03001oogoo059oo`8000Qoo`80029oo`8005=oo`8005Uoo`8002Moo`8005=oo`<005Qoo`<0
02Ioo`8005Moo`<006eoo`00HWoo00<007ooOol0DWoo0P0027oo0P008Woo0P00Dgoo0P00FGoo0P00
9goo0P00E7oo0`00F7oo0`009Goo0P00EWoo0`00KWoo001ROol00`00Oomoo`1BOol20008Ool2000Q
Ool2001DOol2001IOol2000VOol2001FOol3001HOol3000SOol2001DOol5001_Ool0069oo`03001o
ogoo059oo`8000Qoo`8001Uoo`8000Eoo`<005Aoo`8005Uoo`8001ioo`8000Eoo`<005Moo`8005Uo
o`8001]oo`8000Eoo`<005Aoo`@0071oo`00HWoo00<007ooOol0DWoo0P0027oo0P006Goo2@00EGoo
0P00FGoo0P007Woo2@00FGoo0P00FGoo0P006Woo2@00F7oo0P00Kgoo001ROol00`00Oomoo`1BOol2
0008Ool2000IOol200000goo00000003001FOol2001IOol2000NOol200000goo00000003001JOol2
001IOol2000JOol200000goo00000003001JOol2001^Ool0069oo`@0059oo`8000Ioo`8001Yoo`80
05aoo`8005Uoo`8001ioo`8005Moo`8000Moo`80051oo`8000Moo`8001Yoo`80061oo`8006ioo`00
HWoo00<007ooOol0Dgoo0P001Woo0P006Woo0P00G7oo0P00FGoo0P007Woo0P00Egoo0`001Woo0P00
D7oo0`001Woo0P006Woo0P00F7oo0P001Woo0P00KWoo001ROol00`00Oomoo`1DOol20004Ool2000K
Ool2001HOol300000goo0000001EOol300000goo0000000NOol2001GOol40004Ool2001AOol40004
Ool2000KOol2001HOol30004Ool3001^Ool0069oo`03001oogoo05Aoo`P001]oo`X0051oo`H005Eo
o`H001ioo`X0051oo`P005=oo`P001aoo`X0055oo`P006moo`00HWoo00<007ooOol0EWoo10007Goo
2P00Dgoo0`00F7oo0`007Woo2P00DWoo1@00EWoo1@007Goo2P00DWoo1@00LGoo001ROol00`00Oomo
o`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogooogoooGoo001R
Ool00`00Oomoo`3oOoooOoomOol0069oo`03001oogoo0?mooomoooeoo`00HWoo00<007ooOol0ogoo
ogooi7oo30003Goo001ROol00`00Oomoo`3oOoooOooTOol<000=Ool0069oo`03001oogoo0?mooomo
onQoo`8001=oo`00HWoo00<007ooOol0ogooogooj7oo0P004goo001ROol00`00Oomoo`3oOoooOooX
Ool2000COol0069oo`03001oogoo0?mooomoonQoo`8001=oo`00HWoo00<007ooOol0ogooogooj7oo
0P004goo001ROol00`00Oomoo`3oOoooOooXOol2000COol0069oool00?l00=0001]oo`8001=oo`00
N7oo00<007ooOol04goo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol0
4goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04goo00<007ooOol04Woo00<007ooOol0
4goo00<007ooOol04goo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol0
4goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04goo00<007ooOol04Woo00<007ooOol0
4goo00<007ooOol04goo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol0
4goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04goo00<007ooOol04Woo00<007ooOol0
4goo00<007ooOol04goo00<007ooOol0;goo0`004Woo001hOol00`00Oomoo`0COol00`00Oomoo`0C
Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0C
Ool00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0C
Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0C
Ool00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0C
Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0C
Ool00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0_
Ool4000AOol007Qoo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=o
o`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo019o
o`03001oogoo01=oo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=o
o`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo019o
o`03001oogoo01=oo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=o
o`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo019o
o`03001oogoo01=oo`03001oogoo01=oo`03001oogoo02moo`800003Ool0000000Aoo`8000Yoo`00
cgoo00<007ooOol0JGoo00<007ooOol0JWoo00<007ooOol0JGoo00<007ooOol0JWoo00<007ooOol0
JGoo00<007ooOol0F7oo1@000Woo1`002Woo003?Ool00`00Oomoo`1YOol00`00Oomoo`1ZOol00`00
Oomoo`1YOol00`00Oomoo`1ZOol00`00Oomoo`1YOol00`00Oomoo`1HOol50004Ool4000;Ool00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00Cgoo1@00Dgoo1@00ogooogoo
]Woo001?Ool50006Ool2001;Ool5003oOoooOonfOol004moo`8000Uoo`8004ioo`800?mooomookIo
o`00Cgoo0P002Woo0P00CGoo0P00ogooogoo]Woo001?Ool2000:Ool2000TOol2000WOol2003oOooo
OonfOol004moo`8000Yoo`8002Aoo`<002Ioo`800?mooomookIoo`0057oo3@001Woo2P001Woo3000
37oo0P002Woo0P0000=oo`0000000P000goo1@000Woo1`000Woo1`001Woo0P002goo1P000Woo1000
0Woo10002Goo0P00ogooogoo]Woo000DOol=0006Ool:0006Ool<000<Ool2000:Ool80002Ool50002
Ool70002Ool70006Ool2000;Ool60002Ool40002Ool40009Ool2003oOoooOonfOol001Uoo`80011o
o`8000]oo`<000Ioo`8000aoo`8000]oo`8000Aoo`800003Ool0000000Moo`8000Qoo`8000Uoo`80
00aoo`8000Aoo`8000Aoo`8000]oo`800?mooomookIoo`006Goo0P0047oo0P0037oo0`004goo0P00
2goo0P001Woo0`001goo0P0027oo0P002Goo0P0037oo0P0017oo0P0017oo0P002goo0P00ogooogoo
]Woo000IOol2000@Ool2000=Ool3000BOol2000;Ool20007Ool20007Ool20008Ool2000:Ool2000;
Ool20004Ool20004Ool2000;Ool2003oOoooOonfOol001Uoo`80011oo`8000ioo`<0015oo`8000]o
o`8000Moo`<000Ioo`8000Qoo`8000Yoo`8000]oo`8000Aoo`8000Aoo`8000]oo`800?mooomookIo
o`006Goo0P0047oo0P003goo0`0047oo0P0037oo0P001goo0P001Woo0P0027oo0P002goo0P002Woo
0P0017oo0P0017oo0P002goo0P00ogooogoo]Woo000IOol2000@Ool2000@Ool3000?Ool2000<Ool2
0007Ool20006Ool20008Ool2000;Ool2000:Ool20004Ool20004Ool2000;Ool2003oOoooOonfOol0
01Uoo`80011oo`80015oo`<000ioo`8000aoo`8000Moo`8000Ioo``000]oo`<000Uoo`8000Aoo`80
00Aoo`8000]oo`800?mooomookIoo`006Goo0P0047oo0P004Woo0`003Goo0P0037oo0P001goo0P00
1Woo300037oo0P002Goo0P0017oo0P0017oo0P002goo0P00ogooogoo]Woo000IOol2000@Ool2000C
Ool2000=Ool2000<Ool20007Ool30005Ool20008Ool2000<Ool20009Ool20004Ool20004Ool2000;
Ool2003oOoooOonfOol001Uoo`80011oo`8001Aoo`8000aoo`8000eoo`8000Moo`8000Eoo`8000Qo
o`8000eoo`8000Qoo`<0009oo`@0009oo`<000]oo`800?mooomookIoo`006Goo0P0047oo0P0057oo
0P0037oo0P003Goo0P001goo0P001Goo0P0027oo0P003Goo0P001Woo3`0037oo0P00ogooogoo]Woo
000IOol2000@Ool2000;Ool20007Ool2000<Ool2000MOol20008Ool2000>Ool20005Ool400000goo
000000020002Ool3000=Ool2003oOoooOonfOol001Uoo`80011oo`8000]oo`<000Ioo`8000aoo`80
01eoo`8000Qoo`8000ioo`80021oo`800?mooomookIoo`006Goo0P0037oo0`0000=oo`0000002goo
100017oo0P003Goo0P006goo1`000Woo1`0037oo0`007goo0P00ogooogoo]Woo000IOol2000<Ool6
000<Ool8000>Ool2000KOol70002Ool7000=Ool2000OOol2003oOoooOonfOol001Aoo`L000moo`<0
00ioo`D000moo`D003Eoo`8001aoo`D00?mooomookIoo`0057oo1`00=7oo1@00=Woo0P006goo1@00
ogooogoo]Woo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOooo
OomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=o
o`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003o
OoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomo
oomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00001\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The overall agreement of the relaxation calculation with the \
theoretical expressions is satisfactory.\t

The procedures developed until now will be applied to calculate the crosstalk \
of coupled microstrip lines in the following section.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Pigtail", "Section",
  PageBreakAbove->Automatic],

Cell["\<\
The physical dimensions of the pigtail connector for the ATLAS \
detector are shown in Fig. 7.\
\>", "Text"],

Cell[GraphicsData["PICT", "\<\
m`P0000003h1O@0A0_l<0?on0001;0000B`0000000011PHe0000002Q09H02P40
000000000000X02H0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G
0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40000000000000X02H
0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G0:40UP0:0@000000
0000002P09P0X02I0:00U`2Q09H02P40000000000000X02H0:00V@2P09L07P01
00X000000@H6=@0/00T00`I7IFiUMV4000<00`0=00`0;P04003o000[0@41800Y
004P00070000000S0000X02n0:40`00=HgEbLVE^M71_JFid3@00X02o0280?P5l
0000X02n0:40`03;HgEbLVE^M71_JFid838PJFiTIGPPLgER86EhHfPP<b1YKVAU
N21cMF8=83<h<20PI6Uf86EhHfPP3B0f<R0PI6Uf83<PJFiTIGPP3B0`821cMF8P
<b1YKVAUN20=830P87=eHR0d838PLVm/K20e86U^I6Eh83DPJFiTIGPPM79QKW=/
HGAU3FiUIb1cHf5/I@dd838PLVm/K21^IFLPIGQSJ21^IFLPIGQSJ21dLV5^LfaQ
M6DP3B0f<R0PLgER87AbHFicK65dI@d00:40`0559B5@Dbe1I6mRIBdc;S0PAE1C
ARdc;S0=9BE2KgE^I6U^Id9_N3XP830P<20c>30P=S8P3BDUE6UdK6Dj82Q3Kf5h
;T=>ERTP3BDU@g9UHGA_LSXP@f5^MV5c82Pg;S0^<RTP3BDU@g9UHGAYKfi4HGAU
>R0X<3H_<34_<34P@20a<SXc<R1@CBTP3BDUA6mSMFeUKWA@LVmSDfEdLcXPA6E^
IF9QGd=QKWIQLd=eLgA_KD=_K6mbL`dU9B/P@eI4JF=d3BDUA6mSMFeUKWA6Kfid
LcXP3BDUA6mSMFeUKWA>IFETIFA6KfidLcXPAfE^IGIQ3@dU9DA_HgE]IFidD79_
HfEcLd=_K6mbLcXP@gUQKR1=HFMUKWAQ85UUK6a_Mb12K65SJ`dU9DE^I4=_KFeU
KWAc3BDU@VEWJFi@LVm/KfLP3@00X@30@00U9D9UIfU^DVEcKgEbHfDj871bKf=c
IG@P@eI4JF=d3BDUE6UdK6Dj84AUKVERHB1cM65^I65bI21WLV5`J6USL`dU9EIU
LW=YKfhj834^<38=9BE3LVEQM6U_KTAQM6Dj834`;c4d;cTi3BDU@fm`NG9YIfQd
>R0X@bTP<CTi=2`P<CTi>B14IFiUHV4PDgUcM6E]LbhP@Fa/859YIfQdLb1BIG=U
LWIUI0eeLfEbI6USM20_@eI4JF=d838`<21TJF=d871eM0e3ETAYHg@PHVEWJFh=
;fU^MV5/JFASKfa_LWAQHVaU?b1dLWEU86AUIR0P80d_K6EfIF`b82m/HFiWMF5W
IFaUMVE/87MXIG9U87]`Kg0PK65^IgEQIfE/IGIUK20b86MUOG]VHFacIGdPJFIU
K7=U86AUIPe/IGIUK38PKVmd87/P;gQcJ6mg87/=<21SMG9bIFidL6mYKW@P=B0]
<B1bKfa/87]`Kg0PL6m`86e_MVEdKb1TMG0P<B1QI6@P<b0a879_K6`PIGQSJ21T
MG0P=20a879_K6`PIGQSJ21WIG@P<21bKFmfIGA_86=eLW9UKWA`KfU^M7dPIGQS
J21[LfQ_M`e`Kg0PL6m`871_L21`Kg1m86AUIR1m86UV3BmYKVUdJF5/JGYU3G]3
ETAYHg@=NfAeL21hHfQUHf]kHVU^I7eYIR1`Kg0PL6m`OFI_LV5/K0eSMG9bIFid
Lf=bIFE^82mOLg0PIGQSJ21TIFHP;emcHB1UN6=X86AUIR0_Gg=V86EhHfPPI6EV
3Bm4IFIQMFadDf=bIFE^NemcIR1OLf4P;emcL21/Kf5TOFAUIPd_A6EVHGE/M5=S
LVEUKU1bKf=k82mOLg0PK6mQI7eTIFH=;g=UM7=dLVm[IF5TJWEcM21gJ6EbIG]`
Kg0PM79eIGekIV5/LfEmJFIUK7=U3G/_Lf4P;g=UM7=dLVm[IF5TJWEcM21/Kf5T
86AUIPd_K6TP;faYKVEdKb1/Kf5T86AUIPd_KG@P;fe_MVEdKb1/Kf5T86AUIPd_
Hg@P;f=eLWIUM6lPK6mQI21TIFH=;faX87/PHgEbLVE^M71_JFid86EhHfPPL6m`
86aYKVEdKgeRJFiT86AUIPd_K7HPNb1SMG9bIFidL6mYKW@PL6m`86EhHfPPK6U^
IGA_OF9YKV@PI6EVO@ek;g=QNg]SMG9bIFidI6USM21CM79_JfE1I6YeLgA4JF=d
86iUNe=dLVm[ID5TJWEcM4AYHg@PHVEWJFimJFImNb1SMG9bIFidI6USM21CM79_
JfE1I6YeLgA4JF=d86EaNfE^I7eYIWeYIVE/LfEm869YKV@PI6EV3GEcIG9TJF=d
82mCM79_JfE1I6YeLgA4JF=d834`<21TJF=d871eM0eCM79_JfE1I6YeLgA4JF=d
869UIfU^3BmON6`=NgAbHFicIVmbK@d^<SDPLgER879_MFiT82hb=B1QI6@PIGQS
J0d^<SDPLgER879_MFiT82hb=B1QI6@PIGQSJ0eYM79QKW=VKg9]3GeRJFiT86AU
IPd_K6Uk85mhK21/JFiUM6mmHVU^I21TIFH=;fedNb1ON6`PKFmfIGA_OF9YKV@P
I6EV3BmSM7/PGgQ/86=eLWIUM6mmHVU^I21TIFH=;faX87/PI7E`85mhK21`Kg0P
HgEbLVE^M71_JFid86EhHfPPL6m`86aYKVEdKgeRJFiT86AUIPd_K7HPNb1TMG0P
GgQ/871_L21SMG9bIFidL6mYKW@PL6m`86EhHfPPK6U^IGA_OF9YKV@PI6EV3Bmb
L7]ON6`_HgIOHR1hI6H_HgIOLR1hI6H=GgQ/;f=fGg@PN6AV;f=fGf`PN6AV3F=f
Gf`PHgIOM21]KgIUM6l=HgIOLR1SMUmd86aYKVEdK`eSMUmb86=fGf8PK6U^IGA_
3F=fGf`PHgIOHR1/JFiUM6l=Hfa_LfE`HGAX3GeRJFiT86AUIPeUKVAmJFIUK7=U
OFAUIPd_M6EbKFU^HGAU3G]eLfEbI6USM20_DgAbKf]U@FAZMG=dA6USM21[KVmg
KR1kHgEbLVE^M6AYHg@PDgAbKf]U@FAZMG=dA6USM21ULG]UKVAmJFImJFH=HgEb
LVE^M6AYHg@P@eI4JF=d86EaNfE^I7eYIWeTIFH=;fehCF5h83Hd86AUIPd_KGQC
M6/PFfehCF5h87]]HGAbJGQm879UL6EQM5eTIFH=;fehBFAh830PI6EV3BmcM6ek
KGQCM6/PKGQ9I7PP<21/M21k;fehBFAh830PLgA_LVEmJFHPKGQ9I7PPIfEd86=e
LW9UKWA]HGAbJGPPL6m`82m]N4UTN21]N4UTN20a865TI21cM6mbIGeTIFH=;g9d
KG]]N4UTN20a86MU87/_KGQ9I7PPKGQ9I7PP<B1cMF8PLgA_LVDPKGQCM6/PKGQ9
I7PPIfEd87=UM6eQM79YN7eYIR1mI6EV3BmcHf`PNb0g<R1TJGHPIGQSJ20g<R1T
JGHPIGQSJ21cHf5/IB1m86AUIPd_Lf=/JB1k83Lb86EhHfPPI6Uf86EhHfPP=c8P
IGQSJ21TJGHPIGQSJ21cHf5/IB1m86AUIPd_Gf=fKGAh86eQM79YN21TIFH=;emd
N7A]M7PPKF5dLVUh86AUIPd_GfU^JGA]M7PPKF5dLVUh86AUIPd_N6AVNfEhHfPP
I6EVOFAUIPd_KFU^Nc8PHfm`NB1WM7]UN6=XOFUV871_L7eTIFH=;feQN7/b86=_
L7TPK7AkIGQSJ7eYIR1`Kg1mI6EV3Bm3EWIUHb0b=CHPHG9bHGTPI6EV3BmD87Ab
MFDPI6EV3Bm686IQK7=U86AUIPd_GfUT830PI6EV3BmOIFiSKfAYKVAUN20`86AU
IPd_GfE^HfmT@G9b83<PHG9bHGTPI6EV3BmOIV@P<21TIFH=;emdIGQdDf5fIB1^
MFa/86AUIPd_GfaUM7AULU=`HF=U830PI6EV3BmOLg1QHfEHM79Q830PI6EV3BmO
D65WIE=QMVDPKWE/K21TIFH=;em`IFiX834^<21TIFH=;em`IFif834^<21TIFH=
;g=QMVD`86ieK6`PI6EV3BmOMb0`86AUIPd_GfPP<21TIFH=;emTLb0`86AUIPd_
J6=d86IQK7=U86AUIPd_L7LP<21TIFH=;gMTJFHP<21TIFH=;gAUKG0P<21TIFH=
;f=eLW9_M20`86AUIPd_Lf5fIFQQKVA/IG8PKWE/K21TIFH=;fUQ830PI6EV3BmY
N20`86AUIPd_JGQ^834PI6EV3Bm=MFadJG1/IDAQM65CKgEbHfEc86IQK7=U86AU
IR0=;fAUHWEW3G]TMG0P;bAUL7<PIGQSJ21^Kg@PI6EVNbmcHGIUJ65^I6aULR1U
LW9_LVAYHg@P;fQQKVA/IFEbLVmb86MUM21TIFH=IG9bKg9TJF=d3BmXHFiTK6EU
LW9_LW/TIG9bKg8PHVEWJFh=KVEgIG9bKg9k;fiUMfEbLVmb86IQK7=U86AUIPec
J6mgL65WI@dg<R0g<R1cHf5/I@d_B6E/MVEdJF=Q86IYKVAVKfid82hb87=SHFaU
IVm^M21cIGAVKfid3Bhb=B0i;SHPKFmfIGA_3BQ5LW9_LSXP:G=XKgL=IG9bKg9^
HFeU3G]TMG0PM7U`IBmcM79YKVMdNG1U86iU3G/XHfm^MVEbM6ET86EbLVmb86iQ
KFDPMfU/K21UKV@PMG0PJFhPM6QYLb1cM79YKVLYHgIcOFUV3G=XKgMmIGQUH`d^
<SDP>Bhd86e_MVEdK`dXCfIVIFiTJFiW84=_KFeQKV@j82UcJ6mg3BmSKfe]HFiT
86a_HF@=NfAeL21dNG1U;g=dLVU^IgAiL6DPKVD=NbQSKfifIG9dIF@PHfm]KF5^
I21^HFeU87MYK6`PIFiT87E`86U^87AXJG<PLgAbJFiW:F=fLgeYIPecJ6mgOFEh
IF<=;S8e83T^<R1]KgIUM6l=:5=dHF=[>R0YLfQ_M`e_LgAQHf/=Nbhb=B1SMG9b
IFidL6mYKW@P;S8PLgER86EhHfPPL6m`86e_MVEdK`eTMG0PM7U`IBmcM79YKVMd
NG1U86iUNfAeL21dNG1U;fU^M6EWIG9dNG1U86Ea3C4PJFiTIGPPM7U`IBmbIF5/
M7U`IB1ULB1_LPda86U^I6Eh87AiL6D_KV5]IGAiL6DPIG4PKg8=KVmd87]dNG1U
OFUV3BQSKfifIG9dIF@PLgAQHf/PMfU/K21UKV@PMG0PJFhPM6QYLb1cM79YKVLY
HgIcOFUV3G=XKgMmIVmbHFa/3G=XKgM`HFMU3D=FA6USM20_Lf5fIFQQKVA/IG8P
IfEd86EhIF=mJFH=IFiTOG1eM7eYIWeTIFH=;faSNg=UM6aYKVESHG1mI6EV3Bm/
JW]cIGA/JFiUJVmYKWeTIFH=;fa]Ng=UM6eYM6EbK6U]JGAmI6EV3Bm/IW]cIGAV
K65dOFAUIPd_Hg1kHfa_LfE`HGAXOFAUIPd_KW1kKVEgL65dJ7eTIFH=;bA`LgXP
<c0PHG9bHGTPI6EV3BlTL6Uh830PI6EV3BmWLg]WLf5fIB0TL7=j86AeL20TL6Uh
85m`IFiX871eM20TL6Uh834PHFAT85m`IFif871eM20_971YN20TL6Uh838PHFAT
86AUIWeTIFH=;fMbNfMbIG=dKg9U;bA`JGPP971YN20b87=eHR1TIFHP971cNR1T
MG0P971YN21WIG@P;em`IFiX86EhHfPPI6EV82A`JGPP<B1QI6@PIfEd82mOL6E^
MR1UN6=X86AUIWeTIFH=;faYNfaYKVEdKgdPI6EV3Bm/J7]SMG9bIFidL6mYKW@P
IGQSJ21`Kg0PK6U^IGA_OFAUIPd_K7IkHgEbLVE^M71_JFid871_L21UN6=X86aY
KVEdKgeTIFH=;fedNfe_MVEdKgdPI6EV3BmOHgIOKFQkHgEbLVE^M71_JFid86Eh
HfPPL6m`86e_MVEdKgeTIFH=;emSMUm]MW]SMG9bIFidL6mYKW@PL6m`86EhHfPP
KFmfIGA_OFAUIPd_HgAkHgEbMVEdKgdPI6EV3BmbM7/d82db879_K6`PKFmfIGA_
3FAeL20`86EhHfPPLVaYKVEdK`eUN6=X830PLVaYKVEdK`e^IFLP<21UN6=X879/
JFiUM6l=Hfa_LfE`HGAXOFAUIPd_GfQb3G/=Nbm0IG9b86IQK7=U86AUIR1SMG9b
IFidIVaQM21TMG1kIg=QMVEkIFmSK6U`OG=dKg1`IFAkIg9ULgA_LVDP<R1]MF`P
I7E`87=UM6I/HG@PI7E`838`<21WIG/X9BDP@f5^MV5c>T=/JG0PIV5YK6ETG78Y
L79YKW@P;d1ULW8PM79eIB1TIFHPL6m`86EhJGAmJFImNfMbIG=dKg9U87=UM6I/
HG@PIGQYM7eYIVE/LfEmK6m_L210IG9b86i_M21kIFmSK6U`OFUV87=UM6I/HGAm
3G/_@6EbLR1VHFacIB1TIFHPHgEbLVE^M6I/HG@PI7E`NfMcHGIUNf=/JG1mLgA_
L71UI7]WLVEcM6mbIB0b86eeK21TMG0PLfEdIVaQM21TMG0P<S0`86MUNbPU9B13
HFifHG<j@faYL21VHFU/IFALLRU`LVU^M20_@6EbLR1dLWEU86AUIR1`Kg0PIGQY
M7eYIWekIg9ULgA_LVDPLfEdIVaQM21UN6UdOFUVIFacIGe/Kfm`841ULW8PKVmd
87]SK6U`OFUV87=UM6I/HGAm3GeTIFH=;emSLb1^MFa/86AUIPd_IVMkLfEdIg9Q
NGeTIFH=;g=UM6=]NF]SKfa_LR1gJ6EbIB1kL6m`87AbMFEmNfIQK7=UOFUVIFac
I@ek;fHdNb1cIGASKGU[Hfm/Kg9mI6EVOG/_ISAk<B1cMF8P=20a879_K6`P<g/c
86U^I6Eh865TI21^IFLPI7E`830PK7AkL6m`831mJFHP<b0a879_K6amLVE`IF5d
87=UM79WHV=_K6mb871_L7eTIFImJFIUK7=U3BmcIGASKfa_LW=`HF=U87MXIG9U
87]`Kg0PM79eIGekIV5/LfEmJFIUK7=U3G/_Lf=cNb1TMG0PLfEdHfm/Kg9cL65S
IB0_Gf=c86EhHfPPI6EVOFAUIRmV<g/PGf=c87=UM6=_K6mbLg1QHfDPLfEdHfm/
Kg9mI6EV3Gek;fHcNb1cIGAbIf9SKfa_LWeTIFH_Lf=cNb1`Kg1mI6EVOFUVIFac
I@d_96=S83DPHG9bHGTPI6EV3BmVJFiTHfeiJf=eLgA_KF=_K6mb87MXIG9U87]`
Kg0PM79eIGekIV5/LfEmJFIUK7=U3Fi_M21k;fIYKVASKGU[HgEcM6m]Hfm/Kg9k
96=S865cM6mbIGeTIFImJFH=;g=UM6=eLgA_KF=_K6mb87MXIG9U87]`Kg0PM79e
IGekIV5/LfEmJFIUK7=U3Fi_M7/_LfEdHgEcM6m]Hfm/Kg9kIGQSJ21QK6mQI21`
Kg0PL6m`83Ak=21YKVAUN21]MF`P=20a879_K6amLVE`IF5d87=UM6=]NF]SKfa_
LR1`Kg1mI6EVOFUV3BmVHg/f834PLVm/K21VJFiTHfeiJf=eLgA_KF=_K6mb86Eh
HfPPLfEdHgEcM6m]Hfm/Kg9mI6EV3BmcIGAcIG1QLV5dJFm^Ig9QNB1gJ6EbIB1k
L6m`87AbMFEmNfIQK7=UOFUVIFacI@e^KgAk;g=UM7=UL65bHGAYKfiWLV5i87]c
NG=dIFeTJF=d82mcIGAWLV5i86MUM21UN6ESOB1TIFImJFH=;g=WNb1cIGAcIG1Q
LV5dJFm^Ig9QNGeTIFH=;g=`NbmOL6E^MR1hI6H_Gg1UKVPPN6AVOFAUIPd_LW0=
NbmSMUmR87QTIRmSMUmb87QTIPd_HgIOM21hI6H_HgIOK21hI6H=HgIOK21SMUmd
86e_MVEdK`eSMUmb86=fGg@PK6U^IGA_3F=fGg8PHgIOHR1/JFiUM6l=HgIOK21S
MUmR86aYKVEdK`eSK6mcIG1QM6QmI6EV3BmbLW/_NG9QI6UeLb1hI6H=;gQbHFAY
MG<PN6AV3BmSMUmR87QTIPd_HgIOLR1hI6H=;f=fGg@PN6AV3BmSMUm/87QTIPeS
MUm/87QbHFAYMG<PHFAT86=fGg@PKFmfIGA_3F=fGg8PN79QI6UeLb1cMF8PHgIO
M21/JFiUM6l=Gf=fKGAh86=eLW9UKWA]HGAbJGPPL6m`3F=eLW9UKWA`KfU^M21d
LV5^LfaQM6D=N79QI6UeLb1iLV5TJGEc87=SHFaU3C4P<20a834P<B1QLV=dKb0d
Ng1_L7ebIG1UHG@=Gf=fKGAh87=UM6eQM79YN0eSMUmb86=fGf8PNG9QI6UeLb1c
MF8PK6U^IGA_3EmSMVedN21SMG9bIFidKF5dLVUh871_L0eSMG9bIFidL6mYKW@P
M79QKW=/HGAU3GQbHFAYMG<PNG9QI6UeLb1cHf5/I@d`834P;C4P<B0a865bHgA_
83AkL6m`OG9UL6EQM0eOHgI]M7PPLfEdKF5dLVUh3F=fGf`PN79QI6UeLb1QI6@P
HgIOHR1/JFiUM6l=Gf=fKGAh86=eLW9UKWA]HGAbJGPPL6m`3F=eLW9UKWA`KfU^
M21dLV5^LfaQM6D=N79QI6UeLb1iLV5TJGEc87=SHFaU3Bda830P;C4P;C4P<B1Q
LV=dKb0dNg1_L7ebIG1UHG@=Gf=fKGAh87=UM6eQM79YN0eSMUm/86=fGg@PNG9Q
I6UeLb1QI6@PK6U^IGA_3EmSMVedN21SMG9bIFidKF5dLVUh871_L0eSMG9bIFid
L6mYKW@PM79QKW=/HGAU3GQbHFAYMG<PNG9QI6UeLb1cHf5/I@d`82da834P;C4P
<B1QLV=dKb0dNg1_L7ebIG1UHG@=Gf=fKGAh87=UM6eQM79YN0eSK6mcIG1QM6Qm
I6EV3BmUL7]OHgI]M7PPHgEbLVE^M6eQM79YN21`Kg0=M79QKW=/HGAU3G=SHFaU
3C4P<21]KgIUM6l=<20`834P<20c=S0PHG9S3F=/Kg=UL65dJ0eOHgI]M7PPLfEd
KF5dLVUhOFAUIPd_MfAkGf=fKGAh86=eLW9UKWA]HGAbJGPPL6m`3GAbHFicK65d
I@ecHf5/I@d`830PKFmfIGA_3C0P<20a83DP;C8PLVm/K21QLV=^3F=/Kg=UL65d
J0eOHgI]M7PPLfEdKF5dLVUhOFAUIPd_HG=kGf=fKGAh86=eLW9UKWA]HGAbJGPP
L6m`3GAbHFicK65dI@ecHf5/I@d`830P<B0e82db879_K6`PHG9SKPeOHgI]M7PP
LfEdKF5dLVUhOFAUIPd_I7<=Nem`IFif85m`IFiX86iU86AeL7]cM6dPGg1UKVPP
I7E`830PK6EkL6m`835mJFHPGg1UKWHPI7E`830PK6EkL6m`835mJFHPLf=QK6Em
Nem`IFiX87=UM6aYKVEgJFAdJ7eYIVE/LfDPLgAbKf]U87]bM6emJFImI6EV3BmT
IW]VJFa/OFAUIPd_I6EkIFmVJFa/OFAUIPd_GfMcM6/P=B1QLW9QNB1TIFH=;emW
LgA[Hb0`86AUIPd_GfMcM7/P>B1TJF=d869UIfU^86aUMVE/<W/_Gf=SLb1SMG9b
IFidHfm/Kg9cL65SIB1TIFHP;emSHb1KHgEbLVE^M6=_K6mbGB1TIFImNbmOHf<P
Ff=eLW9UKWAbIf9SKfa_LUeTIFImJFIUK7=U87]SMG9bIFidL6mYKWAmLgA_L71U
I21k;emSL21^MFa/86AUIWek838PHG9bHGTPHG=dKg9U82mOHg0PIGQSJ21TIFIm
JFIUK7=U82mOHfHPHgEbLVE^M6I_KW@PI6EV3BmOHfag86=eLW9UKWA/JFiUMfUT
M6PPI6EV82mOHfaS86=eLW9UKWA/JFiUHf5`86AUIR0_Gf=/JR1SMG9bIFidK6U^
IFY_JFhPI6EV82mOHfe/86=eLW9UKWA]JGAULVaYKFUd86AUIR1SMG9bIFidI6US
M21UKVAmI6EV3BmXLg]^IGM`HGAX86McHGIU87=dKGeTIFH=;fQSNbmOJ78PK6mQ
I21UN6=X86MUM21UN6ES86iUMg1QM6QmI6EV3BmXIG]OIg=dJb1OIg=dJf<PGfMc
M21`MG@P;emWLgA[Hb1OIg=dJf<P<B1QI6@PLgA_LVDP3FMbIG=dKg9U879dKB0_
GfMcM6]S85mWLgA[Hb0a87=eHR1cM6mbIB1OIg=dJb1OIg=dJf<PIfEd86aUMVE/
<W]TMG0P;emSHg<PIfEd87=UM6=_K6mbLg1QHfDPI7E`82mOHf<PIfEd865/Kf5T
871_L21cIGASKfa_LWekI7E`82mOHf<PIfEd865/Kf5T871_L21cIGAbIf9SKfa_
LWeYIVE/LfDPI7E`82mOHg0PIfEd86AeL21^MFa/86Ea80e^KgAkHFa_HF@PL6m`
86e_MVEdKgekL6m`OFUVIFacIB1TMG0P;emSIR1WIG@PLfEdIVm^M0eTMG0_Gf=/
Mb1WIG@PLfEdK6U^IGMYI7AX86AeL2mOHfaS86MUM21cIGA/JFiUHf5`86AeL2mO
HfaZ86MUM21cIGA/JFiUJVmYKR1TMG0_Gf=]K21WIG@PLfEdKFUdIG9/JFeYM21`
Kg1mI6EV3BmYI7/P;emYI21hI6ImI6EV3BmOJFeQM79YN7]OMb0`830PGfPPGfUT
830PKVEkKVEW830PGfQmNc0P<7eYIVE/LfDPGf=fKGAh865cM6mbIGeTIFH=9B13
Kg1iLVUWJ7@P:4<Y834i>C0/834i>C4PHWTP@FA_HVDPDgUcM6E]Lb19KV=_LW1_
LV5dIF@^3BDP@Fa/879YIfQdLb1bIG=ULWIUI2h=K6EfIF`b87/PLf5fIB0_I6m^
M6a_HFA/IGIUK34PN6AV87eYIPd_LgAQLWA^Kfa_HFAkNbm^Kfa_HF@PLf5fIB1T
IFIm86UVOFAUIPd_IFiTKVm/Kf5TNg]^Kfa_HF@PLVEcM6mbIGeYIR1mI6EV3Bmd
IG=dLgUcM6E]I6USM7]gJ6EbIG]cNG=dIFeTJF=d86EaNgAbMFEmNfIQK7=UOFUV
IFacIGekIV5/LfEmJFIUK7=UOFAUIPd_KV=_K6mbLb0a86AUIPd_Hfm/Kg9YKF5W
IB1gJ6EbIG]`Kg0PM79eIGekIV5/LfEmJFIUK7=UNbm^Hfm/Kg9c830=LgAQM7Ec
I6USM21RIFMYKR0=;g1bKf=ULg=SKfa_LW<PMfQULVEkL6m`871_L21`LVmSIG=c
Hfm/Kg9cOG/_I6EfJF=UJFiVKb1gJ6EbIG]`Kg0PI6EfJF=UJFiVKb0_@fm/Kg9c
86]^KgM^3G]`Kg0PNfAUMVUSIFU^IVlP;d=_K6mbLb1WIGAmOFUVOFUVOFUVIFac
IB1UKV@PI6EV3FiSKfa_LW<P<21^IG/_Hfm/Kg9YKF5WIB1dIG=dLgUcM6E]I6US
M0d_LfEdHfm/Kg9dLV5^LfIULR1dIG=dLgUcM6E]I6USM0d_HgEbLVE^M6=_K6mb
M79QKW=VIG8PM6EcM7=iLgAUKFAYHg@=;f=eLW9UKWASKGU[Hfm/Kg8PM6EcM7=i
LgAUKFAYHg@=HFiT865^I21QKV@PKVmdNbm^Hfm/Kg9c830PI6EVOFUVOFUVOFUV
3FiSKfa_LW<PI7E`834PKVDPIGQSJ21TMG0P<b1^IB1UN6=X83@PKVDPHFiT865^
I21k;fiSKfa_LW<P<21TIFImJFH=KV=_K6mbLb0a86Ea86AeL21TMG0PKVmd87=d
HG9dKVm/Kf5T3G/_I6mSK7EdJFeQIfEkFg/b=CDPKGE/879_MFiT86=fJB1RMf=/
MG@PIGQSJ21WIG@P<SDe86AYMWdP;fEhIF<PK6mQI21TMG0PHgEbLVE^M7AbHFic
IVEb86EhHfQM80eSMWPPHVU^I21cIGAdLV5^LfIULR1OMb1OJ20h85mYKF5dLVUh
85mTLb1YKF5WIGeTIFImJFH=KVmd86E^I6i_K6mQI0e^Hfm/Kg9c86AeL20c86Ea
86EhHfPP=21ULB1_LPeTMG0PI7E`86i_M21cM65bM6i_K6mQI0ek;fieK6a`LVmS
Ng]mOFAUIRmSKfiSHGAeM6U/NbmUN6ES86a_HF@==b0]<B1bKfa/82mUN6ES86a_
HFAmI6EV3BmTIFIcMF9SK7Ed3G/a865TI21WIGAYKWAULWIQK21TIFImI6EV3Bmc
L6=_KV=QM7AbHFicIVEb820P3G/_A6=/MG@PIGQSJ21TIFH_@f=/MG@PIGQSJ21T
IFH_@V=/MG@PIGQSJ21TIFH_@F=/MG@PIGQSJ21TIFH_KV=_KG1eM6DPIGQSJ21/
I0eSMG9bIFidHfm/Kg9dLV5^LfIULPeKNd5SK7Ed86iSKfe`MGAUOF=_KV=QM7Ed
JFaM86=fN0eKNd9SK7Ed86iSKfe`MGAUOF=_KV=QM7EdJFaM86=fN0eKNd=SK7Ed
86iSKfe`MGAUOF=_KV=QM7EdJFaM86=fN0eKNdASK7Ed86iSKfe`MGAUOF=_KV=Q
M7EdJFaM86=fN0ecIGASKfa_LWAbHFicIVEbOFAUIPd_LfEdMG1bIf9SK7EdL`ek
;f9YM3=h879WHV=/MG@PK6E^IgAX83<PLgER86AUIPd_HVUd<GPPHVUd<gPP<b1Y
I6Uf86AUIRmbHfaeM21bIf9SK7Ed86AUIPd_If=/MG@PLV=/MG@P<B1RJG@cN21T
IFIcMF9SK7Ed;f9SK7Ed879SK7Ed838PHVUd<gPPI6EVLgERHfaeM7eTIFImJFHP
KVmd820=IFiTKVm/Kf5T86iSKfa_LW<P<b1ULB1TMG0PI7E`86i_M21cM65bM6i_
K6mQI0ek;c=SKfe`MGAUNfEhHfPPHVUd<gPPKGE/3G9_MFiT86=fJB1WIG@P<SDe
86AYMWeTIFH=;fA_HfaeM6U]HFMUNbD_LVMRHfaeM21hI6HPL6m`80ecIGAeL79W
HV=/MGAc;c=SKfe`MGAU879SK7Ed86MSK7Ed869SK7Ed86AeL0ecL6=_KV=QM7Ab
HFicIVEb85mg85mX83PPGfU]HGAbJGP=FbmOI7<PK6mQI20_IGQUHb1/Kf5T82mT
MG0PK6mQI21TMG1MHgIh3FieK6a`LVmS86ieK6a`LVmS87AbMFDP<b1SKfa_LVU]
HFMUOFAUIWeYIR1^Kg@PIFiTKVm/Kf5T86iSKfa_LW<P=21ULB1TMG0PI7E`86i_
M21cM65bM6i_K6mQI0ek;g=dMFIVHfaeM7]SKGU[JFiTIGPP<b0]<B1bKfa/871e
M7eTIFH=;fIdKfU^M7/a86EhHfPPLgER838e=B1]MF`PLVmeKV@PHgIYOFAUIPd_
=6=_KG1eM6DPNb1UN6=X869YM3Ah86eeK21bKgE^I21SMVTPIfEd838e=B1TJGHP
OB1TIFH=;f=_KG1eM6ESKGU[HfaeM7]cIGAeL79WHV=/MGAc;f9YM3Ah879WHV=/
MG@PK6E^IgAX83<PJFAYMR0d86eeK20d87=eHR1TIFH=;f=]NF]SK7Ed869YM3Ah
83@PHFAT87=dLVU^Ib1TIFH=;f=SK7Ed86=]NF]SK7Ed86AUIPd_KF=/MG@PHf=/
MG@P<B1RJG@dN21TIFIcMF9SK7Ed3BmiHfaeM21SHfaeM20b869YM3Ah86AUIW=e
HV=/MG@=;f]SK7Ed86=SK7Ed83<PHVUd=7PPI6EVLgERHfaeM0d_HfeiJfU^I6Eh
830PI6EV3C0P<B1RJG@aN0ekI7E`82mSKGU[JFiTIGPPIGQSJ21RJG@aN21UN6=X
87=eHR0d86eeK21TIFH=<b1]MF`PI7E`879SK7Ed86EhHfPPIfEd838e=B1TJGHP
IGQSJ21TMG0PIf=/MG@PIGQSJ21WIG@P<SDe86AYMPeUN6=X869SK7Ed86EhHfPP
IfEd838e=B1TJGH=LfEdLVMRHfm/Kg8PHgEbLVE^M6=]NF]SKfa_LPeVM6mYKW@P
Jf=/MG@PLgAeIVISK7Ed3FIdKfU^M21iHfaeM21cM7EVIV=/MG@=IWA_JFid86eS
K7Ed87=dMFIVHfaeM0eVM6mYKW@PHf=/MG@PLgAeIVISK7Ed3GeVKg9mI6EV3BmT
Kf=/MGAYKF5WIG]YKWIQK6UTHfm/Kg9dHF9/ICmkHfm]L7EdIF=]NF]SK7EdOFUV
3BldHfm]L7EdIB1SHfaeM21]HfaeM21iHfaeM21[HfaeM21cL6=_KV=QM7AbHFic
IVEb3Emg85mX83PPGfU]HGAbJGQK;emTLb1/Kf5T82mUN6ES86a_HF@_I7E`86a_
HF@PI7E`86AeL5dPHgIh80e^MFa/L79_Hb1^MFa/L79_Hb1^MFa/L79_Hb1dLWEU
83@PHfm/Kg9YKF5WIGeTIFImJFH=KVmd86E^I6i_K6mQI0e^Hfm/Kg9c830PIG4=
I7E`86AeL21^Kg@PLgAQLWA^Kfa_HF@=NbmSKfa_LVEhL65^I7]]NG=dLVU^IfEh
L20`879WHV=/MG@=<b1SKg1i3CLP;C4PLVm/K0ek<b1]MF`P<b1WIGAYKWAULWIQ
K21`MGAYKWAULWIQK21UN6=X83<PHFAT86EhHfPP<b1SKg1iOFI_LV5/K0e`Kg0P
L6m`871_L21`Kg0PL6m`OFAUIPd_Hg9UHGAUIGQ`HFiTLgAbNbm]NG=dLVU^IfEh
L21UN6=X87=d<21/IFiWM6PPKGE/87=dLVU^Ib1TIFImI6EV3BmTKf=/MGAYKF5W
IG/_LVMRHfaeM21hI6HPL6m`83<PHg9UHGAUIGQ`HFiTLgAb85mg85mX83PPGfU]
HGAbJGP=FbmOI7<PK6mQI20_IGQUHb1/Kf5T82mSKfa_LVEhL65^I21/Kf5T82mU
N6ES86a_HFAM86=fN0eVHFacIB0c86=_K6mbJFeQIfEmI6EVOFUV86i_M21UKVA^
Kfa_HF@=K6EfIF`b87/PI6m^M6a_HFA/IGIUK34PLVEcM6mbIB1mJFH=K6EfIF`b
86i_M7/PLf5fIB0_I6m^M6a_HFA/IGIUK38PN6AV87eYIPd_LVMRHfaeM20`86AU
IPd_I6mSK7EdJFeQIfEk;fQYMV5/838e=B1TIFHP3E/_BFiTIGQUI20_A6EfJF=U
DTM286QYMV5/879WHV=/MGAM87=UM6=_K6mbLg1QHfD=GfU]HFMUI6USM21TMG0P
HVEWJFhP3BmGJFAdJ21OMb1TIFHP3Bm8IFUWJ7@PGfPPI6EV820=;dAUHfmTIB1K
<21XJGIQK5dPI6EV820=;dU]HFMUCF5dLVUh85mYKF5dLVUh86AUIPd_@VUdLe1U
LT=_KG1_KVE^M20h86AUIR0=;dU^M6EbL6m/HGAU86IQK7=U86AUIPeUKV@PJFeQ
IfEmI6EV3FaUMVE/<R1^KgAk86A_KWA/Kf5TK6EfIF`b879ULgA_LVDPOFUV3BDU
AFiTD79_He=UM0d_GfU]HFMUI6USM20a=B1TJF=d869UIfU^82m9KF5WIEAiL6DP
<B1TIFH_@VUdLe1ULT=_KG1_KVE^M20h86AUIRm9KWAULW1_K65dIB1VHFacIB1T
IFHPHgEbLVE^M6AYHg@PIFiT86AUIPd_J65cHfm/Kg8PM79eIB1TIFH=;faUMVE/
<R1cNG=dIFeTJF=d82m/HFiWMF5WIFaUMVE/86]^KgM^3G]/HFiWMF5WIFaUMVE/
838PIfEmNfIQK7=UOFUVIFacIB1TIFH=;fI_MG9ULB1k=21YKVAUN21ULB0h834P
LVm/K0dd86U^I6Eh86Ea83PP<B1bKfa/3C@PJFiTIGPPIG4P>20a879_K6`==21Y
KVAUN21ULB0h834PLVm/K0e`Kg0PL6m`871_L21`Kg0PHFiT865^I21QKVAm86AU
IPd_LfEdMG1RHFiTLg]WLf5fI@d_Gg=UM7AbHFicIVEb87=iLgAUKFAYHg@P;g=U
M7AbHFicIVEb86MUM21TIFH=;emSMG9bIFidM79QKW=VIG8PLgUcM6E]I6USM20_
HgEbLVE^M7AbHFicIVEb86MUM21TIFH=;emYKF5WIB1cNG=dIFeTJF=d82mYKF5W
IB1WIG@PI6EV3BmRK65^Jb0`85mSMG9bIFidM79QKW=VIG8PIGQUH`da85mSMG9b
IFidM79QKW=VIG8PIGQUHb1ULB1TIFH=;fiUIf5dJGIU869/HFi[Nc0PGf=eLW9U
KWAdLV5^LfIULR1UN6ES830^=B1/M7d=Nc0PGf=eLW9UKWAdLV5^LfIULR1UN6ES
834PGf=eLW9UKWAdLV5^LfIULR1UN6ES86MdOFUVIFacIB1TIFH=;fU^MVEbM6ET
?b1^IFMQM6UfIB1TIFH=;emSMG9bIFidIg9QNB1cNG=dIFeTJF=d82mSMG9bIFid
Ig9QNB1WIG@PI6EV3FQQLf=_K6mbNblTHR0`86AUIWdPNblTHR0e86AUIWdPJFIU
K7=U3BmcIGASKGU[Hfm/Kg8PMfQULVEkL6m`834P<20`830PLfEdHfeiJf=_K6mb
85mSMG9bIFidIg9QNB0a86EhHfPPLgER3C0P<B0`830PLfEdHfeiJf=_K6mb85mS
MG9bIFidIg9QNB0a86EhHfPPLgER3C0P<20a830PLfEdHfeiJf=_K6mb85mSMG9b
IFidIg9QNB0a86EhHfPPLgER3C0P<20`834PLfEdHfeiJf=_K6mb85mSMG9bIFid
Ig9QNB0a86EhHfPPLgER3C@PNc@PHfm`NGdPLVE`IF5d3C4P<20`830PIVmeLVEa
NblTHR0a87=dKg9UOFUV3C0P<B0`830PIVmeLVEaNblTHR0b87=dKg9UOFUV3C0P
<20a830PIVmeLVEaNblTHR0c87=dKg9UOFUV3C0P<20`834PIVmeLVEaNblTHR0d
87=dKg9UOFUV3C0P<20`830PIVmeLVEaNblTHR0f87=dKg9UOFUVOFUV3F9/HFi[
NblTHR0f87=dKg9UOFUV3BAR830PIG4P968P=B1ULB1_LW/_96Ad830PI6EVOFUV
;bATM20]<B1TIFHPIg9ULgA_LVEmI6EV3BmTKfU]HFMUN`e/IGIUK39kJFeQIfEm
Nf9UIfU^3EMYI7AX84QUJFMXM212JGAcD6Eb@fm]L6m^IFid84U]HFMUCF5dLVUh
3DAUHfmTIB1/IFiWM6PP<R1UL@ek;dAQM65CKgEbHfDPK6mQI21UKV@PJFeQIfEm
N`e4IF=_I6DPK6E^IgAX83HPIG4=NdeeK7AYL6aUA65dHE=_MG9SIG=kA65dHE=_
MG9SIB0`86MUM214HGAQDfmeLV=U834PIfEd84AQM65CKgEbHfDP<R1WIGAmNbm4
HGAQDfmeLV=U86a_HFAmJFIUK7=U3DeeK7AYL6aUA65dHE=_MG9SIG<P<b1UKV@P
A5=9@fm/Kg99KF5WIGek3DAUHfmTIB1/IFiWM6PP>21ULG]=MFadJG1/IDAQM65C
KgEbHfEcNdAQM65CKgEbHfDP<21WIG@PA65dHE=_MG9SIB0a86MUM0e4HGAQDfme
LV=U838PIfEd84AQM65CKgEbHfDP<b1WIGAmNbm4HGAQDfmeLV=U86a_HFAmJFIU
K7=U3DeeK7AYL6aUA65dHE=_MG9SIG<P=21UKV@PA5=9@fm/Kg99KF5WIGeYIWeY
IVE/LfD=OFUVIFacI@emJFIUK7=UOFAUIPd_I7Ak;g9WHV=/MG@PN6AV82mRMf=/
MG@PN6AVOFAUIPd_Hfak96TPLfEdKF5dLVUh87AbHFicK65dIB1cHf5/I@d_GgLP
GfU]HFMUI6USM20_EfUTM6PPIfEd86AUIPd_GfPPGfU]HFMUI6USM20_B6EYIfQd
86MUM21TIFH=;emTLb1OJFeQIfETJF=d82m4HGAQDfmeLV=U86MUM21TIFH=I6mS
K7EdJFeQIfEm86AUIPd_HfAk96TPLfEdKF5dLVUh87AbHFicK65dIB1cHf5/I@e/
IGIUK39kGfU]HFMUI6USM20_@fm/Kg9CL65SIB1WIG@PLfEdHfm/Kg9cL65SIGeY
IPd_GgLPGfU]HFMUI6USM20_EfUTM6PPIfEd86AUIPd_GfPPGfU]HFMUI6USM20_
B6EYIfQd86MUM21TIFH=;emTLb1OJFeQIfETJF=d82m4HGAQDfmeLV=U86MUM21T
IFH=GfU]HFMUI6USM21RIFMYKPd_BFeQIfE=HGAbJGPPGfU]HGAbJGPPI6EV3F=e
LW9UKWATJF=d86E^I0eTKfU]HFMUOB1TIFH=;fU]NbAY87=UM6eQM79YN21dLV5^
LfaQM6DPLf=QK6DP3FaUMVE/<W/_A6EfJF=UAg9QNB1cIGASKfa_LW=`HF=U830P
LfEdIg9QNGeYIPd_GgLPGfU]HFMUI6USM20_EfUTM6PPIfEd86AUIPd_GfPPGfU]
HFMUI6USM20_B6EYIfQd86MUM21TIFH=;emTLb1OJFeQIfETJF=d82m4HGAQDfme
LV=U86MUM21TIFH=GfU]HFMUI6USM21RIFMYKPdU;dAUHfmTIB1K<20aGB1TIFHP
80dU;eMYI7AX85mg86AUIPdU;dQUJFMXM21OJ21TIFH=;dU]HFMUCF5dLVUh85mY
KF5dLVUh86AUIPeSMG9bIFidI6USM21UKV@P3FA_JFeQIfDPOFAUIPd_Hfm/Kg9Y
KF5WIB1gJ6EbIG]`Kg0_A5=9@fm/Kg99KF5WIB1kHfm/Kg9YKF5WIGdPI6EVOG/_
A5=9@fm/Kg99KF5WIG/=;bA^Hb1hI6HPL6m`82m`LVmS<21hI6HP<b1YKVAUN20b
86U^I6Eh86eeK20g865TI20h86AYMR1SMVTPLgAbJFiW82mcM34PN6AV3BA^Hb0c
86EaNg]`LVmS<21TMG0_Lg@`87QTIR0`86EhHfPP<b1UN6=X86aUKVMdJ20c87=e
HPekI7E`87=d<21UN6=X86MUM20^<b1]MF`P<B1YKVAUN20a865TI21cM30PIGQS
J21WIG@P;SDi86eeK21QI6@P<B1YKVAUN20b865TI21cM30PIGQSJ21WIG@P;S4a
86eeK21QI6@=HgIY86EhHfPP<b1TJGHPHgIY86EhHfPPLg@a83<P<B1bKfa/871e
M7eVKg8PLg@aOGekNg1bKf<`86AeL2mcM30PN6AV830PIGQSJ20d86EhHfPPK6E^
IgAX83@PLgERNfAeL0ecM30PIGQSJ21WIG@P;S<PKGE/3C4PJFiTIGPP<B1QI6@P
Lg@`86EhHfPPIfEd82he>B1]MF`PHFAT3C4PJFiTIGPP<R1QI6@PLg@`86EhHfPP
IfEd82ha<B1]MF`PHFAT3C4PJFiTIGPP<b1QI6@PLg@`86EhHfPPIfEd865TI21T
MG0P<SDe;S0PIgAkL6m`838e=Bh`OFUV3C8e=Bh`86EhHfPPLgER86=fJ@eUN6=X
83@PI6Uf86=fJB1UN6=X3G=d<B0c834PLVm/K21`MGAmIVmb87=d<GemJFIUK7=U
3FU]HFMUOFAUIWeYIVE/LfD=;dm@BFU]HFMUNfU]HFMUOFAUIPd_96TPKF5dLVUh
86AUIPd_HVUkLf=QK6DPM79QKW=/HGAU82AY86=eLW9UKWA]HGAbJGPPL6m`87Ab
HFicK65dIB1cHf5/IB1cIGAeL69QKVAcOFAUIPd_IFUk96TPLfEdKF5dLVUhOFAU
IPd_JF]k96TPLfEdKF5dLVUh87AbHFicK65dIB1cHf5/IB0=;emg85mYKF5WIFAY
Hg@P;eMYI7AX86MUM21TIFH=;emX85mYKF5WIFAYHg@P;dQUJFMXM21WIG@PI6EV
3BmOI7<PGfU]HFMUI6USM20_A65dHE=_MG9SIB1WIG@PI6EV3Emg85mX86IQK7=U
85mYKF5dLVUh83DP;C4PLVm/K21OI7<PJFeQIfE]HG=[OFAUIPd_LW=k<R1SKg1i
87AbHFicK65dI@dc82da879_K6`PKVEW879_M65dI@e^IFLPIGQSJ21^IFLPIGQS
J21dLV5^LfaQM6D=OFAUIPd_Hg=kGf=fKGAh865cM6mbIB1SKfiSHGAm86AUIPd_
IVAk;emVI21hI6ImI6EV3BmOIVm^M4eQM79YN7/a830P<21OIV@P<21^IG/]<B0`
831mNc4P<20`OFUVIFacIB1OHgI]M7PPHG=dKg9UOFAUIPd_LVIk;emUKV=_I6U^
I6Eh87QTIPe6KfidA6UbIF=dKg9i86EhHfPPJfi_MfhPN`eVJFiTIVm^M21TMG0P
K6E^IgAX834PHFAT86AYHg@PHVEWJFik<B1YKVAUN2m6BD@PKVEkI6EVOG]`Kg0P
L6m`OFUVIFacIGeVKg9QK6`=I7E`82m6KfidCV5]IB1UN6=X86AUIR16KfidE7U`
IB0`86iUNbm5KV=_I6U^Ib15KV=_I6U^Ib0b=CHPHG9bHGTPHfm`NB1TIFH=GfE^
HfmTJFiTIGPP<21WIG/`85mUKV=_I45bLR1OIFiSKfAYKVAUN21WIGAkI7E`87Ai
L6D_KV5]IGAiL6DPIG5kAFiSKfAYKVLP<R1YKVAUN20b86U^I6Eh871eM21`Kg0P
<B1QI6Am3G]UN6=X871_L7eYIVE/LfEmIVmbHFa/871_L7eYIWeYIPeSMG9bIFid
I6USM21UKV@=I6EVJFiUIVm^M21`Kg0POG]`Kg0PL6m`OFUVIFacIGdPI6EV3BmS
MW=VNb1VJFiTIVm^M21VM5=YNVDP<20`86IdDfUjIB1OIV@P<21^IG/]<B1]MFam
JFHP<20`85mSMVedN21QLgA_LVDP3FeQJfEVKfid87=UM6I_KWAmI6EV3Bm]IW/c
82da879_K6`PIVU^I6I_KW@P<b0a879_K6`PIGQSJ21VM5=YNVDPKGE/86EhHfPP
IWACJGYU86eeK20`86EhHfPP<21UN6=X80eOIV@P<21^IG/]<B1]MFamJFHP<20`
85mSMVedN21QLgA_LVDPKF5[IFI_KW@PLfEdIVm^M7eTIFH=;gMbJc4P:20Y86AU
IPd_MfAYHg@P<CHPI6USM21TIFH=;eM_LV/g=B0g=B1cM79YKVLPI6EV3Bm>KF]k
EfmbJcLe86=fLb1TMG1mI6EV3Bm>L7AkL7Ed86=fKWeTIFH=;fAXCfAXNdi]Jb0b
83Li84i`M7eTIFH=;fAX@VAXNdi]Jb0b834a<B1>L7AmI6EV3BmTJ5=TJ7]>KF/P
<R0h<b1>L7AmI6EV3BmcIUMYI7AXNfMcHGIU830P<21]KgIUM6lP<20`86aYKVEd
Kb0`830PK6U^IGA_830P<21/JFiUM6lPHfa_LfE`HGAX86=/JG0PLgAbJFiWMfUT
M6PPIg9ULgA_LVEmI6EV3BmVM7=k;fIdDfUjIB1UN6=X86AUIWeTIFH=;fe[AUAk
I7E`;dI_KWADNG1U86MUM20`86EaNfAeL21]HGQ/IFiWM6PPI6USM21RIFMYKPek
<B1YKVAUN2m6BD@PKVDP<R1YKVAUN20_EFiYLGEUBD@PKVDPHFiTNfAUIWekL6m`
871_L7eYIVE/LfEmIVmbHFa/3F=eLW9UKWATJF=d86E^I0eTMG0_ATAUL5IUHgA_
LR0b86=_L7TPIfEd3E]UN6=X83HPJFiTIGPPIGQSJ20f86U^I6Eh86EhHfQkKF]6
E20c834PLVm/K7eVKg9QK6`PL6m`871_L5dPL7Ed86AeL7ek;gAUKG16E20a<R1T
JF=d86AUIPedIFe`AU@PHVEWJFh=;dI_KWA=HGAbJGPPFc4P<20`834P<20`GB1T
IFH=;dI_KWADNG1U83<PI6EV3FAeL2m5KV=_I6U^Ib1WIG@_AFiSKfAYKVLPIGQS
J21TIFH=;g1bKf<b838PJFiTIGPPI6EV3FAeL2mVM34PIGQSJ21TIFH=;fId<R0a
865bLV5i86AUIPd_AVm^M492KgPPFc0P<20a835M86AUIPd_@WEYK6A3J65bNd=F
A6USM21RIFMYKPeUN6=X86AeL2mVM6Ad87QTIR1RIFMYKPegI6USM21RIFMYKPd_
HfQb87QTIRmSJ79cM21gLV/a86AeL20`86=XLR1`MG@PI6EV3FId<R0`86MUM21^
MFa/86EaNfId<B1TMG0PK6E^IgAX838PHFAT86AYHg@PHVEWJFh=Nc4PJFiTIGP_
ATU486iU838PJFiTIGPP;eE^JG5eIDU486iU865^I7]TIFImNg1_L21`Kg1mJFIU
K7=UOFI_LV5/K0d_D65YKWADNG1U838PI6EV;e=dLVm[IEMYI7AX82h`<S@P<216
KfidCF5dLVUh86UTM79QKW=VKg9]871_L21TIFH=HgEbLVE^M6AYHg@PIFiT3Bma
86EhHfPPI6EVJFiUIVm^M0eVM38PIGQSJ20`86EhHfPPL7EdOFUV3FIdI7@_L79_
Hc8PIfEd86EhIF<PIFiT86E^I21UKVAmI6EV86E^I21dIFe`AUAmJFIUK7=U3C<P
JFiTIGPPIGQSJ0eTIFIYKVEVKfid86EhHfPPL6m`OFAUIPd_KF9kI7E`86AX@VAX
84I_KWA4JG9UHgA_LWTP<B1YKVAUN21[KVmgKPekIGQSJ21`Kg1mNfAe02<0002Q
0<0oog0P<R1YKVAUN0eVJFiTIVm^M7]RKfaTL79_HgdPIGQSJ0e]JdID871_L21`
Kg0PL6m`86EhHfPPL6m`3GeYIVE/LfDPOFAUIPd_KFmkI7E`86AXCfAX84I_KWA4
JG9UHgA_LWTP<B1YKVAUN21[KVmgKPekIGQSJ21`Kg1mNfAeL20b86U^I6Eh3FIY
KVAVKfidNfmeM71bKf=m86EhHfP=KF]6E21`Kg0PL6m`871_L21UN6=X871_L0em
JFIUK7=U87eTIFH=;fecNfAeL21TJ5=TJ216KfidA6UbIF=dKg9i834PJFiTIGPP
Jfi_Mfh=NfEhHfPPL6m`OG]TMG0P<R1YKVAUN0eVJFiTIVm^M7]CJ65T@fQQLWdP
IGQSJ0e]JdID821`Kg0PL6m`871_L21UN6=X871_L0emJFIUK7=U87eTIFH=;fme
M71bKf=kIW@a87=UM6I_KW@=Ig=QMVDPHfQbLg@PLfIGJFAdJ21WLVEcM6mbI@ec
IGASJ65bMfUTM6PPI69/LfQmI6EV3BmRKfaTL79_Hg]VM34PLfEdIVm^M0eWLf5f
I@eSJ79cM21cIUMYI7AX834PJFiTIGPP<21^IG]UN6=X82h`=B1QI6@PIGQSJ7eY
IPeWLVEcM6mbI@ecIGASJ65bMfUTM6P=IW@a82m@HFU^M5AiL6DPIfEd838PKVD=
Nc0P<21]KgIUM6lPIg=QMVDPIW@b830PIfEd87=UM6I_KW@PHfQbLg@PLfQ_Mb1W
LVEcM6mbIB1SJ79cM21cJ6mgO@ek<20`86e_MVEdKb1WLf5fIB1SJ79cM21cJ6mg
86MbIG=dKg9U82h`=B0`86e_MVEdKb1SJ79cM21cJ6mgOFUVIFacIGeTIFH=;fAR
K7=XNf=eLW9UKWASKfa_LR1SMG9bIFidHfm/Kg9cL65SIB0a;S0PLfEdIg9QN@eS
J79cM20`830PKFmfIGA_87=XKgLPLfEdHfm/Kg9cL65SIB1cIGASKfa_LPeVM38P
<21WIG@PLfEdIVm^M21SJ79cM20`830PKFmfIGA_87=XKgMmI6EV3BmCJ65T@fQQ
LW/=IW@a87=UM6I_KW@=Ig=QMVD=HfQbLg@PLfIGJFAdJ20a86U^I6Eh830PKVEk
IGQSJ20^<3DPHFAT86EhHfQmJFH=Ig9ULgA_LVD=LfEdHfQQLWMYI7AX3F=XLW=d
82h`=R0`86e_MVEdKb1cJ6mg3C0P;S0e87AbHFicK65dIB1THVacJ7eTIFH=;gAc
Ng=XKgMmI6EV3BmdHG/_GfaUM7AULU=`HF=U87QTIRmOLg1QHfEHM79Q87QTIWeT
IFH=;gAVNbmOM6EhM5MYI7AX87QTIPd_GfieKE=`HF=ULb1hI6H=;emcM79YKVM<
IFiWM6PPN6AV3FAeL0UcM79YKVMgJFAdJ21`Kg0=GfaUM7AULU=`HF=U85mcM79Y
KVM<IFiWM6PP<B1cMF8PKGE/865TI0eOLg1QHfEHM79Q85m^MFeCL65SIG<PKGE/
865TI0eOM6EhM5MYI7AX86EhHfPPLgER82mgI6UV87QTIPeOLg1QHfEHM79Q830P
<c8=MfAYIR1OLgAbJFiWC6E^IgAX86AYMPeOK6EdM6EbDg1QHfDPHFAT3C0P=R0]
<B1bKfa/865gJFAdJ7=XKgMmI6EV3Bm`HW/_Ge1QIfECHGIU87=QMVDPI6EV;g=X
KgM`HFMUNgeTIFImI6EV3Bm`IG]OD65WIE=QMVDPLVEcM6mbIGeTIFH=;g1]Nem`
KB1SMG9bIFidKF5dLVUh871_L7eTIFH=;em`KB1]HGAbJGPPI6EV3Bm`Lg]cJ6mg
L65WIB1OL6dPLfEdKF5dLVUhOFAUIPe/IGIUK39k;fEV87]WLf5fIB0f865bLV5i
865cM6mbIB1SKfiSHG@PI7E`86EhIF=VKg9]86MbIG=dKg9UOFAUIWd=NbmUIW]W
Lf5fIB0f865bLV5i865cM6mbIB1SKfiSHG@PKVEgL65dJ21TMG0PHVEWJFhPCF5d
LVUh86=_KV=QM0e2@Vmh86AeL21TMG0P<21WIG@PIGQSJ20a86MUM21]KgIUM6l=
I7E`86AeL20`86MUM21UN6=X83<PIfEd86aYKVEdK`eTMG0PI7E`838PIfEd86Eh
HfPP<b1WIG@PK6U^IGA_3FAeL20b86MUM21UN6=X834PIfEd86aYKVEdKb1SK6mc
IG1QM6P=HfaYL21^IGM`HGAX851QJFidD79_Hb1UKV@PIg9ULgA_LVEmI6EVOFUV
IFacI@d_HV=kLf5fIB0a<B0a879_K6`P<C0PI6USM21RIFMYKR0_@T9_N20e834P
LVm/K20d865bLV5i865cM6mbIB1TIFH=;deQM79YN20g834PLVm/K20f865bLV5i
865cM6mbIB1TIFHP;dI_LVeDNG1U834PI6EV;e1QJFidD79_Hg/_L70PIfEd86Eh
IF=mI6EVOFAUIPd_IF=kL6m`879ULgA_LVEmI6EV3Bm`LVU^M7I]Nc4PMVebIF=/
HFU]87I]LgAQM7Ec871_L21UN6=X871_L20X820P820P820P820P820P820P820P
820P82USMW<PL79YKW@P:5a^:G1bJFid86I/MG=XOFAUIPd_LfEdKgIULW1bJFid
87MXIG9U87]`Kg1mNbmcIGA_MVEbL79YKWAkL6m`OFAUIWeYIVE/LfD=;g=cM78P
Nb0_97=cM79c86EhHfPPI6EV82lTLg=dLR1UN6=X86AUIR0_97=cM79i86EhHfPP
I6EV82lTLg=dLWPPIGQSJ21TIFHP;d=_MG9YIG8PIVU^I6I_KW@P97=cM79c80ec
Hf5/IFI_KW@PLfEdIVm^M20TLg=dLWPP97=cM79i86ed87=dKB0a82da87=SHFaU
82AcLgAb87=XKgLPLWA]87dPI6EV3Bm4DdU2IFMYKU1QJFidD79_Hg/_L70PKF5b
Jg]SMG9bIFidIVU/IB1dKf]UKR1^KgAkOFUV86AeL2m4DdU5KVA@HFU^M51bKf<=
2FEaNg1_L21SKgE^M7A_KF5bJb1QLW9QNB1QLgA_LVDPHgIh869YKV@P;fEhIF<P
K6mQI5eSMWPPI6EV84ACBDE^I51QJFidD79_Hb1UN6UdO@d9Nf=_MFidM6m]HG9[
83<`<21WM7]SKgE^M7A_KF5bJb1QLW9QNB1QLgA_LVDPHgIh869YKV@P;fEhIF<P
K6mQI7eYIWeYIVE/LfEmK6m_L7eTIFH=;dACBDE^I51QJFidD79_Hg]SMG9bIFid
I6USM21UKVAmI6EV3Bm4DdU2IFMYKU1QJFidDgERD79_Hb1kLf5fIB0a<B0a879_
K6`P<C0PI6USM21TMG0P;g1486EhHfPPI6EV869UIfU^80d9;d92KgPP=B0a879_
K6`P=21QLW9QNB1QLgA_LVDPI6EV82m=HGAbJGPP=b0a879_K6`P=R1QLW9QNB1Q
LgA_LVDPI6EV80d9;dI_LVeDNG1U834PI6EV82m@HFU^M51bKf<PNb0_L70PIfEd
86EhIF<POB1TIFHP;g1`OB1TIFH=;dACBDE^I51QJFidDgERD79_Hb1kHVU^I21T
IFHPIFiT8714OB1TIFH=;fUQHB1k;fUh86Uh86UhKR1QI6@PI6EVOB1TIFH=;fUQ
Lc8PNbmYIf5`86EhHfPPI6EV82mOLg@`86UQ86Uh86UWHG0PHFAT86MUM21TIFHP
Gg=d<7dPI6EV3BmYHG<PNbmcM30PJF4PJGPPIfEd86AUIR1YHF4PLg@`OB1TIFH=
;fTh=G<PNc0PJF5c<R0_@E=3BDTh=DAUHfmTIB1VJFadIG8PLg@`879UHFAcM79Y
KVLPL6m`86UQHGdPI6EV3BmYLVaULb1k<21YHG<b82m1Dd=9BCPeA6ESKfAU86IY
K7AULR0_DWE^C6E^IgAXA6ESKfAU86IYK7AULR1cM30PLVEQI7=dLVU^Ib1`Kg0P
JF5QOB1TIFH=JFiYM6UQK6UjI@eUKV@=9BE5KVABIG=_MG9SI@e3ETAYHg@PHVEW
JFhP<21YI20a86IT3EmUKV=_I45bLR0`3E/=<cT_LGE_M6EcJFiWK6DP>CH_Ig9Q
MVD=<C8h;f9eK6aUM2mRMFa/IG@_LGE_M6EcJFiWK69QLfD_IVa_LVU^;g5eKgAU
I69/HV5cIBmUK6aYL7=YLbmTHFMWIG8_I65WIfEbI69/;f=YLV=eKFI/IGP_L6Eb
M6Q_MG=QKV@_Df=QLVm^;fMeJFacJFiWK6aUIW@_CdD_HWE/K6Ed;f9eK6aUM2mR
MFa/IG@=;f9eK6aUM2maMFmdIFaUIW@_LGE_M6EbJFMXM2maMFmdIFARK6aUIW@_
LGE_M6ETHVabJFMXM2mRMFa/IG@_IFiTHG=X;fE]I65cJ2mdJFaTIBmdLV5TIFeQ
LV/=;g=SHG9_KPd_IgEYK7=YKVM/LVUWJ7@_KfD_HWE/K6Ed;f9eK6aUM2mII6UU
LVEcJG<=;f9eK6aUM2mUN6=/HFeTKgM^;f=UKW@_LgAULVaYKVL_HgEbLVE^HgT_
NFE^;f9bKf]UKV9QLRmcIF=dJFm^;fAYIG9ULfUc;f=_L7UbJFMXM2m_LVAVIFeY
KVU^IBmWMFU/K6E]KgA/IFId;fa_IfUSHFa^Kg@_J7U`J6E^;g9UIfUcM6EbIF@_
KF5SLVm^3BmTIFMbIFD_L6aeLfeYKWEc;gAgKg=eL6EbJFmb;gAXLVEULgE`IG9Y
Kg8_HF=eM6D_KGD_L65bHFMbHG1X;g1ULVU_I6=UKWAULVET;f=UI6U/K64_KfiU
LgE`IG9YKg8_Kg9TKF5cHgE/JFiU;fMeJFa/IFe_M79YIfQd;fm^IG5eHG9dIG8_
KfiUJ65/IRmdJ79UIG5eHG9dIG9c;g5eIG=dJFm^I6mgKPd_@FMbHGIU;d5QHgEd
IBm1HfUbHgE]IVaUN2m1M6U/I6D_@FAYIG9ULfUc3Bm1LVU^I`d_@DD_@f=UI6U/
K64_AFMbHGIU;dEQHgEdIBm5Ig9QMVD_AFAYIG9ULfUc;dUWLV5fIBm9HF=eM6D_
BF=YLV=eKFI/IGP_BFAYIG9ULfUc3Bm5M6P_CWAYK6AU;dmWLV5fIBm?HF=eM6D_
Cf=YLV=eKFI/IGP_CgAYK6AU;dmTJFEbIG=YLbm]MFadJG1/NBm?LfaQLfP_EFMb
HGIU;eEQHgEdIBmEHfUbHgE]IVaUN2mEI6UULVEcJG<_FF5SMGAU;eAXKg9^;fMU
LVeQKVARK7<=;f5WLV5fIBmQHF=eM6D_HF=YLV=eKFI/IGP_HGAYK6AU;f5TJFEb
IG=YL`d_HG9YKVL=;f5U;f=SIFAYK6aQ;fEWLV5fIBmUHF=eM6D_IF=YLV=eKFI/
IGP_IFAYIG9ULfUc3BmYIg9QMVD=;fUQHgEdI@d_JF=YLV=eKFI/IGP=;fUTJFEb
IG=YL`d_IGAX;fidJFaTIBm_Ig9QMVD_Kf5SMGAU;fmSJG9SMFeVK6Eh;fmdJFaT
IBm_I6UULVEcJG<_I6UfJFAU;fmcK65cJ2meIg9QMVD_MF5SMGAU;gESJG9SMFeV
K6Eh;gETJFEbIG=YLbmiHF=eM6D_M6Q_LVh_NFAYIG9ULfUc3EdPL7Ed3EmUKV=_
I45bLR0a3E/=<cT_LGE_M6EcJFiWK6DP>CH_Ig9QMVD=<C8h;d5TJFEbIG=YLbm1
LVU^Ibm3HfETJFa/HBm5HF=eM6D_CWAYK6AU;dmTJFEbIG=YLbmEI6UULVEcJG<_
HF5SMGAU3BmQIg9QMVD_HF=YLV=eKFI/IGP_HFAYIG9ULfUc;f5dJFaTIBmQLVU^
IbmSHfETJFa/HBmUHF=eM6D_IFMbHGIU3BmUHfUbHgE]IVaUN2mUI6UULVEcJG<_
JF5SMGAU;fUWLV5fIBmYHfUbHgE]IVaUN2mYI6UULVEcJG<_KWAYK6AU;fmQHgEd
I@d_KfMbHGIU;fmSJG9SMFeVK6Eh;fmTJFEbIG=YLbm_M6U/I6D_MF5SMGAU;gEW
LV5fIBmeHfUbHgE]IVaUN2meI6UULVEcJG<=;fAQIfMULRmTIFMbIFD_HfE^M2mc
M6EbK6U^IbmcIF=dJFm^;f9eK6aUM2m`HG9QIg9QL6P_IfEbKF5^I69/L`d_LVEW
JG=dIG9UI2mSKg1iLVUWJ7@_M79QI6E]HG9[;f5SMGAU;fAYIG9ULfUc;fi_M6Ea
MF5/;d55;dmcK65cJ0d_JFiVJFiYM7T_L6aeLfeYKWEc;faULg=ULGEQK2mWLVEQ
M6EbIG5eHF`_NFE^;fee;g1QLWAYHFaTJFIV;g=eKFeQM6U_KPd_L79_I7ESM2m`
JBmYKWAUIg9QK2m_LVAVIFeYKVU^IBm_LVA]HG=SMFaYKVD_CfeUIf4_HFD_Kg=/
HG=X3BmaMFEcM6U_KVA_Mfh_IGQSK65]I6mgKRm/KfMYHf5/KVmd;g9QI6USHF`_
IVa_LVU^;f5`L79_N6EaMF5/;dAUK7AQ;fMeJFa/IFe_M6aUIW@=;fMeJFa/IFe_
M79YIfQd;fE/K6U`LfUc;f9/HFi[;d5WLV5fIBm1M6U/I6D_CgAYK6AU;dm5;fmU
3BmUKVAQLfP_IFeTHG=X;g5eKgAUI69/K6EVM2maMFmdIFARK79YIfQd;g5eKgAU
K6EVM2maMFmdIG9YIfQd;fAYMVUTIBm/KgYUKVMU3BmiI6UULVEcJG<_FFAYIG9U
LfUc;fIbHF=dJFm^;f=eLW9UKV=i;fMeJFacJFiWK6aUIW@_IgEYK7=YKVM/LVUW
J7@_IVT_IV`=;fAQIfMULVARK2m`IG9YKfASIFidIG9UI2maMFmdIG=YKVM/HV5c
IBmaMFmdIFARK69QLfD_L6EbM6Q_MG=QKV@_@F=YLV=eKFI/IGP_AF=YLV=eKFI/
IGP_@F5SMGAU3Bm5I6UULVEcJG<_AFMbHGIU;dUQHgEdIBm9HfUbHgE]IVaUN2m9
I6UULVEcJG<_BFMbHGIU;dmQHgEdIBm?HfUbHgE]IVaUN0d_HG1`K6D_CfMbHGIU
;eEQHgEdIBmEHfUbHgE]IVaUN2mEIg9QMVD_I6mdK6EcLfT_HfUbHgE]IVaUN2md
JFaTI@d_KF5SLVm^;f9bIGIU;fA_M65SHfE^M2mbJFiW;f=UI6U/K64_J7E^If5b
MFe/HGEd;fmWKfiUJbmSHG9_KPeM871eM0eUKV@=9BE5KVA@LVm/KfLP3BDU@VEW
JFiCIGAeL20=@eI4JF=d869UIfU^3@dU9D9UIfU^DVEcKgEbHfDj86I_KW@PAfE^
IGIQ3C4d86AYHg@PHVEWJFh=;dI_KWA>HFeU82m7IFiUMV4PI6EV3Bm6KfidCF5d
LVUh85/`;S0`<B0`830P<2h`<34P<20`GB1TIFH=;dI_KWA9KVI_834`86AYHg@P
I7E`869UIfU^3Bm6MFa/CV5]IB0XAfE^IGIQ:B1TIFH=;dIQKFU/NDiQKFDP:4MU
KVEfHBTPI6EV3BmEKVAULVaYKVE@Kg=YM6U_KR0]<C0`86AUIPd_EFiTIG9/JFiU
E6QYHf]^IG=c83D`86AUIPd_DgAbJF]UKgEdD6mcJGAYKfhP<c0`86AUIPd_DgAb
JF]UKgEdE6QYHf]^IG=c838e86AUIPd_EfEYIfQd82Q=IFAYMFdY86AUIPd_BGAQ
K6US@FiWK6DP<21TIFH=;fUcAVUhIFA@JGASJ21VHFacIB1TIFH=IFiT86AUIPd_
GfM/NG1X82QH820Y86AUIPd_IgP=N`d9<B1UN6=XN`d92FAeL20a=R0X820Y86=f
LW<PGfM/NG1X86EhHfPP<B1UN6=X871eM6U^M6EbMV5/834PJFiTIGPPIGQSJ0d9
2EmWK7U`J21SMVhPL7Ed3@T9OFI_LPemI6EV3Bm@HFU^M5AiL6DP<21TIFH=;dI_
KWADNG1U834PI6EV3Bm5KV=_I6U^Ib0b=CHPHG9bHGT=<20a838e=B1k834PJFiT
IGPPIGQSJ20_;Vi_M6AUIR1`MG@POB1VKg8=<c0P<SDe86Mh3FAUIPd_AVm^M492
KgPPFb0`830P<20`85dPI6EV3F=eLW9UKWATJF=d86E^I0eTMG0P;e1bJGIQM6DP
>21TJF=d86AeL21RIFMYKPd_DTAkLgAbJFiW86=eLW9UKWAVJFaU86EhHfPPLVEQ
I6QUN7=dLVU^Ib1`Kg1mI6EV3Bm>A7]TIFImI6EV3Bm>D7]`MGAmI6EV3Bm2K7EU
EV5/MFEcFb0]<SD`830P<S8`<20b<S0`GB1TIFH=;deYKTIUHGAeLVDPNb0a=R0a
=WdPI6EV3Bm`HG=cMfmbI20e>3<i86AUIPd_DgERLW<P=3<PHG9bHGT=CT@=<R1Y
KVAUN20_@fQQLU=dLVU^Ig<P<SDf86AYHg@PI7E`869UIfU^3Bl^KVmdI6EV820a
<21BA20b=4E3@T@`=C=5@d54<cDbASDh<B1>A0d_F30a820a<R1BA20b=4E3@T@`
=C=5@SU1<3LeA44d>4=3ADDPCT@=;eP`<R0P<C8PDT@P<SA5@d94<3DcAD8i@C0g
=DA1=3Q3@dE584i43BmH<3<P834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5
AB1>A0d_F30d820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;eP`
=B0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<3HP834b8594
838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F30g820a<R1BA20b=4E3@T@`
=C=5@SU1<3LeA44d>4=3ADDPCT@=;eP`>20P<C4PDT@P<SA5@d94<3DcAD=1A3<e
<THe>3He<R1>A0d_F30i820a<R1BA20b=4E3@T@`=C=5@SHe@d@i@S4a=48`@DDP
CT@=;eP`@B0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<48P
834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F313820a<R1BA20b
=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;eP`A20P<C8PDT@P<SA5@d94<3Dc
AD8f=D=4>D8a<CA2<45584i43BmH<4DP834b8594838dAD=2A30e<dE2>D4`=cE4
@C@h@d=5AB1>A0d_F316820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDP
CT@=;ePa<20P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<C4P
834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F34b820a<R1BA20b
=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePa<b0P<C8PDT@P<SA5@d94<3Dc
AD8i@C0g=DA1=3Q3@dE584i43BmH<C@P834b8594838dAD=2A30e<dE2>D4`=cE4
@C@h@d=5AB1>A0d_F34e820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDP
CT@=;ePa=R0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<CLP
834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F34h820a<R1BA20b
=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePa>B0P<C8PDT@P<SA5@d94<3Dc
AD8i@C0g=DA1=3Q3@dE584i43BmH<D4P834b8594838dAD=2A30e<dE2>D4`=cE4
@C@h@d=5AB1>A0d_F352820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDP
CT@=;ePa@b0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<D@P
834a8594838dAD=2A30e<dE3@D@c=C96=CPf=C8PCT@=;ePaAB0P<C8PDT@P<SA5
@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<DHP834b8594838dAD=2A30e<dE2
>D4`=cE4@C@h@d=5AB1>A0d_F38`820a<R1BA20b=4E3@T@`=C=5@SHe@d@i@S4a
=48`@DDPCT@=;ePb<B0P=34PDT@P<SA5@d94<3DcAD8f=dDc<cI1@C@g<CDa=3A4
@CDh<dA2<T8aA4HcAD51ACI3A394=cM1=CTg>44g=c4f3D<`ASM1@SPc@cT`=c=3
>30a<S0i>38PCT@=;ePb<R0P=3DPDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Pc<THg
=3=6=cHi<495A4@c>34e<d8h<cTc=4HaACLhA3U1=D@b>4I23D=5=T4h=38a=D93
@TDgASU1=3TgACL`<CQ1ACPaA21>A0d_F38c820a<CPPDT@P<SA5@d94<3DcAD8h
=cDc@d4dA3I6>4=6>356=48i<SHg<S4b>493>DDe@d55@S4c@DDbA30c@dA5ATI5
3CPb<dE4<SHa@CHd>CLbAT@e=dHf=cDb<d<`@d8a>48a=DHb@cHg>48b=d<a>C55
=SDe=D4f=4<g=DI3<Pe6<T4f=S@i@CA3=THg=c0`>4I1=3La<3U5<dA2<d8e@C51
<c0eA38fAC13=S<b=CA5=dE4<3Hi>D<g>34=AT52<30h>4<i=T8`@SU2=TI5AS52
=C11<SE4<CU2@c0bADE2<S@b<C92AD96=D@g<C8i=THa@d4PCT@=;ePb=20P<SL`
8594838dAD=2A30e<dE2>3Le<d=1=4@fASL`A48a<dDdAC8`=TE3>D8g<C=5=SE3
=30c@c<i@STb@CL`ACTf>@de<CPh@D=3>3<c<4<eAD4bAC8i@d8c@c8d@TDh=CU6
A3TeAC@`<DH`<SDh=c<g=SLa=3<i@c<`<d=1AC@=<34d=S@eA3PfACD`<SLc>3U1
=S0eASM6<S=2@C8d=3Pe@T96ASA1<CHe>393<3D`=dDa=3@dA452=C943C@e<d@f
@cPe@S<f=cE4@dA6AC91<4De<S16A3@i<S8dAC0b=d@e=CL`<D55@d8a<4E5@SE3
<T54@CDc=0d`<3<h=T4e<cTe<D94@STb=dE4<SLh=c93>C<a=48f<cLi<SA3ACTd
=cE5@SDi@CM5=D<g>CM3=D95=c@=>4A3<d4c=SDi=S0h=S16=c=5@C4a@d8gAD8f
<cM4A3Tb=T=3>D91<3U2=c@a<DHe<3<`@SLf=4I5@DA53CD`ASHi=TA6@CQ4>D8f
>4Di>D8b=d55=SQ3A4DaAD4`>CU2>DI6ASTcATHhAS4c=D8b>44aASU6<C8aA@dg
A3@c<T<`<4<e>3<aAT=3>4Dh<d<b=C93>C8`ASPf=cLh=S12>DI2@dE4<C<e@c16
=3Le>393@DI4<DH=>DHh@DA6>30f<C@bATE4@C@h=CDg@d<d@D8g=CI6<S55=S@d
<cA6<34dASU1A4<e@cTc=4@c<48e<S<h84i43BmH<SDP838g<B1BA20b=4E3@T@`
=C=5@T94>4@hADA2@CDdAT54=CTc<c0`@CTcA456<CA1<S4eAT51=SM5ASDe<356
=SP`ASL=@S<`=C95@D8g<THa=3<e<T<fASTc<C52AST`@S<h@SQ1=dHb@T@g=TE4
=44d<S94A3Pe=3Q3=S=3=D@d3CE2<c56=C52<C92<S@dAS@d=d@a<d8e>C<c=4<h
AS<c<4<b>C@aA3Dh=D=2>4Hc<48e@S0c<cLa<4@g<@e6<30g<cA6ACU5A3A3=c@`
@c13AC8gA3Dg@S92AC8d@D@g<SU6<dE3@c0b=S0g@T@`<CDa>456A4I2>CH=@C4f
=3Q2=cHg@d=3AS14<3DhAS92<34f=4E4=S8d=CDe=cM3>4Dd=S13AC@iAD=5=3@g
=cLb=DI4=S563C4e<3@a@dE6A3He<c0hAC96=T=2<T<g=c0i=d8g=d@f=cLcA48b
<S56<T8g@cDb@CLa@S16@CI4=4I2=`diASE2<d4g>4Hf=T=3<4E5=4Db=S<h@dE2
=cI4=SH`@THd@SLfA391<3Dh<CDg<CPd<c0h=4=2>CPf=DD=<SM4<3=2=4@eA3E5
=T4g>4E2=cA5A3Db@S91=3HaATE3@D<a@SDe<S<g@SHg@D@hA44f<SDhAS0`=cQ2
3DI2<DA3ASTd>3Hd=44fATI5=SDh<T<a=S8c@D=5ADE1@T@a>CDb@SU6>44g>3U5
>D@`ASDe=CDh=CTh=Pdb=21>A0d_F38f820c=3PPDT@P<SA5@d94<3DcAD8h<c4e
<CTaADH`=3M4<C<gA3U5>DI3<4<h=T<g=DHf<4Db@CD`<dHd>355@TH`>4I53C8g
=3De<d=1<C52=dI2=S95=c55@cU3ASA3=CM6AD4d@CA2<c51<3=4@cHe=cDi=CHa
<T8i>DE3<D4c<0dcAC8e=C11@DH`<cI2@d4iA3Lc@cHbA3@`=cE3@d8`<C<f<DHc
=cPb>3Dc=C<i<34a<TDf<3Ta>3HgA4D==dA3@cQ6@d53<30d@dI6>3Ti<c@g@d8b
ASPf=D4iACHe=3Hf>DDgA34e@CP`ADI6<TA4ACTg=SPiACPf3C4c=4H`=D8h<CQ6
<cI1<SA6@cDc>34`<CPh<456=CI2>D@g@cD`<TDbASHbAD@f@c0b@CU6@CQ4<d4g
=@e1=d4aA34b=CA2@DDa@S94=DI2<D8a=4@aAS@a>355@S94>CI4A312=SI5=dDa
=3Hd>4E2=cDf=3Dh=S0=<cU5@D8c=c4f=STi>496<313=cU2>3Df>3Hb@CH`>D=6
=CLc>C0c<SDcADA4=48eASE1=cI5@c96<C0a3DE6@S4e=DDe@SE4AD4c>3M4@dH`
<SDi=S8dA3E3A3Tf@S<`=D<gASTd<S4e<C0`=T<`ASE3<c0`@cA6APdc<T94=DA1
<cA1<c=3>C55AS94<SHeA4Dg<TE1AT56>C96AS0f@S0e<38gACLf=SE1ADE3@d93
<CQ6@cD=>DI6=3E2=SM1>C8aAT@a=SE2AC=6A3<f@T52<4HgA4@g@d@h=TDiASPe
<c=2<T=2>4Dg>D4b<T4g@d8`3CTb=4@g@CA2@T4b<cTf<cE1=C<a>3Q6@D8h=SE1
=CDeAS<b=38`>C56=T8`>CLbACDg=D54<cTe@T4eAPdi<cPc>C=6@cPi<cD`A4@d
<cM2>44b<cI6<3@c<CT`@SU1@SPPCT@=;ePb=b0P<c0PDT@P<SA5@d94<3DcAD8f
=dDc<cI1@C@g<C@f>496ACPhAD=6=3Li@CHfA3Lc<3La=S@d>44c<C4dASLi<TDe
84i43BmH<SPP834`=B1BA20b=4E3@T@`=C=5@STg@T56=4E1=SM2AT4e@S92=cHi
=SA2AC<`<cTa>C<d@C=6>3Q1>DI6>C<d=c@d=C8=<S8a=ST`=cU1=cE3=DHe>4Db
AT<eATI2@D4`A391=3@d=4Hg=S56A4A4AC<eAT96ACTbA4<f=SM4=S523CDdAT@e
=S@c@T8g=456=c=2@SLhA48aAT8c<dHf@S4f@D<h<4Hd<D4a=SPf<S0a<C14<DE4
<d91=DDhA0de>3Pd<D4d=S@b<C0h=dE3=4=6>C=1=C<a@c13=cHPCT@=;ePb>B0P
<C0d8594838dAD=2A30e<dE2>CM2@DHdAD4f=3Pc<c8c=313AD8dASTc=d8`<316
ASLc=C4fAS4a=4H`>313>4=4=`e4A34h<4Dh@C13@S8e<C0e<C0a=CTd=44eASTb
A30f<THi=D8g=c@h<THdA455<492>D51ACA1AC12>3T=<CTc>C=2=T8b<SM2@SQ3
>CA2<4H`@D@`A3@hA3E3@d@i@c13<3<h<3TaA354<TDf>4<aASQ4=DDa>4<b3CPg
>3U4A44`=dDg@c0c<391@SA4@C8c=CPf<T8PCT@=;ePb@B0P=c4PDT@P<SA5@d94
<3DcAD8i@SQ4AT=6<cHe@dE4>CHhADA5=C=4@S@c<DHb@CTc@c8a=S4iACHa=C8`
@S<h=C533DA2<d8c=4<i=T8h>3<a<c95=4<iA4I5A34d=392=cDb=dDa=3Q1<D56
<cA4<cTa<D4e<dDg<4D`=3Pc=@e6@d8`AS4d=T<gA3M6<3Df>CU2@CM284i43BmH
<T8P83@i8594838dAD=2A30e<dE2>3Le<d=1=4@fASM5A4A1>DA6<4<cAS94=T<e
<cPa<4<a<D<f<SHg=C8a<T93=4@`<`df@cHb<4Dc<c4`=STd@SU2=38aASQ2<dHh
A34a>3M2@D8`@CI4=21>A0d_F393820g<21BA20b=4E3@T@`=C=5@SHgAC<c=T51
=3Hd=T8c>4<c>44c=S<e<4A3@dI6=dE6=D@g>D@fAS4a<d52AS0d@cP=<D@g@d94
ASM3=c13@T=6A3Pb<TI6@cDf>D<d<CQ6@c@h<T8f=c15=T@g=SLc=c=5@c4bATA2
AS0i>D<b3CE1>D<c<TDgAT<g<CDf<C8h@SE384i43BmH<T@P838f8594838dAD=2
A30e<dE2>C8gAD96=c94A48h@DA1@CTh@c<c<S<c<C@dACE4A3I4<c<hAT@fASHP
CT@=;ePbAB0P<SLPDT@P<SA5@d94<3DcAD8f=dDc<cI1@C@g<CHg<CTg>CM1=d52
<dA4@cE4=DDe>C=1@CLg<T54ADI284i43BmH<THP83<`8594838dAD=2A30e<dE2
>CPf>4=1=3U5ADHc@dDc>C4`@c@`=c<h<T54@T4h<SHaASDb>44gATHd@CI4@d8h
=b1>A0d_F3<`820a<cDPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6>316@S4h>394
=cPg<S8i>3Pg<d8eADI3>34bATI3@SLe=CLb=d<f3D4b<CQ3<3H`@S4c>CE5AC0h
=d=5@C@a<3E6<d@g=34h@C0h>CM4<T8a<CI3=T<h<c@dASE6=SE1ACLg<0e5<T=2
<4@cA38h>DI6=D95@c4b<CHi<c8f>44i<c56=DDhAT@h>DA4>CE4@CM4@CE4A30b
=T4e@dI2<T4=@T@`=T=4=c=5=CM5=SQ6=S96>3Ha>C8`=34i<48h>353<S8d=TE3
ATA1>D<d@cD`=44f@S8a@dHd<cPa3CU1=T8a<SLf=d<b@S15<c4a@cDb@c96>D4i
@S<c>21>A0d_F3<a820c=B1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THh<THh=CTf
=3M3>34d>3<h@SQ5=3Tb=cD`=S54A4I6<cLb=T8d=cT=<DE5<cLf@D@b=21>A0d_
F3<b820a=CPPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I5A34iACTc=S94>CDi=C0a
AD4g=cI2AC15@D8a=3Pa>395<c51@dD`3D51<S92=T4bATE2=c11>3A5<D56@S4d
A3I4>4I2A3Q2=CPe<D94=S53A4Dc>30e@c@cA38eA4@`=d8`>0dd<44h<SE1>3U3
@CI5>DE2<c0i<30b<3PdASQ1A48i=3PdADI4@TDg=494AT@c<CPe<d4gAT8c<T8a
=4H=<SU5=STc=D4c<S=4<CTc@CI6<3E6=cHe<48e<TI4>CQ2@T@e<cI2<CI2=DDc
=c<d=c@i@c0d=SE5<T@g3DD`<cU3@cPcAD8h=cI5>3Tc=cA3=d8f=CI5=c8`<DA2
<4Ha=S<b=S<`=cDdAD96@CE6ACHdAT<h<CPf=0da@SPg@S<bA3PiA3E3>C9584i4
3BmH<c<P838c<B1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THh@T8hAC94=cA2=30b
<44d>3E5@T8b@dDf@cLb>353AD@a<TE6=C<=A4<b=SM5>3A1=cTi>CPa<ST`A391
<D4cATHc<4<a=4<d@CPi<SDa=4@i=T@h=3Lc>CHf<c8g<4E2ASM23CLcAS0h=4Hi
@S0d@c<`<cLf@CM6@THfASE4AC0fA4E3>C<d>3E5=CQ4@S14=cPfAD@h@S@c<C0i
@d<`APd`ACD`@c14=S<aA312<D@a<4E2=3M5=T4d=D4fADA6ACA6=TA2ACA5=SHd
<CU3A4@`AT51<394ACL`@c0=>3TgA4@d<SI3=c<b=DA1<d<e<492>D<d=d4h@cU5
>DI5AS16=CDc<dE1ASTi<3Li<cThASPe@CDe=DDe3CE3=cHeA3<f>D<g=cHh@C@b
=4I3=S=2<THe@d93=c4h=cM1AC=3<34hAD8i<4A4@c@`@CTa@S8`>C4e=`df>CPg
@dE6ACHe=CM2@DA4@C0`=3<g<S=1<DE1>CA2<C8c<DDd@SE6AC0g=S8b=STcAS0g
@C=6@dHc=c0=A491>C=5=C<f<CTaA4<f<T@f@D55=d53=SLf=S<c@TA5=314AS@e
<SLc84i43BmH<c@P83H`8594838dAD=2A30e<dE2>3Le<d=1=4@fASLhASLgAC15
@dI4AS92A4<a<CHi=cI2=S12>4Hg@c8c@SHd@DDc@@e4>3Lf<T=4=DA6=c51=c=3
@cHc=D4e=38a<454<44c@cU4@d<b<S<d@d4f<D56@S16<4I1<TA1<493=CHPCT@=
;ePc=B0P<C<b8594838dAD=2A30e<dE2>3Le<d=1=4@fASQ3=T54A4Dg@cT`@d=3
=T55A3I6AS8a<d@a>4Hg<c@eA4Di@STb=@df>3Pf=STbATDb=3A2AC@b=SPd>DI5
@D<h=T8gA393=4Hb@C<d@C8b<S8g@CQ6<3Tb=38fA34a>DHa@d4=@c8e<4Hc<D4h
<4=4@C16<355@T=5=d<hAT55AD<i=CE5=D@f=3U3>C@a=cDi=3@hASDa>4=2=D55
=S4a3CHc<D@g=d<g>451<cPc=44f>3U2<4@f=3Pc<d@dACL`>3I2=SPf@SI3=d4c
<C93AT<d<d@e=cHdAT=5A@dg<cThAD=6AT93@cPi>3Ha<T52>491A3<PCT@=;ePc
=R0P<S<f8594838dAD=2A30e<dE2>3Le<d=1=4@fASQ1=SL`@S51@SL`AS53<d@`
@d@d<CTa>4@h=d53=cE2@D8h<4Hh=0df<30`<CE6A3Pi@c0c>44h@T8c=30a=SM6
>34a@c<d=D8f@DA1<3TfAD4c>C=5>C=4=495<T<c@SPd=T4=AD96<C@`AT96=4Di
=30c<3M2@cHd<D<aAD8f@CPh=DHd<CTfAS4a>D54<cP`=D54=d92<3T`<CTd<CE5
3D4g>CQ4@SI3=d@a>392@CA3ASPdAS@b<THf<T<d=C4h<CDcA4DeATHa@SQ6<cLb
=STa@S0g=452<S<d>@dc=cH`=cI3ADHe<S0hAT54@TA2@C8d>3A3=d94@cD`A3@f
=cHh<D8h=356<T4g<4E5<4E4>C<i>DHdACT==c13<SU6=D55=3TeA3Le=SPi@C14
AC4gAS<dASE3@S@b=C<b=3Li=SH`<dA5AD96>DA1=3Hd@d@fA3933CU6<4Dg=dHf
=CM6=dA1=4Da@T95>D=6<D=6<c4fASDi>38a@dDa=dE3A3DcAD@h=c91>CA6<353
=D@d@@deAS11<d@`@CI2ADHg=S0b=3=4<TD`=T@d<3U4<C0e=d92A44iATA4>CI1
@D<b>4@c@d<h84i43BmH<cLP83Pf8594838dAD=2A30e<dE2>3Le<d=1=4@fASPd
@CA5=cI4AC13@C51<S@b=396>CE4=C4a=3A6=c0eAS0a=c4b@Pe2>D8hACA3=30d
=D@eASTg>DDh<SQ4AT91<C<i=dE2=T4iA4I5<c51>3Tf@SM6>38f<C4c@d4h<d@a
<D<=A3@i>CTi=T=5<SA6<CLh@T<e>C4h>D<c<C@cACE2<3DhA4=4@cE4@SU3ADHi
=S13=cDa=B1>A0d_F3<h820c<3DPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=cA5
<4Hh>CQ2A34`<3P`=4Di=455=S<g<S8iA30f<d92ACTi>CE53C8f=CQ5>C8e=4<f
A3U2<3Pa>3A2=493<3@g<d<iA3D`@c0h@c4cATD`=c54@T94<dI3<C4i=SQ1=395
<0d`<3=6<4I2AT<aA4<g>4=5<c0iASE5>C=6>CQ1>DDe=DHb<cE1@S8dA4=6=3Hc
<TDf<SU1@cPe@dE5<c0==D8c<cI4>D93>C<`A3Lb<c=4@SDdAS11@cHc<D8g>C15
<d56@DI2<dI3=313ADH`<C@b=3=4>DE1<DA53C55=34`<c8h=c4fASU1@cE3=c8h
=CPb@STi=3Lh>D=1<SHa=cDaACU5<DHh<4Hc@c0a@DDh@SI2=cLf=Pe2@cLc<cM3
=TI3>48a<393>D8d=C<e=DA2@cM6<3<g>4Hf@CLb<CTc=d<bAS53A491=cHb=C@e
=SHe>DH=<SQ3<c93=c8a@D4h=D=6=CE6>D55>493@c@a=S56@C@h=S0a<D<f<dD`
=3Di>4Db>4=6<cPd<S4`<CM53CM3<3Li@DA1<CH`@TE6<d<h=S95<d@a@c16<D@c
>3PdA4<f=S4fAD8`<3Ph@d8b=3I5<CI3<CDhACA2>@e5AC4e@D@e=DDd>3<i=CHh
<c16<STd=dE4@dI6@STgAS0i>3Q6=C0e<dA5>495A44c<3L`@T91>393=TD=<C14
A4I3AC54AC8h<c@e@CU4<CM4=3Ta>3Db@DE2<dA6=T@c=C16ACI5A3Q1=d@d=3La
ADDe=4H`=c4i3C@f=c@i@d52=C@PCT@=;ePc>B0P<S<f8594838dAD=2A30e<dE2
>3Le<d=1=4@fASLf=3A4<T52=492>3Tg=d95<T@f@cQ6>4D`=CA1>D=3>C=3=STa
A0di=d8`=S4f=cE1=SPaA3E4<4@a=DDg<CLi@d8h>3Dg@dE6@S@g@cHbADE5=CTf
<cU2=3Tg<c=4@cQ1@c0==SM2=cPi=c<e>D=6>C@f<c<iA3U5AT4e>4Hg=30g@CA6
=48g<SHd@C<f=TI3@d<g>D=4=3U4@SDh>3=33CE3=C94<cT`=3@c<4H`=DDc=c13
@cDd<CM6@d55<d52>313<CLa<S4h=c@h<D51=3Ha<cHh<ST`AD@f=0da<T=4@D@`
>30f<cQ1>D@c=4<e@C56<T@f<3Lh>C4`<cI3ACHh=DDcASA6@SHbATE4ACA2<4I6
AT@e>4H=<CI2=4Hg>4@`@SDb<d8b@S4b=C0d<T4i>DDf=d@f=cI5>D@g>4@`<CLc
<S4i=dA1>D=5A3Da<THf<CQ63D@g<c0b@c13A4I1<cU5<d8g@cPb@c0`@CPb<cHf
>CI4>CM4A4A2<30h<d@`<SPa<S14=C<b<cHd=c96>0dh@c55AT8i@S<c<dI5@S53
=cHg>C8bA3A6=cHb<cDg=S8e<S56AS8h@C4e=C51@D=3A4<d84i43BmH<d4P83@c
8594838dAD=2A30e<dE2=SM5<c<f@D4d=c4f=c4i=cTg@CM1@S=4A4<eA3E5=CTc
@D4g=c91A4D`A34e=3=3<0e6<D<b@C14>4De=3M2=CQ6<c4`<313AD@g=b1>A0d_
F3=2820h>21BA20b=4E3@T@`=C=5@SHgAC<c=T51=3Hd=T8c>4<c>44c=S<e<4A3
@dI6=dE6=D@g>D@fAS4a<d52AS0d@cP=<D@g@d94ASM3=c13@T=6A3Pb<TI6@cDf
>D<d<CQ6@c@h<T8f=c15=T@g=SLc=c=5@c4bATA2AS0i>D<b3CE1>D<c<TDgAT<g
<CDf<C8h@T4e=D96=c@iA4Da<SDa>CHd=48a>3E6=cDa>DI2A3I4AC@f<cA184i4
3BmH<d<P83@a8594838dAD=2A30e<dE2>3Le<d=1=4@fASM5A4@eAT92>C4a<CLa
<C4i=S0e<3=2>3TaASDf@DA4=cE6<C8i<0dc<352@CHi=T@e=dE6<C0b<TDi@cE6
84i43BmH<d@P83@a8594838dAD=2A30e<dE2>3Le<d=1=4@fASM5A4@e=C14ASTi
<DHg=c<fA3Tf<SPc=DE1>CDb<S0f<3H`<314=Pd`>3<g@T4i@D8c>3Pb@CTf@d8e
<C5184i43BmH<dDP83<h8594838dAD=2A30e<dE2>3Le<d=1=4@f@cLgA30h<CH`
=C95=4Hh<38i@cDd=c0iAT=3@CM2>C0dA4=5<cE4=@e3<DHg<THb>D4i<S94<C4f
84i43BmH<dHP834g<b1BA20b=4E3@T@`=C=5@SU5=3@`<C8e=cU4@dDiASI5=TE4
ACLh@CDfAC56<c<b@c@f@C94AT8`=4A4ASLf@D4=<D@bAT=4@T<a=3L`<STeASTb
>30g<C51AT@`=d51AC11=495ACI5<CTc>CHb>D4i=3E5@D8aADDc=cDi3C51@CLa
<C<d=cPg=D=6=C95A316=D4`=dE2AD8eADA3=c52=CE2ASDh<DA6<CA4ASE6=3=2
<3Pb@C8b=`e6=4=1=T<a=SM3@cTe=dA5<TH`=S4`=THi<S93=492<cQ1=d8e@cDg
ACH`<3Le=4DhA311=3Ld<D=2AST=<C@`A4I6=DDb@S8f=TE2A3I4>4@c<d51@dE3
<T8g>DDg@DDc@CE4A30aATHi=TA2>C@b<cU1<d=2A3Hi3D<c=34b<4A1<3@hACU4
ADDb>D8g>4A1<3=4A394>C=6>CI4=4=2>3@dASI5<30PCT@=;ePd<20P<c@i8594
838dAD=2A30e<dE2>44a@C51<D8i=DHa@S0e<3Th=T=4@C0a<4E3=c@d=C<i@CQ6
@S@cAS<i@CPaA452@@db=4I6A4<d<4I1=T@h=S<h=S@dAS95A3<b=SQ6=dE1<c8e
AD@c<3Hc@SU2=TDd<30e>D8cAC12@cQ3=3T==SI1>CPcA3U4A4Dh@C4b>34c=C<i
@C12>D8`=D95>3LbAC<dADHf>4@hAC<b<TI6<cE5<T8h<D4`=d963DHc=34dA3I1
@SI3=cM5>44b<CPi=44gA3M4=34e@T<f=D8d<315=S8iAC@i=dHbAC@b=TA5=DHg
A3PdA@dhATDe<cQ6@C13<CDd=DI1=C4`<S@g<TI1A496ACPg=T8h=cHe=SQ6AS0`
>3@c@SD`>CDc<T8i=dHiA4@=A4Db<c<fACI6@cTg@c94=D4g<4<c=S<b<CU4=30c
=cE1<CU4AD4i=3Dg=DE2<SHd<d54@S0c@SE4@CH`3C92>4I4<c8cAS15@T<`>D91
@C<d=cE4@d<c>30h=SPc=d4gADDe@cA2>48dAS=2@CU2<dHc>CQ4<T52>@di@CI2
=S4i@DE5AD4b=c8g@cM1@CM5@T=2@dHa@dDg@cU3<S0gADA3ASL`>3LiA3E3ASU1
A3D`<3PeAS@=AT<c=dI1@S@g@c8h>496>455<DE5>C<gA3A1=c13=S0`=SM4AD=2
=dE2=T4a<4A6=3Pe>C93@C93=30g3DHb=S=4@C4i@SD`=SH`=T4`@CM1<SQ6=394
A395AT4e@c15@T@c<d@c<3T`@D<dACA2@cQ2=SM5@TA1>0e2@c8`<d8hAT4g=T4g
=C8fAS<eAC0hASDd<SA2>CLi@C<g<C=5ASTaADE2>C8g@S4i<SA5>D51A3A5AD8=
@T@d=C11<TDh=SA5<cPd@cPd=3<e=dHe<dI4=CHgAC@g>351<4<PCT@=;ePd<B0P
=S0PDT@P<SA5@d94<3DcAD8h<c4e<CTaADH`>C4c=CE5=S<a>D@cASTa<C0e=S53
ACA1<T96>3I6=cM4=c52<D4c3@00X@30?oli<dHeAC4dAD@f@cM3<d<g@c8b>D4c
=dI4AC<d=cQ2<d=2<T<a<3M6AS<g<T4e@c@c=S<h<S4b<3<f=SDPCT@=;ePd<R0P
<CTa8594838dAD=2A30e<dE2>3A1>3P`<cPd=d56=T4a<CHf=S16=d4d>3He=dE2
>392<S0e<D55=C4f=dA1<TI1<Pdc@dI4@CQ4ACHe<CU2=T<a@CTh>CDa<D<e=dE3
@C8fASLi=3M6@SM3<SM5@THe=cLhASTb<T<e<4De>38=@cQ4>34g>3Pf>44a<S11
<cU6<CPc@SHb<D<h=S@dAT8fACU1<D4`>3Hi<DE1>C4b@cDc>DHc=D@i>48i3C0e
@SHf<44f@T4c=3<d=cA1>CTg@T8i=d=3@TDg=c=6<cTh>3Pb=SE1A4Dh<DE4>C@g
=cH`=SI1=C4b<0daA316<S8fASHc>4A1=CM4>4<hAT@e<CDi=T<fADDg@S<cA3A1
=c54<D53=4E3<SHa<dE5<3ThATHdA3T=>C15@CU3@d53@c8b=dDe@c8`>C@`>CU5
<d8aA3Tg=d<a<48d=453=c<bAT56=dHb=C<gAS92ATA3<d=43C8c<SDi=STi=3Dh
=44hAT=6@C4c<cDPCT@=;ePd<b0P<CHd8594838dAD=2A30e<dE2>3@e=c11<S0i
ASI5@SM5>3D`=cTdA494@SPc@T8c<S55A4I4>3Q3=3E6<C0cAD55A0dbA44b<48c
=CDh<S0f=STh@CDg@cE2<c15A3Q2<d<f@CLi@S12@C<c=SA3=S=6<C<h<cE5=S4h
AC8a>38==c16=D@i@S<`ADHg=4E6A3Lc=D94<T=6@SHh<cDb@CE4A3Hh<T@`<456
@CTdATE5=44a>3E6=4Di@T<b3D4eAS54AS4i<D<`<D<aA3Df@dA6=dI4>44g<S@g
AD4`<c<cASQ5@C@d=C=1>3A6<c15=SDe=cQ1<SPfAPdfA3<e>CPeASPh<cA1>D8h
AT92AC8iACTh=3<a=CQ2>D<bAS=1AC52<3<h=TE2=cPgA48hA3PiA48gA38=AD@g
<cU4<496>4<`>C4h<SQ5<dA6AT4c<C96=R1>A0d_F3@d820a<S0PDT@P<SA5@d94
<3DcAD8h<492=CE1AT8h=3Di=3E4A3Dg>D92<C<d@c4bAS0a<TD`<DHg=S56@D4g
>CHb=4I13CE1AS@h@CPaADE3<SQ5<S0aAS<a@DE6=d8d=cM5@TE3>CLc@c<d<T@f
=SHh<TH`>4De<c96>CE3A48i@Pe2=CM5=c53A3Pg>CU2>3E4<d8a=S4i=dDeA4I6
@C0b<THc=351@S4c>CPh<D<i@c8c@c96>4I1=dA4AS8=<D95>4Df<3E5<cU5=T8f
<SHg<CL`=3M2>3M2=C@c=SLg=c54=DA6AC55AC54@C4f=SQ4<cPh<T54ADI284i4
3BmH=3DP83@g8594838dAD=2A30e<dE2>DI3@D4`=c4e=4Hi@T8`<4@iAC52=4<`
@d@bA3H`<CA4AS@cA3Tc@c16<c53AS@b<Pe4@T8`>38a<S=1=c0`>3PgADI5AC56
=SA5ASDb@T4iA31284i43BmH=3HP83@a8594838dAD=2A30e<dE2>CTe>C@b=CTd
<CI3=44g<4I6=3A5=44b<T4eADHc<4A1=d8f@DA4@SHb>C=2<cD`A0dc=S16=C0h
@dE4AC<g=S8i<D@d<48e84i43BmH=3LP834f<R1BA20b=4E3@T@`=C=5@SPf@dDb
<CLa@D4i<d4e=cDaA34f>C8g=SQ2=CM2@S8`AS<`<T8`=SQ5A3Tg<CT`>CD=<d@a
<CDbASQ6<T@i<3Tf<CLh=4E2@C8f=SI1=S8bACDd<d@e<CM5@CLg<CI4@S=3=S8i
=S4f<d<c=3E13CU4=SQ2<SI4@D@h@SL`@cPdA3@f<3Q4@SE6@TDe@S@eAD=3<3Pa
>3@i=S0a<cL`>3E1=3HbAS16>3@i@`dc@D=1A3Hb=d51<C12=4E2=3Pc=C@i=3U6
>DE1<d@f<S0g<SQ2AS=3<CLiA3Ld<SPc=C<g>312=c<d<30=>D<g>4@h=SU2=D<h
AS<cACM1>C=6>34i=4I4<3Td=c8c<C0b>3Th<SHg=THd=T54>3Q4=3E4ATHf<cU2
3CTh=d@`<T8i=STi>4I2A3T`<3U2@cHfA21>A0d_F3@h820d=b1BA20b=4E3@T@`
=C=5@SPaAT@d=T8`=CLeA3Pd=cM4<cM4<cE4<cQ4<3Dd<D8e>DI5<3La<THb<TE4
=S4i@T4=<38b@C<a=cLd<c@a=352>C4`@C@g=4=6=d8e=T@g=S=5=21>A0d_F3@i
820b=B1BA20b=4E3@T@`=C=5@SHc@S<e>DE5=3@`<c12>CQ1=c4`AS4`=d93=SQ1
<cI5<S15@CDi<R1>A0d_F3A1820a<3LPDT@P<SA5@d94<3DcAD8i@CQ5=T<hATE6
<CHg<d8b@c0eACDc<cU2<cA4@c92<CLc=3DcA4E1=c0g<TDh@DDi3C=5@c@`A455
AS96=3=1=3M3>C8`@SPg>3Q6=S<g<312A3<iA3Hc=cLg@STf<cP`<3Lf=C@g<cDd
<T<d@Pdh@C@b=4<gAC=1@c0dA3<g>4Ha@S93ATDd<cPg@TA5>C0gACU6ADHb=CE2
AS@g=dDeAC8b@D<i@STc<c0==452@c11@c0iA3@a<T@fACLb<dA6=d<gAC4h@c0h
A38aA21>A0d_F3A2820e=21BA20b=4E3@T@`=C=5@SPg<DHe=cU1<D8b<d52=D51
<SDaASQ1>3Li@SPbACI5<SLa<SE2<3Te=3A6AT54<cT==4Hg@d51A34`A48`>3Hb
>D=2<c@i=44h@TI5=c0a<CP`=496<C=2=4A1@TA2<T8c84i43BmH=4<P83<`8594
838dAD=2A30e<dE2>DHc=SPfA3@g>3Hf=CDf=SLdA3U5<C@gAT<a<D@f=CP`@cHi
A3E6<3I1=dD`@CPa=21>A0d_F3A4820g=b1BA20b=4E3@T@`=C=5@SQ6<THa<4<a
=SLaAT4g<T55<T8dA3U2=d<c>C55<cPg<d@h@C8`=T54>3Ld<CM1=TH=<352@cI6
A4I1=3Lc@c4f@D56<cPg>CA4=cA2=SDcAD=5@c=6=454AC8`=SHeAD<g@CLgAC4b
>3=2=cE33C55AS=3=SDe@TDg<c8h=S0f<C=2@CLi@S0`<3Ta<cTa>C0PCT@=;ePd
AB0P=CLPDT@P<SA5@d94<3DcAD8h<38g@S4e<d4b>48a@D=2@C55=4I2=3=6@CLa
A3Te=c13>4=2@dDcAC95=SPb<3Q53C8f=C4a@TE4<cE3=4I4<4@g>48b<4Dh@C=2
=3=6=CI2<cM5=S0h<CLf=38c=30eA3A4=cQ2=B1>A0d_F3A6820a<cDPDT@P<SA5
@d94<3DcAD8h<SU5=3@d@S0e>DHi=D4aA3@aATE3<3E5@C8b@D4a>D@c=48e@C12
<d<gAC8`<34b3D@b<D<g<D4h>D92AS8i<SLh>4<c>38g=dHg<T4dAS55ASQ6=C0`
<CE6=cDa<355AS96>D4h>4A4<354>@e5@D4i<DE1<T95@SL`AS8h@CHbA3A5>34a
<C<h<D=1=cTg@cH`=SQ4=cQ2<3Lc@CTf@C@eAD4d=CLa<d8=A3A2=30d@T93@dE1
@S8f=3@i=3DfAC<c<SU3=S4h<T95AC@fAC=2=c=6=3=5<3U2<3Dc<D55AC@c@D@g
3CE5=c<`=3Q6@C8a@S96<SLb<44a<SPi=3Hh=S<f<b1>A0d_F3D`820a<3<PDT@P
<SA5@d94<3DcAD8iAS<f>3I4=3M1<S<i<4E4<4Hh=D=4=SLf>4H`=38b@dE5A4@h
@S53@CU6=D=4=C4c3C0a=T8d>44iACDf@cU5>3M3@DD`ATA1<cI5@DA2>CQ6=dDc
<3Th=CTg@SLd<cPa<S8g<D@d=CQ3<CI6>0da>D4dA4De=SHd=C8e=4D`<3D`=CHe
ACHg<C<`@SHf=38e<3M1>D4`=D8i=3<b>4<i>3Tg<cTfAT@d<DH==4=6AC@e@S53
>CLg=D<b=d<c=c4e>34`@D8PCT@=;ePe<B0P<CTa8594838dAD=2A30e<dE2>38i
AC@d=48`=CU6AC@d=D8fA312<3Lg<dE1>3Hc@cHdA3Pe=cPcAD@bASLb=S8`=@di
<cDa@CM5@C<e=c4i<dH`=D8b@S55<d@h@D8g<T94=C14<d<i=D@f<cLb@SPb<SHe
@CTd@C<c=4@c<T@=@cTh>D8e@d<`=c91=cPg@c4i>DA2>CPf=c8d=3<i<SPd>CDd
<SLi@cDf<4@b@d4a=DE3AD4eAT@i=cLc3CQ4>3Q4@S8f<c<c=c0h@CPd<4Hb=314
A3I4ADI5@d<`<TDi@CDi>351@c@d<S51@TI4=454A38hAS@c@Pe2=313ACU3AC=6
@CDcACTbA312=c4c=D4c<4=3=3Tb@THb<cA4AT55@DI2<3Lb<CH`=TA4@C<iACPc
<TH=<cDhA4E5ADHf=T@e<3=3@SLb@cE4>396@c4h<dA3<cDhA3Pi>CI4<34d<c<h
>CThAT@gASE6@CHb@DI43D<b@D=1=T51@D<f>DHb<cHb<d8g=cHPCT@=;ePe<R0P
<CHc8594838dAD=2A30e<dE2>DA1<c0b<C@b<c8fA3=4@dA1>D55<cDe=4Ha<3Ha
A30f@SPb<356@C<`=S@e@dHc>0d`=DI2A4@g=dE1<D@bAT<fA3U1ATE2=D56=495
<d=4>3H`<4I1=c52AT<dAS12AS8aAD<b<dHe<CU3<C4=A4A6@d<i<cQ3ACHa<SLc
=S4a=cI3@D4i@cU2=C8i@DA2=T4d@T<g<CHi=353<CPg<c0`<c=1@CQ2@cH`3CQ1
<STb=TA2>3Ti>CDiAC96@DDiA456>34`=d8h@C8a<d@f<T54>3I2AS51@D4b@SE2
AD8`=3A2=SP`<`dc<SM3AS4e<S<`@S8c=SI1>48a@DHg@C0a<c16@C4h=c<a>D95
@d@`=c8f<T4b@c8e=S8a<cM5@DI1>DD=@dH`<c94=CPa<3Li@TA1<3DbASE5@c8c
A4DPCT@=;ePe<b0P<S<g8594838dAD=2A30e<dE2>DA1<c0b<C@b<3E6A351@dE4
ASL`A44d@dDf=CPd>48c>CI3<cHi@dD`=CTd<D=2=0e3@d4a=DI4<c@`ASHhASQ6
ASQ5AS8i<34`=dD`<STe@T<h@D51<cI1@d96>3I3>CHf=d8h>CHc<34e=44=<S56
<SI6>C93<3Q5<DDh>C<g=S8bASDc=44`@S95A3Le@C0gACT`@S0g=cQ2<D@f=CE4
@SH`=d<f<D<b3DDd@STe@S=2@c<f<D4`@c<b<dE3<S8a<D4dA3Hc=3HbAD=5AT=4
<S<d<dHg@S0a<d8h<44i@T@d=c0h=0db<S<d>4<a<D<a=STd=D@g<3M3<48`A4@i
=C55=38g<S55=CE1>CHa>30d>315>C@g=D8i@CPf<cU3A3P=@dA4=c56@c<f=c95
>30bA3Te@cQ3ATDe<494<3Pb@C<b@T55=c4c@TDiAD8aASE2>4=6<S@h@CTc=T92
3CQ3>3Q2>3E5@CHd@D4c=c@f@C<c>4@f>456AS4d<CM6@C8h<d<`<CA5AT96A312
@c8hADHg=3Q2A316<0e1@S8e<c4b>C8iA4E1AT@i@T92=D<h<S12=d<i<3Tf<44e
=3Lf=CHgAD4g=TA1>495ACM2=DHPCT@=;ePe=20P<cHPDT@P<SA5@d94<3DcAD8h
=4E2<S@d=C91<30b<c4h=CPe<34c>C=2=C0g<396A3<c<cLg<SPg=T4gACTa>C@f
3DHi>3@a@D<d<T4e=B1>A0d_F3De820a<CHPDT@P<SA5@d94<3DcAD8h=cDc@d4d
A3I3=cTb=C<b<cE5AS@c=c94<S4`@C55<dD`>3HfA3Q3@T@i<S0e<4Hh3C96<48a
ACI4@C0g=CI5@cQ6<391<3Pb>C@h>454<CA6@SM1=TI1>CLd=3M3=D8a<D=1AS@a
@S0g=3Ha=0e2@SA6AC52@DI6>3He<d54=3P`=D95<44b=T<aAD4`@TI3<4@a>3A1
>DA6AD<h=DA4=cU4=dE4<S0`=CH=>D8b=D=1<T@eA38g@d54ASHa=cH`AC<iA355
=353@dA1>CLi<CQ1=D8e@DDd=cTe=D96<b1>A0d_F3Df820d<b1BA20b=4E3@T@`
=C=5@SPc<CDa>C55AS0e@d91<c@d@c94>CL`=391<3<i<d<b<STg=34h<44i<3Pg
=D4g<CP=>34e>34a>D@e@T@`>392=DA4=dI1>3M1=TDPCT@=;ePe=b0P>3TPDT@P
<SA5@d94<3DcAD92>38g<DHb<cTa=c0d<3A5=d8i=SQ2@DI3@d@gATDi=44`AS4b
=c55>3@`<30g=D=23D@d>D8`=3Td@SHbACHe@cDdAC0c<TDa@CA1AS13@T8`A456
ADH`<CI2@dDc>34gA38i>48e<cP`>C=3<@e1ASTb=D<c<CTbAS0h=d4`<T96<4Df
=C<g=SU2=d8g<S8iAT=3<dA5<44b=T8h<T=2@C=2=3Pc>D<b84i43BmH=CPP83Hd
8594838dAD=2A30e<dE2>DA5=d8`=T4h=cI1=C=3@SDi=C4e@TA6=4Db>4=4>CI2
>DDa@SM5>3Hf=391@d=5=`e4=T8`A4<b>D8i<C8i=3Le=c53<T<f@SM1@SE2>C@d
A4Df<C@b>4<cASM2=3<i@C<aACI6=c4i=D=1@DD=<495<C4h>C<PCT@=;ePe>B0P
=3PPDT@P<SA5@d94<3DcAD8iA4Dg@S0f@CPg=SDe@TD`@d92=34g>C4dA34`>DA5
A4Dh>CI2@C16AD93@d<c@SDd3CPi<d96<C=2<3Q6=SPf<48h>3@i<D92>3M1@cA1
=T@eAT@e<R1>A0d_F3E1820d=R1BA20b=4E3@T@`=C=5@SU6@d51<3La=CHdA44b
=S96<C@a<4I3ATDh=391@DE3<cM4>C16<SA3<cPa=T8b@SL=@CM4@S0a@STd>CDg
>3PhA34h<cT`A3@c=315ADE4@d4PCT@=;ePe@R0P<cPPDT@P<SA5@d94<3DcAD8i
=d91ASA5@CHg=496ASLcA48h<C=1@d<i>3<h@c0e<CLe<D56=d55<DDg<d93@C<b
3C53ASE4@cQ1@dDh=c53<cTPCT@=;ePe@b0P<c4PDT@P<SA5@d94<3DcAD8i>3Hh
@d4d>DE5AS=3=TDhA3LiAT4a=T<h<cTg=cTc<cA4A495@CE6<S8i=CM2@TDc3CHa
84i43BmH=D@P83<h8594838dAD=2A30e<dE2>CM2@DHdAD4f=S4`>491<30fACLc
=3=5<c54>CQ5=S54<cE4>3Pc<3E1=SPdAS4eA0d`<cHc@C0`=3E3ASDg=3U684i4
3BmH=DDP83@a8594838dAD=2A30e<dE2>3Le<d=1=4@fASM5A4A1<dDeATI3ACP`
AS8i@S15AD=2=d=1<CI6@THiAC4e@C0b>0e3=SA1=d4c>316=S11<SHb<SM1=T4f
84i43BmH=DHP838e8594838dAD=2A30e<dE2>3Le<d=1=4@f@CI6<44h=3Q2<c<f
AS<f>D@a@C<`>3@iA3Hi<S<h84i43BmH=S0P83<a8594838dAD=2A30e<dE2>D=2
<STg<T=2<3Hf>CQ5AT4b=C16@CH`<c0c=cI6ADE6>3<i=DA5@DHd<d<f>C<i<Pdg
=b1>A0d_F3Ha820b<c4PDT@P<SA5@d94<3DcAD8i>CDi=38e>C@cA3Hi>C8g<SA4
>CU2=3E3@cU4<D8c=cTg<3Pc=30c<C@`<dE2=DDf3CLc>38aADH`ASQ5@THe@C=6
=CTi@S8i=DDa>4<i>38`>CU4@S8b=cQ3@S13ASQ2>391=S0e=DDf@cQ5<0db<3M1
<S8a@T4h=4@i>4=6=D@bAC0d>4Hh>C15@DA1>392<cDa@SLa<3Lg=d4c@D8d=T8c
<4Hg=c=3<d4==D4bASHb=C4f@CLf<C=3>3Q1=d<i@SI3<4A1<S94@c4gAT=5<S0`
=4@h@STb<CQ2=C8i>3Q2AS8e<DDh3C@d=SA5>D8g@cDa<D@d<4H`AC13=34a=38h
<c8g=C92AT<h>CPh>D@bA3<f>4Hb=C0cA3<a<SI6ASPiAPdi>C12@CTdAS@a@SA3
<cPg@S4h<DDe>3Tf=C0b>CM3@D=4<S@d<4E6>3Td>D@fASA2ACTdADH`<S96ASD=
=44f<T@fAC<d=d=4<d8e<4I6=3<b@TDd>D95=3Pc@dHa=CQ1A3E6@dHf<c91=c=6
A3<h@TI3@C13@dI43D8c<DA2=C4g<S52A44h>DDg=TE3=cE1@d<b=4=6<SDg@d8i
=dHf@DE2=R1>A0d_F3Hb820b<34PDT@P<SA5@d94<3DcAD8iA4Dg@S0f@CPg=SQ4
@cHfAT51AC@g<d4e@CLc@T8eA4@e>3Th>3<aAT4b@c4b>3<e3D8a=dI1AC<h<C12
AS0`<S@d<SHe=D4d=4I5=48aAS52<38c=TDh<d@h<S0d<T53=4Hg@S52=SE4@C94
<`di=S0g@C4d=44fAS8e<D=6<3E5=C11A3=3AC<d=d@`AST`<4<g@S8b>4<aA3Hb
<4I6=SHh@d91A3E1<4@=<S4d<S0a<3Tc<3PiAC@`@D@a<3I4ASU1@c@i=cQ6=c<h
<S8c@dHgA38f>CDc=CU2@T96<T4d<354<dDe3D4e<T=6=cTe<SHg@c@`=dE2AC8e
@TDb=CI1>C93<C13>C53<cHg=TDhAS0g<D<i=3<e<3Pb<cU6=T<f@`e4AT8i<48e
<STc>4@e<dHeASU5@CDc@D8e@d4hA3<e@T4f@SA4=THa=C11=4@i<4HdA352=T4b
>D<d<cH==c0e@T4i>4I6>D@`<T@e<3=4=T4c<T<a@D<b=TI4<3LgAD4f<CHf<c16
84i43BmH=S<P834e=B1BA20b=4E3@T@`=C=5@STiA30`@C4c=SE3AS@gA3HfAC<i
A48a=cTa>D=5@cDi<4E1>3De>C11<cDb=cE2>CP==3Pe=C8e@D=2<d8d=3H`<CHb
AS0e=S<`>D53@T=2AD@e>4@e=dI4AC8f<3Pg<4E5AD<f<dI3@c55@SE53CHg<T95
A3<f<4A1=4@eA3@g<3Db=cE4<311<CU6AT<i>4DgAT<b@cLe>C4hASM4@TE2@c@c
ATHd<dDh<@dg=c0e=S@d=C14=cE4ADE2=CU1>451@cTi>3U3<DDiAC=1A3A1>34h
=3I1@CU1<S55>CA4@TI1<cHf=4H=>3=5<C52<4I3AC<g=D93>3M4=S<`>4E5=cPg
<dHi@SLd>C53ASE4@cTi<SQ2@S11<d<i<C<c=3=6ADDd3C4g>4E1=SPc=SLPCT@=
;ePf=20P<CLc8594838dAD=2A30e<dE2>D<f<C4a<DE1@SLd=cM6A4I6@C@h<cLa
<D@e@d4g@S4h=S@f=C54=38h<d4h=C=1<@e5@c<b<cHbACU5<CE6>C<`AD8h=T4h
>3Ha>C55=cU3<356A3A2<SU6<STcA4HhATH`=44a=TA2=4I5@CP==48`@SU4@CQ1
=D93A44a<S4d<T8e=c4f=T4c>CTcACTcACI1A3@a@cTf=C0`=C11=c8e<C=4<3Tg
@DA53CM5<c52<T96>48h>DE1@cDi>CU1=354<c8eA3U4@cDd<T<e<SHe=4HfAC<i
<D@e<494ACE2<SU6<S11>0de=4I4<44cACU6<S15<4Di=3@i=d@i>3=2<S0b@cDi
A3Hh<D<c=SE1@SPf@c4c>D@d=C8fA3Q6A455>38=<CLfASI5>44`<311@C8f>D91
<d8a@CU5AD<`=C56=CLd<d@g<30a<3@c>D@h=R1>A0d_F3He820a=c8PDT@P<SA5
@d94<3DcAD8iAT=1@C0g<CDf=3=3@DE2>3<i>3@d=C@f=4@h=3A2<D4bADDd=CE4
ASI4<dDb=3Lc3C<e<SHi<d8b=C0b=SU4=SLe<SU5=3=3<30a<SE4>DDd<d8f=4=5
AT@c=C=5ACPb@S95<CPh=SDg>4Hg@`e4=c=3<dDe=CI6@CA3AC8f=C0aAC93<3Di
=3@e@DH`A354ADDg@CTe<34hATE3>4A6=d<c@TD`=CM6=c0==4=6A3A3<3@`<cDh
=D8i=CPb<4=5<dE6>C0c>C91<3TiATI2=TE4@CThASM4=TDa<4@b@S@e=30`A3Pa
3CPf@S55>3Pi=CLf<C96<CPg=34g<d4`A3Q5>C<a>3A2<d8f@d@e<CU5@DE6@cLg
=3<dADDe>CE4=S=6@`dg>C51ACQ1>D<c=394AD8c>C<i<30a@cTiAT8g=454@cHf
=cM6=3U1@D@i@b1>A0d_F3Hf820h=B1BA20b=4E3@T@`=C=5@STc<T<h=T@f<TDe
=TDgAS16=S@g@DA3<44h=C8dAD@g@dDcAS51=c8cAC@`>CA2=C8=@dHg<SE6@S<i
@D92<3E5>DHa<dE3ACLc<D8f<S53>4A3AC@e=D<i=T<a@T8`@TI1@CPc<3@fACE3
=SQ23DA1=cDh<T=3=cE2=CPh@T@hA3Tf<c95<CLf<cE6=CHa=d8d<d51@CHi@T4f
@CM6AC@a84i43BmH=SLP838d<21BA20b=4E3@T@`=C=5@SU4ACM2<3I1>3Li=DDd
ADI5ACLa<CDg=48b<c8h>CM3<SA4=cE2A3Q2>D4d<D<`=d<=>C8iAC<`@D@a@S<h
<C95<SLh>3A2>C<cADE1<395=cM2ACTe@T8i=THi=DI6=T4g<cHf=C@i>CU6>3U1
3C=3=cPc<C4a=453=C4`<c0i<STiA4=1@cDb>D51<SPg<DDc@c8h<3Q6<c56@D8g
=S8e@C<b=3A1=CD`<0df<TA4>D4cA4H`@cHd>4=5AS<a<D8a=d<i=S4a<DHd<S52
=SQ4=C4c@c@a<S<a@CA3@d@g=T52=3A3=4D=@C=4=CQ5@cI6<D4c=C@e<3HiAS0i
@c@h@C92@cHg<SU5>DI1ADA3<S0f=STh=cE4<3=1<3PaASPcA3A63CLaA313@T@c
>356>3M2<d8i@c15AS4b@T<e<c8a<D@`>CDi<C8e<D<a@D93=c8g@d8fASHfA4A6
<SM1A@dbACTh=S4d@C=6=S<i<396=S52<d4a=d=5A3TeAS8d=3<i=c@i>48cAC0a
<3<c<3Hf<4E1=492>C0iAS<=@C4i<S@iAT@b>3U3<dE2@CE5AS<a<d<c@TDi@CTb
@C4f=T52=STi<cPaAT@i<S0fASE5=d4g>4Hb>34d84i43BmH=SPP834b<21BA20b
=4E3@T@`=C=5@SU6<cHh=T@d=d4b<c13<38bAD@f>4A3@CU4>D52<cI5<44g<T8a
=cHd=S15>3U6<3D==CHi=S11<3Hc=392>CM6=CL`=3Pe=SI1<4@g@T@cA3Q1<cT`
AC4h@C13A30a>3Q4A4Dh@STg<4<h<4953CDh>C55AS8g<SU3@C55@c0gA44a=3M6
>C12AC8gAS0e<CLi<3Tb@S4`=4=2ACDbA3Pa@THe=DDi<dI3=Pe4@D<`<4Ha=DDe
=D56=4Dg=CHc=c0d@SPa>3Lb>D94<394<d51@D@h<D=2=cTf<cE5ACE4@dI2@d93
=T@PCT@=;ePf>B0P<cPPDT@P<SA5@d94<3DcAD8f@c8aACM4=T<d>D8a<3La>CI1
ATE2>3A3<d8a>C=3>CLg<313<CE5@C=1=3A2A4A33DA3=D4i=D<c>3Tg=3Tb@d8P
CT@=;ePf@B0P>C4PDT@P<SA5@d94<3DcAD8f<CDi>C@g<4I1<3@g=S94=S=1@S4e
=3HgA3Hb>DA5AC0g@S4c>D92>3Lc@STeA3H`3CTgAT4i<3Ha=SDd<SU1@c8d@DA2
@cDi<455<CPf=S91>4I4A4Dc@S=4<C94AS@dACI6<S8cADE2=3L`=`e5AS8a@CDd
=D51@CA3ACQ4=4<a=34d@DA5@DDd=D8bAT8b>C@d<dA4<CA5ATA4=3=3@SA1=3U4
A30gA3<=AC@PCT@=;ePf@R0P=C<PDT@P<SA5@d94<3DcAD8i>3Hh@d4d>DE5AS0e
<T94=T@c>CA6@D=1<3=4@SLf<S0i@STgATHe<dA4=C8c=DE23DE5A44g=C4g@c0a
<d=5=SPg=TDb<dA2=3Ha>CTb=3Ti=CM6=S<h@D@gA30i=TDPCT@=;ePf@b0P<SDP
DT@P<SA5@d94<3DcAD8f@c8aACM4=T<fA3Hg@CQ6=CHfASDh<c=2A4<g>CHa>C4b
AT4e=D@PCT@=;ePfA20P<S4a8594838dAD=2A30e<dE2@T@g<496=C92>C4g>CQ5
@c15@DHc=c15A3U3ASI5>4@`@SE4<c4i<D93ADHc<SE5<0de<S=3A4@e@c15@THb
A494@DHe<T@d@S4i>3Dc<T<i<cQ6@CU2A392<3<c=SPeASLg>3Le>C12ADD`AC4=
=SA5=3Q2<4Hi=D52<DHi=ST`=STgA3DbADHi=C15@dDh>3Da@SE3@CDe>3@gA455
=SDb@TE1<455=cU13CDb@SU5=4Hf>D<e@cPdA34cAS@hAC54>CLc<S52<S0i<TE5
=T<d>4<a=C@b<3DgA48e>3I1@D8gACE4=`db=cM6@CE5A3La<C<f=dHc@c@e<CE5
=T@a@C=1>C52@CHb<3Pa>3Hg=SDc@c94<3=2@D93ACM1@S0hA3L=<c@a@c0f@C0d
<DE3AS8c<T=5ASHb<D93<dE4<S4g>DDc>4Dg<3@`=DA4A4I2=C=3AT93=SDi>C@e
ATHa3D=2=SLe=30a=S0`AT<d<D4f@C14=D<b<T8c@C0f>48d>C0`>C8b@C<`=cA6
@SPa<SU2<d8c<3P`=3<eA0e2=R1>A0d_F3I5820a<CTPDT@P<SA5@d94<3DcAD8i
AS<f>3I4=3M1<S<`@c0b<TE4=SU6=c0i<SLh@cPb=cI1<30g=3<b>4De=D@a<DA2
3C51=d<`>C0e@S@g@T<e=CI3AC92AS@e>4<`=4E2=D8c<THb=CU4@CTi@cLi=SDb
>D@h>4Hf>395=C8c=0dgA454AD4h=T56=4=1=d4dAS@c<S93=cLd=C4cA38e<D8b
<C=1=D4b=D8d>3A6<C<b=3LhAS=4=CPcAD8=<SA3=CPa@d55=cA2A3@d=492ATI1
=dA4AC4i@SU4A394AS<i=3Hf=d8c@T8g<T@iA3Q1=CPdACI5=B1>A0d_F3I6820a
<c4PDT@P<SA5@d94<3DcAD8iA44c<38a=38c<ST`<CPc>C4g=d55=48`<4Dc<T@h
>4I1<3D`AS@aADE3<S0`>3A43C4a@C@f@C8b@c@bAC4g>C53<cDiACLbATHb=C8h
>CPh=D53ASE4=c<b>CHc=T<i>CQ3<4<b=CM1@c@a<0dd=c<e@S52=c@iAT=1@CPg
>C8d<d<h@dHg>3E6@C8d<SA1=C8e<3Tf<D8a=S53>D8bAT8c=c56<C<f@T@=>DDh
>4E3<d@d<S11ACPe<S4c<S8c@D53=38bAT4a<3P`@cDc@D8h=3U6@dE5=30f<cA3
<CPi<3=6@SQ63CTh@T@c=396=cLh=4=6AD@h<cA6=SLPCT@=;ePg<20P<CLc8594
838dAD=2A30e<dE2>D<f<C4a<DE1@SQ3A4@e>3Q6>3Lg<DHiAC<h@D8e=c4b<CDe
<3Di@T4a@SLg@c0e@`dd@c@i@CLeASDg=S=2<dDdACA6<DA4AC8f<48e=T<f>3Lc
AS=2AS@i=3E6@cDa<dHf>3E6ASQ6<392=4H=>316>DDd=CE5=TI4=d4`A311=c<d
=SDcASH`=d52ATE2@cPeA4HaACM1=3Lc=THf<SQ3ACU4<495=d8g3C13<cPiA353
@T4e>CI2>34c@cHd<SDe@T@h=cDh<D@h@dHf@THh=c8g@D93=3I6>4@i<d93@DA6
ACPe<Pe3=TD`=C<h@SDa<cDa<3Pi@c<e<SU2=395=C8d=34b=3A6=T51=D56@C@i
@THd<THdAT8i=c8cAS@`=TH==THf@S0fAD91<CPf@CQ1=c0g>4<f=SI5<d<`=DE2
=SPh=3Th=S95@CA3=T=4=b1>A0d_F3La820a=c<PDT@P<SA5@d94<3DcAD8i@cHa
<C4aAD52=c@g=dDa@c14=DDc>DHe@cP`<D4g@SLh=CHe<c@`>3M5=3Th=THf3D53
=4A5<3Pb<48b>CTh>D8e<CDb@d4`ACE1=c56<S12=C=3AD4d<cTc@S8aAD=2ASM5
>C@`ATA3=T8c@@dg<SHd=dHgA48a<c@d=S8g@S92AS@h@CDc@S96<CHeADHfA494
>311=DDc<S<c<D<c@C0g<SHg@cA3ATD==SPhASU6<T96<S8d=CDi<S@d@C<`>CQ6
<STcAD4i>CU3=30`=TDg>CQ5<CU4A3@a=dHg=d51=SU6AC113CQ1>CDa<c@`=T93
>CHaAS93@D4f<C13<DD`A44hASHg@dI3=S8b>3M3=S=3=S0a<3Hc<DDc>4E6@C55
APe1>C@`=CDgA3Dd<30a<d93<38b>4Hg>313@d4e@cPa<CDe@C13>38h>4Hc@S0`
84i43BmH=c8P83Lh8594838dAD=2A30e<dE2>C=5=dI3A492>C@g>3L`<d94>D<d
<TI5=4Hi=dHb>C4a=CI6<DDe@TA3<48f=cPb@Pdf<dA2ACU4=DA5@T@bA44cAT53
<C0g<3T`@CE1@THa<c=1<30e>38h@TA2>4<f<D<aA3Dd<4I6AT@d=cD=@DDdA3A2
<dI2<cI3A353=T55>CT`<3A2@CHb>3M1<T8h@d4a84i43BmH=c<P838a>21BA20b
=4E3@T@`=C=5@SU2>D53<c@h>30bAC8a>C0g<C52=4HaA3=3@dDh<THa@c55=D8c
=3Ld@S=4>4=6<38=<CLd=c4cA3A1<SHeASM6<cHh>C4iAT8g<c93AT<b@c@e@SI1
=48d@C4c@CPi<SDa<c8d<4@f=ST`=C0g3C=1<4<hACLbAC0f@CL`@c@b@D54AC<i
<S8c@S4`ASHiAS<a@CDe<CI6<3Pe<30fAD@c<d=6<3Ha<CI5>@db<SPc=3La<dA2
<SPf<SI5=TE5<c<a=SPi@SE1=cE1ASLb<C4a<d@a@DI4AT4`AD51<44iA4@h=cM3
>CP=>D=2=THi=dHdA3Tb=3P`@CU3>4<gAS=5A3M5=cD`<DE3>4E5@cPhA4D`>C<i
=cM5@dDd<TI4>4Dg=DHa3CHcAT<c<44`@CTg<SPg=T8i<c=3>392<S94<T91@cPa
@STb@SE1<3L`<D<c=C8`=316ASE1>3Tc>38hAPe3<44b>3E5A3Q6@S=6>C0g<T<`
<S54ASE2@SH`ASDi@CDdASPc=C4f=cTeAT95<DH`@C13=44cAT96<S<==4Hi>C@f
<d@cACE4=DA3A21>A0d_F3Ld820a<38PDT@P<SA5@d94<3DcAD8i=SLhASI3@c<h
<SPh<CA2=SM1>3<h=4A2>3I2<D4eA3Dd=D<f<34bA30d<CDeASA33D4c@DDa=30`
=4=4@C95<S91>D8e<DE2=S4iACPg>48h=CTb=c4f@S<`A3Ta<C14ACLg@dDa@D55
<3@gAPe4>CTg@C@f@TE1=c8a=c@c>3Pa>3HdASA2AT94>312=cLd@cA5=dE2@c8`
>DDa@S<g<SPa<4E3<4I2@DD==S4f=4A1AC<b<C4i<CDd<c0e>4E2AD@g84i43BmH
=cDP834`=b1BA20b=4E3@T@`=C=5@SU6<cHh=T@d=d54A4@`<3P`=c54ADD`=CL`
<c96ACDe=S96AD@`<T55@SLa=cTd<34=A395@S8i>CU4=4HeAS14>CTd<TA3@C=4
@TDe<cDa=CDdA3U6=3Q2@SI6=4@h=SH`=3U4<D4f=D<aAC913DA6=c4c@S16<4A2
=T=6@TA5@THc>4Hf@S=1=cE4=d8e=DI5<T=5<D=3>3<`<c8iA354=cPc<d<fA3M6
@@e1>3Hc<3E4A4=1AT@c=c52<d<g@S8c<4Dg<CLa=TDg=CA584i43BmH=cHP83@a
8594838dAD=2A30e<dE2>DD`<DDdAC<h=cPe=TA3<TI6<3E6<c<f=3La=TI3@SPf
AT4g=THh<c4d>CLi>CDd=Pe5ACPgA44h@DDa<SM2<3Hc=cA3<30c84i43BmH=cLP
83Pe8594838dAD=2A30e<dE2>4I1=d@e@D<eA396>3Tb<c4e=T<g=cM2<S0b@S4b
=SPe<3E6AD4eA3A6@CLg<48g=`dgAT4e@CPf@DE3=DA3>DI4@dI6A3<g@CPi>3Da
<c=5@TE5=D<eAS@d@SPbA3U6AC13>4@e<cU3@CTiAC8==CM6<d4`=CTg>48b<CI4
@D8e=c53=d4f@CHcA44`ACTg=T56ACDfAC93>D=3ACM6=CTPCT@=;ePg>20P=S<P
DT@P<SA5@d94<3DcAD8i>4E6>CI4@cE4>3Pg<c0g=S@`@SLb<dDhADE4=D51=CT`
<cM6<3=5=cLgA48h@dI33DE6<34bA34i<THc@SLa<CLf=TDc=T94@d53=C<aATI1
<T<b=34c@STa=34h<3Df@D<iAD91<d<i=3I3<Pe6AD@i=d@PCT@=;ePg>B0P>C4P
DT@P<SA5@d94<3DcAD8iASPf<4I3AD4f@c8h=44g>CHb<3@f<D<h<CLa=SHb@DHh
>3Ph=SHc>D4g<493@dDg3DDd@C0c=S@i=3He@dI6>C52<3Q1=48i<d=5@SDaA34i
@SDh>CDf>C53@c51A30g<cLg<3HdAC8d<dA2<0di@CQ3@d=6=CLi=C8a<3Hi=c<b
=4<h>DHb@SPc=3Q5@cPe@C8f<CPfA4=4<C8b@d=4AS4hAC<`ASDh>4@=AT4PCT@=
;ePg@B0P=3HPDT@P<SA5@d94<3DcAD8i>CDi=38e>C@cA4=4AS53@STd<dHc=c=4
>D4e<DD`ASPg>3Pd<3H`=DI5=3<h@SHb3D8i=S95=cP`@SPc<30d=c92=c=5@cQ3
@D91@cDd=S<i84i43BmH=d8P838b<21BA20b=4E3@T@`=C=5@STgAT@a<C94=D8d
<3U6=C@g<3=6AT=3>D4c=D4h<cLeA3@`<d4eAT91@S4`=THg>C<=<3Hh<SE1ACI1
=d4iACI2>3HfACLb@CLh=c0g=455@cDi=CT`>3Hh=D52=DA5>3Tc=cE2A3A1<T4f
<CQ13C93>C8f=c14=3=5<S<f@c=4>C<c<cE6=D=3<4<b=T96<3@fACDa=4DcASLb
@SLh=S96ASPf=d4h>4@f<`e4<4=5A4=6ADE2<d8i>311@DDcAC51@dA6@SPe=C<i
=TA3>38cAC4f<CHf=CLg<d@hAC4b<THc=4A4=cT=>CU4=313<S<d<C<b>4Dh@cTg
=DHeAD@a=3ThA38f>DDaASI6A4@iA3Hh<D@i<SM2@DE1=CI2=DI5>30d3DDd=c15
>D4cA3Hd<C8g=TE2<48`<C15>3E4<SU2>DA3<CI3@C8bA3U5AC@`@S0c@T@h<4Hh
=cDf<C8g@`e2=3=2<SPd<S0d<SE6<3La<3LcADHd>38f@S=5<3Lb=DI6<SHc<D<a
@cTa=3@f=CU1AC8h<c<h<3M2=S0=AD56=SLf<CT`<T8i@D8h>4@bAC8PCT@=;ePg
@b0P<SDPDT@P<SA5@d94<3DcAD8f<cM6<cI2=THg<3<b=d92@SA6<3TbA4I4>3M5
@THi=dA6@SPe=TDPCT@=;ePgA20P<S8a8594838dAD=2A30e<dE2>CM6A34a<T@e
@S8i<dDa=C0h=S@h=CLf>D<f<cL`=d54=CA6@SHe=STe<SE1>CLh@`dbAC0a<DA3
>3Ti>4Ha@cLaACQ4<S0g>CI4ASQ4<CU2<3<c@cA1>4I5=C<h=cDc=d@d=DHf@cDh
>3A5<T4=A4E2<T@d=DE2<44f<c0b=D@b@SA6@cLc@d@e=T4b<CHh<cDb<cA4<cPa
@cLcAD8f@d@a<cQ5>CHfA4933D<`<3@a@d4i=TDg=d<f=d55ACTg@cDa=CI1=CPf
ACHe@SE6>44g=dA6=3L`>C11A3<c=SHa=D54@CU1A0dg=4Db<DA5AD<`<T4`>DDi
<T8h<4@cACM5<dE2=STe@SH`=dA3<dH`@D@a<4E1<3Ti<3TaASPd>C8g=D4==TE4
AD4h>4=6@dDf=TE2<S4h<3I6<c@g<3Dg=TA5<cA4<3Ld=T=5A3<cASE2>3Te<c95
ATI6@SA5<c0c3DHh=30g=dDg@d@dA4E4<SPb=D@c=THb=T91A30g@dDg=CQ3@cQ2
ACHcA3He@CE2>3M6AC0c<d91>3<b@`daADHi=c54=c0h=dHb>C8c@d54=CDa84i4
3BmH=dDP834c>B1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=T<g>D=2<395>C8h<493
<S=6A30fAS12ASA5>3D`<4D`@S95@cTe@T@=<cHd=34h<d@a=T56<D@`=d8c@C8a
>4Da@CU5@C@b@c56<T=6<d4i=d8d=dE6<cLhASPbA4@b=d8i<S@a3CQ6<c4aAT=1
A3Ti@cE3=30fAD=1AT@d@T8d>D=3<SM1<SHb<D94<TE4>C@`=T93ASTfA4<e<30c
<S4i<`d`<4<`=4HcA355<CI6<D=6<3Q2@c<`AC<`@cE2=3=5>3=4AC92<S<g<cLf
@TDcA4HgAC4g<D92=C8d<S8==3M6<dDb@DHe<CPaA3DaAS14=cPg@d=5=DDd@cA1
=SHc=3E3A30PCT@=;ePgAR0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE5
84i43BmH>30P83Pe8594838dAD=2A30e<dE2>3<a=C4i<DE6<3Ta<cDeACHc<CU4
<dHi<C4`=CHa@dDd@C92ASPfASLgA3La@S51<`di<dHeAC4dAD@f@cM3<d<g@c8b
>D4c=dI4AC<d=cQ2<d=2<T<a<3M6AS<g<T4e@c@c=S<h<S4b<3<fAT4=<dI2<c0g
=C53<3HiAS8b<d8i<d<f>CTb<c0`=3U1<STf>4Hf<S8g@STb@cLd@c@g=4DPCT@=
;ePh<B0P<CLg8594838dAD=2A30e<dE2>3<a=C4i<DE6<48g@d93=SPb=3M4=4Da
A3<a>3Pi=CTi@d<`=4HcACTc<d95=3@g=0dc<T<e@dDf@dDfAT@a<SA6=SDdATI2
<3E3@DD`<c4iASDdAT@`<4Hf=T4c@T@d=3De>D56<4H`>3Tf@T@==cU4@S=2@SI1
AT8i@TH`<T4`@SA5>3=3A38d@SDi=d4b@SLd<TE3AT4b=SA4=c55<dDf=SPiAS4`
=34e3C0i@DHa@c96@C=1=3A1@C0g=cL`=dA1@cQ6ASQ3>DDb>48h@DDg=SD`=C0a
=d<f<THh<c@b@T4a=SP`@Pe6@C0g<C@dA3<eATE5@c0h<S4hA3<hATI1AC4c>38d
<DDg@c13=D8b@TH`@CD`>DDd=495=4<h<3Q2=S8==CA4=T51<3M2>C4b<S<a>3Q1
=d92AC8gAS15=S=5A3HcATHg<SHf<cA5<D4a=3Q1>D4fAS1284i43BmH>38P838d
=R1BA20b=4E3@T@`=C=5@SPd=CL`@C8`>DHi<496<d8aA30g@d8e=38g<c<`AS8h
=392@DHg<316ACU6A48g<4H=<3M4@DDe@C15>CPe<44b@STb<SPaAS@i=C<a>CI2
>D4g<T53=d<f=TDd@S=1=S<gAD54=CM6ACI6AC4e3C4d=SQ4@SPc<3Pe=D@g<3U6
<cH`=SLg>3M3@d8a=3A1=d4a@c4h=TA4<SA2=D<f=S0a@DHb<T<e@DHcA@e3>C0d
ASDe<CHaADE6=C0g>D4c<S55=d51AD@h>DE2A3HaAS56@C<c<S0c<4He=c51@cT`
@SDb=SI2>3T=>DA4A3M3AS@cADDa<4Di>CHi>C4c@D94=c4i>34bA4Hh<cI6@cM2
@D=2=C0`AC0b@S0e=D=1AS8aA3A23DDe>3L`<d92=3Q2AC4a@T@f<38f<SA2ADA2
AD<a=492>3D`=THe=CDdASI1<C<a<cDi=4@a@cHc<T<g<@ddAST`<dA4@S=2<3E1
A4@f>DDi=4Dc@S<b<3Hf@dA1>3<b>3@f<THb<c4h=cA1=cH`>CA3>38a<S0e=3H=
A3He=3I2>4E2>4DhAS<f=3TiAD@f=D<g@T94<4E5ACA1AT=5<D8b>CQ4=d52<3@f
AS@e=30c=C0e=D8b3DE1=4@d<cHaAS15A21>A0d_F3Pc820f=b1BA20b=4E3@T@`
=C=5@SU6@d51<3La=CA6>D92<314>DDa@SA3<4=4<T@f<34dA4Hd<d@i<d<`AS<a
@dHd<S8=A492<3Pb<C8c@CL`<3Ph=dE6ADDaASHdADHe<T91>DA6<SE2=4Hh>3=1
<4=3>34e=DI1ASD`<3E1@CM13D8`@CHf=cM3A4E1<3@`84i43BmH>3@P834f=b1B
A20b=4E3@T@`=C=5@SP`<SM2<CDc@C8h@S51@d91<DDdAT8d<dI1=c54>CDg<4<h
@d93AC=5<TDf>38`>4D=<SHe<C52AD@c=D<dAT@`A3Lh@S8`ACQ1<d8d<dHe=T8c
=dDf<3Pa=cHd<S<d<3E4=4@g>3A3=351<3Th3CQ5<cM3>DDf=C<d@d4i>3Q2>492
>4Db@cTbAS92=34c>C<g=cDb@D8d<D<i<T4d=CDb@C53=CHd=d92>@de<CTg@T53
AT4dAS55@C93=394@cPaAS=5<34b@SA3>C0cASM3=3Lh@SPi<d@i=D4fADI5ASU1
>3I1<CH=<cQ4A3U6A4E6>C4aAC<gADI5>315<4I4@dE1ACLcA356@CPaA3@f>CU4
<dHd@c16=3M1<dI2=C4cA4E43D53<T4`>454ASDc>3Pa>D<a@cHh>3Pi=cE1A3@g
A494@cHPCT@=;ePh=B0P<CHa8594838dAD=2A30e<dE2>38iAC@d=48`=CU6>CE1
<D@d<DI5@c0eAD4b<T51<CU4<cA2=D4`@S=3=dDb<30a<Pe4<S53=c51>3U2@THb
>C8g>3Q3<cPb=cM6=c91=4HaADHhASD`<34eASLe<C0aADHbASU1>3Q4A30aA3T=
AD51>C55@C92AD8g<4Hb>44f<T@dACPa<C4c>353@CLi=d<f<3HhA3Lh@S0g<d4i
=T4d=DE1=3Dg<C=23D@d@S@`=492@d=5@D8b=S@d>C@e=TDc<c8i@cHa>392ADDd
=TDc@SLcAS@cAC0i@S0e<c51ADDd<d54=`deACLc<3@hAT4b<D8bAS8g<S11<C8h
>C@f>3Hc>CH`=cQ6@CTa=3PfAC<`=S0g<312>3Lc=4@cA3M5AT<=@cPe>C8h@C0d
<C<c=S@e<392@DDg>21>A0d_F3Pf820a=34PDT@P<SA5@d94<3DcAD8h=cDc@d4d
A3I3=cTb=C<b<cE5AS@c=c94<S4`@C55<dD`>3HfA3Q3@T@i<S0e<4Hh3C96<48a
ACI4@C0g=CI5@cQ6<391<3Pb>C@h>454<CA6@SM1=TI1>CLd=3M3=D8a<D=1AS@a
@S0g=3Ha=0e2@SA6AC52@DI6>3He<d54=3P`=D95<44b=T<aAD4`@TI3<4@a>3A1
>DA6AD<h=DA4=cU4=dE4<S0`=CH=>D8b=D=1<T@eA38g@d54ASHa=cH`AC<iA355
=353@dA1>CLi<CQ1=D8e@DDd=cTe=D8`@DHa=S96AC8i3D@h<CQ6@S@b@S@`@dA4
<4=6A4Hi<30gASHaAD4dAS4i>DI3<SLg=dDfAB1>A0d_F3Pg820b=C400:40`3oo
8594838dAD=2A30e<dE2>CTe>C@b=CTd<d@f>CTb=c8dA3Ti@S@e@d<iA352<cLi
=c0h<c@`<c4d<3=5@SE5=Pdg<cPb<DE6<4HhAD96=D4cASDi>D8b>CE5<CQ3>CPb
<3TiA48b<SLh@d8`@dHh@SPb@CH`=CE5=T<hAC0=<S0g@C8b<D91>3A4>CQ3ASE4
<TD`=3Q6>3T`AD54@CPb@S<e<D8g<C0g=cM1<d52=3I2<c16=cLc@c=13CE1<THf
<SDa=T4g=S4c@cPh@CM3>D8f@c14@C8bA4<a=dI3AC8`<3A4>48i<S4h@SDb>CPh
@THb=C55>0dd=3HdACU2=d<e<C54=316<4D`@c@a<C@b>3<b=cDb@TI3>3Th>3U4
<T@c=SQ6<SD`<d@c<C8fATHh>DH=>CT`@T4i=4Hd<D8d@c<h=d8a>355=CPi=SD`
<STg@d53A38d=315ASPi=3U4=THd@TDi=4E6<38bATHe3CA1=S94=TDc=3M3A3=2
=C16AS@c<T95=3U2AC@h<d=6<CDh@D@eAT=6=S<b@CLcAT@c>496@d4`@d=6A0e2
<c54@SDa=c8a@TA1>3U5=cI5@cLe@D=3<SA3AS8e=d=2>CM6=T55=3<g<S0a>38b
ACM3=SDd@CHb@S8=>DI4>3I2<4Hb<4<b=3LgADE6=D=3@B1>A0d_F3Ph820b=C0P
DT@P<SA5@d94<3DcAD8i>CDi=38e>C@cA3Hi>C8g<SA4>CU2=3E3@cU4<D8c=cTg
<3Pc=30c<C@`<dE2=DDf3CLc>38aADH`ASQ5@THe@C=6=CTi@S8i=DDa>4<i>38`
>CU4@S8b=cQ3@S13ASQ2>391=S0e=DDf@cQ5<0db<3M1<S8a@T4h=4@i>4=6=D@b
AC0d>4Hh>C15@DA1>392<cDa@SLa<3Lg=d4c@D8d=T8c<4Hg=c=3<d4==D4bASHb
=C4f@CLf<C=3>3Q1=d<i@SI3<4A1<S94@c4gAT=5<S0`=4@h@STb<CQ2=C8i>3Q2
AS8e<DDh3C@d=SA5>D8g@cDa<D@d<4H`AC13=34a=38h<c8g=C92AT<h>CPh>D@b
A3<f>4Hb=C0cA3<a<SI6ASPiAPdi>C12@CTdAS@a@SA3<cPg@S4h<DDe>3Tf=C0b
>CM3@D=4<S@d<4E6>3Td>D@fASA2ACTdADH`<S96ASD==44f<T@fAC<d=d=4<d8e
<4I6=3<b@TDd>D95=3Pc@dHa=CQ1A3E6@dHf<c91=c=6A3<h@TI3@C13@dI43D8c
<DA2=C4g<S52A44h>DDg=TE3=cE1@d<b=4=6<SDg@d8i=dHf@DDc>C53=S13=C12
@cI4ACDcA3U4@`df<C53ADI3=SQ6=C8c@CTa=cTe>21>A0d_F3Pi820b=CTPDT@P
<SA5@d94<3DcAD8i>CDi=38e>C@cA3Hi>C8g<SA4>CU2=3E3@cU4<D8c=cTg<3Pc
=30c<C@`<dE2=DDf3CLc>38aADH`ASQ5@THe@C=6=CTi@S8i=DDa>4<i>38`>CU4
@S8b=cQ3@S13ASQ2>391=S0e=DDf@cQ5<0db<3M1<S8a@T4h=4@i>4=6=D@bAC0d
>4Hh>C15@DA1>392<cDa@SLa<3Lg=d4c@D8d=T8c<4Hg=c=3<d4==D4bASHb=C4f
@CLf<C=3>3Q1=d<i@SI3<4A1<S94@c4gAT=5<S0`=4@h@STb<CQ2=C8i>3Q2AS8e
<DDh3C@d=SA5>D8g@cDa<D@d<4H`AC13=34a=38h<c8g=C92AT<h>CPh>D@bA3<f
>4Hb=C0cA3<a<SI6ASPiAPdi>C12@CTdAS@a@SA3<cPg@S4h<DDe>3Tf=C0b>CM3
@D=4<S@d<4E6>3Td>D@fASA2ACTdADH`<S96ASD==44f<T@fAC<d=d=4<d8e<4I6
=3<b@TDd>D95=3Pc@dHa=CQ1A3E6@dHf<c91=c=6A3<h@TI3@C13@dI43D8c<DA2
=C4g<S52A44h>DDg=TE3=cE1@d<b=4=6<SDg@d8i=dHf@DDd<dI2>CLd<SPc=44i
@C4h>3Pg>@dhAT8i>4E3=38c=SA5A3@hA30b=C=1=C4g<3A6@CDb@dHiA3M6>21>
A0d_F3Q1820b=CLPDT@P<SA5@d94<3DcAD8i>CDi=38e>C@cA3Hi>C8g<SA4>CU2
=3E3@cU4<D8c=cTg<3Pc=30c<C@`<dE2=DDf3CLc>38aADH`ASQ5@THe@C=6=CTi
@S8i=DDa>4<i>38`>CU4@S8b=cQ3@S13ASQ2>391=S0e=DDf@cQ5<0db<3M1<S8a
@T4h=4@i>4=6=D@bAC0d>4Hh>C15@DA1>392<cDa@SLa<3Lg=d4c@D8d=T8c<4Hg
=c=3<d4==D4bASHb=C4f@CLf<C=3>3Q1=d<i@SI3<4A1<S94@c4gAT=5<S0`=4@h
@STb<CQ2=C8i>3Q2AS8e<DDh3C@d=SA5>D8g@cDa<D@d<4H`AC13=34a=38h<c8g
=C92AT<h>CPh>D@bA3<f>4Hb=C0cA3<a<SI6ASPiAPdi>C12@CTdAS@a@SA3<cPg
@S4h<DDe>3Tf=C0b>CM3@D=4<S@d<4E6>3Td>D@fASA2ACTdADH`<S96ASD==44f
<T@fAC<d=d=4<d8e<4I6=3<b@TDd>D95=3Pc@dHa=CQ1A3E6@dHf<c91=c=6A3<h
@TI3@C13@dI43D8c<DA2=C4g<S52A44h>DDg=TE3=cE1@d<b=4=6<SDg@d8i=dHf
@DDd<cHd=D8f<SLa=4Hh=C52@DHb@@d`=SE3<cPb@THa=c8b<dI1A4Df=3LdAD8e
@S<b>CTf=cTh84i43BmH>48P83<b<21BA20b=4E3@T@`=C=5@STi=CTd<SDi=3=4
=STi<SLb=4@i>D8d=D=3>D@a@S<g>CL`>3<d<3<a=30cAD8eACH==c<h<S55AS16
>4E2ASE1<dHe>CU2<STeAC4h@cTh<S0i>DA2<S8g>4=2<4=6>48h<T4f<3DeACI3
>4D`3C8`=d4b<S52@CPdA3Th@dHeA395<3@hASPi<4E1A44h<T8c=C52=c4`=cLg
@C=1@S@f@S<`ASLg<d<c@@de@C96=S8e<CI1=cHa<d<h>44g@cU2=T<`A44b<TA3
<CM6@dDb<30dA3Q2>C8a>48e<STh>496<SDaACP==3@f=4Di@SM3=C4aA3@`AS15
<4<d<C4d<SPc<SLe<T96@cPi>3PiA394<cHhAS8e<3=4<c4b=TI6>3U63CTi<491
>CA6=352=4<c>3M2<CPaACDh>CHe<38i=d=1@d@b=3@`ADHh>C@iA3I6=495>CA5
AS0b<TI6=@dd@CHbA3I5<c@g@d@c@SD`ATHd<c92AC@i@TDd>3=3AS4e>454=DI3
ASHc<T4g<dI4<cQ2AT=1<4=3AT@=@S<aA48e<CLb<D94@CPiACLfAD<g=D53@c8d
@dHb=CM3@STgASI1AC@c>C4`<D@a=D=5<S=6ADHg>C563D4d@TH`=d91@SH`=C12
@c=3<DI2<DI1ASI5=D93AS<c@TA5=THh<4@fAT@b=3<`@c92<CPa=493>4I1=Pe2
=c@eA4E4@T<f@D8gACA2<44f<C56@TI3=D4h<4H`A3Df>C96=cDf@cTcA4@hAS8f
ACQ5<3Pb=C0h=CH=@d<`AC11=T8h@d8aA3<c@C=2<STa=SU5=T8b@CI5<4A2=CPi
<T<g<21>A0d_F3Q3820c=C8PDT@P<SA5@d94<3DcAD8i>CDi=38e>C@cA3Hi>C8g
<SA4>CU2=3E3@cU4<D8c=cTg<3Pc=30c<C@`<dE2=DDf3CLc>38aADH`ASQ5@THe
@C=6=CTi@S8i=DDa>4<i>38`>CU4@S8b=cQ3@S13ASQ2>391=S0e=DDf@cQ5<0db
<3M1<S8a@T4h=4@i>4=6=D@bAC0d>4Hh>C15@DA1>392<cDa@SLa<3Lg=d4c@D8d
=T8c<4Hg=c=3<d4==D4bASHb=C4f@CLf<C=3>3Q1=d<i@SI3<4A1<S94@c4gAT=5
<S0`=4@h@STb<CQ2=C8i>3Q2AS8e<DDh3C@d=SA5>D8g@cDa<D@d<4H`AC13=34a
=38h<c8g=C92AT<h>CPh>D@bA3<f>4Hb=C0cA3<a<SI6ASPiAPdi>C12@CTdAS@a
@SA3<cPg@S4h<DDe>3Tf=C0b>CM3@D=4<S@d<4E6>3Td>D@fASA2ACTdADH`<S96
ASD==44f<T@fAC<d=d=4<d8e<4I6=3<b@TDd>D95=3Pc@dHa=CQ1A3E6@dHf<c91
=c=6A3<h@TI3@C13@dI43D8c<DA2=C4g<S52A44h>DDg=TE3=cE1@d<b=4=6<SDg
@d8i=dHf@DDd<dHc<3=3<cHd=C<i@C8c=3M4>0dbAC=2>455=cA3>4<d>CM1@C51
<c8c<3=5=CTb<CDc>D51@SU5=cI1ACTfA3Hi@SPbAC0d@SM1=c13@cD=<D=3=CI5
A34g=3=1=C<i>C4f=d@cA4DeACP`A4=5<3A6<D8a>CDd@C4`<SDc=cTb<cQ6@DHi
<4I1<SM53C@d=SDi=SE2<SHgA3De<d8e<D@`AS<`A3DgAS0b@THh>D4e>30g<SHh
=c8f>3=1>C<f=d<a@T8c<dHaAPdh@C4i>D@`A3De@cE6=3Q5ACA2>3Lb=c53>C0e
<D<a<S94AS=4=316ADH`AR1>A0d_F3Q4820b<SDPDT@P<SA5@d94<3DcAD8i>D@`
<44a<cHe<c<`=D51=S93=S8h@D55@SA1>DI2@SE6A314@SDa@D4b>C@d=TE23C96
A3@c@T@c=C0cA4<f=T<gAC4e@CQ4<c@i<4<aA4Hc@C@cAS0h=CU1>452<SPf<3Li
@CI2<SE5AC0i>@e6@D92@SLa@SI4>3Dc=D4d<T4b<SI4@c0g@c@a>30aA3I2=S<`
=D=2<3Q5<SPa>C8i=44i=DI5@S@hAT@==3@`A3DiASHa=d8dADHd@C<c<d8d<cU6
<T<`A4@i<SI2<SU3>4E1=3He@D56@D@e@C55@c=6A4=1@CU13CDaAT4g=48b@CE5
>D8h@T93=4Hc@CTi<34f=TA5=d4d@c0c<dDb<44a=D@g=SI5<C@g<T53<4I4<CPe
<`dd@DHd=C53=392<d8h>3TfA4Hi=D8a@D4d>4HcA3Q2=S0b<S0f@S4d<495A3Tg
<SA5@cM3@cM1AC@a=CL=@C=3>C95<D=3=DDg@d@f@d4d<354AC56<CQ5A4A3<3Tg
@cDe<CE6>C=4=S95ACE3=3@dACE4@C0f=C<i3CHf=T=2ACHa<D56>4@f<3<c<SL`
@C@i@S@f@T8c@B1>A0d_F3Q5820a>C4PDT@P<SA5@d94<3DcAD8iAT=1@C0g<CDf
=3<d<C4`@S0a=3Q5<d<b@SM4=34d<3Li<dDh@c<g>D@`ACDd@c963D8a<d4e<cLi
>CI5=CDfAD<b@d=4ATI4>3I6>CLd<c8d<3Di=S0b=3Hf=38e<3=1>4De@dE1ADDh
>C12<Pe3<CHg<dHaASPh@T=5=TDg<D4cASE4=SQ6ASPgAS=2@D<h@CA3=T8f>CP`
>4Hf=D@d>3@a>C4i@C<h<C8=ACDf=SI3@cA2=T8e<cA5ACPi<SPi>3DfAT<iAS4d
=CLd=cI5<SA2>D52>3Pa<CE6@SLf@DDaA3Df<cI43DDa@T91A3A6AC@`@dH`<S8i
A3=5<SPh<cA3AT53=dE5=c<i@C8aASPh<4I5@CHe=T@d>4Db=C8f=S@iAPdd=44i
A3Hc=4I4=d4fAT@`<3<eA4A2AS0`<496=CM6@C4h<CDgA3=3=DH`ATHf=c0cAT4i
@TA3=T@`<T4=@TA4>38`=38dA4Hg@S0e@S0a>C<g=R1>A0d_F3Q6820a>C8PDT@P
<SA5@d94<3DcAD8iAT=1@C0g<CDf=3<d<C4`@S0a=3Q5<d<b@SM4=34d<3Li<dDh
@c<g>D@`ACDd@c963D8a<d4e<cLi>CI5=CDfAD<b@d=4ATI4>3I6>CLd<c8d<3Di
=S0b=3Hf=38e<3=1>4De@dE1ADDh>C12<Pe3<CHg<dHaASPh@T=5=TDg<D4cASE4
=SQ6ASPgAS=2@D<h@CA3=T8f>CP`>4Hf=D@d>3@a>C4i@C<h<C8=ACDf=SI3@cA2
=T8e<cA5ACPi<SPi>3DfAT<iAS4d=CLd=cI5<SA2>D52>3Pa<CE6@SLf@DDaA3Df
<cI43DDa@T91A3A6AC@`@dH`<S8iA3=5<SPh<cA3AT53=dE5=c<i@C8aASPh<4I5
@CHe=T@d>4Db=C8f=S@iAPdd=44iA3Hc=4I4=d4fAT@`<3<eA4A2AS0`<496=CM6
@C4h<CDgA3=3=DHf<SH`<D<a@c15<c@f>D8f<C<=A3A2@cDa<S93=3@f=4=1<4E6
A4<g<C@a84i43BmH>C0P838`<21BA20b=4E3@T@`=C=5@SU6@d51<3La=CHd<c@a
<C12<34d>4Dc@c92=d@d<C@`=cTcACQ3<cLiA315=CA3<TH=@S4c@CDc=cTi=TDe
=CI5@c93@dA6AT@h=THi=c@c<S@`=CTf<38d=SHd<SD`<d4hACE3AD55ACPi<48b
3D<a=SLcAS56>3Q2@dDfACLa@C=6=D@f>4I6>3M6<d91@cQ1=4<f@SHi>30hASHe
A3@h=34i<CU1<cPa<Pe5=CHf=T=3=48f@SDc=4E5>3Tb>3Th=CI6@cU6<C@e=c@g
=TDb=48i@D8h>34a=DI2=cI1AC54=CHc=T@=AC52@T54=4I5=313AS0b<SU4<dDb
>3Pc=4=6@D<gADDg<cU1<S56>3P`ATE1=SDfA3@hAC8e<SHf=3U63C@d@CU4=S<d
AT@g@CI6A30`<cE4A496<30`@THe=dI1<CPa=CM4<d<eASHb@d4i@d@h<DDa=cPc
=T95>0dg=44e=3H`>48eAT@`AC8`@cM5AD@d=SQ1@dE3<cE4@SE6@D8hAS<a84i4
3BmH>C4P834i=b1BA20b=4E3@T@`=C=5@SU6@d51<3La=CHd<c@a<C12<34d>4Dc
@c92=d@d<C@`=cTcACQ3<cLiA315=CA3<TH=@S4c@CDc=cTi=TDe=CI5@c93@dA6
AT@h=THi=c@c<S@`=CTf<38d=SHd<SD`<d4hACE3AD55ACPi<48b3D<a=SLcAS56
>3Q2@dDfACLa@C=6=D@f>4I6>3M6<d91@cQ1=4<f@SHi>30hASHeA3@h=34i<CU1
<cPa<Pe5=CHf=T=3=48f@SDc=4E5>3Tb>3Th=CI6@cU6<C@e=c@g=TDb=48i@D8h
>34a=DI2=cI1AC54=CHc=T@=AC52@T54=4I5=313AS0b<SU4<dDb>3Pc=4=6@D<g
ADDg<cU1<S56>3P`ATE1=SDfA3@hAC8e<SHf=3U63C@d@CU4=S<dAT@g@CI6A30`
<cE4A496<30`@THe=dI1<CPa=CM4<d<eAS4f=C4d<c4a>D@a<c53=c4e@Pdi@C@b
=3Da=C93>452@C=6@cU4@S55A4<b<T@d=DDi<C0i84i43BmH>C8P83@d8594838d
AD=2A30e<dE2=T<b<DDgA3I3=3U2<C0g<CTf@DI5@SPd@c=2<CTc@cTg=c0`@c4e
<cDi@CHiA48fAPe2<48a<4@fA3=5<495A44i=dHgAC@d<C4dA3Hd84i43BmH>C<P
83@e8594838dAD=2A30e<dE2=T<b<DDgA3I3=3U2<C0g<CTf@DI5@SPd@c=2<CTc
@cTg=c0`@c4eAD4a@d@aAC0c@Pd`>C4d<S54ACI3@S0f=391=T91<C<e<C93<CA6
A3@PCT@=;ePi=20P=C<PDT@P<SA5@d94<3DcAD8f@c8aACM4=T<d>D8a<3La>CI1
ATE2>3A3<d8a>C=3>CLg<313<CE1=CHc>495AS=53C11<T4f<30c=SPi@C4a<D=6
@S4hA3Lc=S<e@SPbAT@f>D4d<356<c=5<c@b<dDPCT@=;ePi=B0P=C0PDT@P<SA5
@d94<3DcAD8f@c8aACM4=T<d>D8a<3La>CI1ATE2>3A3<d8a>C=3>CLg<313<CDc
@c<gASA4<T@h3C<g<DH`@D<d<TE3<c<h<c=2@SM4@d8e<CM1ASTgACPf<d8iACHe
@TDPCT@=;ePi=R0P<S0g8594838dAD=2A30e<dE2>DHc=SPfA3@g@C8c<4<`<S95
A3HiASL`>C8g>4<h<SLf@C0`=c@c<SQ5=CE4<C54@Pda@CM3<3T`=D8d=d93=CDf
@dDb@THd=CQ3<3A5@SE2<c96<SDiA44i>D<g>CHe<SU4>3Q6=SPbACDb<c@==dA1
A4E1>3I1ASA3@CM1=4Hd<c8b@cLg=3Da<d@b=C52<S4c@CE1<SE2=3PdAS4c<S@g
>4HcA3Dh<dE23C8d@cDh<D=1ACLd@T@d=3A2@TI6@CM4A4Da>D8iA4@bA4Hc>C@f
=SM2<d92=c94>D@h@CDh=4Df=3Dd@Pdf=SM2AD8g<CLhAD95=CHb<cQ4=d95=4A5
@d4a=3TbAS<c<3Lg<c@e=3HeACHi@cP`AS0i>C<g>DHg<48=<D8bACPi>CM6<cPc
@S=5<cHdA4<i<3Pd>C<i<CU6=44d<3<f<d<c>44i@C0h@d<dAC@aATHi=TI4=CTc
3D4g=cM6=d4aASI4@DI4=34d=dHg=SPf<455>C4c<CDf<4<`=3Tg<C4g@cM3<C4h
=C8`>CQ5<21>A0d_F3Tg820a=C4PDT@P<SA5@d94<3DcAD8iA44c<38a=38c<ST`
<CPc>C4g=d55=48`<4Dc<T@h>4I1<3D`AS@aADE3<S0`>3A43C4a@C@f@C8b@c@b
AC4g>C53<cDiACLbATHb=C8h>CPh=D53ASE4=c<b>CHc=T<i>CQ3<4<b=CM1@c@a
<0dd=c<e@S52=c@iAT=1@CPg>C8d<d<h@dHg>3E6@C8d<SA1=C8e<3Tf<D8a=S53
>D8bAT8c=c56<C<f@T@=>DDh>4E3<d@d<S11ACPe<S4c<S8c@D53=38bAT4a<3P`
@cDc@D8h=3U6@dE5=30f<cA3<CPi<3=6@SQ63CTh@T@c=396=cLh=4=6AD@h<cA6
>C95@SE6=S<f<SL`ACPb@dI6A44f>C52>4Hb<3Pe@d93A4I3<C0h=Pdf<R1>A0d_
F3Th820a=C0PDT@P<SA5@d94<3DcAD8iA44c<38a=38c<ST`<CPc>C4g=d55=48`
<4Dc<T@h>4I1<3D`AS@aADE3<S0`>3A43C4a@C@f@C8b@c@bAC4g>C53<cDiACLb
ATHb=C8h>CPh=D53ASE4=c<b>CHc=T<i>CQ3<4<b=CM1@c@a<0dd=c<e@S52=c@i
AT=1@CPg>C8d<d<h@dHg>3E6@C8d<SA1=C8e<3Tf<D8a=S53>D8bAT8c=c56<C<f
@T@=>DDh>4E3<d@d<S11ACPe<S4c<S8c@D53=38bAT4a<3P`@cDc@D8h=3U6@dE5
=30f<cA3<CPi<3=6@SQ63CTh@T@c=396=cLh=4=6AD@h<cA6>D@b=CI4<dA6ATA3
>CDe<CHd@dHh@T@d<T4b=SE5=dDaACTd=C=4<R1>A0d_F3Ti820a=CLPDT@P<SA5
@d94<3DcAD8iA44c<38a=38c<ST`<CPc>C4g=d55=48`<4Dc<T@h>4I1<3D`AS@a
ADE3<S0`>3A43C4a@C@f@C8b@c@bAC4g>C53<cDiACLbATHb=C8h>CPh=D53ASE4
=c<b>CHc=T<i>CQ3<4<b=CM1@c@a<0dd=c<e@S52=c@iAT=1@CPg>C8d<d<h@dHg
>3E6@C8d<SA1=C8e<3Tf<D8a=S53>D8bAT8c=c56<C<f@T@=>DDh>4E3<d@d<S11
ACPe<S4c<S8c@D53=38bAT4a<3P`@cDc@D8h=3U6@dE5=30f<cA3<CPi<3=6@SQ6
3CTh@T@c=396=cLh=4=6AD@h<cA6>C0gASDh<T4i=c12<C<cAT<iASTb@SHh<cA1
=D=5AT4i>3A2>4E6=0e5=3Tg@SQ5=4E6=4=4@B1>A0d_F3U1820a=CLPDT@P<SA5
@d94<3DcAD8iA44c<38a=38c<ST`<CPc>C4g=d55=48`<4Dc<T@h>4I1<3D`AS@a
ADE3<S0`>3A43C4a@C@f@C8b@c@bAC4g>C53<cDiACLbATHb=C8h>CPh=D53ASE4
=c<b>CHc=T<i>CQ3<4<b=CM1@c@a<0dd=c<e@S52=c@iAT=1@CPg>C8d<d<h@dHg
>3E6@C8d<SA1=C8e<3Tf<D8a=S53>D8bAT8c=c56<C<f@T@=>DDh>4E3<d@d<S11
ACPe<S4c<S8c@D53=38bAT4a<3P`@cDc@D8h=3U6@dE5=30f<cA3<CPi<3=6@SQ6
3CTh@T@c=396=cLh=4=6AD@h<cA6>C94=C4b>CPiACDd>3U6@CU4<D=6>C0eAC96
=3<bACM3@DHdACQ5@`e4=cA6@CHi@cQ3=DHe=b1>A0d_F3U2820b<CTPDT@P<SA5
@d94<3DcAD8iA44c<38a=38c<ST`<CPc>C4g=d55=48`<4Dc<T@h>4I1<3D`AS@a
ADE3<S0`>3A43C4a@C@f@C8b@c@bAC4g>C53<cDiACLbATHb=C8h>CPh=D53ASE4
=c<b>CHc=T<i>CQ3<4<b=CM1@c@a<0dd=c<e@S52=c@iAT=1@CPg>C8d<d<h@dHg
>3E6@C8d<SA1=C8e<3Tf<D8a=S53>D8bAT8c=c56<C<f@T@=>DDh>4E3<d@d<S11
ACPe<S4c<S8c@D53=38bAT4a<3P`@cDc@D8h=3U6@dE5=30f<cA3<CPi<3=6@SQ6
3CTh@T@c=396=cLh=4=6AD@h<cA6=30b=dE1<4Hb@S12=4@d>3<iAD4i@d8e>DA6
<CM3=394ACDh>C8eA@db<4E5=3Pd=C15<SE3<SA5<44f<3U2A3A2<SM4@DE5@T=6
=d92=dE2<SDc>4A3>C<h@d8bAC=3<492=C0==c55=cDbACDf@c52>C<c=T8i<451
=DA6=3Da>DA2=D@bADA3@cLg=S<e<dH`@CLa=cU4>CDf<3Ph<c<`3D@`@C8f=3E1
=d55A44g>C11=b1>A0d_F3U3820a<SHPDT@P<SA5@d94<3DcAD8iAS<f>3I4=3M1
A4A4<30h<3LaA4E5<3Dg<3<bATDe=CHbATE4<391AD8g<CLi=30a3D@bAD8b>CTi
A3A6=DH`A3Ti=394@d4cA495=C<e<CDe=4@iAS@h@T8fASA4>3Hf<3@iA351=SE3
<DDb@@e4ASLa<d8`AS14@SI3AT94AD96<cQ6=T8c@CLeA3M2=CE6AC93AC53@cPc
<3<b>D@aA3Lh<c=3=T@gAT4=@CPf<c0eA4A3@DI4<cLa@S=3=d8b<c15=c4g<CI5
=cE2@S8`AC0g=SDg>312=d@`>4Hc@THb=d8b=SHa3C0c=DA4@CD`@T<iAB1>A0d_
F3U4820a<SDPDT@P<SA5@d94<3DcAD8iAS<f>3I4=3M1A4A4<30h<3LaA4E5<3Dg
<3<bATDe=CHbATE4<391AD8g<CLi=30a3D@bAD8b>CTiA3A6=DH`A3Ti=394@d4c
A495=C<e<CDe=4@iAS@h@T8fASA4>3Hf<3@iA351=SE3<DDb@@e4ASLa<d8`AS14
@SI3AT94AD96<cQ6=T8c@CLeA3M2=CE6AC93AC53@cPc<3<b>D@aA3Lh<c=3=T@g
AT4=@CPf<c0eA4A3@DI4<cLa@S=3=d8b<c15=c4g<CI5=cDb<CDb@SU1@c4f<C0f
=D4a<D=3@d4dASTg=3M43CQ5>CLa>C=5=c@PCT@=;ePiAB0P<C<e8594838dAD=2
A30e<dE2>DHc=SPfA3@g@DA4A30`>30g<DA5AC0e=c0c<TI5=CDf<TI5A30b@DE2
=c4g>C@`<@e4<TE2<STi>D@dASE6<4@i>C@bA4=1<dA2ACDc=C4e=CA4>DHd>492
=THdA3Pf=S0d>D@a@CHe@c55<T4=A4Hg<C=2<4H`A48f@dI2A4E2AS<hASI2<d4g
=D@g@SDeATDb@dDa@d<h<c0c<SU4<D@g>3<c@cI4=dI13D4h=S<`=DA4@d56A3<g
<D8c@cM2<S<`ACLa=c4fACLe@T91<c4g=SU5@c0h@c=4>3@f@CHd=cPd<T4h<Pda
@CD`>C@c=4<e<d8g=d@dADA3A4@d=SI3=cI1=c8PCT@=;ePiAR0P<C<b8594838d
AD=2A30e<dE2>DHc=SPfA3@g@DA4A30`>30g<DA5AC0e=c0c<TI5=CDf<TI5A30b
@DE2=c4g>C@`<@e4<TE2<STi>D@dASE6<4@i>C@bA4=1<dA2ACDc=C4e=CA4>DHd
>492=THdA3Pf=S0d>D@a@CHe@c55<T4=A4Hg<C=2<4H`A48f@dI2A4E2AS<hASI2
<d4g=D@g@SDeATDb@dDa@d<h<c0c<SU4<D@g>3<c@cI4=dI13D4h=S<`=DA4@d56
A3<g<D8c@cM2<S<`ACLa=c4fACLe@T8`@CE6<4=3=T8c<CDd<S4d@c@b=DDb=4E1
@Pdc@T51<S15@C4`AC@g=C<aASLa=THc<T4PCT@=;eQ1<20P=CTPDT@P<SA5@d94
<3DcAD8h=cDc@d4dA3I6=c0f<C96=S91<CHbA3Hd@T91<44d>D92ADE2ACP`@T@`
=3ThAT8i3D8a@dA3@SDcAD@g<TE2<TDe@cPd@cI4<T51=3@a@THb@T53>4Hb<SQ2
<cQ5<cU4>D8`@c=1<4A6ATDPCT@=;eQ1<B0P<C<b8594838dAD=2A30e<dE2=SDd
=TA4@C55<CQ3@S=2<D@c>CH`=C4g>34f@C0e>451<T54<CL`>3Hg>4E2=S8a<`e3
@T<f=SQ1A456=CA4=CHc=cHhATDaA3E3AD8h>4Dc<4A1=c=1@SA6A44d<3Df>CA2
A3Pg=TDf=30g@D4==3<a<T@`A3TcA3I3>C53ADDeAD51<c95@SDf>4E4>44g<DI1
@CPa>CE2@CM6@SPf=SU4@cU4>313>DE13D8`=SLg=cTb=c4b=495<c8`AS95<C4a
<c52A34f=CA2>38gACI1AC4f=353<T8a>D52>CP`@C14<CHb=@dh@CE6@d@g<cT`
A48e=C8b<cDa<3Lb@dDPCT@=;eQ1<R0P<CT`8594838dAD=2A30e<dE2>3Le<d=1
=4@fASLa<SP`>C<i@CLg=c4a@T8b=TI3<cDe<S92<3E5<T51@C=3@c95<@e6>D95
=d<c<TI3<dHfAT@g@C@d=D54ATA6=cPh<SPi@S=5@d8`=S0h<4H`<C<g=TE5<SHc
=48a<30b@S<=<34b=TA6@c0`@d<fA30dASE6>456@cLe<cA6=D<b>DDa<cI2<dDd
=T94@S93<S<fA44d>DI6ACTfA3923C<hADA6AS0gAS4f=CLc>CI5<dA1ACE1=C<f
=SE1@c4f<S8e@d4i@C@e@CU5<c0c=CDe<D4e@S4c<SLh<0d`=TI5@TI6>30dASDc
=dA2@cHf@dE2A3M6=3E1<3=1<TE4@D8`<d91ACU5<4Hh>C0e<C15@d94=S0hA3@=
=S93<S@d<THf=cE2AC0f<34g>D4d<T=4AS4i@d52=dE3<3<`=355AT94AD8h@S8e
=C<f@c4c=S0eA38`3C@b=TDg=S@i>C8a=S0h@D<`A38b84i43BmH@C<P834e<R1B
A20b=4E3@T@`=C=5@SPg=C=3@CA4=T@dAS11<T8f<SDi=48h<C8h>DE5<cLf@S@c
=SA2ASHh=CDd<cLc=cL=<T4`ACA4@DDdACPb>C56<S53>CU5=D@h>454<3Lg=DHc
<SDc<d4e@S<g=3<i=T=3>352=48c<3Dg@c4e3DE1=3Di<cU3>3=4<S@dACLa<D@i
<3Dc<3E3<3E1>C0`@cU3@C4a<48`>DHbA44gAT92AD<f=3I5=c@a<@df<d4`<3E6
>3@a<T@g<CU3@CQ3@c=1@cPc<S8bA3A6<cI3A34`=C8g<d4e>3Tg<4@e<D8gACDf
AS@f<CP=>3M1<CE3<S8a>3M3ADDe@d@g=SE3>4<i@S54<c<hAS0e<cLg<CA6AT55
AD@dA3@`@d53@T<e@d93A3L`3DE4ASDPCT@=;eQ1=20P<c<e8594838dAD=2A30e
<dE2>3Le<d=1=4@fASLiAT96>CP`<CQ4A48e@T8d@CDb@CTi=CA4A3Db@cD`ASI3
@D=3@`e5<S14<d8g>48h>453=DE4=CLe<c51=CTg<DA6<3@hA48dA3M1@DDe>D56
>4@c<4=1=3I1@C4fASLd=TH==4<`>4Dg>4A6A3DiA30f=CTb>C12<SA4AT55=S<b
ASI5=d@dACQ4=T@b@C8a<S<d@DD`>C52<4@e<3@e3C51>3DeAT<d<d8`<TDc<D8c
>C@b=38`<C91AD8g>D8h>3A3<D94ATE4<TD`@d@h<c<b>C54=T<iA3Tg<Pdd<C8f
ATH`>30a=D8d<cM5@STdASU6>38eASM6AS16@d@a<4I2<48b=4E4=3Pb=cA4ACI5
@CA6@DE4=d<=@D4fAT8c@c15<T8c<cE5>315<cD`=394>DE2AD92=S<bACLe@SI2
@DI1AD=1>DE2>3<a=3M1>D@d<4=63C<f>394=SPdAS=6<D@b@S8h=C=2=4<h@dH`
<C8c<SLe=cD`@SDaA3T`=SDiAS<b@dI1=SPg@S@eAD4h=`e4=C4hACDeA3E6=c8`
=TI3A4=3=34g=CDb=30d<S@i@TI1@c<e=SHfA3E1A34c<C@d<3Q6AS0d=cPaAST=
<C52=T4h<c@b>D94=d91>CM5A3L`>4E2=393AD8fA3=4ACA6@STf=S=4ADDb@c0`
=cLiAT@g=C@b>CDh3CPi=C16=S8h>CDc<D<fASLf<CPe<CPcA453AT53AT8bACDh
<d91=S8iA30d=3Hf>C=1=c@h<SDb=3Hg@@dg=T4`=T92=cLe<T4a=T8cAS4i@D=2
=cLg>CI5>CM1=S=2@cDiAT<iAD4b=4De@D@h<d8`@CU6=d8b=3H=>CU1ATDb<C8f
@b1>A0d_F44e820a<34PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6>4I6@S=6=d4`
@S0g@D94<3=4<D4e<c0d>DE3@d@c=4=3<CA3<C@h3CU6<C<aACA5>D53A38g=44c
@SHf>4DaA48eACM1<D<`<48g@c91ACDh=T@i<3U3>DA2>C0c<T<d<T@i<`dh<d8c
@dHeA3D`=T8d>34i@c4a<cDi@c@i<d8d>CA4@cA1ASDh=DI1A3LfASDcA30e=S<d
A34eASU5=D<==T8a<d8d@S@dADE6A3=1=C@e=34d<R1>A0d_F44f820g=b1BA20b
=4E3@T@`=C=5@SPg=C=3@CA4=THgA3Lh@S4d>D8a=SA5AD@d<3@g<D=5=TDhA3A2
<3Dd=S<`=3Dh>CP=@D@a<CHgA48a>3Ld<D=6ADDaAD8b=d92@D@f=3E2ACH`>4E6
=c<b=S8g@d8b>C=3AT4f<dHb=DDc<3Hg3CLh>C@c@CM5AC<cASE1<SHiAD=6A30a
<dE6=CDe@D<h<T8PCT@=;eQ1=b0P<S@e8594838dAD=2A30e<dE2>D=2<STg<T=2
<TA6>48dA4A6>D4a@S=6=4=4=c8c<T4i@T96=T<i@SI2>4I5A44`<`dc@CDf@SM4
A4I5=3Le<CQ5=DHd@cDe@TA4>C0`<SH`ADHa=3<`=TDb=3E1@S56AT8gAC92=3I2
=4Db<ST=A4@c<d@b>CLb@CQ3=34g=DE2ACU2=DHc@SHi@SA6@C92=T<f=3Lb=3M4
<c@c@cE5=C8g=T8i@CU2=CDh3C8bA3E2>4@g=453>3I5<4@`@dDc>3@g=494<d4f
=c8g>4Dg<cE1=3Di>3Lh@T8eAT53<T8bA3@`>C4c@`dh@DA3ASTf<cQ4<dDc>CTc
=455>4De@CM5<DI2@d94@dI5@c<e@SHfA396=d4c@CDc>CHh=T=5<dDh=CP=<SE5
>395<c=2@CA2=T=4@S8a@D8h@CE6=3M4>DE6=d4cAS54A38f<S95>DE4ATI2@c53
=d@f<SU4@d<e3CI4A3<e<TA5=d@`=CTc=34b=S4e<C<bA3U5=TI2=cE2ATDc=4I3
ATI1ACHg@CPc<SU4@T8h<d=3@S<`APdi=TE4>394AC<e@TDf=DHi@SLe<CQ6AS=1
=d8eAC0b>DHi=DHfA354@d4g@cDh<S@e<T51=cE5>311=S0=>4I5>C8i<CDhA21>
A0d_F44h820c<C@PDT@P<SA5@d94<3DcAD92@cHe@c0e>D<gAC8c<4DiA3U3<355
<C=3@dA1ADDa<S8g=T4f=D=2<S=1<30b=4=33CHc<3U1@DA3<D@`=CE3=T92A3U5
=c8g>4D`<d4a=D53<CA3AD51<D51ASPdA313<T<g@D<`ACE2<3Pi<@e6@C@f=cI4
AS<i<d4d=SQ5=DI4<CHf=CHc<cM6<S@e<dHd<C4bAC0b=c4i<S92<c4a>C0gAD@`
<3M4=TD=>DHc<T@aAS=4<3Db=SE3>C4`@D@e@d8d<38`>3Q5<S8h@T8f<CLg=30b
<SPdASDe=CI4ACHd>DH`>3Lc3C@f@CHg@T<`=TA2@CQ6A48e=4Hc=4@h>3@f<THg
=SL`@SPeA3Ta<S@a@cU2<3Ld=CA1A3@bA4HaAT8i=Pe3=c4`<dA2>CI6=CPc>D52
>3HdADDh>C8c@cQ4<CDg@c92=cQ5AS8g@c8h<DDg>DA5@S<e=c<dAS0dA4H=@C0f
<S13@d51=T4a<d4d=3U4AT8a@c53=3Lg<TE2=SHd<d<fA316>DI1A44hACP`=4E5
@S4f@cA3@c0`3CP`>495@c12A34i>3He<T8`AS@f=3Ph=dA4@C4eAC4c=cPc=38b
ASM6AT<`=TD`A4E1@cM3<D<b>4E6<`e6=34h@dHi<4<`@c93@TE3A34c>4@h=T@d
@S56>4A3<C@e<T8a@S91>CTdACPa@TH`@cA6=CQ6>3Pe<c4==c<h<3A3<S51<34b
A4HhA34g@cLg>CHi<S8g<cI4@d53<4=6<S<c=d=6@S4a=4I5@dA4=SPg@dDc>44f
3D=6=SPb=DE3=c8h<T<b=dI1=S4f=3He@SE3>D@PCT@=;eQ1>B0P<SPi8594838d
AD=2A30e<dE2@T<f=D<`=CU3=dE3A4HiAT4h<3Td<c0a<cLd=3HdA4I2=CT`=DDe
=d8i@d92>CM1A@d`ASLh>3Pa>3<c>C96>38`ACPh@cU5<cLi<d8g@d@f<cPe@CQ1
ACHcA3Q3>3<f>3@c=3TeASPgACE5@SD==THb>4I2>CLb=453AS<f<CA4@SU2<SLh
<3M2=48fADI2AS@h<SHaASDf=cLi<c=1@d=6<c0aA3H`@c8h3CTh<4Hh=C4a=TD`
=CHg<cDeACLgA493=DDi@cD`AT@a=3A1=T54<S8a=C8h>C8gA3Q5@C8eA491=3E6
APe6=3<iADI3AT8h@cHc=T95<THh@C4c=3I2>D@a<3PbA44c>356<d<iA3Hi=3U6
>CTf>D4c<cHg<S8hAC<=@CPb=S@e@D54=T8b@C4i<311<c8fACDcA3M5>38h@S12
=CTe@S93=D8d<cU6@SQ2<T<b=SDh=D<hA3Di3DDh>393>CTh>4I1A3Dh<T@h=SPe
=T=4@CLf=38f=T8f@CHiA4@e=3@dASHg=3I3@S54@T@`AD94=C@eA0db@c0`AC8`
=S<a=T<gA4=4=d@a<SM3=SI5<c15>34e@TE2=dE4>C0d<CU4>CA1@CU3=S@f@SE2
AC<h<C<=>3E6<c8d@cHa@DE1=S8d=d<i<3I1AC4d@S8d=48g>3U5@d@h<3DcA44a
=30f<3Tb=CTc>D@b@d92<cHa3C8eASDf=c@i<S4d@cHc@CLh=cLd>44dA4@iAD8h
=34gA3Ti=3Hc84i43BmH@D4P83P`8594838dAD=2A30e<dE2>4@`>DHfA44d@c4h
@TA1>C4`<cTe=d4gAD4bAT<e>C4g<CHf=S@b@C8`=4=4AC@h@`e3>C=3AS=5>DA2
AT4c<CHb>CQ6@c@d=dHeAT@e<C@e>DDf=c4g>4De=DHc=TA2AT<b<dDcAS12A34d
@cH==4<e@SA2<4=3AC8a>DA5<4@b=4DcADHh<391@CDe@D4g@S<e@T=4<b1>A0d_
F452820c<B1BA20b=4E3@T@`=C=5@SU3@S8i=c93@S0iATDi=C8d@STh=S0c@C4d
<cDi=S<e=CQ1A3Lf>D93A3He=c14<TD=<dHPCT@=;eQ1@b0P<cLPDT@P<SA5@d94
<3DcAD8i@d8b>CLb@d8`>D<bAS=3<4I1>C<h>4=2@T8b=SDfAT=5>3E4<38g=CI1
@D<d=d<f3C56<c8c<TE5=3Li=SM584i43BmH@D@P83La8594838dAD=2A30e<dE2
>3Le<d=1=4@fASM5A4A1<SI5=C4`@c<e>353=dA3@cLgAT=6<T4g<d@d@c<bASQ6
<0dd>CTe=D<e@cM6@SDi<S0e<4E5=d96>3U6>3Hh@cM4<C8`<dDhA4Db<DI2=d4f
ASA1@cDd>C<i@CU3<4<=A4@e<395AD4`=C92@c0`@THiAS0aAB1>A0d_F455820g
>21BA20b=4E3@T@`=C=5@T92<CI6@TDb=3Tf>34e=CM6<CE1=C<d@cQ2@d4d<4<i
@c0b=SA3<CE1<SM2=34i<C<=>44h=CHf>4E2@c=3@d96<T8h@TE4@c12>48c>38b
=453=d4d@STf<S@g=CLf<c4f@C@h>D=2=CA5>C8i3CTe=c=5>CTh=C@a>C@`=4Dg
@SPb<dE6>C<f=d8g<DE4A3Ha=21>A0d_F456820b<3<PDT@P<SA5@d94<3DcAD8h
<SU5=3@d@S0e=STe@cTi=d95<T94ADHi>34iASTf<STiASD`@d55@D94A4A5=3Df
3CA1=S@e@cTg>C0a=D=3>D@e<3P`>DE3=d54=3E1=cLg=d92<352=d<b>3M2A4H`
>CTa=T@i>C<i=3@f=Pdf<4A1<c0eA3L`A4HcASLb=dHi@C0c@S0e<453ACTc<C0b
<4@b@D8eAC@d<38e=CQ4>3Li<T=1=T@eA30==D=1AT8c@S4`=dI5>D8e=CH`>351
=3U1<S91@C8f=dI6>C8`=cE4<3Hf>CTcAC4c@D4i<SLbA3Q4AC133D92<DA5ASQ1
<D<`>4E6AS<d<D=6=d92=4A6<CTg<C91@c4h<4A2ASM4ASDhA3U4@ST`=3Q2=S8f
<S=3<`dg=D4c@c0b>314<SHc@S0i=d=5>352<3=3>3DdACHi@S55@d4cADE4A4@b
<4<i>CE6ASTe@D8f=CHa>D8=@DDa<STc@cI4=44b<C4i<30c=D@dAD94>DA4@TI1
@SDiA3A5ACDd@D=6=4E1@B1>A0d_F48`820b=3HPDT@P<SA5@d94<3DcAD8h=cDc
@d4dA3I6>316<c8e>4@c@cDf@THb=C<a<3Db=T8a@d8a@DI3ADHf=cM5A3<a3CM1
A4=1<dHg@cM4=30e<TE6A4H`ATDe>CDb<3Td<30a@S4aAS14=cA2>D@b=dA5<S@c
=4E2=d4`<CDf<0df=3Ti@dDf=TD`@CPi@T=5=D56<d<d=34g=4<b<cQ2@S<d>D95
@CLc=TH`ASTb>34c@S4d@C8eA3U6<3P=@T8hATHg@D=2=T4d=S<aATHi=SA2ASM5
=TE5=SM2<3La>CL`=dI5<T52@S<i=d<b>44b@CTe@cTaAD@g3D<d<CHi=CPc>CLb
=c8i@cLe<SE1AD@g>DA6A356ACPh@TI2<DDf@cI6@SPf<TI1<d95<38d=cI4=S=5
A0e4=4E1=T4g@D<b>DHh<3LeAT8i@C=6<CTc@cA6@cPi<D4g=3Tg<38cA3M2AC0d
<491>CM1<3Hd@CE5AD@=<CPi=cDb=4<`>494<S0c@C52=D=1<3Lf@c<d@CTc<D95
@T8b=cLaA30gAC@a@CDfA391ASE5@C=2=C133C53@SQ2>30e<4Da<D55AC0cAD4h
=d=5>492@CE2ACHf@S<d>3I2@C<b=4I5=dE1=3Q3=3Lc<315=TE5=Pde<cTbAC<b
=CT`<T8PCT@=;eQ2<B0P=S<PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=dE4A3Db
@d@g=3<f=3L`>3Q4=cPh<S4`<38c=THi=3Ti@d55<4923CLd>C4iACPa>DA4>3A1
=C0hAD4i@d4d@T56=d4d=4Dh=C<f=cPa<S4cACDfASE3AD54>CHh=T53ASHd@`db
>495=T4PCT@=;eQ2<R0P=CDPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=dE4A3A3
A4E6>38eAT4i=CDi=3@b<3E1ASE1<4H`=C4e<c=6=SI63C51@SDbADHe@S<a>3Dd
<TDd<C<c<D4i@dE6>4<b<CDi<CI4@D@b@SHh>4<fAD96=c8e84i43BmH@S<P83Dd
8594838dAD=2A30e<dE2>3Le<d=1=4@f@cLi<STd>44`@CLd=S51A3Ph>453@c8f
=SPh=3@hASA5>494>3=5APdi=391@CP`<dDa=CPeAT4`ASQ6=TDaASTb>314A3Dc
@T4`AD55=c0c<S=1<d54AC8PCT@=;eQ2=20P>3<PDT@P<SA5@d94<3DcAD8h=cDc
@d4dA3I6=c0i=38g<4A1<C<d<48e=356=CDd=d@i=D92<D8d=3M2@cDc@CTe3CE4
<TI3@dA6>34g<T92>D<d>3<i>D@e>4@e=DI6ASTa>D=6ACTg@cA1<4<a>D@a@TDb
@T54=DDd=STc<0e1ATHiASHc@cDd=S96<CD`<c4hASHh>4Hi@c4f@T@h=351<S@i
<3Pd@SLbAS<`84i43BmH@SDP834a<R1BA20b=4E3@T@`=C=5@SU3@S8i=c93@S<c
<dI6=3U3=d4iAS0b@C11=30c=TDg<STd>48b>D4h>4<g<SU6>C0=@CA2=3@dA4<d
=d96>CLe<dE3AD<`ASI1<3=2@TI4ACQ2=DDb=THh@CI6@D=3A4Dg=c11>3U5<S@a
@CPb3C95A48e=CU4ATA2<44g@TH`AS0c>CPh=D4`A4De=356=cPe@d8`>4I2=4<`
@D<g<C8g>C@h<S<`<3<h<`db=c4gA44g@D92=3<g@d54AS8c>C16<cI1<d8dAS8f
=DHg<T8e@DA2A3E2=21>A0d_F48f820b<3@PDT@P<SA5@d94<3DcAD8h=3Dg<44b
<3U6=S53=SI5=T53ADE5>4E5=C0b=4E1<3@d<4@g@S95=dDe=cHg>D943CDg<34b
<48cA4@b=4Hc<3TiA30h<TH`AC0d=CLb<48hAS8g=cU5<dHi@cI6>DHa=3@c>DI5
<CPd@S@f@`dd=4A4ACDhA4<d<SDbA34cAS0g=4A1@S8gAS11<3HbA3P`<356<S4c
AD<c=C4d@c<`<CLf=D54@d@b@T8==S96@d<a<3@a<4<iACHa<CA5ADDe=3I5<THa
=D53>3@a=SLi<CLgASA3<TDh@S94AC<e=C4d<T4g@S963DHd<d4b>34dA34i=3He
>D4iA4De@d54=3La@d@f=CHh>3@f=D4cAD53@CM5<d8dADA4<C=6>3=3=4Dg=@d`
@T@d@DHh@D4f@c91>3=6@cI2@S@g@CA1ACTc=4D`AS@b<C<d=SPi>CPaA354A4Dg
A3Te@T8g<30aACD=ASTe<S8i<4HhACPc<S94=c8e@c<g@T52>3Pa=c=5ASLiASA4
<T8b<C=5@T@h@D9584i43BmH@SLP83Dg8594838dAD=2A30e<dE2>DA1<c0b<C@b
<dA5=T4d@c0fADI6=3@`002Q0<0ood@i<T8d=dE6>D95A4<h=451>3Tb=D95@T<=
@T=6=3Dg<D4e<SU4=C4c=S@c<3M1AC52@cU4<T<f=314AD8`=D4h>3Pi>4Hb>3Q1
@C0`@THf84i43BmH@SPP83@g8594838dAD=2A30e<dE2>4E4ASTg@dDe>DHaAC15
=TDi>3U1@SM4=D<f>C0`=cA3=T<h=dHe=3A1<T53@dI2A@dc=S<a=d92>C4`A4I6
<3Te@c4`=d4h>D@f<C0`<3Lc=C1384i43BmH@STP83Pi8594838dAD=2A30e<dE2
>356A3@f@S0e=cDiA3@f>CI4=454=3Q6A4A3<SI2=d55>4HiAS=3<dI1<S0d@cM1
=`e2AC8hA34f<CLb@SPi>D52=C<aA3@`<4A1>C<d<3Ph@dD`<4E2@cQ6<CPiASM1
@S4e<T8bAT91=3U6ASL=@c11>CA5AT=4=STc=T=2<4HcAC8f=311>312=D8c@CTb
<4HcA3Hb<T8hAD@e@c=4=d4h=d<b<3@iAR1>A0d_F491820b<CHPDT@P<SA5@d94
<3DcAD8i@SL`>CT`<CA6=CM3=c91A44`ACHh=4HdAT@hA3L`<S@c<CPbA3M5@cH`
=d8a@S0d3D8`=d<g=S16<cQ6@SPa<THd@T8e<DA1ASDe<3M4<cT`>3Hc=DHe@T8d
@cA6@C@h>C0c<c0i=3D`<d<d=0di>3A3=3A3<d@f@C4`>4D`<3Th>C8g@D@g@T53
>4Hd=cHaACPh@cDe<452ACU5=SLe<S4a=d<aATHf>D<==353=DA5A44`<30d<d@a
=SHe>3M3A4<c<3I1<d92@T@g<393ACM6>454=4<aACM4@DE2@D<i<cTa<cPe3CE6
=dE6=3E2=T54<D91=dA3@dDc=D<d>CPd=c8c<c=5<D55ASI2@c15>48`=T95ADE2
@TA3AS92ADDfA0df@T54<CDd@d4iA4=5<3<`<T4`@STg<SLbATHf=cM2@S<g<351
<CDc<T<f<3@`>4E3=CA2>CLf=cA5AT8=@T=3<cHa=dA4<d4i<SA2@S8i=c<b>3A3
@S53@CP`=DI6<SDb=T8f>CDa<392<C0`AT52=CI1=c<c<T8d3C4i=c8`<c8a@c4b
=R1>A0d_F492820b<C4PDT@P<SA5@d94<3DcAD8f=D=4>D8a<C@dAC4c>315<d4a
=cDc=T@f<S56A3Lf@S0c=D53<S<h>C=2<CHi<SDe3CLf<d8a<D4g<cH`=D<a=cHf
>4HcASDg@CQ4=S=2=48iAS8fA3E6<dA4=C4e=dE4>3A1=D@a>3A3@SPi<@e3<c16
A313<DA3<CTc@CHi=C8h@SDa<CM6@dHgA34f>D91=D8c>3ThA495<3Tc>C=5<d4d
=cHh>DHc=cT==3A3>4E4@TA2=3U6<312>CDcAC<f<30gA3LcA3=3<cLb@S0f<DDb
=3Pc=c54@C@e@TI3AC@hACTb=cPg3CI1=d4f=4@a<38c>C8c<S96<4A2AC56@CHe
=3@i=dDg=T8h=T8d<S16@c4h=T@f>4<`@SPh@T<g=4D`@PdcASHi>DHa<34d>4Hi
=4A6<C@h@SHhAC12=3Tg=TI6>3<i<3Td@SD`ATHi<cTd=D<d<d4e>44eA3@f>3@=
>C@g=SPe=THcASLh=d4a<CDh<dA3<S93=D<b<S=4A3Q4=SDcAC8b<44a=DHa@cHa
>CQ1@S@d=cLh=CHh3D@g84i43BmH@T<P834c<R1BA20b=4E3@T@`=C=5@STbASDg
=c<g@C<eA4=3@cM1ATA3<cA4=3U4A4I2>4<i=SLf=d95A356@CDgAT<cAS4=<34`
<C4fAC8d@c54>4A4<30c@CP`@c@i=c@h<T8fA396AD@h@CA3AC<cA3E4@TE6@C0b
=cQ2>CTi@cHd3DHcADHf>34h=TE2AS4`ATE1@dHg<d=3<SHh@CU2@T96<d<`AS0b
AC<d<d8h=D<c<TDc<C8b<313<TE6<Pdi<T<f>30g@SA5<CU6<C<a=cI1ACQ5A4Db
@CA6@SDb=30`@d8f>C55<T52>44i=C4cAS<c<3M5=3A3=T@=@d8i<S56<cE2=cLe
<C@d@SU1@SI1@SHa84i43BmH@T@P834g=B1BA20b=4E3@T@`=C=5@SQ5A4Hi=d=5
=CU6@D@e<T<aATDa@CTgACI6@CTe=4H`=CHhA393=C<hA3U2@dI6<CL=@TA3<cPd
ASU1>D@c=C@g<C4f@TDb@cHd<38gAS=1<cU1>CTa@S4i<cLfA3Pc<C53=T8a<4I4
>DA3@cA23DHf=c15<C@h=S55<c@b@dHf<cI2@c8g@D<cAS52>C96@S52=3I5@d94
<DHd<c0b=352@S0cAT8a<STh=@e3AD8b=C=5=dA4=d4d=D<g=c<cA4<d<DA6AC0`
ADA2=CI2@S8f<392=4<h@SI6<d4g=CPf<d4f<CM1@S<=@STe@C0b@SLb=C4`=S0b
>CA1@SI2<T4h>3DcATDi@d<aA4A6ACPc@D8g<c4g=3HdAC4b=D<a=D8gAC123C54
>355=cPa>C11<4I5=34i>CPg=3Da=DHi=34a>C8iA4<d<TDa<DI4<3Di<c0d=38a
84i43BmH@TDP83<f<R1BA20b=4E3@T@`=C=5@T96<DH`=DHh=CA3<3Pc=CM6<D53
=TI6@D4gA3=2<d4iA30e=cPd>DHiA3E1AS8a@c<=@STi@SDg=SE6<3U6@CLa=cQ1
=c@i<3Q6@CQ3ASTg=d=2=TE3@C8g<T=4A394=T@h=T=1=TI2@CP`@TE53D<f=C4a
A3T`=d4h=3=2=C@h<453=c0d>3Tc>DDdA48e@C<i>CTh=dE1AC54@cHe@DDc<S4h
@T51@C4`@@db=454A4<e=3I4>4<`>C<`<cDg<4<d=456<SLcAS<fAS96ACA5@DA1
@T4i<C4g>DHb=c=3AC<g<C53<c<=>C8f<CQ2=C<d@d8f<S=3>48g@T@fAS@i<d<g
@SHh<D8a@c95=CE4AC@e=CE1=4=4@S<e@cA3=d@dASI13CE5ASDg=CTc<CPc=c0i
<C0eA3Ph=d@`<4@h>CTf=SU2@S=5<C=5AC12<S11=3<g@c8e<3=5@CE1AC0bA@df
<DE2>CQ5ADDh<34`=C8b>D8f<CPg@d=4=D91<cE3AS0b@DHg@T@i<DHi>CDdASA2
<CPc=D<b@D96@c0=@S<g<STf<THe=4A5@c92<c<fATDh<S54=dH`=c8g=cHi>C15
=TA3<cU5=c0`=S@i@cLaAD=6=313>DA23C0i<3A6ADI5>4@cA48gAD54AC0`>3A3
=c<f<D<d=SDg=4Dd<STh@SLf<D95>3U5@T55<cA4=CE6A3LcAPde=CM2A3P`=cHc
>3Da@CTb<T8`=3Pf=c14@T93=THg=d@`=T8g@S55@DDb<cA4>C=5<dI3=3@h@c@i
>4@=<D=2A4@`=C<g=c@`=CHf>394=S<h<c=3<S0`<C<f@DA1=3A5@CPi@DHa=D@i
<S55=3Ta<cH`A3Hg@C933C8e<dHf<TE4ACDdAS8a<D4b<TDe<d8h@T55=T8a=cHf
=c0`>DE2>4<bA4Hb=S4e<DHd<CL`<THb@DHf<Pe4>48`84i43BmH@THP834g>B1B
A20b=4E3@T@`=C=5@SU4@C<`<S4d<S<b=492@dA5A44eACQ5=C<bASHb>34e@SHh
@SM3AC@f=48a>30eA4H=@CPfAS4a@cLb=C<gAS<g@c0e=CU3=T91=3<g<SDe@CD`
AC0e<c0e<3A2=3Ti>3Q1=SM3<4@c<d95=CA23C92@c55<d4`=CTi>DDa<CTa=D56
@CM4=CLg=CU5A3Pf@cLfA3E5<cE1@D<e>CI3<S91@THf@TDc<T4aA0deAS16@T@b
<d8bA3U2@C@i<SPd=d8`@C=5@dDh=cLd=S=6<DHh>38f@d4f<d@h=SM1<C4a<dHg
@D@b@ST=ACD`=3T`=C<b=T4i<CLa>48f=30a=DDc@c@`@D@`A3@b=3Q1ADDeAD@g
AC<h@S8e=T4`<dDf@SH`>CU33D4e>4De@SLd<CD`>4I2@c=3<d4h@SA2<T<e@S<e
<d96>D@h>D<`=T4a@cM1@cPcAC<e=c@d>CQ2@SPPCT@=;eQ3<20P<CLc8594838d
AD=2A30e<dE2>DDd=30a<SDg>DA4=cE4>3@iACE5@T=4@c<f<cL`<30b<STg@D@b
@DE4<D<`@c8c>@dh@C@e<c8fAS11=d8hASE1<CDc=c0f<d<a<S0f>CQ2=cU6=c8`
@T=1<dE1@S94ACA2=cQ3ATHd=d@b=4H=<48g<S@c@SA6@SU4=SHa=c4h<4I5@C<d
=c92A38h=C8b=3<eACE3<S<cA44i=D4eA3I2=3<d<SA3=c0d3C4`=STi=d94>CLf
>4@fA4E2@THb=c0i@S0h=DDi>CPi<d96>4@`>DE5ASHd=3A5<3@a<dHd<T4hAS=2
>@dc>3HaA44e<44d=CT`<4@f<S0c<C@g>30`=S13@ST`=4<e@C4d=S0iA3@h>4<e
<4@g@DI4>3H`=dA3>D4=A4E4@cE4@DHg=3Q5=3Pb@C<e=C8aA4H`@D@e@d92@CU3
>3<a<3HbAT4b<3Ld@R1>A0d_F4<a820d<R1BA20b=4E3@T@`=C=5@SHgAC<c=T51
=3Lb<S92<STe>3PgA38fAC4b<S@`<dDi<dHe@C4h<3@cA3=4A3I2<d<=@c<h@S0e
>DHdAS<c@cHe<THe<TA3@S4c84i43BmH@c8P83<c8594838dAD=2A30e<dE2>3Le
<d=1=4@fASM5A4A1>DA6<30g<S8`>452=SDi=S11>CLb@D=6@S8b@S0aA3M3@Pe3
=3<b>3<PCT@=;eQ3<b0P=C0PDT@P<SA5@d94<3DcAD92A3=3<CE4>CI3AD<eAT<g
A4E3=SQ6=T56<34b>3Lg=48fA3I5=DA6=SM4>C0c>C0a3C8cA3U4<dDb@d94>4A3
=cPd>CPi<44d@d95<38c@S54@D=6>CPb@CLPCT@=;eQ3=20P>C4PDT@P<SA5@d94
<3DcAD8h=cDc@d4dA3I6>3U2=C8c>CDb<cI6=C@`<DA5>3Te>CE1A3Ld@DE4@d4d
=3Pg<d@g3D<g=CHa<D<e<dE4@T@cASU4=DHeA3=3<38c@DH`AT@a=D<f=C4eA3I2
@c@c=cHeAT@fA3=5>CPd<3Q4@@dg=4Dd<T8b=C4bACM1@D4cADHh@DI2>3Lf=c8i
@DE3>C@h=34fA451ACE6<SPb<cDf<CPg@CI5=CTh@SH==d@PCT@=;eQ3=B0P<SHe
8594838dAD=2A30e<dE2>3Le<d=1=4@f@cLi@CDi=48g<S4c>C16@C0i<T<`AC@b
A3<bACDf>D<iA316>DDf@Pe2@cPe=c0a=cThASM2>DDc<38a=dHh>3=4@cTe<4<`
ADHc<3DiAT@fACI1ADHf@C8gA456AS8c@C4aA30=@S0c@c4d=SHg<CTcAD52<cA1
=S0a<SL`=CTe>D4a=3M4A3De<CA6=C4iADI6=SA6<D4g=S@cA3PeA3@i3D4c=3Q4
=CI5=c<`=d56@SD`<T51@cDd<T4h<SPa<CM3<CPi<CHf<4Hd>CHhAD8b<4Hb=3@f
@CDc@dE6<`dh<C8g@S<b@TI1=S@e=D4aASE6@cPa@SM5<44b@THb>30b<T8e=SA2
<dDa=c@h@T4i<C0i<C<e<C0f>CP=>CTfACDa=CP`A4@`<TA2A48c@TA4=3U1@c8a
<d<aA3L`@cLd=3=5<S0c=SQ3=D92=391<D=5<cLd@SI13DA2=DA2<cI3>396=DI6
@d4i@SDe>DE1A3A2@c4f@SHd@TDf=S0e@SDd>DA1=44i=CM6<dI5=3E6A3Pi=`d`
=SDa<S11A453A453ADI4<cE2A493<T94<3A3<3Pd=c4f<4=5<456=D4a>3T`<dI4
<D96=4Hi@cA3@D8=>3Ph@DHe=T4dA4@c@c0f<S8`AS0`@T52<SDb=cPb@CLd=4=2
>CLf>3Q5=3E6<c14>D<PCT@=;eQ3=R0P=C0PDT@P<SA5@d94<3DcAD8hA30iASI4
@C@iASE5@S4eA34f<CE1>CHaAC<iACDa@C56=SU6=3Lc>4DgA3Pe=SLe3D4e=C@c
<T=2<d4fAS4d=SLc>315<CA1A48`@cDbAD=3A312=4@gA30PCT@=;eQ3=b0P=c<P
DT@P<SA5@d94<3DcAD8i>38d@C0f=3Tf>CM5>C0g@d4d@d<d>3Dh@d<e<c93@T96
=S<bAT<dA38fADE1>CLe3DI5@cDh<3A2<STd<4A1@D52<44h>C8e<DI4@T@a@TA4
@CPc@C=5<C8i=3@b=3Lg@DHi<34b<c4c@C11@PddADHa=TE5AD94=3U3@T53A3La
@DE6=D93AB1>A0d_F4<h820g<b1BA20b=4E3@T@`=C=5@STh<SA1<3Hd>CHi@c4i
>C93>CE2AD@hAD=2<CU1<3A4>4Dg@SQ3=3@h=DD`@c4c<D8=<cHi>314A3@d<TA5
@C16<D8c=C4f<3Lf=S@c@TA6@DD`=DI5<C4e>4=3>34i=CE6<cLh@cHfA356ADI2
3CTb=4E5<DDb>4@e@C8e<S8g<TA5@cDb=T4g84i43BmH@cTP83Di8594838dAD=2
A30e<dE2@SE6=4E1AT@f>C@b>30f@CLd@dA4AT@c>453@D=2<S0i>30d>4A3ACDe
@cPg=S8a@`e5<T@`=T4i>C4f=d=3>34e>C51ACHi<c0f=S0e>D95@TDh=dHfA3@e
=C@gASI1=493<4He=d<a>4<c84i43BmH@d4P834b8594838dAD=2A30e<dE2>3Le
<d=1=4@f<3I3=B1>A0d_F4=2820h<21BA20b=4E3@T@`=C=5@SPc<CDa>C55AS0i
<C<e=DDf<c4iA3=6>C4a<3Df<D=5=44b@THh=THg=d@g<D8a@C<=>C=6=DDa=4E4
=T<g@c=3=d<b<SU1<cM6A4Dc=3Lh@S=3@S93<C0gATHc=c91=D<d<cHc>38a<S0c
=STc3D8i=44e<D<i@THi<D4i@T8i@c52<3Pb@SQ2@d@g@SI2@T93=CLc=c0PCT@=
;eQ3@b0P<CHi8594838dAD=2A30e<dE2>3<a=C4i<DE6<3Ta<cDeACHc<CU4<dHi
<C4`=CHa@dDd@C92ASPfASLgA3La@S51<`di<dHeAC4dAD@f@cM3<d<g@c8b>D4c
=dI4AC<d=cQ2<d=2<T<a<3M6AS<g<T4e@c@c=S<h<S4b<3<f>34=@d@c=S95<T@g
ADA6@cM1<c0g=S0g=S<h=4<b<C4`=CQ3<30f=cPaASE3<48h=C0b>30d>C0c>48d
>4<d3CE6A452<CE1>4Dh<DDiAC8c<d8bAT53=cA2A3Dg>4<cADHf<dHd<SLiAT@c
=3LfA4Db<S15<C@a<C4g=0e1=4Hg=d51>34b@dD`=3Pi>496=SLi=CQ2>355@C<c
A30d=3A3@CTb<3M1=c<`A4Dc=355>3M3=CDc<3L==c14=c0b<SLi@cQ6=D8dADDf
<c@b<TE1@d95=T91@SQ4<c4a<4HPCT@=;eQ3A20P<S@d8594838dAD=2A30e<dE2
>38iAC@d=48`=CU6>CE1<D@d<DI5@c0eAD4b<T51<CU4<cA2=D4`@S=3=dDb<30a
<Pe4<S53=c51>3U2@THb>C8g>3Q3<cPb=cM6=c91=4HaADHhASD`<34eASLe<C0a
ADHbASU1>3Q4A30aA3T=AD51>C55@C92AD8g<4Hb>44f<T@dACPa<C4c>353@CLi
=d<f<3HhA3Lh@S0g<d4i=T4d=DE1=3Dg<C=23D@d@S@`=492@d=5@D8b=S@d>C@e
=TDc<c8i@cHa>392ADDd=TDc@SLcAS@cAC0i@S0e<c51ADDd<d54=`deACLc<3@h
AT4b<D8bAS8g<S11<C8h>C@f>3Hc<c0a>315<CQ5<S4a<THd=SM1<C4e@CT`ACE3
<3HdACH=<c8c=S0d<d4`=48gA451=4@gASTe<STf<SHb<SE5@d53=44h<cDbASHh
=S0e>CDiASDa<dHe<DE5=C513DHg<cE4=3<d@C0fAC8`=cTf@CPfACQ5@STh<C=3
=3@c<D<a@D@a<C0h@C=6=cHf>C@c=DHi=S94@CTbAPda<SQ4@dHg<CU3AS<h<4=6
>30i<c15=C@d>3TfASPf@d=4<TA2<S=1@S@`@cDg<CI2>3Lh@TE3ASQ5=c<==3<d
=c=2<4<PCT@=;eQ3AB0P<CHh8594838dAD=2A30e<dE2@S4b<S55<SI6@d=4>4E2
>CM4@S<f<34g@dE1=48d=S4fATHaAT<g@cLf<c@f=T<d=Pdi=cE2<3Hd=ST`<SA5
<4=2=D91>311>CDf=3E5<3PdACHg<C95AS0c>44e=CHdA4Dh<T51<4Df=D=2<D4=
>CDg@D4g=cTh@d8cAC4bA4@a@c=1@dE6<T@d<C91@T@aAC=1=3<h>D4f=TA1<STb
AS<e=4<i<4A1=S8b3C4a<SPa@dDdA3Dh=C96ASI2>3Td=S@b@c8a@C<i=4E3>3A3
=dD`<SPe>DDg<D4g<CPa>30gASM6=4I4A0dfACHg=3E5>C4aA34i>CA5=CTi=T<f
>DE1=44h=D4b<4E5=SU1@CE5<dI6A4=4=S4i<48c=CPcA4HbAC<=@DHc=T8d<SA1
=CTbAS0fATHh=D4b=30a<cHg=C8f=T4b@cHa84i43BmH@dHP838h<b1BA20b=4E3
@T@`=C=5@T92A30b<3D`>D@g<C0`=D<f@cHd@cDe@c56A38f<3I4>C<aA30c=cDi
=4=1=C<iA3L==T8b>D=6@d8a=cE4@cA4<S55=d4d>D51=3Pe@CDhACPf<S<g=34e
=D8f>C8h=38a>4=1<S92=30h=DHh3C95A3DgAD8h=4Da=SLiACPf<CP`@d=1=3@f
=d@`<DI2<THa=DDc=311<T@i=C4d@SDg@CE4=T4d@d@h=@e5<48i<3=3@SHh=C4`
ASDa@cLa>44`@S0f<S0`AD<c<C13=T91=3Da@CQ5=C<c=3M6>CHb@SQ4@dI6@C0=
<3<d=THd>DA5@DDc=cPe=C4`>DE6=SPfASM4>D54AC=6=CDf=3Hi=d@e<d4`AT<a
@T<a>4Hg=D=6=3Q33CPg<cPa@cPc<cDcAD54=4E6=CI5=cI3@d8`@SLh=c@a<cDh
>311<TDc<3Pa<d@`A30d@STh@CTc=SDc@@e3@c<g=30a<STb=DA6@S8a=cI1ACM1
>456=d8f=T51<cE6A4@b=d<gADDa=D95<CTiA4=5AT92=c0h>4<=>3Q5<CDg>CI1
@S96@CHeACU1=THf@DA1=4<b<4@hASLi<4Hd=d@a@cM2=S4g>C0b@c<f<d=3A4Hh
=THd3D=5@SI4=CLg<cHf<C<`>3@eAT8f@CDhAC0cA3<a=TE2<d51=3=4<DA3=C8d
AT<b@D<f=3Q2>3=6=d92<Pd`@T8f<CU1>4=2@d4`@C@d<S52A456<S<f>21>A0d_
F4@`820b=R1BA20b=4E3@T@`=C=5@SU2ASM1>3M4>CU1ACM4>D<b@c4e<S=6<c8f
>3U2@DI6=d=5ADA2@d=684i43BmHA34P838f8594838dAD=2A30e<dE2@SE6=4E1
AT@f@d53<c0h=C0b<CE3@cLi=4@g<T<d@S94AC0a=3@b=48PCT@=;eQ4<R0P<C8i
8594838dAD=2A30e<dE2>D4hACI3>4I5>CM4=d=3AS=1AT<c@D<`<SQ1@cPd<CPh
=S95AD95@c51@CHg<d@d=`da=4@h<C<c<cQ2=TDbACU6=c0i@C4d>48g>D@iA3@a
<SA6ACA6@SPbAS95@dDd=c55>CHi<CHi=CLdACL==SE4<DA4=T91>311>3A5<3U5
=CQ2>DHc@SLd=CA4@DHf<T51A3Hi@T95=CDd<dDgAT8c@S4i=d92AS@i3CLh@C0g
<SHi=D8dAS95@d4c=C95ASQ1=SHh@SDfA3@h@C4c=d=5@D@e<S0c@cU3ACI1AC8e
=D<h<S@i<Pdd@cTiATHbAC8c@c=3<c0`>4@PCT@=;eQ4<b0P<C8h8594838dAD=2
A30e<dE2>D4hACI3>4I5>4@a=D=5>316@C12>4I5@cLi>CP`@SLi<cLe@dD`@SA2
@C4e<4@f<@e3@d@a<STi@cPi>DI3@D4g=STa<DA2<CU3<cTf>396@dDf@TDe<C14
@d4a@DHh=T56<T4e<C@i<T56>38=<S<`=D4f=DI2AT=3@cM2=44a<d@b>3Lb@SLh
>4Df>3@`<cM4>4@f@d@`<C<f>CTgADI5A3U3=352AT8c3C<a=44hAS96AD8h<dA2
=cA2<CLgAC<a<S=6AC8g<dDa<3Di<S=2=cHg=CE6=4@a@C0i<315>3Tb@CTdAPdg
<dHi>3L`<CDc>D53<THe84i43BmHA3@P83La8594838dAD=2A30e<dE2=SM5<c<f
@D4d=c4f=dHf<30cAS0f<S93AS0g>3Tb=48i<D94=3@b=351@c0i<dDdA0d`<3Q5
<4H`=DA5<cPc=cM6@S8c=3@d@D@g@CD`ACHa>DE6AT55>3U3=S0a<THf@c16=cHf
@SLhACU4>38==S8a@d<h<STaA38`@CTh=C0eA4@h=b1>A0d_F4@e820g<21BA20b
=4E3@T@`=C=5@SHgAC<c=T51=3Hd=SPh=d55>48i=3I3@D<e<3Q5=C56>C<iAC95
<CQ1<dI3<S16=D8=<CTc=c<f>4@b=C<gA3@i<d@f@CLg<cLa<D92@c=1=d@f@d<i
<CTa=S51=DA3ACE1<C<g@D4d<C54<S0g3C0eAC91@d@e@DI3A3<f<d91>3=384i4
3BmHA3HP83Dc8594838dAD=2A30e<dE2>3Le<d=1=4@fASM5A4A1>DA6<4<cAS94
<C0g<3=2<T@i>D92<351<S51=STd@S0eAPda@SLg@cP`@T<cA34c>3Pg=T8aA3Df
<cA6=d4`=cTd=SA5@cTa@D=5A454<S1484i43BmHA3LP83H`8594838dAD=2A30e
<dE2>3Le<d=1=4@fASM5A4@e=351=4I3=T<a=3Ti<C0a>DDiA356@S<`<C=2=S4d
AD<eAPe6=CM1=D93ASTc>3@b<CTgAT@g<3<f>4E4<cU5AC<h>38gA3LeAT4`<cQ6
>3DgAT95A30eAD8f=T<f@D8PCT@=;eQ4>20P<C4f8594838dAD=2A30e<dE2>DHh
=S16@dE1=T<b>3A1=cTf<S0d=S53>34g<CHf<T56>3Ph>3Hf<cU1=c12@d=5=`e5
=44`<cHd>C@f=D=6ASTa@S0h@CA2>C=3AD8e<D@a>D8e>3Te=STa@d<a@D@`=c<g
=c0f=4Db=3=4@S0=>D4h@d=3ASDg>CDb<C0f>CLc<SA3>3U6<T8h<c@hAD<h=D4b
=S4h=TA3A34b<T=3A4Ha>4Dc<4He>3Q43D@f<T8eA3Te<D<i=T@b<C4a>CP`A48h
AD=6@THg>4=6=CTc=C4a=TE1=3<d<S<gAT54A3TPCT@=;eQ4>B0P=c@PDT@P<SA5
@d94<3DcAD8iA4Dg@S0f@CPg=SDe@TD`@d92=34g>C4dA34`>DA5A4Dh>CI2@C16
AD93@d<c@SDd3CPi<d96<C=2<3Q6=SPf<48h>3@i<D92>3M1@cA1=T@eATA1=c13
<TI5<d<aAC=2ACM4ASM1<CHa=TE3=0dcADHa<CTa<STaAC8e<4I1<4<d=SLb<355
A3Lb84i43BmHA44P838i8594838dAD=2A30e<dE2<4E2<4Hc@DA5>D91<c52<d8d
=c<h@C4g>3Ha@D55<cHdA3T`AD8a<C8g@C=5>C<PCT@=;eQ4@R0P<C<i8594838d
AD=2A30e<dE2>38f=c<f>CPh>C13AD@b=DI4ACHi@dHb>CPi@T8e>D92ASPb<D94
=SQ1@CTbA4<`A0dcAD8c=dDf<44aA48b@D55<44g@c8h>CD`<c0g=30h<C8`A38f
<311@CTh@C@aAC4a>CI5@CTa<4<b@S@=@SA4<dD`@C0`@SLd<T8`<SLa@c=4=44i
>DHh=c4e@T<`=CE5<DHd=c<f=dI3@SA6A38f=4A4A3H`<dDf3CE2<TA6=cHe=d8b
=T95<CPa=C4a@C54<S=3=c93=C@b<dDf=CQ6AT@c@cA5AC0c=c=2<SHb=S0h>C4b
A@de<cI3@S12@SU6A396@CM2@DHi>CI6<3E4ASHh<CQ4ACLa<D@e=21>A0d_F4A3
820d<b1BA20b=4E3@T@`=C=5@SHf@TDa<c4c>34c<3<i<T<i=4Dd@TH`=T@i=cM3
@T=4>CA6A3Hh<3=1A34gA48e>48=<THh<SM3@C52=cM3<30f=S=5=TDfACM1AT8P
CT@=;eQ4A20P=3<PDT@P<SA5@d94<3DcAD8f=T95<C<a<cPa<c@hATE2>3<b<cP`
=SM2<3Ld@SE1=dE6<3I6=dI2=CHi<c4f<THb3D96AT55>CLc@d@d@SA6@dDf@SL`
<C96>C0d84i43BmHA4DP83Ta8594838dAD=2A30e<dE2>D<c@T<b=CU4@DHa=4Da
@T95>D4i=T@e<D@a<D=6<c<e<C8e=C8e>3@i<d92@cLbA0e6=cTb=C95@C14<cQ5
>CD`=SDd@SPd>3@h<D91<3Q6@c@h=353A392>392=D@d<T8b@c14@CM5ADH`=DD=
@dE1AS51<4<d=C4`ATHa@C@b<CHe<C4c<CHd<SE5<T@c=4<d@SH`AT=1=DHh<T8`
<3Pe=C@a<38`@DI33CTf84i43BmHA4HP834`<21BA20b=4E3@T@`=C=5@SU3<d93
<SDiA456=c<f>D4`=3E4AC<g@d52<SLi<D54=493<D<h<T8h<cI6=SPe@C8==cA1
=d4i=CM4@C<i=cM2<D92@C<cACA1ATHi@cA4<3P`<44i@cA2=3=5ASA4<T94<CA6
@ST`>396@CH`3D4e<D<eA3De<c96<456@dI1>C@`@d=5=4=3=c=4ACA2@D@c=T<d
AT<aA3Lf@CPhATDf>4E5@CU4@T93=0dhAS13ACTi@T<fA3Lc@T8d=SM5<B1>A0d_
F4D`820h=b1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THg<3Ha<THf<T4a=S95<cHc
<T4iAC<d@CQ6=TDa<T54=3M5<SQ1=CP=<3Hb=3@`=DI4<c16@S@d=CHhASDb<SPc
=D8e>3I3A3Dh>D=4<CDi<C94=3<`=DDe=d4gA34dAD<i>CE33CDf=c93>353<SPc
=S8`<SH`=SPi<D<g<CU5<SA6A34d>D@aACDcAC0e@CI1=cLc=30e<C=5<R1>A0d_
F4Da820b>B1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THh=4Hi=c8dAC@c@T<i=3U5
=c53>3Lh@STd=SQ2<d8e=T@cACA484i43BmHAC8P83L`8594838dAD=2A30e<dE2
=SM5<c<f@D4d=S@f@S<h@c<h@C<f<cD`A4=3ATHgADHeA3LiA3I6<C4c@D96<3A3
>0daA3M3@TA6=d<g<4=2@dI4>38bATI3=CHi@c@a>4I3=3Pb@SHg<4DfA3Lf=c<g
<dE3<C96A496<3Ti@c8==D4i@c<bACM6@cLa=CHa<SQ2=D<PCT@=;eQ5<b0P<C8h
8594838dAD=2A30e<dE2>D4hACI3>4I5>4@a=T<g>DE2=dHc@S4b=3Dh>DI6@DHd
>CLc<d<b<SQ6<S@d=SDb@@e6<44b=4@fAS0i>3@iA3E4<CA5=cQ6ADA5ASLeAD=2
=cE6=cTh<38gA4Hd>4<a<SDa=3Pa<T8dASE1>CP=>DHi<3@cATI6@D@h=3LhA4@c
<cI3<SU4=CPc@D56AS<f=3Lg>34h<CDd>4A5@CLe<DE6<c0h>3@d@SLg3C0d=C0b
=3Q3=TA1@S0dASU3ADA5AC4c=3A6@STg@c92=SU6A492<S<`AC<f=S8h<c13=3@b
=d8g=SM5<0e2<c0f<351=C8eA3Tc>39684i43BmHAC@P83<i<b1BA20b=4E3@T@`
=C=5@TDc<393<C=4=455=D56=C=4@SLe<4HhA44e@D8g=DDe@cA3<S96<c8e=D54
=d4c@d8=<SHh>DE3AT@gASPd=3@e<CM1<3DgA3HbATHc=c@f@CPc@cPbA4@dACTc
@d55=491@cPeA3Pa=38d@TE33D8b<DA2AS@e=dI4@cHhAC8eA38`=cDg@c8g<CM4
=S8h>C0iA3Dc@cLbAD8f<3<gAT51=3Di>DI4=3E1A@e1<4@i@c16=CI4<C4g@S4e
>4Hf<C14>353<c4b@c=1>DA6>3@eASA2AS51<C@b>CTf>C0a>3Pi=S4f=CL=>391
=S=6<4Dg@SI4@D96=D51@TI4AS53AC14@C4c@dDe@C54>3A1<314AS4g=T@bA3<b
=cTf=CM6=4943DI3<cLg<DDa@cM2<T<`A393<SQ6<CT`<S0c=d<e=3TcAT4h@cTb
=S4fAC8`=3=2>C=1@CM6A48e@CDh=0e6<CTg=T@h=c8a@TDc<C93<SPg=T8cA44a
<c@`A34d@THb@d4h>4E1=SDi>C@c=T<`@T4f>3Hd>DE2AC<=@C56>48i=493@d@h
=4A3A44a@d8f@CDd=cPhAS8f<4Hc=D4h<TE5=THf>4@g=CHd<352>CE6@SDb=d@c
3DA5AD@f<S<`>D4c@C8b=DA5@DE6<CA3=SA5<CLc<T4d=48hA4A5<SPg@C52@d54
ACQ5<CHiA4@aAS=1<Pdg@C<h>C4e=452@c12=4E4=CI3>4@g<d<b<S<hA3Hh<4@d
@TDe<3U4AC@a@SI5=3Lc=3=2>DDc=cM1A48=<c<d=T<`A3Hg=dHd<4E2=S=6<3A1
A44f=TI5=CM6=THc=SQ4AD8h@c52>CDe@T54A3Hh@CLf<3<h=d8c3CDcACTcACHc
A454>C0i@d51ACM3@SDaAT@eA4<hAT@f=4Hh<3Da=T4d<S@f=SDh@T92@S<i@DI2
=DDf<`e1>C=1=354<S<fA3I4<THg@SI6=3A5=T8b>4E6AT4a@c94>4De<C4c<d52
<cPi<CHe@DHf<S8i<d52=SH=ACDf<D8g84i43BmHACDP83Pf8594838dAD=2A30e
<dE2>3<a=C4i<DE6<3Ta<cDeACHc<CU4<dHi<C4`=CHa@dDd@C92ASPfASLgA3La
@S51<`di<dHeAC4dAD@f@cM3<d<g@c8b>D4c=dI4AC<d=cQ2<d=2<T<a<3M6AS<g
<T4e@c@c=S<h<S4b<3<f>D<=>C4b=cPf=TA1>4DbAD<g<DDe<S<`AS@h<dA2=SPf
<cQ6>496@D@c<C16ATHa@d52=34f<21>A0d_F4Df820g<b1BA20b=4E3@T@`=C=5
@SU6@d51<3La=CA6>D92<314>DDa@SA3<4=4<T@f<34dA4Hd<d@i<d<`AS<a@dHd
<S8=A492<3Pb<C8c@CL`<3Ph=dE6ADDaASHdADHe<T91>DA6<TA1ACLg@STeA4E1
<T55@CLiA312=CTi=d=23D4aAD=3ASPf<cU3>4<`<cU6ACE4=CE1=c<b84i43BmH
ACLP83P`8594838dAD=2A30e<dE2>3<a=C4i<DE6<3Ta<cDeACHc<CU4<dHi<C4`
=CHa@dDd@C92ASPfASLgA3La@S51<`di<dHeAC4dAD@f@cM3<d<g@c8b>D4c=dI4
AC<d=cQ2<d=2<T<a<3M6AS<g<T4e@c@c=S<h<S4b<3<f>D<=AT@`A3@g>4=1>4=6
>D@eASLc=cPiAT91=SP`AS@d=S0f>CA3@cHi<b1>A0d_F4Dh820g<R1BA20b=4E3
@T@`=C=5@SU6@d51<3La=CA6>D92<314>DDa@SA3<4=4<T@f<34dA4Hd<d@i<d<`
AS<a@dHd<S8=A492<3Pb<C8c@CL`<3Ph=dE6ADDaASHdADHe<T91>DA4>D<e@cHe
>C93>CPg=D8i@S13@d=6>3A1@dHd3C53@S0`=STd@d@f>CHa<CQ5>4H`=dDc>21>
A0d_F4Di820f=b1BA20b=4E3@T@`=C=5@SU6@d51<3La=CA6>D92<314>DDa@SA3
<4=4<T@f<34dA4Hd<d@i<d<`AS<a@dHd<S8=A492<3Pb<C8c@CL`<3Ph=dE6ADDa
ASHdADHe<T91>DA6A34b>394=3LdASHi@CHg>DI5=3@b<312@cLd3C4i<4@b<CDg
<S@c@TI584i43BmHAD4P83@d8594838dAD=2A30e<dE2=S=2<cDiADDd=30c<48i
>44g<C16<C0g@T<f>44c=TDb<4E1=D93<38gA3I3<S4g=@e6>3Pc=3LaAC@f=S8c
<dA4<48fAS0h>3I1AT8b84i43BmHAD8P83D`8594838dAD=2A30e<dE2=S=2<cDi
ADDd=30c<48i>44g<C16<C0g@T<f>44c=TDb<4E1=C=4=T4a>CHf<3Pd>@db>C8a
ASLd=TE3=3Ha<D8h=4Hf<451A3Lh<THf<CLc=SI3A3Dg<39684i43BmHAD<P83Da
8594838dAD=2A30e<dE2=S=2<cDiADDd=30c<48i>44g<C16<C0g@T<f>44c=TDb
<4E1=CHg<STc=d8hAC0iAPe2A30dADDe=S@d>C8f@c4c=48d>496>4DiASA1@SPb
ATDc=3@c=T=3@c<PCT@=;eQ5A20P=3DPDT@P<SA5@d94<3DcAD8f<d8c=CU5AC@d
<3<`@STh@CLa<4Ha<3M2@cHh@C<fAC8`AD4e=T95>4<b=dH`>3913CD`>CI6<48b
<S<g=3Da@CHhA3U5<dE2<D94@SQ6>21>A0d_F4E5820a=C@PDT@P<SA5@d94<3Dc
AD8h<SU5=3@d@S0e>DHi=D4aA3@aATE3<3E5@C8b@D4a>D@c=48e@C12<d<gAC8`
<34b3D@b<D<g<D4h>D92AS8i<SLh>4<c>38g=dHg<T4dAS55ASQ6=C0`<CE6=cDa
<355AS96>D4h>4A4<354>@e5@D4i<DE1<T95@SL`AS8h@CHbA3A5>34a<C<h<D=1
=cTg@cH`=SQ4=cQ2<3Lc@CTf@C@eAD4d=CLa<d8=A3A2=30d@T93@dE1@S8f=3@i
=3DfAC<c<SU3=S4h<T95AC@fAC=2=c=6=3=5<3U2<3Dc<D55AC@c@D@g3CE5=c<`
=3Q6@C8a@S96<SLb<44a<SPi=3Hh=S<cAS0`AS0d@S8h=SDc@CQ3>CU5AD8d>493
=3Da@S12<@deADE5AD4`<R1>A0d_F4E6820a=S0PDT@P<SA5@d94<3DcAD8h<SU5
=3@d@S0e>DHi=D4aA3@aATE3<3E5@C8b@D4a>D@c=48e@C12<d<gAC8`<34b3D@b
<D<g<D4h>D92AS8i<SLh>4<c>38g=dHg<T4dAS55ASQ6=C0`<CE6=cDa<355AS96
>D4h>4A4<354>@e5@D4i<DE1<T95@SL`AS8h@CHbA3A5>34a<C<h<D=1=cTg@cH`
=SQ4=cQ2<3Lc@CTf@C@eAD4d=CLa<d8=A3A2=30d@T93@dE1@S8f=3@i=3DfAC<c
<SU3=S4h<T95AC@fAC=2=c=6=3=5<3U2<3Dc<D55AC@c@D@g3CE5=c<`=3Q6@C8a
@S96<SLb<44a<SPi=3Hh=S=2ACTh=3@f@cTf>4H`<T55=CLc<SLa<C4b=C4b=3Pf
=Pe4@dI5@S4a@cE4<c<`ADA6<T4f@B1>A0d_F4H`820b<CTPDT@P<SA5@d94<3Dc
AD8hAS0fA3HiAS15@cE5=4Df@c96=S0d<STcASE2@cLf<T4f<C@i=C8aATA3=c4`
=T4f3DHg@C<aA3Ti<SU6>3I1<c4gAC16A3<g=D@e@SPeA3@`<44d=CH`A353=30f
AC0i>C=3=c4e<3Le<cHdAPe5@cA5=CU3>C@c<CQ6@d55@cDf=S<i>48`=SPaADH`
AT4e<T53>DDf@S93>CDi@c4d>C8d<CQ5ATE1=34=AS12>44c=C12<4A4@c<cA3<g
@c0a@SQ1@S8d@CDhAC11>C@i=cHg=S0gASHd>3PhAT8h@c52@D4h=dA23D@cA3Di
>3PiAC=4=cU3=3<cA3D`ATDaAC91=S95=CPcA44d=dI2ASPiASM6A4@`=cP`=C8b
<cA2ACE1@@dd>3A6<3@a=dHbA3=3@d@iASLbA3<i<SM5A3@`>CI1=C0c=CU5ADA6
@C95=4<g<CTb=dE5A3@hAS51=SP=@DH`=c55ADI3<T4gAD@cAD4a>C11<SP`=c8g
@dE6A3D`@SM1>48a=D=6AC4i@D8g<3HgA4@g=T<`=T=53C@f=S<g=cTh<48a=dA1
<3M1>21>A0d_F4Ha820a=CDPDT@P<SA5@d94<3DcAD8h<SU5=3@d@S0e>DHi=D4a
A3@aATE3<3E5@C8b@D4a>D@c=48e@C12<d<gAC8`<34b3D@b<D<g<D4h>D92AS8i
<SLh>4<c>38g=dHg<T4dAS55ASQ6=C0`<CE6=cDa<355AS96>D4h>4A4<354>@e5
@D4i<DE1<T95@SL`AS8h@CHbA3A5>34a<C<h<D=1=cTg@cH`=SQ4=cQ2<3Lc@CTf
@C@eAD4d=CLa<d8=A3A2=30d@T93@dE1@S8f=3@i=3DfAC<c<SU3=S4h<T95AC@f
AC=2=c=6=3=5<3U2<3Dc<D55AC@c@D@g3CE5=c<`=3Q6@C8a@S96<SLb<44a<SPi
=3Hh=S<i@C8i@S=4=C92AT4i@S=5<4I3=d8h=cTi>C0a=3A2<@dgA4I1<CPaAS4c
84i43BmHAS8P834c=B1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=T<g>C8e<c8c=DE6
=3<g<T@b<C11<DDcAC0h=SI4>4=2A3Tb<3D`ASP=<TH`@S55=TA1<3Le=TE3>4H`
<T4`>38i=3Ph@D@a=4I2=d4fAT4i=c@d=d<e@S4a@d56=352<3Ld=S4d3D92=4I5
<D91ATHh=SDc@D@d>30e@TD`@C8f@c55@C12AT<`A34h=44iA4I5@cPeA4@g>D@g
AD@b<30e=Pdi@S8e@d4bA3E4<SM3@DA6=S4g=S15<cU4<DDd<D=3A44i=cTa>44e
@SE1AC@g>CDe@S11@S8c<CM3>44=ACDf<3Hf=cHa@d@h<TD`AS13@C8i<S91@SA4
<T5584i43BmHAS<P834d<R1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=T<g>C8e<c8c
=DE6=3<g<T@b<C11<DDcAC0h=SI4>4=2A3Tb<3D`ASP=<TH`@S55=TA1<3Le=TE3
>4H`<T4`>38i=3Ph@D@a=4I2=d4fAT4i=c@d=d<e@S4a@d56=352<3Ld=S4d3D92
=4I5<D91ATHh=SDc@D@d>30e@TD`@C8f@c55@C12AT<`A34h=44iA4I5@cPeA4@g
>D@gAD@b<30e=Pdi@S8e@d4bA3E4<SM3@DA6=S4g=S15<cU4<DDd<D=3A44i=cTa
>44e@SE1AC@g>CDe@S11<4Dd=SHiACL=@C8b>CDd=S<d@dE5=T8cASE4@SU3>CU2
A4I5@S8f<34h<DHh<48fASQ6A48PCT@=;eQ6=20P<C<e8594838dAD=2A30e<dE2
>3Le<d=1=4@f@cLi<SDc<S<eADHd<cLbA38a<44aAC=5<3Pf=T@h@d94>C8`=C16
>0dbAS12<DDfA44`=cDfAD<hAS0b@C0h<STd>3Q1A34dAT8g@CI6@CTg=3@g@cE2
<C53@DHd<D8`=c@f<C@=@T8dATDa@T56ASPf=C=1A3@h<3E2AC11<SI3<DE1<496
@c14<CPd@CU4ATE3>3E4A3LiA3M5A38`<3Df3CU2<SE3@C94=D@b=d=1A4Hf<CLf
<4Dc>D@aAC@a@d=4@CTg>C4h@CE2=D55=3Li=CE2<3DeAS8`=S52=Pe4ADI6>4<b
@S<fA452AS92@c0i<SM5=c0iATDe<c4PCT@=;eQ6=B0P<SHPDT@P<SA5@d94<3Dc
AD8f@c8aACM4=T<d>D8a<3La>CI1ATE2>3A3<d8a>C=3>CLg<313<CDa<b1>A0d_
F4Hf820c>B1BA20b=4E3@T@`=C=5@SU3@S8i=c93@S0i=D@f<315A4=1AC<f<cE5
>30b=CQ2>4E1<S12<dHi<4E1=C8e<TD=AS13<T8fACPg<48f=34h>4He84i43BmH
ASLP834`<21BA20b=4E3@T@`=C=5@SU3@S8i=c93@S0i@THf=SA5=CE6=c@h=C0a
@DDf@SQ6<c16<c4h>CU4A4He@C<`=3<==CE2ATHa@CA5=CA5A3Pi<D94<D94<cL`
<3@d>C4d=DH`<T<`=CDa@c8aAS<b@STa>3M2<D<h@dE2<CE63C=3@d96=SHf<S8g
@SA6>48`A3Tg<4I2=CI5@C0i@SA4=dA1=cTd=d94AS<`>4@b<C<b=D96=3U4>DE4
=Pe4=CU6<S8f@dHi@d=6=3Ph<dHb@R1>A0d_F4Hh820b=b1BA20b=4E3@T@`=C=5
@SU3@S8i=c93@S0iA3E1=CD`<30h>3M2=3@cA48i=S4c@T=3<C@i=4<e@T@PCT@=
;eQ6>B0P>C4PDT@P<SA5@d94<3DcAD8i@d8b>CLb@d8`>CQ3>3I6@C<b<494ASA3
A451@T4b@dE4@T@h=T91AD8c=dHcAS0h3C0f@T8bACPa<D<a=C14=T=6<cLd<C53
=c52A4A6=C=6AD92=CPc<CT`<c<b=CE5>3Tf=3Hb>3TcASHb@@dd@C8iA4De@SLc
<392@SQ6@c8i=cM5A3Q1>4Hh<3TaA3A2<3A3A4A5<DDiACPa<c8a=d4`ADHc<CTi
=d4=@STPCT@=;eQ6@B0P<SDPDT@P<SA5@d94<3DcAD8i@d8b>CLb@d8`>CHh>34i
@C8eAS92=D54=THd=D@bASP`ASTd=c@PCT@=;eQ6@R0P<C<b8594838dAD=2A30e
<dE2>D=2<STg<T=2<3TeA3H`=S<d<D51<48aASA2=S@h@S92<3Pi=c@e<cPa<cLb
<C@a<0e5@cM6<CA4>3Dd=CPh>DHi=C4a@cLb<C94A38dAD96A491<cA1ACM1=T<f
=S56<DE6@T52=C0g>4@i>CP=<3<cA3Pf<3@b=3U1>4@c@c93<d8h=c4eASPgAC8g
<38h>CHg=CLg<cHd<S51<4A2>3Hb>C4i@S<`=dHh3C4b<4@aATHc@cT`=S<d=T8d
>D93=SPd<S@`<dH`A3H`AS<iA34`=d@g@cU4@D=6>DI4>4Dc<T55@D@d@@db>C<d
>CI6>C<i>CDg=C<c=DI2>CLgA34PCT@=;eQ6@b0P>3PPDT@P<SA5@d94<3DcAD8i
@d8b>CLb@d8`>C<hA38i=cLe<T<i<cA6=SThAS<bAS4e>3I4@DA4=S53<4A4>C54
3C<`<SLgA30a<T=2AC13@cPe=STfAD94<C0g<3Db=3=4<3E2=d95=c<i@T<h<T@h
A4<d=S@f=C@e<cTi>@e1AC4i@S56A492<SD`@cU4=3Tf=4=2AS95>30a@SI1<3I3
@dHi@S8f=CI5ACTd@S<cASE3>C@dAR1>A0d_F4I4820d=B1BA20b=4E3@T@`=C=5
@SU3@S8i=c93@S0i=cLf>CA3=cDa>CA4ATI4AT@h@CTa=T94ACM1AT=1<c@d<T95
=dH=<dDh>3Q5@TI3<THi>C0d>38a=THeAC<i=SLb=C=184i43BmHATDP83Pb8594
838dAD=2A30e<dE2>D=2<STg<T=2<3Hg=C<b=T<g=d4g@d52=cLeAT4f<DI6>CLf
=dE1=C@d=cE6A451A0da<cHb=DE3=S4g=dI4=SDi>3A3@D4b>@00X@300?]5=S<b
AC55<S13<S0b@CQ4>34a>455<c12<3U6<d8h>3=6<cE63C15@CA5<CPc<SDeAT@`
>3Lb>DHiAS4h>3Tg=D4c=cTa<S=4<T4c=ST`<CU384i43BmHATHP83<i8594838d
AD=2A30e<dE2>D=2<STg<T=2<3TeA3H`<3=6ACM5>D<a<c0a=TA2ACU3A4<c<S@f
<S<`=c@h@DHd<`da>3<g@SDg<dHa>CHgAT@h<CLPCT@=IFiT3FE^I0e`MG@=L7Ed
3FAeL20_AVm^M4iQKFDPIfEd86EhHfPPI6EVJFiUIVm^M21`Kg0=9BE5KVABIG=_
MG9SIB0=3@00X@300L/_GemOATha82m7IFiUMV4P;dMUKVEfHB1TMG0PIVU^I6I_
KW@PI7E`82m3J65bDgAbJFiWLb1[KVmgKR1kHVEWJFhP@fQQLU=dLVU^Ig<P;d5T
JFEbIG=YLb1[KVmgKR1k;C4POG/]<GdPJFIUK7=U86E^I7dPNg1_L20]<GdPJFIU
K7=U879V3C0PJF@=<B1VI0d`83Hb87AbHFicK65dI@dc<30P;C<`<21cHfaY3BDU
AFiTDfEdMG0P3BDU@VEWJFi@HFMUDfEdMG0P3G1]3BDUAFiTD65WIE=UM7E`3Bm4
IGIYHfEBAd8PLf=c3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=830PK6<=838P
K6X=E21cH@dUL65WIB1bIF=d>R0d>B0d<cLP=38i83@i>B0=LgA]3C0P<20`86Hc
3Fi`3C<a<bhh<38h83@f=Bhg<C8h83Lf>Bhh<c4d83Db<bhe<CLg879`3FAU3C0P
<20`86Hc3C4g;S<f<C0P<CL^<cHa<21cL0da<Bhe86a]3B0`86aZ3Fi`3C<a<bhh
<38h83@f=Bhg<C8h83Lf>Bhh<c4d83Db<bhe<CLg879`3FAc3G9dK@d00:40`01h
LgA]3C0P<20`86Hc3Fi`3C8a<c4^=SPh>B0d=SD^=c4b>20b=CPg;SLa=cLP=C8c
;SDa=cLPLW0=I6D=<20`830PIS<=KW0=<S4c<Bhf>3Pi83@f=Bhg<C8h838e>3L^
=c4g=b0e<S<^=C4g=b1bL0eTL`ebM6d=0:40`01hLgA]3C0P<20`86Hc3Fi`3C<i
=S8^=38b=B0d=SD^=c4b>20d=34h;S@e<C4P=C8c;SDa=cLPLW0=I6D=<20`830P
IS<=KW0=<cTf<Rhd<S8e83@f=Bhg<C8h83@d<CP^=3Da<B0e<S<^=C4g=b1bL0eT
L`ebM6d=0:40`01hLgA]3C0P<20`86Hc3Fi`3CDg>30^<c0h=R0d=SD^=c4b>20f
<S<f;S<c=c@P=C8c;SDa=cLPLW0=I6D=<20`830PIS<=KW0==CLh<2hc<3Pf83@f
=Bhg<C8h83Hb<cH^<c<g=20e<S<^=C4g=b1bL0eTL`ebM6d=0:40`01oLgA]3C0^
=cPe<R0`;SLh=C8P<2hg>3Db86Hc3Fi`3CP^=SP`=B0e<SH^=c<g<b0f=CPf;S@b
=B0g<3H^=CT`>B1bL0eTI@d`830P<21V<`e^L0dh;SHh<3DP=C8f;SLc=c<P=SDh
=Rhd<SDP=c0f;SDi<3TPLW0=I7<=LWA]3@00X@3004acM6d=<2hc>C0f830^<cT`
=R0`;S<i<3HPIS<=KW0=>CP^=S4a<b0g<CT^=3@f<B0f=3Pc;SHd=b0a<3Hf;S<a
=21bL0eTI@ebM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=
<20`830PIS<=002Q0<00gG=dK@d`;SLd<30P<2h`<30`830^<30`<20`;SLd<30P
<Rhb=CHh830^<30`<21SL`db<3P^<c<b<b1VM7<=;emOGdI><B1SMW=V3C0P<20`
86Hc3DHPLf4=<c<e<Rhc<CHg834b=3T^>CTc=b1]M0dXIg9_MFiT871/HFiU:B1K
<C8g;S0e83P`;S@f834b=Rhb=20a<S4^=CHP<C8a;SDf834b=Bhd<b0f>Bhd>20a
<SD^=3<P=3P^>C<P<C4e;S8e834b<Bhe=R0`85dPN7=XKgL=E21cH@ebM6d=002Q
0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P
<21V<`d00:40`02/LgA]3C0^=c@`<20`;S0`<30P<2h`<30`830^=c@`<20b;S8e
=SPP<2h`<30`86=c3C4g<bhf<C0b86IdL`d_GemOATha86=fLfH=<20`830PIS<=
AR1cH@df=STb;SHg=3<P>3Pe;S@a<S8PKG@=:6]QL7A_KRTPFcTc;S@b83Tf;S0e
834`=2he<R0g=Rhi=b0a<3D^<S0P<21M87QcJ6mg3E@PLf4=LWA]3@2Q0<008c0P
<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00RW=dK@d`;SLd
<30P<2h`<30`830^<30`<20`;SLd<30P<Rhb=CHh830^<30`<21SL`d`830P<21V
<`e687=Q3CLb=c0^<C<a>20h>3D^=34b<R1]M0dX86I_JF`Y85/e=bhi<20f=bhg
<b0a<3D^<S0P=30^=cLP<21M87QcJ6mg3E@PLf4=LWA]3@2Q0<00179dK@d0X@30
02McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`02W
LgA]3C0^=c@`<20`;S0`<30P<2h`<30`830^=c@`<20b;S8e=SPP<2h`<30`86=c
3C8`>2hc<c8c86IdL`d_GemOATha86=fLfH=<20`830PIS<=AR1cH@dd<3L^>CPd
83@f>2hg=3Lf86ed3BPa<SDPG38f=BTPFc4c>2hh=B0a<cP^>3DP<C<h;SPe83Hi
;S@h830PGB1hLfQ_M`eD87=Q3G9dK@d00:40`004LWA]3@2Q0<009g=dK@d`830P
<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@3008icM6d=<2hg=30`
830^<30`<20`;S0`<30P<2hg=30`838^<SDf>20`;S0`<30PHg<=<20`830PIS<=
AR1cH@dd<C@`;SH`=20d=SP^=c@g=R1]M0dX<cLe85`b=SDY85/a<cP^>3DP<C<h
;SPe834c>2hh=B0f>Bhd>20`85dPN7=XKgL=E21cH@ebM6d=0:40`004LWA]3@2Q
0<00DG=dK@d`830P<21V<`da=bhc=S4`834g;S<f<C0PLg0=KW0=<cDh<2hb<CHg
838h<Rhf<cTf86ed3C<i<cT^>3Ta838h<Rhf<c4f86aY3FAc3@00X@3000=WL`d0
0:40`02`<20`830PIS<=KW0=<cLg=Rhf<S4P<S4d;SPb<SPPKG@=<cLg=Rhf<S4P
<S4d;SPb<SPP<cLd=Bhd>C@g838h<Rhb=c4d83<g=cL^<cHd83<e<2hd=3Pd86=d
3C<h<CL^<cPd=R0c<cL^>3@b>B0c>CL`;SLi=S@P<SPa;SDa=B0c>CL`;SLi=S@P
<SPa;SDa=B1SM0dc=cLf;SHb<B0b<C@^>38b>21/J@eSL0eTI@d0X@3000=WLPd0
0:40`004LWA]3@2Q0<00?g=dK@d`830P<21V<`e^L0dc<30b;S0i<38P<SPb;SHc
>CHPKG@=<SHd<Rhc=SLa838h<Rhf<cTf86aY3FAc3@00X@3000=WL`d00:40`02e
<20`830PIS<=KW0=<SLf<bha>34d838c<Rhd=CTd86ed3C8g=S<^<CPa=20b<c8^
=3Di=20b=cPf;S8a=CPP<SPb;S<g<C@P<SLf<Rhf<c<P<c<b;SPb<c8PHg@=<SLc
<bh`<CLd83<b<bhd>CDe838f<CT^=3Ta<B0b>34^>34d<b0b=S4i;S@i<C4P<SPa
;SPa=3<PHg@=<SLf<bha>34d838c<Rhd=CTd86aY3F=`3FAU3@00X@3000=WLPd0
0:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P
<20`86Hc3@00X@300:5cM6d=<2hg=30`830^<30`<20`;S0`<30P<2hg=30`838^
<SDf>20`;S0`<30PHg<=<CLc;SHa<38PIWAc3BmOGem6CS4PHgIcIPd`830P<21V
<`e687=Q3CHa=c4^>3@c=b0h>3D^=34b<R1]M0dX=C0PG38f=BTPFc4a=Bhg<B0a
<CD^=c4P=CL^>C0P<21M87QcJ6mg3E@PLf4=LWA]3@00X@3000AbM6d=0:40`00W
LgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00cG=d
K@d`;SLd<30P<2h`<30`830^<30`<20`;SLd<30P<Rhb=CHh830^<30`<21SL`db
<3P^<c<b<b1VM7<=;emOGdI><B1SMW=V3C0P<20`86Hc3DHPLf4==S<a<2hg<c4h
838`>2hc<c8c86ed3BQSKfiTMF=dKg9c:B1K<C4c;SHc834b=Rhb=20a<S4^=CHP
<C8e;S@c834b<Bhe=R0a<C<^=S<P>C8^<cLP<C8f;S8d83P`;S@f830PGB1hLfQ_
M`eD87=Q3G9dK@d00:40`004LWA]3@2Q0<00DW=dK@d`830P<21V<`da=bhc=S4`
834g;S<f<C0PLg0=KW0==3Hc<bhf>C4d834f=bh`<C@c86ed3C@b<3T^=SPc<b0c
>CP^<SDf>B1/J@eTL`d0X@3000=WL`d00:40`02e<20`830PIS<=KW0==3<h=Bhd
<S0h83<g>Bhf<S<c86ed3C@c>3D^=38`>20c=cT^=S8c<b0d<cP`;S@e=B0c<3D^
=C0d=R0d<c4i;SPc<cPP<SH`;ST`=c<PHg@==38i<2hg<c<b838i<Bha<cDb83@a
>3<^<34d=b0d<C@^<3<h<R0d<CPc;S0a=3LP=34d;S0c>38PHg@==3<h=Bhd<S0h
83<g>Bhf<S<c86aY3F=`3FAU3@00X@3000=WLPd00:40`004LWA]3@2Q0<00?W=d
K@d`830P<21V<`e^L0de=C@e;SPd=S<P<CDd;S4f=b1]M0df<30h;S8i>3HP=34a
;S4`=34PK6T=I7<=0:40`003Ig<=002Q0<00]C0P<20`86Hc3Fi`3CDh>CP^=3@b
=B0b=c8^=C<d<B1]M0de>3Th;S@d<SDP<SLb;SDc=34P=CPc>2hd=cDb83<a=Rhc
=cDd83Dh<c<^<S8`=B0c>C4^=3@i=21SM0de>3Ld;S<b=R0c>CT^>3Hh<B0f<3<e
;SLh=CHP=38e;S4d<38P=S0c=Bhg>3Df83@b=Bha=30b86=d3CDh>CP^=3@b=B0b
=c8^=C<d<B1/J@eSL0eTI@d00:40`003Ig8=002Q0<00179dK@d0X@3000YdIG9]
JFiQM6D=0:00_`2P0;h0VP000?n?X00000011P?X000010000000B00004P0000@
02000`08000000000002_N7H000000460nP000000@H3jP000321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0hPOn1oh7oPOn1oh7oPOoco`00POn1oh7oPOn1oh7oPOnJo`00POn1oh7o
POn1oh7oPOnJo`00Z?l0>87oPOn1oh7oPOn1oh7oloom087oPOn1oh7oPOn1oh7o
WOom087oPOn1oh7oPOn1oh7oWOom0:_o03R1oh7oPOn1oh7oPOn1oo?onP21oh7o
POn1oh7oPOn1oj3onP21oh7oPOn1oh7oPOn1oj3onP2^o`18Tooj087oPOn1oh7o
ROok087oi_og087o`ooj087oPOn1oh7oROok087oi_og087o`ooj087oPOn1oh7o
ROok087oi_og0;7o07:Yood0lOof0??ol`21oh7oPOn1ojWomP3gonh0n?oc09go
m021omcoo@3aooH0looc087oPOn1oh7oZOof0?OokP3hoo<0WOod087og?om0?7o
mP3coo<0POn1oh7oPOnYooH0moo^0?Sol`2Moo@0]?l0OZ_on`3boo@0m?oc087o
POn1oh7oo?om0;?om@3gonh0n?oc09kol@21on3on`3boo@0m?oc087oPOn1oh7o
o?om0;?om@3gonh0n?oc09kol@21on3on`3boo@0m?oc087oPOn1oh7oo?om0;?o
m@3gonh0n?oc09kol@2fo`2I[_oh0??oo03moo/0mOoc087oPOn1oh7o0OoonP2e
oo/0oOok0?WokP3hoo<0W_o^087oi_oh0??oo03moo/0mOoc087oPOn1oh7o0Ooo
nP2eoo/0oOok0?WokP3hoo<0W_o^087oi_oh0??oo03moo/0mOoc087oPOn1oh7o
0OoonP2eoo/0oOok0?WokP3hoo<0W_o^0;Wo09J^ooP0m?om0?Woo@3eooh0POn1
oh7oPOofooP0]Oom0?[oo03Yooh0n?on09?oj`21onWon03dood0nOom0?GooP21
oh7oPOn1ooKon02eood0n_ol0>WooP3hooh0Too[087ojOoh0?Coo@3iood0mOon
087oPOn1oh7om_oh0;Goo@3joo`0jOon0?SooP2Con/0_?l0XZkooP3nooh0m?om
0?Soo@3fooh0POn1oh7oPOoioo@0]_on0?Ooo@3/ood0moon09?oj021oncooP3n
ooh0m?om0?Soo@3fooh0POn1oh7oPOoioo@0]_on0?Ooo@3/ood0moon09?oj021
oncooP3nooh0m?om0?Soo@3fooh0POn1oh7oPOoioo@0]_on0?Ooo@3/ood0moon
09?oj02oo`2:[_l00?cooP3Wood0m_on087oPOn1oh7oo?oa0:Woo@3]ood0m_on
09Coi021onoo003looh0ioom0?KooP21oh7oPOn1oocol@2Yood0kOom0?KooP2D
on@0POo_o`00o?on0>Ooo@3fooh0POn1oh7oPOoloo40ZOom0>goo@3fooh0U?oT
0<;o086Xooh0ioom0?KooP21oh7oPOn1o`7oonh0ZOom0>goo@3fooh0U?oQ087o
k?on0>Ooo@3fooh0POn1oh7oPOl1ooo^0:Woo@3]ood0m_on09Coh@21oncooP3W
ood0m_on087oPOn1oh7o0OookP2Yood0kOom0?KooP2Don40aOl0Z:SooP3Wood0
m_on0>7oo@3hood0POn1oh7o/oo[0:[oo@3]ood0mOon0>7oo@3hood0aOoN087o
koon0>Ooo@3fooh0hOom0?Soo@21oh7oPOncon/0Z_om0>goo@3eooh0hOom0?So
o@35omh0POo_ooh0ioom0?KooP3Qood0n?om087oPOn1ok?oj`2Zood0kOom0?Go
oP3Qood0n?om0<GogP38o`2XZ?on0>OooP3eooh0hOom0?Soo@21oh7oPOnfonP0
Z_om0>goo@3eooh0hOom0?Soo@35om/0POobooh0ioon0?GooP3Qood0n?om087o
POn1okKoj02Zood0kOom0?GooP3Qood0n?om0<Gof`21oo;ooP3Wooh0mOon0>7o
o@3hood0POn1oh7o]_oX0:[oo@3]ood0mOon0>7oo@3hood0aOoK0<_o0:RXooh0
ioon0?GooP3Qood0nOol087oPOn1okSoiP2[ood0kOom0?CooP3Qood0nOol0<Ko
f021ooCooP3Wooh0mOon0>7oo@3ioo`0POn1oh7o^?oV0:_oo@3]ood0m?on0>7o
o@3ioo`0a_oH087om?on0>OooP3eooh0hOom0?Woo021oh7oPOnhonH0Zoom0>go
o@3dooh0hOom0?Woo036omP0cOl0Z:SooP3Yoo`0mOoi0>Ooo@3hood0POn1oh7o
^onZ0>Goo03]ooh0l_oi0>Ooo@3hood0lOnY087omoon0>Woo03eooT0ioom0?So
o@21oh7oPOnkojX0iOol0>gooP3booT0ioom0?Soo@3aojT0POogooh0jOol0?Go
n@3Wood0n?om087oPOn1ok_oZP3Uoo`0kOon0?;on@3Wood0n?om0?7oZ@3@o`2X
Z?on0>[oo03dooL0jOom0?Soo@21oh7oPOnmojP0j_oh0>cooP3booL0jOom0?So
o@3aojH0POojooh0j_ol0?Com`3Yood0n?om087oPOn1okgoZ03ZooP0k?on0?;o
m`3Yood0n?om0?7oYP21oo[ooP3Zoo`0m?og0>Woo@3hood0POn1oh7o_OnX0>[o
n03/ooh0l_og0>Woo@3hood0lOnV0=?o0:RXooh0j_om0??omP3Zood0n?om087o
POn1okooYP3ZooX0joom0?;omP3Zood0n?om0?7oY021oocooP3Zood0loof0>[o
o@3hood0POn1oh7o_onV0>[onP3[ood0l_of0>[oo@3hood0lOnT087oo?on0>[o
o@3cooH0j_om0?Soo@21oh7oPOnoojH0j_oj0>_oo@3booH0j_om0?Soo@3aoj@0
eOl0Z:SooP3]oo/0jook0>goo@3gooh0POn1oh7o^onY0>[om`3_ood0j_ok0>go
o@3gooh0l?nV087on_on0>gon`3[oo/0kOom0?OooP21oh7oPOnkojT0j_og0>oo
o@3Zoo/0kOom0?OooP3`ojH0POojooh0kOok0>_on`3]ood0moon087oPOn1ok_o
Z@3ZooL0koom0>[on`3]ood0moon0?3oYP3Co`2XZ?on0>goo03Yoo`0kOom0?Oo
oP21oh7oPOnhon<0[_ok0?7oo03Yoo`0kOom0?OooP34omD0POogooh0kOol0>Wo
o03]ood0moon087oPOn1okSoh`2^oo/0lOol0>Woo03]ood0moon0<Coe@21ooOo
oP3]oo`0jOol0>goo@3gooh0POn1oh7o^?oS0:kon`3aoo`0jOol0>goo@3gooh0
a?oE0=3o0:RXooh0k_ol0>Koo@3^ood0moon087oPOn1okKoi@2/oo`0l_om0>Ko
o@3^ood0moon0<Cof021ooCooP3^oo`0i_om0>koo@3gooh0POn1oh7o]_oU0:co
o03bood0i_om0>koo@3gooh0a?oH087om?on0>koo03Vood0k_om0?OooP21oh7o
POnfonD0[?ol0?;oo@3Vood0k_om0?OooP34omP0cOl0Z:SooP3`oo`0i?ol0>oo
o@3gooh0POn1oh7o/ooX0:_oo03cooh0iOol0>ooo@3gooh0a?oK087olOon0?3o
o03Too`0koom0?OooP21oh7oPOnconP0Zool0??ooP3Uoo`0koom0?OooP34om/0
POoaooh0l?ol0>Coo03_ood0moon087oPOn1ok?oj02[oo`0loon0>Goo03_ood0
moon0<Cof`3:o`2XZ?on0?3oo@3Soo`0koom0?Soo@21oh7oPOnaon/0ZOom0?Co
o@3Uoo`0koom0?Soo@34omd0POo_ooh0l?om0>?oo03_ood0n?om087oPOn1ok7o
j`2Yood0m?om0>Goo03_ood0n?om0<Cog@21onoooP3`ood0hool0>ooo@3hood0
POn1oh7o/Oo[0:Woo@3dood0iOol0>ooo@3hood0a?oM0<So0:RXooh0lOom0>7o
o@3_ooh0moom087oPOn1ojkokP2Xooh0m?om0>Coo@3_ooh0moom0<?oh@21onco
oP3aood0hOom0>oooP3good0POn1oh7o[_o^0:SooP3dood0i?om0>oooP3good0
`ooQ087ok?on0?7oo@3Qood0koon0?Ooo@21oh7oPOn^onh0Z?on0?Coo@3Tood0
koon0?Ooo@33on40aOl0Z:SooP3coo`0h?om0>oooP3good0POn1oh7oZooa0:So
oP3eood0hoom0>oooP3good0`ooS087oj_on0??oo03Pood0koon0?Ooo@21oh7o
POn[oo40Z?on0?Goo@3Sood0koon0?Ooo@33on<0POoZooh0lool0>3oo@3_ooh0
moom087oPOn1oj_ol@2Xooh0mOom0>?oo@3_ooh0moom0<?oh`33o`2XZ?on0??o
o@3Oood0koon0?Soo021oh7oPOnXooD0Yoon0?Koo03Sood0koon0?Soo033onH0
POoWooh0loom0=ooo@3_ooh0n?ol087oPOn1ojSom@2Wooh0m_ol0>?oo@3_ooh0
n?ol0<?oiP21onOooP3cood0goom0>oooP3hoo`0POn1oh7oZ?oe0:OooP3foo`0
hoom0>oooP3hoo`0`ooV0<3o0:RXooh0loon0=koo@3`ood0n?ol087oPOn1ojGo
n02Wooh0m_om0>;oo@3`ood0n?ol0<;oj@21onGooP3cooh0g_om0?3oo@3hoo`0
POn1oh7oYOoh0:OooP3food0h_om0?3oo@3hoo`0`_oY087oiOon0??ooP3Nood0
l?om0?Soo021oh7oPOnUooP0Yoon0?Koo@3Rood0l?om0?Soo032onT0__l0Z:So
oP3cooh0goom0>ooo@3hood0POn1oh7oXOok0:Soo@3food0hoom0>ooo@3hood0
`Oo/087oh_on0??ooP3Oood0koom0?Soo@21oh7oPOnQoo/0Z?om0?Koo@3Sood0
koom0?Soo@31on`0POoRooh0loon0=ooo@3_ood0n?om087oPOn1oj7on`2Xood0
m_om0>?oo@3_ood0n?om0<7ok02ko`3<Z?on0?Coo@3[ood0nOom0>ooo@3ioo`0
POn1oh7oWoon0;CooP3good0m_on0>koo@3iood0koom0?Woo031oo00POoNooh0
m?om0>_oo@3iood0koom0?Woo021oh7oPOnOooh0]?on0?Ooo@3fooh0k_om0?Wo
o@3_ood0nOol0<7ol021omkooP3dood0joom0?Woo@3_ood0nOol087oPOn1oioo
oP2dooh0moom0?KooP3^ood0nOom0>ooo@3ioo`0`Oo`0;Oo0<JXooh0m?om0>_o
o@3jood0k_om0?_onP21oh7oPOn1olooo@3joo`0mOon0>koo@3jood0k_om0?_o
nP30ooD0POoJooh0m?om0>_oo@3jood0k_om0?_onP21oh7oPOn1olooo@3joo`0
mOon0>koo@3jood0k_om0?_onP30ooD0POoJooh0m?om0>_oo@3jood0k_om0?_o
nP21oh7oPOn1olooo@3joo`0mOon0>koo@3jood0k_om0?_onP30ooD0/ol0gZSo
oP3donl0n?ol0?goo03_ooX0o_on003ooP21oh7oPOn1olkon`3lood0m?on0>go
o03moo`0kooj0?kooP00ooh0_oog087of?on0?Cok`3hoo`0oOol0>oonP3nooh0
0?on087oPOn1oh7oc_ok0?coo@3dooh0kOol0?goo03_ooX0o_on003ooP2oooL0
POoHooh0m?o_0?Soo03moo`0kooj0?kooP00ooh0POn1oh7oPOo>oo/0o?om0?Co
oP3]oo`0oOol0>oonP3nooh00?on0;oom`2ao`2XZ?on0?Cok`3hoo<0kooe007o
ooh0POn1oh7oPOo=oo<0m?on0>gol`3_ooD00OoooP2oooX0POoEooh0m?o_0?So
l`3_ooD00OoooP21oh7oPOn1olgol`3dooh0kOoc0>oom@01ooon0;oonP21omGo
oP3donl0n?oc0>oom@01ooon087oPOn1oh7ocOoc0?CooP3]oo<0kooe007oooh0
_ooj0:ko0::Xooh0m?o_0?Kon03/ooH0o_on087oPOn1oh7oboog0?;ooP3[ooP0
k?of0?kooP2nood0POoCooh0m?o_0?Kon03/ooH0o_on087oPOn1oh7oboog0?;o
oP3[ooP0k?of0?kooP2nood0POoCooh0m?o_0?Kon03/ooH0o_on087oPOn1oh7o
boog0?;ooP3[ooP0k?of0?kooP2nood0[?l0NX7onOok0>_oo@00ood0POn1oh7o
POo2ooX0eOok0>_oo@00ood0POn1omGon`3[ood00?om087oPOn1oh7o`_oj0=Go
n`3[ood00?om087oPOoEoo/0joom003oo@21oh7oPOn1ol;onP3Eoo/0joom003o
o@21omgo04B1omkoo@21oh7oPOn1oh7ok_om087oPOndood0POn1oh7oPOn1onko
o@21oh7o]?om087oPOn1oh7oPOo^ood0POoGo`14POoNood0POn1oh7oPOn1onko
o@21oh7o]?om087oPOn1oh7oPOo^ood0POn1okCoo@21oh7oPOn1oh7ok_om087o
eol0A87og_om087oPOn1oh7oPOo^ood0POn1okCoo@21oh7oPOn1oh7ok_om087o
POndood0POn1oh7oPOn1onkoo@21omOo04B1omkoo@21oh7oPOn1oh7ok_om087o
POndood0POn1oh7oPOn1onkoo@21oh7o]?om087oPOn1oh7oPOo^ood0POoGo`14
POoNooh0POn1oh7oPOn1ongooP21oh7o/oon087oPOn1oh7oPOo]ooh0POn1ok?o
oP21oh7oPOn1oh7okOon087oe_l0A87og_on087oPOn1oh7oPOo]ooh0POn1ok?o
oP21oh7oPOn1oh7okOon087oPOncooh0POn1oh7oPOn1ongooP21omKo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0?;CoS`21oh7o__n@087o
POnkom80]?n?087oPOnnoi00POn1ok_odP2dohl0POn1okkoT021oh7o^ooB000l
]?n?087oPOnnoi00POn1ok_odP2dohl0POn1okkoT021oh7o^ooB0;CoS`21oh7o
__n@087oPOnkom8003bdohl0POn1okkoT021oh7o^ooB0;CoS`21oh7o__n@087o
POnkom80]?n?087oPOnnoi00POn1ok_odP00?;CoS`21oh7o__n@087oPOnkom80
]?n?087oPOnnoi00POn1ok_odP2dohl0POn1okkoT021oh7o^ooB000l]?n?087o
POnnoi00POn1ok_odP2dohl0POn1okkoT021oh7o^ooB0;CoS`21oh7o__n@087o
POnkom8003bdohl0POn1okkoT021oh7o^ooB0;CoS`21oh7o__n@087oPOnkom80
]?n?087oPOnnoi00POn1ok_odP00?;CoS`21oh7o__n@087oPOnkom80]?n?087o
POnnoi00POn1ok_odP2dohl0POn1okkoT021oh7o^ooB000l]?n?087oPOnnoi00
POn1ok_odP2dohl0POn1okkoT021oh7o^ooB0;CoS`21oh7o__n@087oPOnkom80
03bdohl0POn1okkoT021oh7o^ooB0;CoS`21oh7o__n@087oPOnkom80]?n?087o
POnnoi00POn1ok_odP00?;CoS`21oh7o__n@087oPOnkom80]?n?087oPOnnoi00
POn1ok_odP2dohl0POn1okkoT021oh7o^ooB000l]?n?087oPOnnoi00POn1ok_o
dP2dohl0POn1okkoT021oh7o^ooB0;CoS`21oh7o__n@087oPOnkom8003bdohl0
POn1okkoT021oh7o^ooB0;CoS`21oh7o__n@087oPOnkom80]?n?087oPOnnoi00
POn1ok_odP00?;CoS`21oh7o__n@087oPOnkom80]?n?087oPOnnoi00POn1ok_o
dP2dohl0POn1okkoT021oh7o^ooB000l]?n?087oPOnnoi00POn1ok_odP2dohl0
POn1okkoT021oh7o^ooB0;CoS`21oh7o__n@087oPOnkom8003bdohl0POn1okko
T021oh7o^ooB0;CoS`21oh7o__n@087oPOnkom80]?n?087oPOnnoi00POn1ok_o
dP00=_goP@210840P@210840P@2M0?goP@210840P@210840P@2M0?goP@210840
P@210840P@2M000foOn10840P@210840P@2109d0oOn10840P@210840P@2109d0
oOn10840P@210840P@2109d003Kmoh40P@210840P@210840W@3moh40P@210840
P@210840W@3moh40P@210840P@210840W@00=_goP@210840P@210840P@2M0?go
P@210840P@210840P@2M0?goP@210840P@210840P@2M000loOom0878PLR1b878
PLR1b878XLSmood0PLR1b878PLR1b878PLRQb?goo@21b878PLR1b878PLR1b:78
03cmood0PLR1b878PLR1b878PLRQb?goo@21b878PLR1b878PLR1b:78oOom0878
PLR1b878PLR1b878XLP0??goo@21b878PLR1b878PLR1b:78oOom0878PLR1b878
PLR1b878XLSmood0PLR1b878PLR1b878PLRQb00loOom0878PLR1b878PLR1b878
XLSmood0PLR1b878PLR1b878PLRQb?goo@21b878PLR1b878PLR1b:7803cmood0
PLR1b878PLR1b878PLRQb?goo@21b878PLR1b878PLR1b:78oOom0878PLR1b878
PLR1b878XLP0??goo@21b878PLR1b878PLR1b:78oOom0878PLR1b878PLR1b878
XLSmood0PLR1b878PLR1b878PLRQb00loOom0878PLR1b878PLR1b878XLSmood0
PLR1b878PLR1b878PLRQb?goo@21b878PLR1b878PLR1b:7803cmood0PLR1b878
PLR1b878PLRQb?goo@21b878PLR1b878PLR1b:78oOom0878PLR1b878PLR1b878
XLP0??goo@21b878PLR1b878PLR1b:78oOom0878PLR1b878PLR1b878XLSmood0
PLR1b878PLR1b878PLRQb00loOom0878PLR1b878PLR1b878XLSmood0PLR1b878
PLR1b878PLRQb?goo@21b878PLR1b878PLR1b:7803cmood0PLR1b878PLR1b878
PLRQb?goo@21b878PLR1b878PLR1b:78oOom0878PLR1b878PLR1b878XLP0??go
o@21b878PLR1b878PLR1b:78oOom0878PLR1b878PLR1b878XLSmood0PLR1b878
PLR1b878PLRQb00loOom0878PLR1b878PLR1b878XLSmood0PLR1b878PLR1b878
PLRQb?goo@21b878PLR1b878PLR1b:7803cmood0PLR1b878PLR1b878PLRQb?go
o@21b878PLR1b878PLR1b:78oOom0878PLR1b878PLR1b878XLP0??goo@21b878
PLR1b878PLR1b:78oOom0878PLR1b878PLR1b878XLSmood0PLR1b878PLR1b878
PLRQb00loOom0878PLR1b878PLR1b878XLSmood0PLR1b878PLR1b878PLRQb?go
o@21b878PLR1b878PLR1b:7803cmood0PLR1b878PLR1b878PLRQb?goo@21b878
PLR1b878PLR1b:78oOom0878PLR1b878PLR1b878XLP0??goo@21b878PLR1b878
PLR1b:78oOom0878PLR1b878PLR1b878XLSmood0PLR1b878PLR1b878PLRQb00l
oOom0878PLR1b878PLR1b878XLSmood0PLR1b878PLR1b878PLRQb?goo@21b878
PLR1b878PLR1b:7803cmood0PLR1b878PLR1b878PLRQb?goo@21b878PLR1b878
PLR1b:78oOom0878PLR1b878PLR1b878XLP0??goo@21b878PLR1b878PLR1b:78
oOom0878PLR1b878PLR1b878XLSmood0PLR1b878PLR1b878PLRQb00loOom0878
PLR1b878PLR1b878XLSmood0PLR1b878PLR1b878PLRQb?goo@21b878PLR1b878
PLR1b:7803cmood0PLR1b878PLR1b878PLRQb?goo@21b878PLR1b878PLR1b:78
oOom0878PLR1b878PLR1b878XLP0??goo@21b878PLR1b878PLR1b:78oOom0878
PLR1b878PLR1b878XLSmood0PLR1b878PLR1b878PLRQb00loOom0878PLR1b878
PLR1b878XLSmood0PLR1b878PLR1b878PLRQb?goo@21b878PLR1b878PLR1b:78
03cmood0PLR1b878PLR1b878PLRQb?goo@21b878PLR1b878PLR1b:78oOom0878
PLR1b878PLR1b878XLP0??goo@21b878PLR1b878PLR1b:78oOom0878PLR1b878
PLR1b878XLSmood0PLR1b878PLR1b878PLRQb00loOom0878PLR1b878PLR1b878
XLSmood0PLR1b878PLR1b878PLRQb?goo@21b878PLR1b878PLR1b:7803cmood0
PLR1b878PLR1b878PLRQb?goo@21b878PLR1b878PLR1b:78oOom0878PLR1b878
PLR1b878XLP0??goo@21b878PLR1b878PLR1b:78oOom0878PLR1b878PLR1b878
XLSmood0PLR1b878PLR1b878PLRQb00loOom0878PLR1b878PLR1b878XLSmood0
PLR1b878PLR1b878PLRQb?goo@21b878PLR1b878PLR1b:7803cmood0PLR1b878
PLR1b878PLRQb?goo@21b878PLR1b878PLR1b:78oOom0878PLR1b878PLR1b878
XLP0??goo@21b878PLR1b878PLR1b:78oOom0878PLR1b878PLR1b878XLSmood0
PLR1b878PLR1b878PLRQb00loOom0878PLR1b878PLR1b878XLSmood0PLR1b878
PLR1b878PLRQb?goo@21b878PLR1b878PLR1b:7803cmood0PLR1b878PLR1b878
PLRQb?goo@21b878PLR1b878PLR1b:78oOom0878PLR1b878PLR1b878XLP0??go
o@21b878PLR1b878PLR1b:78oOom0878PLR1b878PLR1b878XLSmood0PLR1b878
PLR1b878PLRQb00loOom0878PLR1b878PLR1b878XLSmood0PLR1b878PLR1b878
PLRQb?goo@21b878PLR1b878PLR1b:7803cmood0PLR1b878PLR1b878PLRQb?go
o@21b878PLR1b878PLR1b:78oOom0878PLR1b878PLR1b878XLP0??goo@21b878
PLR1b878PLR1b:78oOom0878PLR1b878PLR1b878XLSmood0PLR1b878PLR1b878
PLRQb00foOn10840P@210840P@2109d0oOn10840P@210840P@2109d0oOn10840
P@210840P@2109d003Kmoh40P@210840P@210840W@3moh40P@210840P@210840
W@3moh40P@210840P@210840W@00=_goP@210840P@210840P@2M0?goP@210840
P@210840P@2M0?goP@210840P@210840P@2M000foOn10840P@210840P@2109d0
oOn10840P@210840P@2109d0oOn10840P@210840P@2109d00321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0=^GoPFB1I85T
PFB1I85TPFBeI>GoPFB1I85TPFB1I85TPFBeI>GoPFB1I85TPFB1I85TPFBeI00f
iOn1I85TPFB1I85TPFB1I;ETiOn1I85TPFB1I85TPFB1I;ETiOn1I85TPFB1I85T
PFB1I;ET03KUoh5TPFB1I85TPFB1I85T]FCUoh5TPFB1I85TPFB1I85T]FCUoh5T
PFB1I85TPFB1I85T]F@0=^GoPFB1I85TPFB1I85TPFBeI>GoPFB1I85TPFB1I85T
PFBeI>GoPFB1I85TPFB1I85TPFBeI00fiOn1I85TPFB1I85TPFB1I;ETiOn1I85T
PFB1I85TPFB1I;ETiOn1I85TPFB1I85TPFB1I;ET03KUoh5TPFB1I85TPFB1I85T
]FCUoh5TPFB1I85TPFB1I85T]FCUoh5TPFB1I85TPFB1I85T]F@0=^GoPFB1I85T
PFB1I85TPFBeI>GoPFB1I85TPFB1I85TPFBeI>GoPFB1I85TPFB1I85TPFBeI00f
iOn1I85TPFB1I85TPFB1I;ETiOn1I85TPFB1I85TPFB1I;ETiOn1I85TPFB1I85T
PFB1I;ET03KUoh5TPFB1I85TPFB1I85T]FCUoh5TPFB1I85TPFB1I85T]FCUoh5T
PFB1I85TPFB1I85T]F@0=^GoPFB1I85TPFB1I85TPFBeI>GoPFB1I85TPFB1I85T
PFBeI>GoPFB1I85TPFB1I85TPFBeI00fiOn1I85TPFB1I85TPFB1I;ETiOn1I85T
PFB1I85TPFB1I;ETiOn1I85TPFB1I85TPFB1I;ET03KUoh5TPFB1I85TPFB1I85T
]FCUoh5TPFB1I85TPFB1I85T]FCUoh5TPFB1I85TPFB1I85T]F@0=^GoPFB1I85T
PFB1I85TPFBeI>GoPFB1I85TPFB1I85TPFBeI>GoPFB1I85TPFB1I85TPFBeI00f
iOn1I85TPFB1I85TPFB1I;ETiOn1I85TPFB1I85TPFB1I;ETiOn1I85TPFB1I85T
PFB1I;ET03KUoh5TPFB1I85TPFB1I85T]FCUoh5TPFB1I85TPFB1I85T]FCUoh5T
PFB1I85TPFB1I85T]F@0=^GoPFB1I85TPFB1I85TPFBeI>GoPFB1I85TPFB1I85T
PFBeI>GoPFB1I85TPFB1I85TPFBeI00fiOn1I85TPFB1I85TPFB1I;ETiOn1I85T
PFB1I85TPFB1I;ETiOn1I85TPFB1I85TPFB1I;ET03KUoh5TPFB1I85TPFB1I85T
]FCUoh5TPFB1I85TPFB1I85T]FCUoh5TPFB1I85TPFB1I85T]F@0=^GoPFB1I85T
PFB1I85TPFBeI>GoPFB1I85TPFB1I85TPFBeI>GoPFB1I85TPFB1I85TPFBeI00f
iOn1I85TPFB1I85TPFB1I;ETiOn1I85TPFB1I85TPFB1I;ETiOn1I85TPFB1I85T
PFB1I;ET04SUoh5TPFB1I85TPFC=I?h0fFCm085TV6CUoh5TPFB1I85TPFC=I?h0
fFCm085TV6CUoh5TPFB1I85TPFC=I?h0fFCm085TV6@0B>GoPFB1I85TPFB1I<eT
oP3II?d0PFBHI>GoPFB1I85TPFB1I<eToP3II?d0PFBHI>GoPFB1I85TPFB1I<eT
oP3II?d0PFBHI018iOn1I85TPFB1I85TcFCn0=UTo@21I9QTiOn1I85TPFB1I85T
cFCn0=UTo@21I9QTiOn1I85TPFB1I85TcFCn0=UTo@21I9QT04SUoh5TPFB1I85T
PFC=I?h0fFCm085TV6CUoh5TPFB1I85TPFC=I?h0fFCm085TV6CUoh5TPFB1I85T
PFC=I?h0fFCm085TV6@0B>GoPFB1I85TPFB1I<eToP3II?d0PFBHI>GoPFB1I85T
PFB1I<eToP3II?d0PFBHI>GoPFB1I85TPFB1I<eToP3II?d0PFBHI018iOn1I85T
PFB1I85TcFCn0=UTo@21I9QTiOn1I85TPFB1I85TcFCn0=UTo@21I9QTiOn1I85T
PFB1I85TcFCn0=UTo@21I9QT04SUoh5TPFB1I85TPFC=I?h0fFCm085TV6CUoh5T
PFB1I85TPFC=I?h0fFCm085TV6CUoh5TPFB1I85TPFC=I?h0fFCm085TV6@0B>Go
PFB1I85TPFB1I<eToP3II?d0PFBHI>GoPFB1I85TPFB1I<eToP3II?d0PFBHI>Go
PFB1I85TPFB1I<eToP3II?d0PFBHI02^iOn1I85TPFB1I;eTo03/I?h0nFCk0=UT
o03bI?`0oFCn0>QTo03gI?d0n6Ck0?1To03cI?`0PFC@I>GoPFB1I85TPFBmI?`0
k6Cn0?UTn`3II?`0lVCl0?eToP3XI?`0mfCm0?QTn`3`I?`0lfCl085Td6CUoh5T
PFB1I85T_FCl0>aToP3iI?/0fFCl0?9To03mI?h0j6Cl0?MTo@3hI?/0l6Cl0?=T
o021I=1T0@GUoh5TPFB1I85T_fCi0?iToP3kI?d00FATo03kI?P0mVCm0?QTo@3m
I?d0oVCj0?ITn@3nI?h0l6Cm0?iTnP3hI?d0nfCf0?UTo@3nI?X0mfCh085TdVCU
oh5TPFB1I85T_fCi0?iToP3kI?d00FATo03kI?P0mVCm0?QTo@3mI?d0oVCj0?IT
n@3nI?h0l6Cm0?iTnP3hI?d0nfCf0?UTo@3nI?X0mfCh085TdVCUoh5TPFB1I85T
_fCi0?iToP3kI?d00FATo03kI?P0mVCm0?QTo@3mI?d0oVCj0?ITn@3nI?h0l6Cm
0?iTnP3hI?d0nfCf0?UTo@3nI?X0mfCh085TdV@0j^GoPFB1I85TPFC1I?D006Cn
0?]To@00I?/0oFCd0?QTo@3hI?d0oFCb0?QTmP00I?h0l6Cm001TmP3jI?d0o6Cd
0?YTlP3jI?@0PFCDI>GoPFB1I85TPFC1I?D006Cn0?]To@00I?/0oFCd0?QTo@3h
I?d0oFCb0?QTmP00I?h0l6Cm001TmP3jI?d0o6Cd0?YTlP3jI?@0PFCDI>GoPFB1
I85TPFC1I?D006Cn0?]To@00I?/0oFCd0?QTo@3hI?d0oFCb0?QTmP00I?h0l6Cm
001TmP3jI?d0o6Cd0?YTlP3jI?@0PFCDI04niOn1I85TPFB1I<5To03mI?h006Cn
0?]Tn@3kI?`0o6Cl0?UTo@3hI?d0oFCj0?iTo03iI?`0oFCn001ToP3`I?d00V@0
0?eTo03jI?d0oFCl0?eTo03jI?X0oVCl0?]Tn`3nI?`0PFCDI>GoPFB1I85TPFC1
I?`0oFCn001ToP3kI?T0nfCl0?aTo03iI?d0n6Cm0?eTnP3nI?`0nFCl0?eToP00
I?h0l6Cm009T003mI?`0nVCm0?eTo03mI?`0nVCj0?iTo03kI?/0oVCl085Te6CU
oh5TPFB1I85T`FCl0?eToP00I?h0nfCi0?]To03lI?`0nFCm0?QTo@3mI?X0oVCl
0?UTo03mI?h006Cn0?1To@02I000oFCl0?YTo@3mI?`0oFCl0?YTnP3nI?`0nfCk
0?iTo021I=AT0A[Uoh5TPFB1I85T`VCl0?]Tn`3kI?/0nVCk0?]To03jI?d0n6Cm
0?eTn`3kI?h0nVCl0?]Tn`3`I?/0nVCm0?]To@3mI?d0nVCm0?]Tn`3kI?h0nfCl
0?]ToP21I=ATiOn1I85TPFB1I<9To03kI?/0nfCk0?YTn`3kI?`0nVCm0?QTo@3m
I?/0nfCn0?YTo03kI?/0l6Ck0?YTo@3kI?d0oFCm0?YTo@3kI?/0nfCn0?]To03k
I?h0PFCDI>GoPFB1I85TPFC2I?`0nfCk0?]Tn`3jI?/0nfCl0?YTo@3hI?d0oFCk
0?]ToP3jI?`0nfCk0?1Tn`3jI?d0nfCm0?eTo@3jI?d0nfCk0?]ToP3kI?`0nfCn
085Te6@16^GoPFB1I85TPFC3I?`0nFCl0?]To03iI?d0n6Cm0?YTo@3hI?d0oFCl
0?YTo@3kI?d0nFCl0?1To03iI?`0o6Cm0?iTo@3iI?d0nfCl0?YTo@3lI?h0nFCm
085TeFCUoh5TPFB1I85T`fCl0?UTo03kI?`0nFCm0?QTo@3jI?d0n6Cm0?eTo03j
I?d0nfCm0?UTo03`I?`0nFCl0?aTo@3nI?d0nFCm0?]To03jI?d0o6Cn0?UTo@21
I=ETiOn1I85TPFB1I<=To03iI?`0nfCl0?UTo@3hI?d0nVCm0?QTo@3mI?`0nVCm
0?]To@3iI?`0l6Cl0?UTo03lI?d0oVCm0?UTo@3kI?`0nVCm0?aToP3iI?d0PFCE
I04>iOn1I85TPFB1I<=To@3gI?d0nfCl0?UToP3fI?h0nVCm0?QTo@3mI?d0nFCm
0?]ToP3gI?d0l6Cl0?QTo@3lI?d0lVCm0?]To@3iI?d0oFCm0?UTo@21I=ETiOn1
I85TPFB1I<=To@3gI?d0nfCl0?UToP3fI?h0nVCm0?QTo@3mI?d0nFCm0?]ToP3g
I?d0l6Cl0?QTo@3lI?d0lVCm0?]To@3iI?d0oFCm0?UTo@21I=ETiOn1I85TPFB1
I<=To@3gI?d0nfCl0?UToP3fI?h0nVCm0?QTo@3mI?d0nFCm0?]ToP3gI?d0l6Cl
0?QTo@3lI?d0lVCm0?]To@3iI?d0oFCm0?UTo@21I=ET0@kUoh5TPFB1I85T`fCn
0?EToP3kI?d0nFCm0?ITo@3kI?d0n6Cm0?eTo@3iI?d0o6Cm0?IToP3`I?`0mfCm
0?eTo@3bI?d0nfCm0?UTo@3mI?d0n6Cm085TeVCUoh5TPFB1I85T`fCn0?EToP3k
I?d0nFCm0?ITo@3kI?d0n6Cm0?eTo@3iI?d0o6Cm0?IToP3`I?`0mfCm0?eTo@3b
I?d0nfCm0?UTo@3mI?d0n6Cm085TeVCUoh5TPFB1I85T`fCn0?EToP3kI?d0nFCm
0?ITo@3kI?d0n6Cm0?eTo@3iI?d0o6Cm0?IToP3`I?`0mfCm0?eTo@3bI?d0nfCm
0?UTo@3mI?d0n6Cm085TeV@13^GoPFB1I85TPFC3I?h0mFCn0?]To@3iI?d0mFCn
0?]To@3hI?d0oFCm0?UTo@3lI?d0mVCn0?1To@3fI?d0oFCm0?9To@3kI?d0nFCm
0?iTo@3gI?d0PFCFI>GoPFB1I85TPFC3I?h0mFCn0?]To@3iI?d0mFCn0?]To@3h
I?d0oFCm0?UTo@3lI?d0mVCn0?1To@3fI?d0oFCm0?9To@3kI?d0nFCm0?iTo@3g
I?d0PFCFI>GoPFB1I85TPFC3I?h0mFCn0?]To@3iI?d0mFCn0?]To@3hI?d0oFCm
0?UTo@3lI?d0mVCn0?1To@3fI?d0oFCm0?9To@3kI?d0nFCm0?iTo@3gI?d0PFCF
I042iOn1I85TPFB1I<=ToP3eI?h0nfCm0?UTo@3eI?h0nfCm0?QTo@3mI?d0nFCm
0?aTo@3fI?h0l6Cm0?ITo@3mI?d0lfCl0?]To@3iI?d0oVC_085TeVCUoh5TPFB1
I85T`fCn0?EToP3kI?d0nFCm0?EToP3kI?d0n6Cm0?eTo@3iI?d0o6Cm0?IToP3`
I?d0mVCm0?eTo@3cI?`0nfCm0?UTo@3nI>l0PFCFI>GoPFB1I85TPFC3I?h0mFCn
0?]To@3iI?d0mFCn0?]To@3hI?d0oFCm0?UTo@3lI?d0mVCn0?1To@3fI?d0oFCm
0?=To03kI?d0nFCm0?iTk`21I=IT0@;Uoh5TPFB1I85T`fCn0?EToP3kI?d0nFCm
0?EToP3kI?d0n6Cm0?eTo@3iI?d0o6Cm0?IToP3`I?d0mVCm0?eTo@3hI?L0nfCm
0?UTo@3nI>l0PFCFI>GoPFB1I85TPFC3I?h0mFCn0?]To@3iI?d0mFCn0?]To@3h
I?d0oFCm0?UTo@3lI?d0mVCn0?1To@3fI?d0oFCm0?QTm`3kI?d0nFCm0?iTk`21
I=ITiOn1I85TPFB1I<=ToP3eI?h0nfCm0?UTo@3eI?h0nfCm0?QTo@3mI?d0nFCm
0?aTo@3fI?h0l6Cm0?ITo@3mI?d0n6Cg0?]To@3iI?d0oVC_085TeV@10^GoPFB1
I85TPFC3I?h0mFCn0?]To@3iI?d0mFCn0?]To@3hI?d0oFCm0?UTo@3lI?d0mVCn
0?1To@3fI?d0oFCm0?]Tm03kI?d0nFCm0?iTk`21I=ITiOn1I85TPFB1I<=ToP3e
I?h0nfCm0?UTo@3eI?h0nfCm0?QTo@3mI?d0nFCm0?aTo@3fI?h0l6Cm0?ITo@3m
I?d0nfCd0?]To@3iI?d0oVC_085TeVCUoh5TPFB1I85T`fCn0?EToP3kI?d0nFCm
0?EToP3kI?d0n6Cm0?eTo@3iI?d0o6Cm0?IToP3`I?d0mVCm0?eTo@3kI?@0nfCm
0?UTo@3nI>l0PFCFI04>iOn1I85TPFB1I<=ToP3eI?h0nfCm0?UTo@3eI?h0nfCm
0?QTo@3mI?d0nFCm0?aTo@3fI?h0l6Cm0?ITo@3mI?d0nfCi001To@3kI?d0nFCm
0?iTo@21I<QTiOn1I85TPFB1I<=ToP3eI?h0nfCm0?UTo@3eI?h0nfCm0?QTo@3m
I?d0nFCm0?aTo@3fI?h0l6Cm0?ITo@3mI?d0nfCi001To@3kI?d0nFCm0?iTo@21
I<QTiOn1I85TPFB1I<=ToP3eI?h0nfCm0?UTo@3eI?h0nfCm0?QTo@3mI?d0nFCm
0?aTo@3fI?h0l6Cm0?ITo@3mI?d0nfCi001To@3kI?d0nFCm0?iTo@21I<QT0@kU
oh5TPFB1I85T`fCn0?ITo@3kI?d0nFCm0?EToP3kI?d0n6Cm0?eTo@3iI?d0o6Cm
0?IToP3`I?d0mVCm0?eTo@3mI?`0nfCm0?]To@3iI?d0oVCm085Tb6CUoh5TPFB1
I85T`fCn0?ITo@3kI?d0nFCm0?EToP3kI?d0n6Cm0?eTo@3iI?d0o6Cm0?IToP3`
I?d0mVCm0?eTo@3mI?`0nfCm0?]To@3iI?d0oVCm085Tb6CUoh5TPFB1I85T`fCn
0?ITo@3kI?d0nFCm0?EToP3kI?d0n6Cm0?eTo@3iI?d0o6Cm0?IToP3`I?d0mVCm
0?eTo@3mI?`0nfCm0?]To@3iI?d0oVCm085Tb6@13^GoPFB1I85TPFC3I?d0mfCm
0?]To@3iI?d0mVCm0?]To@3hI?d0oFCm0?UTo@3lI?d0mfCm0?1To@3fI?d0oFCm
0?eTo@3jI?d0nfCm0?UTo@3nI?d0PFC8I>GoPFB1I85TPFC3I?d0mfCm0?]To@3i
I?d0mVCm0?]To@3hI?d0oFCm0?UTo@3lI?d0mfCm0?1To@3fI?d0oFCm0?eTo@3j
I?d0nfCm0?UTo@3nI?d0PFC8I>GoPFB1I85TPFC3I?d0mfCm0?]To@3iI?d0mVCm
0?]To@3hI?d0oFCm0?UTo@3lI?d0mfCm0?1To@3fI?d0oFCm0?eTo@3jI?d0nfCm
0?UTo@3nI?d0PFC8I04>iOn1I85TPFB1I<=To@3gI?d0nfCm0?QToP3fI?h0nVCm
0?UTo03mI?d0nFCm0?]ToP3gI?d0l6Cl0?QTo@3lI?d0oVCl0?YTo@3kI?d0nFCm
0?eTo@21I<UTiOn1I85TPFB1I<=To@3gI?d0nfCm0?QToP3fI?h0nVCm0?UTo03m
I?d0nFCm0?]ToP3gI?d0l6Cl0?QTo@3lI?d0oVCl0?YTo@3kI?d0nFCm0?eTo@21
I<UTiOn1I85TPFB1I<=To@3gI?d0nfCm0?QToP3fI?h0nVCm0?UTo03mI?d0nFCm
0?]ToP3gI?d0l6Cl0?QTo@3lI?d0oVCl0?YTo@3kI?d0nFCm0?eTo@21I<UT0A[U
oh5TPFB1I85T`VCm0?YTn`3kI?d0n6Cm0?QTo@3jI?d0nVCk0?eTo@3iI?d0nfCn
0?QTo03`I?`0nFCl0?aTo@3nI?d0nFCm0?]To@3iI?d0oFCm0?QTo@21I=ITiOn1
I85TPFB1I<9To@3jI?/0nfCm0?QTo@3hI?d0nVCm0?YTn`3mI?d0nFCm0?]ToP3h
I?`0l6Cl0?UTo03lI?d0oVCm0?UTo@3kI?d0nFCm0?eTo@3hI?d0PFCFI>GoPFB1
I85TPFC2I?d0nVCk0?]To@3hI?d0n6Cm0?YTo@3jI?/0oFCm0?UTo@3kI?h0n6Cl
0?1To03iI?`0o6Cm0?iTo@3iI?d0nfCm0?UTo@3mI?d0n6Cm085TeV@16^GoPFB1
I85TPFC2I?`0nfCk0?]To@3hI?`0nVCl0?YTo03kI?/0oFCm0?UTo@3kI?d0nFCl
0?1To03iI?d0nfCm0?iTo@3jI?`0nfCm0?UTo@3lI?d0nFCm085TeVCUoh5TPFB1
I85T`VCl0?]Tn`3kI?d0n6Cl0?YTo03jI?`0nfCk0?eTo@3iI?d0nfCm0?UTo03`
I?`0nFCm0?]To@3nI?d0nVCl0?]To@3iI?d0o6Cm0?UTo@21I=ITiOn1I85TPFB1
I<9To03kI?/0nfCm0?QTo03jI?`0nVCl0?]Tn`3mI?d0nFCm0?]To@3iI?`0l6Cl
0?UTo@3kI?d0oVCm0?YTo03kI?d0nFCm0?aTo@3iI?d0PFCFI04ViOn1I85TPFB1
I<5To03mI?h006Cn0?]To@3hI?/0nfCl0?UTo@3kI?/0oFCm0?UTo@3kI?`0nfCk
0?1Tn`3jI?d0nfCm0?iTo03lI?/0nfCm0?UTo@3lI?`0nfCm085TeFCUoh5TPFB1
I85T`FCl0?eToP00I?h0nfCm0?QTn`3kI?`0nFCm0?]Tn`3mI?d0nFCm0?]To03k
I?/0l6Ck0?YTo@3kI?d0oVCl0?aTn`3kI?d0nFCm0?aTo03kI?d0PFCEI>GoPFB1
I85TPFC1I?`0oFCn001ToP3kI?d0n6Ck0?]To03iI?d0nfCk0?eTo@3iI?d0nfCl
0?]Tn`3`I?/0nVCm0?]To@3nI?`0o6Ck0?]To@3iI?d0o6Cl0?]To@21I=ET0?WU
oh5TPFB1I85T`6Cg005TI?h0nfCm0?ITm03gI?H006Cm0?eTo@3iI?d0nFCf001T
oP3`I?d006Cf0?YTo@3mI?80nfCm0?UTo@3kI?@0PFCDI>GoPFB1I85TPFC0I?L0
0FAToP3kI?d0mVCd0?MTmP00I?d0oFCm0?UTo@3iI?H006Cn0?1To@00I?H0nVCm
0?eTlP3kI?d0nFCm0?]Tm021I=ATiOn1I85TPFB1I<1Tm`01I6Cn0?]To@3fI?@0
mfCf001To@3mI?d0nFCm0?UTmP00I?h0l6Cm001TmP3jI?d0oFCb0?]To@3iI?d0
nfCd085Te6@12>GoPFB1I85TPFBoI?T0oVCn0?]To@3eI?D0mVCh005TI?d0oFCm
0?UTo@3hI?P00FAToP3`I?d006Cg0?UTo@3lI?P006Cl0?aTo@3iI?d0nVCe085T
e6CUoh5TPFB1I85T_fCi0?iToP3kI?d0mFCe0?ITn001I6Cm0?eTo@3iI?d0n6Ch
005TI?h0l6Cm001Tm`3iI?d0o6Ch001To03lI?d0nFCm0?YTm@21I=ATiOn1I85T
PFB1I;mTn@3nI?h0nfCm0?ETm@3fI?P00FATo@3mI?d0nFCm0?QTn001I6Cn0?1T
o@00I?L0nFCm0?aTn000I?`0o6Cm0?UTo@3jI?D0PFCDI045iOn1I85TPFB1I;eT
o@3lI?h0nfCm0?ATn03cI?X0oVCm0?eTo@3iI?d0n6Ci0?iToP3`I?d00FATn@3h
I?d0nfCk0?eTo@3lI?d0nFCm0?UTm`21I==TiOn1I85TPFB1I;eTo@3lI?h0nfCm
0?ATn03cI?X0oVCm0?eTo@3iI?d0n6Ci0?iToP3`I?d00FATn@3hI?d0nfCk0?eT
o@3lI?d0nFCm0?UTm`21I==TiOn1I85TPFB1I;eTo@3lI?h0nfCm0?ATn03cI?X0
oVCm0?eTo@3iI?d0n6Ci0?iToP3`I?d00FATn@3hI?d0nfCk0?eTo@3lI?d0nFCm
0?UTm`21I==T04;Uoh5TPFB1I85T]6Cn08UTo@21I85TiOn1I85TPFB1I;AToP29
I?d0PFB1I>GoPFB1I85TPFBdI?h0RFCm085TPF@0@^GoPFB1I85TPFBdI?h0RFCm
085TPFCUoh5TPFB1I85T]6Cn08UTo@21I85TiOn1I85TPFB1I;AToP29I?d0PFB1
I01>iOn1I85TPFB1I<=ToP3fI?h0R6Cm085TPFCUoh5TPFB1I85T`fCn0?IToP28
I?d0PFB1I>GoPFB1I85TPFC3I?h0mVCn08QTo@21I85T04kUoh5TPFB1I85T`fCm
0?QTo@28I?d0PFB1I>GoPFB1I85TPFC3I?d0n6Cm08QTo@21I85TiOn1I85TPFB1
I<=To@3hI?d0R6Cm085TPF@0C^GoPFB1I85TPFC3I?`0nVCl08QTo@21I85TiOn1
I85TPFB1I<=To03jI?`0R6Cm085TPFCUoh5TPFB1I85T`fCl0?YTo028I?d0PFB1
I012iOn1I85TPFB1I<9TlP27I?d0PFB1I>GoPFB1I85TPFC2I?80QfCm085TPFCU
oh5TPFB1I85T`VCb08MTo@21I85T04;Uoh5TPFB1I85T`FCd08ITo@21I85TiOn1
I85TPFB1I<5Tm026I?d0PFB1I>GoPFB1I85TPFC1I?@0QVCm085TPF@0@^GoPFB1
I85TPFC0I?H0QFCm085TPFCUoh5TPFB1I85T`6Cf08ETo@21I85TiOn1I85TPFB1
I<1TmP25I?d0PFB1I00fiOn1I85TPFB1I85TPFB1I;ETiOn1I85TPFB1I85TPFB1
I;ETiOn1I85TPFB1I85TPFB1I;ET03KUoh5TPFB1I85TPFB1I85T]FCUoh5TPFB1
I85TPFB1I85T]FCUoh5TPFB1I85TPFB1I85T]F@0=^GoPFB1I85TPFB1I85TPFBe
I>GoPFB1I85TPFB1I85TPFBeI>GoPFB1I85TPFB1I85TPFBeI00fiOn1I85TPFB1
I85TPFB1I;ETiOn1I85TPFB1I85TPFB1I;ETiOn1I85TPFB1I85TPFB1I;ET03KU
oh5TPFB1I85TPFB1I85T]FCUoh5TPFB1I85TPFB1I85T]FCUoh5TPFB1I85TPFB1
I85T]F@0=^GoPFB1I85TPFB1I85TPFBeI>GoPFB1I85TPFB1I85TPFBeI>GoPFB1
I85TPFB1I85TPFBeI00fiOn1I85TPFB1I85TPFB1I;ETiOn1I85TPFB1I85TPFB1
I;ETiOn1I85TPFB1I85TPFB1I;ET03KUoh5TPFB1I85TPFB1I85T]FCUoh5TPFB1
I85TPFB1I85T]FCUoh5TPFB1I85TPFB1I85T]F@0=^GoPFB1I85TPFB1I85TPFBe
I>GoPFB1I85TPFB1I85TPFBeI>GoPFB1I85TPFB1I85TPFBeI00fiOn1I85TPFB1
I85TPFB1I;ETiOn1I85TPFB1I85TPFB1I;ETiOn1I85TPFB1I85TPFB1I;ET03KU
oh5TPFB1I85TPFB1I85T]FCUoh5TPFB1I85TPFB1I85T]FCUoh5TPFB1I85TPFB1
I85T]F@0=^GoPFB1I85TPFB1I85TPFBeI>GoPFB1I85TPFB1I85TPFBeI>GoPFB1
I85TPFB1I85TPFBeI00fiOn1I85TPFB1I85TPFB1I;ETiOn1I85TPFB1I85TPFB1
I;ETiOn1I85TPFB1I85TPFB1I;ET03KUoh5TPFB1I85TPFB1I85T]FCUoh5TPFB1
I85TPFB1I85T]FCUoh5TPFB1I85TPFB1I85T]F@0=^GoPFB1I85TPFB1I85TPFBe
I>GoPFB1I85TPFB1I85TPFBeI>GoPFB1I85TPFB1I85TPFBeI00fiOn1I85TPFB1
I85TPFB1I;ETiOn1I85TPFB1I85TPFB1I;ETiOn1I85TPFB1I85TPFB1I;ET03KU
oh5TPFB1I85TPFB1I85T]FCUoh5TPFB1I85TPFB1I85T]FCUoh5TPFB1I85TPFB1
I85T]F@0=^GoPFB1I85TPFB1I85TPFBeI>GoPFB1I85TPFB1I85TPFBeI>GoPFB1
I85TPFB1I85TPFBeI00fiOn1I85TPFB1I85TPFB1I;ETiOn1I85TPFB1I85TPFB1
I;ETiOn1I85TPFB1I85TPFB1I;ET03KUoh5TPFB1I85TPFB1I85T]FCUoh5TPFB1
I85TPFB1I85T]FCUoh5TPFB1I85TPFB1I85T]F@0=^GoPFB1I85TPFB1I85TPFBe
I>GoPFB1I85TPFB1I85TPFBeI>GoPFB1I85TPFB1I85TPFBeI00fiOn1I85TPFB1
I85TPFB1I;ETiOn1I85TPFB1I85TPFB1I;ETiOn1I85TPFB1I85TPFB1I;ET03KU
oh5TPFB1I85TPFB1I85T]FCUoh5TPFB1I85TPFB1I85T]FCUoh5TPFB1I85TPFB1
I85T]F@0=^GoPFB1I85TPFB1I85TPFBeI>GoPFB1I85TPFB1I85TPFBeI>GoPFB1
I85TPFB1I85TPFBeI00fiOn1I85TPFB1I85TPFB1I;ETiOn1I85TPFB1I85TPFB1
I;ETiOn1I85TPFB1I85TPFB1I;ET0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`00VP000?n9D00000011P9D00001000
0000B00004P0000@02000`08000000000002_N7H000000460Td000?Z0@H6=@00
01b1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohGo01b1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ohGo01b1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohGo01b1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ohGo01b1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ohGo01b1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohGo01b1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ohGo01b1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohGo
01b1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohGo01b1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ohGo01b1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohGo01b1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ohGo02N1ok;ooP21oh7oPOn1ok3ooP21oh7o
POn1ok3ooP21oh7oPOl1ool09h7o/_on087oPOn1oh7o/?on087oPOn1oh7o/?on
087oPOn1o`7oo`0WPOnbooh0POn1oh7oPOn`ooh0POn1oh7oPOn`ooh0POn1oh7o
0Ooo02N1ok;ooP21oh7oPOn1ok3ooP21oh7oPOn1ok3ooP21oh7oPOl1ool0<87o
/_on0=3oo@21oh7oPOn1onGooP3@ood0POn1oh7oPOoUooh0d?om087oPOndo`0`
POnbooh0d?om087oPOn1oh7oiOon0=3oo@21oh7oPOn1onGooP3@ood0POn1okCo
0321ok;ooP3@ood0POn1oh7oPOoUooh0d?om087oPOn1oh7oiOon0=3oo@21oh7o
]?l0<87o/_on0=3oo@21oh7oPOn1onGooP3@ood0POn1oh7oPOoUooh0d?om087o
POndo`2<POokoo/0look0>ooo03boo`0oOon0>7on`3food0l_ok0>gooP3kooX0
POn1oh7oiook0??on`3_oo`0l_ol0?gooP3Qoo/0m_om0?;on`3]ooh0nooj087o
POn1onOon`3coo/0kool0?;oo03mooh0hOok0?Koo@3boo/0kOon0?_onP21oh7o
kOl0_h7ooOog0?Oon03good0o_oj0?Kon@3nooh0o?om0?Soo@3iooL0o?oc0?[o
n03food00Oooo03mooL0POn1oh7oj_og0?Oon03good0o_oj0?Kon@3nooh0o?om
0?Soo@3iooL0o?oc0?[on03food00Oooo03mooL0POn1oh7oj_og0?Oon03good0
o_oj0?Kon@3nooh0o?om0?Soo@3iooL0o?oc0?[on03food00Oooo03mooL0POn1
onko0;21ookom@3joo@0nOob0?SomP00ooh0o?om0?Soo@3jooD0oOoc0?com03h
ood00?ok0?kom021oh7oPOo]ooD0n_od0?WolP3hooH00?on0?coo@3hood0n_oe
0?gol`3loo@0n?om003on`3noo@0POn1oh7okOoe0?[om03ioo80n?of003ooP3l
ood0n?om0?[om@3moo<0o?od0?Soo@00oo/0o_od087oPOo`o`3iPOl1oool0?co
o@3loo`0o?ol0?[onP3noo`0nOol0?gooP00ooh0o?om0?Soo@3koo`0o?om0?ko
l`3moo`0o?ol0?Won@3loo`0o?om087oPOn1onkoo03lood0o?ol0?coo03jooX0
o_ol0?Woo03mooh00?on0?coo@3hood0nool0?coo@3noo<0oOol0?coo03iooT0
o?ol0?coo@21oh7oPOo^oo`0o?om0?coo03loo`0n_oj0?koo03ioo`0oOon003o
oP3lood0n?om0?_oo03lood0o_oc0?goo03loo`0nOoi0?coo03lood0POn1oo3o
0>b1o`3oo03koo`0o_ok0?_oo03koo/0noon0?[oo03koo/0o?om0?Soo@3loo`0
nool0?_oo@3hoo/0nool0?[on`3jood0nool087oPOn1oo3oo03koo`0o_ok0?_o
o03koo/0noon0?[oo03koo/0o?om0?Soo@3loo`0nool0?_oo@3hoo/0nool0?[o
n`3jood0nool087oPOn1oo3oo03koo`0o_ok0?_oo03koo/0noon0?[oo03koo/0
o?om0?Soo@3loo`0nool0?_oo@3hoo/0nool0?[on`3jood0nool087oPOoao`3N
POol0?Woo@3nood0n?om0?_oo03jood0noom0?Woo03lood0n?om0?goo03iood0
noom0?Soo@3hood0n_ol0?[oo@21oh7oPOoUoo`0nOom0?koo@3hood0nool0?[o
o@3kood0nOol0?coo@3hood0oOol0?Woo@3kood0n?om0?Soo@3joo`0n_om087o
POn1onGoo03iood0o_om0?Soo@3koo`0n_om0?_oo@3ioo`0o?om0?Soo@3moo`0
nOom0?_oo@3hood0n?om0?[oo03jood0POn1onGo0<J1ood0lOon0?KooP3kood0
nOom0?_ooP3good0o?om0?Soo@3mood0k_om0?SooP3fooh0n_ol0?[oo@21oh7o
POoUood0lOon0?KooP3kood0nOom0?_ooP3good0o?om0?Soo@3mood0k_om0?So
oP3fooh0n_ol0?[oo@21oh7oPOoUood0lOon0?KooP3kood0nOom0?_ooP3good0
o?om0?Soo@3mood0k_om0?SooP3fooh0n_ol0?[oo@21oh7oiOl0aX7ooP3aood0
m_om0?coo@3iood0o?om0?KooP3lood0n?om0?gooP3]ood0nOom0?Koo@3kood0
nOol087oPOn1onKooP3aood0m_om0?coo@3iood0o?om0?KooP3lood0n?om0?go
oP3]ood0nOom0?Koo@3kood0nOol087oPOn1onKooP3aood0m_om0?coo@3iood0
o?om0?KooP3lood0n?om0?gooP3]ood0nOom0?Koo@3kood0nOol087oPOoVo`36
POon0?7oo@3eooh0o?om0?Woo@3lood0m_on0?coo@3hood0oOon0>goo@3iood0
mOon0?_oo@3hoo/0POn1oh7oj?on0?7oo@3eooh0o?om0?Woo@3lood0m_on0?co
o@3hood0oOon0>goo@3iood0mOon0?_oo@3hoo/0POn1oh7oj?on0?7oo@3eooh0
o?om0?Woo@3lood0m_on0?coo@3hood0oOon0>goo@3iood0mOon0?_oo@3hoo/0
POn1onSo0<J1ooh0lOom0?GooP3lood0nOom0?coo@3fooh0o?om0?Soo@3mooh0
kOom0?Woo@3eooh0noom0?Son@21oh7oPOoZooh0lOom0?GooP3lood0nOom0?co
o@3fooh0o?om0?Soo@3mooh0kOom0?Woo@3eooh0noom0?Son@21oh7oPOoZooh0
lOom0?GooP3lood0nOom0?coo@3fooh0o?om0?Soo@3mooh0kOom0?Woo@3eooh0
noom0?Son@21oh7oj_l0aX7ooP3aood0mOon0?coo@3iood0o?om0?KooP3lood0
n?om0?gooP3]ood0nOom0?GooP3kood0m_og087oPOn1onkooP3aood0mOon0?co
o@3iood0o?om0?KooP3lood0n?om0?gooP3]ood0nOom0?GooP3kood0m_og087o
POn1onkooP3aood0mOon0?coo@3iood0o?om0?KooP3lood0n?om0?gooP3]ood0
nOom0?GooP3kood0m_og087oPOo^o`36POon0?7oo@3eooh0o?om0?Woo@3lood0
m_on0?coo@3hood0oOon0>goo@3iood0mOon0?_oo@3dooP0POn1oh7okoon0?7o
o@3eooh0o?om0?Woo@3lood0m_on0?coo@3hood0oOon0>goo@3iood0mOon0?_o
o@3dooP0POn1oh7okoon0?7oo@3eooh0o?om0?Woo@3lood0m_on0?coo@3hood0
oOon0>goo@3iood0mOon0?_oo@3dooP0POn1onoo0<J1ooh0lOom0?GooP3lood0
nOom0?coo@3fooh0o?om0?Soo@3mooh0kOom0?Woo@3eooh0noom0?;on@21oh7o
POo`ooh0lOom0?GooP3lood0nOom0?coo@3fooh0o?om0?Soo@3mooh0kOom0?Wo
o@3eooh0noom0?;on@21oh7oPOo`ooh0lOom0?GooP3lood0nOom0?coo@3fooh0
o?om0?Soo@3mooh0kOom0?Woo@3eooh0noom0?;on@21oh7ol?l0aX7ooP3aood0
mOon0?coo@3iood0o?om0?KooP3lood0n?om0?gooP3]ood0nOom0?GooP3kood0
k_ol087oPOn1oo7ooP3aood0mOon0?coo@3iood0o?om0?KooP3lood0n?om0?go
oP3]ood0nOom0?GooP3kood0k_ol087oPOn1oo7ooP3aood0mOon0?coo@3iood0
o?om0?KooP3lood0n?om0?gooP3]ood0nOom0?GooP3kood0k_ol087oPOoao`36
POon0?7oo@3food0o?om0?Woo@3lood0moom0?coo@3hood0oOon0>goo@3iood0
m_om0?_oo@3]ood0POn1oh7olOon0?7oo@3food0o?om0?Woo@3lood0moom0?co
o@3hood0oOon0>goo@3iood0m_om0?_oo@3]ood0POn1oh7olOon0?7oo@3food0
o?om0?Woo@3lood0moom0?coo@3hood0oOon0>goo@3iood0m_om0?_oo@3]ood0
POn1oo7o0<J1ood0lOon0?KooP3kood0nOom0?_ooP3good0o?om0?Woo03mood0
k_om0?SooP3fooh0n_om0>goo@21oh7oPOoaood0lOon0?KooP3kood0nOom0?_o
oP3good0o?om0?Woo03mood0k_om0?SooP3fooh0n_om0>goo@21oh7oPOoaood0
lOon0?KooP3kood0nOom0?_ooP3good0o?om0?Woo03mood0k_om0?SooP3fooh0
n_om0>goo@21oh7olOl0gX7oo03iood0o_om0?Soo@3kood0nOom0?_ooP3hoo`0
o?om0?[on`3moo`0nOom0?_oo@3hood0n?om0?[oo@3]ood0POn1oh7olOol0?Wo
o@3nood0n?om0?_oo@3iood0noon0?Soo03lood0n_ok0?goo03iood0noom0?So
o@3hood0n_om0>goo@21oh7oPOoaoo`0nOom0?koo@3hood0noom0?Woo@3kooh0
n?ol0?coo@3joo/0oOol0?Woo@3kood0n?om0?Soo@3jood0kOom087oPOoao`3/
POl0ood0nOom0?koo03joo`0noom0?Woo@3kood0nOol0?coo03koo/0o?om0?Wo
o@3kood0n?ol0?[oo03jood0nOom0?[oo021oh7oPOo`ood0nOom0?koo03joo`0
noom0?Woo@3kood0nOol0?coo03koo/0o?om0?Woo@3kood0n?ol0?[oo03jood0
nOom0?[oo021oh7oPOo`ood0nOom0?koo03joo`0noom0?Woo@3kood0nOol0?co
o03koo/0o?om0?Woo@3kood0n?ol0?[oo03jood0nOom0?[oo021oh7olOl0k87o
0?ol0?_oo@3moo/0nool0?_oo@3iood0nool0?_on`3kood0nook0?coo03kood0
nOon0?Son`3koo`0n_om0?Woo03kood0POn1oh7okool0?_oo@3moo/0nool0?_o
o@3iood0nool0?_on`3kood0nook0?coo03kood0nOon0?Son`3koo`0n_om0?Wo
o03kood0POn1oh7okool0?_oo@3moo/0nool0?_oo@3iood0nool0?_on`3kood0
nook0?coo03kood0nOon0?Son`3koo`0n_om0?Woo03kood0POn1oo3o0;21ooko
m@3joo@0nOom0?Woo@3iooH00?on0?_omP00ood0n_oe0?Son03loo@0n?om0?So
m021oh7oPOo/ooD0n_od0?Woo@3iood0nOof003ooP3kooH00?om0?[om@3hooP0
o?od0?Soo@3hoo@0POn1oh7ok?oe0?[om03iood0nOom0?WomP00ooh0noof003o
o@3jooD0n?oh0?com03hood0n?od087oPOo_o`36POonooH0n?oe0?Woo@3iood0
n?oh007oooh0n_oh007oood0n_of0?Kon@3kooD0n?om0?OomP3bo`40087oPOn1
oocomP3hooD0nOom0?Woo@3hooP00OoooP3jooP00Oooo@3jooH0m_oi0?_om@3h
ood0moof0?;o0@00POn1oh7oo?of0?Som@3iood0nOom0?Son001ooon0?[on001
ooom0?[omP3fooT0nooe0?Soo@3gooH0l_l10021oh7o0Ooo0;Z1oogom`3gooP0
moom0?Woo@3hooT0o_on0?WonP3nood0nOog0?Kon@3jooP0m_om0?Kom`3coo`0
POn1oh7ooOog0?Oon03good0nOom0?Son@3nooh0nOoj0?koo@3iooL0m_oi0?[o
n03food0m_og0??oo021oh7oPOomooL0mooh0?Ooo@3iood0n?oi0?kooP3iooX0
o_om0?Wom`3fooT0n_oh0?Koo@3fooL0lool087oPOl0987oPOnboo/0POn1oh7o
POncoo/0POn1oh7oPOncoo/0POn2o`0ZT?on087oYooh087oPOnCooh0POnWooP0
POn1oi?ooP21ojOon021ohCo02ZBoo`0POnUooP0POn1oiOoo021ojGon021oh7o
Uool087oYOoh087oQ_l0:Y?onP21ojCon021oh7oV_oj087oY?oh087oPOnJooX0
POnTooP0POn8o`0ZUOoh087oXoog087oPOnNooP0POnSooL0POn1oikon021oj?o
m`21oh[o02ZGooP0POnOooP0POn1oj7on021oioon021oh7oXOoh087oWooh087o
Rol0:YWon021oi_on021oh7oYOoh087oVooh087oPOnUooP0POnKooP0POn=o`0Z
Voog087oV?oh087oPOnYooL0POnHooP0POn1ojWom`21oiSon021ohoo02ZMooL0
POnDooP0POn1ojgom`21oiCon021oh7o[Oog087oU?oh087oTOl0:Ykon021oi7o
n021oh7o[ooh087oTOoh087oPOn_ooP0POnAooP0POnBo`0ZX?oh087oSOoh087o
POncooP0POn=ooP0POn1ok?on021ohgon021oiCo02ZRooP0POn9ooP0POn1okOo
n021ohWon021oh7o]ooh087oROoh087oU_l0:ZCon021ohGon021oh7o^ooh087o
QOoh087oPOnkooP0POn5ooP0POnHo`0ZY_og087oPoog087oPOnoooL0POn3ooL0
POn1okoom`21oh?om`21oi[o03>WooP0POn1o`7oooP0POn1ol7on021oh7o0Ooo
n021oh7o`Ooh087oPOl1oooh087oVol0<:Won021oh7onooh087oPOo5ooP0POn1
oo_on021oh7oaOoh087oPOokooP0POnMo`0`Zooh087oPOogooP0POn1olWon021
oh7omooh087oPOo9ooP0POn1ooOon021oioo032]ooP0POn1oo?on021oh7ocOoh
087oPOocooP0POn1olgon021oh7olooh087oXOl0<:oom`21oh7olOog087oPOoA
ooL0POn1oo7om`21oh7odOog087oPOoaooL0POnSo`0`/Oog087oPOo]ooP0POn1
omCom`21oh7okOoh087oPOoDooL0POn1ongon021ojCo032booP0POn1onWon021
oh7oeooh087oPOoYooP0POn1omOon021oh7ojOoh087oY_l0<;Con021oh7oiOoh
087oPOoKooP0POn1onGon021oh7ofooh087oPOoUooP0POnXo`0`]_oh087oPOoQ
ooP0POn1omoon021oh7ohOoh087oPOoOooP0POn1on7on021oj[o032hooP0POn1
omkom`21oh7ohooh087oPOoNooL0POn1on?on021oh7og_og087o[?l0<;[om`21
oh7ofooh087oPOoVooL0POn1om_on021oh7oi_og087oPOoKooP0POn]o`0`_?og
087oPOoGooP0POn1on[om`21oh7oeooh087oPOoZooL0POn1omOon021ojoo03_I
o`400>Oon021oh7odooh087oROl1003WooP0POn1om?on021ohWo0@00iooh087o
POoCooP0POnao`0hf_ol0>_on021oh7ocooh087oS?ol0>_on021oh7ocooh087o
S?ol0>_on021oh7ocooh087o/ol0A=_onP3^ooP0POn1olcom`3Vo`00POn[ooX0
k_oh087oPOo<ooL0i_l0087oZooj0>kon021oh7oc?og0>Ko0021om7o04OLooP0
lOoh087oPOo8ooP0iol10021ojgon03aooP0POn1olSon03Wo`40087o[Ooh0?7o
n021oh7ob?oh0>Oo0@00POoBo`14gOof0?Com`21oh7oaOoh0>[oo@21ojoomP3d
ooL0POn1olGon03Zood0POn_ooH0m?og087oPOo5ooP0j_om087odol0A=gom@3f
ooP0POn1ol7on03]oo/0POn`ooD0m_oh087oPOo1ooP0kOok087o/?oe0?Kon021
oh7o`Ooh0>gon`21omCo04CNoo<0nOoh087oPOnmooP0lOoh087o/_oc0?Won021
oh7o_Ooh0?7on021ok;ol`3iooP0POn1okgon03aooP0POoEo`14goob0?_on021
oh7o^_oh0??omP21okColP3kooP0POn1ok[on03cooH0POndoo80nooh087oPOnj
ooP0loof087oe_l0A>3ol03nooP0POn1okKon03foo@0POnfoo00o_oh087oPOnf
ooP0m_od087o]_o`0?kon021oh7o]_oh0?Kom021omOo03SQon@0POn1ok?on03i
oo<0POngon@0POn1ok?on03ioo<0POngon@0POn1ok?on03ioo<0POoGo`0hh_oU
087oPOn_ooP0noob087o^OoU087oPOn_ooP0noob087o^OoU087oPOn_ooP0noob
087of?l0>>?oiP21oh7o[?og0?kol021ok_oiP21oh7o[?og0?kol021ok_oiP21
oh7o[?og0?kol021omWo03_TonL0POn1ojSon001ooo_087o_OoW087oPOnXooP0
0Oook`21okgoi`21oh7oZ?oh007oonl0POoJo`0/iOoX087oPOnTonD0POnoonP0
POn1ojCoi@21okooj021oh7oY?oU087ofol0;>Koi`21oh7oX_oV087o`OoW087o
POnRonH0POo1onL0POn1oj;oiP21omco02cWonH0POn1oj3oi`21ol?oiP21oh7o
X?oW087o`ooV087oPOnPonL0POoMo`0/j?oT087oPOnPonL0POo5on@0POn1oj3o
i`21olGoi021oh7oX?oW087og_l0;>Soi021oh7oWooW087oa_oT087oPOnOonL0
POo6on@0POn1oiooi`21omoo02cYon80POn1oj7oi@21olSohP21oh7oXOoU087o
b?oR087oPOnQonD0POoPo`0/j_oQ087oPOnQon@0POo:on40POn1oj7oi021ol[o
h@21oh7oXOoT087ohOl0;>_og`21oh7oXooR087oc?oO087oPOnSon80POo<oml0
POn1oj?ohP21on;o02c/omh0POn1oj?ohP21olgogP21oh7oXooR087ocOoN087o
POnSon80POoRo`0/kOoM087oPOnSon40POo?omd0POn1oj?oh@21oloog@21oh7o
XooQ087ohol0;>gog@21oh7oY?oO087od?oM087oPOnToml0POo@omd0POn1ojCo
g`21onCo02c^om`0POn1ojCogP21om;og021oh7oY?oN087od_oL087oPOnTomh0
POoUo`0/kooJ087oPOnUomd0POoDomX0POn1ojGog@21omCofP21oh7oYOoM087o
i_l0;?3of@21oh7oYOoL087oe_oI087oPOnUom`0POoFomT0POn1ojGog021onOo
02caomP0POn1ojGof`21omSof021oh7oYOoK087of?oH087oPOnUom/0POoXo`0/
l_oL087oPOnQomT0POoJom`0POn1oj7of@21om[og021oh7oXOoI087ojOl0;??o
h@21oh7oVooH087og?oQ087oPOnKomP0POoLon40POn1oi_of021on[o02cdonD0
POn1oiKoe`21omkoi@21oh7oU_oG087og_oU087oPOnFomL0POo[o`0/mOoZ087o
POn;om/0POoPonX0POn1oh_of`21on3ojP21oh7oRooK087ok?l0=OKokP21oh7o
POl1oooQ087oh_o^087oPOn1o`7oon40POoRonh0POn1oh7o0Oooh@21ongo03;g
oo<0POn1oh7omOoU087ohooc087oPOn1ooGoi@21on?ol`21oh7oPOoeonD0POo]
o`0bn?og087oPOn1oncoj021onGom`21oh7oPOo/onP0POoUooL0POn1oh7ok?oX
087ok_l0<_Soo@21oh7oPOoNonl0POoVood0POn1oh7og_o_087oi_om087oPOn1
omkok`21onoo02J1oh7oPOo9ooH0POn1oh7oPOnhooH0POn1oh7oPOnhooH0POo`
o`0VPOn1oh7o`_ol087oPOn1oh7o/_ol087oPOn1oh7o/_ol087olOl0787oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oQOl0787oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oQOl0787oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oQOl0787oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oQOl0787oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oQOl0
787oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oQOl0787oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oQOl0787oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oQOl09;h0POn1
okooS`2Tokh0POn1okooS`2Tokh0POn1okooS`2To`0T_P21oh7o_on?0:Co_P21
oh7o_on?0:Co_P21oh7o_on?0:Co02Bn087oPOnoohl0Y?nn087oPOnoohl0Y?nn
087oPOnoohl0Y?l09;h0POn1okooS`2Tokh0POn1okooS`2Tokh0POn1okooS`2T
o`0T_P21oh7o_on?0:Co_P21oh7o_on?0:Co_P21oh7o_on?0:Co02Bn087oPOno
ohl0Y?nn087oPOnoohl0Y?nn087oPOnoohl0Y?l09;h0POn1okooS`2Tokh0POn1
okooS`2Tokh0POn1okooS`2To`0T_P21oh7o_on?0:Co_P21oh7o_on?0:Co_P21
oh7o_on?0:Co02Bn087oPOnoohl0Y?nn087oPOnoohl0Y?nn087oPOnoohl0Y?l0
9;h0POn1okooS`2Tokh0POn1okooS`2Tokh0POn1okooS`2To`0T_P21oh7o_on?
0:Co_P21oh7o_on?0:Co_P21oh7o_on?0:Co02Bn087oPOnoohl0Y?nn087oPOno
ohl0Y?nn087oPOnoohl0Y?l09;h0POn1okooS`2Tokh0POn1okooS`2Tokh0POn1
okooS`2To`0T_P21oh7o_on?0:Co_P21oh7o_on?0:Co_P21oh7o_on?0:Co02Bn
087oPOnoohl0Y?nn087oPOnoohl0Y?nn087oPOnoohl0Y?l09840P@210840]P3h
oh40P@210840]P3hoh40P@210840]P3ho`0TP@210840P@2f0?SoP@210840P@2f
0?SoP@210840P@2f0?So02B10840P@210;H0n?n10840P@210;H0n?n10840P@21
0;H0n?l09840P@210840]P3hoh40P@210840]P3hoh40P@210840]P3ho`0ZPLR1
b878PLRjb?d0n?n1b878PLR1b;[8o@3hoh78PLR1b878^/Sm0?So02Z1b878PLR1
b;[8o@3hoh78PLR1b878^/Sm0?SoPLR1b878PLRjb?d0n?l0:X78PLR1b878^/Sm
0?SoPLR1b878PLRjb?d0n?n1b878PLR1b;[8o@3ho`0ZPLR1b878PLRjb?d0n?n1
b878PLR1b;[8o@3hoh78PLR1b878^/Sm0?So02Z1b878PLR1b;[8o@3hoh78PLR1
b878^/Sm0?SoPLR1b878PLRjb?d0n?l0H9S8m@3fb?T0aLSn08o8n`3]b?h0o<Sn
0878V<Sm0?SoV<Se0?K8n@35b?h0SlSk0>g8oP3lb?h0PLRHb?d0n?nHb?D0m/Si
0<G8oP2?b?/0kLSn0?c8oP21b9S8o@3ho`1PV<Se0?O8m`36b?h0T<Sj0>g8oP3l
b?h0PLRHb?d0n?nHb?D0mlSg0<K8oP2@b?X0kLSn0?c8oP21b9S8o@3hoiS8m@3g
b?L0a/Sn0938nP3]b?h0o<Sn0878V<Sm0?So06bHb?D0n<Sm0?g8oP36b?h0TLSm
0>W8oP3lb?h0PLRHb?d0n?nHb?D0n<Sm0?g8oP36b?h0TLSm0>W8oP3lb?h0PLRH
b?d0n?nHb?D0n<Sm0?g8oP36b?h0TLSm0>W8oP3lb?h0PLRHb?d0n?l0K9S8oP3`
b?h0n/Sn0<O8oP3>b?h0b<Sn0=o8oP21b9S8o@3hoiS8oP3`b?h0n/Sn0<O8oP3>
b?h0b<Sn0=o8oP21b9S8o@3hoiS8oP3`b?h0n/Sn0<O8oP3>b?h0b<Sn0=o8oP21
b9S8o@3ho`1/V<Sn0?38oP3ib?h0b<Sn0<k8oP38b?h0glSn0878V<Sm0?SoV<Sn
0?38oP3ib?h0b<Sn0<k8oP38b?h0glSn0878V<Sm0?SoV<Sn0?38oP3ib?h0b<Sn
0<k8oP38b?h0glSn0878V<Sm0?So06bHb?h0l<Sn0?W8oP38b?h0c/Sn0<S8oP3O
b?h0PLRHb?d0n?nHb?h0l<Sn0?W8oP38b?h0c/Sn0<S8oP3Ob?h0PLRHb?d0n?nH
b?h0l<Sn0?W8oP38b?h0c/Sn0<S8oP3Ob?h0PLRHb?d0n?l0K9S8oP3ab?h0mlSn
0<W8oP3>b?h0b<Sn0=o8oP21b9S8o@3hoiS8oP3ab?h0mlSn0<W8oP3>b?h0b<Sn
0=o8oP21b9S8o@3hoiS8oP3ab?h0mlSn0<W8oP3>b?h0b<Sn0=o8oP21b9S8o@3h
o`3cV<Sn0?78oP3gb?h0l<P1003ib?h0ilSn0?_8o@3jb?`0n<Sn0?k8o@3jb?H0
nLSl0?O8oP3nb?d0l<Sf0?_8o03hb?h0o<Sn0878V<Sm0?SoV<Sn0?78oP3gb?h0
l<P1003ib?h0ilSn0?_8o@3jb?`0n<Sn0?k8o@3jb?H0nLSl0?O8oP3nb?d0l<Sf
0?_8o03hb?h0o<Sn0878V<Sm0?SoV<Sn0?78oP3gb?h0l<P1003ib?h0ilSn0?_8
o@3jb?`0n<Sn0?k8o@3jb?H0nLSl0?O8oP3nb?d0l<Sf0?_8o03hb?h0o<Sn0878
V<Sm0?So0?>Hb?h0l/Sm0?O8oP3`b0400?W8oP3Wb?h0nlSn0?_8n03jb?h00<Si
0?c8mP3jb?T0nLSn0038n@3bb?H0o<Si0?[8oP3lb?h0PLRHb?d0n?nHb?h0l/Sm
0?O8oP3`b0400?W8oP3Wb?h0nlSn0?_8n03jb?h00<Si0?c8mP3jb?T0nLSn0038
n@3bb?H0o<Si0?[8oP3lb?h0PLRHb?d0n?nHb?h0l/Sm0?O8oP3`b0400?W8oP3W
b?h0nlSn0?_8n03jb?h00<Si0?c8mP3jb?T0nLSn0038n@3bb?H0o<Si0?[8oP3l
b?h0PLRHb?d0n?l159S8nP3fb?h0m/Sn0?78oP3jb?h0i/Sn0?g8o@3kb?h0oLSm
0?_8n`3nb?d0n/Sn0?O8o@3nb?d0n/Sk0?k8oP3`b?h0n<Sm0?k8o@3kb?h0o<Sn
0878V<Sm0?SoV<Sj0?K8oP3fb?h0lLSn0?[8oP3Vb?h0oLSm0?_8oP3mb?d0nlSk
0?k8o@3jb?h0mlSm0?k8o@3jb?/0o/Sn0?38oP3hb?d0o/Sm0?_8oP3lb?h0PLRH
b?d0n?nHb?X0m/Sn0?K8oP3ab?h0n/Sn0>K8oP3mb?d0nlSn0?g8o@3kb?/0o/Sm
0?[8oP3gb?d0o/Sm0?[8n`3nb?h0l<Sn0?S8o@3nb?d0nlSn0?c8oP21b9S8o@3h
o`4DV<Sh0?S8oP3fb?h0lLSn0?[8oP3Vb?h0oLSm0?_8oP3lb?d0o<Sm0?_8oP3j
b?h0n<Sm0?c8o@3kb?d0o<Sm0?78oP3ib?d0o<Sm0?c8oP3lb?h0PLRHb?d0n?nH
b?P0n<Sn0?K8oP3ab?h0n/Sn0>K8oP3mb?d0nlSn0?c8o@3lb?d0nlSn0?[8oP3h
b?d0o<Sm0?_8o@3lb?d0lLSn0?W8o@3lb?d0o<Sn0?c8oP21b9S8o@3hoiS8n03h
b?h0m/Sn0?78oP3jb?h0i/Sn0?g8o@3kb?h0o<Sm0?c8o@3kb?h0n/Sn0?S8o@3l
b?d0nlSm0?c8o@3ab?h0nLSm0?c8o@3lb?h0o<Sn0878V<Sm0?So0ABHb?H0n/Sn
0?K8oP3ab?h0n/Sn0>K8oP3nb?d0nlSn0?[8oP3lb?d0n/Sn0?_8oP3hb?h0n/Sm
0?c8o@3kb?h0lLSn0?W8oP3jb?d0oLSn0?c8oP21b9S8o@3hoiS8mP3jb?h0m/Sn
0?78oP3jb?h0i/Sn0?k8o@3kb?h0n/Sn0?c8o@3jb?h0nlSn0?S8oP3jb?d0o<Sm
0?_8oP3ab?h0nLSn0?[8o@3mb?h0o<Sn0878V<Sm0?SoV<Sf0?[8oP3fb?h0lLSn
0?[8oP3Vb?h0o/Sm0?_8oP3jb?h0o<Sm0?[8oP3kb?h0n<Sn0?[8o@3lb?d0nlSn
0?78oP3ib?h0n/Sm0?g8oP3lb?h0PLRHb?d0n?l12i38o@3kb?h0m/Sn0?;8o@3k
b?d0i/Sn0078b?d0l<Sn0?c8oP3hb?h0o<Sn0?W8o@3ib?h0o<Sm0?_8oP3ab?h0
n/Sm0?W8oP3mb?h0o<Sn0878V<Sm0?SoT<Sm0?_8oP3fb?h0l/Sm0?_8o@3Vb?h0
0LS8o@3`b?h0o<Sn0?S8oP3lb?h0nLSm0?W8oP3lb?d0nlSn0?78oP3jb?d0nLSn
0?g8oP3lb?h0PLRHb?d0n?n@b?d0nlSn0?K8oP3bb?d0nlSm0>K8oP01b<Sm0?38
oP3lb?h0n<Sn0?c8oP3ib?d0nLSn0?c8o@3kb?h0lLSn0?[8o@3ib?h0oLSn0?c8
oP21b9S8o@3ho`48SlSn0?_8oP3fb?h0l/Sn0?[8oP3Ub?h00<Sm0>o8oP3lb?h0
n<Sn0?c8oP3ib?h0n<Sn0?c8oP3jb?h0lLSn0?[8oP3hb?h0oLSn0?c8oP21b9S8
o@3hoho8oP3kb?h0m/Sn0?;8oP3jb?h0iLSn0038o@3_b?h0o<Sn0?S8oP3lb?h0
nLSn0?S8oP3lb?h0n/Sn0?78oP3jb?h0n<Sn0?g8oP3lb?h0PLRHb?d0n?n?b?h0
nlSn0?K8oP3bb?h0n/Sn0>G8oP00b?d0klSn0?c8oP3hb?h0o<Sn0?W8oP3hb?h0
o<Sn0?[8oP3ab?h0n/Sn0?S8oP3mb?h0o<Sn0878V<Sm0?So0?b?b?h0nlSn0?K8
oP3bb?h0n/Sn0>G8nP3`b?`0o<Sn0?S8oP3lb?h0nLSn0?S8oP3lb?h0n/Sn0?78
oP3jb?h0n<Sn0?g8oP3lb?h0PLRHb?d0n?n?b?h0nlSn0?K8oP3bb?h0n/Sn0>G8
nP3`b?`0o<Sn0?S8oP3lb?h0nLSn0?S8oP3lb?h0n/Sn0?78oP3jb?h0n<Sn0?g8
oP3lb?h0PLRHb?d0n?n?b?h0nlSn0?K8oP3bb?h0n/Sn0>G8nP3`b?`0o<Sn0?S8
oP3lb?h0nLSn0?S8oP3lb?h0n/Sn0?78oP3jb?h0n<Sn0?g8oP3lb?h0PLRHb?d0
n?l0o8k8oP3lb?h0m/Sn0?;8oP3jb?h0iLSk0?C8m`3lb?h0n<Sn0?c8oP3ib?h0
n<Sn0?c8oP3jb?h0lLSn0?[8oP3hb?h0oLSn0?c8oP21b9S8o@3hohk8oP3lb?h0
m/Sn0?;8oP3jb?h0iLSk0?C8m`3lb?h0n<Sn0?c8oP3ib?h0n<Sn0?c8oP3jb?h0
lLSn0?[8oP3hb?h0oLSn0?c8oP21b9S8o@3hohk8oP3lb?h0m/Sn0?;8oP3jb?h0
iLSk0?C8m`3lb?h0n<Sn0?c8oP3ib?h0n<Sn0?c8oP3jb?h0lLSn0?[8oP3hb?h0
oLSn0?c8oP21b9S8o@3ho`4;S/Sn0?c8o@3gb?h0llSm0?[8oP3Ub?X0m/Sk0078
b?h0o<Sn0?S8oP3lb?h0nLSn0?S8oP3lb?h0n/Sn0?78oP3jb?h0n<Sn0?g8oP3l
b?h0PLRHb?d0n?n>b?h0o<Sm0?O8oP3cb?d0n/Sn0>G8nP3fb?/00LS8oP3lb?h0
n<Sn0?c8oP3ib?h0n<Sn0?c8oP3jb?h0lLSn0?[8oP3hb?h0oLSn0?c8oP21b9S8
o@3hohk8oP3lb?d0mlSn0??8o@3jb?h0iLSj0?K8n`01b<Sn0?c8oP3hb?h0o<Sn
0?W8oP3hb?h0o<Sn0?[8oP3ab?h0n/Sn0?S8oP3mb?h0o<Sn0878V<Sm0?So0AB>
b?h0nlSn0?O8oP3cb?h0nLSn0>G8oP00b?d0n<Sl0?g8oP3lb?h0n<Sn0?c8oP3i
b?h0n<Sn0?c8oP3jb?h0lLSn0?[8oP3hb?h0oLSn0?c8oP21b9S8o@3hohk8oP3k
b?h0mlSn0??8oP3ib?h0iLSn0038o@3hb?`0oLSn0?c8oP3hb?h0o<Sn0?W8oP3h
b?h0o<Sn0?[8oP3ab?h0n/Sn0?S8oP3mb?h0o<Sn0878V<Sm0?SoS/Sn0?_8oP3g
b?h0llSn0?W8oP3Ub?h00<Sm0?S8o03mb?h0o<Sn0?S8oP3lb?h0nLSn0?S8oP3l
b?h0n/Sn0?78oP3jb?h0n<Sn0?g8oP3lb?h0PLRHb?d0n?l158k8oP3kb?h0mlSn
0??8oP3jb?d0iLSn0?k8oP3jb?d0nlSn0?c8oP3hb?h0o<Sn0?W8o@3ib?h0o<Sn
0?[8oP3ab?h0n/Sm0?W8oP3mb?h0o<Sn0878V<Sm0?SoS/Sn0?_8oP3gb?h0llSn
0?[8o@3Ub?h0o/Sn0?[8o@3kb?h0o<Sn0?S8oP3lb?h0nLSm0?W8oP3lb?h0n/Sn
0?78oP3jb?d0nLSn0?g8oP3lb?h0PLRHb?d0n?n>b?h0nlSn0?O8oP3cb?h0n/Sm
0>G8oP3nb?h0n/Sm0?_8oP3lb?h0n<Sn0?c8oP3ib?d0nLSn0?c8oP3jb?h0lLSn
0?[8o@3ib?h0oLSn0?c8oP21b9S8o@3ho`4DS/Sn0?[8oP3ib?h0l/Sn0?[8o@3U
b?h0o/Sn0?[8oP3kb?d0o<Sn0?W8oP3kb?h0n<Sn0?W8oP3lb?h0n/Sn0?78oP3i
b?h0nLSn0?g8oP3lb?h0PLRHb?d0n?n>b?h0n/Sn0?W8oP3bb?h0n/Sm0>G8oP3n
b?h0n/Sn0?_8o@3lb?h0nLSn0?_8oP3hb?h0nLSn0?c8oP3jb?h0lLSn0?W8oP3i
b?h0oLSn0?c8oP21b9S8o@3hohk8oP3jb?h0nLSn0?;8oP3jb?d0iLSn0?k8oP3j
b?h0nlSm0?c8oP3ib?h0nlSn0?S8oP3ib?h0o<Sn0?[8oP3ab?h0nLSn0?W8oP3m
b?h0o<Sn0878V<Sm0?So0B2Ib?h0n/Sn0?W8oP3jb?h0lLSn0?c8o03Tb?h0oLSm
0?c8oP3lb?`0o<Sm0?_8oP3jb?h0n<Sm0?c8o@3kb?h0n/Sn0?78oP3ib?d0o<Sm
0?c8oP3lb?h0PLRHb?d0n?nIb?h0n/Sn0?W8oP3jb?h0lLSn0?c8o03Tb?h0oLSm
0?c8oP3lb?`0o<Sm0?_8oP3jb?h0n<Sm0?c8o@3kb?h0n/Sn0?78oP3ib?d0o<Sm
0?c8oP3lb?h0PLRHb?d0n?nIb?h0n/Sn0?W8oP3jb?h0lLSn0?c8o03Tb?h0oLSm
0?c8oP3lb?`0o<Sm0?_8oP3jb?h0n<Sm0?c8o@3kb?h0n/Sn0?78oP3ib?d0o<Sm
0?c8oP3lb?h0PLRHb?d0n?l1>9W8o@3kb?h0nLSm0?c8o@3ab?d0o/P20038oP3T
b?h0o<Sm0?g8o@3nb?/0o<Sk0?k8o@3ib?h0oLP00?g8o@3nb?d0n/Sn0?[8oP3a
b?h0n<Sm0?k8o@3kb?h0o<Sn0878V<Sm0?SoVLSm0?_8oP3ib?d0o<Sm0?78o@3n
b0800<Sn0>C8oP3lb?d0oLSm0?k8n`3lb?/0o/Sm0?W8oP3mb000oLSm0?k8o@3j
b?h0n/Sn0?78oP3hb?d0o/Sm0?_8oP3lb?h0PLRHb?d0n?nIb?d0nlSn0?W8o@3l
b?d0lLSm0?k80P00b?h0i<Sn0?c8o@3mb?d0o/Sk0?c8n`3nb?d0nLSn0?g8003m
b?d0o/Sm0?[8oP3jb?h0lLSn0?S8o@3nb?d0nlSn0?c8oP21b9S8o@3ho`3oV<Sn
0?g8o03hb?d0oLSn0?38n@01b<Sn0>C8oP3kb?h0o<Si0038oP3lb?D0n<Si0?c8
n03ib?h0n/Sn0?78oP3gb?P0n/Sn0?c8oP21b9S8o@3hoiS8oP3mb?`0n<Sm0?g8
oP3`b?T00LS8oP3Tb?h0nlSn0?c8n@00b?h0o<Se0?S8n@3lb?P0nLSn0?[8oP3a
b?h0mlSh0?[8oP3lb?h0PLRHb?d0n?nHb?h0oLSl0?S8o@3mb?h0l<Si0078b?h0
i<Sn0?_8oP3lb?T00<Sn0?c8m@3hb?T0o<Sh0?W8oP3jb?h0lLSn0?O8n03jb?h0
o<Sn0878V<Sm0?So0?2Gb?P0m<Si0?38nP3mb?h0i<Sn0?_8o@3kb?d0o/Sn0?c8
oP3nb?d0m<Sl0?W8o03gb?h0n/Sn0?78oP3eb?`0n<Sn0?c8oP21b9S8o@3hoiO8
n03db?T0l<Sj0?g8oP3Tb?h0nlSm0?_8o@3nb?h0o<Sn0?k8o@3db?`0nLSl0?O8
oP3jb?h0lLSn0?G8o03hb?h0o<Sn0878V<Sm0?SoUlSh0?C8n@3`b?X0oLSn0>C8
oP3kb?d0nlSm0?k8oP3lb?h0o/Sm0?C8o03ib?`0mlSn0?[8oP3ab?h0mLSl0?S8
oP3lb?h0PLRHb?d0n?l0CYG8o03ab?`0k/Sn0;O8oP21b878XlSm0?SoULSl0?78
o03^b?h0]lSn0878PLRSb?d0n?nEb?`0lLSl0>k8oP2gb?h0PLR1b:?8o@3ho`0l
PLSXb?h0]lSn0878PLRSb?d0n?n1b>S8oP2gb?h0PLR1b:?8o@3hoh78j<Sn0;O8
oP21b878XlSm0?So03b1b>S8oP2gb?h0PLR1b:?8o@3hoh78j<Sn0;O8oP21b878
XlSm0?SoPLSXb?h0]lSn0878PLRSb?d0n?l0?878jLSm0;O8oP21b878XlSm0?So
PLSYb?d0]lSn0878PLRSb?d0n?n1b>W8o@2gb?h0PLR1b:?8o@3ho`0lPLSYb?h0
]/Sn0878PLRSb?d0n?n1b>W8oP2fb?h0PLR1b:?8o@3hoh78jLSn0;K8oP21b878
XlSm0?So0321b9_8oP21b878XlSm0?SoPLRKb?h0PLR1b:?8o@3hoh78VlSn0878
PLRSb?d0n?l0<878VlSn0878PLRSb?d0n?n1b9_8oP21b878XlSm0?SoPLRKb?h0
PLR1b:?8o@3ho`0ZPLR1b878PLRjb?d0n?n1b878PLR1b;[8o@3hoh78PLR1b878
^/Sm0?So02Z1b878PLR1b;[8o@3hoh78PLR1b878^/Sm0?SoPLR1b878PLRjb?d0
n?l0:X78PLR1b878^/Sm0?SoPLR1b878PLRjb?d0n?n1b878PLR1b;[8o@3ho`0T
P@210840P@2f0?SoP@210840P@2f0?SoP@210840P@2f0?So02B10840P@210;H0
n?n10840P@210;H0n?n10840P@210;H0n?l09840P@210840]P3hoh40P@210840
]P3hoh40P@210840]P3ho`0TP@210840P@2f0?SoP@210840P@2f0?SoP@210840
P@2f0?So01b1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ohGo02B1I85TPFB1I=5T
gOn1I85TPFB1I=5TgOn1I85TPFB1I=5TgOl0985TPFB1I85TdFCMoh5TPFB1I85T
dFCMoh5TPFB1I85TdFCMo`0TPFB1I85TPFCAI=goPFB1I85TPFCAI=goPFB1I85T
PFCAI=go02B1I85TPFB1I=5TgOn1I85TPFB1I=5TgOn1I85TPFB1I=5TgOl0985T
PFB1I85TdFCMoh5TPFB1I85TdFCMoh5TPFB1I85TdFCMo`0TPFB1I85TPFCAI=go
PFB1I85TPFCAI=goPFB1I85TPFCAI=go02B1I85TPFB1I=5TgOn1I85TPFB1I=5T
gOn1I85TPFB1I=5TgOl0985TPFB1I85TdFCMoh5TPFB1I85TdFCMoh5TPFB1I85T
dFCMo`0TPFB1I85TPFCAI=goPFB1I85TPFCAI=goPFB1I85TPFCAI=go02B1I85T
PFB1I=5TgOn1I85TPFB1I=5TgOn1I85TPFB1I=5TgOl0985TPFB1I85TdFCMoh5T
PFB1I85TdFCMoh5TPFB1I85TdFCMo`0TPFB1I85TPFCAI=goPFB1I85TPFCAI=go
PFB1I85TPFCAI=go02B1I85TPFB1I=5TgOn1I85TPFB1I=5TgOn1I85TPFB1I=5T
gOl0985TPFB1I85TdFCMoh5TPFB1I85TdFCMoh5TPFB1I85TdFCMo`0TPFB1I85T
PFCAI=goPFB1I85TPFCAI=goPFB1I85TPFCAI=go02B1I85TPFB1I=5TgOn1I85T
PFB1I=5TgOn1I85TPFB1I=5TgOl0985TPFB1I85TdFCMoh5TPFB1I85TdFCMoh5T
PFB1I85TdFCMo`0TPFB1I85TPFCAI=goPFB1I85TPFCAI=goPFB1I85TPFCAI=go
02B1I85TPFB1I=5TgOn1I85TPFB1I=5TgOn1I85TPFB1I=5TgOl0985TPFB1I85T
dFCMoh5TPFB1I85TdFCMoh5TPFB1I85TdFCMo`0TPFB1I85TPFCAI=goPFB1I85T
PFCAI=goPFB1I85TPFCAI=go02B1I85TPFB1I=5TgOn1I85TPFB1I=5TgOn1I85T
PFB1I=5TgOl0985TPFB1I85TdFCMoh5TPFB1I85TdFCMoh5TPFB1I85TdFCMo`0T
PFB1I85TPFCAI=goPFB1I85TPFCAI=goPFB1I85TPFCAI=go02B1I85TPFB1I=5T
gOn1I85TPFB1I=5TgOn1I85TPFB1I=5TgOl0985TPFB1I85TdFCMoh5TPFB1I85T
dFCMoh5TPFB1I85TdFCMo`0TPFB1I85TPFCAI=goPFB1I85TPFCAI=goPFB1I85T
PFCAI=go02B1I85TPFB1I=5TgOn1I85TPFB1I=5TgOn1I85TPFB1I=5TgOl0985T
PFB1I85TdFCMoh5TPFB1I85TdFCMoh5TPFB1I85TdFCMo`0TPFB1I85TPFCAI=go
PFB1I85TPFCAI=goPFB1I85TPFCAI=go02B1I85TPFB1I=5TgOn1I85TPFB1I=5T
gOn1I85TPFB1I=5TgOl0985TPFB1I85TdFCMoh5TPFB1I85TdFCMoh5TPFB1I85T
dFCMo`0TPFB1I85TPFCAI=goPFB1I85TPFCAI=goPFB1I85TPFCAI=go02B1I85T
PFB1I=5TgOn1I85TPFB1I=5TgOn1I85TPFB1I=5TgOl0985TPFB1I85TdFCMoh5T
PFB1I85TdFCMoh5TPFB1I85TdFCMo`0TPFB1I85TPFCAI=goPFB1I85TPFCAI=go
PFB1I85TPFCAI=go02B1I85TPFB1I=5TgOn1I85TPFB1I=5TgOn1I85TPFB1I=5T
gOl0985TPFB1I85TdFCMoh5TPFB1I85TdFCMoh5TPFB1I85TdFCMo`0TPFB1I85T
PFCAI=goPFB1I85TPFCAI=goPFB1I85TPFCAI=go02B1I85TPFB1I=5TgOn1I85T
PFB1I=5TgOn1I85TPFB1I=5TgOl0985TPFB1I85TdFCMoh5TPFB1I85TdFCMoh5T
PFB1I85TdFCMo`0TPFB1I85TPFCAI=goPFB1I85TPFCAI=goPFB1I85TPFCAI=go
02B1I85TPFB1I=5TgOn1I85TPFB1I=5TgOn1I85TPFB1I=5TgOl0985TPFB1I85T
dFCMoh5TPFB1I85TdFCMoh5TPFB1I85TdFCMo`0TPFB1I85TPFCAI=goPFB1I85T
PFCAI=goPFB1I85TPFCAI=go02B1I85TPFB1I=5TgOn1I85TPFB1I=5TgOn1I85T
PFB1I=5TgOl0985TPFB1I85TdFCMoh5TPFB1I85TdFCMoh5TPFB1I85TdFCMo`0T
PFB1I85TPFCAI=goPFB1I85TPFCAI=goPFB1I85TPFCAI=go02B1I85TPFB1I=5T
gOn1I85TPFB1I=5TgOn1I85TPFB1I=5TgOl0985TPFB1I85TdFCMoh5TPFB1I85T
dFCMoh5TPFB1I85TdFCMo`0TPFB1I85TPFCAI=goPFB1I85TPFCAI=goPFB1I85T
PFCAI=go02B1I85TPFB1I=5TgOn1I85TPFB1I=5TgOn1I85TPFB1I=5TgOl0985T
PFB1I85TdFCMoh5TPFB1I85TdFCMoh5TPFB1I85TdFCMo`0TPFB1I85TPFCAI=go
PFB1I85TPFCAI=goPFB1I85TPFCAI=go02B1I85TPFB1I=5TgOn1I85TPFB1I=5T
gOn1I85TPFB1I=5TgOl0985TPFB1I85TdFCMoh5TPFB1I85TdFCMoh5TPFB1I85T
dFCMo`0TPFB1I85TPFCAI=goPFB1I85TPFCAI=goPFB1I85TPFCAI=go02B1I85T
PFB1I=5TgOn1I85TPFB1I=5TgOn1I85TPFB1I=5TgOl0985TPFB1I85TdFCMoh5T
PFB1I85TdFCMoh5TPFB1I85TdFCMo`0TPFB1I85TPFCAI=goPFB1I85TPFCAI=go
PFB1I85TPFCAI=go02B1I85TPFB1I=5TgOn1I85TPFB1I=5TgOn1I85TPFB1I=5T
gOl0985TPFB1I85TdFCMoh5TPFB1I85TdFCMoh5TPFB1I85TdFCMo`0TPFB1I85T
PFCAI=goPFB1I85TPFCAI=goPFB1I85TPFCAI=go02B1I85TPFB1I=5TgOn1I85T
PFB1I=5TgOn1I85TPFB1I=5TgOl0985TPFB1I85TdFCMoh5TPFB1I85TdFCMoh5T
PFB1I85TdFCMo`0TPFB1I85TPFCAI=goPFB1I85TPFCAI=goPFB1I85TPFCAI=go
02B1I85TPFB1I=5TgOn1I85TPFB1I=5TgOn1I85TPFB1I=5TgOl0985TPFB1I85T
dFCMoh5TPFB1I85TdFCMoh5TPFB1I85TdFCMo`0TPFB1I85TPFCAI=goPFB1I85T
PFCAI=goPFB1I85TPFCAI=go02B1I85TPFB1I=5TgOn1I85TPFB1I=5TgOn1I85T
PFB1I=5TgOl0985TPFB1I85TdFCMoh5TPFB1I85TdFCMoh5TPFB1I85TdFCMo`0T
PFB1I85TPFCAI=goPFB1I85TPFCAI=goPFB1I85TPFCAI=go02B1I85TPFB1I=5T
gOn1I85TPFB1I=5TgOn1I85TPFB1I=5TgOl0985TPFB1I85TdFCMoh5TPFB1I85T
dFCMoh5TPFB1I85TdFCMo`0TPFB1I85TPFCAI=goPFB1I85TPFCAI=goPFB1I85T
PFCAI=go02B1I85TPFB1I=5TgOn1I85TPFB1I=5TgOn1I85TPFB1I=5TgOl0985T
PFB1I85TdFCMoh5TPFB1I85TdFCMoh5TPFB1I85TdFCMo`0TPFB1I85TPFCAI=go
PFB1I85TPFCAI=goPFB1I85TPFCAI=go02B1I85TPFB1I=5TgOn1I85TPFB1I=5T
gOn1I85TPFB1I=5TgOl0985TPFB1I85TdFCMoh5TPFB1I85TdFCMoh5TPFB1I85T
dFCMo`0TPFB1I85TPFCAI=goPFB1I85TPFCAI=goPFB1I85TPFCAI=go02B1I85T
PFB1I=5TgOn1I85TPFB1I=5TgOn1I85TPFB1I=5TgOl0985TPFB1I85TdFCMoh5T
PFB1I85TdFCMoh5TPFB1I85TdFCMo`0LPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn5o`0LPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn5o`2P0;l0o`\>"], "NumberedFigure",
  ImageSize->{381, 62},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Figure 7.  Cross section of the Pigtail connector. The conductors \
have a thickness of 17\[Mu].\
\>", "Caption"],

Cell["\<\
Size and distance of the 4 conductors and the dielectric foil are \
mapped onto a 446 * 80 grid to calculate the coefficients of capacity and \
inductance of this system. Pairs of conductors are operated as differential \
lines to minimize disturbances. The width and distance of the conductors will \
be 22 and 66 grid squares, the thickness of the conductors and the dielectric \
(\[Epsilon] = 4) will be 3 and 9 squares. The numbers of squares should be \
chosen as large as program memory allows to minimize quantization \
error.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Code  (Coefficients of Induction for the pigtail)"
}], "Subsection",
  PageBreakAbove->True],

Cell["RAM requirements: Front End 40 MB,Kernel 80 MB", "Text"],

Cell[CellGroupData[{

Cell["\<\
v1=1.;v2=1.;v3=0.;v4=0.;(* potential of the electrodes *)
nz=80; (* # of rows of the grid, divisible by 2 *)
ns=446; (* # of columns of the grid, divisible by 2 *)
u=.;m=.;m=Array[u,{nz,ns}];a=Array[u,{nz,ns}];
mb=Table[0,{nz},{ns}];
\[Epsilon]=Table[1,{i,1,nz},{j,1,ns}];
eps=4;
exl=1;exr=ns;eyd=1;eyu=10; (* dielectric area *)
Do[Do[\[Epsilon][[i,j]]=eps,{i,eyd,eyu}],{j,exl,exr}];
Do[Do[a[[i,j]]=u[[i,j]],{j,1,ns}],{i,1,nz}]
Do[Do[
m[[i,j]]:=Evaluate[0.25(a[[i-1,j]]+a[[i,j-1]]+a[[i+1,j]]+
a[[i,j+1]])+
0.0625/\[Epsilon][[i,j]]((\[Epsilon][[i,j+1]]-\[Epsilon][[i,j-1]])(a[[i,j+1]]-\
a[[i,j-1]])+(\[Epsilon][[i+1,j]]-\[Epsilon][[i-1,j]])(a[[i+1,j]]-a[[i-1,j]]))]\
,
{j,2,ns-1}],{i,2,nz-1}]
Do[m[[1,j]]:=0.,{j,1,ns}]
Do[m[[nz,j]]:=0.,{j,1,ns}]
Do[m[[i,1]]:=0.,{i,1,nz}]
Do[m[[i,ns]]:=0.,{i,1,nz}]
xl1=80;xr1=102;yd1=11;yu1=14;
xl2=168;xr2=190;yd2=11;yu2=14;
xl3=256;xr3=278;yd3=11;yu3=14;
xl4=344;xr4=366;yd4=11;yu4=14;
Do[Do[{m[[i,j]]:=v1;mb[[i,j]]=1;},{j,xl1,xr1}],{i,yd1,yu1}]
Do[Do[{m[[i,j]]:=v2;mb[[i,j]]=1;},{j,xl2,xr2}],{i,yd2,yu2}]
Do[Do[{m[[i,j]]:=v3;mb[[i,j]]=1;},{j,xl3,xr3}],{i,yd3,yu3}]
Do[Do[{m[[i,j]]:=v4;mb[[i,j]]=1;},{j,xl4,xr4}],{i,yd4,yu4}]
(* uncomment next lines to verify coordinates *)
p1=ListPlot3D[\[Epsilon]-1,ViewPoint\[Rule]{3.,1.,1.},
      DisplayFunction\[Rule]Identity];
p2=ListPlot3D[mb,ViewPoint\[Rule]{3.,1.,1.},
DisplayFunction\[Rule]Identity];
Show[p1,p2,DisplayFunction\[Rule]$DisplayFunction];\
\>", "Input",
  CellLabel->"In[1]:=",
  CellFrame->True,
  PageBreakAbove->Automatic,
  ImageRegion->{{0, 1}, {0, 1}},
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(Part::"partd" \(\(:\)\(\ \)\) 
      "Part specification \!\(u \[LeftDoubleBracket] \(\(1, 1\)\) \
\[RightDoubleBracket]\) is longer than depth of object."\)], "Message",
  CellLabel->"From In[1]:="],

Cell[BoxData[
    \(Part::"partd" \(\(:\)\(\ \)\) 
      "Part specification \!\(u \[LeftDoubleBracket] \(\(1, 1\)\) \
\[RightDoubleBracket]\) is longer than depth of object."\)], "Message",
  CellLabel->"From In[1]:="],

Cell[BoxData[
    \(Part::"partd" \(\(:\)\(\ \)\) 
      "Part specification \!\(u \[LeftDoubleBracket] \(\(1, 2\)\) \
\[RightDoubleBracket]\) is longer than depth of object."\)], "Message",
  CellLabel->"From In[1]:="],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Part :: \"partd\"\) will be suppressed during \
this calculation."\)], "Message",
  CellLabel->"From In[1]:="],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P00022A000`40O003h00OogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooiioo`H000eoo`@00:eoo`00ogooogooWGoo20002Woo2000Zgoo003oOoooOonLOol30004Ool3
0009Ool20004Ool2002[Ool00?mooomooi]oo`<000Ioo`<000Moo`8000Ioo`800:Yoo`00ogooogoo
Vgoo0P0027oo0P001goo0P001Woo0P00ZWoo003oOoooOonKOol20008Ool20006Ool20008Ool2002Y
Ool00?mooomooi]oo`8000Qoo`8000Ioo`8000Qoo`800:Uoo`00ogooogooVgoo0`001Woo0`001Woo
0P0027oo0P00ZGoo003oOoooOonLOol30004Ool30007Ool20008Ool2002YOol00?mooomooieoo`P0
00Qoo`8000Qoo`800:Uoo`00ogooogooWGoo200027oo0P0027oo0P00ZGoo003oOoooOonLOol30004
Ool30007Ool20008Ool2002YOol00?mooomooi]oo`8000Qoo`8000Ioo`8000Qoo`800:Uoo`00ogoo
ogooVgoo0P0027oo0P001goo0P001Woo0P00ZWoo003oOoooOonKOol20008Ool20007Ool20006Ool2
002ZOol00?mooomooiaoo`<000Aoo`@000Qoo`8000Aoo`800:]oo`00ogooogooW7oo2P002Goo2000
Zgoo003oOoooOonNOol6000=Ool4002]Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogoo0goo1@003Goo1000ogooBWoo003oOoooOol1Ool8
000:Ool8003oOom8Ool00?mooomoo`5oo`8000Aoo`<000Uoo`8000Aoo`800?moodQoo`00ogooogoo
0P001Woo0`001goo0P001Woo0P00ogooAgoo003oOoonOol20008Ool20007Ool20006Ool2003oOom7
Ool00?moooioo`8000Qoo`8000Ioo`8000Qoo`800?moodIoo`00ogoooWoo0P0027oo0P001Woo0P00
27oo0P00ogooAWoo003oOoonOol20008Ool20006Ool20008Ool2003oOom6Ool00?moooioo`<000Io
o`<000Ioo`8000Qoo`8009Yoo`D00:Ioo`00ogoooWoo100017oo0`001goo0P0027oo0P00Tgoo1`00
17oo00<007ooOol0Y7oo003oOoonOol200000goo000000050008Ool20008Ool2002<Ool7000;Ool2
002UOol00?mooomoo`03001oogoo00D000Uoo`8000Qoo`8008Eoo`L0009oo`03001oogoo00eoo`80
0:Eoo`00ogooogoo0P003goo0P0027oo0P00OWoo1`002Goo00<007ooOol03Goo00<007oo0000Y7oo
003oOoooOol3000?Ool20006Ool2001hOol7000@Ool00`00Oomoo`0=Ool00`00Ool0002TOol00?mo
oomoo`5oo`<000ioo`8000Ioo`80071oo`P001Moo`03001oogoo00eoo`04001oogoo002SOol00?mo
oomoo`9oo`<000ioo`8000Aoo`8006Yoo`L001moo`03001oogoo00eoo`04001oogoo002SOol00?mo
oomoo`=oo`P000Qoo`P006=oo`L002Ioo`03001oogoo00eoo`05001oogooOol0002ROol00?mooomo
o`Eoo`H000Yoo`@005ioo`L000Eoo`03001oogoo03Eoo`05001oogooOol0002ROol00?mooomoog1o
o`L000aoo`03001oogoo03Eoo`03001oogoo009oo`03001oogoo09moo`00ogooogooJGoo1`004goo
00<007ooOol0=Goo00<007ooOol00Woo00<007ooOol0Wgoo003oOoooOomQOol8001BOol00`00Oomo
o`03Ool00`00Oomoo`2NOol00?moog1oo`L000Yoo`@00=Aoo`L005Yoo`03001oogoo00=oo`03001o
ogoo09ioo`00ogooL7oo1`0027oo2000bgoo1`000Woo00<007ooOol0GGoo00<007ooOol00goo00<0
07ooOol0WGoo003oOomcOol2000:Ool20004Ool20034Ool70009Ool00`00Oomoo`1;Ool5000=Ool0
0`00Oomoo`03Ool00`00Oomoo`2MOol00?moog=oo`8000Uoo`8000Ioo`800;aoo`L0011oo`03001o
ogoo04Aoo`L000E7?`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo09aoo`00ogooLgoo0P00
2Goo0P001Woo0P00]Goo1`005goo00<007ooOol0?7oo200014Lo100014Lo00<007ooOol02Woo00<0
07ooOol01Goo00<007ooOol0Vgoo003oOom[Ool<0006Ool20008Ool2002/Ool8001GOol60004Acl6
0002Acl40005Acl00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`2KOol00?moof]oo``000Io
o`8000Qoo`800:Eoo`L005]oo`@00097?`@000A7?`800097?`030017?dLo0097?`@000A7?`8000Yo
o`03001oogoo00Ioo`03001oogoo09Yoo`00ogooJgoo0P001Woo0P0000=oo`00Ool01Goo0P0027oo
0P00WWoo1`001Woo00<007ooOol0Dgoo1P001TLo10001DLo100014Lo10001DLo00<007ooOol027oo
00<007ooOol01Woo00<007ooOol0VWoo003oOom/Ool20005Ool20008Ool20008Ool2002GOol7000=
Ool00`00Oomoo`1;Ool80004Acl40005Acl40004Acl40005Acl40005Acl00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`2IOol00?moofaoo`<000Aoo`8000Qoo`8000Qoo`80091oo`L001Aoo`03
001oogoo04=oo`P000E7?`@000A7?`@000E7?`@000A7?`H000=7?`@000A7?`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo09Uoo`00ogooKGoo0P0017oo0P0027oo0P0027oo0P00RGoo1`00FGoo
2@0014Lo100014Lo1@0014Lo1P000TLo100014Lo0P001dLo100014Lo0P0027oo00<007ooOol027oo
00<007ooOol0V7oo003oOom^Ool20003Ool20008Ool20008Ool20021Ool8001IOol70005Acl40004
Acl400000dLo00000002Acl40004Acl20007Acl40004Acl40005Acl40004Acl00`00Oomoo`06Ool0
0`00Oomoo`08Ool00`00Oomoo`2HOol00?moofioo`<0009oo`8000Qoo`8000Qoo`8007Yoo`L000Ao
o`03001oogoo059oo`P000A7?`H000=7?`@000A7?`8000I7?`D000A7?`@000A7?`D000A7?`@000A7
?`H000=7?`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo09Moo`00ogooKgoo0P000Woo0P00
2Goo0P001Woo0P00M7oo1`002goo00<007ooOol0BWoo2P000TLo10001DLo0P001TLo100014Lo1000
1DLo100014Lo10001DLo100014Lo10001DLo0P001TLo00<007ooOol01Goo00<007ooOol02Goo00<0
07ooOol0Ugoo003oOom`Ool200000goo00000009Ool20006Ool2001]Ool7000BOol00`00Oomoo`12
Ool80004Acl20002Acl00`00Acm7?`02Acl40004Acl50004Acl40004Acl50004Acl40004Acl60003
Acl40004Acl40004Acl50004Acl00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`2FOol00?mo
og5oo`@000Yoo`8000Aoo`8006Moo`L001Uoo`03001oogoo03]oo`L000E7?`@000A7?`@000A7?`@0
00E7?`@000A7?`@000E7?`H00097?`@000A7?`8000M7?`@000A7?`@000E7?`@000A7?`8000Eoo`03
001oogoo00Yoo`03001oogoo09Ioo`00ogooLGoo10002Woo2000H7oo1`0087oo00<007ooOol0<goo
200014Lo100014Lo1@0014Lo100014Lo1@0014Lo1P000TLo100014Lo0P000TLo00<004LoAcl00TLo
100014Lo10001DLo100014Lo100014Lo100000=7?`0000000TLo00<007ooOol00goo00<007ooOol0
2goo00<007ooOol0UGoo003oOombOol3000<Ool4001JOol800000goo001oo`1BOol80004Acl50004
Acl40004Acl40004Acl40005Acl40004Acl20006Acl40005Acl40004Acl50004Acl40004Acl50004
Acl40004Acl20006Acl20004Ool00`00Oomoo`0;Ool00`00Oomoo`2EOol00?moomQoo`L000Uoo`03
001oogoo04Yoo`L000A7?`@000E7?`@000A7?`D000A7?`H00097?`@000A7?`D000A7?`@000A7?`@0
00E7?`@000A7?`@000A7?`@00003Acl000000097?`@000A7?`@000A7?`@000E7?`03001oogoo009o
o`03001oogoo00aoo`03001oogoo09Aoo`00g7oo30002goo1000fGoo1`0047oo00<007ooOol0@Woo
200014Lo100014Lo1@0014Lo100014Lo100014Lo0P001dLo100014Lo100014Lo1@0014Lo100014Lo
1@0014Lo100014Lo0P001TLo10001DLo100014Lo100014Lo0P000goo00<007ooOol037oo00<007oo
Ool0U7oo003LOol<0009Ool8003@Ool7000GOol00`00Oomoo`0kOol70004Acl50004Acl40004Acl6
0002Acl40004Acl50004Acl40004Acl50004Acl40004Acl40005Acl60002Acl40004Acl40004Acl5
0004Acl40004Acl50004Acl40004Acl01@00Oomoogoo00003goo00<007ooOol0Tgoo003MOol30006
Ool20009Ool20004Ool20039Ool7001DOol80004Acl40004Acl40004Acl40004Acl20002Acl00`00
Acm7?`02Acl40004Acl50004Acl40004Acl40004Acl50004Acl40004Acl20006Acl50004Acl40004
Acl40004Acl40005Acl40004Acl40004Acl20002Ool00`00Oomoo`0=Ool00`00Oomoo`2COol00=io
o`<000moo`8000Ioo`800<5oo`P0059oo`P000A7?`@000A7?`H000=7?`@000A7?`@000A7?`D000A7
?`@000A7?`@000A7?`D000A7?`H00097?`@000A7?`D000A7?`@000A7?`@000A7?`D000A7?`@000A7
?`H00097?`@000E7?`@000A7?`04001oogoo000@Ool00`00Oomoo`2BOol00=moo`<000ioo`8000Io
o`800;Uoo`P000Moo`03001oogoo04Uoo`L000A7?`D000A7?`@000A7?`8000I7?`D000A7?`@000A7
?`@000A7?`D000A7?`@000A7?`@000A7?`8000I7?`@000E7?`@000A7?`D000A7?`@000A7?`@000A7
?`@000A7?`800097?`030017?dLo0097?`@000A7?`@000E7?`03001oo`00011oo`03001oogoo099o
o`00h7oo0`0037oo0P0027oo0P00/Goo1`003goo00<007ooOol0@Goo200014Lo1P000TLo100014Lo
1@0014Lo100014Lo100014Lo1@0014Lo100014Lo1P000TLo100014Lo1@0014Lo100014Lo1@0014Lo
100014Lo100014Lo1P000dLo100014Lo100014Lo100014Lo1@0014Lo100014Lo00<007oo00004Goo
00<007ooOol0TGoo003QOol3000;Ool20008Ool2002ZOol7000FOol00`00Oomoo`0kOol60004Acl4
0004Acl20002Acl00`00Acm7?`02Acl40004Acl40004Acl50004Acl40004Acl40004Acl40004Acl2
0002Acl00`00Acm7?`02Acl40004Acl50004Acl40004Acl40004Acl50004Acl40004Acl20006Acl4
0004Acl50004Acl40004Acl40004Acl50004Acl2000AOol00`00Oomoo`2AOol00>9oo`<000Yoo`80
00Qoo`800:=oo`L005Qoo`<000=7?`@000A7?`@000A7?`@000A7?`D000A7?`@000A7?`D000=7?`H0
00=7?`@000A7?`@000A7?`D000A7?`@000A7?`@000A7?`D000A7?`@000A7?`@000A7?`@000A7?`D0
00A7?`@000A7?`@000A7?`D000A7?`@000A7?`@000A7?`80019oo`03001oogoo091oo`00hgoo0`00
2Goo0P0027oo0P00W7oo1`00FGoo1P001TLo1@0014Lo100014Lo100014Lo1@0014Lo100014Lo1000
14Lo0P001TLo1@0014Lo100014Lo100014Lo1@0014Lo100014Lo1P000TLo100014Lo1@0014Lo1000
14Lo100014Lo1@0014Lo100014Lo1P000TLo100014Lo1@0014Lo0P004Goo00<007ooOol0T7oo003T
Ool30008Ool20008Ool2002EOol70006Ool00`00Oomoo`1@Ool80004Acl40004Acl40004Acl50004
Acl40004Acl40004Acl40004Acl50004Acl40004Acl40004Acl50004Acl40004Acl40004Acl40004
Acl20002Acl00`00Acm7?`02Acl40004Acl40004Acl50004Acl40004Acl40004Acl40004Acl20002
Acl00`00Acm7?`02Acl40004Acl40004Acl2000BOol00`00Oomoo`2?Ool00>Eoo`8000Qoo`8000Qo
o`8008eoo`P000eoo`03001oogoo04Qoo`P000A7?`D000A7?`@000A7?`@000A7?`D000A7?`@000A7
?`@000A7?`@000A7?`@000A7?`D000A7?`@000A7?`@000A7?`D000A7?`@000A7?`@000A7?`@000A7
?`D000A7?`@000A7?`@000A7?`D000A7?`@000A7?`@000A7?`@000A7?`D000A7?`@000A7?`03001o
ogoo011oo`03001oogoo08moo`00iWoo0P001goo0P0027oo0P00QWoo1`005Goo00<007ooOol0@Goo
200014Lo100014Lo100014Lo1@0014Lo100014Lo1P000TLo100014Lo1@0014Lo100014Lo100014Lo
1@0014Lo100014Lo1P000TLo100014Lo100014Lo1@0014Lo100014Lo100014Lo1@0014Lo1P000TLo
100014Lo100014Lo1@0014Lo100014Lo100014Lo100014Lo00<007ooOol04Goo00<007ooOol0SWoo
003VOol20007Ool20008Ool2001oOol7001IOol70004Acl50004Acl40004Acl40004Acl50004Acl4
0003Acl20002Acl00`00Acm7?`02Acl40004Acl40004Acl50004Acl40004Acl40004Acl40004Acl2
0002Acl00`00Acm7?`02Acl40004Acl40004Acl40004Acl50004Acl40004Acl40004Acl20006Acl5
0004Acl40004Acl40004Acl40004Acl50004Acl40003Acl2000BOol00`00Oomoo`2>Ool00=eoo`80
00Moo`8000Qoo`8000Ioo`8007Uoo`L005Qoo`P000A7?`@000A7?`D000=7?`D000A7?`@000A7?`@0
00A7?`@000A7?`D000A7?`@000A7?`@000A7?`D000=7?`D000A7?`@000A7?`@000A7?`@000A7?`D0
00A7?`@000A7?`@000A7?`@000A7?`@000A7?`D000A7?`@000A7?`@000A7?`D000A7?`@000A7?`@0
00A7?`@000A7?`@000=7?`<0019oo`03001oogoo08eoo`00gGoo0`001Woo0P0027oo0P001Woo0P00
LWoo1`001Goo00<007ooOol0D7oo20000dLo1@0014Lo100014Lo100014Lo1@0014Lo10000dLo1@00
14Lo100014Lo100014Lo1@0014Lo100014Lo100014Lo100014Lo1@000dLo1@0014Lo100014Lo1000
14Lo1@0014Lo100014Lo100014Lo100014Lo100014Lo1@0014Lo100014Lo100014Lo100014Lo1000
14Lo1@0014Lo10000TLo00<004Lo00004Woo00<007ooOol0SGoo003MOol40004Ool2000:Ool20004
Ool2001/Ool7000<Ool00`00Oomoo`18Ool80004Acl50003Acl50004Acl40004Acl40004Acl40004
Acl40004Acl50004Acl40004Acl40004Acl50003Acl50004Acl40004Acl40004Acl40004Acl50003
Acl50004Acl40004Acl40004Acl40004Acl50003Acl50004Acl40004Acl40004Acl50004Acl40004
Acl40004Acl40004Acl40004Acl500001DLo0017?dLo00004Woo00<007ooOol0S7oo003NOol8000;
Ool8001UOol7000COol00`00Oomoo`11Ool80004Acl40004Acl40004Acl50004Acl40004Acl40004
Acl40004Acl40004Acl50003Acl50004Acl40004Acl40004Acl40004Acl50003Acl50004Acl40004
Acl40004Acl50003Acl50004Acl40004Acl40004Acl40004Acl40004Acl50004Acl40004Acl40004
Acl40004Acl40004Acl50004Acl40004Acl400001DLo0017?dLo00004goo00<007ooOol0Rgoo003P
Ool5000>Ool4001OOol8000JOol00`00Oomoo`0jOol80003Acl50004Acl40004Acl40004Acl60002
Acl40004Acl50003Acl50004Acl40004Acl40004Acl50004Acl40004Acl40004Acl40004Acl40004
Acl50003Acl50004Acl40004Acl40004Acl40004Acl40004Acl50004Acl40004Acl40004Acl40004
Acl50004Acl40003Acl50004Acl40004Acl40004Acl50003Acl60003Acl00`00Oomoo`0@Ool00`00
Oomoo`2;Ool00?mooe1oo`L0029oo`03001oogoo039oo`P000A7?`@000A7?`D000A7?`@000A7?`@0
00A7?`8000I7?`@000A7?`D000=7?`D000A7?`@000A7?`@000A7?`H00097?`@000A7?`D000=7?`D0
00A7?`@000A7?`@000A7?`D000=7?`H000=7?`@000A7?`@000A7?`@000A7?`@000A7?`D000A7?`@0
00A7?`@000A7?`@000A7?`@000A7?`@000A7?`D000A7?`@000A7?`@000A7?`D000=7?`03001oogoo
015oo`03001oogoo08Yoo`00I7oo1000h7oo1`001Woo00<007ooOol0CWoo200014Lo100014Lo1000
14Lo1@000dLo100014Lo1@000dLo1@0014Lo100014Lo100014Lo1@000dLo1@0014Lo10000dLo0P00
0TLo00<004LoAcl00TLo100014Lo100014Lo1@000dLo1@0014Lo100014Lo100014Lo0P001TLo1000
14Lo1@000dLo1@0014Lo100014Lo100014Lo1@000dLo100014Lo1@0014Lo100014Lo100014Lo1000
14Lo1@000dLo1@0014Lo100014Lo00<007ooOol047oo00<007ooOol0RWoo001ROol8003GOol7000<
Ool00`00Oomoo`18Ool80003Acl50004Acl40004Acl40004Acl40004Acl40004Acl50003Acl50004
Acl40004Acl40004Acl40004Acl40004Acl50003Acl50004Acl40004Acl40004Acl40004Acl50003
Acl50004Acl40004Acl40004Acl40004Acl40004Acl50003Acl50004Acl40004Acl40004Acl40004
Acl40004Acl50003Acl50004Acl40004Acl40004Acl40004Acl40004Acl00`00Oomoo`0AOol00`00
Oomoo`29Ool0069oo`8000Aoo`800=1oo`L001=oo`03001oogoo045oo`L000A7?`D000=7?`D000A7
?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`D000=7?`D000A7?`@000A7?`@000A7?`@000A7
?`@000A7?`D000=7?`D000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`D000=7?`D000A7
?`@000A7?`@000A7?`@000A7?`@000A7?`D000=7?`D000A7?`@000A7?`@000A7?`@000A7?`D000=7
?`@000A7?`D000A7?`@000A7?`03001oogoo011oo`03001oogoo08Uoo`00HGoo0P001Woo0P00b7oo
1`00EWoo200014Lo100014Lo1@000dLo1@000dLo1@0014Lo10000dLo1@0014Lo100014Lo100014Lo
1@000dLo1@0014Lo100014Lo100014Lo100014Lo100014Lo100014Lo1@000dLo1@0014Lo100014Lo
100014Lo100014Lo100014Lo100014Lo1@000dLo1@0014Lo100014Lo100014Lo100014Lo100014Lo
100014Lo1@000dLo1@0014Lo100014Lo100014Lo100014Lo100014Lo100014Lo0P004Woo00<007oo
Ool0R7oo001QOol20006Ool20030Ool8001FOol80004Acl40004Acl40004Acl40004Acl50003Acl4
0004Acl50003Acl50004Acl40004Acl40004Acl40004Acl50003Acl40004Acl50003Acl50004Acl4
0004Acl40004Acl40004Acl50003Acl40004Acl50003Acl50004Acl40004Acl40004Acl40004Acl5
0003Acl40004Acl50003Acl50004Acl40004Acl40004Acl40004Acl40004Acl40004Acl40004Acl5
0004Acl40004Acl40004Acl00`00Oomoo`0@Ool00`00Oomoo`28Ool0061oo`8000Qoo`800;Qoo`L0
00Ioo`03001oogoo04ioo`P000=7?`D000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`D0
00=7?`D000=7?`D000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`D000=7?`D000A7?`@0
00A7?`@000A7?`@000A7?`@000A7?`@000A7?`D000=7?`D000A7?`@000A7?`@000A7?`@000A7?`@0
00A7?`@000A7?`@000A7?`D000=7?`D000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@0
00A7?`D000=7?`80019oo`03001oogoo08Moo`00H7oo0P0027oo0P00/Goo1`003Goo00<007ooOol0
Agoo1`0014Lo1@000dLo1@0014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo1@00
0dLo1@0014Lo100014Lo10000dLo1@0014Lo100014Lo100014Lo100014Lo1@000dLo1@0014Lo1000
0dLo1@0014Lo100014Lo100014Lo100014Lo100014Lo1@000dLo100014Lo1@000dLo1@0014Lo1000
14Lo100014Lo100014Lo100014Lo100014Lo100014Lo1@000dLo1@0014Lo100014Lo100014Lo1000
14Lo00<007ooOol047oo00<007ooOol0Qgoo001POol20008Ool2002ZOol7000DOol00`00Oomoo`10
Ool70004Acl40004Acl50003Acl50004Acl40004Acl40003Acl50004Acl40004Acl40004Acl40004
Acl50003Acl50003Acl40004Acl50003Acl50004Acl40004Acl40004Acl40004Acl40004Acl40004
Acl40004Acl50003Acl50003Acl50004Acl40004Acl40004Acl40004Acl40004Acl40004Acl40004
Acl50003Acl50004Acl40004Acl40004Acl40004Acl40004Acl40004Acl40004Acl40004Acl50003
Acl40004Acl2000BOol00`00Oomoo`26Ool0061oo`8000Qoo`800:=oo`L005Ioo`P000A7?`@000A7
?`@000A7?`D000=7?`D000=7?`@000A7?`D000=7?`D000=7?`D000A7?`@000A7?`@000A7?`@000A7
?`@000A7?`@000A7?`@000A7?`D000=7?`D000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7
?`@000A7?`@000A7?`D000=7?`D000A7?`@000A7?`@000=7?`D000A7?`@000A7?`@000A7?`@000A7
?`@000A7?`D000=7?`@000A7?`D000=7?`D000A7?`@000A7?`@000A7?`@000A7?`@000=7?`D000A7
?`03001oogoo011oo`03001oogoo08Ioo`00H7oo0P0027oo0P00W7oo1`00EWoo200014Lo100014Lo
100014Lo100014Lo1@000dLo1@000dLo100014Lo1@000dLo1@000dLo1@0014Lo100014Lo100014Lo
100014Lo100014Lo100014Lo100014Lo1@000dLo1@000dLo1@0014Lo100014Lo10000dLo1@0014Lo
100014Lo100014Lo100014Lo100014Lo1@000dLo100014Lo100014Lo1@000dLo1@000dLo1@0014Lo
100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo1@000dLo1@0014Lo10000TLo
1P0014Lo00<007ooOol047oo00<007ooOol0QGoo001POol20008Ool2002DOol80006Ool00`00Oomo
o`1=Ool80003Acl50004Acl40004Acl40004Acl40004Acl50003Acl40004Acl40004Acl50003Acl5
0003Acl50004Acl40004Acl40004Acl40003Acl50004Acl40004Acl40004Acl40004Acl40004Acl5
0003Acl40004Acl40004Acl50003Acl50003Acl50004Acl40004Acl40004Acl40004Acl40004Acl4
0004Acl40004Acl40004Acl50003Acl50003Acl40004Acl50003Acl50003Acl50004Acl40004Acl4
0004Acl40004Acl40004Acl40002Acl00`00Acl000030004Acl00`00Oomoo`0@Ool00`00Oomoo`25
Ool0061oo`8000Qoo`8008eoo`L000ioo`03001oogoo03moo`l000=7?`D000A7?`@000A7?`@000A7
?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`D000=7?`D000=7?`D000A7?`@000=7
?`D000=7?`D000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7
?`D000=7?`D000=7?`D000A7?`@000=7?`D000=7?`D000A7?`@000A7?`@000A7?`@000A7?`@000A7
?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`D000=7?`D000=7?`D000A7?`@000=7?`D00004
Acl004LoAcl40004Acl00`00Oomoo`0@Ool00`00Oomoo`24Ool0061oo`8000Qoo`8008Ioo`L001Eo
o`03001oogoo03Qoo`L000A7?`@000=7?`D000=7?`D000A7?`@000A7?`@000A7?`@000A7?`@000A7
?`@000A7?`@000A7?`@000A7?`@000A7?`D000=7?`D000=7?`D000=7?`@000A7?`D000=7?`D000=7
?`D000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7
?`D000=7?`@000A7?`@000A7?`@000A7?`D000=7?`D000=7?`D000A7?`@000A7?`@000=7?`D000A7
?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@00004Acl004LoAcl40004
Acl00`00Oomoo`0@Ool00`00Oomoo`24Ool0065oo`8000Ioo`80081oo`L0051oo`L000A7?`@000=7
?`D000=7?`D000=7?`D000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7
?`@000A7?`@000A7?`D000=7?`@000A7?`@000A7?`@000A7?`D000=7?`D000=7?`D000=7?`D000A7
?`@000=7?`D000=7?`D000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7
?`@000A7?`@000A7?`@000A7?`D000=7?`@000A7?`@000A7?`@000A7?`D000=7?`D000=7?`D000A7
?`@000A7?`@000=7?`D000A7?`@000A7?`D000=7?`@000A7?`03001oogoo011oo`03001oogoo08=o
o`00HGoo0P001Woo0P00NGoo2000Cgoo1`0014Lo10000dLo1@000dLo1@000dLo1@000dLo1@0014Lo
100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo1@000dLo
100014Lo100014Lo100014Lo100014Lo1@000dLo1@000dLo1@000dLo100014Lo1@000dLo1@000dLo
1@000dLo1@0014Lo100014Lo100014Lo10000dLo1@0014Lo100014Lo100014Lo100014Lo100014Lo
100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo
100014Lo1@000dLo1@000dLo0P004Goo00<007ooOol0Pgoo001ROol20004Ool2001cOol70007Ool0
0`00Oomoo`16Ool70003Acl50004Acl40003Acl50003Acl50003Acl50003Acl50004Acl40004Acl4
0004Acl40003Acl50003Acl50004Acl40004Acl40004Acl40004Acl40004Acl40004Acl40004Acl4
0004Acl40004Acl40004Acl40004Acl50003Acl40004Acl40004Acl40004Acl40004Acl50003Acl5
0003Acl50003Acl40004Acl40004Acl50003Acl50003Acl50003Acl50003Acl50004Acl40003Acl5
0003Acl50003Acl50004Acl40004Acl40004Acl40004Acl40004Acl40004Acl40004Acl40004Acl5
0003Acl40004Acl00`00Oomoo`0@Ool00`00Oomoo`22Ool0069oo`P006]oo`P000ioo`03001oogoo
03moo`L000=7?`D000A7?`@000=7?`D000=7?`D000=7?`D000=7?`D000=7?`D000A7?`@000A7?`@0
00A7?`@000=7?`D000=7?`D000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@0
00A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@0
00A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`D000=7?`@000A7?`@0
00A7?`@000A7?`@000A7?`D000=7?`D000=7?`D000=7?`@000A7?`@000A7?`D000=7?`D000=7?`D0
00=7?`D000=7?`80015oo`03001oogoo089oo`00I7oo1000IWoo1`005Woo00<007ooOol0>7oo1`00
0dLo1@0014Lo100014Lo10000dLo1@000dLo1@000dLo1@000dLo1@0014Lo100014Lo100014Lo1000
0dLo1@000dLo1@000dLo1@000dLo1@0014Lo100014Lo100014Lo10000dLo1@000dLo1@000dLo1@00
14Lo100014Lo100014Lo100014Lo10000dLo1@0014Lo100014Lo100014Lo100014Lo100014Lo1000
14Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo1000
14Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo1000
14Lo100014Lo00<007ooOol047oo00<007ooOol0PGoo0037Ool7000MOol00`00Oomoo`0aOol70003
Acl50004Acl40004Acl40004Acl40003Acl50003Acl50003Acl50003Acl50004Acl40004Acl40004
Acl40003Acl50003Acl50003Acl50003Acl50004Acl40004Acl40004Acl40003Acl50003Acl50003
Acl50003Acl50004Acl40004Acl40004Acl40003Acl50003Acl50003Acl50003Acl50004Acl40004
Acl40004Acl40003Acl50003Acl50003Acl50003Acl50004Acl40004Acl40004Acl40003Acl50003
Acl50003Acl50003Acl50004Acl40004Acl40004Acl40003Acl50003Acl50003Acl50003Acl50004
Acl40004Acl40004Acl00`00Oomoo`0?Ool00`00Oomoo`21Ool00<1oo`L0009oo`03001oogoo01mo
o`03001oogoo02Yoo`L000=7?`D000A7?`@000A7?`@000A7?`@000=7?`D000=7?`D000=7?`D000=7
?`D000=7?`D000A7?`@000A7?`@000=7?`D000=7?`D000=7?`D000=7?`D000=7?`D000=7?`D000A7
?`@000=7?`D000=7?`D000=7?`D000=7?`D000=7?`D000=7?`D000=7?`@000A7?`@000A7?`D000=7
?`D000=7?`D000=7?`D000=7?`D000=7?`@000A7?`@000A7?`@000A7?`@000A7?`D000=7?`D000=7
?`D000=7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`D000=7?`@000A7
?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`03001oogoo011oo`03001oogoo081o
o`00^Goo1`002Goo00<007ooOol0AGoo1`0014Lo0`001DLo100014Lo100014Lo100014Lo10000dLo
1@000dLo1@000dLo1@000dLo1@000dLo1@0014Lo100014Lo10000dLo1@000dLo1@000dLo1@000dLo
1@000dLo1@000dLo1@000dLo100014Lo100014Lo1@000dLo1@000dLo1@000dLo1@000dLo1@000dLo
100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo
100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo
100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo10000dLo0P004Goo
00<007ooOol0P7oo002bOol7000@Ool00`00Oomoo`0nOol70004Acl40004Acl40004Acl40004Acl4
0004Acl40004Acl40003Acl50003Acl50003Acl50003Acl50004Acl40004Acl40004Acl40003Acl5
0003Acl50003Acl50003Acl50003Acl50003Acl50003Acl40004Acl40004Acl40004Acl40004Acl4
0004Acl50003Acl50003Acl40004Acl40004Acl40004Acl40004Acl40004Acl40004Acl40004Acl4
0004Acl40004Acl40004Acl40004Acl40004Acl40004Acl40004Acl40003Acl50003Acl50003Acl5
0003Acl50003Acl50003Acl50003Acl40004Acl40004Acl40004Acl50003Acl50003Acl50003Acl5
0003Acl40004Acl00`00Oomoo`0@Ool00`00Oomoo`1oOol00:Yoo`P0055oo`L000A7?`@000A7?`@0
00A7?`@000A7?`@000A7?`@000A7?`@000=7?`D000=7?`D000=7?`D000=7?`D000=7?`D000A7?`@0
00A7?`@000=7?`D000=7?`D000=7?`D000=7?`D000=7?`D000=7?`D000=7?`@000A7?`@000A7?`@0
00A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@0
00A7?`@000A7?`@000=7?`D000=7?`D000=7?`D000=7?`D000=7?`D000=7?`D000=7?`D000=7?`@0
00A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@0
00A7?`@000A7?`@000A7?`@000A7?`@000A7?`03001oogoo00moo`03001oogoo07moo`00Xgoo1`00
DWoo1`0014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo10000dLo1@000dLo1@00
0dLo1@000dLo1@0014Lo100014Lo100014Lo10000dLo1@000dLo1@000dLo1@000dLo1@000dLo1@00
0dLo1@000dLo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo10000dLo1@00
0dLo1@000dLo1@000dLo1@000dLo1@000dLo1@000dLo100014Lo100014Lo100014Lo100014Lo1000
14Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo1000
0dLo1@000dLo1@000dLo1@000dLo1@000dLo1@000dLo1@000dLo100014Lo100014Lo00<007ooOol0
47oo00<007ooOol0OWoo002LOol70004Ool00`00Oomoo`1;Ool80003Acl40004Acl40004Acl40004
Acl40004Acl40004Acl40004Acl40004Acl40003Acl50003Acl50004Acl30005Acl40004Acl40004
Acl40004Acl40003Acl50003Acl50003Acl50003Acl50003Acl50003Acl50003Acl40004Acl40004
Acl40004Acl40004Acl40004Acl40004Acl40004Acl40003Acl50003Acl50003Acl50003Acl50003
Acl50003Acl50003Acl40004Acl40004Acl40004Acl40004Acl40004Acl40004Acl40004Acl40003
Acl50003Acl50003Acl50003Acl50003Acl50003Acl50003Acl40004Acl40004Acl40004Acl40004
Acl40004Acl40004Acl40003Acl50004Acl40004Acl00`00Oomoo`0?Ool00`00Oomoo`1nOol009Eo
o`L000]oo`03001oogoo04Eoo`H000E7?`<000A7?`@000A7?`@000A7?`@000A7?`@000A7?`D000=7
?`D000=7?`@000A7?`<000E7?`<000E7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000=7
?`D000=7?`D000=7?`D000=7?`D000=7?`D000=7?`D000=7?`@000A7?`@000A7?`@000A7?`@000A7
?`@000A7?`@000A7?`@000A7?`@000=7?`D000=7?`D000=7?`D000=7?`@000A7?`@000A7?`@000A7
?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000=7?`D000=7?`@000A7
?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7
?`@00097?`030017?`0000<000=7?`@000A7?`03001oogoo011oo`03001oogoo07eoo`00SWoo1`00
4Woo00<007ooOol0?Woo1`0014Lo100014Lo10000dLo1@000dLo1@000dLo1@000dLo1@000dLo1@00
0dLo1@000dLo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo10000dLo1@00
0dLo1@000dLo1@000dLo1@000dLo100014Lo100014Lo100014Lo10000dLo1@000dLo1@000dLo1@00
0dLo1@000dLo1@000dLo1@000dLo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo1000
14Lo10000dLo1@000dLo1@000dLo1@000dLo1@000dLo1@000dLo1@000dLo100014Lo100014Lo1000
14Lo100014Lo100014Lo100014Lo100014Lo10000dLo1@000dLo1@000dLo1@000dLo1@000dLo1000
14Lo10000TLo00<004Lo00000`0014Lo100014Lo00<007ooOol047oo00<007ooOol0O7oo0027Ool7
001COol70004Acl40004Acl40004Acl40003Acl50003Acl50003Acl50003Acl50003Acl50003Acl5
0003Acl40004Acl40004Acl40004Acl40004Acl40004Acl40004Acl40004Acl40003Acl50003Acl5
0003Acl40004Acl40004Acl40004Acl40004Acl40003Acl50003Acl50003Acl50003Acl50003Acl5
0003Acl50003Acl40004Acl40004Acl40004Acl40004Acl40004Acl40004Acl40004Acl40003Acl5
0003Acl50003Acl50003Acl40004Acl40004Acl40004Acl40004Acl40004Acl40004Acl40003Acl5
0003Acl50003Acl50003Acl50003Acl40004Acl40004Acl40004Acl40004Acl40004Acl40004Acl4
000014Lo0017?dLo10000dLo1@000dLo0P004Goo00<007ooOol0O7oo001oOol8001COol70004Acl4
0004Acl40004Acl40004Acl40003Acl50003Acl50003Acl50003Acl50003Acl50003Acl50003Acl4
0004Acl40004Acl40004Acl40004Acl40004Acl40004Acl40004Acl40003Acl50003Acl40004Acl4
0004Acl40004Acl40004Acl40004Acl40003Acl50003Acl50003Acl50003Acl50003Acl50003Acl5
0003Acl40004Acl40004Acl40004Acl40004Acl40004Acl40003Acl50003Acl40004Acl40004Acl4
0004Acl40004Acl40004Acl40004Acl40004Acl40003Acl50003Acl50003Acl50003Acl40004Acl4
0004Acl40004Acl40004Acl40004Acl40004Acl40003Acl50003Acl50003Acl50003Acl60002Acl4
0004Acl40004Acl00`00Oomoo`0@Ool00`00Oomoo`1kOol007Qoo`L000Moo`03001oogoo04Yoo`P0
00=7?`D000=7?`D000=7?`D000=7?`D000=7?`@000A7?`<000E7?`<000A7?`D000=7?`D000=7?`D0
00=7?`D000=7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000=7?`@0
00A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000=7?`D000=7?`D000=7?`D000=7?`D0
00=7?`D000=7?`@000A7?`@000A7?`@000=7?`D000=7?`D000=7?`D000=7?`D000=7?`D000=7?`@0
00A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000=7?`D000=7?`@000A7?`@000A7?`@000A7?`@0
00A7?`@000A7?`@000A7?`@000A7?`@000=7?`D000=7?`D000=7?`@000A7?`@000A7?`@000A7?`@0
00A7?`D000=7?`@000=7?`D000=7?`80015oo`03001oogoo07]oo`00LGoo1`003Woo00<007ooOol0
?Goo3P000dLo1@000dLo1@000dLo1@000dLo1@000dLo1@000dLo100014Lo100014Lo0`001DLo0`00
1DLo0`0014Lo1@000dLo1@000dLo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo1000
14Lo10000dLo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo10000dLo1@000dLo1@00
0dLo1@000dLo100014Lo100014Lo100014Lo10000dLo1@000dLo1@000dLo1@000dLo1@000dLo1@00
0dLo100014Lo100014Lo10000dLo1@000dLo1@000dLo1@000dLo1@000dLo1@000dLo100014Lo1000
14Lo100014Lo100014Lo10000dLo1@000dLo1@000dLo100014Lo100014Lo100014Lo100014Lo1000
14Lo100014Lo10000dLo1@000dLo100014Lo100014Lo00<007ooOol047oo00<007ooOol0NWoo001Z
Ool7000EOol00`00Oomoo`0fOol70003Acl40004Acl30005Acl30005Acl30005Acl30004Acl50003
Acl50003Acl40004Acl40004Acl40004Acl40004Acl30005Acl30005Acl30004Acl40004Acl40004
Acl40004Acl40004Acl40004Acl40004Acl40004Acl30004Acl40004Acl40004Acl40004Acl40004
Acl40004Acl40004Acl40003Acl50003Acl40004Acl40004Acl40004Acl40004Acl40004Acl40003
Acl50003Acl50003Acl40004Acl40004Acl40004Acl40004Acl40003Acl50003Acl50003Acl50003
Acl40004Acl40004Acl40004Acl40003Acl50003Acl50003Acl50003Acl50003Acl40004Acl40004
Acl40004Acl40003Acl50003Acl50003Acl50003Acl40004Acl40004Acl40004Acl40004Acl40003
Acl2000AOol00`00Oomoo`1jOol006=oo`L004ioo`L000A7?`<000E7?`<000A7?`@000A7?`@000A7
?`@000A7?`<000E7?`<000E7?`<000E7?`<000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7
?`<000E7?`<000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`<000A7?`@000A7
?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000=7?`@000A7?`@000A7?`@000A7?`@000A7
?`@000A7?`@000A7?`@000=7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000=7
?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000=7?`@000A7?`@000A7?`@000A7
?`@000A7?`@000A7?`@000A7?`@000=7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7
?`@000=7?`@000A7?`@000A7?`03001oogoo011oo`03001oogoo07Uoo`00G7oo1`000Woo00<007oo
Ool0BWoo1P0014Lo100014Lo100014Lo0`0014Lo100014Lo100014Lo100014Lo100014Lo100014Lo
100014Lo0`0014Lo100014Lo100014Lo100014Lo100014Lo100014Lo100014Lo0`0014Lo100014Lo
100014Lo100014Lo100014Lo100014Lo100014Lo0`0014Lo100014Lo100014Lo100014Lo100014Lo
100014Lo10000dLo100014Lo100014Lo100014Lo100014Lo100014Lo10000dLo1@000dLo1@000dLo
100014Lo100014Lo100014Lo100014Lo10000dLo1@000dLo1@000dLo100014Lo100014Lo100014Lo
10000dLo1@000dLo1@000dLo1@000dLo100014Lo100014Lo100014Lo10000dLo1@000dLo1@000dLo
1@000dLo100014Lo100014Lo10000dLo1@000dLo1@000dLo1@000dLo100014Lo100014Lo100014Lo
00<007ooOol03goo00<007ooOol0NGoo001HOol40009Ool00`00Oomoo`13Ool70003Acl40004Acl4
0004Acl40004Acl40003Acl50003Acl50003Acl40004Acl40004Acl40004Acl40004Acl40003Acl5
0003Acl40004Acl40004Acl40004Acl40004Acl40004Acl40003Acl40004Acl40004Acl40004Acl4
0004Acl40004Acl40004Acl30004Acl40004Acl40004Acl40004Acl40004Acl40003Acl50003Acl5
0003Acl40004Acl40004Acl40004Acl40003Acl50003Acl50003Acl50003Acl40004Acl40004Acl4
0003Acl50003Acl50003Acl50003Acl40004Acl40004Acl40003Acl50003Acl50003Acl50003Acl4
0004Acl40004Acl40003Acl50003Acl50003Acl50003Acl40004Acl40004Acl40004Acl40003Acl5
0003Acl40004Acl40004Acl40004Acl40004Acl40004Acl40003Acl40004Acl00`00Oomoo`0@Ool0
0`00Oomoo`1hOol005Qoo`03001oo`0000Uoo`03001oogoo03eoo`L000=7?`D00097?`H000=7?`D0
00=7?`D000=7?`@000A7?`@000=7?`D000=7?`D000=7?`D000=7?`@000A7?`@000A7?`@000A7?`@0
00=7?`D000=7?`@000A7?`@000A7?`@000A7?`@000A7?`@000A7?`<000A7?`@000A7?`@000A7?`@0
00A7?`@000A7?`@000=7?`D000=7?`@000A7?`@000A7?`@000A7?`@000=7?`D000=7?`D000=7?`D0
00=7?`@000A7?`@000A7?`@000=7?`D000=7?`D000=7?`D000=7?`@000A7?`@000=7?`D000=7?`D0
00=7?`D000=7?`D000=7?`@000A7?`@000A7?`@000=7?`D000=7?`D000=7?`@000A7?`@000A7?`@0
00A7?`@000A7?`@000=7?`@000A7?`@000A7?`@000A7?`@000A7?`@000=7?`D000=7?`@000A7?`@0
00A7?`@000A7?`@000A7?`@000=7?`D000=7?`D000=7?`@000A7?`@000A7?`03001oogoo00moo`03
001oogoo07Qoo`00@Woo10004Woo00@007ooOol000Qoo`03001oogoo03Ioo`L000A7?`<000E7?`<0
0097?`H000A7?`D000=7?`D000=7?`D000=7?`@000A7?`<000A7?`D000=7?`D000=7?`D000=7?`@0
00A7?`@000A7?`@000=7?`D000=7?`D000=7?`@000A7?`@000A7?`@000A7?`@000A7?`<000A7?`@0
00A7?`@000A7?`@000A7?`@000A7?`<000A7?`D000=7?`@000A7?`@000A7?`@000A7?`<000A7?`D0
00=7?`D000=7?`D000=7?`@000A7?`@000=7?`D000=7?`D000=7?`D000=7?`@000A7?`@000A7?`@0
00=7?`D000=7?`D000=7?`@000A7?`@000A7?`@000A7?`@000A7?`@000=7?`@000A7?`@000A7?`@0
00A7?`@000A7?`@000=7?`D000=7?`@000A7?`@000A7?`@000A7?`@000=7?`D000=7?`D000=7?`@0
00A7?`@000A7?`@000=7?`D000=7?`D000=7?`@000A7?`@000A7?`@000A7?`@000=7?`D000=7?`03
001oogoo011oo`03001oogoo07Moo`00@7oo200047oo00@007ooOomoo`8000Ioo`03001oogoo031o
o`H000E7?`<000A7?`@000A7?`/000E7?`<000E7?`<000A7?`D000=7?`@000A7?`<000E7?`<000A7
?`D000=7?`D000=7?`D000=7?`@000A7?`@000=7?`D000=7?`D000=7?`@000A7?`@000A7?`@000A7
?`@000A7?`@000=7?`@000A7?`@000A7?`@000A7?`@000A7?`<000A7?`D000=7?`@000A7?`@000A7
?`@000=7?`D000=7?`D000=7?`D000=7?`D000=7?`@000=7?`D000=7?`D000=7?`D000=7?`@000A7
?`@000A7?`@000A7?`@000=7?`@000A7?`@000A7?`@000A7?`@000A7?`@000=7?`D000=7?`@000A7
?`@000A7?`@000=7?`D000=7?`D000=7?`D000=7?`@000A7?`@000=7?`D000=7?`D000=7?`D000=7
?`@000A7?`@000A7?`@000A7?`@000=7?`@000A7?`@000A7?`@000A7?`@000A7?`@000=7?`D000=7
?`D000=7?`@000A7?`03001oogoo00moo`03001oogoo07Moo`00@7oo0P0017oo0P0047oo00<007oo
Ool00goo00<007ooOol0;goo1`0014Lo100014Lo10000dLo100014Lo300014Lo100014Lo0`001DLo
0`001DLo0`0014Lo100014Lo0`001DLo0`0014Lo1@000dLo1@000dLo1@000dLo10000dLo1@000dLo
1@000dLo1@000dLo100014Lo100014Lo100014Lo10000dLo100014Lo100014Lo100014Lo100014Lo
0`0014Lo1@000dLo1@000dLo100014Lo0`0014Lo1@000dLo1@000dLo1@000dLo100014Lo100014Lo
10000dLo1@000dLo100014Lo100014Lo100014Lo10000dLo1@000dLo100014Lo100014Lo10000dLo
1@000dLo1@000dLo1@000dLo100014Lo10000dLo1@000dLo1@000dLo100014Lo100014Lo100014Lo
10000dLo100014Lo100014Lo100014Lo100014Lo10000dLo1@000dLo1@000dLo100014Lo10000dLo
1@000dLo1@000dLo10000dLo1@0014Lo100014Lo10000dLo00<007ooOol047oo00<007ooOol0MWoo
000oOol20006Ool2000?Ool00`00Ool000020002Ool00`00Oomoo`0XOol60004Acl50003Acl50003
Acl40004Acl40003Acl<0004Acl40004Acl40004Acl40004Acl30005Acl30004Acl40004Acl30005
Acl30004Acl50003Acl50003Acl50003Acl40003Acl50003Acl50003Acl40004Acl40004Acl40004
Acl40004Acl30004Acl40004Acl40004Acl40004Acl30004Acl50003Acl50003Acl40003Acl50003
Acl50003Acl50003Acl40004Acl40004Acl40004Acl40003Acl40004Acl40004Acl40004Acl40003
Acl50003Acl50003Acl40004Acl40003Acl50003Acl50003Acl40004Acl40004Acl40004Acl40003
Acl40004Acl40004Acl40004Acl40003Acl50003Acl50003Acl40004Acl40003Acl50003Acl50003
Acl40004Acl40004Acl40004Acl40003Acl40004Acl40004Acl40004Acl40002Acl00`00Acl00003
0003Acl50003Acl40004Acl00`00Oomoo`0?Ool00`00Oomoo`1fOol003moo`8000Ioo`8000ioo`<0
00Ioo`80025oo`L000A7?`<000E7?`<000E7?`<000A7?`D000=7?`@000=7?`d000=7?`D000=7?`@0
00A7?`@000A7?`@000A7?`<000A7?`@000A7?`@000A7?`<000E7?`<000A7?`D000=7?`D000=7?`@0
00=7?`D000=7?`D000=7?`D000=7?`@000A7?`@000A7?`@000A7?`<000A7?`@000A7?`@000A7?`@0
00A7?`<000A7?`D000=7?`D000=7?`@000=7?`D000=7?`D000=7?`D000=7?`@000A7?`@000A7?`@0
00=7?`@000A7?`@000A7?`@000A7?`@000=7?`D000=7?`D000=7?`D000=7?`@000=7?`D000=7?`D0
00=7?`@000A7?`@000A7?`@000A7?`@000=7?`@000A7?`@000A7?`@000A7?`@000=7?`D000=7?`D0
00=7?`@000A7?`@000=7?`D000=7?`@000A7?`@000A7?`@000A7?`@000=7?`D000=7?`@000A7?`@0
00A7?`@000=7?`D000=7?`D00003Acl004Lo00@000A7?`@000A7?`@000A7?`03001oogoo00moo`03
001oogoo07Eoo`00?Woo0P0027oo0P003Woo00<007ooOol01goo00<007ooOol04Goo3P000dLo1000
14Lo100014Lo100014Lo0`001DLo0`001DLo0`000TLo3@0014Lo1@000dLo1@000dLo100014Lo1000
14Lo10000dLo100014Lo100014Lo100014Lo0`001DLo0`0014Lo1@000dLo100014Lo0`0014Lo1@00
0dLo1@000dLo100014Lo100014Lo100014Lo0`0014Lo100014Lo100014Lo10000dLo1@000dLo1@00
0dLo1@000dLo100014Lo10000dLo1@000dLo100014Lo100014Lo100014Lo0`0014Lo1@000dLo1000
14Lo10000dLo1@000dLo1@000dLo1@000dLo100014Lo100014Lo10000dLo100014Lo100014Lo1000
0dLo1@000dLo1@000dLo100014Lo10000dLo1@000dLo1@000dLo100014Lo100014Lo100014Lo1000
0dLo100014Lo100014Lo10000dLo1@000dLo1@000dLo100014Lo100014Lo10000dLo100014Lo1000
14Lo100000A7?`00Acm7?`@000=7?`D000=7?`D000=7?`03001oogoo00moo`03001oogoo07Eoo`00
?Woo0P0027oo0P003Goo00<007ooOol02Goo0P003Goo10000dLo1@000dLo10000dLo1@000dLo1@00
0dLo100014Lo100014Lo100014Lo0`0000E7?`00000007lA00X000E7?`<000A7?`D000=7?`D000=7
?`@000A7?`@000A7?`@000=7?`@000A7?`@000A7?`@000A7?`<000A7?`D000=7?`D000=7?`@000=7
?`D000=7?`D000=7?`@000A7?`@000A7?`@000A7?`<000A7?`@000A7?`@000A7?`<000A7?`D000=7
?`D000=7?`@000A7?`@000A7?`@000=7?`@000A7?`@000A7?`@000A7?`@000=7?`D000=7?`D000=7
?`@000=7?`D000=7?`D000=7?`D000=7?`@000A7?`@000A7?`@000=7?`@000A7?`@000A7?`@000=7
?`D000=7?`D000=7?`@000A7?`@000A7?`@000=7?`@000A7?`@000A7?`@000A7?`@000=7?`D000=7
?`D000=7?`@000=7?`D000=7?`D000=7?`@000A7?`@000A7?`@000=7?`D000=7?`@000A7?`@000A7
?`@000=7?`D00003Acl004Lo00@000A7?`@000A7?`@000A7?`03001oogoo00moo`03001oogoo07Ao
o`00?Woo0P0027oo0P003Goo00<007ooOol02goo00<007ooOol02goo0`001DLo0`001DLo0`0014Lo
0`001DLo0`0014Lo1@000dLo100014Lo100014Lo1`0000=o4@0000002@0014Lo0`001DLo0`001DLo
0`0014Lo1@000dLo100014Lo10000dLo1@000dLo100014Lo100014Lo0`001DLo0`0014Lo1@000dLo
100014Lo0`0014Lo1@000dLo100014Lo100014Lo100014Lo0`0014Lo100014Lo100014Lo0`0014Lo
1@000dLo1@000dLo100014Lo100014Lo100014Lo0`0014Lo100014Lo10000dLo1@000dLo1@000dLo
100014Lo100014Lo10000dLo1@000dLo100014Lo100014Lo10000dLo1@000dLo1@000dLo10000dLo
1@000dLo1@000dLo100014Lo100014Lo10000dLo1@000dLo100014Lo10000dLo1@000dLo1@000dLo
100014Lo100014Lo10000dLo100014Lo100014Lo10000dLo1@000dLo1@000dLo100014Lo100014Lo
10000dLo100014Lo100000A7?`00Acm7?`@000A7?`@000=7?`D000=7?`03001oogoo00moo`03001o
ogoo07Aoo`00?Woo0P0027oo0P003Goo00<007ooOol037oo00<007ooOol02goo100014Lo100014Lo
0`001DLo0`0014Lo0`001DLo0`0014Lo1@000dLo1@000dLo1`0000=o4@0000002@0014Lo100014Lo
100014Lo0`0014Lo1@000dLo1@000dLo100014Lo10000dLo100014Lo100014Lo100014Lo0`0014Lo
1@000dLo1@000dLo10000dLo1@000dLo1@000dLo100014Lo100014Lo0`0014Lo1@000dLo100014Lo
0`0014Lo1@000dLo1@000dLo100014Lo100014Lo10000dLo100014Lo100014Lo0`0014Lo1@000dLo
1@000dLo100014Lo100014Lo10000dLo100014Lo100014Lo10000dLo1@000dLo1@000dLo100014Lo
10000dLo1@000dLo100014Lo100014Lo10000dLo1@000dLo100014Lo10000dLo1@000dLo100014Lo
100014Lo100014Lo10000dLo1@000dLo100014Lo10000dLo1@000dLo100014Lo100014Lo10000dLo
1@000dLo100014Lo100014Lo1@000TLo1@000dLo100014Lo100014Lo00<007ooOol03goo00<007oo
Ool0Lgoo000nOol20008Ool2000=Ool00`00Oomoo`0=Ool2000<Ool50003Acl40004Acl40004Acl3
0004Acl40004Acl30005Acl30005Acl30004AclD0003Acl40004Acl40004Acl30005Acl30004Acl5
0003Acl50003Acl40003Acl50003Acl40004Acl40004Acl30005Acl30004Acl50003Acl40003Acl5
0003Acl50003Acl40004Acl40004Acl30004Acl50003Acl50003Acl40003Acl50003Acl40004Acl4
0004Acl40004Acl30004Acl50003Acl40003Acl50003Acl50003Acl40004Acl40004Acl40003Acl5
0003Acl40004Acl40003Acl50003Acl50003Acl40004Acl40004Acl40003Acl40004Acl40004Acl4
0003Acl50003Acl40004Acl40004Acl40003Acl40004Acl40004Acl40003Acl50003Acl50003Acl4
0004Acl40004Acl40003Acl40004Acl40004Acl40003Acl50003Acl40004Acl40004Acl40003Acl5
0003Acl40004Acl40003Acl50003Acl00`00Oomoo`0?Ool00`00Oomoo`1cOol003ioo`8000Qoo`80
00eoo`03001oogoo00moo`03001oogoo00]oo`<000E7?`<000A7?`D000=7?`@000A7?`@000=7?`@0
00A7?`@000A7?`<000A7?a@000A7?`@000=7?`@000A7?`@000A7?`<000E7?`<000A7?`D000=7?`@0
00A7?`@000=7?`@000A7?`@000A7?`@000A7?`<000A7?`D000=7?`@000A7?`@000=7?`D000=7?`@0
00A7?`@000A7?`<000A7?`D000=7?`D000=7?`@000=7?`D000=7?`@000A7?`@000A7?`@000=7?`D0
00=7?`D000=7?`@000=7?`D000=7?`D000=7?`@000A7?`@000A7?`<000A7?`D000=7?`@000=7?`D0
00=7?`D000=7?`@000A7?`@000A7?`@000=7?`D000=7?`@000=7?`D000=7?`D000=7?`@000A7?`@0
00A7?`@000=7?`D000=7?`@000A7?`@000=7?`D000=7?`@000A7?`@000A7?`@000=7?`D000=7?`@0
00A7?`@000=7?`D000=7?`@000A7?`@000A7?`@000=7?`D000=7?`@000A7?`@000=7?`D000=7?`@0
00A7?`@000A7?`03001oogoo00moo`03001oogoo079oo`00?Woo0P0027oo0P003Goo00<007ooOol0
47oo00<007ooOol02goo100014Lo0`001DLo0`0014Lo1@000dLo100014Lo10000dLo100014Lo1000
0TLo2@0000=o4@0000002P000dLo100014Lo10000dLo100014Lo100014Lo0`001DLo0`0014Lo1@00
0dLo100014Lo10000dLo100014Lo100014Lo0`0014Lo1@000dLo1@000dLo100014Lo10000dLo1000
14Lo100014Lo0`0014Lo1@000dLo1@000dLo100014Lo10000dLo100014Lo100014Lo0`0014Lo1@00
0dLo100014Lo100014Lo10000dLo100014Lo100014Lo10000dLo1@000dLo100014Lo100014Lo1000
0dLo100014Lo100014Lo10000dLo1@000dLo100014Lo100014Lo10000dLo100014Lo100014Lo1000
0dLo1@000dLo100014Lo100014Lo10000dLo100014Lo100014Lo10000dLo1@000dLo100014Lo1000
14Lo10000dLo100014Lo10000dLo1@000dLo1@000dLo100014Lo10000dLo100014Lo100014Lo1000
0dLo1@000dLo00<007ooOol03goo00<007ooOol0LWoo000nOol20008Ool2000=Ool00`00Oomoo`0A
Ool2000<Ool40004Acl40004Acl30005Acl30004Acl50003Acl40003Acl50003Acl400000dLo0000
000800000glA000000090004Acl50003Acl40003Acl50003Acl40004Acl40004Acl30004Acl50003
Acl40004Acl40003Acl40004Acl40004Acl30005Acl30004Acl50003Acl40004Acl40003Acl40004
Acl40004Acl30004Acl50003Acl40004Acl40004Acl40003Acl40004Acl40004Acl30004Acl50003
Acl40004Acl40004Acl30004Acl40004Acl40003Acl50003Acl50003Acl40004Acl40003Acl50003
Acl40004Acl40003Acl50003Acl40004Acl40004Acl40003Acl50003Acl40004Acl40003Acl50003
Acl40004Acl40004Acl40003Acl50003Acl40003Acl50003Acl40004Acl40004Acl40003Acl50003
Acl40004Acl40003Acl50003Acl40004Acl40004Acl40003Acl50003Acl40004Acl40003Acl50003
Acl40004Acl00`00Oomoo`0?Ool00`00Oomoo`1aOol003moo`8000Ioo`8000ioo`03001oogoo01=o
o`03001oogoo00]oo`<000A7?`@000A7?`@000A7?`<000E7?`<000A7?`D000=7?`@000=7?`l00003
Oa40000000T000A7?`D000=7?`@000A7?`@000=7?`@000A7?`@000A7?`<000E7?`<000A7?`D000=7
?`@000A7?`@000=7?`@000A7?`@000A7?`<000A7?`D000=7?`@000A7?`@000A7?`<000A7?`@000A7
?`<000A7?`D000=7?`@000A7?`@000A7?`<000A7?`@000A7?`@000=7?`D000=7?`D000=7?`@000A7
?`@000A7?`<000A7?`@000A7?`<000A7?`D000=7?`@000A7?`@000A7?`<000A7?`D000=7?`@000=7
?`D000=7?`D000=7?`@000A7?`@000=7?`D000=7?`D000=7?`@000=7?`D000=7?`@000A7?`@000=7
?`D000=7?`D000=7?`@000A7?`@000=7?`@000A7?`@000A7?`@000=7?`D000=7?`@000A7?`@000=7
?`@000A7?`@000A7?`@000=7?`D000=7?`@000A7?`@000A7?`@000=7?`D000=7?`@000=7?`D000=7
?`03001oogoo00moo`03001oogoo075oo`00?goo0P001Woo0P003Woo00<007ooOol057oo00<007oo
Ool02goo0`001DLo0`0014Lo1@000dLo100014Lo0`001DLo0`0014Lo1@000dLo3`0000=o4@000000
20001DLo0`0014Lo1@000dLo100014Lo10000dLo100014Lo100014Lo0`0014Lo1@000dLo100014Lo
100014Lo0`0014Lo100014Lo0`0014Lo1@000dLo100014Lo100014Lo0`0014Lo100014Lo0`0014Lo
1@000dLo100014Lo100014Lo0`0014Lo1@000dLo10000dLo1@000dLo100014Lo100014Lo10000dLo
1@000dLo100014Lo10000dLo1@000dLo100014Lo10000dLo1@000dLo100014Lo100014Lo10000dLo
100014Lo10000dLo1@000dLo1@000dLo100014Lo10000dLo100014Lo10000dLo1@000dLo1@000dLo
100014Lo10000dLo1@000dLo10000dLo1@000dLo1@000dLo100014Lo10000dLo1@000dLo100014Lo
10000dLo1@000dLo100014Lo10000dLo1@000dLo100014Lo100014Lo10000dLo100014Lo00<007oo
Ool03goo00<007ooOol0L7oo0010Ool20004Ool2000?Ool00`00Oomoo`0EOol2000=Ool30004Acl3
0005Acl30004Acl50003Acl40004Acl30005Acl30004AclK0004Acl30005Acl30004Acl40004Acl4
0003Acl40004Acl40004Acl30004Acl50003Acl40004Acl40004Acl30004Acl40004Acl30004Acl5
0003Acl40004Acl40004Acl30004Acl50003Acl40003Acl50003Acl40004Acl40004Acl30004Acl5
0003Acl40004Acl40003Acl40004Acl40004Acl30004Acl50003Acl40004Acl40003Acl40004Acl4
0003Acl50003Acl50003Acl40004Acl40003Acl50003Acl40003Acl50003Acl50003Acl40004Acl4
0003Acl50003Acl40004Acl40003Acl50003Acl40004Acl40003Acl50003Acl40004Acl40003Acl4
0004Acl40004Acl40003Acl50003Acl40004Acl40003Acl50003Acl40004Acl40003Acl50003Acl4
0004Acl40003Acl50003Acl40004Acl40003Acl2000@Ool00`00Oomoo`1`Ool0041oo`P000moo`03
001oogoo01Moo`03001oogoo00]oo`<000E7?`<000A7?`<000E7?`<000A7?`@000A7?`@000A7?`<0
00=7?a`000A7?`@000A7?`<000A7?`D000=7?`@000A7?`@000=7?`@000A7?`<000E7?`<000A7?`D0
00=7?`@000A7?`<000E7?`<000A7?`<000A7?`D000=7?`@000A7?`@000A7?`<000A7?`D000=7?`@0
00=7?`D000=7?`@000A7?`@000A7?`<000A7?`D000=7?`@000A7?`@000=7?`@000A7?`@000=7?`D0
00=7?`@000A7?`@000A7?`<000A7?`@000A7?`<000A7?`D000=7?`@000A7?`@000=7?`D000=7?`D0
00=7?`@000A7?`@000=7?`@000A7?`@000=7?`D000=7?`@000A7?`@000A7?`@000=7?`@000A7?`@0
00=7?`D000=7?`@000A7?`@000=7?`D000=7?`@000A7?`@000=7?`D000=7?`@000A7?`@000=7?`D0
00=7?`@000A7?`@000=7?`@000A7?`@000A7?`@000=7?`D000=7?`@000A7?`@000=7?`D000=7?`03
001oogoo00moo`03001oogoo06moo`00@Woo10004Goo00<007ooOol067oo00<007ooOol02goo1000
14Lo0`001DLo0`0014Lo0`001DLo0`0014Lo100014Lo100000=7?`00000070000dLo100014Lo0`00
1DLo0`0014Lo100014Lo100014Lo0`0014Lo100014Lo0`0014Lo1@000dLo100014Lo100014Lo0`00
14Lo10000dLo1@000dLo100014Lo100014Lo0`0014Lo1@000dLo100014Lo10000dLo100014Lo1000
0dLo1@000dLo100014Lo100014Lo0`0014Lo100014Lo0`0014Lo1@000dLo100014Lo10000dLo1@00
0dLo100014Lo10000dLo100014Lo100014Lo0`0014Lo1@000dLo100014Lo10000dLo100014Lo1000
0dLo1@000dLo100014Lo100014Lo10000dLo1@000dLo10000dLo1@000dLo100014Lo10000dLo1@00
0dLo100014Lo10000dLo1@000dLo100014Lo10000dLo1@000dLo100014Lo10000dLo1@000dLo1000
14Lo10000dLo10000dLo1@000dLo1@000dLo100014Lo100014Lo00<007ooOol03Woo00<007ooOol0
Kgoo001FOol4000IOol2000<Ool50003Acl40004Acl30005Acl30004Acl30005Acl30004Acl70000
0glA0000000=00000glA000000090003Acl40004Acl40004Acl30004Acl50003Acl40004Acl30005
Acl30004Acl30004Acl50003Acl40004Acl40004Acl30004Acl50003Acl40003Acl40004Acl40004
Acl30004Acl50003Acl40004Acl40003Acl40004Acl30004Acl50003Acl40004Acl40004Acl30004
Acl50003Acl40003Acl40004Acl40004Acl30004Acl50003Acl40004Acl40003Acl40004Acl40003
Acl50003Acl40004Acl40003Acl50003Acl40004Acl40003Acl50003Acl40004Acl40003Acl50003
Acl40004Acl40003Acl40004Acl40003Acl50003Acl40004Acl40003Acl50003Acl40004Acl40003
Acl40004Acl40004Acl40003Acl50003Acl40004Acl40003Acl40004Acl40002Acl60003Acl40004
Acl40003Acl50003Acl00`00Oomoo`0?Ool00`00Oomoo`1^Ool005Moo`03001oogoo01]oo`03001o
ogoo00]oo`<000A7?`D000=7?`@000A7?`<000E7?`<000A7?`<000A7?b<000A7?`@000=7?`@000A7
?`<000E7?`<000A7?`@000A7?`@000A7?`<000A7?`@000A7?`<000A7?`@000A7?`@000A7?`<000A7
?`D000=7?`@000A7?`<000A7?`@000A7?`<000A7?`D000=7?`@000A7?`<000A7?`D000=7?`@000=7
?`D000=7?`@000A7?`@000=7?`D000=7?`@000A7?`@000A7?`<000A7?`@000=7?`D000=7?`@000A7
?`@000A7?`<000A7?`D000=7?`@000=7?`@000A7?`@000A7?`<000A7?`D000=7?`@000A7?`@000=7
?`@000A7?`@000=7?`D000=7?`@000A7?`@000=7?`D000=7?`@000A7?`@000=7?`@000A7?`@000=7
?`D000=7?`@000A7?`@000=7?`D000=7?`@000=7?`D000=7?`@000A7?`@000=7?`D000=7?`@000A7
?`@000=7?`@00097?`030017?`0000<000A7?`@000=7?`@000A7?`@000A7?`03001oogoo00ioo`03
001oogoo06ioo`00Egoo00<007ooOol077oo0P0037oo0`001DLo0`0014Lo1@000dLo100014Lo0`00
1DLo0`0014Lo8`000dLo100014Lo0`0014Lo100014Lo0`0014Lo1@000dLo100014Lo0`0014Lo1@00
0dLo10000dLo100014Lo100014Lo0`0014Lo1@000dLo100014Lo0`0014Lo100014Lo0`0014Lo1@00
0dLo100014Lo0`0014Lo1@000dLo100014Lo10000dLo100014Lo0`0014Lo1@000dLo100014Lo1000
0dLo1@000dLo10000dLo1@000dLo100014Lo10000dLo1@000dLo100014Lo10000dLo100014Lo1000
0dLo1@000dLo100014Lo10000dLo1@000dLo100014Lo10000dLo100014Lo10000dLo1@000dLo1000
14Lo10000dLo1@000dLo10000dLo1@000dLo100014Lo10000dLo1@000dLo100014Lo10000dLo1000
14Lo10000dLo1@000dLo100014Lo10000dLo1@000dLo100000A7?`00Acm7?`@000=7?`@000A7?`@0
00=7?`D000=7?`03001oogoo00moo`03001oogoo06eoo`00EWoo00<007ooOol07goo00<007ooOol0
2Woo100014Lo0`001DLo0`0014Lo100014Lo100014Lo0`0014Lo1@0000=o4@0000006P0014Lo1000
14Lo100014Lo0`0014Lo0`0014Lo1@000dLo100014Lo0`001DLo0`0014Lo100014Lo10000dLo1000
14Lo0`0014Lo1@000dLo100014Lo0`0014Lo1@000dLo10000dLo1@000dLo100014Lo0`0014Lo1@00
0dLo100014Lo0`0014Lo100014Lo0`0014Lo1@000dLo100014Lo0`0014Lo1@000dLo100014Lo0`00
14Lo100014Lo0`0014Lo100014Lo100014Lo0`0014Lo100014Lo10000dLo100014Lo10000dLo1@00
0dLo100014Lo10000dLo1@000dLo10000dLo1@000dLo100014Lo10000dLo1@000dLo100014Lo1000
0dLo100014Lo10000dLo1@000dLo100014Lo10000dLo1@000dLo100014Lo10000dLo100014Lo1000
0dLo1@000dLo100014Lo1@000TLo1@000dLo10000dLo1@000dLo100014Lo00<007ooOol03goo00<0
07ooOol0K7oo001FOol00`00Oomoo`0POol00`00Oomoo`0;Ool40003Acl40004Acl30005Acl30004
Acl40004Acl30003AclF00000glA0000000:0004Acl50003Acl40004Acl30004Acl40004Acl30004
Acl40004Acl40004Acl30004Acl40004Acl40004Acl30004Acl30004Acl50003Acl40004Acl30004
Acl50003Acl40004Acl30004Acl40004Acl30004Acl50003Acl40004Acl30004Acl50003Acl40003
Acl40004Acl40004Acl30004Acl40004Acl40004Acl30004Acl40003Acl50003Acl40004Acl40003
Acl50003Acl40004Acl40003Acl40004Acl30004Acl50003Acl40004Acl30004Acl50003Acl40004
Acl30004Acl40003Acl50003Acl40004Acl40003Acl50003Acl40004Acl40003Acl40004Acl40003
Acl50003Acl40004Acl40003Acl50003Acl40003Acl50003Acl40004Acl40003Acl50003Acl40003
Acl50003Acl40003Acl50003Acl2000@Ool00`00Oomoo`1/Ool005Ioo`03001oogoo025oo`8000ao
o`@000A7?`<000A7?`@000A7?`<000A7?`D000=7?`@00003Acl00000028000E7?`<000A7?`@000A7
?`<000E7?`<000A7?`@000=7?`@000A7?`@000A7?`<000A7?`@000A7?`@000A7?`<000A7?`@000=7
?`D000=7?`@000A7?`<000A7?`D000=7?`@000A7?`<000A7?`@000A7?`<000A7?`@000A7?`@000A7
?`<000A7?`@000A7?`@000A7?`<000A7?`@000=7?`D000=7?`@000A7?`@000=7?`D000=7?`@000A7
?`<000A7?`@000A7?`<000A7?`@000A7?`@000=7?`D000=7?`@000A7?`@000=7?`@000A7?`@000=7
?`D000=7?`@000A7?`@000=7?`D000=7?`@000=7?`@000A7?`@000=7?`D000=7?`@000A7?`@000=7
?`D000=7?`@000=7?`D000=7?`@000A7?`@000=7?`D000=7?`@000=7?`D000=7?`@000A7?`@000=7
?`@000A7?`@000=7?`D000=7?`@000A7?`@000=7?`@000A7?`03001oogoo00moo`03001oogoo06]o
o`00EWoo00<007ooOol08goo00<007ooOol02goo0`0014Lo100014Lo0`0014Lo0`001DLo0`0014Lo
:P0014Lo0`0014Lo100014Lo100014Lo0`0014Lo100014Lo10000dLo100014Lo0`0014Lo1@000dLo
100014Lo0`0014Lo1@000dLo10000dLo100014Lo0`0014Lo1@000dLo100014Lo0`0014Lo1@000dLo
10000dLo100014Lo100014Lo0`0014Lo100014Lo10000dLo1@000dLo10000dLo100014Lo100014Lo
0`0014Lo100014Lo10000dLo1@000dLo10000dLo1@000dLo100014Lo0`0014Lo1@000dLo100014Lo
0`0014Lo10000dLo1@000dLo100014Lo10000dLo1@000dLo100014Lo10000dLo100014Lo10000dLo
100014Lo10000dLo1@000dLo100014Lo10000dLo1@000dLo10000dLo100014Lo10000dLo1@000dLo
100014Lo10000dLo1@000dLo10000dLo1@000dLo10000dLo1@000dLo100014Lo10000dLo0P0047oo
00<007ooOol0Jgoo001FOol00`00Oomoo`0TOol00`00Oomoo`0;Ool30004Acl50003Acl40004Acl3
0004Acl30004Acl=00000glA0000000J0004Acl30004Acl50003Acl40004Acl30004Acl50003Acl4
0004Acl30004Acl30004Acl50003Acl40004Acl30004Acl50003Acl40004Acl30004Acl30004Acl5
0003Acl40004Acl30004Acl50003Acl40004Acl30004Acl40003Acl50003Acl40004Acl30004Acl5
0003Acl40004Acl30004Acl40003Acl50003Acl40004Acl30004Acl50003Acl40004Acl30004Acl4
0003Acl50003Acl40004Acl40003Acl50003Acl40004Acl30004Acl40003Acl50003Acl40004Acl4
0003Acl50003Acl40004Acl30004Acl40003Acl50003Acl40004Acl40003Acl50003Acl40003Acl5
0003Acl40003Acl50003Acl40004Acl40003Acl50003Acl40003Acl50003Acl40003Acl50003Acl4
0004Acl40003Acl40004Acl00`00Oomoo`0?Ool00`00Oomoo`1ZOol005Ioo`03001oogoo02Eoo`80
00aoo`<000E7?`<000A7?`@000A7?`<000E7?`<000A7?``00003Oa40000001X000E7?`<000A7?`@0
00=7?`@000A7?`<000E7?`<000A7?`@000A7?`<000A7?`D000=7?`@000=7?`@000A7?`<000A7?`D0
00=7?`@000A7?`<000A7?`@000A7?`@000=7?`@000A7?`<000A7?`@000A7?`@000A7?`<000A7?`@0
00A7?`@000=7?`@000A7?`<000A7?`@000A7?`@000=7?`D000=7?`@000A7?`<000A7?`@000A7?`<0
00A7?`@000A7?`@000=7?`D000=7?`@000A7?`<000A7?`@000=7?`D000=7?`@000A7?`@000=7?`D0
00=7?`@000A7?`<000A7?`@000=7?`D000=7?`@000A7?`@000=7?`@000A7?`@000=7?`@000A7?`@0
00=7?`D000=7?`@000A7?`<000A7?`@000A7?`@000=7?`@000A7?`@000=7?`D000=7?`@000=7?`D0
00=7?`@000A7?`@000=7?`@000A7?`@000=7?`@000A7?`@000=7?`80011oo`03001oogoo06Yoo`00
EWoo00<007ooOol09goo00<007ooOol02Woo100014Lo0`001DLo0`0014Lo100014Lo0`0014Lo3@00
00=o4@0000006P0014Lo0`0014Lo100014Lo0`0014Lo100014Lo0`0014Lo100014Lo0`0014Lo1@00
0dLo100014Lo0`0014Lo0`0014Lo1@000dLo100014Lo0`0014Lo100014Lo100014Lo0`0014Lo0`00
14Lo100014Lo100014Lo0`0014Lo100014Lo0`0014Lo100014Lo0`0014Lo100014Lo0`0014Lo1@00
0dLo100014Lo0`0014Lo10000dLo1@000dLo100014Lo0`0014Lo100014Lo10000dLo1@000dLo1000
0dLo100014Lo10000dLo1@000dLo100014Lo10000dLo100014Lo10000dLo100014Lo10000dLo1@00
0dLo10000dLo1@000dLo100014Lo10000dLo100014Lo10000dLo100014Lo10000dLo1@000dLo1000
14Lo10000dLo10000dLo1@000dLo100014Lo10000dLo100014Lo10000dLo100014Lo10000dLo1000
14Lo00<007ooOol03goo00<007ooOol0JGoo001FOol00`00Oomoo`0XOol00`00Oomoo`0;Ool40003
Acl40004Acl30004Acl40004Acl30002AclO00000glA0000000:0004Acl30004Acl40004Acl40004
Acl30004Acl30004Acl40004Acl30005Acl30004Acl40004Acl30004Acl40003Acl50003Acl40004
Acl30004Acl40004Acl40004Acl30004Acl40003Acl40004Acl40003Acl50003Acl40004Acl30004
Acl40004Acl40003Acl40004Acl30004Acl40004Acl40003Acl50003Acl40004Acl30004Acl40003
Acl50003Acl40004Acl30004Acl40004Acl40003Acl40004Acl30004Acl40004Acl40003Acl50003
Acl40004Acl30004Acl40003Acl50003Acl40004Acl30004Acl40004Acl40003Acl50003Acl40003
Acl40004Acl40003Acl50003Acl40004Acl40003Acl40004Acl40003Acl40004Acl40003Acl40004
Acl40003Acl50003Acl40003Acl50003Acl40003Acl2000@Ool00`00Oomoo`1YOol005Ioo`03001o
ogoo02Uoo`8000aoo`@000A7?`<000A7?`<000E7?`<000A7?b@00003Oa40000000X000A7?`<000A7
?`D000=7?`@000A7?`<000A7?`@000=7?`@000A7?`@000A7?`<000A7?`@000A7?`<000A7?`@000A7
?`@000A7?`<000A7?`<000A7?`@000A7?`@000=7?`D000=7?`@000A7?`<000A7?`@000=7?`D000=7
?`@000A7?`<000A7?`@000A7?`<000A7?`D000=7?`@000=7?`@000A7?`<000A7?`@000A7?`@000=7
?`D000=7?`@000A7?`<000A7?`@000=7?`D000=7?`@000A7?`<000A7?`@000A7?`@000=7?`@000A7
?`<000A7?`@000A7?`@000=7?`D000=7?`@000=7?`D000=7?`@000=7?`@000A7?`@000=7?`D000=7
?`@000A7?`<000A7?`@000A7?`@000=7?`@000A7?`@000=7?`@000A7?`@000=7?`D000=7?`@000=7
?`@000A7?`@000=7?`D000=7?`@000=7?`D000=7?`@000=7?`D000=7?`03001oogoo00moo`03001o
ogoo06Qoo`00EWoo00<007ooOol0:goo00<007ooOol02goo0`0014Lo100014Lo0`0014Lo10000dLo
0`0000Ao4@00001o4Ad00003Oa40000000X000A7?`<000E7?`<000A7?`@000A7?`<000A7?`@000A7
?`@000A7?`<000A7?`<000A7?`@000A7?`<000A7?`D000=7?`@000A7?`<000A7?`@000=7?`@000A7
?`<000A7?`D000=7?`@000A7?`<000A7?`@000A7?`<000A7?`@000A7?`<000A7?`@000A7?`<000A7
?`@000A7?`@000=7?`@000A7?`<000A7?`@000A7?`<000A7?`@000A7?`@000=7?`D000=7?`@000=7
?`@000A7?`@000=7?`D000=7?`@000A7?`<000A7?`@000A7?`<000A7?`@000=7?`D000=7?`@000A7
?`<000A7?`@000A7?`@000=7?`@000=7?`D000=7?`@000A7?`@000=7?`@000A7?`@000=7?`D000=7
?`@000=7?`@000A7?`@000=7?`D000=7?`@000=7?`D000=7?`@000=7?`@000=7?`D000=7?`D000=7
?`@000=7?`D000=7?`@000A7?`03001oogoo00ioo`03001oogoo06Qoo`00EWoo00<007ooOol0;7oo
00<007ooOol02goo0`0014Lo100014Lo0`001DLo0`0014Lo500000=o4@000000300000=o4@000000
2`0014Lo0`0014Lo0`0014Lo100014Lo0`0014Lo1@000dLo100014Lo0`0014Lo10000dLo100014Lo
0`0014Lo1@000dLo100014Lo0`0014Lo100014Lo0`0014Lo0`0014Lo1@000dLo100014Lo0`0014Lo
100014Lo0`0014Lo10000dLo1@000dLo100014Lo0`0014Lo100014Lo0`0014Lo100014Lo10000dLo
100014Lo0`0014Lo100014Lo0`0014Lo100014Lo10000dLo1@000dLo10000dLo100014Lo10000dLo
100014Lo10000dLo1@000dLo10000dLo100014Lo10000dLo100014Lo10000dLo1@000dLo10000dLo
1@000dLo10000dLo1@000dLo10000dLo1@000dLo10000dLo1@000dLo100014Lo10000dLo10000dLo
1@000dLo10000dLo1@000dLo10000TLo00<004Lo00000`000dLo10000dLo1@000dLo100014Lo1000
0dLo00<007ooOol03goo00<007ooOol0Igoo001FOol00`00Oomoo`0]Ool2000<Ool30005Acl30004
Acl40004Acl30004AclT00000glA0000000:0004Acl30004Acl40004Acl30004Acl30005Acl30004
Acl40004Acl30004Acl40004Acl30004Acl40003Acl50003Acl40004Acl30004Acl40004Acl30004
Acl40004Acl30004Acl40004Acl30004Acl40004Acl30004Acl40004Acl30004Acl40003Acl50003
Acl40004Acl30004Acl40004Acl30004Acl40004Acl40003Acl40004Acl30004Acl40004Acl30004
Acl40004Acl40003Acl40003Acl50003Acl40004Acl30004Acl40004Acl30004Acl40004Acl40003
Acl40004Acl30004Acl40004Acl30004Acl40004Acl40003Acl40003Acl50003Acl40004Acl30004
Acl40004Acl40003Acl40004Acl40003Acl40004Acl30004Acl40004Acl40002Acl50004Acl40003
Acl40003Acl50003Acl40004Acl00`00Oomoo`0>Ool00`00Oomoo`1WOol005Eoo`@002moo`03001o
ogoo00]oo`<000A7?`<000A7?`@000A7?`<000=7?bD00003Oa40000000X000A7?`<000A7?`@000==
e003001Em5Gd00AEm0D000A7?`<000A7?`@000A7?`<000A7?`@000A7?`<000A7?`@000A7?`@000=7
?`@000A7?`<000A7?`@000A7?`<000A7?`@000A7?`<000A7?`@000=7?`D000=7?`@000A7?`<000A7
?`@000A7?`<000A7?`@000A7?`<000A7?`@000=7?`D000=7?`@000A7?`<000A7?`@000A7?`<000A7
?`@000=7?`@000A7?`@000=7?`D000=7?`@000A7?`<000A7?`@000A7?`<000A7?`@000=7?`@000A7
?`@000=7?`D000=7?`@000=7?`D000=7?`@000A7?`<000A7?`@000=7?`@000A7?`@000=7?`D000=7
?`@000=7?`D000=7?`@000=7?`@000A7?`@000=7?`@000A7?`@000=7?`D000=7?`@000=7?`@000A7
?`@000=7?`@00097?`030017?`0000<000=7?`@000A7?`@000=7?`@000A7?`@000=7?`80011oo`03
001oogoo06Ioo`00EWoo00<007ooOol0<7oo00<007ooOol02goo0`001DLo0`0014Lo0`0014Lo0`00
0TLo1@0000=o4@0000007`0000=o4@0000002@0014Lo0`000dgD00<004gDCM@014gD00<005GdEO@0
15Gd1P0014Lo100014Lo0`0014Lo0`0014Lo100014Lo0`0014Lo100014Lo100014Lo0`0014Lo1000
0dLo100014Lo0`0014Lo100014Lo0`0014Lo100014Lo0`0014Lo100014Lo0`0014Lo100014Lo0`00
14Lo100014Lo0`0014Lo100014Lo0`0014Lo10000dLo1@000dLo10000dLo1@000dLo100014Lo0`00
14Lo10000dLo100014Lo10000dLo100014Lo10000dLo1@000dLo10000dLo100014Lo0`0014Lo1000
14Lo0`0014Lo100014Lo10000dLo100014Lo10000dLo10000dLo1@000dLo100014Lo0`0014Lo1000
14Lo0`0014Lo10000dLo1@000dLo10000dLo1@000dLo10000dLo1@000dLo10000dLo100014Lo1000
00=7?`00Acl0100014Lo10000dLo100014Lo10000dLo1@000dLo00<007ooOol03Woo00<007ooOol0
IWoo001FOol00`00Oomoo`0aOol2000<Ool40004Acl30004Acl40004AclI00000glA0000000I0005
CM@00`00CMA=e003CM@00`00CMA=e004CM@00`00EOAEm004EO@70004Acl40004Acl30004Acl40003
Acl40004Acl30004Acl40004Acl40004Acl30004Acl40004Acl30004Acl30004Acl40004Acl30004
Acl40004Acl30004Acl40004Acl40003Acl40003Acl50003Acl40004Acl30004Acl40004Acl30004
Acl40004Acl30004Acl30004Acl40004Acl40003Acl40004Acl40003Acl50003Acl40003Acl40004
Acl30004Acl40004Acl30004Acl40004Acl30004Acl40003Acl50003Acl40003Acl50003Acl40003
Acl50003Acl40003Acl40004Acl40003Acl40004Acl40003Acl40004Acl40003Acl40004Acl40003
Acl40003Acl50003Acl40003Acl50003Acl40003Acl60002Acl40003Acl40004Acl40003Acl40004
Acl40003Acl00`00Oomoo`0?Ool00`00Oomoo`1UOol005Eoo`03001oogoo03Aoo`03001oogoo00Yo
o`@000A7?`<000A7?`@000A7?c@000E=e003001=e4gD00==e003001=e4gD00A=e003001Em5Gd00AE
m0P000A7?`@000A7?`<000A7?`@000A7?`<000A7?`@000=7?`D000=7?`@000A7?`<000A7?`@000A7
?`<000A7?`@000A7?`<000A7?`<000A7?`@000A7?`<000A7?`@000A7?`<000A7?`@000A7?`<000A7
?`@000=7?`D000=7?`@000=7?`D000=7?`@000A7?`<000A7?`@000=7?`@000A7?`<000A7?`@000A7
?`<000A7?`@000A7?`<000A7?`@000=7?`D000=7?`@000=7?`D000=7?`@000=7?`D000=7?`@000=7
?`@000A7?`<000A7?`@000A7?`<000A7?`@000A7?`<000A7?`@000A7?`<000A7?`@000=7?`D000=7
?`@000=7?`D000=7?`@000=7?`D000=7?`@000=7?`@000A7?`<000A7?`@000A7?`<000A7?`D000=7
?`<000A7?`@000=7?`@000A7?`@000=7?`@000A7?`03001oogoo00ioo`03001oogoo06Eoo`00EGoo
00<007ooOol0=Goo0P0037oo10000dLo0`001DLo0`0014Lo:`0000=o4@0000001@001DgD00<004gD
CM@00dgD00<004gDCM@014gD00<005GdEO@00eGd0P0000=o<P0000001P000dLo100014Lo0`0014Lo
100014Lo0`0014Lo100014Lo100014Lo0`0014Lo0`0014Lo100014Lo0`0014Lo100014Lo0`0014Lo
100014Lo0`0014Lo0`0014Lo100014Lo0`0014Lo100014Lo0`0014Lo100014Lo0`0014Lo0`0014Lo
100014Lo10000dLo100014Lo10000dLo100014Lo10000dLo10000dLo1@000dLo100014Lo0`0014Lo
100014Lo0`0014Lo10000dLo100014Lo0`0014Lo100014Lo0`0014Lo100014Lo0`0014Lo10000dLo
100014Lo10000dLo100014Lo10000dLo100014Lo10000dLo10000dLo1@000dLo10000dLo1@000dLo
10000dLo1@000dLo10000dLo100014Lo10000dLo100014Lo10000dLo100014Lo10000dLo100014Lo
0`0014Lo10000dLo0P0047oo00<007ooOol0I7oo001EOol00`00Oomoo`0gOol00`00Oomoo`0:Ool4
0004Acl30004Acl30004Acl:00000glA0000000U0005CM@00`00CMA=e003CM@00`00CMA=e004CM@0
0`00EOAEm003EO@300000glb000000060004Acl30004Acl30004Acl40004Acl30005Acl30004Acl4
0004Acl30004Acl40003Acl40004Acl30004Acl40004Acl30004Acl40004Acl30004Acl40003Acl4
0004Acl30004Acl40004Acl30004Acl40004Acl30004Acl40004Acl30004Acl30004Acl40004Acl3
0004Acl40004Acl30004Acl40004Acl30004Acl40003Acl40004Acl40003Acl40004Acl40003Acl4
0004Acl40003Acl40003Acl40004Acl40003Acl40004Acl40003Acl40004Acl40003Acl40003Acl5
0003Acl40003Acl50003Acl40003Acl50003Acl40003Acl40004Acl30004Acl40003Acl50003Acl4
0003Acl50003Acl40003Acl40004Acl40003Acl40004Acl40003Acl40003Acl50003Acl00`00Oomo
o`0>Ool00`00Oomoo`1TOol005Eoo`03001oogoo03Qoo`03001oogoo00]oo`<000A7?`<000E7?`<0
0097?`/00003Oa40000002@000E=e003001=e4gD00==e003001=e4gD00A=e003001Em5Gd00=Em0@0
0003Oc80000000H000A7?`<000E7?`<000A7?`@000=7?`@000A7?`<000A7?`@000A7?`<000A7?`@0
00A7?`<000A7?`@000=7?`@000A7?`<000A7?`@000A7?`<000A7?`@000A7?`<000A7?`@000=7?`@0
00A7?`<000A7?`@000A7?`<000A7?`@000=7?`D000=7?`@000=7?`@000A7?`<000A7?`@000A7?`<0
00A7?`@000=7?`D000=7?`@000=7?`@000A7?`<000A7?`@000A7?`<000A7?`@000=7?`D000=7?`@0
00=7?`@000A7?`<000A7?`@000A7?`<000A7?`@000=7?`D000=7?`@000=7?`@000A7?`<000A7?`@0
00A7?`<000A7?`@000=7?`D000=7?`@000=7?`@000A7?`<000A7?`@000A7?`<000A7?`@000=7?`D0
00=7?`@000=7?`@000A7?`@000=7?`@000A7?`<000A7?`@000=7?`80011oo`03001oogoo06=oo`00
EGoo00<007ooOol0>Goo0P0037oo0`0014Lo100014Lo4@0000=o4@0000008P001DgD00<004gDCM@0
0dgD00<004gDCM@014gD00<005GdEO@00eGd1@0000=o<P0000001P0014Lo100014Lo0`0014Lo1000
14Lo0`0014Lo10000dLo100014Lo0`0014Lo10000dLo1@000dLo10000dLo100014Lo0`0014Lo1000
0dLo100014Lo10000dLo100014Lo0`0014Lo100014Lo0`0014Lo10000dLo100014Lo0`0014Lo1000
14Lo0`0014Lo100014Lo0`0014Lo10000dLo100014Lo0`0014Lo100014Lo0`0014Lo100014Lo0`00
14Lo10000dLo100014Lo0`0014Lo100014Lo0`0014Lo100014Lo0`0014Lo10000dLo100014Lo0`00
14Lo100014Lo0`0014Lo100014Lo0`0014Lo10000dLo100014Lo0`0014Lo100014Lo0`0014Lo1000
0dLo100014Lo10000dLo100014Lo0`0014Lo10000dLo1@000dLo10000dLo100014Lo10000dLo1000
0dLo1@000dLo00<007ooOol03Woo00<007ooOol0Hgoo001EOol00`00Oomoo`0kOol00`00Oomoo`0:
Ool40003Acl40004AclB00000glA0000000<00000glA0000000A0005CM@00`00CMA=e003CM@00`00
CMA=e004CM@00`00EOAEm003EO@@0003Acl40004Acl30004Acl40004Acl30004Acl40004Acl30004
Acl40003Acl30004Acl40004Acl30004Acl40004Acl30004Acl40004Acl30004Acl30004Acl40004
Acl30004Acl40004Acl30004Acl40004Acl30004Acl30004Acl40004Acl30004Acl40004Acl30004
Acl40004Acl30004Acl30004Acl40004Acl30004Acl40003Acl50003Acl40003Acl40003Acl50003
Acl40003Acl40004Acl40003Acl40004Acl40003Acl40003Acl40004Acl40003Acl40004Acl40003
Acl40004Acl30004Acl40003Acl40004Acl40003Acl40004Acl30004Acl40003Acl50003Acl40003
Acl40004Acl30004Acl40003Acl50003Acl40003Acl40004Acl40003Acl40003Acl2000@Ool00`00
Oomoo`1ROol005Eoo`03001oogoo03aoo`03001oogoo00]oo`<000A7?`<000A7?`05001o4@00001o
4@0=00000glA0000000<00000glA0000000@0005CM@00`00CMA=e003CM@00`00CMA=e004CM@00`00
EOAEm003EO@A0004Acl30004Acl40003Acl40004Acl30004Acl40004Acl30004Acl30004Acl40004
Acl30004Acl30004Acl40004Acl30004Acl40004Acl30004Acl40004Acl30004Acl30004Acl40004
Acl30004Acl40004Acl30004Acl40003Acl40004Acl30004Acl40003Acl40004Acl40003Acl40004
Acl30004Acl40003Acl40004Acl30004Acl40004Acl30004Acl40004Acl30004Acl40003Acl40004
Acl30004Acl40003Acl50003Acl40003Acl40004Acl40003Acl40003Acl40004Acl40003Acl40004
Acl40003Acl40004Acl30004Acl40003Acl40004Acl30004Acl40003Acl50003Acl40003Acl40004
Acl30004Acl40003Acl50003Acl40003Acl40004Acl40003Acl00`00Oomoo`0>Ool00`00Oomoo`1R
Ool005Eoo`03001oogoo03eoo`8000aoo`<000A7?`@000=7?`03Oa40000001000003Oa40000000/0
0003Oa40000000l000E=e003001=e4gD00==e003001=e4gD00A=e003001Em5Gd00=Em0T00003Oc80
000000H000A7?`<000A7?`@000A7?`<000A7?`<000A7?`@000A7?`<000A7?`<000A7?`@000A7?`<0
00A7?`@000A7?`<000A7?`<000A7?`@000A7?`<000A7?`@000A7?`<000A7?`@000A7?`<000A7?`<0
00A7?`@000=7?`@000A7?`<000A7?`@000A7?`<000A7?`@000=7?`@000A7?`<000A7?`@000A7?`<0
00A7?`@000=7?`D000=7?`@000=7?`@000=7?`@000A7?`@000=7?`@000A7?`<000A7?`@000A7?`<0
00A7?`<000A7?`@000A7?`<000A7?`@000=7?`D000=7?`@000=7?`@000=7?`D000=7?`@000=7?`@0
00A7?`@000=7?`@000A7?`<000A7?`@000=7?`@000A7?`<000A7?`@000=7?`D000=7?`@000=7?`@0
00A7?`@000=7?`@000=7?`@000A7?`@000=7?`@000A7?`03001oogoo00ioo`03001oogoo065oo`00
EGoo00<007ooOol0?goo00<007ooOol02Woo0`0014Lo10000TLo<`001DgD00<004gDCM@00dgD00<0
04gDCM@014gD00<005GdEO@00eGd2P0000Eo<P00000004Lo00@000A7?`<000A7?`@000A7?`<000A7
?`@000A7?`<000A7?`<000A7?`<000A7?`@000A7?`<000A7?`@000A7?`<000A7?`@000A7?`<000A7
?`<000A7?`@000A7?`<000A7?`@000=7?`@000A7?`<000A7?`@000=7?`@000A7?`<000A7?`@000A7
?`<000A7?`@000=7?`D000=7?`@000=7?`@000=7?`@000A7?`<000A7?`@000A7?`<000A7?`@000A7
?`<000A7?`<000A7?`@000=7?`D000=7?`@000=7?`@000A7?`<000A7?`@000=7?`@000A7?`<000A7
?`@000A7?`<000A7?`@000=7?`@000A7?`@000=7?`@000=7?`@000A7?`@000=7?`@000A7?`<000A7
?`@000=7?`@000A7?`<000A7?`@000=7?`D00097?`D000=7?`@000A7?`@000=7?`@000=7?`@000A7
?`@000=7?`03001oogoo00ioo`03001oogoo065oo`00EGoo00<007ooOol0@7oo00<007ooOol02goo
0`0014Lo0`0000=7?`0000008P0000=o4@00000030001DgD00<004gDCM@00dgD00<004gDCM@014gD
00<005GdEO@00UGd3`000dLo0`0014Lo0`0014Lo100014Lo0`0014Lo100014Lo0`0014Lo0`0014Lo
10000dLo100014Lo0`0014Lo100014Lo0`0014Lo100014Lo0`0014Lo10000dLo10000dLo100014Lo
0`0014Lo100014Lo0`0014Lo100014Lo0`0014Lo10000dLo10000dLo100014Lo0`0014Lo100014Lo
0`0014Lo100014Lo0`0014Lo0`0014Lo10000dLo100014Lo10000dLo100014Lo0`0014Lo10000dLo
100014Lo0`0014Lo10000dLo1@000dLo10000dLo100014Lo0`0014Lo10000dLo100014Lo0`0014Lo
10000dLo1@000dLo10000dLo10000dLo100014Lo10000dLo100014Lo0`0014Lo10000dLo1@000dLo
10000dLo10000TLo1P000dLo10000dLo100014Lo0`0014Lo10000dLo100014Lo00<007ooOol03Woo
00<007ooOol0H7oo001EOol00`00Oomoo`11Ool2000<Ool30004Aclf0005CM@00`00CMA=e003CM@0
0`00CMA=e004CM@00`00EOAEm002EO@?0004Acl30004Acl40004Acl30004Acl40003Acl40004Acl3
0004Acl30004Acl40004Acl30004Acl40004Acl30004Acl30004Acl40004Acl30004Acl30004Acl4
0004Acl30004Acl40003Acl40004Acl30004Acl40003Acl40004Acl30004Acl40004Acl30004Acl3
0004Acl40004Acl30004Acl40003Acl40004Acl30004Acl40003Acl40004Acl30004Acl40003Acl4
0004Acl40003Acl40004Acl30004Acl30004Acl40004Acl30004Acl40003Acl40004Acl40003Acl4
0003Acl40004Acl30004Acl40003Acl50003Acl40003Acl40004Acl30004Acl40003Acl40004Acl3
0004Acl40003Acl40004Acl400000dLo0017?`040003Acl40004Acl40003Acl40003Acl50003Acl4
0003Acl00`00Oomoo`0>Ool00`00Oomoo`1POol005Eoo`<004=oo`03001oogoo00Yoo`<000E7?bP0
0003Oa40000000P000I=e003001=e4gD00==e003001=e4gD00A=e003001Em5Gd009Em10000A7?`<0
00A7?`@000A7?`<000A7?`@000A7?`<000A7?`@000=7?`<000A7?`@000A7?`<000A7?`@000A7?`<0
00A7?`@000=7?`@000=7?`@000A7?`<000A7?`@000A7?`<000A7?`@000=7?`@000A7?`<000A7?`<0
00A7?`@000A7?`<000A7?`@000A7?`<000A7?`@000=7?`@000=7?`@000A7?`<000A7?`@000A7?`<0
00A7?`@000=7?`@000A7?`<000A7?`<000A7?`@000A7?`<000A7?`@000=7?`@000A7?`<000A7?`@0
00=7?`@000A7?`<000A7?`@000=7?`@000A7?`@000=7?`@000A7?`<000A7?`<000A7?`@000=7?`D0
00=7?`@000=7?`@000A7?`<000A7?`@000=7?`@000A7?`<000A7?`@000=7?`@00004Acl004LoAcl4
0003Acl40003Acl40004Acl30004Acl40003Acl40004Acl00`00Oomoo`0>Ool00`00Oomoo`1OOol0
05Aoo`8004Ioo`03001oogoo00]oo`<000A7?aH00003Oa40000001T000I=e003001=e4gD00==e003
001=e4gD00A=e003001Em5Gd009Em0D00003Oc80000000T000E7?`<000=7?`@000A7?`<000A7?`@0
00A7?`<000A7?`<000A7?`@000A7?`<000A7?`<000A7?`@000A7?`<000A7?`<000A7?`@000A7?`<0
00A7?`@000=7?`@000A7?`<000A7?`<000A7?`@000A7?`<000A7?`@000A7?`<000A7?`<000A7?`@0
00=7?`@000A7?`<000A7?`@000A7?`<000A7?`@000=7?`@000=7?`@000A7?`<000A7?`@000A7?`<0
00A7?`@000=7?`@000=7?`@000A7?`<000A7?`@000=7?`D000=7?`@000=7?`@000A7?`<000A7?`<0
00A7?`@000=7?`D000=7?`@000=7?`@000A7?`<000A7?`@000=7?`@000=7?`D000=7?`@000=7?`@0
00A7?`<000A7?`@000=7?`@000=7?`D000=7?`D00097?`@000A7?`<000A7?`@000=7?`@000A7?`@0
00=7?`@000=7?`8000moo`03001oogoo05moo`00EGoo00<007ooOol0AGoo0P0037oo0`000dLo<P00
1TgD00<004gDCM@00dgD00<004gDCM@014gD00<005GdEO@00UGd3P0000=7?`0000000P0014Lo0`00
14Lo0`0014Lo10000dLo100014Lo0`0014Lo0`0014Lo100014Lo0`0014Lo100014Lo0`0014Lo0`00
14Lo0`0014Lo100014Lo0`0014Lo100014Lo0`0014Lo0`0014Lo0`0014Lo100014Lo0`0014Lo1000
0dLo100014Lo0`0014Lo10000dLo100014Lo0`0014Lo10000dLo100014Lo0`0014Lo10000dLo1000
0dLo100014Lo10000dLo100014Lo0`0014Lo10000dLo100014Lo0`0014Lo0`0014Lo100014Lo0`00
14Lo10000dLo100014Lo0`0014Lo10000dLo10000dLo1@000dLo10000dLo100014Lo0`0014Lo1000
0dLo10000dLo100014Lo10000dLo100014Lo0`0014Lo10000dLo100014Lo10000dLo10000dLo1000
0dLo1@000dLo10000dLo100014Lo0`0014Lo00<007ooOol03Woo00<007ooOol0GWoo001EOol00`00
Oomoo`17Ool00`00Oomoo`0:Ool30002Acl:00000glA0000000U0006CM@00`00CMA=e003CM@00`00
CMA=e004CM@00`00EOAEm002EO@>0002Acl40004Acl30004Acl30004Acl40004Acl30004Acl40003
Acl30004Acl40004Acl30004Acl40004Acl30004Acl30004Acl40003Acl40004Acl30004Acl40003
Acl40004Acl30004Acl40004Acl30004Acl30004Acl30004Acl40004Acl30004Acl40003Acl40004
Acl30004Acl30004Acl40004Acl30004Acl30004Acl40004Acl30004Acl40003Acl40003Acl40004
Acl30004Acl40003Acl40004Acl40003Acl40003Acl40004Acl30004Acl40003Acl40004Acl30004
Acl40003Acl40004Acl40003Acl40003Acl40004Acl30004Acl40003Acl40004Acl30004Acl40003
Acl40003Acl50003Acl40003Acl40003Acl50003Acl40003Acl40003Acl40004Acl40003Acl40003
Acl2000?Ool00`00Oomoo`1NOol005Aoo`03001oogoo04Uoo`8000]oo`l00003Oa40000001`00003
Oa40000000D000I=e003001=e4gD00==e003001=e4gD00==e003001Em5Gd00=Em0h000A7?`<000A7
?`<000A7?`<000A7?`@000A7?`<000A7?`@000A7?`<000A7?`<000A7?`<000A7?`@000A7?`<000A7
?`<000A7?`@000A7?`<000A7?`@000=7?`@000=7?`@000A7?`<000A7?`@000=7?`@000A7?`<000A7
?`@000A7?`<000=7?`@000A7?`<000A7?`@000A7?`<000A7?`@000=7?`@000A7?`<000A7?`<000A7
?`@000=7?`@000A7?`<000A7?`@000=7?`@000A7?`<000A7?`<000A7?`@000A7?`<000A7?`@000=7
?`@000A7?`<000A7?`@000=7?`@000=7?`@000A7?`<000A7?`@000=7?`@000A7?`<000A7?`@000=7
?`@000A7?`<000A7?`@000=7?`@000A7?`<000A7?`@000=7?`@000=7?`@000A7?`<000A7?`@000=7
?`@000A7?`@000=7?`@000=7?`@000=7?`D000=7?`03001oogoo00ioo`03001oogoo05eoo`00E7oo
00<007ooOol0Bgoo00<007ooOol02Woo3`0000=o4@0000008P001TgD00<004gDCM@00TgD00<004gD
CM@014gD00<005GdEO@00eGd3`0014Lo0`0014Lo100014Lo0`0014Lo0`0014Lo0`0014Lo100014Lo
0`0014Lo0`0014Lo100014Lo0`0014Lo0`0014Lo0`0014Lo100014Lo0`0014Lo0`0014Lo100014Lo
0`0014Lo10000dLo0`0014Lo100014Lo0`0014Lo10000dLo100014Lo0`0014Lo10000dLo10000dLo
100014Lo0`0014Lo10000dLo100014Lo0`0014Lo10000dLo10000dLo100014Lo0`0014Lo100014Lo
0`0014Lo10000dLo10000dLo100014Lo0`0014Lo10000dLo100014Lo0`0014Lo10000dLo10000dLo
100014Lo0`0014Lo10000dLo100014Lo0`0014Lo10000dLo10000dLo100014Lo10000dLo10000dLo
1@000dLo10000dLo10000dLo100014Lo0`0014Lo10000dLo100014Lo0`0014Lo10000dLo100014Lo
00<007ooOol03Woo00<007ooOol0G7oo001DOol00`00Oomoo`1<Ool00`00Oomoo`0:Oolc0005CM@0
0`00CMA=e003CM@00`00CMA=e004CM@00`00EOAEm002EO@A0004Acl30004Acl40004Acl30004Acl3
0004Acl40004Acl30003Acl40004Acl30004Acl40004Acl30004Acl30004Acl40004Acl30004Acl3
0004Acl30004Acl40004Acl30004Acl30004Acl40004Acl30004Acl30004Acl30004Acl40004Acl3
0004Acl30004Acl40004Acl30004Acl30004Acl30004Acl40004Acl30004Acl40003Acl40004Acl3
0004Acl30004Acl40003Acl40004Acl30004Acl40003Acl40004Acl30004Acl30004Acl40003Acl4
0004Acl30004Acl40003Acl40004Acl30004Acl40003Acl40003Acl40004Acl30004Acl40003Acl4
0004Acl30004Acl40003Acl40003Acl40004Acl30004Acl40003Acl40004Acl30004Acl40003Acl4
0003Acl40004Acl40003Acl00`00Oomoo`0>Ool00`00Oomoo`1LOol005Aoo`03001oogoo04eoo`80
00Yoo`04Oa400000Oa4K00000glA0000000A0005CM@00`00CMA=e003CM@00`00CMA=e004CM@00`00
EOAEm002EO@>000014Lo0000000014Lo100014Lo0`0014Lo0`0014Lo0`0014Lo100014Lo0`0014Lo
0`0014Lo100014Lo0`0014Lo0`0014Lo0`0014Lo100014Lo0`0014Lo0`0014Lo100014Lo0`000dLo
100014Lo0`0014Lo10000dLo100014Lo0`0014Lo10000dLo10000dLo100014Lo0`0014Lo10000dLo
100014Lo0`0014Lo10000dLo10000dLo100014Lo0`0014Lo10000dLo100014Lo0`0014Lo10000dLo
10000dLo100014Lo0`0014Lo10000dLo100014Lo0`0014Lo10000dLo10000dLo100014Lo0`0014Lo
10000dLo100014Lo0`0014Lo10000dLo10000dLo100014Lo0`0014Lo10000dLo100014Lo0`0014Lo
10000dLo10000dLo10000dLo1@000dLo10000dLo10000dLo1@000dLo10000dLo10000dLo10000dLo
0P0047oo00<007ooOol0Fgoo001DOol00`00Oomoo`1?Ool00`00Oomoo`07Ool00glA0000000M0000
0glA0000000@0005CM@00`00CMA=e003CM@00`00CMA=e004CM@00`00EOAEm002EO@>0002Acl30004
Acl40004Acl30004Acl30004Acl40003Acl40004Acl30004Acl30004Acl40004Acl30004Acl30004
Acl40003Acl40003Acl40004Acl30004Acl40003Acl40004Acl30004Acl40003Acl30004Acl40004
Acl30004Acl30004Acl40004Acl30004Acl30004Acl30004Acl40004Acl30004Acl30004Acl40004
Acl30004Acl30004Acl30004Acl40003Acl40004Acl30004Acl40003Acl40004Acl30004Acl30004
Acl40003Acl40004Acl30004Acl40003Acl40004Acl30004Acl30004Acl40003Acl40003Acl50003
Acl40003Acl40003Acl40003Acl40004Acl40003Acl40003Acl40004Acl30004Acl40003Acl40003
Acl40004Acl30004Acl40003Acl40004Acl30004Acl40003Acl00`00Oomoo`0>Ool00`00Oomoo`1K
Ool005Aoo`03001oogoo051oo`03001oogoo00Iooa<00003Oa40000000/00003Oa40000000l000E=
e003001=e4gD00==e003001=e4gD00A=e003001Em5Gd009Em0D00003Oc80000000H000=7?`<000A7
?`@000A7?`<000A7?`<000A7?`@000A7?`<000A7?`<000A7?`@000=7?`@000A7?`<000A7?`<000A7
?`@000A7?`<000A7?`<000A7?`@000=7?`<000A7?`@000A7?`<000A7?`<000A7?`@000A7?`<000A7
?`<000A7?`<000A7?`@000=7?`@000A7?`<000A7?`@000=7?`@000A7?`<000A7?`<000A7?`@000=7
?`@000A7?`<000A7?`<000A7?`@000A7?`<000=7?`@000A7?`<000A7?`@000=7?`@000A7?`<000A7
?`@000=7?`@000=7?`@000A7?`<000A7?`@000=7?`@000A7?`<000A7?`<000A7?`@000=7?`@000=7
?`@000A7?`<000A7?`@000=7?`@000A7?`<000A7?`@000=7?`@000=7?`@000A7?`<000=7?`D000=7
?`@000=7?`@000A7?`<000A7?`@000=7?`@000=7?`@000A7?`03001oogoo00ioo`03001oogoo05Yo
o`00E7oo00<007ooOol0DGoo0P001Woo<`001DgD00<004gDCM@00dgD00<004gDCM@014gD00<005Gd
EO@00UGd3`0014Lo0`0014Lo0`0014Lo10000dLo0`0014Lo100014Lo0`0014Lo0`0014Lo100014Lo
0`0014Lo0`0014Lo0`0014Lo10000dLo100014Lo0`0014Lo0`0014Lo100014Lo0`0014Lo0`0014Lo
0`0014Lo10000dLo100014Lo0`0014Lo10000dLo10000dLo100014Lo0`0014Lo0`0014Lo100014Lo
0`0014Lo0`0014Lo10000dLo10000dLo100014Lo0`0014Lo10000dLo100014Lo0`0014Lo0`0014Lo
0`0014Lo10000dLo100014Lo0`0014Lo10000dLo100014Lo0`0014Lo0`0014Lo10000dLo10000dLo
100014Lo0`0014Lo10000dLo10000dLo100014Lo0`0014Lo10000dLo10000dLo100014Lo0`0014Lo
10000dLo10000TLo1@0014Lo0`0014Lo10000dLo10000dLo100014Lo10000dLo10000dLo0P003goo
00<007ooOol0FWoo001DOol00`00Oomoo`1COol00`00Oomoo`03OolT00000glA0000000<0005CM@0
0`00CMA=e003CM@00`00CMA=e004CM@00`00EOAEm002EO@@0004Acl30004Acl30004Acl40004Acl3
0004Acl30004Acl40003Acl30004Acl40004Acl30004Acl30004Acl40004Acl30004Acl30004Acl3
0004Acl30004Acl40004Acl30004Acl30004Acl40003Acl40003Acl40004Acl30004Acl30004Acl4
0004Acl30004Acl30004Acl40003Acl40003Acl40004Acl30004Acl30004Acl40003Acl40004Acl3
0004Acl30004Acl40003Acl40004Acl30004Acl30004Acl40003Acl40003Acl40004Acl30004Acl4
0003Acl40004Acl30004Acl30004Acl40003Acl40003Acl40004Acl30004Acl40003Acl40003Acl4
0004Acl30004Acl30004Acl40003Acl40004Acl30004Acl40002Acl50003Acl40003Acl40004Acl3
0004Acl40003Acl40003Acl50003Acl00`00Oomoo`0>Ool00`00Oomoo`1IOol005Aoo`03001oogoo
05Aoo`03001oogoo009oo`D00003Oa40000002/000E=e003001=e4gD00==e003001=e4gD00A=e003
001Em5Gd009Em14000A7?`<000A7?`<000A7?`@000A7?`<000A7?`<000A7?`<000A7?`@000A7?`<0
00A7?`<000A7?`<000A7?`@000=7?`@000A7?`<000A7?`<000A7?`@000=7?`@000=7?`@000A7?`<0
00A7?`<000A7?`@000A7?`<000A7?`<000A7?`<000A7?`@000=7?`@000A7?`<000A7?`<000A7?`@0
00=7?`@000A7?`<000A7?`<000A7?`<000A7?`@000A7?`<000A7?`<000A7?`@000=7?`@000=7?`@0
00A7?`<000A7?`<000A7?`@000=7?`@000A7?`<000A7?`@000=7?`@000=7?`@000=7?`@000A7?`<0
00A7?`@000=7?`@000A7?`<000=7?`@000A7?`<000A7?`@000=7?`@000A7?`<000A7?`@000=7?`@0
00=7?`@000=7?`@00097?`030017?`00008000A7?`@000=7?`@000=7?`@000A7?`<000A7?`<000A7
?`@000=7?`8000moo`03001oogoo05Uoo`00E7oo00<007ooOol0EGoo0P000Woo9`0000=o4@000000
2@001DgD00<004gDCM@00dgD00<004gDCM@014gD00<005GdEO@00UGd3P0000A7?`00000000A7?`<0
00A7?`@000A7?`<000A7?`<000A7?`<000A7?`<000A7?`@000A7?`<000A7?`<000A7?`@000A7?`<0
00=7?`@000A7?`<000A7?`<000A7?`@000A7?`<000A7?`<000A7?`<000A7?`<000A7?`@000=7?`@0
00A7?`<000A7?`<000A7?`@000A7?`<000=7?`@000A7?`<000A7?`<000A7?`@000A7?`<000A7?`<0
00A7?`@000=7?`@000=7?`@000A7?`<000A7?`<000A7?`@000=7?`@000A7?`<000A7?`<000A7?`<0
00A7?`@000=7?`@000A7?`<000A7?`<000A7?`@000=7?`@000=7?`@000A7?`<000A7?`@000=7?`@0
00=7?`@000A7?`<000A7?`<000A7?`@000=7?`@000=7?`@000A7?`<000A7?`@000=7?`@00003Acl0
04Lo00@000=7?`@000A7?`<000A7?`@000=7?`@000=7?`@000A7?`<000A7?`03001oogoo00ioo`03
001oogoo05Qoo`00E7oo00<007ooOol0Egoo00<007oo00005@0000=o4@0000006P001DgD00<004gD
CM@00dgD00<004gDCM@014gD00@005GdEOAEm0l00097?`@000=7?`<000A7?`@000A7?`<000A7?`<0
00A7?`@000A7?`<000A7?`<000A7?`<000A7?`<000A7?`@000A7?`<000A7?`<000A7?`<000A7?`@0
00=7?`@000=7?`@000A7?`<000A7?`<000A7?`@000=7?`@000A7?`<000A7?`<000A7?`<000A7?`@0
00=7?`@000A7?`<000A7?`<000A7?`@000=7?`@000=7?`@000A7?`<000A7?`<000A7?`@000=7?`@0
00A7?`<000A7?`<000A7?`<000A7?`@000=7?`@000A7?`<000A7?`<000A7?`@000=7?`@000=7?`@0
00=7?`@000A7?`<000A7?`@000=7?`@000A7?`<000=7?`@000A7?`<000A7?`@000=7?`@000=7?`@0
00A7?`<000A7?`@000=7?`@000=7?`@000=7?`@000A7?`<00004Acl004LoAcl40003Acl40003Acl4
0003Acl40004Acl30004Acl40003Acl40003Acl2000?Ool00`00Oomoo`1HOol005Aoo`<005Qooc@0
00E=e003001=e4gD00==e003001=e4gD00A=e004001Em5GdEO@>0004Acl40004Acl30004Acl30004
Acl40003Acl30004Acl40004Acl30004Acl30004Acl30004Acl40004Acl30003Acl40004Acl30004
Acl30004Acl40003Acl40004Acl30004Acl30004Acl30004Acl30004Acl40004Acl30004Acl30004
Acl40003Acl40003Acl40003Acl40004Acl30004Acl30004Acl40003Acl40004Acl30004Acl30004
Acl30004Acl40003Acl40004Acl30004Acl30004Acl40003Acl40003Acl40003Acl40004Acl30004
Acl40003Acl40003Acl40003Acl40004Acl30004Acl40003Acl40003Acl40004Acl30004Acl30004
Acl30004Acl40003Acl40003Acl40004Acl30004Acl40003Acl40003Acl50002Acl40004Acl30004
Acl40003Acl40003Acl40004Acl30004Acl30004Acl00`00Oomoo`0>Ool00`00Oomoo`1GOol005=o
o`8005]oo`X00003Oa40000002H000E=e003001=e4gD00==e003001=e4gD00A=e004001Em5GdEO@?
0004Acl40004Acl30004Acl30004Acl40004Acl30004Acl30004Acl30004Acl30004Acl30004Acl4
0004Acl30004Acl30004Acl30004Acl30004Acl30004Acl40004Acl30004Acl30004Acl40003Acl4
0003Acl40003Acl40004Acl30004Acl30004Acl40003Acl40004Acl30004Acl30004Acl30004Acl3
0004Acl40003Acl40004Acl30004Acl30004Acl40003Acl40003Acl40004Acl30004Acl30004Acl4
0003Acl40004Acl30003Acl40004Acl30004Acl30004Acl40003Acl40004Acl30004Acl30004Acl3
0004Acl40003Acl40003Acl40004Acl30004Acl40003Acl40003Acl40003Acl40004Acl30004Acl3
0004Acl40003Acl40003Acl40003Acl40004Acl30004Acl40003Acl40003Acl40003Acl2000?Ool0
0`00Oomoo`1GOol005Aoo`03001oogoo05Uoo`/00003Oa40000002D000E=e003001=e4gD00==e003
001=e4gD00A=e004001Em5GdEO@500000glb000000090004Acl30004Acl40003Acl30004Acl40004
Acl30004Acl30004Acl30004Acl40003Acl40003Acl40004Acl30004Acl30004Acl30004Acl40003
Acl40004Acl30004Acl30004Acl30004Acl30004Acl40003Acl40004Acl30004Acl30004Acl30004
Acl30004Acl40003Acl40004Acl30004Acl30004Acl40003Acl30004Acl40003Acl40004Acl30004
Acl30004Acl40003Acl40003Acl40004Acl30004Acl30004Acl40003Acl40003Acl40004Acl30004
Acl30004Acl30004Acl40003Acl40003Acl40004Acl30004Acl30004Acl30004Acl40003Acl40003
Acl40004Acl30004Acl40003Acl40003Acl40003Acl40003Acl40004Acl30004Acl40003Acl40003
Acl40004Acl30003Acl40004Acl30004Acl00`00Oomoo`0>Ool00`00Oomoo`1FOol005Aoo`03001o
ogoo05Qoo`h00003Oa40000001X00003Oa40000000H000E=e003001=e4gD00==e003001=e4gD00A=
e004001Em5GdEO@B0004Acl30004Acl40004Acl30004Acl30004Acl30004Acl30004Acl30004Acl3
0004Acl40004Acl30004Acl30004Acl30004Acl30004Acl30004Acl40004Acl30004Acl30004Acl3
0004Acl40003Acl30004Acl40004Acl30004Acl30004Acl30004Acl40003Acl40003Acl40003Acl4
0004Acl30004Acl30004Acl40003Acl40004Acl30003Acl40004Acl30004Acl30004Acl40003Acl4
0004Acl30004Acl30004Acl30004Acl30004Acl40003Acl40003Acl40004Acl30004Acl40003Acl3
0004Acl40003Acl40003Acl40004Acl30004Acl40003Acl40003Acl40003Acl40003Acl40004Acl3
0004Acl40003Acl40003Acl40003Acl40003Acl40004Acl30004Acl40003Acl40003Acl40003Acl4
0004Acl00`00Oomoo`0=Ool00`00Oomoo`1FOol005=oo`03001oogoo05Uoo`04Oa400000Oa4<0000
0glA0000000Q0005CM@00`00CMA=e003CM@00`00CMA=e004CM@01000EOAEm5Gd500014Lo0`000dLo
100014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo100014Lo0`000dLo100014Lo0`0014Lo0`0014Lo
0`0014Lo100014Lo0`0014Lo0`000dLo100014Lo0`0014Lo0`0014Lo10000dLo100014Lo0`0014Lo
0`0014Lo0`0014Lo0`0014Lo0`0014Lo10000dLo100014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo
10000dLo100014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo10000dLo10000dLo100014Lo0`0014Lo
0`0014Lo10000dLo0`0014Lo10000dLo100014Lo0`0014Lo0`0014Lo10000dLo10000dLo10000dLo
10000dLo100014Lo0`0014Lo0`0014Lo10000dLo10000dLo10000dLo100014Lo0`0014Lo0`0014Lo
10000dLo10000dLo10000dLo10000dLo100014Lo0`0014Lo10000dLo00<007ooOol03Woo00<007oo
Ool0EGoo001COol00`00Oomoo`1IOol00glA0000000>00000glA0000000;00000glA0000000@0000
0gk_001=e004CM@00`00CMA=e003CM@00`00CMA=e004CM@01000EOAEm5Gd5@0014Lo0`0014Lo0`00
14Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo100014Lo0`0014Lo0`0014Lo0`0014Lo10000dLo0`00
14Lo10000dLo100014Lo0`0014Lo0`0014Lo0`0014Lo10000dLo0`0014Lo10000dLo100014Lo0`00
14Lo0`0014Lo0`0014Lo10000dLo0`0014Lo10000dLo100014Lo0`0014Lo0`0014Lo10000dLo1000
0dLo10000dLo10000dLo100014Lo0`0014Lo0`0014Lo10000dLo10000dLo10000dLo100014Lo0`00
14Lo0`0014Lo0`0014Lo10000dLo10000dLo10000dLo100014Lo0`0014Lo0`0014Lo10000dLo1000
0dLo10000dLo10000dLo100014Lo0`0014Lo0`0014Lo10000dLo10000dLo10000dLo10000dLo1000
14Lo0`0014Lo10000dLo10000dLo10000dLo100014Lo0`000dLo0P003goo00<007ooOol0EGoo001C
Ool00`00Oomoo`1IOol00glA0000000@00000glA0000000:00000glA0000000?00000gk_001=e004
CM@00`00CMA=e003CM@00`00CMA=e004CM@01000EOAEm5Gd5P0014Lo0`0014Lo0`0014Lo0`0014Lo
0`0014Lo100014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo100014Lo0`0014Lo
0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo100014Lo0`0014Lo0`000dLo100014Lo0`0014Lo
0`0014Lo0`0014Lo10000dLo100014Lo0`000dLo100014Lo0`0014Lo0`0014Lo0`0014Lo10000dLo
100014Lo0`000dLo100014Lo0`0014Lo0`0014Lo0`0014Lo10000dLo100014Lo0`000dLo100014Lo
0`0014Lo0`0014Lo0`0014Lo10000dLo10000dLo10000dLo100014Lo0`0014Lo0`0014Lo10000dLo
10000dLo10000dLo100014Lo0`0014Lo0`0014Lo0`0014Lo10000dLo10000dLo10000dLo100014Lo
0`000dLo100014Lo0`0014Lo10000dLo10000dLo00<007ooOol03Woo00<007ooOol0E7oo001COol0
0`00Oomoo`1IOolQ00000glA0000000>00000gk_001=e004CM@00`00CMA=e003CM@00`00CMA=e004
CM@00`00EOAEm00H0004Acl30004Acl30004Acl40003Acl30004Acl40004Acl30004Acl30004Acl3
0004Acl30004Acl40003Acl30004Acl40003Acl40004Acl30004Acl30004Acl30004Acl40003Acl3
0004Acl40003Acl40004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl40003Acl4
0004Acl30004Acl30004Acl30004Acl30004Acl30004Acl40003Acl40003Acl40004Acl30004Acl3
0004Acl30004Acl30004Acl40003Acl40003Acl40004Acl30004Acl30004Acl30004Acl30004Acl3
0004Acl40003Acl40003Acl40004Acl30004Acl30004Acl30004Acl30004Acl40003Acl40003Acl4
0003Acl40004Acl30003Acl40004Acl30004Acl40003Acl40003Acl40003Acl40004Acl30003Acl4
0004Acl00`00Oomoo`0=Ool00`00Oomoo`1DOol005=oo`03001oogoo05Uooc800003O^l004gD00A=
e003001=e4gD00==e003001=e4gD00A=e003001Em5Gd01T000A7?`<000A7?`<000A7?`@000=Em0@0
00A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`@000=7?`@000A7?`<000A7?`<000A7?`<0
00A7?`<000A7?`<000A7?`<000A7?`@000=7?`@000A7?`<000=7?`@000A7?`<000A7?`<000A7?`<0
00A7?`<000A7?`@000=7?`@000A7?`<000=7?`@000A7?`<000A7?`<000A7?`<000A7?`<000A7?`@0
00=7?`@000=7?`@000=7?`@000A7?`<000A7?`<000A7?`<000A7?`@000=7?`@000=7?`@000=7?`@0
00=7?`@000A7?`<000A7?`<000A7?`<000A7?`@000=7?`<000A7?`@000=7?`@000=7?`@000=7?`@0
00A7?`<000A7?`<000A7?`<000A7?`<000A7?`@000=7?`@00097?`D000=7?`@000A7?`<000A7?`<0
00A7?`<000A7?`@000=7?`@000=7?`@000=7?`03001oogoo00ioo`03001oogoo05=oo`00Dgoo00<0
07ooOol0FGoo900000=o4@00000030001TgD00<004gDCM@00dgD00<004gDCM@014gD00<005GdEO@0
6`0014Lo0`000dgD00<004gDCM@00dgD00<005GdEO@015Gd1@0014Lo0`0014Lo0`0014Lo0`0014Lo
10000dLo100014Lo0`000dLo100014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo10000dLo10000dLo
0`0014Lo10000dLo100014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo10000dLo
100014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo10000dLo10000dLo100014Lo
0`000dLo100014Lo0`0014Lo0`0014Lo0`0014Lo10000dLo10000dLo10000dLo10000dLo10000dLo
100014Lo0`0014Lo0`0014Lo0`0014Lo10000dLo0`0014Lo10000dLo10000dLo10000dLo100014Lo
0`0014Lo0`0014Lo0`000TLo00<004Lo00000P0014Lo10000dLo10000dLo10000dLo100014Lo0`00
0dLo100014Lo0`0014Lo00<007ooOol03Goo00<007ooOol0Dgoo001COol00`00Oomoo`1IOol50000
0glA0000000[0006CM@00`00CMA=e003CM@00`00CMA=e004CM@00`00EOAEm00500000glb00000006
00000glA0000000;0003CM@00`00CMA=e003CM@00`00CMA=e003CM@00`00EOAEm004EO@60004Acl3
0004Acl40003Acl30004Acl30004Acl40004Acl30004Acl30004Acl30004Acl30004Acl30004Acl3
0004Acl30004Acl40003Acl40004Acl30004Acl30003Acl40004Acl30004Acl30004Acl30004Acl3
0004Acl40003Acl40003Acl40003Acl40003Acl40004Acl30004Acl30004Acl30004Acl30004Acl3
0004Acl30004Acl40003Acl40003Acl40004Acl30004Acl30004Acl30004Acl30004Acl30004Acl3
0004Acl40003Acl40003Acl40003Acl40003Acl40003Acl40004Acl30004Acl30004Acl30004Acl4
0003Acl30004Acl40003Acl40003Acl40003Acl4000014Lo0017?dLo0`0014Lo0`0014Lo0`0014Lo
0`0014Lo10000dLo10000dLo10000dLo10000dLo0P003goo00<007ooOol0DWoo001COol00`00Oomo
o`1IOolW00000glA000000090006CM@00`00CMA=e003CM@00`00CMA=e004CM@00`00EOAEm00?0000
0glA000000080005CM@00`00CMA=e003CM@00`00CMA=e003CM@00`00EOAEm004EO@70004Acl30004
Acl40003Acl40004Acl30004Acl30003Acl40004Acl30004Acl30004Acl30004Acl30004Acl40003
Acl40003Acl30004Acl40003Acl40004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004
Acl30004Acl40003Acl40003Acl40004Acl30003Acl40003Acl40004Acl30004Acl30004Acl30004
Acl30004Acl40003Acl30004Acl40003Acl40003Acl40004Acl30004Acl30004Acl30004Acl30004
Acl30004Acl30004Acl40003Acl40003Acl40003Acl40003Acl40003Acl40003Acl40004Acl30004
Acl30004Acl30004Acl40003Acl40003Acl50002Acl40003Acl40003Acl40003Acl40004Acl30004
Acl30004Acl30004Acl30004Acl00`00Oomoo`0=Ool00`00Oomoo`1BOol003Yoo`X000moo`03001o
ogoo05Uooc<000I=e003001=e4gD00==e003001=e4gD00A=e003001Em5Gd01X000E=e003001=e4gD
00==e003001=e4gD00==e003001Em5Gd00=Em003001o<P0000L000A7?`<000=7?`<000A7?`@000A7
?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`@000=7?`<000A7?`<000A7?`@000=7?`@000A7
?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`@000=7?`@000=7
?`<000A7?`@000=7?`@000=7?`@000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7
?`<000A7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000A7?`<000A7?`<000A7?`<000A7
?`<000A7?`<000A7?`<000A7?`<000A7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7
?`@000A7?`<000A7?`@000=7?`<000A7?`@000=7?`<000A7?`@000=7?`@000=7?`@000=7?`@000=7
?`@000=7?`8000moo`03001oogoo055oo`00>Woo2P003goo00<007ooOol0FGoo5P0000=o4@000000
6P001TgD00<004gDCM@00dgD00<004gDCM@014gD00<005GdEO@06P001DgD00<004gDCM@00dgD00<0
04gDCM@00dgD00<005GdEO@00eGd0P0000=o<P0000001P0014Lo0`0014Lo0`0014Lo0`0014Lo0`00
14Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo10000dLo100014Lo0`000dLo10000dLo1000
14Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo1000
0dLo10000dLo10000dLo10000dLo10000dLo100014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`00
14Lo0`0014Lo0`0014Lo0`0014Lo10000dLo10000dLo10000dLo10000dLo10000dLo10000dLo1000
14Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo10000dLo10000dLo10000dLo1000
0dLo10000dLo10000dLo10000dLo100014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`00
14Lo00<007ooOol03Goo00<007ooOol0DGoo000nOol2000COol00`00Oomoo`1IOol;00000glA0000
000U0006CM@00`00CMA=e003CM@00`00CMA=e004CM@00`00EOAEm00J0005CM@00`00CMA=e003CM@0
0`00CMA=e003CM@00`00EOAEm003EO@<0004Acl30004Acl30004Acl30004Acl30004Acl30004Acl3
0004Acl30004Acl40003Acl30004Acl30004Acl40003Acl40004Acl30004Acl30004Acl30003Acl4
0004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl40003Acl30004Acl30004Acl4
0003Acl40003Acl40004Acl30004Acl30003Acl40003Acl40004Acl30004Acl30004Acl30004Acl3
0004Acl30004Acl30004Acl30004Acl30004Acl40003Acl40003Acl40003Acl40003Acl40003Acl4
0003Acl40003Acl40004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl4
0003Acl40003Acl40003Acl40003Acl40003Acl40003Acl40003Acl40003Acl40004Acl00`00Oomo
o`0=Ool00`00Oomoo`1@Ool003ioo`80019oo`H005Ioo`h00003Oa40000002<000I=e003001=e4gD
00==e003001=e4gD00A=e004001Em000Oc8;00000glb0000000;0005CM@00`00CMA=e003CM@00`00
CMA=e003CM@00`00EOAEm003EO@=0004Acl30004Acl30004Acl30004Acl30004Acl40003Acl30004
Acl30004Acl30004Acl40003Acl40004Acl30004Acl30003Acl40003Acl40004Acl30004Acl30004
Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl40003Acl40003
Acl30004Acl40003Acl40003Acl40003Acl40004Acl30004Acl30003Acl40003Acl40004Acl30004
Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl40003Acl40003
Acl40003Acl40003Acl40003Acl40003Acl40003Acl40003Acl40004Acl30003Acl40003Acl40004
Acl30004Acl30004Acl30004Acl30004Acl40003Acl30004Acl30004Acl40003Acl00`00Oomoo`0=
Ool00`00Oomoo`1@Ool003ioo`8001=oo`03001oogoo05Qoo`04Oa400000Oa4W00000glA00000006
0006CM@00`00CMA=e003CM@00`00CMA=e004CM@00`00EO@0000J0005CM@00`00CMA=e003CM@00`00
CMA=e003CM@00`00EOAEm003EO@>0004Acl40003Acl30004Acl30004Acl30004Acl30004Acl40004
Acl30004Acl30003Acl30004Acl40003Acl40004Acl30004Acl30004Acl30004Acl30004Acl30004
Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl40003Acl30004Acl30004Acl30004
Acl40003Acl40003Acl40003Acl40003Acl40003Acl40003Acl40003Acl40003Acl40004Acl30004
Acl30003Acl40003Acl40004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004
Acl30004Acl30004Acl40003Acl40003Acl40003Acl30004Acl40003Acl40003Acl40003Acl40003
Acl40003Acl40003Acl40003Acl40003Acl40003Acl40003Acl40004Acl30004Acl00`00Oomoo`0=
Ool00`00Oomoo`1?Ool003ioo`8001=oo`03001oogoo05Qoo`03Oa400000034000I=e003001=e4gD
00==e003001=e4gD00A=e003001Em00001X000E=e003001=e4gD00==e003001=e4gD00==e003001E
m5Gd00=Em0l000A7?`<000A7?`@000=7?`@000A7?`<000A7?`<000=7?`@000=7?`@000=7?`@000A7
?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7
?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`@000=7?`<000A7?`<000A7
?`<000A7?`@000=7?`@000=7?`@000=7?`@000=7?`<000A7?`@000=7?`@000=7?`@000=7?`@000=7
?`@000A7?`<000=7?`@000=7?`@000=7?`@000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000A7
?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7
?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`03001oogoo00eoo`03001oogoo04mo
o`00?Woo0P004goo00<007ooOol0F7oo00=o4@000000700000=o4@000000400000=nk`00CM@01DgD
00<004gDCM@00dgD00<004gDCM@014gD00<005Gd0000100000=o<P0000004`001DgD00<004gDCM@0
0dgD00<004gDCM@00dgD00<005GdEO@00eGd200000=o<P0000000P0000A7?`00000000A7?`<000A7
?`<000=7?`@000=7?`@000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7
?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7
?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`@000=7?`<000A7
?`<000A7?`<000A7?`@000=7?`@000=7?`@000=7?`@000=7?`<000A7?`@000=7?`@000=7?`@000=7
?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000A7?`<000=7
?`@000=7?`@000=7?`@000=7?`@000=7?`@000A7?`<000A7?`<000=7?`@000=7?`@000A7?`<000A7
?`<000A7?`<000A7?`<000A7?`03001oogoo00eoo`03001oogoo04ioo`00?Woo0P004Woo00<007oo
Ool0FGoo00=o4@000000400000=o4@0000002P0000=o4@0000003`0000=nk`00CM@01DgD00<004gD
CM@00dgD00<004gDCM@014gD00<005Gd00006P001DgD00<004gDCM@00dgD00<004gDCM@00dgD00<0
05GdEO@00eGd2@0000Ao<P0000000097?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7
?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7
?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7
?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`@000=7?`<000A7
?`<000A7?`<000A7?`<000A7?`<000A7?`@000=7?`@000=7?`<000A7?`<000A7?`<000A7?`@000=7
?`@000=7?`@000=7?`@000=7?`<000A7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@00097
?`D000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`8000mo
o`03001oogoo04eoo`00?Woo0P004Woo00<007ooOol0FGoo8@0000=o4@0000003P0000=nk`00CM@0
1DgD00<004gDCM@00dgD00<004gDCM@014gD00<005Gd00006P001DgD00<004gDCM@00dgD00<004gD
CM@00dgD00<005GdEO@00eGd3@000dLo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo
0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo
0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo
0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo
0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo
0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`000TLo
00<004Lo00000P0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`00
14Lo00<007ooOol03Goo00<007ooOol0CGoo000nOol2000BOol00`00Oomoo`1IOolb00000gk_001=
e005CM@00`00CMA=e003CM@00`00CMA=e004CM@00`00EO@0000J0005CM@00`00CMA=e003CM@00`00
CMA=e003CM@00`00EOAEm002EO@>0004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004
Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004
Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004
Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004
Acl30004Acl30004Acl30004Acl30004Acl30004Acl30003Acl40003Acl40003Acl40004Acl30004
Acl30004Acl30004Acl30003Acl40003Acl40003Acl40003Acl40003Acl40003Acl40003Acl40000
0dLo0017?`040003Acl40003Acl40003Acl40003Acl40003Acl40003Acl40003Acl40003Acl40003
Acl2000?Ool00`00Oomoo`1<Ool003ioo`80019oo`03001oogoo05Uoob@00003Oa40000000/00003
O^l004gD00E=e003001=e4gD00==e003001=e4gD00A=e003001Em00001X000E=e003001=e4gD00==
e003001=e4gD00==e003001Em5Gd009Em0l000A7?`<000A7?`<000A7?`@000=7?`@000=7?`<000A7
?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7
?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7
?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`@000=7
?`@000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7
?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`<000A7?`<000A7
?`<00097?`030017?`0000<000=7?`@000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<0
00A7?`<000A7?`03001oogoo00eoo`03001oogoo04aoo`00?Woo0P004Woo00<007ooOol0FGoo<P00
00=nk`00CM@01DgD00<004gDCM@00dgD00<004gDCM@014gD0P0000=o<P0000002@0000=o<P000000
30001DgD00<004gDCM@00dgD00<004gDCM@00dgD00<005GdEO@00UGd3@0000A7?`00000000A7?`<0
00=7?`<000A7?`<000A7?`<000A7?`@000=7?`@000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<0
00A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<0
00A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@0
00=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@0
00=7?`@000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<0
00A7?`<000A7?`<000A7?`<000A7?`<000A7?`<00004Acl004LoAcl30003Acl40003Acl40003Acl4
0003Acl40003Acl40003Acl40003Acl40003Acl40003Acl2000?Ool00`00Oomoo`1;Ool003ioo`80
019oo`03001oogoo05UoobL00003Oa40000000P00003O^l004gD00E=e003001=e4gD00==e003001=
e4gD00A=e1d000E=e003001=e4gD00==e003001=e4gD00==e003001Em5Gd009Em0d00097?`<000A7
?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`@000=7?`@000=7?`@000=7
?`@000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7
?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`@000=7?`@000=7
?`@000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<000A7?`@000=7?`@000=7?`@000=7?`@000=7
?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7
?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`D00097?`@000=7?`@000=7?`@000=7?`@000=7
?`@000=7?`<000A7?`<000A7?`<000A7?`<000A7?`03001oogoo00eoo`03001oogoo04]oo`00?Woo
0P004Woo00<007ooOol0FGoo<P0000=nk`00CM@01DgD00<004gDCM@00dgD00<004gDCM@00dgD00<0
05Gd00003P0000=o4@0000002P001DgD00<004gDCM@00dgD00<004gDCM@00dgD00<005GdEO@00UGd
3@000dLo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo
0`000dLo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo
0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo
0`0014Lo0`000dLo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo
0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`000dLo10000dLo10000dLo10000dLo10000dLo
10000dLo10000dLo10000dLo10000dLo10000dLo0`0014Lo0`0014Lo10000dLo0`0014Lo0`0014Lo
0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`000dLo0P003goo00<007ooOol0BWoo
000nOol2000BOol00`00Oomoo`1IOol:00000glA0000000900000glA0000000I00000gk_001=e004
CM@00`00CMA=e003CM@00`00CMA=e004CM@00`00EO@0000400000glb0000000800000glA00000009
0005CM@00`00CMA=e003CM@00`00CMA=e003CM@00`00EOAEm002EO@>0003Acl30004Acl30004Acl3
0004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl3
0004Acl30003Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl3
0004Acl30004Acl30004Acl30004Acl30004Acl30003Acl40003Acl40003Acl30004Acl30004Acl3
0004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30003Acl4
0003Acl40003Acl40003Acl40003Acl40003Acl40003Acl40003Acl30004Acl30004Acl30004Acl3
0004Acl30004Acl30004Acl30003Acl40003Acl40003Acl40003Acl40003Acl40003Acl40003Acl4
0003Acl40003Acl40003Acl40003Acl00`00Oomoo`0=Ool00`00Oomoo`1:Ool003Yoo`<00003Ool0
0000019oo`03001oogoo05Qoo``00003Oa40000002@00003O^l004gD00A=e003001=e4gD00==e003
001=e4gD00A=e003001Em00001/000A=e003001=e4gD00A=e003001=e4gD00==e003001Em5Gd009E
m0P00003Oc80000000<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7
?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`<000A7
?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7
?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7
?`<000A7?`<000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`<000A7
?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`@000=7?`@000=7
?`@000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`03001o
ogoo00eoo`03001oogoo04Uoo`00>Woo1P004Woo00<007ooOol0F7oo00Ao4@00001o4@X00003Oa40
000002800003O^l004gD00A=e003001=e4gD00==e003001=e4gD00A=e003001Em00001X000E=e003
001=e4gD00A=e003001=e4gD00==e003001Em5Gd009Em0T00003Oc80000000@000A7?`<000=7?`<0
00A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<0
00A7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<0
00A7?`<000A7?`<000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<0
00A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@0
00=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@0
00=7?`@000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@0
00=7?`@000=7?`@000=7?`@000=7?`@000=7?`03001oogoo00eoo`03001oogoo04Uoo`00?Goo0`00
4Woo00<007ooOol0F7oo00=o4@000000<00000=nk`00CM@014gD00<004gDCM@00dgD00<004gDCM@0
14gD00<005Gd00006P001DgD00<004gDCM@014gD00<004gDCM@00dgD00<005GdEO@00UGd3@0000A7
?`00000000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<000A7?`<0
00A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<0
00A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<0
00A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@0
00=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@0
00=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`@0
00=7?`@000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000A7?`03001oogoo00eoo`03
001oogoo04Qoo`00DGoo1000F7oo00=o4@000000:00000=o4@0000001@0000=nk`00CM@014gD00<0
04gDCM@00dgD00<004gDCM@014gD00<005Gd00006P001DgD00<004gDCM@014gD00<004gDCM@00dgD
00@005GdEOAEm0d000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`<0
00A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<0
00=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`<0
00A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`@0
00=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@0
00=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`@000=7?`@000=7?`@0
00=7?`@000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`@000=7?`03
001oogoo00eoo`03001oogoo04Qoo`00DWoo00<007ooOol0F7oo00=o4@000000700000=o4@000000
40000Wk_00<004gDCM@00dgD00<004gDCM@00dgD00<004gDCM@014gD0P0000=o<P0000002@0000=o
<P00000030001DgD00<004gDCM@014gD00<004gDCM@00dgD00@005GdEOAEm0h000A7?`<000=7?`<0
00A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<000A7?`<0
00A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<0
00A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<0
00A7?`<000A7?`<000A7?`<000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<0
00A7?`<000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@0
00=7?`@000=7?`@000=7?`@000=7?`@000=7?`<000=7?`@000A7?`<000A7?`<000=7?`@000=7?`@0
00=7?`@000=7?`@000=7?`<000A7?`<000A7?`<000A7?`03001oogoo00eoo`03001oogoo04Moo`00
DWoo00<007ooOol0F7oo4`0000=o4@0000002P0000=o4@0000003`000Wk_00<004gDCM@00dgD00<0
04gDCM@00dgD00<004gDCM@014gD7@001DgD00<004gDCM@014gD00<004gDCM@00dgD00@005GdEOAE
m0l000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7
?`@000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7
?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<000A7
?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7
?`<000=7?`@000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7
?`@000=7?`@000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<00097?`D000=7?`@000=7
?`@000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`03001oogoo00eo
o`03001oogoo04Moo`00DWoo00<007ooOol0F7oo8@0000=o4@0000003P0000=nk`00CM@01DgD00<0
04gDCM@00dgD00<004gDCM@014gD7@001DgD00<004gDCM@014gD00<004gDCM@00dgD00@005GdEOAE
m10000A7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7
?`<000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7
?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000A7
?`<000A7?`<000=7?`@000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7
?`@000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`@000=7
?`@000=7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`@00003Acl004Lo00@000=7
?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`@000=7?`@000=7?`<000A7?`03001o
ogoo00eoo`03001oogoo04Ioo`00DGoo00<007ooOol0FGoo<P0000=nk`00CM@01DgD00<004gDCM@0
0dgD00<004gDCM@014gD1P0000=o<P00000050001DgD00<004gDCM@014gD00<004gDCM@00dgD00@0
05GdEOAEm0H00003Oc80000000@00004Acl000000004Acl30004Acl30004Acl30004Acl30003Acl3
0004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30003Acl40003Acl30004Acl30004Acl3
0004Acl30004Acl30003Acl40003Acl40003Acl30004Acl30004Acl30004Acl30004Acl30003Acl4
0003Acl40003Acl30004Acl30004Acl30004Acl30004Acl30003Acl40003Acl40003Acl40003Acl3
0004Acl30004Acl30004Acl30003Acl40003Acl40003Acl40003Acl30004Acl30004Acl30004Acl3
0003Acl40003Acl40003Acl40003Acl30004Acl30004Acl30004Acl30003Acl40003Acl40003Acl4
0003Acl40003Acl3000014Lo0017?dLo0`0014Lo0`000dLo10000dLo10000dLo10000dLo10000dLo
0`0014Lo0`0014Lo0`000dLo10000dLo0P003Woo00<007ooOol0AWoo001AOol00`00Oomoo`1IOol5
00000glA0000000L00000glA0000000;00000gk_001=e005CM@00`00CMA=e003CM@00`00CMA=e004
CM@M0005CM@00`00CMA=e004CM@00`00CMA=e003CM@01000EOAEm5Gd3@000TLo0`0014Lo0`0014Lo
0`0014Lo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo
0`000dLo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`0014Lo
0`0014Lo0`0014Lo0`0014Lo0`000dLo10000dLo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`000dLo
10000dLo10000dLo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`000dLo10000dLo10000dLo0`0014Lo
0`0014Lo0`0014Lo0`000dLo10000dLo10000dLo10000dLo0`0014Lo0`0014Lo0`000dLo10000dLo
10000dLo10000dLo0`0014Lo0`0014Lo0`000dLo1@000TLo10000dLo10000dLo10000dLo0`0014Lo
0`0014Lo0`000dLo10000dLo10000dLo10000dLo10000dLo00<007ooOol03Goo00<007ooOol0AGoo
001AOol00`00Oomoo`1IOold0006CM@00`00CMA=e003CM@00`00CMA=e004CM@M0005CM@00`00CMA=
e004CM@00`00CMA=e003CM@01000EOAEm5Gd3@0014Lo0`000dLo0`0014Lo0`0014Lo0`0014Lo0`00
14Lo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`000dLo10000dLo0`0014Lo0`00
14Lo0`0014Lo0`0014Lo0`000dLo10000dLo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`000dLo1000
0dLo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`0014Lo0`00
14Lo0`0014Lo0`0014Lo0`000dLo10000dLo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`000dLo1000
0dLo10000dLo0`0014Lo0`0014Lo0`0014Lo0`000dLo10000dLo10000dLo0`0014Lo0`0014Lo0`00
0dLo10000dLo10000dLo10000dLo0`0014Lo0`0014Lo0`000dLo10000dLo10000dLo10000dLo1000
0dLo0`0014Lo0`000dLo10000dLo0P003Woo00<007ooOol0AGoo001AOol00`00Oomoo`1IOolW0000
0glA0000000:0006CM@00`00CMA=e003CM@00`00CMA=e004CM@M0005CM@00`00CMA=e004CM@00`00
CMA=e003CM@01000EOAEm5Gd2P0000Ao<P00000000A7?`<000=7?`<000A7?`<000A7?`<000A7?`<0
00A7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<0
00=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<0
00=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<0
00A7?`<000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`<000A7?`<0
00A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000=7?`@0
00=7?`@000=7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<0
00=7?`@000=7?`@000=7?`@000=7?`03001oogoo00eoo`03001oogoo04Aoo`00DGoo00<007ooOol0
FGoo=0001TgD00<004gDCM@00dgD00<004gDCM@014gD7@001DgD00<004gDCM@014gD00<004gDCM@0
0dgD00<005GdEO@0400014Lo0`0014Lo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`0014Lo
0`000dLo10000dLo0`0014Lo0`0014Lo0`0014Lo0`000dLo10000dLo0`0014Lo0`0014Lo0`0014Lo
0`0014Lo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`000dLo10000dLo
0`0014Lo0`0014Lo0`000dLo10000dLo10000dLo0`0014Lo0`0014Lo0`000dLo10000dLo10000dLo
0`0014Lo0`0014Lo0`0014Lo0`000dLo10000dLo0`0014Lo0`0014Lo0`0014Lo0`0014Lo0`000dLo
10000dLo0`0014Lo0`0014Lo0`0014Lo0`000dLo10000dLo10000dLo10000dLo0`0014Lo0`000dLo
10000dLo10000dLo10000dLo0`0014Lo0`000dLo10000dLo10000dLo10000dLo0`0014Lo0`0014Lo
0`0014Lo00<007ooOol037oo00<007ooOol0A7oo001AOol00`00Oomoo`1HOol;00000glA00000009
00000glA0000000K0006CM@00`00CMA=e003CM@00`00CMA=e004CM@00`00Oc80000:00000glb0000
000=0005CM@00`00CMA=e004CM@00`00CMA=e003CM@00`00EOAEm00A0004Acl30004Acl30004Acl3
0003Acl30004Acl30004Acl30004Acl30004Acl30004Acl30004Acl30003Acl30004Acl30004Acl3
0004Acl30004Acl30003Acl30004Acl30004Acl30004Acl30003Acl40003Acl30004Acl30004Acl3
0004Acl30004Acl30003Acl30004Acl30004Acl30004Acl30004Acl30004Acl30003Acl40003Acl3
0004Acl30004Acl30003Acl40003Acl40003Acl30004Acl30004Acl30003Acl40003Acl30004Acl3
0004Acl30004Acl30004Acl30003Acl30004Acl30004Acl30004Acl30004Acl30003Acl40003Acl4
0003Acl30004Acl30004Acl30003Acl40003Acl40003Acl30004Acl30003Acl40003Acl40003Acl4
0003Acl30004Acl30004Acl30003Acl40003Acl40003Acl00`00Oomoo`0=Ool00`00Oomoo`13Ool0
055oo`03001oogoo05Qoo`04Oa400000Oa4800000glA0000000V0006CM@00`00CMA=e003CM@00`00
CMA=e004CM@@00000glA0000000:0005CM@00`00CMA=e004CM@00`00CMA=e003CM@00`00EOAEm00C
0004Acl30003Acl30004Acl30004Acl30004Acl30003Acl30004Acl30004Acl30004Acl30003Acl3
0004Acl30004Acl30004Acl30004Acl30004Acl30003Acl30004Acl30004Acl30004Acl30004Acl3
0003Acl40003Acl30004Acl30004Acl30003Acl40003Acl30004Acl30004Acl30004Acl30003Acl4
0003Acl30004Acl30004Acl30004Acl30004Acl30003Acl40003Acl30004Acl30004Acl30003Acl4
0003Acl40003Acl30004Acl30004Acl30003Acl40003Acl30004Acl30004Acl30004Acl30004Acl3
0003Acl40003Acl30004Acl30004Acl30003Acl40003Acl40003Acl30004Acl30004Acl30003Acl4
0003Acl40003Acl30004Acl30004Acl30003Acl40003Acl30004Acl30004Acl30004Acl00`00Oomo
o`0<Ool00`00Oomoo`13Ool0055oo`03001oogoo05Qoo`03Oa40000000/00003Oa40000002@000I=
e003001=e4gD00==e003001=e4gD00A=e1400003Oa40000000T000E=e003001=e4gD00A=e003001=
e4gD00==e003001Em5Gd01@000A7?`<000=7?`<000A7?`<000A7?`@000=7?`<000A7?`<000=7?`<0
00A7?`<000A7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<000A7?`<000=7?`<000A7?`<0
00A7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`<0
00A7?`<000A7?`<000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<0
00A7?`<000A7?`<000=7?`@000=7?`<000A7?`<000A7?`<000=7?`@000=7?`<000A7?`<000A7?`<0
00A7?`<000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7?`<000A7?`<0
00=7?`@000=7?`@000=7?`<000A7?`<000A7?`<000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<0
00=7?`@000=7?`03001oogoo00eoo`03001oogoo049oo`00DGoo00<007ooOol0F7oo00=o4@000000
3@0000=o4@0000008P001TgD00<004gDCM@00dgD00@004gDCMA=e0P00003Oc80000001D000E=e003
001=e4gD00A=e003001=e4gD00==e003001Em5Gd01H000=7?`<000A7?`<000A7?`<000=Em0<000A7
?`<000A7?`<000=7?`<000A7?`<000A7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<000A7
?`<000A7?`<000=7?`<000A7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<000A7?`<000A7
?`<000=7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`<000A7?`<000A7?`<000=7?`@000=7
?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`<000A7?`<000A7?`<000=7?`@000=7?`@000=7
?`<000A7?`<000=7?`@000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`<000A7
?`<000A7?`<000=7?`@00097?`@000A7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<000A7
?`<000=7?`@000=7?`@000=7?`<000A7?`03001oogoo00aoo`03001oogoo049oo`00DGoo00<007oo
Ool0F7oo00=o4@0000003P0000=o4@0000008@000dgD3@0014=O70001DgD00<004gDCM@00dgD00<0
04gDCM@00dgD00@005GdEOAEm1H000A7?`<00005AcmAe57DDM@00005DM@00`00EOAEm003EO@40004
Acl30004Acl30004Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004Acl30004Acl30004
Acl30004Acl30003Acl30004Acl30004Acl30004Acl30003Acl40003Acl30004Acl30004Acl30003
Acl30004Acl30004Acl30004Acl30004Acl30003Acl40003Acl30004Acl30004Acl30003Acl40003
Acl30004Acl30004Acl30003Acl30004Acl30004Acl30004Acl30004Acl30003Acl40003Acl30004
Acl30003Acl40003Acl40003Acl30004Acl30004Acl30004Acl30003Acl30004Acl30004Acl30003
Acl40003Acl40003Acl30002Acl00`00Acl000020003Acl40003Acl40003Acl30004Acl30004Acl3
0003Acl40003Acl40003Acl30004Acl30003Acl40003Acl2000>Ool00`00Oomoo`11Ool0055oo`03
001oogoo05Qoo`03Oa40000001000003Oa40000000P00003Oa40000000X00003Oa40000000X000=3
G`@000A3G`<000A3Ga/000E=e003001=e4gD00==e003001=e4gD00==e004001Em5GdEO@800000glb
0000000=0003DM@00`00DMAAe003DM@00`00DMAAe003DM@00`00EOAEm003EO@60003Acl30004Acl3
0004Acl30003Acl30004Acl30004Acl30004Acl30004Acl30004Acl30003Acl30004Acl30004Acl3
0003Acl30004Acl30004Acl30004Acl30004Acl30003Acl30004Acl30004Acl30003Acl40003Acl3
0004Acl30004Acl30003Acl30004Acl30004Acl30004Acl30004Acl30003Acl40003Acl30004Acl3
0003Acl40003Acl30004Acl30004Acl30004Acl30003Acl40003Acl30004Acl30004Acl30003Acl4
0003Acl30004Acl30004Acl30003Acl40003Acl30004Acl30004Acl30003Acl40003Acl30004Acl3
0004Acl300000dLo0017?`040003Acl30004Acl30004Acl30003Acl40003Acl40003Acl30004Acl3
0003Acl40003Acl40003Acl30004Acl00`00Oomoo`0<Ool00`00Oomoo`11Ool0055oo`<005Qoob00
0003Oa40000001D000A3G`@000A3G`<000A3G`H00003Oc800000014000E=e003001=e4gD00==e003
001=e4gD00==e004001Em5GdEO@900000glb0000000:0005DM@00`00DMAAe003DM@00`00DMAAe003
DM@00`00EOAEm003EO@70004Acl30003Acl40003Acl30004Acl30004Acl30003Acl30004Acl30004
Acl30003Acl30004Acl30004Acl30004Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004
Acl30004Acl30004Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004Acl30004Acl30004
Acl30004Acl30003Acl30004Acl30004Acl30003Acl40003Acl30004Acl30004Acl30003Acl30004
Acl30004Acl30004Acl30003Acl40003Acl30004Acl30004Acl30003Acl40003Acl30004Acl30004
Acl30003Acl40003Acl30004Acl30003Acl40003Acl50002Acl30004Acl30004Acl30003Acl40003
Acl30004Acl30003Acl40003Acl40003Acl30004Acl30004Acl30003Acl2000>Ool00`00Oomoo`10
Ool0051oo`8005Yoob400003Oa40000001H000A3G`<000E3G`<000A3G`D00003Oc800000010000E=
e003001=e4gD00==e003001=e4gD00==e004001Em5GdEO@F0005DM@00`00DMAAe003DM@00`00DMAA
e003DM@00`00EOAEm002EO@90004Acl30003Acl30004Acl30004Acl30004Acl30004Acl30003Acl3
0004Acl30004Acl30003Acl30004Acl30004Acl30004Acl30003Acl30004Acl30004Acl30003Acl4
0003Acl30004Acl30004Acl30004Acl30003Acl30004Acl30004Acl30003Acl40003Acl30004Acl3
0004Acl30003Acl30004Acl30004Acl30004Acl30003Acl30004Acl30004Acl30003Acl40003Acl3
0004Acl30004Acl30003Acl40003Acl30004Acl30004Acl30003Acl40003Acl30004Acl30004Acl3
0003Acl40003Acl30004Acl30003Acl40003Acl40003Acl40003Acl30004Acl30003Acl40003Acl3
0004Acl30003Acl40003Acl30004Acl30004Acl30003Acl40003Acl30004Acl00`00Oomoo`0<Ool0
0`00Oomoo`10Ool0055oo`03001oogoo05Qooc/000A3G`@000A3G`<000A3G`H00003Oc80000000h0
00E=e003001=e4gD00==e003001=e4gD00==e003001Em5Gd01L000EAe003001Ae57D00=Ae003001A
e57D00=Ae003001Em5Gd009Em0/000=7?`<000A7?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7
?`<000A7?`<000A7?`<000A7?`<000=7?`<000A7?`<000=7?`@000=7?`<000A7?`<000A7?`<000A7
?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<000A7?`<000=7?`@000=7?`<000A7
?`<000=7?`@000=7?`<000A7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7
?`<000A7?`<000A7?`<000=7?`@000=7?`<000A7?`<000=7?`@000=7?`<000A7?`<000A7?`<000=7
?`@000=7?`<000A7?`<000=7?`@000=7?`<000A7?`<000A7?`<000=7?`@000=7?`<000A7?`<000A7
?`<000=7?`@000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<000=7?`8000ioo`03001o
ogoo03moo`00DGoo00<007ooOol0F7oo1@0000=o4@000000700000=o4@0000002@0000=o4@000000
2P0014=O0`0014=O10000d=O500000=nk`00CM@014gD00<004gDCM@00dgD00<004gDCM@00dgD00<0
05GdEO@0400000=o4@00000010001E7D00<0057DDM@00e7D00<0057DDM@00e7D00<005GdEO@00UGd
2`0014Lo0`0014Lo0`0014Lo0`000dLo10000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`0014Lo
0`000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`0014Lo
0`000dLo0`0014Lo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo10000dLo0`0014Lo
0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo10000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo
0`0014Lo0`000dLo10000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo10000dLo
0`0014Lo0`0014Lo0`000dLo10000dLo0`0014Lo0`000dLo10000dLo0`0014Lo0`0014Lo0`000dLo
10000dLo0`0014Lo0`000dLo10000dLo10000dLo00<007ooOol037oo00<007ooOol0?goo001@Ool0
0`00Oomoo`1IOolb00000glA000000090004@el30004@el40004@elB00000gk_001=e004CM@00`00
CMA=e003CM@00`00CMA=e003CM@00`00EOAEm00A00000glA000000030005DM@00`00DMAAe003DM@0
0`00DMAAe003DM@00`00EOAEm002EO@=0003Acl30004Acl30004Acl30003Acl30004Acl40003Acl3
0004Acl30003Acl30004Acl30004Acl30003Acl30004Acl30004Acl30004Acl30003Acl30004Acl3
0003Acl30004Acl30004Acl30004Acl30003Acl40003Acl30004Acl30003Acl30004Acl30004Acl3
0004Acl30003Acl40003Acl30004Acl30003Acl30004Acl30004Acl30004Acl30003Acl30004Acl3
0004Acl30003Acl30004Acl30004Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004Acl3
0004Acl30003Acl40003Acl30004Acl30004Acl30003Acl30004Acl30004Acl30003Acl40003Acl3
0004Acl30004Acl30003Acl30004Acl30004Acl30003Acl40003Acl30004Acl30004Acl00`00Oomo
o`0<Ool00`00Oomoo`0nOol0051oo`03001oogoo05UoobL00003Oa40000000/00003Oa40000000L0
00A3G`@000=3G`@000A3Ga400003O^l004gD00A=e003001=e4gD00==e003001=e4gD00==e003001E
m5Gd01L000EAe003001Ae57D00=Ae003001Ae57D00=Ae003001Em5Gd009Em0h000=7?`<000A7?`@0
00=7?`<000A7?`<000=7?`<000A7?`@000=7?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<0
00A7?`<000A7?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<000A7?`<000=7?`<0
00A7?`<000=7?`@000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<0
00A7?`<000A7?`<000=7?`<000A7?`<000=7?`@000=7?`<000A7?`<000A7?`<000=7?`@000=7?`<0
00A7?`<000=7?`@000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<000=7?`@000=7?`<000A7?`<0
00A7?`<000=7?`@000=7?`<000A7?`<000=7?`@000=7?`<000A7?`<000A7?`<000=7?`@000=7?`<0
00A7?`<000=7?`@000=7?`03001oogoo00eoo`03001oogoo03eoo`00D7oo00<007ooOol0F7oo=`00
00=o4@0000001`001D=O0`0014=O100014=O3`0000=nk`00CM@014gD00<004gDCM@00dgD00<004gD
CM@00dgD00<005GdEO@01P0000=o<P0000003P001E7D00<0057DDM@00e7D00<0057DDM@00e7D00<0
05GdEO@00UGd3`0014Lo0`000dLo0`0014Lo10000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`00
14Lo10000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`0014Lo0`000dLo0`00
14Lo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo10000dLo0`0014Lo0`000dLo0`0014Lo0`00
14Lo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`00
14Lo0`0014Lo0`000dLo0`0014Lo0`000dLo10000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`00
0dLo10000dLo0`0014Lo0`0014Lo0`000dLo10000dLo0`0014Lo0`000dLo10000dLo0`0014Lo0`00
0dLo10000dLo0`0014Lo0`000dLo10000dLo0`0014Lo0`0014Lo00<007ooOol037oo00<007ooOol0
?Goo001@Ool00`00Oomoo`1HOol017lA000007lA200000=o4@000000200000=o4@0000007P0000=o
4@000000200014=O10000d=O5P0000=nk`00CM@014gD00<004gDCM@00dgD00<004gDCM@00dgD00<0
05GdEO@05`001E7D00<0057DDM@00e7D00<0057DDM@00e7D00<005GdEO@00UGd300000=7?`000000
0P000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo10000dLo0`0014Lo0`000dLo0`0014Lo
0`000dLo0`0014Lo10000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`0014Lo0`000dLo0`0014Lo
0`000dLo0`0014Lo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo
10000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo10000dLo0`0014Lo0`0014Lo0`000dLo
0`0014Lo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo10000dLo0`0014Lo0`000dLo0`0014Lo
0`0014Lo0`000dLo10000dLo0`0014Lo0`000dLo10000dLo0`0014Lo0`000dLo10000dLo0`0014Lo
0`000dLo10000dLo0`0014Lo0`000dLo10000dLo00<007ooOol03Goo00<007ooOol0?7oo001@Ool0
0`00Oomoo`1HOol00glA0000000;00000glA0000000c00000d=O0000000M00000gk_001=e004CM@0
0`00CMA=e003CM@00`00CMA=e003CM@00`00EOAEm00G0005DM@00`00DMAAe003DM@00`00DMAAe003
DM@00`00EOAEm002EO@<0002Acl30004Acl40003Acl30003Acl30004Acl30004Acl30003Acl30004
Acl30004Acl30004Acl30003Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004Acl30004
Acl30003Acl30004Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004Acl30004Acl30003
Acl30004Acl30004Acl30003Acl40003Acl30004Acl30003Acl30004Acl30004Acl30003Acl40003
Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004Acl30004
Acl30003Acl30004Acl30004Acl30003Acl40003Acl30003Acl40003Acl30004Acl30004Acl30003
Acl40003Acl30004Acl30003Acl30004Acl30004Acl30003Acl40003Acl30004Acl00`00Oomoo`0<
Ool00`00Oomoo`0lOol0051oo`03001oogoo05Qoo`03Oa40000004D00003Oa40000001T00003O^l0
04gD00A=e003001=e4gD00==e003001=e4gD00==e003001Em5Gd00X00003Oc80000000X000EAe003
001Ae57D00=Ae003001Ae57D00=Ae004001Em5GdEO@=0004Acl30003Acl30004Acl30003Acl30004
Acl40003Acl30004Acl30003Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004Acl40003
Acl30004Acl30003Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004Acl30003Acl40003
Acl30004Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004Acl30003Acl40003Acl30004
Acl30004Acl30003Acl30004Acl30003Acl40003Acl30004Acl30003Acl40003Acl30004Acl30003
Acl30004Acl30004Acl30003Acl40003Acl30004Acl30003Acl40003Acl30004Acl30002Acl40004
Acl30004Acl30003Acl40003Acl30003Acl40003Acl30004Acl30004Acl30003Acl30004Acl30004
Acl30003Acl00`00Oomoo`0=Ool00`00Oomoo`0kOol0051oo`03001oogoo05Qoo`03Oa40000005D0
0003Oa40000000T00003O^l004gD00A=e003001=e4gD00==e003001=e4gD00==e003001Em00001L0
00EAe003001Ae57D00=Ae003001Ae57D00=Ae004001Em5GdEO@>0004Acl30003Acl30004Acl30004
Acl30003Acl30004Acl30004Acl30003Acl30004Acl30003Acl30004Acl30004Acl30004Acl30003
Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004Acl30004
Acl30003Acl30004Acl30004Acl30003Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004
Acl30004Acl30003Acl40003Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004Acl30003
Acl40003Acl30004Acl30003Acl40003Acl30004Acl30003Acl40003Acl30004Acl30003Acl30002
Acl00`00Acl000020004Acl30003Acl40003Acl30003Acl40003Acl30004Acl30003Acl40003Acl3
0004Acl30003Acl40003Acl30004Acl00`00Oomoo`0<Ool00`00Oomoo`0kOol0051oo`03001oogoo
05Qoo`03Oa40000005H00003Oa40000000P00003O^l004gD00A=e003001=e4gD00==e003001=e4gD
00==e003001Em00001L000EAe003001Ae57D00=Ae003001Ae57D00=Ae004001Em5GdEO@@0003Acl3
0004Acl30003Acl30004Acl30004Acl30003Acl30004Acl30003Acl30004Acl30004Acl30003Acl3
0004Acl30004Acl30003Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004Acl30004Acl3
0003Acl30004Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004Acl30003Acl30004Acl3
0004Acl30003Acl30004Acl30003Acl30004Acl30004Acl30003Acl40003Acl30004Acl30003Acl4
0003Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004Acl30003Acl30004Acl30004Acl3
0003Acl40003Acl3000014Lo0017?dLo0`000dLo10000dLo0`000dLo10000dLo0`0014Lo0`000dLo
10000dLo0`0014Lo0`000dLo10000dLo0`0014Lo0`000dLo0P003Woo00<007ooOol0>Woo001@Ool0
0`00Oomoo`1HOol00glA0000000@00000glA0000000800000glA0000001300000gk_001=e004CM@0
0`00CMA=e003CM@00`00CMA=e003CM@00`00EO@0000G0005DM@00`00DMAAe003DM@00`00DMAAe003
DM@01000EOAEm5Gd300000A7?`00000000A7?`@000=7?`<000=7?`<000A7?`@000=7?`<000=7?`@0
00=7?`<000=7?`<000A7?`@000=7?`<000A7?`<000=7?`<000=7?`<000A7?`@000=7?`<000A7?`<0
00=7?`<000A7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<0
00=7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<0
00A7?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000A7?`<000=7?`<0
00A7?`<000=7?`@000=7?`<000A7?`<000=7?`@000=7?`<000A7?`@00097?`@000=7?`<000=7?`@0
00=7?`<000A7?`<000=7?`@000=7?`<000A7?`<000=7?`<000A7?`<000=7?`@000=7?`<000A7?`03
001oogoo00aoo`03001oogoo03Yoo`00D7oo00<007ooOol0F7oo800000=o4@000000200000=o4@00
0000=P0000=nk`00CM@014gD00<004gDCM@00dgD00<004gDCM@00dgD00<005Gd00005`001E7D00<0
057DDM@00e7D00<0057DDM@00e7D00@005GdEOAEm0`000=7?`<000=7?`<000A7?`<000A7?`<000=7
?`<000A7?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<000=7
?`<000A7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7
?`<000=7?`<000A7?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7
?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7
?`<000=7?`@000=7?`<000A7?`<000=7?`<000A7?`<000=7?`@000=7?`<000A7?`<000=7?`@000=7
?`<000=7?`@000=7?`<000A7?`<000=7?`@000=7?`<000A7?`<000=7?`<000A7?`<000=7?`@000=7
?`<000A7?`<000=7?`8000ioo`03001oogoo03Uoo`00D7oo00<007ooOol0F7oo8@0000=o4@000000
@00000=nk`00CM@014gD00<004gDCM@00dgD00<004gDCM@00dgD00<005Gd00005`001E7D00<0057D
DM@00U7D00<0057DDM@00e7D00<005GdEO@00UGd300014Lo0`0014Lo0`000dLo0`0014Lo0`000dLo
10000dLo0`0014Lo0`000dLo10000dLo0`0014Lo0`000dLo0`000dLo0`0014Lo0`0014Lo0`000dLo
0`0014Lo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`0014Lo
0`000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo
10000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`0014Lo
0`000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`000dLo10000dLo0`0014Lo
0`000dLo0`0014Lo0`000dLo10000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo10000dLo0`0014Lo
0`000dLo10000dLo00<007ooOol037oo00<007ooOol0>Goo001@Ool3001HOom@00000glA0000000A
00000gk_001=e004CM@00`00CMA=e003CM@00`00CMA=e003CM@00`00EO@0000G0004DM@00`00DMAA
e003DM@00`00DMAAe003DM@00`00EOAEm002EO@>0003Acl40003Acl30004Acl30003Acl30003Acl3
0004Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004Acl30003Acl30004Acl30004Acl3
0003Acl40003Acl30003Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004Acl30003Acl3
0004Acl30004Acl30003Acl30004Acl30003Acl30004Acl30003Acl30004Acl30004Acl30003Acl3
0004Acl30004Acl30003Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004Acl30003Acl4
0003Acl30003Acl40003Acl30004Acl30003Acl30004Acl30004Acl30003Acl30004Acl30003Acl3
0004Acl30003Acl40003Acl30004Acl30003Acl30004Acl30003Acl40003Acl30004Acl30003Acl4
0003Acl30003Acl2000>Ool00`00Oomoo`0hOol004moo`8005Yoob@00003Oa40000003d00003O^l0
04gD00A=e003001=e4gD00==e003001=e4gD00==e003001Em00000L00003Oc80000000`000EAe003
001Ae57D00=Ae003001Ae57D00=Ae003001Em5Gd009Em0l000=7?`<000A7?`<000=7?`<000A7?`<0
00A7?`<000=7?`<000A7?`<000A7?`<000=7?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<0
00A7?`<000=7?`<000A7?`<000=7?`@000=7?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<0
00=7?`<000A7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000A7?`<0
00=7?`<000A7?`<000A7?`<000=7?`<000=7?`@000=7?`<000A7?`<000=7?`<000A7?`<000A7?`<0
00=7?`<000A7?`<000=7?`<000A7?`<000=7?`@000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<0
00A7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`@000=7?`<000A7?`<000=7?`<0
00A7?`<000=7?`@000=7?`03001oogoo00aoo`03001oogoo03Qoo`00D7oo00<007ooOol0F7ooI@00
1DgD00<004gDCM@014gD00<004gDCM@00dgD00<005Gd0000200000=o<P0000002`001E7D00<0057D
DM@00e7D00<0057DDM@00e7D00<005GdEO@00UGd2`000TLo10000dLo0`000dLo0`0014Lo0`000dLo
10000dLo0`0014Lo0`000dLo10000dLo0`000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo
10000dLo0`000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo10000dLo0`000dLo0`0014Lo
0`000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo
0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`000dLo
0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo10000dLo
0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo10000dLo0`0014Lo0`000dLo0`0014Lo
0`000dLo0`0014Lo0`000dLo0P003Woo00<007ooOol0=goo001@Ool00`00Oomoo`1GOolX00000glA
0000000i00000gk_001=e004CM@00`00CMA=e004CM@00`00CMA=e003CM@00`00EO@0000F0005DM@0
0`00DMAAe003DM@00`00DMAAe003DM@01000EOAEm5Gd30000dLo0`0014Lo0`000dLo10000dLo0`00
0dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`000dLo10000dLo0`000dLo0`0014Lo0`0014Lo0`00
0dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo0`000dLo0`0014Lo0`00
14Lo0`000dLo0`0014Lo0`0014Lo0`000dLo0`000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`00
0dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`00
14Lo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo0`00
0dLo10000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo10000dLo0`0014Lo0`000dLo0`0014Lo0`00
0dLo0`0014Lo0`000dLo10000dLo00<007ooOol037oo00<007ooOol0=goo001?Ool00`00Oomoo`1H
Ool;00000glA0000001F00000gk_001=e004CM@00`00CMA=e004CM@00`00CMA=e003CM@I0005DM@0
0`00DMAAe003DM@00`00DMAAe003DM@01000EOAEm5Gd3@000dLo10000dLo0`000dLo0`0014Lo0`00
14Lo0`000dLo0`0014Lo0`000dLo10000dLo0`000dLo0`0014Lo0`0014Lo0`000dLo10000dLo0`00
0dLo0`0014Lo0`000dLo10000dLo0`000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`000dLo0`00
14Lo0`000dLo0`0014Lo0`0014Lo0`000dLo0`000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`00
0dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`000dLo0`00
14Lo0`000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`00
0TLo1@000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo1000
0dLo0`000dLo10000dLo0`0014Lo00<007ooOol01goo1P00>7oo001?Ool00`00Oomoo`1HOol017lA
000007lA200000=o4@000000200000=o4@0000007P0000=o4@000000200000=o4@0000007P0000=n
k`00CM@014gD00<004gDCM@014gD00<004gDCM@00dgD4P0000=o4@00000010001E7D00<0057DDM@0
0e7D00<0057DDM@00e7D00@005GdEOAEm0h000=7?`<000A7?`@000=7?`<000=7?`@000=7?`<000A7
?`<000=7?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7
?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7
?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7
?`<000=7?`<000A7?`<000=7?`<000A7?`<000A7?`<000=7?`<000=7?`<000A7?`<000A7?`<000=7
?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000A7?`<00003Acl004Lo
00<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`@000=7?`<000=7
?`@000=7?`<000A7?`<000=7?`X000Eoo`03001oogoo03Ioo`00Cgoo00<007ooOol0F7oo00=o4@00
00002`0000=o4@000000<`0000=o4@0000007@0000=nk`00CM@014gD00<004gDCM@014gD00<004gD
CM@00dgD4`0000=o4@0000000`001E7D00<0057DDM@00e7D00<0057DDM@00e7D00@005GdEOAEm100
00=7?`<000=7?`<000A7?`<000A7?`<000=7?`@000=7?`<000=7?`<000=7?`<000A7?`<000A7?`<0
00=7?`@000=7?`<000=7?`<000A7?`<000=7?`@000=7?`<000=7?`<000A7?`<000A7?`<000=7?`<0
00=7?`<000A7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<0
00A7?`<000=7?`<000A7?`<000A7?`<000=7?`<000=7?`<000A7?`<000A7?`<000=7?`<000A7?`<0
00=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`@000=7?`<000=7?`<000A7?`<0
00A7?`<000=7?`<000A7?`<000=7?`<00004Acl004LoAcl30003Acl30004Acl30003Acl30004Acl3
0003Acl40003Acl30004Acl30003Acl30003Acl40003Acl30004Acl30003Acl30004Acl00`00Oomo
o`0;Ool00`00Oomoo`0fOol004moo`03001oogoo05Qoo`03Oa40000000d00003Oa40000002P00003
Oa40000002H00003O^l004gD00A=e003001=e4gD00A=e003001=e4gD00==e1T000EAe003001Ae57D
00=Ae003001Ae57D00=Ae004001Em5GdEO@<000014Lo0000000014Lo0`0014Lo0`000dLo10000dLo
0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo10000dLo0`000dLo0`0014Lo0`000dLo10000dLo
0`000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo0`000dLo0`0014Lo0`0014Lo0`000dLo
0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo
0`000dLo0`000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo0`000dLo0`0014Lo0`0014Lo
0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo
10000TLo10000dLo0`000dLo0`0014Lo0`000dLo10000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo
0`0014Lo0`000dLo0`0000=7?gooOol05Goo00<007ooOol0=Woo001?Ool00`00Oomoo`1HOol00glA
0000000>00000glA0000000c00000glA0000000J00000gk_001=e004CM@00`00CMA=e004CM@00`00
CMA=e003CM@700000glb0000000?0005DM@00`00DMAAe003DM@00`00DMAAe003DM@01000EOAEm5Gd
30000dLo0`000dLo10000dLo0`000dLo0`0014Lo0`0014Lo0`000dLo0`000dLo10000dLo0`000dLo
0`0014Lo0`0014Lo0`000dLo0`000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo
0`000dLo0`000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo
0`000dLo10000dLo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo
0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo10000dLo0`000dLo0`0014Lo
0`000dLo10000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo
0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`007Woo00<007ooOol0=Woo001?Ool0
0`00Oomoo`1HOol00glA0000000@00000glA0000000b00000glA0000000I00000gk_001=e004CM@0
0`00CMA=e004CM@00`00CMA=e003CM@I0005DM@00`00DMAAe003DM@00`00DMAAe003DM@01000EOAE
m5Gd3@000dLo0`000dLo0`0014Lo0`0014Lo0`000dLo0`000dLo10000dLo0`000dLo0`0014Lo0`00
14Lo0`000dLo10000dLo0`000dLo0`000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`000dLo0`00
0dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`000dLo10000dLo0`000dLo0`000dLo0`0014Lo0`00
14Lo0`000dLo0`0014Lo0`000dLo10000dLo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`00
14Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`00
14Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`00
14Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`00:Woo00<007ooOol0=Woo001?Ool00`00Oomoo`1H
Ool00glA0000000K00000glA0000000g00000glA0000000900000gk_001=e004CM@00`00CMA=e004
CM@00`00CMA=e003CM@I0005DM@00`00DMAAe003DM@00`00DMAAe003DM@01000EOAEm5Gd3P000dLo
10000dLo0`000dLo10000dLo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo10000dLo0`000dLo
10000dLo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo10000dLo0`000dLo0`000dLo0`0014Lo
0`0014Lo0`000dLo0`0014Lo0`000dLo10000dLo0`000dLo0`000dLo0`0014Lo0`0014Lo0`000dLo
0`0014Lo0`000dLo0`000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo0`0014Lo0`000dLo
0`000dLo0`0014Lo0`000dLo0`0014Lo0`0014Lo0`000dLo0`000dLo0`0014Lo0`000dLo0`0014Lo
0`000dLo10000dLo0`0014Lo0`000dLo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo10000dLo
0`000dLo0`0014Lo0`00<7oo00<007ooOol0=Woo001?Ool00`00Oomoo`1HOolP00000glA0000000f
00000glA0000000:0005CM@00`00CMA=e004CM@00`00CMA=e003CM@;00000glb0000000;0005DM@0
0`00DMAAe003DM@00`00DMAAe003DM@00`00EOAEm00@0003Acl30004Acl30003Acl30004Acl30004
Acl30003Acl30003Acl40003Acl30003Acl40003Acl30003Acl30004Acl30003Acl30004Acl30003
Acl40003Acl30003Acl40003Acl30003Acl30004Acl30003Acl30004Acl30003Acl30004Acl30003
Acl40003Acl30003Acl30003Acl30004Acl30003Acl30004Acl30004Acl30003Acl30003Acl30004
Acl30003Acl30004Acl30003Acl30004Acl30003Acl30004Acl30003Acl30004Acl30003Acl30004
Acl30003Acl30004Acl30003Acl30004Acl30003Acl30004Acl30003Acl30004Acl30003Acl30003
Acl40003Acl30004Acl30003Acl30004Acl30003Acl30004Acl3000lOol00`00Oomoo`0fOol004mo
o`03001oogoo05Qoob400003Oa40000000L00003Oa40000003P000E=e003001=e4gD00A=e003001=
e4gD00==e1T000EAe003001Ae57D00=Ae003001Ae57D00=Ae003001Em5Gd018000=7?`<000=7?`@0
00=7?`<000=7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000A7?`<000=7?`<0
00=7?`@000=7?`<000=7?`@000=7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<0
00=7?`<000A7?`<000=7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<0
00A7?`<000=7?`@000=7?`<000=7?`@000=7?`<000=7?`@000=7?`<000=7?`<000A7?`<000=7?`<0
00A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000=7?`<000A7?`<000=7?`<000A7?`<0
00=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<00003Acmoogoo04Ioo`03001o
ogoo03Ioo`00Cgoo00<007ooOol0F7ooIP001DgD00<004gDCM@014gD00<004gDCM@00dgD6@001E7D
00<0057DDM@00e7D00<0057DDM@00e7D00<005GdEO@04`000dLo0`000dLo0`0014Lo0`000eHD0`00
14Lo0`000dLo0`0014Lo0`000dLo10000dLo0`000dLo10000dLo0`000dLo0`000dLo10000dLo0`00
0dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`00
0dLo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`00
14Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`000dLo0`0014Lo0`000dLo0`0014Lo0`00
0dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`00
0TLo10000dLo0`0014Lo0`000dLo0`00Cgoo00<007ooOol0=Woo001?Ool00`00Oomoo`1HOolT0000
0glA0000000Y00000glA0000000C0005CM@00`00CMA=e004CM@00`00CMA=e003CM@200000glb0000
000D0005DM@00`00DMAAe003DM@00`00DMAAe003DM@00`00EOAEm00D0003Acl40002DO@00`00DOAA
m003DO@00`00EQAF5003EQ@50003Acl30003Acl40003Acl30003Acl40003Acl30003Acl40003Acl3
0003Acl30003Acl30004Acl30003Acl30004Acl30003Acl30004Acl30003Acl30004Acl30003Acl3
0004Acl30003Acl30004Acl30003Acl30003Acl30004Acl30003Acl30004Acl30003Acl30004Acl3
0003Acl30004Acl30003Acl30004Acl30003Acl30003Acl30004Acl30003Acl30004Acl30003Acl3
0004Acl30003Acl30004Acl30003Acl30004Acl30003Acl30003Acl30004Acl30003Acl30004Acl3
0003Acl30004Acl30003Acl30002Acl00`00Acl000020003Acl3001LOol00`00Oomoo`0eOol004mo
o`03001oogoo05MoofL000E=e003001=e4gD00A=e003001=e4gD00==e0<00003Oc80000001<000EA
e003001Ae57D00=Ae003001Ae57D00=Ae003001Em5Gd01D000=Am003001Am57d009Am003001Am57d
00=Am003001F55HD00=F50H000=7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<0
00=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000=7?`@000=7?`<000=7?`@0
00=7?`<000=7?`<000A7?`<000=7?`<000=7?`@000=7?`<000=7?`@000=7?`<000=7?`@000=7?`<0
00=7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<0
00A7?`<000=7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000A7?`<0
00=7?`<000A7?`<000=7?`<00097?`@0069oo`03001oogoo03Eoo`00CWoo1000Egoo:00000=o4@00
0000?0001DgD00<004gDCM@014gD00<004gDCM@070001E7D00<0057DDM@00e7D00<0057DDM@00e7D
00<005GdEO@04`001E7d00<0057dDO@00U7d00<0057dDO@00e7d00<005HDEQ@00eHD1`000dLo1000
0dLo0`000dLo10000dLo0`000dLo0`0014Lo0`000dLo0`000dLo10000dLo0`000dLo10000dLo0`00
0dLo0`0014Lo0`000dLo0`000dLo10000dLo0`000dLo10000dLo0`000dLo0`0014Lo0`000dLo0`00
0dLo10000dLo0`000dLo10000dLo0`000dLo10000dLo0`000dLo0`000dLo0`0014Lo0`000dLo1000
0dLo0`000dLo10000dLo0`000dLo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo10000dLo0`00
0dLo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo0`0027oo00<007ooOol0
Hgoo00<007ooOol0=Goo001?Ool00`00Oomoo`1GOol017lA000007lA200000=o4@0000009`0000=o
4@000000;P001DgD00@004gDCMA=e0H000=3G`H00003Oc800000010000EAe003001Ae57D00=Ae003
001Ae57D00=Ae003001Em5Gd01<000EAm003001Am57d009Am003001Am57d00=Am003001F55HD00=F
50P000=7?`@000=7?`<000=7?`@000=7?`<000=7?`@000=7?`<000=7?`<000=7?`@000=7?`<000=7
?`@000=7?`<000=7?`@000=7?`<000=7?`<000=7?`@000=7?`<000=7?`@000=7?`<000=7?`<000A7
?`<000=7?`<000=7?`@000=7?`<000=7?`@000=7?`<000=7?`<000A7?`<000=7?`<000=7?`@000=7
?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7
?`<000A7?`<000=7?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<001Aoo`03001oogoo06=o
o`03001oogoo03Eoo`00Cgoo00<007ooOol0Egoo00=o4@0000002`0000=o4@0000009P0000=o4@00
0000=P0014=O0`0014=O5`001E7D00<0057DDM@00e7D00<0057DDM@00e7D00<005GdEO@04`001E7d
00<0057dDO@00U7d00<0057dDO@00e7d00<005HDEQ@00UHD2P0014Lo0`000dLo0`000dLo0`0014Lo
0`000dLo10000dLo0`000dLo0`000dLo0`0014Lo0`000dLo10000dLo0`000dLo10000dLo0`000dLo
0`000dLo10000dLo0`000dLo10000dLo0`000dLo0`0014Lo0`000dLo0`000dLo10000dLo0`000dLo
0`0014Lo0`000dLo0`0014Lo0`000dLo0`000dLo0`0014Lo0`000dLo0`000dLo0`0014Lo0`000dLo
0`0014Lo0`000dLo0`000dLo0`0014Lo0`000dLo0`0014Lo0`000dLo10000dLo0`000dLo0`000dLo
0`0014Lo0`000dLo0`006Woo00<007ooOol0Hgoo00<007ooOol0=Goo001>Ool00`00Oomoo`1HOol0
0glA0000000D00000glA0000000N00000glA0000000_0004@el30004@el30004@elF0005DM@00`00
DMAAe003DM@00`00DMAAe003DM@00`00EO@0000C0005DO@00`00DOAAm002DO@00`00DOAAm003DO@0
0`00EQAF5002EQ@<0003Acl30003Acl40003Acl30003Acl30004Acl30003Acl30003Acl30004Acl3
0003Acl30003Acl30004Acl30003Acl40003Acl30003Acl30003Acl40003Acl30003Acl40003Acl3
0003Acl30004Acl30003Acl30003Acl40003Acl30003Acl30004Acl30003Acl30003Acl30004Acl3
0003Acl30003Acl30004Acl30003Acl30004Acl30003Acl40003Acl30003Acl30003Acl40003Acl3
0003Acl30004Acl30003Acl30004Acl30003Acl30003Acl3000VOol00`00Oomoo`1SOol00`00Oomo
o`0eOol004ioo`03001oogoo05Qoo`03Oa40000004000003Oa40000002D000A3G`<000A3G`<000A3
G`H00003Oc80000000`000EAe003001Ae57D00=Ae003001Ae57D00=Ae003001Em00001<000EAm003
001Am57d009Am003001Am57d00=Am003001F55HD009F50d000=7?`<000=7?`@000=7?`<000=7?`@0
00=7?`<000=7?`<000A7?`<000=7?`<000=7?`<000A7?`<000=7?`<000=7?`@000=7?`<000=7?`@0
00=7?`<000=7?`<000=7?`@000=7?`<000=7?`<000A7?`<000=7?`<000=7?`<000A7?`<000=7?`<0
00=7?`<000A7?`<000=7?`@000=7?`<000=7?`<000=7?`@000=7?`<000=7?`@000=7?`<000=7?`<0
00A7?`<000=7?`<000=7?`<000A7?`<000=7?`<000=7?`<000A7?`<000=7?`@0035oo`03001oogoo
06=oo`03001oogoo03Eoo`00CWoo00<007ooOol0F7oo00=o4@000000>00000=o4@000000;P0014=O
0`0014=O100014=O4`001E7D00<0057DDM@00e7D00<0057DDM@00e7D00<005Gd0000300000=o4@00
000010001E7d00<0057dDO@00U7d00<0057dDO@00e7d00<005HDEQ@00UHD3P000dLo0`000dLo0`00
14Lo0`000dLo10000dLo0`000dLo10000dLo0`000dLo0`000dLo10000dLo0`000dLo0`000dLo0`00
14Lo0`000dLo10000dLo0`000dLo0`000dLo10000dLo0`000dLo0`0014Lo0`000dLo0`000dLo0`00
14Lo0`000dLo0`000dLo0`0014Lo0`000dLo10000dLo0`000dLo0`000dLo10000dLo0`000dLo0`00
14Lo0`000dLo0`000dLo0`0014Lo0`000dLo0`000dLo0`0014Lo0`000dLo0`0014Lo0`00=goo00<0
07ooOol0Hgoo00<007ooOol0=Goo001>Ool00`00Oomoo`1HOol00glA0000000@00000glA0000001H
0004@el30004@el30004@el:00000glA000000050005DM@00`00DMAAe003DM@00`00DMAAe003DM@0
0`00EO@0000C0005DO@00`00DOAAm002DO@00`00DOAAm003DO@00`00EQAF5002EQ@;00000dLo0000
00020003Acl30003Acl30003Acl30003Acl30004Acl30003Acl40003Acl30003Acl30003Acl40003
Acl30003Acl30004Acl30003Acl30003Acl40003Acl30003Acl30003Acl40003Acl30003Acl30004
Acl30003Acl30003Acl30003Acl30004Acl30003Acl40003Acl30003Acl30004Acl30003Acl30003
Acl30004Acl30003Acl30003Acl40003Acl30003Acl30004Acl30003Acl30003Acl30004Acl30013
Ool00`00Oomoo`1SOol00`00Oomoo`0eOol004ioo`03001oogoo05QoodP00003Oa40000002@000A3
G`<000A3G`<000A3G`X00003Oa40000000@000EAe003001Ae57D00=Ae003001Ae57D00=Ae003001E
m00001<000EAm003001Am57d009Am003001Am57d00=Am003001F55HD009F50P00003Oc8000000097
?`@000=7?`<000=7?`<000=7?`@000=7?`<000=7?`<000=7?`@000=7?`<000=7?`@000=7?`<000=7
?`<000=7?`@000=7?`<000=7?`<000=7?`@000=7?`<000=7?`<000=7?`@000=7?`<000=7?`<000A7
?`<000=7?`<000=7?`@000=7?`<000=7?`<000=7?`@000=7?`<000=7?`<000=7?`<000A7?`<000=7
?`<000=7?`<000A7?`<000=7?`<000A7?`<000=7?`<000=7?`<000A7?`<000=7?`<004Uoo`03001o
ogoo06=oo`03001oogoo03Eoo`00CWoo00<007ooOol0F7oo7`0000=o4@000000C`000d=O0`0014=O
100014=O3`001E7D00<0057DDM@00e7D00<0057DDM@00e7D00<005Gd0000400000=o4@0000001E7d
00<0057dDO@00U7d00<0057dDO@00e7d00<005HDEQ@00UHD2`000dLo0`0014Lo0`000dLo0`000dLo
10000dLo0`000dLo10000dLo0`000dLo0`000dLo10000dLo0`000dLo0`000dLo10000dLo0`000dLo
0`000dLo10000dLo0`000dLo0`000dLo10000dLo0`000dLo0`000dLo0`0014Lo0`000dLo10000dLo
0`000dLo0`000dLo0`0014Lo0`000dLo0`000dLo10000dLo0`000dLo0`000dLo10000dLo0`000dLo
0`000dLo0`0014Lo0`000dLo0`00EGoo00<007ooOol0Hgoo00<007ooOol0=Goo001>Ool00`00Oomo
o`1HOolP00000glA0000000800000glA0000000Z00000glA0000000G0004@el30004@el300000d=O
0000000?0005DM@00`00DMAAe003DM@00`00DMAAe003DM@00`00EO@0000C0005DO@00`00DOAAm002
DO@00`00DOAAm003DO@00`00EQAF5002EQ@=0003Acl30003Acl30003Acl40003Acl30003Acl30003
Acl40003Acl30003Acl30003Acl40003Acl30003Acl30003Acl40003Acl30003Acl30003Acl30004
Acl30003Acl40003Acl30003Acl30003Acl30003Acl30004Acl30003Acl40003Acl30003Acl30003
Acl30003Acl30004Acl30003Acl40003Acl30003Acl30003Acl30004Acl30003Acl30003Acl4001P
Ool00`00Oomoo`1SOol00`00Oomoo`0eOol004ioo`03001oogoo05Qoo`D00003Oa40000005400003
Oa40000001L000A3Ga/000EAe003001Ae57D00=Ae003001Ae57D00=Ae003001Em00001<000EAm003
001Am57d009Am003001Am57d00=Am003001F55HD009F50h000=7?`<000=7?`@000=7?`<000=7?`<0
00=7?`<000=7?`@000=7?`<000=7?`<000A7?`<000=7?`<000=7?`<000=7?`@000=7?`<000=7?`<0
00=7?`<000A7?`<000=7?`@000=7?`<000=7?`<000=7?`<000=7?`@000=7?`<000=7?`<000A7?`<0
00=7?`<000=7?`<000=7?`@000=7?`<000=7?`<000A7?`<000=7?`<000=7?`@000=7?`<000=7?`<0
06Ioo`03001oogoo06=oo`03001oogoo03Eoo`00<goo30003goo00<007ooOol0EgooT@0000=nk`00
DM@0157D00<0057DDM@00e7D00<0057DDM@00e7D5P001E7d00<0057dDO@00U7d00<0057dDO@00e7d
00@005HDEQAF50/00097?`<000=7?`<000=7?`@000=7?`<000=7?`<000=7?`<000=7?`@000=7?`<0
00=7?`@000=7?`<000=7?`<000=7?`@000=7?`<000=7?`<000=7?`<000=7?`<000A7?`<000=7?`@0
00=7?`<000=7?`<000=7?`<000=7?`@000=7?`<000=7?`<000=7?`<000A7?`<000=7?`<000=7?`@0
00=7?`<000=7?`<000=7?`@000=7?`<000=7?`<0079oo`03001oogoo06=oo`03001oogoo03Eoo`00
<goo30003goo00<007ooOol0EgooD00000=o4@000000?P0000=nk`00DM@0157D00<0057DDM@00e7D
00<0057DDM@00e7D5P001E7d00<0057dDO@00U7d00<0057dDO@00e7d00@005HDEQAF50/000=7?`<0
00=7?`<000=7?`@000=7?`<000=7?`@000=7?`<000=7?`<000=7?`<000=7?`@000=7?`<000=7?`<0
00=7?`@000=7?`<000=7?`<000=7?`<000=7?`<000A7?`<000=7?`@000=7?`<000=7?`<000=7?`<0
00=7?`@000=7?`<000=7?`<000=7?`@000=7?`<000=7?`<000=7?`<000A7?`<000=7?`<000=7?`@0
07eoo`03001oogoo06=oo`03001oogoo03Eoo`00=7oo0`001Woo0P003goo00<007ooOol0Egoo00Ao
4@00001o4B@00003Oa40000000H00003Oa40000005d00003O^l0057D00AAe003001Ae57D00=Ae003
001Ae57D00=Ae1H000EAm003001Am57d009Am003001Am57d00=Am004001F55HDEQ@<0003Acl30003
Acl40003Acl30003Acl30003Acl40003Acl30003Acl30003Acl30003Acl40003Acl30003Acl30003
Acl40003Acl30003Acl30004Acl30003Acl30003Acl30003Acl40003Acl30003Acl30003Acl40003
Acl30003Acl30003Acl30003Acl40003Acl30003Acl30003Acl40003Acl30003Acl30023Ool00`00
Oomoo`1SOol00`00Oomoo`0eOol003Eoo`<001Ioo`03001oogoo05Moo`03Oa40000000T00003Oa40
000002@00003Oa40000005/00003O^l0057D00AAe003001Ae57D00=Ae003001Ae57D00=Ae1H000EA
m003001Am57d009Am003001Am57d00=Am004001F55HDEQ@=0003Acl40003Acl30003Acl30003Acl3
0003Acl40003Acl30003Acl30003Acl40003Acl30003Acl30003Acl40003Acl30003Acl30003Acl4
0003Acl30003Acl30003Acl30003Acl40003Acl30003Acl30003Acl40003Acl30003Acl30003Acl3
0003Acl40003Acl30003Acl30003Acl3002?Ool00`00Oomoo`1SOol00`00Oomoo`0eOol003Ioo`<0
01Aoo`H005Eoo`03Oa40000000/00003Oa40000002D00003Oa40000005P00003O^l0057D00AAe003
001Ae57D00=Ae003001Ae57D00=Ae1H000EAm003001Am57d009Am003001Am57d00=Am004001F55HD
EQ@?0003Acl30003Acl30003Acl30003Acl40003Acl30003Acl30003Acl40003Acl30003Acl30003
Acl30003Acl40003Acl30003Acl30003Acl40003Acl30003Acl30003Acl30003Acl40003Acl30003
Acl30003Acl40003Acl30003Acl30003Acl30003Acl30004Acl3002JOol00`00Oomoo`1SOol00`00
Oomoo`0eOol003Moo`<001Aoo`03001oogoo05Moo`03Oa40000000d00003Oa40000000@00003Oa40
000001d00003Oa40000003<00003Oa40000001400003Oa40000000d00003O^l0057D00AAe003001A
e57D009Ae003001Ae57D00=Ae003001Em00001@000EAm003001Am57d009Am003001Am57d00=Am004
001F55HDEQ@8000017lb000004Lo10000dLo0`000dLo0`000dLo10000dLo0`000dLo0`000dLo0`00
0dLo10000dLo0`000dLo0`000dLo10000dLo0`000dLo0`000dLo0`000dLo10000dLo0`000dLo0`00
0dLo10000dLo0`000dLo0`000dLo0`000dLo0`000dLo10000dLo0`000dLo0`00YWoo00<007ooOol0
Hgoo00<007ooOol0=Goo000hOol3000COol00`00Oomoo`1GOol00glA0000000>00000glA0000000T
00000glA0000001F00000gk_001Ae003DM@00`00DMAAe003DM@00`00DMAAe003DM@00`00EO@0000D
0005DO@00`00DOAAm002DO@00`00DOAAm003DO@01000EQAF55HD2`000dLo0`000dLo0`000dLo1000
0dLo0`000dLo0`000dLo0`000dLo0`000dLo10000dLo0`000dLo0`000dLo10000dLo0`000dLo0`00
0dLo0`000dLo10000dLo0`000dLo0`000dLo10000TLo10000dLo0`000dLo0`000dLo0`000dLo1000
0dLo0`00Zgoo00<007ooOol0I7oo00<007ooOol0=7oo000iOol3000AOol00`00Oomoo`1HOol00glA
0000000@00000glA0000000]00000glA0000000^00000glA0000000K0005DM@00`00DMAAe003DM@0
0`00DMAAe003DM@00`00EO@0000D0005DO@00`00DOAAm002DO@00`00DOAAm003DO@01000EQAF55HD
30000dLo0`000dLo0`000dLo10000dLo0`000dLo0`000dLo10000dLo0`000TLo10000dLo0`000dLo
0`000dLo10000dLo0`000dLo0`000dLo0`000dLo10000dLo0`000dLo0`000dLo0`000dLo10000dLo
0`000dLo0`000dLo0`00]goo00<007ooOol0I7oo00<007ooOol0=7oo000jOol3000@Ool00`00Oomo
o`1HOol00glA0000002200000glA0000000:0005DM@00`00DMAAe003DM@00`00DMAAe003DM@00`00
EO@0000D0005DO@00`00DOAAm002DO@00`00DOAAm003DO@01000EQAF55HD3@000dLo10000dLo0`00
0TLo10000dLo0`000dLo0`000dLo10000dLo0`000dLo0`000dLo0`000dLo10000TLo10000dLo0`00
0dLo0`000dLo10000dLo0`000dLo0`000dLo0`000dLo0`000dLo10000dLo0`00`Woo00<007ooOol0
I7oo00<007ooOol0=7oo000kOol3000?Ool00`00Oomoo`1HOonB0005DM@00`00DMAAe003DM@00`00
DMAAe003DM@G0005DO@00`00DOAAm002DO@00`00DOAAm003DO@00`00EQAF500;000014Lo00000000
0dLo10000dLo0`000dLo0`000dLo0`000dLo10000TLo10000dLo0`000dLo0`000dLo10000dLo0`00
0TLo10000dLo0`000dLo0`000dLo10000dLo0`000dLo0`000dLo0`000dLo0`000dLo0`00b7oo00<0
07ooOol0I7oo00<007ooOol0=7oo000lOol2000?Ool00`00Oomoo`1HOolO00000glA0000000V0000
0glA000000170005DM@00`00DMAAe003DM@00`00DMAAe003DM@G0005DO@00`00DOAAm002DO@00`00
DOAAm003DO@00`00EQAF500;0002Acl40003Acl30003Acl30003Acl30003Acl30003Acl40003Acl3
0003Acl30003Acl30003Acl40003Acl30003Acl30003Acl30003Acl30003Acl40003Acl30003Acl3
0003Acl3003COol00`00Oomoo`1TOol00`00Oomoo`0dOol003eoo`8000ioo`03001oogoo05Qoob00
0003Oa40000006l000EAe003001Ae57D00=Ae003001Ae57D00=Ae1L000EAm003001Am57d009Am003
001Am57d00=Am003001F55HD00/000=7?`@000=7?`<000=7?`<000=7?`@00097?`@000=7?`<000=7
?`<000=7?`<000=7?`<000=7?`@000=7?`<000=7?`<000=7?`@00097?`<000=7?`@000=7?`<00=io
o`03001oogoo06Aoo`03001oogoo03Aoo`00?Goo0P003Woo00<007ooOol0Egoo;00000=o4@000000
G00000=o4@0000001@001E7D00<0057DDM@00e7D00<0057DDM@00e7D5`001E7d00<0057dDO@00U7d
00<0057dDO@00e7d00<005HDEQ@03@000dLo0`000dLo0`000dLo0`000dLo10000dLo0`000dLo0`00
0dLo0`000dLo10000dLo0`000TLo10000dLo0`000dLo0`000dLo10000TLo1000jGoo00<007ooOol0
I7oo00<007ooOol0=7oo000dOol20007Ool2000>Ool00`00Oomoo`1GOomI00000glA0000000`0000
0glA000000040005DM@00`00DMAAe003DM@00`00DMAAe003DM@?00000glA000000050005DO@00`00
DOAAm002DO@00`00DOAAm003DO@00`00EQAF500>0003Acl30003Acl40003Acl30002Acl40003Acl3
0003Acl30003Acl30003Acl40003Acl30003Acl30003Acl30003Acl30003Acl3003_Ool00`00Oomo
o`1TOol00`00Oomoo`0dOol003Aoo`<000Ioo`8000ioo`03001oogoo05Moo`04Oa400000Oa5F0000
0glA0000000a00000glA000000020005DM@00`00DMAAe003DM@00`00DMAAe003DM@G0005DO@00`00
DOAAm002DO@00`00DOAAm003DO@00`00EQAF500800000glb000000040003Acl40002Acl40003Acl3
0003Acl30003Acl30003Acl30003Acl40002Acl40003Acl30003Acl30003Acl3003kOol00`00Oomo
o`1SOol00`00Oomoo`0dOol003Aoo`@000Aoo`8000moo`03001oogoo05Moo`03Oa40000000P00003
Oa40000001X00003Oa40000002D00003Oa400000040000EAe003001Ae57D00=Ae003001Ae57D00=A
e1L000EAm003001Am57d009Am003001Am57d00=Am003001F55HD010000=7?`@000=7?`<000=7?`<0
00=7?`<000=7?`@00097?`@000=7?`<000=7?`<000=7?`<00?moo`Moo`03001oogoo06=oo`03001o
ogoo03Aoo`00=Goo200047oo00<007ooOol0Egoo00=o4@0000002@0000=o4@0000008P0000=o4@00
0000G`001E7D00<0057DDM@00e7D00<0057DDM@00e7D4`0000Ao4@00000000EAm003001Am57d009A
m003001Am57d00=Am003001F55HD018000=7?`<000=7?`<000=7?`<000=7?`<000=7?`@00097?`@0
00=7?`<00?mooa9oo`03001oogoo06=oo`03001oogoo03Aoo`00=goo1@004Goo00<007ooOol0Egoo
00=o4@0000002`0000=o4@0000008P0000=o4@000000G@001E7D00<0057DDM@00e7D00<0057DDM@0
0e7D5`001E7d00<0057dDO@00U7d00<0057dDO@00e7d00<005HDEQ@04`000dLo0`000dLo0`000dLo
0`000dLo10000TLo10000dLo0`00ogoo5goo00<007ooOol0Hgoo00<007ooOol0=7oo001=Ool00`00
Oomoo`1GOol00glA0000000=00000glA0000000400000glA0000000L00000glA0000001J0005DM@0
0`00DMAAe003DM@00`00DMAAe003DM@E00000gk_001Am004DO@01@00DOAAm57d00001E7d00<005HD
EQ@05@000dLo0`000dLo10000TLo10000dLo0`00ogoo8Woo00<007ooOol0Hgoo00<007ooOol0=7oo
001=Ool3001GOol00glA0000000>00000glA0000000S00000glA0000001I0005DM@00`00DMAAe003
DM@00`00DMAAe003DM@E00000gk_001Am003DO@00`00DOAAm002DO@00`00DOAAm003DO@00`00EQAF
500G0003Acl30002Acl4003oOol]Ool00`00Oomoo`1SOol00`00Oomoo`0dOol004aoo`8005Uoo`03
Oa40000001000003Oa40000002800003Oa40000003800003Oa40000002<000EAe003001Ae57D00=A
e003001Ae57D01T000EAm003001Am57d009Am003001Am57d00=Am003001F55HD01P00?moocQoo`03
001oogoo06=oo`03001oogoo03Aoo`00CGoo00<007ooOol0Egoo00=o4@000000@00000=o4@000000
C@001E7D00<0057DDM@01P0014=O5@001E7d00<0057dDO@00U7d00<0057dDO@00e7d00<005HDEQ@0
5P00ogoo>Woo00<007ooOol0Hgoo00<007ooOol0=7oo001<Ool00`00Oomoo`1HOom400000glA0000
000j00000glA0000000G0004@el30004@elD0005DO@00`00DOAAm002DO@00`00DOAAm003DO@00`00
EQAF500F003oOoljOol00`00Oomoo`1SOol00`00Oomoo`0dOol004aoo`03001oogoo05Qooah00003
Oa40000005000004Oa400000Oa4Q0004@el30004@el30004@elB0005DO@00`00DOAAm002DO@00`00
DOAAm003DO@00`00EQAF500800000glb0000000;003oOoljOol00`00Oomoo`1SOol00`00Oomoo`0d
Ool004aoo`03001oogoo05Qoob000003Oa40000002@00003Oa40000004d000A3G`<000A3G`<000A3
Ga4000EAm003001Am57d009Am003001Am57d00=Am003001F55HD01H00?moocYoo`03001oogoo06Ao
o`03001oogoo03=oo`00C7oo00<007ooOol0EgooB@0000=o4@000000>P0000=o4@0000004@0014=O
0`000d=O0`0014=O40001E7d00<0057dDO@00U7d00<0057dDO@00e7d00<005HDEQ@05P00ogoo>Woo
00<007ooOol0I7oo00<007ooOol0<goo001<Ool00`00Oomoo`1GOol017lA000007lA:00000=o4@00
0000K00014=O0`0014=O0`0014=O3P001E7d00<0057dDO@00U7d00<0057dDO@00e7d00<005HDEQ@0
5P00ogoo=Goo1P00IWoo00<007ooOol0<goo001<Ool00`00Oomoo`1GOol00glA0000002I0004@el3
0004@el30004@el=0005DO@00`00DOAAm002DO@00`00DOAAm003DO@00`00EQ@0000F003oOol[Ool:
0005Ool00`00Oomoo`1TOol00`00Oomoo`0cOol004aoo`03001oogoo05Moo`03Oa40000000T00003
Oa40000001T00003Oa40000005l00003Oa400000014000A3G`<000=3G`<000A3G``000EAm003001A
m57d009Am003001Am57d00=Am003001F500001H00?moob1oo`/0011oo`03001oogoo06=oo`03001o
ogoo03=oo`00C7oo00<007ooOol0Egoo00=o4@0000002`0000=o4@000000N`0000=o4@0000004@00
0d=O60001E7d00<0057dDO@00U7d00<0057dDO@00e7d00<005HD00004@0000=o4@0000000P00ogoo
5Woo2P0077oo00<007ooOol0HWoo00<007ooOol0<goo001<Ool00`00Oomoo`1GOol00glA0000000=
00000glA0000000n00000glA0000000700000glA0000001M0005DO@00`00DOAAm002DO@00`00DOAA
m003DO@00`00EQ@0000F003oOol<Ool:000WOol00`00Oomoo`1QOol00`00Oomoo`0cOol004aoo`03
001oogoo05Moo`03Oa40000000h00003Oa40000000<00003Oa4000000:4000EAm003001Am57d009A
m003001Am57d00=Am003001F500001H00?moo`9oo`X0035oo`03001oogoo065oo`03001oogoo03=o
o`00C7oo00<007ooOol0Egoo00=o4@000000400000=o4@000000W@0000=o4@0000001@001E7d00<0
057dDO@00U7d00<0057dDO@00e7d00<005HD00001`0000=o<P0000002`00mgoo2`00?7oo00<007oo
Ool0H7oo00<007ooOol0<goo001<Ool00`00Oomoo`1GOol00glA0000000e00000glA000000200005
DO@00`00DOAAm002DO@00`00DOAAm003DO@00`00EQ@0000E003]Ool:0018Ool00`00Oomoo`1OOol0
0`00Oomoo`0cOol004aoo`03001oogoo05Mook/000EAm003001Am57d009Am003001Am57d00=Am003
001F500001D00>=oo`X0059oo`03001oogoo05moo`03001oogoo03=oo`00Bgoo1000Egoo>`0000=o
4@000000N@0000Ao4@00000000EAm003001Am57d009Am003001Am57d00=Am003001F500001D00=Uo
o`X005eoo`03001oogoo05ioo`03001oogoo03=oo`00C7oo00<007ooOol0Egoo7P0000=o4@000000
8P0000=o4@0000009`0000=o4@000000=P0000=o4@0000004P001E7d00<0057dDO@00U7d00<0057d
DO@00e7d6000cWoo2`00J7oo00<007ooOol0GGoo00<007ooOol0<goo001;Ool00`00Oomoo`1GOol6
00000glA0000000H00000glA0000002F00000gk_001Am004DO@00`00DOAAm002DO@00`00DOAAm003
DO@H0034Ool:001dOol00`00Oomoo`1LOol00`00Oomoo`0cOol004]oo`03001oogoo05Moo`04Oa40
0000Oa5`00000glA0000001300000gk_001Am004DO@00`00DOAAm002DO@00`00DOAAm003DO@H002j
Ool:001nOol00`00Oomoo`1LOol00`00Oomoo`0cOol004]oo`03001oogoo05Moo`03Oa40000004H0
0003Oa40000002H00004Oa400000Oa4<00000glA0000000e00000gk_001Am004DO@00`00DOAAm002
DO@00`00DOAAm003DO@H002`Ool:0029Ool00`00Oomoo`1KOol00`00Oomoo`0cOol004]oo`03001o
ogoo05Moo`03Oa40000002T00003Oa40000008/00003O^l0057d00AAm003001Am57d009Am003001A
m57d00=Am1P00:Eoo`/009Aoo`03001oogoo05Yoo`03001oogoo03=oo`00Bgoo00<007ooOol0Egoo
00=o4@0000002@0000=o4@0000006@0000=o4@000000S`0000=nk`00DO@0157d00<0057dDO@00U7d
00<0057dDO@00e7d2@0000=o<P0000003000Vgoo2P00Wgoo00<007ooOol0FWoo00<007ooOol0<goo
001;Ool00`00Oomoo`1GOol00glA0000000;00000glA0000001e00000glA0000000a00000gk_001A
m004DO@00`00DOAAm002DO@00`00DOAAm003DO@H002AOol:002ZOol00`00Oomoo`1IOol00`00Oomo
o`0cOol004]oo`03001oogoo05Moo`03Oa40000000d00003Oa40000001h00003Oa40000008P000EA
m003001Am57d009Am003001Am57d00=Am1P008Moo`X00;Eoo`03001oogoo05Uoo`03001oogoo039o
o`00Bgoo00<007ooOol0Egoo00=o4@0000003P0000=o4@0000007`0000=o4@0000006P0000=o4@00
0000J@001E7d00<0057dDO@00U7d00<0057dDO@00e7d6000OGoo2P00`7oo00<007ooOol0F7oo00<0
07ooOol0<Woo001;Ool00`00Oomoo`1GOol00glA0000000@00001GlA00000000Oa40@`0000=o4@00
0000;00000=o4@000000;`001E7d00<0057dDO@00U7d00<0057dDO@00e7d6000LWoo2`00bWoo00<0
07ooOol0F7oo00<007ooOol0<Woo001;Ool00`00Oomoo`1GOol00glA0000002900000glA0000000]
0005DO@00`00DOAAm002DO@00`00DOAAm003DO@H001XOol:003FOol00`00Oomoo`1GOol00`00Oomo
o`0bOol004]oo`03001oogoo05MoocP00003Oa400000084000EAm003001Am57d009Am003001Am57d
00=Am1P005ioo`X00>5oo`03001oogoo05Ioo`03001oogoo039oo`00Bgoo00<007ooOol0Egoo_000
1E7d00<0057dDO@00U7d00<0057dDO@00e7d6000E7oo2P00jgoo00<007ooOol0EWoo00<007ooOol0
<Woo001;Ool00`00Oomoo`1FOolO00000glA0000002K0005DO@00`00DOAAm00?00000glb0000000>
0019Ool;003fOol00`00Oomoo`1EOol00`00Oomoo`0bOol004]oo`<005Ioo`04Oa400000Oa4M0000
0glA0000000P00000glA0000001n0003@el30003@el700000glb0000000=000oOol:003oOol3Ool0
0`00Oomoo`1DOol00`00Oomoo`0bOol004Yoo`8005Qoo`03Oa4000000;`000A3G`<000=3G`<000A3
GaD003Eoo`X00?moo`ioo`03001oogoo05=oo`03001oogoo039oo`00BWoo00<007ooOol0Egoo00=o
4@000000J`0000=o4@000000D0000d=O10000d=O0`000d=O3`0000=o4@0000000P00:goo2P00ogoo
67oo00<007ooOol0Dgoo00<007ooOol0<Woo001:Ool00`00Oomoo`1GOol00glA0000000900000glA
0000000j00000glA0000001f0003@el30004@el30003@elC000POol;003oOolSOol00`00Oomoo`1B
Ool00`00Oomoo`0bOol004Yoo`03001oogoo05Moo`03Oa40000000/00003Oa40000001L00005Oa40
0000001o4@1700000glA0000000`00000glA0000000>00000glA000000090003@el30004@el30003
@elA000FOol:003oOol_Ool00`00Oomoo`1AOol00`00Oomoo`0bOol004Yoo`03001oogoo05Moo`03
Oa40000007800003Oa40000004d000=3G`@000=3G`<000=3G`l000eoo`X00?moocYoo`03001oogoo
051oo`03001oogoo039oo`00BWoo00<007ooOol0Egoo00=o4@000000O`0000=o4@000000@@000d=O
0`0014=O50000goo2P00ogooA7oo00<007ooOol0D7oo00<007ooOol0<Woo001:Ool00`00Oomoo`1G
Ool00glA0000000^00000glA0000002K00000glA0000000E003oOom?Ool00`00Oomoo`1?Ool00`00
Oomoo`0bOol004Yoo`03001oogoo05Moo`03Oa40000001000005Oa400000001o4@0K00000glA0000
000J00000glA0000000b00000glA0000001L003oOomCOol00`00Oomoo`1>Ool00`00Oomoo`0bOol0
04Yoo`03001oogoo05Moo`03Oa40000008@00003Oa40000005X00?mooe=oo`03001oogoo04ioo`03
001oogoo039oo`00BWoo00<007ooOol0EgooF`0000=o4@000000M@0000=o4@0000003P00ogooE7oo
00<007ooOol0CGoo00<007ooOol0<Woo001:Ool00`00Oomoo`1FOoli00000glA0000002Y003oOomE
Ool00`00Oomoo`1=Ool00`00Oomoo`0aOol004Yoo`03001oogoo05Ioo`04Oa400000Oa4K00000glA
0000001Z00000glA0000001F003oOomFOol00`00Oomoo`1<Ool00`00Oomoo`0aOol004Yoo`03001o
ogoo05Ioo`03Oa40000001h00003Oa40000006T00003Oa40000005D00?mooeIoo`03001oogoo04ao
o`03001oogoo035oo`00BWoo00<007ooOol0EWoo00=o4@000000S00000=o4@000000D`00ogooEgoo
00<007ooOol0Bgoo00<007ooOol0<Goo001:Ool00`00Oomoo`1FOol00glA0000001100000glA0000
001n00000glA0000000M003oOomHOol00`00Oomoo`1:Ool00`00Oomoo`0aOol004Uoo`@005Ioo`03
Oa40000000T00003Oa40000005d00003Oa40000003000003Oa40000002<00003Oa40000001d00?mo
oeQoo`03001oogoo04Yoo`03001oogoo035oo`00BGoo00<007ooOol0Egoo00=o4@0000002`0000=o
4@0000005`0000Eo4@00000007lA04400003Oa40000005@00003Oa40000001d00?mooeUoo`03001o
ogoo04Uoo`03001oogoo035oo`00BGoo00<007ooOol0Egoo00=o4@0000003@0000=o4@000000=P00
00=o4@000000BP0000=o4@0000002@0000=o4@000000800000=o4@0000007@00ogooFWoo00<007oo
Ool0B7oo00<007ooOol0<Goo0019Ool00`00Oomoo`1GOol00glA0000000>00000glA0000002a0000
0glA0000000M003oOomKOol00`00Oomoo`17Ool00`00Oomoo`0aOol004Uoo`03001oogoo05Moo`03
Oa40000001000003Oa40000005`00003Oa4007lA05000003Oa40000001d00?mooe]oo`03001oogoo
04Moo`03001oogoo035oo`00BGoo00<007ooOol0Egoo00=o4@000000500000=o4@0000005`0000=o
4@000000@@0000=o4@000000K@00ogooG7oo00<007ooOol0AWoo00<007ooOol0<Goo0019Ool00`00
Oomoo`1GOol00glA0000000`00000glA0000000J00000glA0000002B003oOomMOol00`00Oomoo`15
Ool00`00Oomoo`0aOol004Uoo`03001oogoo05IoocL00003Oa40000004T00003Oa40000003<00003
Oa40000000h00003Oa40000001T00?mooeioo`03001oogoo04Aoo`03001oogoo035oo`00BGoo00<0
07ooOol0EWoo00Ao4@00001o4N800?mooeioo`03001oogoo04Aoo`03001oogoo035oo`00BGoo00<0
07ooOol0EWoo00=o4@0000000P0000=o4@0000005`0000=o4@0000005`0000=o4@000000800000=o
4@0000009`0000=o4@000000F00000=o4@0000000P00ogooGgoo00<007ooOol0@goo00<007ooOol0
<Goo0019Ool00`00Oomoo`1FOol00glA0000002500000glA0000001K003oOomPOol00`00Oomoo`12
Ool00`00Oomoo`0aOol0039oo`D0019oo`03001oogoo05Ioo`03Oa4000000<`00003Oa40000001@0
0?moof1oo`03001oogoo049oo`03001oogoo035oo`00<7oo2@0047oo00<007ooOol0Dgoo@@0000=o
4@000000S`0000=o4@0000004P00ogooHWoo00<007ooOol0@Goo00<007ooOol0<Goo000_Ool40004
Ool3000?Ool00`00Oomoo`15OolM00000glA0000000e00000glA0000001500000glA000000130000
0glA0000000@003oOomSOol00`00Oomoo`11Ool00`00Oomoo`0`Ool002moo`8000Moo`<000ioo`03
001oogoo03ioo`L000@kG``000@kG`/00003Oa40000001L00003Oa40000006800003Oa40000005D0
0?moofAoo`03001oogoo041oo`03001oogoo031oo`00>Goo0P003Woo00<007oo00000P00;Woo6@00
0S]O100013]O100013]O2`0000=o4@0000006@0000=o4@000000H00000=o4@000000D`00ogooI7oo
00<007ooOol0@7oo00<007ooOol0<7oo000iOol2000=Ool3000[Ool60004>el=0003>el50004>el3
0005>el40003>el;00000glA0000000e00000glA0000000P00000glA0000001f003oOomUOol00`00
Oomoo`0oOol00`00Oomoo`0`Ool003Uoo`8000eoo`03001oogoo01eooaP0008kG`D000<kG`D000<k
G`D000@kG`<000@kG`D000<kG`/00003Oa40000005P00003Oa40000007@00?moofIoo`03001oogoo
03ioo`03001oogoo031oo`00>7oo0`003Goo00<007ooOol06Goo100013]O300013]O100013]O1@00
0c]O1@000c]O100013]O100013]O100013]O3@0000=o4@0000005`0000=o4@000000J`0000=o4@00
00008`0000=o4@0000007@00ogooIWoo00<007ooOol0?Woo00<007ooOol0<7oo000gOol3000>Ool0
0`00Oomoo`0GOol:0002>el30005>el40004>el40004>el40003>el50004>el30005>el40004>el4
0004>elW00000glA0000002?00000glA0000000M003oOomWOol00`00Oomoo`0mOol00`00Oomoo`0`
Ool003Aoo`D000moo`03001oogoo00aoo`/000Eoo`D000@kG`<000DkG`@000@kG`@000<kG`D000<k
G`D000@kG`<000DkG`@000@kG`@000@kGd800003Oa40000002400003Oa40000002/00003Oa400000
02000003Oa40000001d00?moofQoo`03001oogoo03aoo`03001oogoo031oo`00=7oo100047oo00<0
07ooOol00Woo2P004Woo1@0013]O0`001C]O0`0013]O1@000c]O1@000c]O1@000c]O1@0013]O0`00
1C]O100013]OI@0000=o4@000000C@0000=o4@0000007@00ogooJGoo00<007ooOol0>goo00<007oo
Ool0<7oo000gOol2000?Ool5000OOol30005>el30004>el40004>el50003>el50003>el50003>el5
0003>el50004>el30004>el=00000glA0000000G00000glA0000002:00000glA0000000M003oOomY
Ool00`00Oomoo`0kOol00`00Oomoo`0`Ool003Qoo`80011oo`80029oo`<000@kG`@000@kG`@000@k
G`D000<kG`D000<kG`D000<kG`D000<kG`@000@kG`@000@kG`d00003Oa4000000:800003Oa400000
01d00?moofYoo`03001oogoo03Yoo`03001oogoo031oo`00>7oo0P004Woo0P008Goo100013]O1000
13]O100013]O100013]O1@000c]O1@000c]O100013]O0`001C]O100013]O3@0000=o4@000000=P00
00=o4@000000900000=o4@000000;`0000=o4@0000003P0000=o4@0000007@00ogooJgoo00<007oo
Ool0>Goo00<007ooOol0<7oo000`Ool20006Ool2000DOol20004Ool00`00Oomoo`0JOol40004>el4
0004>el40004>el40004>el40004>el40003>el50004>el30005>el30005>en^00000glA0000000M
003oOom[Ool00`00Oomoo`0iOol00`00Oomoo`0`Ool0031oo`<000Aoo`<001Ioo`80009oo`03001o
ogoo01aoo`@000@kG`@000@kG`@000@kG`@000@kG`@000@kG`@000<kG`D000<kG`D000<kG`D000<k
Gfd00003Oa40000005d00?moofaoo`03001oogoo03Qoo`03001oogoo031oo`00<Goo20006Goo0`00
87oo100013]O100013]O100013]O100013]O10000c]O1@000c]O1@000c]O1@000c]O1@000c]O3@00
00=o4@0000006@0000=o4@000000@@0000=o4@000000;P0000=o4@000000:P00ogooKGoo00<007oo
Ool0=goo00<007ooOol0<7oo000bOol5000MOol2000QOol30005>el30005>el40004>el40003>el5
0003>el50003>el50003>el50003>el50003>en]00000glA0000000I003oOom^Ool00`00Oomoo`0f
Ool00`00Oomoo`0`Ool005Ioo`80025oo`<000DkG`<000DkG`<000DkG`<000@kG`@000@kG`@000@k
G`@000@kG`@000@kG`@000@kG`d00003Oa40000005`00003Oa40000005P00?moofioo`03001oogoo
03Ioo`03001oogoo031oo`00F7oo0P008Goo0`001C]O0`001C]O0`0013]O100013]O100013]O1000
13]O100013]O100013]O100013]O:00000=o4@000000@@0000=o4@000000EP00ogooKgoo00<007oo
Ool0=Goo00<007ooOol0<7oo001JOol2000QOol30005>el30005>el30004>el40004>el40004>el4
0004>el30005>el30005>el30005>eo3003oOom`Ool00`00Oomoo`0dOol00`00Oomoo`0`Ool005ao
o`8000=oo`03001oogoo01]oo`<000DkG`<000@kG`@000@kG`<000DkG`<000DkG`<000DkG`<000Dk
G`<000@kG`D000<kG`d00003Oa40000009`00003Oa40000000h00003Oa40000000800?moog5oo`03
001oogoo03Aoo`03001oogoo02moo`00GWoo0P0000=oo`00Ool07Woo0`0013]O1@000c]O100013]O
0`001C]O0`001C]O0`0013]O1@000c]O1@000c]O1@000c]O3@0000=o4@000000>00000=o4@000000
M@00ogooLGoo00<007ooOol0=7oo00<007ooOol0;goo001POol2000POol50003>el40004>el30005
>el30004>el50003>el50003>el50003>el50003>el40004>enn003oOombOol00`00Oomoo`0cOol0
0`00Oomoo`0_Ool0065oo`<0021oo`D000<kG`@000@kG`<000@kG`D000<kG`D000<kG`D000<kG`@0
00@kG`@000@kG`@000<kGbL00003Oa40000008400003Oa40000000h00?moogAoo`03001oogoo039o
o`03001oogoo02moo`00I7oo0P002Goo00<007ooOol057oo1@000c]O10000c]O1@000c]O1@000c]O
100013]O100013]O100013]O100013]O0`001C]O300000=o4@000000>P0000=o4@0000009`0000=o
4@000000@`00ogooM7oo00<007ooOol0<Woo00<007ooOol0;goo001VOol20007Ool00`00Oomoo`0F
Ool40004>el40004>el40003>el40004>el40004>el40004>el30005>el30004>el50003>enH0000
0glA0000000M003oOomeOol00`00Oomoo`0aOol00`00Oomoo`0_Ool006Qoo`8000Eoo`03001oogoo
01Qoo`@000@kG`@000@kG`<000@kG`@000@kG`@000@kG`<000DkG`<000@kG`D000<kG`D000<kGg<0
0003Oa40000002000003Oa40000001d00?moogIoo`03001oogoo031oo`03001oogoo02moo`00JWoo
0P000Woo00<007ooOol06goo100013]O0`001C]O0`0013]O0`001C]O0`001C]O0`0013]O1@000c]O
100013]O100013]O300000=o4@0000006`0000=o4@000000I`0000=o4@0000007@00ogooMgoo00<0
07ooOol0;goo00<007ooOol0;goo001/Ool3000OOol30005>el30005>el30004>el30005>el30004
>el50003>el40004>el40004>el30005>enB00000glA0000000M003oOomgOol00`00Oomoo`0_Ool0
0`00Oomoo`0_Ool006ioo`80021oo`<000DkG`<000@kG`D000<kG`@000<kG`D000<kG`@000@kG`@0
00@kG`<000DkG`<000@kGdh00003Oa40000004000003Oa40000001d00?moogQoo`03001oogoo02io
o`03001oogoo02moo`00L7oo0P0087oo0`0013]O1@000c]O100013]O10000c]O100013]O100013]O
0`001C]O0`0013]O1@000c]O3@0000=o4@000000O`0000=o4@0000007@00ogooNGoo00<007ooOol0
;Goo00<007ooOol0;goo001bOol00`00Oomoo`0NOol50003>el40004>el40004>el30005>el30004
>el30005>el30004>el40004>el40004>em=00000glA0000000/00000glA0000000>00000glA0000
000M003oOomiOol00`00Oomoo`0]Ool00`00Oomoo`0_Ool007=oo`80021oo`@000@kG`@000@kG`<0
00DkG`<000@kG`D000<kG`@000<kG`@000@kG`@000@kG`<000DkG``00003Oa40000003h00003Oa40
000003/00003Oa40000001d00?moogYoo`03001oogoo02aoo`03001oogoo02moo`00MGoo0P0017oo
00<007ooOol06Goo100013]O0`001C]O0`0013]O1@000c]O100013]O0`001C]O0`0013]O0`001C]O
0`0013]O3@0000=o4@000000NP0000=o4@0000007@00ogooNgoo00<007ooOol0:goo00<007ooOol0
;goo001gOol20002Ool00`00Oomoo`0KOol40004>el30005>el30004>el40004>el40004>el30004
>el40004>el30004>el40004>em=00000glA0000000[00000glA0000000600001GlA00000000Oa40
7`00ogooO7oo00<007ooOol0:Woo00<007ooOol0;goo001iOol3000OOol40004>el30004>el40004
>el40004>el30004>el50003>el40004>el30004>el40004>el/00000glA0000000N00000glA0000
001F003oOomlOol00`00Oomoo`0ZOol00`00Oomoo`0_Ool007]oo`80021oo`@000@kG`@000<kG`@0
00@kG`<000DkG`<000@kG`@000@kG`<000DkG`<000@kG`@000<kGbd00003Oa40000001h00003Oa40
000005@00?moogeoo`03001oogoo02Uoo`03001oogoo02moo`00OGoo0P0087oo100013]O0`0013]O
100013]O0`0013]O100013]O0`001C]O0`0013]O100013]O100013]O300000=o4@000000M`0000=o
4@0000006@00ogooOWoo00<007ooOol0:7oo00<007ooOol0;goo001oOol2000POol30005>el30004
>el40004>el30005>el30004>el30004>el40004>el40004>el30004>enQ003oOomoOol00`00Oomo
o`0XOol00`00Oomoo`0^Ool0085oo`8000Eoo`03001oogoo01Qoo`<000@kG`@000@kG`@000@kG`<0
00@kG`@000@kG`@000<kG`@000@kG`<000@kG`@000@kGb/00003Oa40000007400?moogmoo`03001o
ogoo02Qoo`03001oogoo02ioo`00Pgoo0P000goo00<007ooOol06Woo0`0013]O100013]O0`0013]O
1@000c]O100013]O0`0013]O10000c]O1@000c]O100013]O;00000=o4@0000007P0000=o4@000000
C@00ogooP7oo00<007ooOol09goo00<007ooOol0;Woo0025Ool200000goo001oo`0MOol30005>el3
0004>el30004>el40004>el30004>el50003>el40004>el30004>el40003>en600000glA0000000C
003oOon1Ool00`00Oomoo`0VOol00`00Oomoo`0^Ool008Moo`80021oo`<000@kG`@000@kG`<000@k
G`<000DkG`<000@kG`@000@kG`<000@kG`@000@kG`@000@kG`h00003Oa40000004400003Oa400000
04@00?mooh5oo`03001oogoo02Ioo`03001oogoo02ioo`00RGoo0P0087oo0`0013]O100013]O0`00
13]O100013]O0`0013]O0`0013]O1@000c]O100013]O0`0013]OT`0000=o4@0000000P00ogooPWoo
00<007ooOol09Goo00<007ooOol0;Woo002;Ool2000OOol40004>el30004>el40004>el30005>el3
0004>el40004>el30004>el30004>el40004>eme00000glA0000000<00000glA0000000?003oOon3
Ool00`00Oomoo`0TOol00`00Oomoo`0^Ool008eoo`8000Eoo`03001oogoo01Qoo`<000@kG`@000<k
G`@000@kG`<000@kG`@000@kG`<000@kG`@000@kG`<000DkG`<000@kGg<00003Oa40000001`00003
Oa4007oo0?mooh=oo`03001oogoo02=oo`03001oogoo02ioo`00Sgoo0P000goo00<007ooOol06Goo
100013]O0`0013]O10000c]O100013]O0`001C]O0`0013]O100013]O0`0013]O100013]O3P0000=o
4@0000007@0000=o4@000000@00000=o4@0000007@00ogooQGoo00<007ooOol08goo00<007ooOol0
;Woo001IOol7000:Ool4000>Ool4000AOol200000goo001oo`0LOol40004>el30004>el40004>el3
0004>el40003>el40004>el30004>el40004>el30004>emB00000glA0000000K00000glA0000000M
003oOon6Ool00`00Oomoo`0ROol00`00Oomoo`0^Ool005Uoo`L000Qoo`P000Yoo`P0015oo`8001mo
o`@000<kG`@000@kG`<000@kG`@000@kG`<000@kG`@000@kG`<000@kG`@000<kG`@000@kGbh00003
Oa40000003d00003Oa40000001d00?moohMoo`03001oogoo025oo`03001oogoo02ioo`00G7oo0P00
2Woo0P0017oo0P002Woo0P0017oo0P004goo0P007goo100013]O0`0013]O10000c]O100013]O0`00
13]O100013]O0`0013]O100013]O0`0013]O;P0000=o4@000000>`0000=o4@0000007@00ogooQgoo
00<007ooOol08Goo00<007ooOol0;Woo001LOol20009Ool20006Ool20008Ool20006Ool2000DOol2
000OOol30004>el40004>el30004>el40004>el30004>el30004>el40004>el30004>el40004>emZ
00000glA0000000M003oOon8Ool00`00Oomoo`0POol00`00Oomoo`0^Ool005aoo`8000Uoo`8000Io
o`8000Qoo`8000Ioo`8001Ioo`8000Eoo`03001oogoo01Moo`<000@kG`<000DkG`<000@kG`<000Dk
G`<000@kG`<000@kG`@000<kG`@000@kG`<000@kG`l00003Oa40000001`00003Oa40000003P00003
Oa40000001d00?moohUoo`03001oogoo01moo`03001oogoo02ioo`00E7oo30001Woo0P0027oo0P00
1Woo0P0027oo0P005goo0P000goo00<007ooOol06Goo0`0013]O100013]O0`0013]O0`0013]O1000
13]O0`0013]O0`001C]O0`0013]O0`0013]O3`0000=o4@000000700000=o4@000000=P0000=o4@00
00007@00ogooRWoo00<007ooOol07Woo00<007ooOol0;Woo001DOol<0006Ool20008Ool20006Ool2
0008Ool2000IOol200000goo001oo`0LOol30004>el30005>el30004>el30004>el40003>el40004
>el30004>el40004>el30004>el^00000glA0000000W00000glA0000000:00000glA0000000M003o
Oon:Ool00`00Oomoo`0NOol00`00Oomoo`0^Ool005Aoo`8000Ioo`800003Ool007oo00Eoo`8000Qo
o`8000Ioo`8000Qoo`8001]oo`8001moo`<000@kG`<000@kG`@000@kG`<000@kG`<000@kG`@000@k
G`<000@kG`@000<kG`@000@kGf<00003Oa40000001d00?mooh]oo`03001oogoo01eoo`03001oogoo
02ioo`00EGoo0P001Goo0P0027oo0P0027oo0P001Woo0P0027oo0P007Goo0P002Goo00<007ooOol0
4goo0`0013]O0`0013]O100013]O0`0013]O0`0013]O0`001C]O0`0013]O0`0013]O100013]O3P00
00=o4@000000C00000Eo4@00000007lA01l00?moohaoo`03001oogoo01aoo`03001oogoo02ioo`00
EGoo0`0017oo0P0027oo0P0027oo0P001Woo0P0027oo0P007goo0P001goo00<007ooOol057oo1000
13]O0`0013]O0`0013]O100013]O0`0013]O100013]O0`0013]O0`0013]O0`0013]O3`0000=o4@00
0000KP00ogooS7oo00<007ooOol077oo00<007ooOol0;Woo001FOol20004Ool20008Ool20008Ool2
0006Ool20008Ool2000QOol20005Ool00`00Oomoo`0GOol30004>el30004>el40003>el30005>el3
0004>el30004>el40004>el30004>el30004>el^00000glA0000001=003oOon=Ool00`00Oomoo`0L
Ool00`00Oomoo`0]Ool005Moo`8000=oo`8000Qoo`8000Qoo`8000Ioo`8000Qoo`8002=oo`8000=o
o`03001oogoo01Qoo`<000DkG`<000@kG`<000@kG`@000@kG`<000@kG`<000@kG`<000@kG`@000@k
G`<000@kGf000003Oa40000001T00?moohioo`03001oogoo01]oo`03001oogoo02eoo`00Egoo0`00
0Woo0P0027oo0P0027oo0P001Woo0P0027oo0P009Goo0P0000=oo`00Ool06goo100013]O0`0013]O
0`0013]O0`0013]O100013]O0`0013]O0`0013]O100013]O0`0013]ONP00ogooSgoo00<007ooOol0
6Woo00<007ooOol0;Goo001HOol20002Ool20009Ool20006Ool20008Ool20006Ool2000XOol2000N
Ool30004>el40004>el30004>el30004>el40003>el40004>el30004>el30004>el40004>ela0000
0glA00000014003oOon?Ool00`00Oomoo`0JOol00`00Oomoo`0]Ool005Uoo`800003Ool0000000Uo
o`8000Ioo`8000Qoo`8000Ioo`8002Yoo`8001ioo`@000<kG`<000@kG`@000@kG`<000@kG`<000@k
G`@000@kG`<000@kG`<000@kG`<000@kGgL00?mooi1oo`03001oogoo01Uoo`03001oogoo02eoo`00
FWoo10002Woo0P0017oo0P002Woo0P0017oo0P00;Goo0P007Woo0`0013]O0`001C]O0`0013]O0`00
13]O0`0013]O0`0013]O100013]O0`0013]O0`0013]OG`0000=o4@0000004`00ogooTGoo00<007oo
Ool067oo00<007ooOol0;Goo001JOol4000:Ool8000:Ool8000_Ool20004Ool00`00Oomoo`0GOol3
0004>el30004>el30004>el40004>el30004>el30004>el40004>el30003>el40004>el?00000glA
0000001000000glA0000000:00000glA0000000A003oOonBOol00`00Oomoo`0GOol00`00Oomoo`0]
Ool005]oo`<000aoo`@000ioo`@003=oo`80009oo`03001oogoo01Uoo`<000@kG`<000@kG`@000@k
G`<000@kG`<000@kG`<000@kG`<000@kG`<000@kG`@000@kGe000003Oa40000001h00?mooi9oo`03
001oogoo01Moo`03001oogoo02eoo`00]Goo0`007Goo0`0013]O0`0013]O0`0013]O0`0013]O1000
13]O0`0013]O0`0013]O0`0013]O10000c]O3`0000=o4@000000?@0000=o4@0000007P00ogooTgoo
00<007ooOol05Woo00<007ooOol0;Goo002gOol2000NOol30004>el30004>el30004>el40004>el3
0003>el30005>el30004>el30004>el30004>el?00000glA0000000k00000glA0000000I00000glA
00000002003oOonDOol00`00Oomoo`0EOol00`00Oomoo`0]Ool00;Uoo`8001ioo`<000@kG`<000@k
G`<000@kG`<000@kG`<000@kG`@000@kG`<000@kG`<000@kG`<000@kGd/00003Oa40000001h00?mo
oiAoo`03001oogoo01Eoo`03001oogoo02eoo`00^goo0P007Goo0`001C]O0`0013]O0`0013]O0`00
13]O0`0013]O10000c]O0`0013]O100013]O0`0013]O3P0000=o4@000000>00000=o4@0000007000
00=o4@00Ool0ogooU7oo00<007ooOol057oo00<007ooOol0;Goo002mOol20003Ool00`00Oomoo`0G
Ool40004>el30004>el30004>el30004>el30004>el30004>el30004>el40004>el30004>el>0000
0glA0000000f00000glA0000000M003oOonGOol00`00Oomoo`0COol00`00Oomoo`0]Ool00;moo`80
0003Ool007oo01]oo`<000<kG`<000@kG`@000@kG`<000@kG`<000@kG`<000@kG`<000@kG`@000<k
G`<000@kG`l00003Oa40000003@00003Oa40000001d00?mooiQoo`03001oogoo019oo`03001oogoo
02eoo`00`Goo0P007Goo0`0013]O0`001C]O0`0013]O0`0013]O0`0013]O0`0013]O0`0013]O0`00
13]O0`0013]OA00000=o4@0000007@00ogooV7oo00<007ooOol04Woo00<007ooOol0;Goo0032Ool3
000MOol30004>el40004>el30003>el30004>el40004>el30004>el30004>el30004>el30004>ele
00000glA0000000:00000glA0000000M003oOonIOol00`00Oomoo`0AOol00`00Oomoo`0]Ool00<Eo
o`8001eoo`<000@kG`<000@kG`<000@kG`<000@kG`@000@kG`<000@kG`<000<kG`<000@kG`@000@k
Gd000003Oa40000001d00?mooiYoo`03001oogoo011oo`03001oogoo02eoo`00agoo00<007ooOol0
0goo00<007ooOol05Woo0`0013]O0`0013]O0`0013]O0`0013]O10000c]O0`0013]O0`0013]O0`00
13]O100013]O3P0000=o4@000000;@0000=o4@0000007@00ogooVWoo00<007ooOol047oo00<007oo
Ool0;Goo0038Ool20003Ool00`00Oomoo`0HOol30004>el30004>el30004>el30004>el30004>el3
0004>el30004>el30004>el40004>elh00001GlA00000000Oa407`00ogooVgoo00<007ooOol047oo
00<007ooOol0;7oo003:Ool200000goo001oo`0KOol30004>el30004>el30004>el30004>el30004
>el30004>el30004>el30004>el30004>elk00000glA0000000M003oOonLOol00`00Oomoo`0?Ool0
0`00Oomoo`0/Ool00<aoo`8001ioo`<000@kG`<000@kG`<000@kG`<000@kG`<000@kG`<000@kG`<0
00@kG`<000@kG`<000@kGeT00?mooieoo`03001oogoo00ioo`03001oogoo02aoo`00UGoo1@003Woo
10003Woo100047oo0P007Woo0`0013]O0`0013]O0`0013]O0`000c]O100013]O0`0013]O0`0013]O
0`0013]O0`0013]O400000=o4@000000A000ogooWGoo00<007ooOol03Woo00<007ooOol0;7oo002C
Ool9000:Ool8000:Ool8000@Ool20006Ool00`00Oomoo`0EOol30004>el30003>el30004>el30004
>el40004>el30004>el30004>el30004>el30003>elj00000glA0000000I003oOonNOol00`00Oomo
o`0=Ool00`00Oomoo`0/Ool0099oo`@000Aoo`<000Uoo`8000Aoo`8000Yoo`8000Aoo`80019oo`80
00Aoo`03001oogoo01Ioo`<000@kG`<000@kG`<000@kG`<000@kG`<000@kG`@000<kG`@000<kG`<0
00@kG`<000@kGe@00?mooimoo`03001oogoo00aoo`03001oogoo02aoo`00TWoo0P001goo0`001goo
0P001Woo0P0027oo0P001Woo0P004goo0P000Woo00<007ooOol067oo0`0013]O0`0013]O0`0013]O
0`0013]O0`0013]O0`0013]O0`0013]O0`0013]O0`0013]ODP00ogooX7oo00<007ooOol02goo00<0
07ooOol0;7oo002LOol20007Ool20006Ool20008Ool20006Ool2000EOol3000LOol30004>el30004
>el30004>el30004>el30004>el30004>el30004>el30004>el30004>el_00000glA0000000N003o
OonPOol00`00Oomoo`0;Ool00`00Oomoo`0/Ool009aoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`80
01Ioo`8000Qoo`03001oogoo019oo`<000@kG`<000@kG`<000@kG`<000@kG`<000@kG`<000@kG`<0
00@kG`<000@kG`<000@kGbd00003Oa40000000P00003Oa40000001<00?mooj5oo`03001oogoo00Yo
o`03001oogoo02aoo`00W7oo0P001Woo0P0027oo0P001Woo0P0027oo0P0067oo0P001Woo00<007oo
Ool057oo0`0013]O0`0013]O0`0013]O0`0013]O0`0013]O0`0013]O0`0013]O0`0013]O0`000c]O
;00000=o4@0000002P0000=o4@0000004@00ogooXWoo00<007ooOol02Goo00<007ooOol0;7oo002K
Ool30006Ool20008Ool20006Ool20008Ool2000JOol20004Ool00`00Oomoo`0FOol30004>el30004
>el30004>el30004>el30004>el30004>el30004>el30003>el30004>elZ00000glA0000000N003o
OonROol00`00Oomoo`09Ool00`00Oomoo`0/Ool009Yoo`<000Moo`8000Qoo`8000Ioo`8000Qoo`80
01aoo`80009oo`03001oogoo01Qoo`<000@kG`<000@kG`<000@kG`<000@kG`<000@kG`<000@kG`<0
00<kG`<000@kG`<000@kGbP00003Oa40000001h00?mooj=oo`03001oogoo00Qoo`03001oogoo02ao
o`00Ugoo1@0027oo0P0027oo0P001Woo0P0027oo0P007Woo0`0077oo0`0013]O0`0013]O0`0013]O
0`0013]O0`000c]O0`0013]O0`0013]O0`0013]O0`0013]O9P0000=o4@0000007P00ogooY7oo00<0
07ooOol01goo00<007ooOol0;7oo002GOol40009Ool20008Ool20006Ool20008Ool2000POol2000M
Ool30004>el30004>el30004>el30003>el30004>el30004>el30004>el30004>el30004>elT0000
0glA0000000N003oOonUOol00`00Oomoo`06Ool00`00Oomoo`0/Ool009Yoo`8000Qoo`8000Qoo`80
00Ioo`8000Qoo`80029oo`8001eoo`<000@kG`<000@kG`<000<kG`<000@kG`<000@kG`<000@kG`<0
00@kG`<000<kG`<000@kGb<00003Oa40000001T00003Oa40000000800?moojEoo`03001oogoo00Io
o`03001oogoo02aoo`00Vgoo0P001goo0P0027oo0P001Woo0P0027oo0P0097oo0P0017oo00<007oo
Ool05Woo0`0013]O0`000c]O0`0013]O0`0013]O0`0013]O0`0013]O0`000c]O0`0013]O0`0013]O
8@0000=o4@0000007P00ogooYWoo00<007ooOol01Goo00<007ooOol0;7oo002KOol20008Ool20006
Ool20008Ool20006Ool2000WOol20002Ool00`00Oomoo`0HOol30004>el30003>el30004>el30004
>el30004>el30003>el30004>el30004>el30004>elB00000glA0000000:00000glA0000000L0000
0glA001oo`3oOonVOol00`00Oomoo`04Ool00`00Oomoo`0/Ool009=oo`8000Ioo`8000Qoo`8000Io
o`8000Qoo`8000Ioo`8002Uoo`<001aoo`<000<kG`<000@kG`<000@kG`<000@kG`<000<kG`<000@k
G`<000@kG`@000<kG`<000@kGad00003Oa40000001d00?moojQoo`03001oogoo00Aoo`03001oogoo
02aoo`00Tgoo0`0017oo0`002Goo0P0017oo0P002Woo0P0017oo0P00;7oo0P007Goo0`000c]O0`00
13]O0`0013]O0`000c]O0`0013]O0`0013]O10000c]O0`0013]O0`0013]O6`0000=o4@0000007@00
ogooZGoo00<007ooOol00goo00<007ooOol0;7oo002DOol8000:Ool8000:Ool8000^Ool2000LOol3
0004>el30004>el30003>el30004>el30004>el40003>el30004>el30004>el30003>elJ00000glA
0000000M003oOonZOol00`00Oomoo`03Ool00`00Oomoo`0[Ool009Eoo`D000ioo`@000ioo`@0039o
o`8000Aoo`03001oogoo01Eoo`<000@kG`@000<kG`<000<kG`<000@kG`@000<kG`<000@kG`<000@k
G`<000<kG`<000@kGaP00003Oa40000001d00?mooj]oo`03001oogoo009oo`03001oogoo02]oo`00
lWoo0P000Woo00<007ooOol05goo0`0013]O10000c]O0`000c]O0`0013]O0`0013]O0`0013]O0`00
0c]O0`0013]O10000c]O4P0000Eo4@00000007lA01l00?mooj]oo`03001oogoo009oo`03001oogoo
02]oo`00m7oo0`006goo10000c]O0`0013]O0`000c]O0`0013]O0`0013]O0`000c]O0`0013]O1000
0c]O0`0013]O500000=o4@0000007@00ogoo[7oo00D007ooOomoo`0002eoo`00mWoo0P0077oo1000
0c]O0`0013]O0`000c]O0`0013]O0`000c]O0`0013]O10000c]O0`0013]O0`000c]O<`00ogoo[Goo
00@007ooOol002eoo`00n7oo0P0077oo0`0013]O0`000c]O0`0013]O10000c]O0`000c]O0`0013]O
0`0013]O0`000c]O0`0013]O<@00ogoo[Goo00@007ooOol002eoo`00nWoo0P0017oo00<007ooOol0
5Goo0`0013]O0`000c]O0`0013]O0`0013]O0`000c]O0`0013]O0`000c]O0`0013]O10000c]O4`00
00=o4@0000006@00ogoo[Woo00<007oo0000;Goo003lOol20002Ool00`00Oomoo`0GOol30003>el3
0004>el40003>el30004>el30003>el30004>el30003>el30004>el30004>el<00000glA0000000N
003oOon_Ool2000]Ool00?ioo`<001Yoo`<000@kG`@000<kG`<000@kG`<000<kG`<000@kG`<000@k
G`<000<kG`<000@kG`<000<kG`/00003Oa40000001h00?moojUoo`P002eoo`00ogoo0Goo0P0077oo
0`000c]O0`0013]O0`000c]O0`0013]O10000c]O0`000c]O0`0013]O0`000c]O0`0013]O2@0000=o
4@0000007P00ogooVgoo3P00=Goo003oOol3Ool20006Ool00`00Oomoo`0COol30003>el30004>el3
0003>el40003>el30004>el30003>el40003>el30004>el30003>el700000glA0000000800000glA
0000000C003oOon=Ool>0013Ool00?moo`Eoo`8000Aoo`03001oogoo01Aoo`<000@kG`@000<kG`<0
00<kG`<000@kG`<000<kG`<000@kG`<000@kG`<000<kG`<000@kG`D00003Oa40000000X00003Oa40
000001400?moogioo`l0055oo`00b7oo30002goo10003Woo10004Goo0P000Woo00<007ooOol05Woo
10000c]O0`0013]O0`000c]O10000c]O0`000c]O10000c]O0`000c]O0`0013]O0`0013]O0`0000=o
4@0000007P00ogooL7oo3P00H7oo0038Ool<0009Ool8000:Ool8000AOol30008Ool00`00Oomoo`0?
Ool40003>el30003>el30004>el30004>el30003>el40003>el30003>el30004>el30003>elS003o
OomROol>001^Ool00<Uoo`<000Ioo`8000Uoo`8000Aoo`8000Yoo`8000Aoo`8001=oo`8000Moo`03
001oogoo015oo`<000@kG`<000<kG`@000<kG`<000<kG`<000@kG`<000@kG`<000<kG`@000<kG`<0
00<kGb400?mooeAoo`h007aoo`00bWoo0`003goo0P001Woo0P0027oo0P001Woo0P0057oo0P001Goo
00<007ooOol04goo10000c]O0`000c]O0`0013]O0`000c]O10000c]O0`000c]O10000c]O0`000c]O
0`0013]O7`00ogooAWoo3P00RWoo003;Ool3000>Ool20006Ool20008Ool20006Ool2000FOol20003
Ool00`00Oomoo`0EOol30004>el30003>el40003>el30003>el40003>el30003>el30004>el30003
>el40003>elM003oOolhOol>002HOol00<aoo`<000aoo`8000Qoo`8000Ioo`8000Qoo`8001Moo`80
0003Ool007oo01Qoo`<000<kG`@000<kG`<000<kG`<000@kG`<000@kG`<000<kG`@000<kG`<000<k
G`<000<kGa`00?moobYoo`h00:Ioo`00cGoo0`002goo0P0027oo0P001Woo0P0027oo0P006Goo0P00
6goo0`000c]O0`0013]O0`000c]O10000c]O0`000c]O10000c]O0`000c]O0`0013]O0`000c]O5@00
00=o4@0000000P00ogoo6goo3`00]7oo003>Ool3000:Ool20008Ool20006Ool20008Ool2000KOol2
000KOol30003>el40003>el30003>el40003>el30003>el30004>el30003>el30004>el30003>elH
003oOol=Ool>0033Ool00<moo`<000Uoo`8000Qoo`8000Ioo`8000Qoo`8001eoo`8000Aoo`03001o
ogoo01Aoo`<000<kG`<000@kG`<000<kG`<000@kG`<000<kG`@000<kG`<000<kG`<000<kG`@000<k
Ga@00003Oa4007oo0?eoo`h00=5oo`00d7oo0`0027oo0P0027oo0P001Woo0P0027oo0P007goo0P00
0Woo00<007ooOol05Woo0`000c]O10000c]O0`000c]O0`000c]O10000c]O0`000c]O10000c]O0`00
0c]O10000c]O4`00lGoo3P00ggoo003AOol20008Ool20008Ool20006Ool20008Ool2000QOol00`00
Ool0000IOol40003>el30003>el40003>el30003>el40003>el30003>el30003>el30004>el30003
>elB003SOol>003]Ool00=9oo`8000Moo`8000Qoo`8000Ioo`8000Qoo`80029oo`8001aoo`<000<k
G`<000@kG`<000<kG`<000<kG`<000@kG`<000<kG`<000<kG`<000@kG`<000<kGa000=Eoo`h00?]o
o`00dWoo0P001goo0P0027oo0P001Woo0P0027oo0P0097oo0P001Woo00<007ooOol04Woo10000c]O
0`000c]O10000c]O0`000c]O10000c]O0`000c]O0`000c]O10000c]O0`000c]O3P00agoo3P00ogoo
2Woo0039Ool20007Ool20008Ool20006Ool20008Ool20006Ool2000WOol20004Ool00`00Oomoo`0D
Ool40003>el30003>el30003>el40003>el30003>el40003>el30003>el40003>el30003>el<002h
Ool?003oOolHOol00<Uoo`<000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8002Uoo`80009oo`03
001oogoo01Ioo`@000<kG`<000<kG`<000<kG`@000<kG`<000<kG`<000<kG`@000<kG`<000<kG`@0
00<kG`X00:Yoo`h00?moobMoo`00bGoo100017oo0P002Woo0P0017oo0P002Woo0P0017oo0P00;7oo
0`006Woo10000c]O0`000c]O0`000c]O10000c]O0`000c]O0`000c]O10000c]O0`000c]O0`000c]O
2@00W7oo3P00ogoo=Goo003:Ool8000;Ool8000:Ool8000^Ool2000KOol30003>el40003>el30003
>el40003>el30003>el30003>el30003>el40003>el30003>el7002>Ool>003oOom3Ool00<aoo`D0
00ioo`@000ioo`@0039oo`8000Eoo`03001oogoo019oo`@000<kG`@000<kG`<000<kG`<000<kG`@0
00<kG`<000<kG`<000<kG`@000<kG`<000<kG`D0081oo`h00?mooe5oo`00ogoo:Woo0P000goo00<0
07ooOol04Woo00<007ooOol00`000c]O10000S]O10000c]O0`000c]O10000c]O0`000c]O0`000c]O
0`000c]O10000c]O0`00LWoo3P00ogooGgoo003oOol/Ool200000goo001oo`0COol00`00Oomoo`02
Ool30003>el40003>el30003>el30003>el30003>el40003>el30003>el30003>el40003>el00`00
Oomoo`1ROol>003oOom]Ool00?moobioo`8001Aoo`03001oogoo00Aoo`<000<kG`<000<kG`@000<k
G`<000<kG`<000<kG`@000<kG`<006Aoo`l00?moog]oo`00ogoo<7oo0P001Goo00<007ooOol02Woo
00<007ooOol01Woo0`000c]O0`000c]O10000c]O0`000c]O0`00HGoo3P00ogooRWoo003oOolbOol2
0003Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool30003>el3001TOol>003oOonHOol00?moocAoo`80
0003Ool007oo00Moo`05001oogooOol0001YOol>003oOonVOol00?]oo`X000]oo`@000ioo`@000mo
o`8000Qoo`05001oogooOol0001KOol>003oOondOol00?]oo`X000Uoo`P000Yoo`P000moo`8000Io
o`05001oogooOol0001=Ool>003oOoo2Ool00?moo`8000eoo`8000Aoo`8000Yoo`8000Aoo`80015o
o`8000Aoo`05001oogooOol0000oOol>003oOoo@Ool00?moo`8000aoo`8000Ioo`8000Qoo`8000Io
o`80019oo`80009oo`05001oogooOol0000`Ool?003oOooNOol00?moo`8000aoo`8000Ioo`8000Qo
o`8000Ioo`8001Aoo`<000=oo`03001oogoo021oo`h00?mooneoo`00ogoo0P002goo0P0027oo0P00
1Woo0P0027oo0P005Goo0P000Woo00<007ooOol04Woo3P00ogoongoo003oOol2000;Ool20008Ool2
0006Ool20008Ool2000GOol30006Ool>003oOoooOol:Ool00?moo`8000]oo`8000Qoo`8000Ioo`80
00Qoo`8001Uoo`L00?mooomooaQoo`00ogoo0P002goo0P0027oo0P001Woo0P0027oo0P00ogooogoo
>7oo003oOol2000;Ool20008Ool20006Ool20008Ool2003oOoooOolhOol00?moo`8000]oo`8000Qo
o`8000Ioo`8000Qoo`800?mooomoocQoo`00ogoo0P002goo0P0027oo0P001Woo0P0027oo0P00ogoo
ogoo>7oo003oOol2000;Ool20008Ool20006Ool20008Ool2003oOoooOolhOol00?moo`8000aoo`80
00Ioo`8000Qoo`8000Ioo`800?mooomoocUoo`00ogoo0P0037oo0P001Woo0P0027oo0P001Woo0P00
ogooogoo>Goo003kOol300000goo0000000=Ool20004Ool2000:Ool20004Ool2003oOoooOoljOol0
0?]oo`H000eoo`P000Yoo`P00?mooomoocYoo`00oWoo0`003goo10003Woo1000ogooogoo?7oo003o
OoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooceo
o`@00?mooomoob9oo`00ogoo>goo2000ogooogoo87oo003oOolkOol20004Ool2003oOoooOolPOol0
0?moocYoo`8000Ioo`800?mooomooamoo`00ogoo>Woo0P001Woo0P00ogooogoo7goo003oOoliOol2
0008Ool2003oOoooOolNOol00?moocUoo`8000Qoo`800?mooomooaioo`00ogoo>Goo0P0027oo0P00
ogooogoo7Woo003oOoliOol20008Ool2003oOoooOolNOol00?moocUoo`8000Qoo`800?mooomooaio
o`00ogoo>Goo0P0027oo0P00ogooogoo7Woo003oOoliOol20008Ool2003oOoooOolNOol00?moocUo
o`8000Qoo`800?mooomooaioo`00ogoo>Woo0P001Woo0P00ogooogoo7goo003oOoljOol20006Ool2
003oOoooOolOOol00?mooc]oo`8000Aoo`800?mooomoob1oo`00ogoo>goo2000ogooogoo87oo003o
OolmOol4003oOoooOolROol00?mooomooomoof=oo`00ogooogooogooHgoo0000\
\>"], "Graphics",
  CellLabel->"From In[1]:=",
  Evaluatable->False,
  PageBreakAbove->True,
  ImageSize->{288, 173.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
The picture shows the location of the conductors and the dielectric \
material.\
\>", "Text"],

Cell["\<\
nz1=nz/2;ns1=ns/2;u1=.;m1=.;
m1=Array[u1,{nz1,ns1}];a1=Array[u1,{nz1,ns1}];
Do[Do[a1[[i,j]]=u1[[i,j]],{j,1,ns1}],{i,1,nz1}]
Do[Do[m1[[i,j]]:=Evaluate[0.25(a1[[i-1,j]]+a1[[i+1,j]]+
a1[[i,j-1]]+a1[[i,j+1]])],{j,2,ns1-1}],{i,2,nz1-1}];
Do[m1[[1,j]]:=0.,{j,1,ns1}];
Do[m1[[nz1,j]]:=0.,{j,1,ns1}];
Do[m1[[i,1]]:=0.,{i,1,nz1}];
Do[m1[[i,ns1]]:=0.,{i,1,nz1}];
(* guess for coordinates:old/2;mb:location of conductors *)
Do[Do[If[mb[[2i,2j]]==1,m1[[i,j]]=m[[2i,2j]]],{i,nz1}],
{j,ns1}]
u1=Table[0.,{i,1,nz1},{j,1,ns1}];
Timing[Do[{u1=m1;If[Mod[i,500]==0,
Print[i,\" residual error:\",Max[Flatten[Abs[u1-m1]]]]]},
{i,1,3000}]]\
\>", "Input",
  CellLabel->"In[30]:=",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}},
  Background->GrayLevel[0.849989]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p = ListInterpolation[Transpose[u1]];\)\), "\n", 
    \(Plot3D[p[x, y], {x, 1, ns1}, {y, 1, nz1}, PlotRange \[Rule] All, 
      PlotPoints \[Rule] 30, ViewPoint \[Rule] {3. , 1. , 1. }]\)}], "Input",
  CellLabel->"In[42]:=",
  CellFrame->True,
  PageBreakAbove->Automatic,
  Background->GrayLevel[0.849989]],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P00022A000`40O003h00OogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomoom=oo`L000Yoo`@007Yoo`00ogooogoodgoo1`0027oo2000N7oo003oOoooOooFOol2000:Ool2
0004Ool2001hOol00?mooomoomIoo`8000Uoo`8000Ioo`8007Moo`00ogooogooeWoo0P002Goo0P00
1Woo0P00Mgoo003oOoooOoo>Ool<0006Ool20008Ool2001fOol00?mooomoolioo``000Ioo`8000Qo
o`8007Ioo`00ogooogoocWoo0P001Woo0P0000=oo`00Ool01Goo0P0027oo0P00MWoo003oOoooOoo?
Ool20005Ool20008Ool20008Ool2001fOol00?mooomoolmoo`<000Aoo`8000Qoo`8000Qoo`8007Io
o`00ogooogood7oo0P0017oo0P0027oo0P0027oo0P00MWoo003oOoooOooAOol20003Ool20008Ool2
0008Ool2001fOol00?mooomoom5oo`<0009oo`8000Qoo`8000Qoo`8007Ioo`00ogooogoodWoo0P00
0Woo0P002Goo0P001Woo0P00Mgoo003oOoooOooCOol200000goo00000009Ool20006Ool2001gOol0
0?mooomoomAoo`@000Yoo`8000Aoo`8007Qoo`00ogooogooe7oo10002Woo2000N7oo003oOoooOooE
Ool3000<Ool4001jOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
8Woo1@003Woo1000ogoo:Woo003oOoooOolPOol9000:Ool8003oOolXOol00?mooomooamoo`@000Ao
o`<000Uoo`8000Aoo`800?moobQoo`00ogooogoo7goo0P001goo0`001goo0P001Woo0P00ogoo9goo
003oOoooOolYOol20007Ool20006Ool2003oOolWOol00?mooomoobUoo`8000Ioo`8000Qoo`800?mo
obIoo`00ogooogoo:Goo0P001Woo0P0027oo0P00ogoo9Woo003oOoooOolXOol30006Ool20008Ool2
003oOolVOol00?mooomoobMoo`<000Moo`8000Qoo`8009eoo`D008=oo`00ogooogoo97oo1@0027oo
0P0027oo0P00UWoo1`0017oo00<007ooOol0PGoo003oOoooOolTOol40009Ool20008Ool2002?Ool7
000;Ool20022Ool00?mooomoobMoo`8000Qoo`8000Qoo`8008Qoo`L0019oo`80089oo`00ogooogoo
:7oo0P001goo0P0027oo0P00PGoo1`006Goo00<007oo0000PGoo003oOoooOolXOol20008Ool20006
Ool2001jOol8000POol00`00Ool00021Ool00?mooomoob1oo`8000Ioo`8000Qoo`8000Ioo`8007=o
o`L000Aoo`03001oogoo01ioo`@0009oo`03001oogoo07ioo`00ogooogoo87oo0`0017oo0`002Goo
0P0017oo0P00KGoo1`002goo00<007ooOol067oo1P000dLo00@007ooOol0081oo`00ogooogoo8Goo
20002Woo2000IWoo1`004Woo00<007ooOol04Woo1P002DLo0P000Woo00<007ooOol0OGoo003oOooo
OolROol5000>Ool4001QOol7000XOol6000?Acl20002Ool00`00Oomoo`1mOol00?mooomooi9oo`P0
02Qoo`L001E7?`030017?`00009oo`03001oogoo07aoo`00ogooogooRgoo1`001Goo00<007ooOol0
87oo200014Lo00<004LoAcl05DLo00<004Lo00000Woo00<007ooOol0O7oo003oOoooOon4Ool7000<
Ool00`00Oomoo`0HOol8000=Acl00`00Acm7?`0DAcl01000Acm7?`000Woo00<007ooOol0Ngoo003o
OoooOommOol7000COol00`00Oomoo`0@Ool8000EAcl00`00Acm7?`0DAcl01000Acm7?`000goo00<0
07ooOol0NWoo003oOoooOomfOol7000UOol80004Acl00`00Acm7?`0GAcl00`00Acm7?`0CAcl01@00
Acm7?dLo00000Woo00<007ooOol0NWoo003oOomhOol<000;Ool4003JOol8000TOol8000=Acl00`00
Acm7?`0GAcl00`00Acm7?`0CAcl01000Acm7?`000goo00<007ooOol0NGoo003oOomhOol<0009Ool8
003AOol70006Ool00`00Oomoo`0KOol8000FAcl00`00Acm7?`0FAcl00`00Acm7?`0CAcl50002Ool0
0`00Oomoo`1iOol00?moogUoo`<000Ioo`8000Uoo`8000Aoo`800<Yoo`L000eoo`03001oogoo01=o
o`P000A7?`030017?dLo01M7?`030017?dLo01M7?`030017?dLo00Y7?`T000=7?`05001oogooOol0
001jOol00?moogYoo`<000moo`8000Ioo`800<9oo`L001Aoo`03001oogoo00]oo`P000e7?`030017
?dLo01M7?`030017?dLo01I7?`030017?dLo0097?`P000Q7?`030017?dLo0097?`04001oogoo001j
Ool00?moog]oo`<000ioo`8000Ioo`800;]oo`L0029oo`L001I7?`030017?dLo01I7?`030017?dLo
01A7?`L00117?`030017?dLo0097?`05001oogooOol0001iOol00?moogaoo`<000aoo`8000Qoo`80
0;9oo`P002=oo`H000=7?`030017?dLo01M7?`030017?dLo01M7?`030017?dLo00e7?`H000=7?`03
0017?dLo0157?`030017?dLo00=7?`04001oogoo001iOol00?moogeoo`<000]oo`8000Qoo`800:]o
o`L000Moo`03001oogoo01aoo`D000Y7?`030017?dLo01M7?`030017?dLo01M7?`030017?dLo00M7
?`D000Y7?`030017?dLo0117?`030017?dLo00=7?`05001oogooOol0001hOol00?moogioo`<000Yo
o`8000Qoo`800:Aoo`L000ioo`03001oogoo01Ioo`H00117?`030017?dLo01I7?`030017?dLo01M7
?`040017?dLoAcl6000@Acl00`00Acm7?`0?Acl00`00Acm7?`04Acl01000Oomoo`00N7oo003oOomo
Ool30009Ool20008Ool2002MOol7000EOol00`00Oomoo`0?Ool7000FAcl00`00Acm7?`0GAcl00`00
Acm7?`0CAcl7000FAcl00`00Acm7?`0?Acl00`00Acm7?`04Acl01@00Oomoogoo0000Mgoo003oOon0
Ool30008Ool20008Ool2002EOol8000VOol80004Acl00`00Acm7?`0GAcl00`00Acm7?`0GAcl00`00
Acm7?`0:Acl80004Acl00`00Acm7?`0GAcl00`00Acm7?`0>Acl00`00Acm7?`05Acl01000Oomoo`00
Mgoo003oOon1Ool20008Ool20008Ool2002>Ool70002Ool00`00Oomoo`0ROol7000=Acl00`00Acm7
?`0GAcl00`00Acm7?`0FAcl00`00Acm7?`02Acl8000=Acl00`00Acm7?`0FAcl00`00Acm7?`0>Acl0
0`00Acm7?`05Acl01@00Oomoogoo0000MWoo003oOon2Ool20007Ool20008Ool20027Ool70009Ool0
0`00Oomoo`0JOol8000EAcl00`00Acm7?`0GAcl00`00Acm7?`0BAcl8000EAcl00`00Acm7?`0GAcl0
0`00Acm7?`0=Acl00`00Acm7?`02Acl50002Ool00`00Oomoo`1dOol00?mooh9oo`8000Moo`8000Qo
o`80081oo`L0011oo`03001oogoo019oo`P000A7?`030017?dLo01I7?`030017?dLo01M7?`030017
?dLo00Y7?`P000A7?`030017?dLo01M7?`030017?dLo01M7?`030017?dLo00U7?`P000A7?`05001o
ogooOol0001eOol00?moogUoo`8000Moo`8000Qoo`8000Ioo`8007Yoo`L001Moo`03001oogoo00]o
o`L000e7?`030017?dLo01I7?`030017?dLo01M7?`030017?dLo0097?`L000e7?`030017?dLo01M7
?`030017?dLo01I7?`030017?dLo0097?`L000=7?`030017?dLo00M7?`04001oogoo001eOol00?mo
ogUoo`<000Ioo`8000Qoo`8000Ioo`80079oo`P001ioo`03001oogoo00=oo`P001E7?`030017?dLo
01I7?`030017?dLo01=7?`P001E7?`030017?dLo01I7?`030017?dLo01=7?`P000Y7?`030017?dLo
00M7?`05001oogooOol0001dOol00?moogUoo`@000Aoo`8000Yoo`8000Aoo`8006aoo`L000Aoo`03
001oogoo01eoo`P000A7?`030017?dLo01I7?`030017?dLo01I7?`030017?dLo00]7?`P000A7?`03
0017?dLo01I7?`030017?dLo01M7?`030017?dLo00Y7?`P000A7?`030017?dLo00]7?`030017?dLo
00Q7?`04001oogoo001dOol00?moogYoo`P000]oo`P006Eoo`L000]oo`03001oogoo01Ioo`L000e7
?`030017?dLo01I7?`030017?dLo01I7?`030017?dLo0097?`P000e7?`030017?dLo01I7?`030017
?dLo01I7?`030017?dLo0097?`P000e7?`030017?dLo00Y7?`030017?dLo00U7?`04001oogoo001c
Ool00?moogaoo`D000ioo`@0061oo`L0019oo`03001oogoo00ioo`P001E7?`030017?dLo01I7?`03
0017?dLo0197?`P001I7?`030017?dLo01I7?`030017?dLo0197?`P001E7?`030017?dLo00Y7?`03
0017?dLo00U7?`04001oogoo001cOol00?moonaoo`L0029oo`P000A7?`030017?dLo01I7?`030017
?dLo01I7?`030017?dLo00Y7?`P000A7?`030017?dLo01M7?`030017?dLo01I7?`030017?dLo00Y7
?`P000A7?`030017?dLo01M7?`030017?dLo00U7?`030017?dLo00Y7?`04001oogoo001bOol00?mo
onAoo`P0029oo`L000e7?`030017?dLo01I7?`030017?dLo01I7?`030017?dLo0097?`L000e7?`03
0017?dLo01M7?`030017?dLo01I7?`030017?dLo0097?`L000e7?`030017?dLo01I7?`030017?dLo
00U7?`030017?dLo00Y7?`04001oogoo001bOol00?moomeoo`L000Ioo`03001oogoo01Yoo`L001E7
?`030017?dLo01I7?`030017?dLo01=7?`L001E7?`030017?dLo01I7?`030017?dLo01A7?`L001E7
?`030017?dLo01I7?`030017?dLo00Q7?`030017?dLo00Q7?`@0009oo`03001oogoo06moo`00ogoo
eWoo1`003Goo00<007ooOol057oo1P000dLo00<004LoAcl05TLo00<004LoAcl05dLo00<004LoAcl0
3DLo1@000dLo00<004LoAcl05TLo00<004LoAcl05dLo00<004LoAcl03DLo1P000dLo00<004LoAcl0
5TLo00<004LoAcl05TLo00<004LoAcl024Lo00<004LoAcl00TLo1P000dLo00@007ooOol0075oo`00
g7oo2P002goo1000fGoo1`0057oo00<007ooOol03goo1@002TLo00<004LoAcl05TLo00<004LoAcl0
5TLo00<004LoAcl01dLo1P002DLo00<004LoAcl05TLo00<004LoAcl05dLo00<004LoAcl01dLo1@00
2TLo00<004LoAcl05TLo00<004LoAcl05TLo00<004LoAcl01dLo1@002TLo00@007ooOol0071oo`00
g7oo2P002Goo2000d7oo1`009goo1P0044Lo00<004LoAcl05TLo00<004LoAcl05TLo00@004LoAcm7
?`D00117?`030017?dLo01I7?`030017?dLo01I7?`040017?dLoAcl6000@Acl00`00Acm7?`0EAcl0
0`00Acm7?`0FAcl01000Acm7?dLo1`003TLo00D007ooOomoo`0006moo`00h7oo0P003Goo0P0017oo
0P00b7oo200000=oo`00Ool097oo1`005TLo00<004LoAcl05dLo00<004LoAcl04TLo1`005DLo00<0
04LoAcl05dLo00<004LoAcl04TLo1`005TLo00<004LoAcl05TLo00<004LoAcl04TLo1`001TLo00<0
04LoAcl03DLo00@007ooOol006moo`00h7oo0P0037oo0P001Woo0P00`7oo1`002Goo00<007ooOol0
77oo1`0014Lo00<004LoAcl05dLo00<004LoAcl05TLo00<004LoAcl02TLo200014Lo00<004LoAcl0
5TLo00<004LoAcl05TLo00<004LoAcl02TLo200014Lo00<004LoAcl05dLo00<004LoAcl05TLo00<0
04LoAcl02DLo200014Lo00<004LoAcl01TLo00<004LoAcl03DLo00D007ooOomoo`0006ioo`00h7oo
0P0037oo0P001Woo0P00^Goo1`0047oo00<007ooOol05Goo1`0034Lo00<004LoAcl05dLo00<004Lo
Acl05TLo00<004LoAcl00TLo1`003DLo00<004LoAcl05TLo00<004LoAcl05TLo00<004LoAcl00TLo
1`003DLo00<004LoAcl05TLo00<004LoAcl05TLo00<004LoAcl00TLo1`003DLo00<004LoAcl01DLo
00<004LoAcl03TLo00@007ooOol006ioo`00h7oo0P002goo0P0027oo0P00/Goo1`005goo00<007oo
Ool03Goo200054Lo00<004LoAcl05dLo00<004LoAcl04TLo20005DLo00<004LoAcl05TLo00<004Lo
Acl04TLo20005DLo00<004LoAcl05TLo00<004LoAcl04TLo200054Lo00<004LoAcl01TLo00<004Lo
Acl03DLo00D007ooOomoo`0006eoo`00h7oo0P002goo0P0027oo0P00ZWoo1`009goo1`0014Lo00<0
04LoAcl05TLo00<004LoAcl05TLo00<004LoAcl02TLo200014Lo00<004LoAcl05TLo00<004LoAcl0
5TLo00<004LoAcl02TLo200014Lo00<004LoAcl05TLo00<004LoAcl05dLo00<004LoAcl02DLo2000
14Lo00<004LoAcl05TLo00<004LoAcl01DLo00<004LoAcl03TLo00@007ooOol006eoo`00h7oo0P00
2goo0P0027oo0P00XWoo200017oo00<007ooOol087oo1`0034Lo00<004LoAcl05TLo00<004LoAcl0
5TLo00<004LoAcl00TLo1`003DLo00<004LoAcl05TLo00<004LoAcl05TLo00<004LoAcl00TLo1`00
3DLo00<004LoAcl05TLo00<004LoAcl05TLo00<004LoAcl00TLo1`003DLo00<004LoAcl05TLo00<0
04LoAcl014Lo00<004LoAcl03TLo00D007ooOomoo`0006aoo`00h7oo0P002goo0P0027oo0P00Vgoo
1`0037oo00<007ooOol067oo200054Lo00<004LoAcl05TLo00<004LoAcl04TLo20005DLo00<004Lo
Acl05TLo00<004LoAcl04TLo20005DLo00<004LoAcl05TLo00<004LoAcl04TLo200054Lo00<004Lo
Acl05TLo00<004LoAcl014Lo00<004LoAcl02dLo1@000Woo00<007ooOol0JWoo003POol2000;Ool2
0008Ool2002DOol7000COol00`00Oomoo`0@Ool80004Acl00`00Acm7?`0FAcl00`00Acm7?`0FAcl0
0`00Acm7?`0:Acl70004Acl00`00Acm7?`0GAcl00`00Acm7?`0EAcl00`00Acm7?`0:Acl80004Acl0
0`00Acm7?`0FAcl00`00Acm7?`0FAcl00`00Acm7?`0:Acl80004Acl00`00Acm7?`0FAcl00`00Acm7
?`0FAcl00`00Acm7?`03Acl00`00Acm7?`03Acl80004Acl01@00Oomoogoo0000Jgoo003POol2000;
Ool20008Ool2002=Ool7000VOol7000=Acl00`00Acm7?`0FAcl00`00Acm7?`0FAcl00`00Acm7?`02
Acl7000<Acl00`00Acm7?`0GAcl00`00Acm7?`0EAcl00`00Acm7?`02Acl7000=Acl00`00Acm7?`0F
Acl00`00Acm7?`0FAcl00`00Acm7?`02Acl7000=Acl00`00Acm7?`0FAcl00`00Acm7?`0EAcl00`00
Acm7?`02Acl7000=Acl01000Oomoo`00Jgoo003POol2000;Ool20008Ool20026Ool700000goo001o
o`0SOol7000EAcl00`00Acm7?`0FAcl00`00Acm7?`0BAcl8000DAcl00`00Acm7?`0FAcl00`00Acm7
?`0BAcl8000EAcl00`00Acm7?`0FAcl00`00Acm7?`0BAcl8000DAcl00`00Acm7?`0FAcl00`00Acm7
?`0BAcl800000dLo0017?`0AAcl01@00Oomoogoo0000JWoo003POol2000;Ool20008Ool2001nOol8
0008Ool00`00Oomoo`0KOol70004Acl00`00Acm7?`0FAcl00`00Acm7?`0FAcl00`00Acm7?`0:Acl7
0004Acl00`00Acm7?`0FAcl00`00Acm7?`0FAcl00`00Acm7?`0:Acl70004Acl00`00Acm7?`0FAcl0
0`00Acm7?`0FAcl00`00Acm7?`0:Acl80004Acl00`00Acm7?`0FAcl00`00Acm7?`0FAcl00`00Acm7
?`09Acl80004Acl00`00Acm7?`02Acl00`00Acm7?`0AAcl01000Oomoo`00JWoo003POol2000<Ool2
0006Ool2001hOol7000@Ool00`00Oomoo`0DOol7000<Acl00`00Acm7?`0FAcl00`00Acm7?`0FAcl0
0`00Acm7?`02Acl7000<Acl00`00Acm7?`0FAcl00`00Acm7?`0FAcl00`00Acm7?`02Acl7000<Acl0
0`00Acm7?`0FAcl00`00Acm7?`0FAcl00`00Acm7?`02Acl7000=Acl00`00Acm7?`0FAcl00`00Acm7
?`0EAcl00`00Acm7?`02Acl7000=Acl01@00Acm7?dLo000054Lo00@007ooOol006Uoo`00h7oo0P00
37oo0P001Woo0P00LGoo1`005goo00<007ooOol037oo200054Lo00<004LoAcl05TLo00<004LoAcl0
4TLo200054Lo00<004LoAcl05DLo00<004LoAcl04dLo200054Lo00<004LoAcl05TLo00<004LoAcl0
4TLo200054Lo00<004LoAcl05TLo00<004LoAcl04TLo200054Lo00D004LoAcm7?`0001A7?`04001o
ogoo001YOol00=aoo`<00003Ool0000000eoo`8000Aoo`8006]oo`L001ioo`03001oogoo00Eoo`L0
00A7?`030017?dLo01I7?`030017?dLo01I7?`030017?dLo00Y7?`L000A7?`030017?dLo01I7?`03
0017?dLo01E7?`030017?dLo00Y7?`P000A7?`030017?dLo01I7?`030017?dLo01E7?`030017?dLo
00Y7?`P000A7?`030017?dLo01I7?`030017?dLo01I7?`030017?dLo00U7?`P000A7?`030017?dLo
01I7?`040017?dLo000EAcl01000Oomoo`00J7oo003LOol6000=Ool8001TOol70004Ool00`00Oomo
o`0NOol8000<Acl00`00Acm7?`0FAcl00`00Acm7?`0FAcl00`00Acm7?`02Acl7000<Acl00`00Acm7
?`0FAcl00`00Acm7?`0EAcl00`00Acm7?`02Acl7000=Acl00`00Acm7?`0FAcl00`00Acm7?`0EAcl0
0`00Acm7?`02Acl7000=Acl00`00Acm7?`0FAcl00`00Acm7?`0EAcl00`00Acm7?`02Acl7000=Acl0
0`00Acm7?`0FAcl00`00Acl0000EAcl01000Oomoo`00J7oo003OOol3000?Ool4001NOol8000;Ool0
0`00Oomoo`0GOol8000DAcl00`00Acm7?`0FAcl00`00Acm7?`0BAcl8000DAcl00`00Acm7?`0EAcl0
0`00Acm7?`0BAcl8000EAcl00`00Acm7?`0EAcl00`00Acm7?`0BAcl8000EAcl00`00Acm7?`0EAcl0
0`00Acm7?`0BAcl8000DAcl00`00Acm7?`0FAcl00`00Acl0000BAcl50002Ool00`00Oomoo`1UOol0
0?moodeoo`L001=oo`03001oogoo011oo`L000A7?`030017?dLo01I7?`030017?dLo01I7?`030017
?dLo00Y7?`L000A7?`030017?dLo01I7?`030017?dLo01E7?`030017?dLo00Y7?`L000A7?`030017
?dLo01M7?`030017?dLo01E7?`030017?dLo00Y7?`L000A7?`030017?dLo01I7?`030017?dLo01I7
?`030017?dLo00U7?`P000A7?`030017?dLo01I7?`030017?dLo01I7?`8000Y7?`P000A7?`04001o
ogoo001WOol00?moodIoo`L002Ioo`L000a7?`030017?dLo01I7?`030017?dLo01I7?`030017?dLo
0097?`L000a7?`030017?dLo01I7?`030017?dLo01E7?`030017?dLo0097?`L000a7?`030017?dLo
01M7?`030017?dLo01E7?`030017?dLo0097?`L000a7?`030017?dLo01I7?`030017?dLo01E7?`03
0017?dLo0097?`L000e7?`030017?dLo01I7?`030017?dLo01E7?`8000=7?`L000e7?`04001oogoo
001VOol00?moocmoo`L0009oo`03001oogoo025oo`L001A7?`030017?dLo01I7?`030017?dLo0197
?`P001A7?`030017?dLo01E7?`030017?dLo0197?`P001A7?`030017?dLo01I7?`030017?dLo0197
?`P001A7?`030017?dLo01I7?`030017?dLo0157?`P001E7?`030017?dLo01E7?`030017?dLo0197
?`P001A7?`04001oogoo001VOol00?moocQoo`L000Uoo`03001oogoo01Yoo`L000A7?`030017?dLo
01E7?`030017?dLo01I7?`030017?dLo00Y7?`L000A7?`030017?dLo01I7?`030017?dLo01E7?`03
0017?dLo00Y7?`L000A7?`030017?dLo01I7?`030017?dLo01I7?`030017?dLo00Y7?`L000A7?`03
0017?dLo01E7?`030017?dLo01I7?`030017?dLo00Y7?`L000A7?`030017?dLo01I7?`030017?dLo
01I7?`030017?dLo00U7?`P000A7?`030017?dLo01I7?`04001oogoo001UOol00?mooc1oo`P0011o
o`03001oogoo01=oo`L000a7?`030017?dLo01E7?`030017?dLo01I7?`030017?dLo0097?`L000a7
?`030017?dLo01I7?`030017?dLo01E7?`030017?dLo0097?`L000a7?`030017?dLo01I7?`030017
?dLo01I7?`030017?dLo0097?`L000a7?`030017?dLo01E7?`030017?dLo01I7?`030017?dLo0097
?`L000a7?`030017?dLo01I7?`030017?dLo01E7?`030017?dLo0097?`L000a7?`8001Q7?`03001o
o`0006Eoo`00ogoo:Goo1`0067oo00<007ooOol02goo200054Lo00<004LoAcl05DLo00<004LoAcl0
4TLo200054Lo00<004LoAcl05DLo00<004LoAcl04TLo200054Lo00<004LoAcl05DLo00<004LoAcl0
4dLo200054Lo00<004LoAcl05DLo00<004LoAcl04TLo200054Lo00<004LoAcl05TLo00<004LoAcl0
4DLo20004dLo0P0064Lo00@007ooOol006Aoo`00ogoo8Woo1`009Woo1`001DLo00<004LoAcl05DLo
00<004LoAcl05DLo00<004LoAcl02TLo1`0014Lo00<004LoAcl05TLo00<004LoAcl05DLo00<004Lo
Acl02TLo1`0014Lo00<004LoAcl05TLo00<004LoAcl05DLo00<004LoAcl02TLo200014Lo00<004Lo
Acl05DLo00<004LoAcl05DLo00<004LoAcl02TLo200014Lo00<004LoAcl05DLo00<004LoAcl05TLo
00<004LoAcl02TLo1`0014Lo00<004LoAcl054Lo00<004Lo000064Lo00<007oo0000I7oo003oOolK
Ool70006Ool00`00Oomoo`0MOol7000=Acl00`00Acm7?`0EAcl00`00Acm7?`0EAcl00`00Acm7?`02
Acl7000<Acl00`00Acm7?`0FAcl00`00Acm7?`0EAcl00`00Acm7?`02Acl7000<Acl00`00Acm7?`0F
Acl00`00Acm7?`0EAcl00`00Acm7?`02Acl7000=Acl00`00Acm7?`0EAcl00`00Acm7?`0EAcl00`00
Acm7?`02Acl7000=Acl00`00Acm7?`0EAcl00`00Acm7?`0FAcl00`00Acm7?`02Acl7000<Acl00`00
Acm7?`0CAcl01000Acm7?`005dLo00@007ooOol006=oo`00ogoo57oo1`003Goo00<007ooOol05Woo
1`005DLo00<004LoAcl05DLo00<004LoAcl04TLo1`0054Lo00<004LoAcl05TLo00<004LoAcl04TLo
1`0054Lo00<004LoAcl05DLo00<004LoAcl04TLo20005DLo00<004LoAcl05DLo00<004LoAcl04DLo
20005DLo00<004LoAcl05DLo00<004LoAcl04TLo20004dLo00<004LoAcl04dLo00@004LoAcl001A7
?`D0009oo`03001oogoo061oo`00ogoo37oo200057oo00<007ooOol03goo1`0014Lo00<004LoAcl0
5TLo00<004LoAcl05DLo00<004LoAcl02TLo1`0014Lo00<004LoAcl05DLo00<004LoAcl05TLo00<0
04LoAcl02TLo1`000dLo00<004LoAcl05TLo00<004LoAcl05DLo00<004LoAcl02TLo1`0014Lo00<0
04LoAcl05TLo00<004LoAcl05DLo00<004LoAcl02TLo1`0014Lo00<004LoAcl05TLo00<004LoAcl0
5DLo00<004LoAcl02TLo200014Lo00<004LoAcl05DLo00<004LoAcl04TLo00D004LoAcm7?`0000]7
?`P000A7?`04001oogoo001ROol00?moo`Eoo`L002Moo`L000a7?`030017?dLo01I7?`030017?dLo
01E7?`030017?dLo0097?`L000a7?`030017?dLo01E7?`030017?dLo01I7?`030017?dLo0097?`L0
00]7?`030017?dLo01I7?`030017?dLo01E7?`030017?dLo0097?`L000a7?`030017?dLo01I7?`03
0017?dLo01E7?`030017?dLo0097?`L000a7?`030017?dLo01I7?`030017?dLo01E7?`030017?dLo
0097?`L000e7?`030017?dLo01E7?`030017?dLo0157?`050017?dLoAcl00004Acl7000=Acl01000
Oomoo`00HGoo003mOol70004Ool00`00Oomoo`0POol7000DAcl00`00Acm7?`0FAcl00`00Acm7?`0B
Acl7000DAcl00`00Acm7?`0EAcl00`00Acm7?`0BAcl8000CAcl00`00Acm7?`0FAcl00`00Acm7?`0B
Acl7000DAcl00`00Acm7?`0FAcl00`00Acm7?`0AAcl8000DAcl00`00Acm7?`0FAcl00`00Acm7?`0A
Acl8000DAcl00`00Acm7?`0EAcl00`00Acm7?`0AAcl9000DAcl01000Oomoo`00HGoo003fOol7000;
Ool00`00Oomoo`0IOol70005Acl00`00Acm7?`0DAcl00`00Acm7?`0FAcl00`00Acm7?`0:Acl70004
Acl00`00Acm7?`0EAcl00`00Acm7?`0EAcl00`00Acm7?`0:Acl70004Acl00`00Acm7?`0EAcl00`00
Acm7?`0FAcl00`00Acm7?`0:Acl70003Acl00`00Acm7?`0FAcl00`00Acm7?`0EAcl00`00Acm7?`0:
Acl70004Acl00`00Acm7?`0FAcl00`00Acm7?`0EAcl00`00Acm7?`0:Acl70004Acl00`00Acm7?`0F
Acl00`00Acm7?`0EAcl00`00Acm7?`09Acl80004Acl00`00Acm7?`0FAcl01000Oomoo`00H7oo003^
Ool8000BOol00`00Oomoo`0BOol7000=Acl00`00Acm7?`0DAcl00`00Acm7?`0FAcl00`00Acm7?`02
Acl7000<Acl00`00Acm7?`0EAcl00`00Acm7?`0EAcl00`00Acm7?`02Acl7000<Acl00`00Acm7?`0E
Acl00`00Acm7?`0FAcl00`00Acm7?`02Acl7000;Acl00`00Acm7?`0FAcl00`00Acm7?`0EAcl00`00
Acm7?`02Acl7000<Acl00`00Acm7?`0FAcl00`00Acm7?`0EAcl00`00Acm7?`02Acl7000<Acl00`00
Acm7?`0FAcl00`00Acm7?`0DAcl00`00Acm7?`02Acl70007Acl00`00Acm7?`03Acl00`00Acm7?`0E
Acl01000Oomoo`00H7oo003WOol7000XOol7000EAcl00`00Acm7?`0DAcl00`00Acm7?`0BAcl8000D
Acl00`00Acm7?`0EAcl00`00Acm7?`0BAcl7000DAcl00`00Acm7?`0EAcl00`00Acm7?`0BAcl8000C
Acl00`00Acm7?`0EAcl00`00Acm7?`0BAcl8000DAcl00`00Acm7?`0EAcl00`00Acm7?`0BAcl8000D
Acl00`00Acm7?`0EAcl00`00Acm7?`0AAcl8000?Acl00`00Acm7?`03Acl00`00Acm7?`0DAcl01@00
Oomoogoo0000Ggoo003POol70002Ool00`00Oomoo`0SOol70005Acl00`00Acm7?`0EAcl00`00Acm7
?`0DAcl00`00Acm7?`0:Acl70005Acl00`00Acm7?`0EAcl00`00Acm7?`0EAcl00`00Acm7?`0:Acl7
0004Acl00`00Acm7?`0EAcl00`00Acm7?`0EAcl00`00Acm7?`0:Acl70004Acl00`00Acm7?`0EAcl0
0`00Acm7?`0EAcl00`00Acm7?`0:Acl70004Acl00`00Acm7?`0FAcl00`00Acm7?`0EAcl00`00Acm7
?`0:Acl70004Acl00`00Acm7?`0FAcl00`00Acm7?`0EAcl00`00Acm7?`09Acl70004Acl00`00Acm7
?`0@Acl00`00Acm7?`03Acl00`00Acm7?`0EAcl01000Oomoo`00Ggoo003IOol70009Ool00`00Oomo
o`0LOol7000=Acl00`00Acm7?`0EAcl00`00Acm7?`0DAcl00`00Acm7?`02Acl7000=Acl00`00Acm7
?`0EAcl00`00Acm7?`0EAcl00`00Acm7?`02Acl7000<Acl00`00Acm7?`0EAcl00`00Acm7?`0EAcl0
0`00Acm7?`02Acl7000<Acl00`00Acm7?`0EAcl00`00Acm7?`0EAcl00`00Acm7?`02Acl7000<Acl0
0`00Acm7?`0FAcl00`00Acm7?`0EAcl00`00Acm7?`02Acl7000<Acl00`00Acm7?`0EAcl00`00Acm7
?`0EAcl00`00Acm7?`02Acl7000<Acl00`00Acm7?`0?Acl00`00Acm7?`04Acl00`00Acm7?`0DAcl0
1@00Oomoogoo0000GWoo003BOol7000@Ool00`00Oomoo`0COol9000EAcl00`00Acm7?`0EAcl00`00
Acm7?`0?Acl9000EAcl00`00Acm7?`0EAcl00`00Acm7?`0@Acl9000DAcl00`00Acm7?`0EAcl00`00
Acm7?`0@Acl9000DAcl00`00Acm7?`0EAcl00`00Acm7?`0@Acl9000DAcl00`00Acm7?`0FAcl00`00
Acm7?`0@Acl9000DAcl00`00Acm7?`0EAcl00`00Acm7?`0@Acl9000DAcl00`00Acm7?`0>Acl00`00
Acm7?`04Acl00`00Acm7?`0@Acl60002Ool00`00Oomoo`1LOol00<Yoo`P001Moo`03001oogoo00Qo
o`/000M7?`030017?dLo01E7?`030017?dLo01E7?`030017?dLo00=7?`/000M7?`030017?dLo01E7
?`030017?dLo01E7?`030017?dLo00A7?`/000I7?`030017?dLo01E7?`030017?dLo01E7?`030017
?dLo00A7?`/000E7?`030017?dLo01I7?`030017?dLo01E7?`030017?dLo00A7?`/000E7?`030017
?dLo01I7?`030017?dLo01I7?`030017?dLo00A7?`/000E7?`030017?dLo01E7?`030017?dLo01I7
?`030017?dLo00A7?`/000E7?`030017?dLo01E7?`030017?dLo00i7?`030017?dLo00E7?`030017
?dLo00A7?`/000E7?`05001oogooOol0001MOol00<=oo`L00003Ool007oo01aoo`03001oogoo00P0
01=7?`030017?dLo01E7?`030017?dLo0197?`P001=7?`030017?dLo01E7?`030017?dLo0197?`T0
0197?`030017?dLo01E7?`030017?dLo0197?`T00157?`030017?dLo01I7?`030017?dLo0197?`T0
0157?`030017?dLo01I7?`030017?dLo0197?`X00157?`030017?dLo01E7?`030017?dLo0197?`X0
0157?`030017?dLo01E7?`030017?dLo00e7?`030017?dLo0097?`X00157?`04001oogoo001MOol0
0;aoo`L000Qoo`03001oogoo01Moo`L000E7?`030017?dLo01A7?`030017?dLo01E7?`030017?dLo
00Y7?`L000A7?`030017?dLo01E7?`030017?dLo01E7?`030017?dLo00Y7?`L000A7?`030017?dLo
01E7?`030017?dLo01E7?`030017?dLo00Y7?`L000=7?`030017?dLo01E7?`030017?dLo01I7?`03
0017?dLo00Y7?`L000=7?`030017?dLo01E7?`030017?dLo01I7?`030017?dLo00Y7?`L000A7?`03
0017?dLo01E7?`030017?dLo01A7?`030017?dLo00Y7?`P000A7?`030017?dLo01E7?`030017?dLo
01A7?`030017?dLo00Y7?`P000A7?`030017?dLo01E7?`04001oogoo001LOol00;Eoo`L000moo`03
001oogoo011oo`L000e7?`030017?dLo01A7?`8001I7?`030017?dLo0097?`L000a7?`030017?dLo
01E7?`030017?dLo01E7?`030017?dLo0097?`L000a7?`030017?dLo01E7?`030017?dLo01E7?`03
0017?dLo0097?`L000]7?`030017?dLo01E7?`030017?dLo01I7?`030017?dLo0097?`L000]7?`03
0017?dLo01E7?`030017?dLo01I7?`030017?dLo0097?`L000a7?`030017?dLo01A7?`030017?dLo
01E7?`030017?dLo0097?`L000e7?`030017?dLo01A7?`030017?dLo01E7?`030017?dLo0097?`L0
00=7?`030017?dLo00M7?`030017?dLo01A7?`04001oogoo001LOol00:ioo`L001Ioo`03001oogoo
00Yoo`H001E7?`030017?dLo01E7?`030017?dLo0157?`L001A7?`030017?dLo01E7?`030017?dLo
0197?`L001A7?`030017?dLo01E7?`030017?dLo0197?`L001=7?`030017?dLo01E7?`030017?dLo
0197?`P001=7?`030017?dLo01E7?`030017?dLo0197?`P001A7?`030017?dLo01A7?`030017?dLo
0157?`P001A7?`030017?dLo01E7?`030017?dLo0157?`P000Y7?`030017?dLo00M7?`030017?dLo
01E7?`04001oogoo001KOol00:Ioo`P002=oo`L000E7?`030017?dLo01A7?`030017?dLo01E7?`03
0017?dLo00U7?`L000E7?`030017?dLo01A7?`030017?dLo01E7?`030017?dLo00Y7?`L000A7?`03
0017?dLo01E7?`030017?dLo01E7?`030017?dLo00Y7?`L000=7?`030017?dLo01E7?`030017?dLo
01E7?`030017?dLo00Y7?`L000A7?`030017?dLo01E7?`030017?dLo01E7?`030017?dLo00Y7?`L0
00A7?`030017?dLo01E7?`030017?dLo01A7?`030017?dLo00Y7?`L000A7?`030017?dLo01I7?`03
0017?dLo01A7?`030017?dLo00Y7?`L000A7?`030017?dLo00]7?`030017?dLo00Q7?`030017?dLo
01A7?`04001oogoo001KOol009moo`L000Ioo`03001oogoo01]oo`L000e7?`030017?dLo01A7?`03
0017?dLo01E7?`040017?dLoAcl7000=Acl00`00Acm7?`0DAcl00`00Acm7?`0EAcl00`00Acm7?`02
Acl7000<Acl00`00Acm7?`0EAcl00`00Acm7?`0EAcl00`00Acm7?`02Acl7000;Acl00`00Acm7?`0E
Acl00`00Acm7?`0EAcl00`00Acm7?`02Acl7000<Acl00`00Acm7?`0EAcl00`00Acm7?`0EAcl00`00
Acm7?`02Acl7000<Acl00`00Acm7?`0EAcl00`00Acm7?`0DAcl00`00Acm7?`02Acl7000<Acl00`00
Acm7?`0FAcl00`00Acm7?`0DAcl00`00Acm7?`02Acl7000<Acl00`00Acm7?`0:Acl00`00Acm7?`08
Acl00`00Acm7?`0EAcl01000Oomoo`00FWoo002HOol7000=Ool00`00Oomoo`0DOol7000EAcl00`00
Acm7?`0DAcl00`00Acm7?`0BAcl6000EAcl00`00Acm7?`0DAcl00`00Acm7?`0BAcl7000DAcl00`00
Acm7?`0EAcl00`00Acm7?`0BAcl7000CAcl00`00Acm7?`0EAcl00`00Acm7?`0BAcl7000DAcl00`00
Acm7?`0DAcl00`00Acm7?`0BAcl8000DAcl00`00Acm7?`0EAcl00`00Acm7?`0AAcl7000DAcl00`00
Acm7?`0EAcl00`00Acm7?`0AAcl8000CAcl00`00Acm7?`0:Acl00`00Acm7?`08Acl00`00Acm7?`0B
Acl500000goo001oo`1IOol0095oo`L001Aoo`03001oogoo00eoo`L000E7?`030017?dLo01E7?`03
0017?dLo01A7?`030017?dLo00Y7?`L000E7?`030017?dLo01A7?`030017?dLo01A7?`030017?dLo
00Y7?`L000E7?`030017?dLo01A7?`030017?dLo01E7?`030017?dLo00Y7?`L000A7?`030017?dLo
01A7?`030017?dLo01E7?`030017?dLo00Y7?`L000A7?`030017?dLo01E7?`030017?dLo01A7?`03
0017?dLo00Y7?`L000A7?`030017?dLo01E7?`030017?dLo01E7?`030017?dLo00Y7?`L000=7?`03
0017?dLo01E7?`030017?dLo01I7?`030017?dLo00U7?`L000A7?`030017?dLo01E7?`030017?dLo
00U7?`030017?dLo00U7?`030017?dLo00U7?`P000A7?`04001oogoo001IOol008Yoo`L002Aoo`L0
00e7?`030017?dLo01E7?`030017?dLo01A7?`030017?dLo0097?`L000e7?`030017?dLo01A7?`03
0017?dLo01A7?`030017?dLo0097?`L000e7?`030017?dLo01A7?`030017?dLo01E7?`030017?dLo
0097?`L000a7?`030017?dLo01A7?`030017?dLo01E7?`030017?dLo0097?`L000a7?`030017?dLo
01E7?`030017?dLo01A7?`030017?dLo0097?`L000a7?`030017?dLo01E7?`030017?dLo01E7?`03
0017?dLo0097?`L000]7?`030017?dLo01E7?`030017?dLo01E7?`030017?dLo0097?`L000a7?`03
0017?dLo01E7?`030017?dLo00Q7?`030017?dLo00U7?`030017?dLo0097?`L000e7?`03001oo`00
05Uoo`00PWoo20001Goo00<007ooOol07Goo1P005DLo00<004LoAcl05DLo00<004LoAcl04DLo1`00
5DLo00<004LoAcl054Lo00<004LoAcl04DLo1`005DLo00<004LoAcl054Lo00<004LoAcl04TLo1`00
54Lo00<004LoAcl054Lo00<004LoAcl04TLo1`0054Lo00<004LoAcl054Lo00<004LoAcl04TLo1`00
54Lo00<004LoAcl05DLo00<004LoAcl04DLo20004dLo00<004LoAcl05DLo00<004LoAcl04DLo2000
4dLo00<004LoAcl05DLo00<004LoAcl024Lo00<004LoAcl01TLo200054Lo00@007ooOol005Qoo`00
Ngoo1`0037oo00<007ooOol05goo1`001DLo00<004LoAcl054Lo0P005TLo00<004LoAcl02DLo1`00
1DLo00<004LoAcl05DLo00<004LoAcl054Lo00<004LoAcl02DLo1`001DLo00<004LoAcl05DLo00<0
04LoAcl054Lo00<004LoAcl02TLo1`0014Lo00<004LoAcl05DLo00<004LoAcl054Lo00<004LoAcl0
2TLo1`0014Lo00<004LoAcl05DLo00<004LoAcl054Lo00<004LoAcl02TLo1`000dLo00<004LoAcl0
5TLo00<004LoAcl054Lo00<004LoAcl02TLo1`0014Lo00<004LoAcl054Lo00<004LoAcl05DLo00<0
04LoAcl02TLo1`0014Lo00<004LoAcl05DLo00<004LoAcl05DLo00<004LoAcl01dLo00<004Lo0000
1P0014Lo00<004LoAcl05TLo00<007oo0000F7oo001dOol7000COol00`00Oomoo`0@Ool7000=Acl0
0`00Acm7?`0EAcl00`00Acm7?`0DAcl01000Acm7?dLo1`003DLo00<004LoAcl05DLo00<004LoAcl0
54Lo00@004LoAcm7?`L000e7?`030017?dLo01E7?`030017?dLo01A7?`030017?dLo0097?`L000a7
?`030017?dLo01E7?`030017?dLo01A7?`030017?dLo0097?`L000a7?`030017?dLo01E7?`030017
?dLo01A7?`030017?dLo0097?`L000]7?`030017?dLo01I7?`030017?dLo01A7?`030017?dLo0097
?`L000a7?`030017?dLo01A7?`030017?dLo01E7?`030017?dLo0097?`L000a7?`030017?dLo01E7
?`030017?dLo01A7?`030017?dLo0097?`L000a7?`030017?dLo01E7?`04001oogoo001GOol006eo
o`L002Eoo`P001E7?`030017?dLo01E7?`030017?dLo00m7?`P001E7?`030017?dLo01E7?`030017
?dLo00m7?`P001E7?`030017?dLo01E7?`030017?dLo00m7?`T001A7?`030017?dLo01E7?`030017
?dLo00m7?`T001A7?`030017?dLo01E7?`030017?dLo00m7?`T001=7?`030017?dLo01E7?`030017
?dLo0197?`L001A7?`030017?dLo01A7?`030017?dLo0157?`P001A7?`030017?dLo01A7?`030017
?dLo0157?`P000E7?`030017?dLo00a7?`030017?dLo01E7?`03001oo`0005Moo`00IWoo1`0017oo
00<007ooOol06goo2P001dLo00<004LoAcl054Lo0P005TLo00<004LoAcl00dLo2`001dLo00<004Lo
Acl054Lo0P005TLo00<004LoAcl00dLo2`001dLo00<004LoAcl054Lo00<004LoAcl05DLo00<004Lo
Acl00dLo2`001TLo00<004LoAcl05DLo00<004LoAcl05DLo00<004LoAcl00dLo2`001TLo00<004Lo
Acl05DLo00<004LoAcl05DLo00<004LoAcl00dLo2`001DLo00<004LoAcl05DLo00<004LoAcl05DLo
00<004LoAcl02TLo1`000dLo00<004LoAcl05TLo00<004LoAcl04dLo00<004LoAcl02TLo1`0014Lo
00<004LoAcl05DLo00<004LoAcl05DLo00<004LoAcl02DLo1`0014Lo00<004LoAcl01TLo00<004Lo
Acl034Lo00<004LoAcl05DLo00@007ooOol005Ioo`00HWoo10002goo00<007ooOol04goo20004TLo
00<004LoAcl05DLo00<004LoAcl04DLo20004dLo00<004LoAcl05DLo00<004LoAcl04DLo20004dLo
00<004LoAcl054Lo00<004LoAcl04TLo20004TLo00<004LoAcl05DLo00<004LoAcl04TLo20004TLo
00<004LoAcl05DLo00<004LoAcl04TLo20004DLo00<004LoAcl05DLo00<004LoAcl05DLo00<004Lo
Acl00TLo1`002dLo00<004LoAcl05DLo00<004LoAcl054Lo00<004LoAcl00TLo1`0034Lo00<004Lo
Acl05DLo00<004LoAcl054Lo00<004LoAcl00TLo1`0034Lo00<004LoAcl01DLo00<004LoAcl03DLo
00<004LoAcl04DLo1@000Woo00<007ooOol0Dgoo001ROol00`00Ool0000<Ool00`00Oomoo`0<Ool7
0005Acl00`00Acm7?`0CAcl00`00Acm7?`0EAcl00`00Acm7?`09Acl70005Acl00`00Acm7?`0DAcl0
0`00Acm7?`0EAcl00`00Acm7?`09Acl70005Acl00`00Acm7?`0DAcl00`00Acm7?`0DAcl00`00Acm7
?`0:Acl70004Acl00`00Acm7?`0DAcl00`00Acm7?`0EAcl00`00Acm7?`0:Acl70003Acl00`00Acm7
?`0EAcl00`00Acm7?`0EAcl00`00Acm7?`0:Acl70003Acl00`00Acm7?`0DAcl00`00Acm7?`0EAcl0
0`00Acm7?`0@Acl9000CAcl00`00Acm7?`0EAcl00`00Acm7?`0?Acl9000DAcl00`00Acm7?`0DAcl0
0`00Acm7?`0@Acl9000DAcl00`00Acm7?`04Acl00`00Acm7?`0=Acl00`00Acm7?`0:Acl70004Ael0
1000Oomoo`00EGoo001ROol01000Oomoo`004goo1`003DLo00<004LoAcl04dLo0P005TLo00@004Lo
Acm7?`L000e7?`030017?dLo01A7?`8001I7?`040017?dLoAcl7000=Acl00`00Acm7?`0DAcl00`00
Acm7?`0DAcl00`00Acm7?`02Acl7000<Acl00`00Acm7?`0DAcl00`00Acm7?`0EAcl00`00Acm7?`02
Acl7000;Acl00`00Acm7?`0EAcl00`00Acm7?`0EAcl00`00Acm7?`02Acl7000;Acl00`00Acm7?`0D
Acl00`00Acm7?`0EAcl00`00Acm7?`04Acl;0005Acl00`00Acm7?`0EAcl00`00Acm7?`0EAcl00`00
Acm7?`03Acl;0005Acl00`00Acm7?`0FAcl00`00Acm7?`0DAcl00`00Acm7?`04Acl;0005Acl00`00
Acm7?`0EAcl00`00Acm7?`04Acl00`00Acm7?`0>Acl00`00Acm7?`02Acl7000<Ael01000Oomoo`00
E7oo001<Ool4000BOol01000Oomoogoo0P002goo1P005DLo00<004LoAcl054Lo00<004LoAcl04DLo
1P005DLo00<004LoAcl05DLo00<004LoAcl04DLo1P005DLo00<004LoAcl054Lo00<004LoAcl04DLo
1`0054Lo00<004LoAcl054Lo00<004LoAcl04TLo1`004dLo00<004LoAcl05DLo00<004LoAcl04TLo
1`004dLo00<004LoAcl054Lo00<004LoAcl04TLo2@004DLo00<004LoAcl054Lo00<004LoAcl04TLo
2@004DLo00<004LoAcl05DLo00<004LoAcl04TLo2@004DLo00<004LoAcl05DLo00<004LoAcl00dLo
00<004LoAcl02dLo20004dMO00@007ooOol005Aoo`00BWoo200047oo00<007ooOol00goo00@007oo
Oomoo`L000E7?`030017?dLo01A7?`030017?dLo01A7?`030017?dLo00U7?`L000E7?`030017?dLo
01A7?`030017?dLo01E7?`030017?dLo00U7?`L000E7?`030017?dLo01A7?`030017?dLo01A7?`03
0017?dLo00U7?`L000E7?`030017?dLo01A7?`030017?dLo01A7?`030017?dLo00Y7?`L000A7?`03
0017?dLo01A7?`030017?dLo01E7?`030017?dLo00Y7?`L000=7?`030017?dLo01E7?`030017?dLo
01A7?`030017?dLo00Y7?`L000=7?`030017?dLo01E7?`030017?dLo01A7?`030017?dLo00Y7?`L0
00A7?`030017?dLo01A7?`030017?dLo01E7?`030017?dLo00Y7?`L000=7?`030017?dLo01E7?`03
0017?dLo01A7?`030017?dLo00=7?`030017?dLo00A7?`L000A7?`030017GdMO01E7G`04001oogoo
001COol004Yoo`8000Aoo`80011oo`03001oogoo00L000e7?`030017?dLo01A7?`030017?dLo01A7
?`040017?dLoAcl7000=Acl00`00Acm7?`0DAcl00`00Acm7?`0EAcl01000Acm7?dLo1`003DLo00<0
04LoAcl054Lo00<004LoAcl054Lo00@004LoAcm7?`L000e7?`030017?dLo01A7?`030017?dLo01A7
?`030017?dLo0097?`L000a7?`030017?dLo01A7?`030017?dLo01E7?`030017?dLo0097?`L000]7
?`030017?dLo01E7?`030017?dLo01A7?`030017?dLo0097?`L000]7?`030017?dLo01E7?`030017
?dLo01A7?`030017?dLo0097?`L000a7?`030017?dLo01A7?`030017?dLo01E7?`030017?dLo0097
?`L000]7?`030017?dLo01A7?`030017?dLo01E7?`030017?dLo0097?`L000a7?`030017GdMO01A7
G`04001oogoo001COol004Uoo`8000Ioo`8000moo`<001E7?`8001E7?`030017?dLo0157?`H001E7
?`030017?dLo01A7?`030017?dLo0197?`H001E7?`030017?dLo01A7?`030017?dLo0157?`H001E7
?`030017?dLo01A7?`030017?dLo0157?`L001A7?`030017?dLo01A7?`030017?dLo0197?`L001=7
?`030017?dLo01A7?`030017?dLo0197?`L001=7?`030017?dLo01A7?`030017?dLo0197?`L001A7
?`030017?dLo01=7?`030017?dLo0197?`P001=7?`030017?dLo01A7?`030017?dLo0157?`T00197
?`030017GdMO01A7G`05001oogooOol0001BOol004Uoo`8000Ioo`8000moo`03001oo`0001M7?`03
0017?dLo01=7?`030017?dLo00U7?`L000E7?`030017?dLo01A7?`8001E7?`030017?dLo00Y7?`L0
00E7?`030017?dLo01A7?`030017?dLo01A7?`030017?dLo00U7?`L000E7?`030017?dLo01A7?`03
0017?dLo01A7?`030017?dLo00U7?`L000A7?`030017?dLo01E7?`030017?dLo01A7?`030017?dLo
00Y7?`L000=7?`030017?dLo01E7?`030017?dLo01A7?`030017?dLo00Y7?`L000=7?`030017?dLo
01E7?`030017?dLo01A7?`030017?dLo00Y7?`L000=7?`030017?dLo01E7?`030017?dLo01A7?`03
0017?dLo00Y7?`L000A7?`030017?dLo01A7?`030017?dLo01A7?`030017?dLo00Y7?`L000A7?`05
0017?dLoAcl0000CAcl00`00Aem7G`0DAel01000Oomoo`00DWoo0018Ool20008Ool2000>Ool01000
Oomoo`005dLo0P0054Lo00@004LoAcm7?`L000e7?`030017?dLo01E7?`030017?dLo01=7?`030017
?dLo0097?`L000e7?`030017?dLo01A7?`030017?dLo01A7?`040017?dLoAcl7000=Acl00`00Acm7
?`0DAcl00`00Acm7?`0DAcl01000Acm7?dLo1`0034Lo00<004LoAcl05DLo00<004LoAcl054Lo00<0
04LoAcl00TLo1`002dLo00<004LoAcl05DLo00<004LoAcl054Lo00<004LoAcl00TLo1`002dLo00<0
04LoAcl05DLo00<004LoAcl054Lo00<004LoAcl00TLo1`002dLo00<004LoAcl05DLo00<004LoAcl0
54Lo00<004LoAcl00TLo1`0034Lo00<004LoAcl054Lo00<004LoAcl054Lo00<004LoAcl00TLo1`00
34Lo00@004LoAcl001=7?`030017GdMO01A7G`05001oogooOol0001AOol004Qoo`8000Qoo`8000eo
o`03001oogoo009oo`8001M7?`030017?dLo00e7?`P001E7?`8001I7?`030017?dLo00i7?`T001E7
?`030017?dLo01A7?`030017?dLo00m7?`P001E7?`030017?dLo01A7?`030017?dLo00m7?`P001A7
?`030017?dLo01E7?`030017?dLo00m7?`T001=7?`030017?dLo01E7?`030017?dLo00m7?`T001=7
?`030017?dLo01E7?`030017?dLo00m7?`T001=7?`030017?dLo01E7?`030017?dLo0157?`L001A7
?`030017?dLo01A7?`030017?dLo0157?`L001A7?`040017?dLo000CAcl00`00Aem7G`0?Ael60002
Ool00`00Oomoo`1?Ool004Qoo`8000Qoo`8000eoo`03001oogoo00Aoo`030017?dLo01E7?`030017
?dLo00=7?`T000M7?`030017?dLo01E7?`030017?dLo01A7?`030017?dLo00=7?`X000M7?`030017
?dLo01E7?`030017?dLo01A7?`030017?dLo00=7?`/000M7?`030017?dLo01A7?`030017?dLo01A7
?`030017?dLo00=7?`/000I7?`030017?dLo01A7?`030017?dLo01E7?`030017?dLo00=7?`/000E7
?`030017?dLo01E7?`030017?dLo01E7?`030017?dLo00=7?`/000E7?`030017?dLo01E7?`030017
?dLo01E7?`030017?dLo00=7?`/000E7?`030017?dLo01E7?`030017?dLo01A7?`030017?dLo00Y7
?`L000=7?`030017?dLo01E7?`030017?dLo01A7?`030017?dLo00Y7?`L000=7?`030017?dLo01E7
?`040017?dLo000CAcl00`00Aem7G`04Ael;0005Ael01@00Oomoogoo0000D7oo0018Ool20008Ool2
000=Ool00`00Oomoo`05Ool2000CAcl8000AAcl00`00Acm7?`0EAcl2000BAcl8000BAcl00`00Acm7
?`0EAcl00`00Acm7?`0AAcl8000CAcl00`00Acm7?`0DAcl00`00Acm7?`0AAcl8000BAcl00`00Acm7
?`0DAcl00`00Acm7?`0BAcl8000AAcl00`00Acm7?`0EAcl00`00Acm7?`0BAcl8000AAcl00`00Acm7
?`0EAcl00`00Acm7?`0BAcl8000AAcl00`00Acm7?`0DAcl00`00Acm7?`0EAcl00`00Acm7?`02Acl7
000;Acl00`00Acm7?`0EAcl00`00Acm7?`0DAcl00`00Acm7?`02Acl7000;Acl00`00Acm7?`0EAcl0
0`00Acl0000AAcl9000AAel01000Oomoo`00D7oo0018Ool20008Ool2000=Ool00`00Oomoo`07Ool0
0`00Acm7?`09Acl70005Acl00`00Acm7?`0BAcl2000GAcl00`00Acm7?`08Acl70005Acl00`00Acm7
?`0CAcl00`00Acm7?`0EAcl00`00Acm7?`09Acl70005Acl00`00Acm7?`0DAcl00`00Acm7?`0DAcl0
0`00Acm7?`09Acl70005Acl00`00Acm7?`0CAcl00`00Acm7?`0DAcl00`00Acm7?`0:Acl70004Acl0
0`00Acm7?`0CAcl00`00Acm7?`0EAcl00`00Acm7?`0:Acl70003Acl00`00Acm7?`0DAcl00`00Acm7
?`0EAcl00`00Acm7?`0:Acl70003Acl00`00Acm7?`0DAcl00`00Acm7?`0DAcl00`00Acm7?`0@Acl9
000CAcl00`00Acm7?`0DAcl00`00Acm7?`0@Acl9000CAcl00`00Acm7?`0DAcl00`00Acl0000:Acl7
0003Bel00`00Aem7G`0DAel01@00Oomoogoo0000Cgoo0018Ool20008Ool2000=Ool00`00Oomoo`08
Ool01000Acm7?dLo1`003DLo00<004LoAcl04dLo00<004LoAcl05DLo00@004LoAcm7?`H000e7?`03
0017?dLo01=7?`8001I7?`040017?dLoAcl7000=Acl00`00Acm7?`0DAcl00`00Acm7?`0DAcl01000
Acm7?dLo1`003DLo00<004LoAcl04dLo00<004LoAcl054Lo00<004LoAcl00TLo1`0034Lo00<004Lo
Acl04dLo00<004LoAcl05DLo00<004LoAcl00TLo1`002dLo00<004LoAcl054Lo00<004LoAcl05DLo
00<004LoAcl00TLo1`002dLo00<004LoAcl054Lo00<004LoAcl054Lo00<004LoAcl014Lo2`001DLo
00<004LoAcl05DLo00<004LoAcl054Lo00<004LoAcl014Lo2`001DLo00<004LoAcl054Lo00<004Lo
Acl05DLo0P000dLo1`002d]O00<004MOAel054MO00@007ooOol004moo`00B7oo0P0027oo0P003Goo
00<007ooOol02Goo0`005DLo00<004LoAcl04dLo0P004dLo1P0054Lo00<004LoAcl054Lo00<004Lo
Acl04DLo1P005DLo00<004LoAcl054Lo00<004LoAcl04DLo1P005DLo00<004LoAcl04dLo00<004Lo
Acl04DLo1`0054Lo00<004LoAcl04dLo00<004LoAcl04TLo1`004dLo00<004LoAcl054Lo00<004Lo
Acl04TLo1`004dLo00<004LoAcl04dLo00<004LoAcl04TLo2@004DLo00<004LoAcl054Lo00<004Lo
Acl04TLo2@004DLo00<004LoAcl054Lo00<004LoAcl04DLo20004T]O00<004MOAel054MO00D007oo
Oomoo`0004ioo`00B7oo0P0027oo0P003Goo00<007ooOol02goo00<004LoAcl054Lo0P005DLo00<0
04LoAcl02DLo1`001DLo00<004LoAcl04dLo0P005DLo00<004LoAcl02DLo1`001DLo00<004LoAcl0
54Lo0P005DLo00<004LoAcl02DLo1`001DLo00<004LoAcl054Lo00<004LoAcl04dLo00<004LoAcl0
2DLo1`001DLo00<004LoAcl054Lo00<004LoAcl04dLo00<004LoAcl02TLo1`000dLo00<004LoAcl0
5DLo00<004LoAcl054Lo00<004LoAcl02TLo1`000dLo00<004LoAcl054Lo00<004LoAcl054Lo00<0
04LoAcl02TLo1`000dLo00<004LoAcl05DLo00<004LoAcl054Lo00<004LoAcl02TLo1`000dLo00<0
04LoAcl05DLo00<004LoAcl04dLo00<004LoAcl02TLo1`0014/o00<004]OBel054]O00<004MOAel0
54MO00@007ooOol004ioo`00BGoo0P001Woo0P003Woo00<007ooOol037oo00<004LoAcl05DLo00<0
04LoAcl04dLo00@004LoAcm7?`L000e7?`030017?dLo01A7?`030017?dLo01=7?`040017?dLoAcl7
000=Acl00`00Acm7?`0EAcl00`00Acm7?`0CAcl01000Acm7?dLo1`003DLo00<004LoAcl054Lo00<0
04LoAcl04dLo00@004LoAcm7?`L000e7?`030017?dLo01A7?`030017?dLo01=7?`030017?dLo0097
?`L000]7?`030017?dLo01E7?`030017?dLo01A7?`030017?dLo0097?`L000]7?`030017?dLo01A7
?`030017?dLo01A7?`030017?dLo0097?`L000]7?`030017?dLo01A7?`030017?dLo01E7?`030017
?dLo0097?`L000]7?`030017?dLo01A7?`030017?dLo01A7?`030017?dLo0097?`L000];?`8001I;
G`030017GdMO01=7G`05001oogooOol0001=Ool004Uoo`8000Ioo`8000ioo`@000aoo`8001I7?`03
0017?dLo00i7?`P001E7?`030017?dLo01A7?`030017?dLo00i7?`P001E7?`030017?dLo01E7?`03
0017?dLo00i7?`P001E7?`030017?dLo01A7?`030017?dLo00i7?`P001E7?`030017?dLo01A7?`03
0017?dLo00i7?`T001=7?`030017?dLo01E7?`030017?dLo00m7?`T001=7?`030017?dLo01A7?`03
0017?dLo0157?`L001=7?`030017?dLo01A7?`030017?dLo0157?`P00197?`030017?dLo01E7?`03
0017?dLo0157?`L0019;?`8001I;G`030017GdMO0157G`@0009oo`03001oogoo04]oo`00BWoo0P00
17oo0P003goo00<007ooOol03goo00<004LoAcl054Lo00<004LoAcl00dLo2P001dLo00<004LoAcl0
54Lo0P005DLo00<004LoAcl00dLo2P001dLo00<004LoAcl054Lo0P005TLo00<004LoAcl00dLo2P00
1dLo00<004LoAcl054Lo00<004LoAcl054Lo00<004LoAcl00dLo2P001TLo00<004LoAcl05DLo00<0
04LoAcl054Lo00<004LoAcl00dLo2P001TLo00<004LoAcl054Lo00<004LoAcl05DLo00<004LoAcl0
0dLo2`001DLo00<004LoAcl05DLo00<004LoAcl04dLo00<004LoAcl02TLo1`000dLo00<004LoAcl0
5DLo00<004LoAcl04dLo00<004LoAcl02TLo1`0014/o00<004LoAcl054Lo00<004LoAcl054Lo00<0
04LoAcl02TLo1`000d/o00<004/oBcl04d/o00<004/o00005T]O00<004MOAel02DMO1`000d]O00D0
07ooOomoo`0004aoo`00BWoo20003goo00<007ooOol047oo0P004TLo20004TLo00<004LoAcl05DLo
00<004LoAcl044Lo20004TLo00<004LoAcl05DLo00<004LoAcl04DLo20004TLo00<004LoAcl054Lo
00<004LoAcl04DLo20004DLo00<004LoAcl05DLo00<004LoAcl04DLo20004DLo00<004LoAcl054Lo
00<004LoAcl04TLo20004DLo00<004LoAcl054Lo00<004LoAcl054Lo00<004LoAcl00TLo1`002dLo
00<004LoAcl054Lo00<004LoAcl054Lo00<004LoAcl00TLo1`0034/o00<004LoAcl054Lo00<004Lo
Acl054Lo00<004LoAcl00TLo1`002d/o00<004/oBcl04T/o00<004/o00005T]O00<004MOAel00TMO
1`002d]O00@007ooOol004aoo`00C7oo10004Goo00<007ooOol04Woo00<004LoAcl024Lo1`001DLo
00<004LoAcl04dLo00<004LoAcl05DLo00<004LoAcl024Lo1`001DLo00<004LoAcl04dLo00<004Lo
Acl05DLo00<004LoAcl02DLo1`001DLo00<004LoAcl04dLo00<004LoAcl054Lo00<004LoAcl02DLo
1`0014Lo00<004LoAcl04dLo00<004LoAcl05DLo00<004LoAcl02DLo1`0014Lo00<004LoAcl04dLo
00<004LoAcl054Lo00<004LoAcl02TLo1`000dLo00<004LoAcl054Lo00<004LoAcl054Lo00<004Lo
Acl03dLo2@004dLo00<004LoAcl054Lo00<004LoAcl03dLo2@0054/o00<004LoAcl04dLo00<004Lo
Acl04DLo20004d/o00<004/oBcl04D/o00@004/oBcl0015;G`T001=;G`04001oogoo001;Ool0065o
o`03001oogoo01=oo`040017?dLoAcl6000=Acl00`00Acm7?`0CAcl2000FAcl01000Acm7?dLo1P00
3DLo00<004LoAcl04dLo0P005TLo00@004LoAcm7?`L000e7?`030017?dLo01=7?`030017?dLo01A7
?`040017?dLoAcl7000<Acl00`00Acm7?`0CAcl00`00Acm7?`0EAcl01000Acm7?dLo1`0034Lo00<0
04LoAcl04dLo00<004LoAcl054Lo00<004LoAcl00TLo1`002dLo00<004LoAcl054Lo00<004LoAcl0
54Lo00<004LoAcl00dLo2`001DLo00<004LoAcl05DLo00<004LoAcl054Lo00<004LoAcl00dLo2`00
1D/o00<004/oBcl05D/o00<004LoAcl054Lo00<004LoAcl02DLo1`0014/o00<004/oBcl054/o00<0
04/oBcl04D/o00@004/oBcl000I;G`/000E;G`03001;Gd]O01A;G`04001oogoo001;Ool0065oo`03
001oogoo01Aoo`<001A7?`8001E7?`030017?dLo0157?`H001A7?`030017?dLo01A7?`030017?dLo
0157?`H001E7?`030017?dLo01=7?`030017?dLo0157?`H001A7?`030017?dLo01=7?`030017?dLo
0197?`H001A7?`030017?dLo01=7?`030017?dLo0157?`L001=7?`030017?dLo01A7?`030017?dLo
0157?`P00157?`030017?dLo01A7?`030017?dLo0197?`P0015;?`03001;?d/o01E;?`030017?dLo
01=7?`030017?dLo0097?`L000a;?`03001;?d/o01A;?`03001;?d/o011;?`X0015;G`03001;Gd]O
01A;G`04001oogoo001:Ool0065oo`03001oogoo01Ioo`030017?dLo01A7?`030017?dLo01=7?`03
0017?dLo00U7?`L000E7?`030017?dLo01=7?`8001E7?`030017?dLo00U7?`L000E7?`030017?dLo
01A7?`030017?dLo01=7?`030017?dLo00U7?`L000A7?`030017?dLo01A7?`030017?dLo01=7?`03
0017?dLo00Y7?`L000=7?`030017?dLo01E7?`030017?dLo01=7?`030017?dLo00U7?`L000A7?`03
0017?dLo01A7?`030017?dLo01A7?`030017?dLo00U7?`L000=7?`030017?dLo01A7?`030017?dLo
01A7?`030017?dLo00Y7?`L000=;?`03001;?d/o01A;?`03001;?d/o01A;?`030017?dLo00m7?`T0
01A;?`03001;?d/o01=;?`03001;?d/o00Y;?`L000=;?`03001;Gd]O01A;G`03001;Gd]O01A;G`05
001oogooOol00019Ool0061oo`03001oogoo01Qoo`030017?dLo01A7?`8001A7?`040017?dLoAcl7
000=Acl00`00Acm7?`0DAcl00`00Acm7?`0CAcl01000Acm7?dLo1`003DLo00<004LoAcl054Lo00<0
04LoAcl04dLo00@004LoAcm7?`L000a7?`030017?dLo01A7?`030017?dLo01=7?`030017?dLo0097
?`L000]7?`030017?dLo01E7?`030017?dLo01=7?`040017?dLoAcl7000<Acl00`00Acm7?`0DAcl0
0`00Acm7?`0DAcl01000Acm7?dLo1`002dLo00<004LoAcl054Lo00<004LoAcl054Lo00<004LoAcl0
0TLo1`002d/o00<004/oBcl054/o00<004/oBcl054/o00<004LoAcl00dLo2`001D/o00<004/oBcl0
5D/o00<004/oBcl054/o00<004/oBcl00T/o1`001T/o00<004/oBcl00T/o00<004]OBel054]O00<0
04]OBel054]O00@007ooOol004Uoo`00H7oo00<007ooOol06Goo00<004LoAcl05DLo00<004LoAcl0
3DLo20005DLo00<004LoAcl054Lo00<004LoAcl03TLo20005DLo00<004LoAcl054Lo00<004LoAcl0
3TLo200054Lo00<004LoAcl054Lo00<004LoAcl03TLo2@004dLo00<004LoAcl05DLo00<004LoAcl0
3TLo200054Lo00<004LoAcl054Lo00<004LoAcl03dLo20004dLo00<004LoAcl054Lo00<004LoAcl0
4DLo1`004d/o00<004/oBcl04d/o00<004/oBcl04T/o20004D/o00<004/oBcl05D/o00<004/oBcl0
4D/o1`003D/o00<004/oBcl00T/o00<004]OBel054]O00<004]OBel04D]O1@000Woo00<007ooOol0
AWoo001POol00`00Oomoo`0JOol2000FAcl00`00Acm7?`03Acl90007Acl00`00Acm7?`0DAcl2000E
Acl00`00Acm7?`03Acl:0007Acl00`00Acm7?`0DAcl00`00Acm7?`0DAcl00`00Acm7?`03Acl:0007
Acl00`00Acm7?`0CAcl00`00Acm7?`0DAcl00`00Acm7?`03Acl:0007Acl00`00Acm7?`0CAcl00`00
Acm7?`0EAcl00`00Acm7?`03Acl:0005Acl00`00Acm7?`0EAcl00`00Acm7?`0DAcl00`00Acm7?`03
Acl;0005Acl00`00Acm7?`0DAcl00`00Acm7?`0DAcl00`00Acm7?`09Acl70003Bcl00`00Bcm;?`0D
Bcl00`00Bcm;?`0DBcl00`00Bcm;?`0:Bcl70003Bcl00`00Bcm;?`0DBcl00`00Bcm;?`0DBcl00`00
Bcm;?`0:Bcl70003Bcl00`00Bcm;?`0>Bcl00`00Bcm;?`03Bcl00`00Bem;G`0DBel00`00Bem;G`09
Bel70004Bel01000Oomoo`00B7oo001POol00`00Oomoo`0LOol00`00Acm7?`0AAcl8000AAcl2000F
Acl00`00Acm7?`0@Acl8000BAcl00`00Acm7?`0DAcl00`00Acm7?`0AAcl8000BAcl00`00Acm7?`0C
Acl00`00Acm7?`0AAcl8000BAcl00`00Acm7?`0CAcl00`00Acm7?`0BAcl8000@Acl00`00Acm7?`0E
Acl00`00Acm7?`0AAcl8000AAcl00`00Acm7?`0DAcl00`00Acm7?`0DAcl01000Acm7?dLo1`002d/o
00<004/oBcl054/o00<004/oBcl054/o00<004/oBcl00T/o1`002d/o00<004/oBcl054/o00<004/o
Bcl054/o00<004/oBcl00T/o1`002d/o00<004/oBcl03D/o00<004/oBcl014/o00<004]OBel04d]O
00<004]OBel00T]O1`0034]O00@007ooOol004Moo`00H7oo1@006goo00<004LoAcl02DLo1`001DLo
00<004LoAcl04dLo00<004LoAcl054Lo00<004LoAcl024Lo1`001DLo00<004LoAcl04dLo0P005DLo
00<004LoAcl02DLo1`001DLo00<004LoAcl04dLo00<004LoAcl04dLo00<004LoAcl02DLo1`0014Lo
00<004LoAcl054Lo00<004LoAcl04dLo00<004LoAcl02TLo1`000dLo00<004LoAcl04dLo00<004Lo
Acl05DLo00<004LoAcl02DLo1`000dLo00<004LoAcl054Lo00<004LoAcl054Lo00<004LoAcl03dLo
20004d/o00<004/oBcl054/o00<004/oBcl04D/o1`004d/o00<004/oBcl04d/o00<004/oBcl04T/o
1`004T/o00<004/oBcl03D/o00<004/oBcl014/o00<004]OBel04D]O1`004d]O00@007ooOol004Mo
o`00H7oo00<007ooOol07Woo00@004LoAcm7?`L000e7?`030017?dLo01=7?`030017?dLo01A7?`04
0017?dLoAcl6000=Acl00`00Acm7?`0DAcl00`00Acm7?`0CAcl01000Acm7?dLo1`003DLo00<004Lo
Acl04dLo00<004LoAcl04dLo00@004LoAcm7?`L000a7?`030017?dLo01A7?`030017?dLo01=7?`03
0017?dLo0097?`L000]7?`030017?dLo01=7?`030017?dLo01E7?`040017?dLoAcl7000;Acl00`00
Acm7?`0DAcl00`00Acm7?`0DAcl00`00Acm7?`03Acl;0005Bcl00`00Bcm;?`0DBcl00`00Bcm;?`0C
Bcl00`00Bcm;?`0:Bcl70003Bcl00`00Bcm;?`0DBcl00`00Bcm;?`0DBcl00`00Bcm;?`0:Bcl70003
Bcl00`00Bcm;?`0DBcl00`00Bcm;?`0<Bcl00`00Bcm;?`05Bcl00`00Bem;G`09Bel70003Bel00`00
Bem;G`0EBel01000Oomoo`00AWoo001POol00`00Oomoo`0OOol3000EAcl00`00Acm7?`0CAcl2000@
Acl8000DAcl00`00Acm7?`0DAcl00`00Acm7?`0>Acl8000EAcl00`00Acm7?`0CAcl00`00Acm7?`0>
Acl8000DAcl00`00Acm7?`0DAcl00`00Acm7?`0>Acl9000CAcl00`00Acm7?`0CAcl00`00Acm7?`0B
Acl6000CAcl00`00Acm7?`0CAcl00`00Acm7?`0BAcl8000ABcl00`00Bcm;?`0DBcl00`00Bcm;?`0C
Bcl00`00Bcm;?`02Bcl7000;Bcl00`00Bcm;?`0DBcl00`00Bcm;?`0DBcl00`00Bcm;?`02Bcl7000;
Bcl00`00Bcm;?`0DBcl00`00Bcm;?`0;Bcl00`00Bcm;?`05Bcl00`00Bem;G`02Bel7000;Bel00`00
Bem;G`0EBel00`00Ool00016Ool0061oo`03001oogoo025oo`030017?dLo01A7?`8001E7?`030017
?dLo00=7?`X000M7?`030017?dLo01=7?`8001E7?`030017?dLo00=7?`X000M7?`030017?dLo01A7
?`030017?dLo01=7?`030017?dLo00=7?`X000M7?`030017?dLo01=7?`030017?dLo01A7?`030017
?dLo00=7?`X000I7?`030017?dLo01A7?`030017?dLo01=7?`030017?dLo00Y7?`L000=7?`030017
?dLo01A7?`030017?dLo01=7?`030017?dLo00Y7?`L000=;?`03001;?d/o01A;?`03001;?d/o01A;
?`03001;?d/o00i;?`T001=;?`03001;?d/o01A;?`03001;?d/o015;?`L0019;?`03001;?d/o01A;
?`03001;?d/o00];?`03001;?d/o00=;?`L0019;G`03001;Gd]O01E;G`04001oogoo0015Ool0061o
o`03001oogoo029oo`8001I7?`030017?dLo0117?`P00197?`030017?dLo01A7?`030017?dLo0117
?`P00197?`030017?dLo01A7?`030017?dLo0117?`P00197?`030017?dLo01=7?`030017?dLo0157
?`P00157?`030017?dLo01A7?`030017?dLo01=7?`030017?dLo0097?`L000]7?`030017?dLo01A7
?`030017?dLo01=7?`030017?dLo0097?`L000];?`03001;?d/o01A;?`03001;?d/o01A;?`03001;
?d/o00=;?`X000E;?`03001;?d/o01E;?`03001;?d/o01=;?`03001;?d/o00Y;?`L000=;?`03001;
?d/o01A;?`03001;?d/o01A;?`03001;?d/o00U;?`L000=??`03001;Gd]O01A;G`03001;Gd]O019;
G`@00003Ool007oo04Aoo`00H7oo00<007ooOol097oo0P005DLo00<004LoAcl024Lo1`001DLo00<0
04LoAcl04dLo0P005DLo00<004LoAcl024Lo1`001DLo00<004LoAcl04dLo0P005DLo00<004LoAcl0
24Lo1`001DLo00<004LoAcl04dLo0P0054Lo00<004LoAcl02DLo1`0014Lo00<004LoAcl04dLo00<0
04LoAcl054Lo00<004LoAcl03TLo2@004dLo00<004LoAcl054Lo00<004LoAcl03TLo2@004d/o00<0
04/oBcl04d/o00<004/oBcl04T/o200044/o00<004/oBcl054/o00<004/oBcl054/o00<004/oBcl0
0T/o1`002d/o00<004/oBcl054/o00<004/oBcl04d/o00<004/oBcl00T/o1`0000=??`00Ccl024lo
00<004]OBel04d]O00<004]OBel03D]O1@000dmO00@007ooOol004Aoo`00H7oo00<007ooOol09Woo
00<004LoAcl04dLo00@004LoAcm7?`H000e7?`030017?dLo01A7?`030017?dLo01=7?`040017?dLo
Acl6000=Acl00`00Acm7?`0DAcl00`00Acm7?`0CAcl01000Acm7?dLo1P003DLo00<004LoAcl054Lo
00<004LoAcl04TLo00@004LoAcm7?`L000a7?`030017?dLo01=7?`030017?dLo01A7?`030017?dLo
00=7?`X000M7?`030017?dLo01=7?`030017?dLo01A7?`030017?dLo00=7?`X000E;?`03001;?d/o
01E;?`03001;?d/o01=;?`03001;?d/o00Y;?`L000=;?`03001;?d/o01=;?`03001;?d/o01A;?`03
001;?d/o00m;?`T0019;?`03001;?d/o01A;?`03001;?d/o015;?`L000Q??`03001??dlo00M??`03
001;Gd]O01A;G`03001;Gd]O00I;G`H000U?G`03001oo`0004Aoo`00H7oo00<007ooOol09goo0P00
3dLo200054Lo00<004LoAcl054Lo00<004LoAcl03TLo200054Lo00<004LoAcl054Lo00<004LoAcl0
3TLo200054Lo00<004LoAcl054Lo00<004LoAcl03DLo200054Lo00<004LoAcl04dLo00<004LoAcl0
4DLo20004TLo00<004LoAcl04dLo00<004LoAcl04DLo200044/o00<004/oBcl054/o00<004/oBcl0
54/o00<004/oBcl00T/o1`002d/o00<004/oBcl04d/o00<004/oBcl054/o00<004/oBcl00d/o2`00
1D/o00<004/oBcl054/o00<004/oBcl054/o00<004/oBcl02D/o1`000dlo00<004loCcl02Dlo00<0
04loCcl024lo00<004]OBel04d]O00@004]OBem;G`D000m?G`04001oogoo0013Ool0061oo`03001o
ogoo02Uoo`030017?dLo00=7?`T000M7?`030017?dLo01=7?`8001E7?`030017?dLo00=7?`X000M7
?`030017?dLo01=7?`8001E7?`030017?dLo00=7?`X000M7?`030017?dLo01=7?`030017?dLo01A7
?`030017?dLo00=7?`T000M7?`030017?dLo01=7?`030017?dLo01=7?`030017?dLo00U7?`L000A7
?`030017?dLo01A7?`030017?dLo01=7?`030017?dLo00U7?`L000=;?`03001;?d/o01=;?`03001;
?d/o01A;?`03001;?d/o00m;?`T0019;?`03001;?d/o01=;?`03001;?d/o019;?`P0015;?`03001;
?d/o01A;?`03001;?d/o01=;?`03001;?d/o009;?`L000]??`03001??dlo00U??`03001??dlo00M?
?`03001;Gd]O015;G`H001E?G`03001oo`0004=oo`00H7oo00<007ooOol0:Woo1@004DLo0P005DLo
00<004LoAcl044Lo20004TLo00<004LoAcl054Lo00<004LoAcl044Lo20004TLo00<004LoAcl04dLo
00<004LoAcl04DLo20004DLo00<004LoAcl04dLo00<004LoAcl04dLo00@004LoAcm7?`L000a7?`03
0017?dLo01A7?`030017?dLo01=7?`040017?dLoAcl7000;Bcl00`00Bcm;?`0CBcl00`00Bcm;?`0D
Bcl00`00Bcm;?`03Bcl;0005Bcl00`00Bcm;?`0DBcl00`00Bcm;?`0CBcl00`00Bcm;?`0:Bcl70003
Bcl00`00Bcm;?`0CBcl00`00Bcm;?`0DBcl00`00Bcm;?`0ABcl7000BCcl00`00Ccm??`09Ccl00`00
Ccm??`08Ccl00`00Bem;G`09Bel70003Cel00`00Cem?G`0ECel01000Oomoo`00@Woo001POol00`00
Oomoo`0/Ool00`00Acm7?`0CAcl00`00Acm7?`0CAcl00`00Acm7?`08Acl70005Acl00`00Acm7?`0C
Acl2000EAcl00`00Acm7?`08Acl70005Acl00`00Acm7?`0CAcl00`00Acm7?`0CAcl00`00Acm7?`09
Acl70004Acl00`00Acm7?`0CAcl00`00Acm7?`0CAcl00`00Acm7?`0>Acl8000DAcl00`00Acm7?`0D
Acl00`00Acm7?`0>Acl8000CBcl00`00Bcm;?`0CBcl00`00Bcm;?`0ABcl8000ABcl00`00Bcm;?`0D
Bcl00`00Bcm;?`0CBcl00`00Bcm;?`02Bcl7000;Bcl00`00Bcm;?`0CBcl00`00Bcm;?`0DBcl00`00
Bcm;?`09Bcl70003Ccl00`00Ccm??`0DCcl00`00Ccm??`08Ccl00`00Ccm??`08Ccl00`00Bem;G`02
Bel7000;Cel00`00Cem?G`0ECel00`00Ool00012Ool0061oo`04001oo`00000/Ool00`00Acm7?`0C
Acl00`00Acm7?`0CAcl01000Acm7?dLo1P003DLo00<004LoAcl054Lo00<004LoAcl04dLo00@004Lo
Acm7?`H000e7?`030017?dLo01=7?`030017?dLo01=7?`040017?dLoAcl7000<Acl00`00Acm7?`0C
Acl00`00Acm7?`0CAcl00`00Acm7?`03Acl:0007Acl00`00Acm7?`0CAcl00`00Acm7?`0DAcl00`00
Acm7?`03Acl:0005Acl00`00Bcm;?`0DBcl00`00Bcm;?`0CBcl00`00Bcm;?`09Bcl70003Bcl00`00
Bcm;?`0DBcl00`00Bcm;?`0CBcl00`00Bcm;?`0ABcl7000BBcl00`00Bcm;?`0DBcl00`00Bcm;?`0C
Bcl00`00Bcm;?`02Bcl7000;Ccl00`00Ccm??`0CCcl00`00Ccm??`08Ccl00`00Ccm??`06Ccl7000C
Cel00`00Cem?G`0DCel01000Oomoo`00@Goo001OOol3000_Ool00`00Acm7?`0CAcl2000?Acl8000D
Acl00`00Acm7?`0DAcl00`00Acm7?`0>Acl8000DAcl00`00Acm7?`0CAcl00`00Acm7?`0>Acl8000D
Acl00`00Acm7?`0CAcl00`00Acm7?`0@Acl8000BAcl00`00Acm7?`0CAcl00`00Acm7?`0AAcl8000@
Acl00`00Bcm;?`0DBcl00`00Bcm;?`0CBcl01000Bcm;?d/o1`002d/o00<004/oBcl054/o00<004/o
Bcl04d/o00<004/oBcl02D/o1`000d/o00<004/oBcl054/o00<004/oBcl04d/o00<004/oBcl04D/o
1`004Tlo00<004loCcl04dlo00<004loCcl024lo00@004loCcm??`D000=??`03001?GdmO01A?G`03
001?GdmO019?G`@00003Ool007oo041oo`00Ggoo00<007ooOol0<7oo0P005DLo00<004LoAcl00dLo
2@001dLo00<004LoAcl04dLo0P005DLo00<004LoAcl00dLo2P001dLo00<004LoAcl04dLo00<004Lo
Acl04dLo00<004LoAcl00dLo2P001dLo00<004LoAcl04dLo00<004LoAcl04dLo00<004LoAcl024Lo
1`0014Lo00<004LoAcl054Lo00<004LoAcl04dLo00<004LoAcl02DLo1`000dLo00<004LoAcl04dLo
00<004/oBcl054/o00<004/oBcl03T/o20004d/o00<004/oBcl04d/o00<004/oBcl04d/o00<004/o
Bcl00T/o1`002d/o00<004/oBcl054/o00<004/oBcl04d/o00<004/oBcl02D/o1`000dln00<004lo
Ccl054lo00<004loCcl04dlo00<004loCcl01Tlo1@002Dlo00<004mOCel054mO00<004mOCel034mO
1@000e=O00@007ooOol0041oo`00Ggoo00<007ooOol0<Woo00<004LoAcl044Lo20004DLo0P005DLo
00<004LoAcl044Lo20004TLo00<004LoAcl04dLo00<004LoAcl044Lo20004TLo00<004LoAcl04dLo
00<004LoAcl04dLo00@004LoAcm7?`H000a7?`030017?dLo01A7?`030017?dLo01=7?`040017?dLo
Acl7000;Acl00`00Acm7?`0CAcl00`00Bcm;?`0DBcl00`00Bcm;?`03Bcl:0005Bcl00`00Bcm;?`0D
Bcl00`00Bcm;?`0CBcl00`00Bcm;?`0>Bcl9000CBcl00`00Bcm;?`0CBcl00`00Bcm;?`0CBcl00`00
Bcm;?`02Bcl7000;Cch00`00Ccm??`0CCcl00`00Ccm??`0CCcl01000Ccm??dlo1@0000=??`00Ccl0
2dlo00<004mOCel054mO00<004mOCel01dmO1@002E=O00<007oo0000@7oo001OOol00`00Oomoo`0c
Ool00`00Acm7?`08Acl70005Acl00`00Acm7?`0CAcl00`00Acm7?`0CAcl00`00Acm7?`08Acl70005
Acl00`00Acm7?`0CAcl2000DAcl00`00Acm7?`08Acl70005Acl00`00Acm7?`0CAcl00`00Acm7?`0C
Acl00`00Acm7?`0>Acl8000CAcl00`00Acm7?`0DAcl00`00Acm7?`0>Acl8000CAcl00`00Acm7?`0C
Acl00`00Bcm;?`0ABcl8000@Bcl00`00Bcm;?`0DBcl00`00Bcm;?`0CBcl00`00Bcm;?`03Bcl:0005
Bcl00`00Bcm;?`0DBcl00`00Bcm;?`0DBcl00`00Bcm;?`0>Bcl9000BCch00`00Ccm??`0CCcl00`00
Ccm??`0ACcl60006Ccl00`00Ccm??`0;Ccl00`00Cem?G`0DCel01000Cem?GdmO1@003U=O00@007oo
Ool003moo`00Ggoo00<007ooOol0=7oo00@004LoAcm7?`H000e7?`030017?dLo01=7?`030017?dLo
01=7?`040017?dLoAcl6000=Acl00`00Acm7?`0DAcl00`00Acm7?`0BAcl01000Acm7?dLo1P003DLo
00<004LoAcl04dLo00<004LoAcl04dLo00<004LoAcl00dLo2P001TLo00<004LoAcl04dLo00<004Lo
Acl054Lo00<004LoAcl00dLo2P001DLo00<004LoAcl054Lo00<004LoAcl04dLo00<004/oBcl02D/o
1`000d/o00<004/oBcl04d/o00<004/oBcl04d/o00<004/oBcl04D/o200044/o00<004/oBcl054/o
00<004/oBcl04d/o00<004/oBcl00d/o2`001Dln00<004lnCch054ln00<004loCcl04dlo00<004lo
Ccl02Dlo1`000e<n00<004loCcl01Tlo00<004loCcl034lo00<004mOCel04DmO1P0055=O00<007oo
0000?goo001OOol00`00Oomoo`0eOol3000DAcl00`00Acm7?`0CAcl2000?Acl8000DAcl00`00Acm7
?`0DAcl00`00Acm7?`0=Acl8000DAcl00`00Acm7?`0CAcl00`00Acm7?`0>Acl:000AAcl00`00Acm7
?`0CAcl00`00Acm7?`0AAcl8000@Acl00`00Acm7?`0DAcl00`00Acm7?`0CAcl01000Bcm;?d/o1`00
2d/o00<004/oBcl04d/o00<004/oBcl04d/o00<004/oBcl02D/o1`000d/o00<004/oBcl04d/o00<0
04/oBcl054/o00<004/oBcl044/o20004Dln00<004lnCch054ln00<004loCcl04Tlo00<004loCcl0
0Tlo1`002e<n00<004loCcl01Dlo00<004loCcl034lo00<004mOCel034mO1@000e=O00<005=ODel0
55=O00@007ooOol003ioo`00Ggoo00<007ooOol0=goo00<004LoAcl04dLo0P005DLo00<004LoAcl0
0dLo2@001dLo00<004LoAcl04dLo00<004LoAcl054Lo00<004LoAcl00dLo2@001dLo00<004LoAcl0
4dLo00<004LoAcl04dLo00<004LoAcl00dLo2P001TLo00<004LoAcl04dLo00<004LoAcl04dLo00<0
04LoAcl02DLo1`000dLo00<004LoAcl04dLo00<004LoAcl054Lo00<004LoAcl03TLo20004d/o00<0
04/oBcl04d/o00<004/oBcl04d/o00@004/oBcm;?`L000];?`03001;?d/o019;?`03001;?d/o01A;
?`03001;?d/o00U;?`L000=?7P03001??Tln01=??P03001??Tln01A??P03001??dlo011??`L0019C
?P03001??dlo00E??`03001??dlo00e??`03001?GdmO00I?G`D000UCG`03001CGe=O01=CG`04001o
ogoo000nOol005moo`03001oogoo03Qoo`8001E7?`030017?dLo0117?`P00157?`030017?dLo01=7
?`030017?dLo0157?`P00157?`030017?dLo01=7?`030017?dLo0117?`P00157?`030017?dLo01=7
?`030017?dLo01=7?`040017?dLoAcl7000;Acl00`00Acm7?`0CAcl00`00Acm7?`0DAcl00`00Acm7
?`03Acl:0005Bcl00`00Bcm;?`0DBcl00`00Bcm;?`0CBcl00`00Bcm;?`0>Bcl8000CBcl00`00Bcm;
?`0BBcl00`00Bcm;?`0DBcl01000Bcm;?d/o1`002dlN00<004lnCch04dln00<004lnCch054ln00<0
04loCcl024lo1`000e<n00<005<nDch055<n00<004loCcl014lo00<004loCcl03Dlo00@004mOCem?
G`D000iCG`03001CGe=O019CG`<0009oo`03001oogoo03]oo`00Ggoo00<007ooOol0>Woo00<004Lo
Acl04dLo00<004LoAcl024Lo1`001DLo00<004LoAcl04TLo0P0054Lo00<004LoAcl02DLo1`001DLo
00<004LoAcl04TLo0P0054Lo00<004LoAcl024Lo1`001DLo00<004LoAcl04TLo00<004LoAcl04dLo
00<004LoAcl03TLo20004dLo00<004LoAcl04dLo00<004LoAcl04DLo200044/o00<004/oBcl054/o
00<004/oBcl04d/o00<004/oBcl00d/o2P001D/o00<004/oBcl04d/o00<004/oBcl04d/o00<004/o
Bcl04D/o1P004TlN00<004lnCch054ln00<004lnCch04dln00@004loCcm??`L000]C?P03001C?U<n
01AC?P03001??dlo00=??`03001??dlo00]??`H001ACG`03001CGe=O00eCG`@0009CO`05001oogoo
Ool0000lOol005moo`03001oogoo03]oo`030017?dLo01=7?`040017?dLoAcl6000=Acl00`00Acm7
?`0CAcl00`00Acm7?`0BAcl01000Acm7?dLo1`003DLo00<004LoAcl04dLo00<004LoAcl04TLo00@0
04LoAcm7?`H000e7?`030017?dLo0197?`030017?dLo01=7?`030017?dLo00=7?`X000M7?`030017
?dLo0197?`030017?dLo01=7?`030017?dLo00U7?`L000=;?`03001;?d/o01=;?`03001;?d/o01=;
?`03001;?d/o015;?`P0011;?`03001;?d/o01=;?`03001;?d/o019;?`03001;?d/o00Y;?`L000=?
7P03001?7TlN01=?7P03001??Tln01=??P03001??Tln015??PH0019C?P03001C?U<n01AC?P03001?
?dlo00=??`03001??dlo00I??`D000=C?P03001CGe=O01ACG`03001CGe=O00UCG`@000MCO`04001o
ogoo000lOol005moo`04001oo`00000kOol2000?Acl8000DAcl00`00Acm7?`0CAcl00`00Acm7?`0=
Acl8000EAcl00`00Acm7?`0CAcl00`00Acm7?`0=Acl8000DAcl00`00Acm7?`0BAcl00`00Acm7?`0@
Acl8000BAcl00`00Acm7?`0BAcl00`00Acm7?`0CAcl01000Acm7?dLo1`002d/o00<004/oBcl04d/o
00<004/oBcl04d/o00<004/oBcl02D/o1`000d/o00<004/oBcl04d/o00<004/oBcl04T/o00<004/o
Bcl04d/o00<004/oBcl00T/o1`002dlN00<004lNCah04TlN00<004lnCch054ln00<004lnCch02Dln
1`000e<N00<005<nDch04e<n00<005<nDch055<n00<004loCcl00Tlo00@004loCcm??`D000UC?P03
001CGe=O01ACG`03001CGe=O00ACG`@000]CO`05001oogooOol0000kOol005moo`8003moo`030017
?dLo00=7?`T000M7?`030017?dLo01=7?`030017?dLo01=7?`030017?dLo00=7?`T000M7?`030017
?dLo01A7?`030017?dLo01=7?`030017?dLo00=7?`T000M7?`030017?dLo01=7?`030017?dLo0197
?`030017?dLo00Q7?`L000A7?`030017?dLo01A7?`030017?dLo0197?`030017?dLo00i7?`P001=;
?`03001;?d/o01=;?`03001;?d/o01=;?`04001;?d/oBcl7000;Bcl00`00Bcm;?`0BBcl00`00Bcm;
?`0CBcl00`00Bcm;?`0@Bcl7000BCah00`00Cai?7P0CCah00`00Cci??P0CCch00`00Cci??P02Cch7
000;Dah00`00DciC?P0BDch00`00DciC?P0DDch01000Ccm??dlo1@003U<n00<005=ODel055=O00<0
05=ODel0100045=o00@007ooOol003]oo`00Ggoo00<007ooOol0?goo1@004DLo0P0054Lo00<004Lo
Acl044Lo20004DLo00<004LoAcl054Lo00<004LoAcl044Lo20004DLo00<004LoAcl04dLo00<004Lo
Acl04TLo00@004LoAcm7?`H000a7?`030017?dLo01A7?`030017?dLo0197?`030017?dLo00=7?`X0
00E;?`03001;?d/o01A;?`03001;?d/o01=;?`03001;?d/o00i;?`P001=;?`03001;?d/o019;?`03
001;?d/o01=;?`03001;?d/o00Q;?`L000=?7P03001?7TlN01A?7P03001?7TlN01=?7P03001??Tln
015??PH0019C7P03001C?U<n01=C?P03001C?U<n015C?PH00003Dch005<n015C?P03001CGe=O019C
G`@001ACO`05001oogooOol0000jOol005moo`03001oogoo045oo`030017?dLo01=7?`030017?dLo
0197?`030017?dLo00Q7?`L000E7?`030017?dLo0197?`8001E7?`030017?dLo00Q7?`L000A7?`03
0017?dLo01=7?`030017?dLo01=7?`030017?dLo00e7?`P001=7?`030017?dLo01A7?`030017?dLo
00e7?`X0011;?`03001;?d/o01A;?`03001;?d/o01=;?`03001;?d/o00=;?`X000E;7`03001;?d/o
01=;?`03001;?d/o01=;?`03001;?d/o019;?`04001;?d/oBcl7000;Cah00`00Cai?7P0CCah00`00
Cai?7P0CCah00`00Cci??P0<Cch50002Dah00`00DaiC7P0DDah00`00DciC?P0BDch00`00DciC?P0<
Dch50003Dch01@00DciC?U<n00004U<n00<005=ODel03U=O10000UMN00<005=oDgl055=o00@007oo
Ool003Yoo`00Ggoo00<007ooOol0@Woo0P0054Lo00<004LoAcl04TLo00@004LoAcm7?`H000e7?`80
01A7?`030017?dLo01=7?`040017?dLoAcl6000<Acl00`00Acm7?`0CAcl00`00Acm7?`0CAcl00`00
Acm7?`03Acl90007Acl00`00Acm7?`0BAcl00`00Acm7?`0DAcl00`00Acm7?`03Acl90006Bcl00`00
Bcm;?`0BBcl00`00Bcm;?`0CBcl00`00Bcm;?`0ABcl8000@Bal00`00Bcm;?`0CBcl00`00Bcm;?`0B
Bcl00`00Bcm;?`0>Bcl8000BCah00`00Cai?7P0DCah00`00Cai?7P0CCah00`00Cci??P06Cch50008
Dah00`00DaiC7P0CDah00`00DciC?P0CDch00`00DciC?P06Dch50009Dch01000DciC?P004U<n00<0
05=ODel02E=O1@001eMN00<005=oDgl04e=o00D007ooOomoo`0003Uoo`00GWoo00<007ooOol0AGoo
00<004LoAcl04TLo0P003dLo1`005DLo00<004LoAcl04TLo00<004LoAcl03TLo20004dLo00<004Lo
Acl04dLo00<004LoAcl03TLo2P004DLo00<004LoAcl04TLo00<004LoAcl04DLo200044/o00<004/o
Bcl04T/o00<004/oBcl04d/o00<004/oBcl02D/o1`000d/O00<004/OBal04d/O00<004/oBcl04T/o
00<004/oBcl04d/o00<004/oBcl00d/o2P001DlN00<004lNCah04dlN00<004lNCah04dlN00<004lN
Cah04dlN00@004lnCci??PD000eC7P03001C7U<N01AC7P03001C?U<n019C?P04001C?U<nDch5000>
Dch01000DciC?P004e<n00<005=ODel015=O100035MN00<005=oDgl04U=o0`000Woo00<007ooOol0
=goo001NOol00`00Oomoo`16Ool00`00Acm7?`0CAcl00`00Acm7?`03Acl90006Acl00`00Acm7?`0D
Acl00`00Acm7?`0BAcl00`00Acm7?`03Acl:0007Acl00`00Acm7?`0BAcl00`00Acm7?`0CAcl00`00
Acm7?`03Acl:0007Acl00`00Acm7?`0BAcl00`00Acm7?`0BAcl00`00Acm7?`09Acl70003Acl00`00
Bcm;?`0CBcl00`00Bcm;?`0BBcl00`00Bcm;?`0CBcl01000Bcm;?d/o1`002d/O00<004/OBal04T/O
00<004/oBcl04d/o00<004/oBcl044/o200044lN00<004lNCah04TlN00<004lNCah04dlN00<004lN
Cah04DlN1P004e<N00<005<NDah04e<N00<005<nDch04E<n1@004e<n00@005<nDch001=C?P03001C
Ge=O00@0015GGP03001COe=o00eCO`@0009GO`05001oogooOol0000hOol005ioo`03001oogoo04Mo
o`8000m7?`X00117?`8001E7?`8000m7?`T00197?`030017?dLo0197?`030017?dLo0117?`P00197
?`030017?dLo0197?`030017?dLo0197?`040017?dLoAcl7000;Acl00`00Bcm;?`0CBcl00`00Bcm;
?`0BBcl00`00Bcm;?`0>Bcl8000CBal00`00Bam;7`0BBal00`00Bcm;?`0CBcl00`00Bcm;?`08Bcl7
0003Cah00`00Cai?7P0BCah00`00Cai?7P0CCah00`00Cai?7P0CCah00`00Cai?7P09Cah70003Dad0
0`00DaiC7P0CDah00`00DaiC7P0CDah00`00DciC?P0<Dch50002Ead00`00DciC?P0DDch00`00Dch0
000BDch4000EEeh00`00DgmCO`09Dgl40007Egl01000Oomoo`00>7oo000COol4000>Ool3000:Ool<
0009Ool6000AOol00`00Oomoo`19Ool00`00Acm7?`03Acl90007Acl00`00Acm7?`0BAcl00`00Acm7
?`0DAcl00`00Acm7?`03Acl90006Acl00`00Acm7?`0CAcl00`00Acm7?`0BAcl00`00Acm7?`08Acl7
0005Acl00`00Acm7?`0CAcl00`00Acm7?`0BAcl00`00Acm7?`0=Acl8000CAcl00`00Bcm;?`0CBcl0
0`00Bcm;?`0BBcl00`00Bcm;?`03Bcl:0005Bal00`00Bam;7`0CBal00`00Bam;7`0CBal00`00Bcm;
?`0BBcl01000Bcm;?d/o1`002dlN00<004lNCah04TlN00<004lNCah04dlN00<004lNCah04TlN00<0
04lNCah00TlN1`002e<M00<005<NDah04e<N00<005<NDah04e<N00<005<nDch01U<n1@0025LM00<0
05<nDch04e<n00<005<n00003U<n10000ULn00<005MNEeh05EMN00<005=oDgl015=o10002eMo00D0
07ooOomoo`0003Moo`004Goo20002goo1@002Goo30001goo2P003goo00<007ooOol0BWoo1@004DLo
00<004LoAcl04TLo00<004LoAcl04DLo200044Lo00<004LoAcl04dLo00<004LoAcl04TLo00@004Lo
Acm7?`H000e7?`030017?dLo01=7?`030017?dLo0197?`030017?dLo00=7?`T000I7?`030017?dLo
01=7?`03001;?d/o01=;?`03001;?d/o00e;?`X0011;7`03001;7d/O01=;7`03001;7d/O019;7`03
001;?d/o00i;?`P0019?7P03001?7TlN019?7P03001?7TlN01=?7P03001?7TlN011?7PL0019C7@03
001C7U<N01=C7P03001C7U<N01=C7P04001C?U<nDch5000=Ead00`00DciC?P0DDch20009Dch50007
Ech00`00EeiGGP0DEeh00`00DgmCO`04000@Egl01000Oomoo`00=goo000AOol20004Ool2000;Ool5
000:Ool30006Ool20007Ool30005Ool3000>Ool00`00Oomoo`1<Ool00`00Acm7?`0BAcl2000CAcl2
000:Acl70005Acl00`00Acm7?`0AAcl2000DAcl00`00Acm7?`0=Acl8000DAcl00`00Acm7?`0CAcl0
0`00Acm7?`0=Acl:000@Acl00`00Acm7?`0CAcl00`00Bcm;?`0CBcl00`00Bcm;?`03Bcl90005Bal0
0`00Bam;7`0CBal00`00Bam;7`0BBal00`00Bam;7`0CBal00`00Bcm;?`03Bcl:0005Cah00`00Cai?
7P0CCah00`00Cai?7P0BCah00`00Cai?7P0CCah00`00Cai?7P08Cah70003D_d00`00DaeC7@0DDad0
0`00DaiC7P0BDah00`00DaiC7P0ADah6000CEad00`00DciC?P0CDch20005Dch4000<Ech00`00EeiG
GP0CEeh4000EEgl01000Oomoo`00=Woo000@Ool20006Ool2000:Ool5000;Ool3000GOol2000>Ool0
0`00Oomoo`1=Ool2000DAcl00`00Acm7?`0BAcl01000Acm7?dLo1P003DLo00<004LoAcl04TLo00<0
04LoAcl04TLo00<004LoAcl00dLo2@001dLo00<004LoAcl04dLo00<004LoAcl04dLo00<004LoAcl0
0dLo2@001TLo00<004LoAcl04TLo00<004LoAcl04TLo00<004/oBcl04D/o20003d/O00<004/OBal0
4d/O00<004/OBal04T/O00<004/OBal044/O200044lN00<004lNCah04TlN00<004lNCah04dlN00<0
04lNCah04TlN00@004lNCai?7PL000]Bo@03001C7E<M01=C7@03001C7U<N01=C7P03001C7U<N00UC
7PL000=G7@03001G7ELM01=G7@03001C?U<n01=C?P800003Dch000000080015G?P03001GGUMN00mG
GP<0009GOP03001GOeMo01AGO`04001oogoo000fOol0011oo`8000Ioo`8000]oo`<000eoo`<001Mo
o`8000eoo`H004aoo`030017?dLo0197?`030017?dLo00e7?`P001A7?`030017?dLo0197?`030017
?dLo00e7?`X00157?`030017?dLo01=7?`030017?dLo0117?`P00117?`030017?dLo0197?`030017
?dLo0197?`03001;?d/o00U;?`L000=;7`03001;7d/O019;7`03001;7d/O01=;7`03001;7d/O019;
7`03001;7d/O00Q;7`L000=?7P03001?7TlN019?7P03001?7TlN01=?7P03001?7TlN019?7P03001?
7TlN011?7PH0019Bo@03001C7E<M01AC7@03001C7U<N019C7P03001C7U<N009C7PL000]G7@03001G
7ELM01=G7@03001C?U<n015C?P@001EG?P03001GGUMN00]GGP@000IGOP03001GOeMo019GO`<0009o
o`03001oogoo03=oo`003goo0P0027oo0P006goo0`005Woo0P003Goo00<007ooOol0D7oo00<004Lo
Acl04TLo00<004LoAcl00dLo2@001dLo00<004LoAcl04dLo00<004LoAcl04TLo00<004LoAcl00dLo
2@001dLo00<004LoAcl04TLo0P0054Lo00<004LoAcl024Lo1`0014Lo00<004LoAcl04TLo00<004Lo
Acl04TLo00<004LoAcl04TLo00@004/oBcm;?`L000];7`03001;7d/O019;7`03001;7d/O019;7`03
001;7d/O019;7`04001;7d/OBal7000;Cah00`00Cai?7P0BCah00`00Cai?7P0CCah00`00Cai?7P0B
Cah00`00Cai?7P08Cah70003D_d00`00D_eBo@0CD_d00`00DaeC7@0CDad00`00DaiC7P0ADah6000B
Ead00`00EaeG7@0CEad00`00DciC?P0<Dch50002Ech2000EEch00`00EeiGGP08Eeh3000:Egh00`00
EgmGO`0?Egl30002Egl01000Oomoo`00=Goo000?Ool20008Ool2000LOol3000EOol2000=Ool00`00
Oomoo`1AOol2000?Acl9000AAcl00`00Acm7?`0CAcl00`00Acm7?`0?Acl8000AAcl00`00Acm7?`0C
Acl00`00Acm7?`0BAcl01000Acm7?dLo1P0034Lo00<004LoAcl04TLo00<004LoAcl04TLo00<004Lo
Acl03DLo20004d/O00<004/OBal04T/O00<004/OBal04T/O00<004/OBal03D/O20004TlN00<004lN
Cah04TlN00<004lNCah04dlN00<004lNCah04TlN00@004lNCai?7PL000]Bo@03001BoE;m019Bo@03
001C7E<M01=C7@03001C7U<N00aC7PD0009Fo@03001G7ELM01AG7@03001G7ELM01=G7@03001C?U<n
00IC?PD000QG?P03001G?ULn01AG?P03001GGUMN00=GGP@000iGOP03001GOeMo00]GO`<000IGO`04
001oogoo000dOol000moo`8000Qoo`8001eoo`<001Aoo`8000eoo`03001oogoo05=oo`030017?dLo
00=7?`T000I7?`030017?dLo0197?`8001A7?`030017?dLo00Q7?`H000E7?`030017?dLo0197?`80
01A7?`030017?dLo00e7?`P001=7?`030017?dLo0197?`030017?dLo0197?`030017?dLo00=7?`T0
00E;7`03001;7d/O01A;7`03001;7d/O015;7`03001;7d/O01=;7`03001;7d/O00=;7`T000E>oP03
001?7TlN01=?7P03001?7TlN019?7P03001?7TlN01=?7P03001?7TlN00e?7PP0019Bo@03001BoE;m
01=Bo@03001C7E<M01=C7@03001C7U<N00IC7PD000QFo@03001G7ELM01=G7@03001G7ELM01=G7@04
001C?U<nDch5000=Ech00`00EciG?P0DEch00`00EeiGGP03000BEgh00`00EgmGO`07Egl40009Egl0
1000Oomoo`00=7oo000?Ool20008Ool2000NOol3000COol2000=Ool00`00Oomoo`1DOol5000@Acl0
0`00Acm7?`0CAcl00`00Acm7?`0BAcl01000Acm7?dLo1P0034Lo00<004LoAcl04dLo00<004LoAcl0
4TLo00<004LoAcl00dLo2@001dLo00<004LoAcl04TLo00<004LoAcl04TLo00<004LoAcl03DLo2P00
3d/O00<004/OBal054/O00<004/OBal04D/O00<004/OBal03T/O2P003dkn00<004lNCah04TlN00<0
04lNCah04dlN00<004lNCah04TlN00<004lNCah00dlN2P001E;m00<005;mD_d04e;m00<005;mD_d0
4U;m00<005<MDad04e<M00@005<NDaiC7PD000eFo@03001G7ELM01AG7@03001G7ELM015G7@D0019G
?P8001AG?P@001IGOP03001GOeMo00=GO`<000iGO`04001oogoo000cOol000moo`8000Qoo`8001mo
o`<0015oo`8000ioo`03001oogoo05Ioo`030017?dLo0157?`8001A7?`030017?dLo00e7?`P001=7
?`8001A7?`030017?dLo00e7?`X00157?`030017?dLo0197?`030017?dLo0197?`030017?dLo00=7
?`T000E;?`03001;7d/O019;7`03001;7d/O01=;7`03001;7d/O019;7`03001;7d/O00=;7`X000E>
oP03001>oTkn019>oP03001?7TlN019?7P03001?7TlN019?7P03001?7TlN011?7PP0011Bo@03001B
oE;m019Bo@03001BoE;m01=Bo@03001C7E<M015C7@D0019Fo@03001G7ELM01AG7@03001G7ELM00eG
7@@0009G7@03001G?ULn019G?P80015G?P<0009GGP03001GOUMn01EGOP03001GOeMo00<0019GO`03
001oo`0003=oo`003goo0P0027oo0P0087oo0P002Goo0P001Goo0`003Woo00<007ooOol0Egoo00<0
04LoAcl04TLo00<004LoAcl04TLo00<004LoAcl00dLo2@001dLo00<004LoAcl04dLo00<004LoAcl0
4TLo00<004LoAcl00dLo2@001dLo00<004LoAcl04TLo00<004LoAcl04TLo00<004LoAcl03DLo2P00
3d/o00<004/OBal04T/O00<004/OBal04d/O00<004/OBal03D/O2P0044kn00<004knC_h04Dkn00<0
04lNCah04TlN00<004lNCah04dlN00<004lNCah024lN1`000e;m00<005;mD_d04U;m00<005;mD_d0
4e;m00<005;mD_d04U;m00<005<MDad035<M1@000UKl00<005KmE_d04eKm00<005LMEad04eLM00<0
05LMEad02ELM10001eLM00<005LnEch04ELn00<005Ln00003ELn0`001UMN00<005MnEgh04eMn1000
5EMo00@007ooOol0039oo`003goo0P0027oo0P008Goo0P0027oo2@003goo00<007ooOol0F7oo0P00
4dLo00<004LoAcl03DLo2P004DLo00<004LoAcl04dLo00<004LoAcl03DLo2P004DLo00<004LoAcl0
4TLo00<004LoAcl04TLo00<004LoAcl00dLo2@001D/o00<004/oBcl04T/o00<004/OBal04T/O00<0
04/OBal04d/O00<004/OBal00d/O2@001Dkn00<004knC_h04Tkn00<004knC_h04Tkn00<004lNCah0
4TlN00<004lNCah04TlN00@004lNCai?7PL000]Bo@03001BoE;m019Bo@03001BoE;m019Bo@03001B
oE;m01=Bo@03001C7E<M00IC7@D000QFo003001FoEKm019Fo@03001G7ELM01AG7@03001G7ELM00AG
7@@000]G7@03001G?ULn015G?P03001G?P0000UG?P@000UGGP03001GOUMn011GOP<0009GO`03001G
OeMo01=GO`<00003Ool007oo035oo`003goo0P0027oo0P008Goo0P0027oo0P0000=oo`0000000`00
47oo00<007ooOol0FWoo00<004LoAcl04DLo00<004LoAcl00dLo2@001dLo00<004LoAcl04TLo00<0
04LoAcl04dLo00<004LoAcl00dLo2@001dLo00<004LoAcl04TLo00<004LoAcl04TLo00<004LoAcl0
3DLo2P003d/o00<004/oBcl04T/o00<004/OBal04D/O00<004/OBal04D/O20003dkn00<004knC_h0
4Tkn00<004knC_h04Tkn00<004lNCah04DlN00<004lNCah044lN1P004U;m00<005;mD_d04U;m00<0
05;mD_d04e;m00<005;mD_d04U;m00@005<MDaeC7@D000eFo003001FoEKm01=Fo@03001G7ELM01=G
7@03001G7ELM00@0011G7@03001G?ULn011G?P04001G?ULn0005Ech3000>Eeh00`00EgiGOP0;Egh4
0006Egl00`00EgmGO`0?Egl30002Dgl01000Oomoo`00<Goo000@Ool20006Ool2000IOol20007Ool2
0008Ool2000EOol00`00Oomoo`1LOol00`00Acm7?`0=Acl9000AAcl00`00Acm7?`0BAcl00`00Acm7
?`0@Acl8000AAcl00`00Acm7?`0BAcl00`00Acm7?`0BAcl00`00Acm7?`03Acl90005Acl00`00Bcm;
?`0BBcl00`00Bcm;?`0BBcl00`00Bam;7`0ABal00`00Bam;7`09Bal70003C_h00`00C_i>oP0AC_h0
0`00C_i>oP0BC_h00`00C_i>oP0BC_h00`00Cai?7P0BCah00`00Cai?7P08Cah70003D]`00`00D_eB
o@0CD_d00`00D_eBo@0BD_d00`00D_eBo@0BD_d00`00D_eBo@0@D_d6000BE_`00`00E_eFo@0CE_d0
0`00EaeG7@0BEad4000DEad00`00EciG?P0@Ech01000EciG?P000ULn0`004EMN00<005MnEgh025Mn
0`002UMo00<005MoEgl035Mo0`001U=o00<007oo0000<Goo000@Ool20006Ool2000IOol30006Ool2
0008Ool2000EOol00`00Oomoo`1MOol00`00Acm7?`03Acl90006Acl00`00Acm7?`0BAcl2000CAcl0
0`00Acm7?`08Acl70005Ael00`00Acm7?`0BAcl00`00Acm7?`0BAcl00`00Acm7?`0=Acl:000?Acl0
0`00Bcm;?`0BBcl00`00Bcm;?`0ABcl00`00Bam;7`0BBal01000Bam;7d/O1`002dkn00<004knC_h0
4Dkn00<004knC_h04Tkn00<004knC_h04Tkn00<004lNCah04DlN00@004lNCai?7PL000]Bg003001B
oE;m019Bo@03001BoE;m019Bo@03001BoE;m01=Bo@03001BoE;m00QBo@L000=Fo003001Fo5Kl01=F
o003001FoEKm019Fo@03001G7ELM00iG7@@0009G7@03001G7ELM01AG7@03001G?ULn00mG?P03001G
?P0000<001EGGP03001GOUMn00=GOP@000iGO`03001GOeMo00MGO`@000UCO`04001oogoo000`Ool0
015oo`8000Aoo`8001Yoo`@000Aoo`8000Uoo`8001Eoo`03001oo`00008005aoo`D00117?`8001A7
?`030017?dLo0157?`040017?dLoAcl6000=Ael00`00Acm7?`0BAcl00`00Acm7?`0BAcl00`00Acm7
?`03Acl90006Acl00`00Acm7?`0AAcl00`00Bcm;?`0BBcl00`00Bcm;?`0ABcl00`00Bam;7`0=Bal8
000BC_h00`00C_i>oP0BC_h00`00C_i>oP0AC_h00`00C_i>oP0BC_h00`00Cai?7P0=Cah8000BD]`0
0`00D_eBo@0BD_d00`00D_eBo@0BD_d00`00D_eBo@0CD_d01000D_eBoE;m1`002eKl00<005KlE_`0
4UKl00<005KmE_d04eKm00<005LMEad025LM1@001eLM00<005LMEad04eLM00<005LnEch03ELn1000
0UMN00<005MNEeh055MN00<005MnEgh00`004eMo00<005MoEgl00eMo0`003U=o00@007ooOol002mo
o`004Goo20006goo20002Woo2P003Goo0P00HGoo00<004LoAcl04TLo00<004LoAcl04TLo00<004Lo
Acl03DLo1`0054MO0P004dLo00<004LoAcl03DLo2P0044Lo00<004LoAcl04DLo00<004/oBcl04T/o
00<004/oBcl04D/o00<004/OBal00d/O2@001Dkn00<004knC_h04dkn00<004knC_h04Dkn00<004kn
C_h04Tkn00<004knC_h04Tkn00<004lNCah00dlN2@001E;L00<005;LD]`04e;L00<005;mD_d04U;m
00<005;mD_d04U;m00<005;mD_d04E;m1@004UKl00<005KlE_`04eKl00<005KmE_d04UKm00<005LM
Ead015LM100035LM00<005LMEad04eLM00<005LnEch02ELn10000UMN00<005MNEeh00UMN00<005MN
Eeh04eMN0`005UMo00<005MoEgl00`004E=o00@007ooOol002moo`004goo10007goo1@002goo2P00
3Goo00<007ooOol0HGoo00<004LoAcl04TLo00<004LoAcl04TLo00<004LoAcl00dLo2@001TMO00<0
04MOAel054MO00<004LoAcl04DLo00<004LoAcl00dLo2@001d<o00<004LoAcl04DLo00<004LoAcl0
4DLo00<004/oBcl04T/o00<004/oBcl024/o3P003dkn00<004knC_h04dkn00<004knC_h04Dkn00<0
04knC_h04Dkn00<004knC_h044kn20003e;L00<005;LD]`04U;L00<005;mD_d04U;m00<005;mD_d0
4U;m00<005;mD_d035;m1@000UKL00<005KlE_`04UKl00<005KlE_`04eKl00<005KmE_d04UKm00<0
05LMEad0100045LM00<005LMEad055LM00<005LnEch015Ln10001UMN00<005MNEeh00UMN00<005MN
Eeh045MN0`0000=GO`00Egl05UMo0`0055=o00D007ooOomoo`0002ioo`00GGoo00<007ooOol0HWoo
0P004dLo0P003dLo2@0044MO0P005DMO00<004LoAcl03DLo2@004D<o00<004LoAcl04DLo00<004Lo
Acl04DLo00<004/oBcl03D/o3`002Dkn00<004knC_h04Tkn00<004knC_h04Tkn00<004knC_h04Dkn
00<004knC_h04Tkn00<004knC_h024kn1`000e;L00<005;LD]`04E;L00<005;LD]`04U;L00<005;m
D_d04e;m00<005;mD_d04U;m00<005;mD_d01U;m1@0025KL00<005KlE_`04UKl00<005KlE_`04UKl
00<005KmE_d04EKm10005ELM00<005LMEad04eLM00<005LnEch010002UMN00<005MNEeh00eMN00<0
05MNEeh035MN0`001EMo00<005MoEgl04EMo0`0000=CW`00Dgl04e=o0`000Woo00<007ooOol0;7oo
001MOol00`00Oomoo`1TOol00`00Acm7?`0BAcl00`00Acm7?`03Acl90006Acl00`00Aem7G`0BAel0
0`00Aem7G`0CAel00`00Acm7?`03Acl90006Acl00`00@cm3?`0B@cl00`00Acm7?`0AAcl00`00Acm7
?`0AAcl00`00Bcm;?`03Bcl90005C_h00`00C_i>oP0AC_h00`00C_i>oP0BC_h00`00C_i>oP0BC_h0
0`00C_i>oP0AC_h00`00C_i>oP0AC_h01000C_i>oTkn1`002e;L00<005;LD]`04E;L00<005;LD]`0
4U;L00<005;mD_d04U;m00<005;mD_d04U;m00@005;mD_eBo@D000eFg003001Fo5Kl019Fo003001F
o5Kl01=Fo003001FoEKm00]Fo@D0009Fo003001G7ELM01AG7@03001G7ELM019G7@@000iGGP03001G
GUMN00=GGP03001GGUMN00UGGP<000QGO`03001GOeMo00iGO`<000ECW`03001COe=o00iCO`<0009C
O`05001oogooOol0000]Ool005eoo`03001oogoo06Eoo`030017?dLo00e7?`X00117?`8001=7G`80
00m7G`X00117?`030013?d<o0193?`030017?dLo0157?`030017?dLo00e7?`T000m>oP03001>oTkn
015>oP03001>oTkn015>oP03001>oTkn019>oP03001>oTkn019>oP03001>oTkn00a>oPP0019Bg003
001Bg5;L015Bg003001Bg5;L019Bg003001BoE;m01=Bo@03001BoE;m00mBo@H0019Fg003001Fo5Kl
019Fo003001Fo5Kl01=Fo003001FoEKm00IFo@D000QFo003001G7ELM01AG7@03001G7ELM00iG7@<0
009K?@03001GGUMN00eGGP03001GGUMN00=GGP03001GGUMN00IGGP<000aGO`03001GOeMo00YGO`<0
00QCW`03001COe=o00]CO`<000ICO`04001oogoo000]Ool005eoo`03001oogoo06Ioo`030017?dLo
00=7?`T000M7?`030017?dLo0197?`030017GdMO0197G`030017GdMO00=7G`T000M7G`030017?dLo
0157?`030013?d<o0193?`030017?dLo0157?`030017?dLo00=7?`T000A:oP03001>oTkn019>oP03
001>oTkn015>oP03001>oTkn015>oP03001>oTkn019>oP03001>oTkn015>oP03001>oTkn00=>oPT0
00EBg003001Bg5;L019Bg003001Bg5;L019Bg003001Bg5;L019Bg003001BoE;m019Bo@03001BoE;m
00QBo@L000=Ff`03001Fg5KL01=Fg003001Fo5Kl019Fo003001Fo5Kl019Fo004001FoEKmE_d5000=
E_`00`00EaeG7@0DEad00`00EaeG7@0;Ead30006Fcd00`00EeiGGP0<Eeh00`00EeiGGP04Eeh00`00
EeiGGP02Eeh3000?Egl00`00EgmGO`07Egl3000<Dil00`00DgmCO`06Dgl4000:Dgl01000Oomoo`00
;7oo001MOol00`00Oomoo`1WOol5000AAcl00`00Acm7?`0BAcl2000?Ael9000AAel00`00Acm7?`0A
Acl00`00@cm3?`0B@cl00`00Acm7?`08Acl>000>B_h00`00C_i>oP0AC_h00`00C_i>oP0AC_h00`00
C_i>oP0BC_h00`00C_i>oP0BC_h00`00C_i>oP0<C_h:000?D]`00`00D]aBg00BD]`00`00D]aBg00A
D]`00`00D]aBg00BD]`00`00D_eBo@0BD_d01000D_eBoE;m1`002eKK00<005KLE]`04UKL00<005Kl
E_`04UKl00<005KlE_`04EKl1@004eKl00<005LMEad055LM00<005LMEad01ULM10002E/m00<005MN
Eeh035MN00<005MNEeh015MN00<005MN00000P004eMo00<005MoEgl00eMo0`003e>O00<005=oDgl0
0e=o0`003U=o00@007ooOol002aoo`00GGoo00<007ooOol0JGoo00<004LoAcl04TLo0P0054Lo00<0
04MOAel00dMO2@001TLo00<004MOAel04TMO00<004LoAcl04DLo00<004<o@cl03D<o3`002D[n00<0
04[nB_h04D[n00<004knC_h04Dkn00<004knC_h04Dkn00<004knC_h04Dkn00<004knC_h04Tkn00<0
04knC_h00dkn2@001E;L00<005;LD]`04E;L00<005;LD]`04U;L00<005;LD]`04U;L00<005;LD]`0
4U;L00<005;mD_d03e;m1P004UKK00<005KLE]`04UKL00<005KlE_`04UKl00<005KlE_`03EKl1000
0UKl00<005KlE_`04eKl00<005LMEad055LM00<005LMEad00eLM0`003E/m00<005MNEeh035MN00<0
05MNEeh00eMN0`005UMo00<005MoEgl00`004U>O00<005=oDgl00`004U=o00@007ooOol002]oo`00
GGoo00<007ooOol0JWoo00<004LoAcl04dLo00<004LoAcl03dLo200044Lo00<004MOAel04TMO00<0
04LoAcl04DLo00<004<o@cl00d<o2@001D[n00<004[nB_h04D[n00<004[nB_h04D[n00<004knC_h0
4Dkn00<004knC_h04Dkn00<004knC_h04Dkn00<004knC_h03Dkn2P003e;L00<005;LD]`04E;L00<0
05;LD]`04U;L00<005;LD]`04E;L00<005;LD]`04U;L00<005;mD_d025;m1`000eJk00<005KKE]/0
4UKK00<005KLE]`04eKL00<005KlE_`04UKl00<005KlE_`025Kl10001eKl00<005KlE_`04eKl00<0
05LMEad04eLM00<005LMEad00`004E/m00<005MNEeh02eMN00<005MNEeh00`000UMo00<005MoEgl0
4eMo100055>O100055=o0`0000=oo`00Ool0:Woo001MOol00`00Oomoo`1[Ool2000DAcl00`00Acm7
?`08Acl60005Acl00`00Acm7?`0AAcl2000CAel00`00Acm7?`0=Acl9000?B_h00`00B_i:oP0AB_h0
0`00B_i:oP0@B_h00`00C_i>oP0AC_h00`00C_i>oP0AC_h00`00C_i>oP0BC_h00`00C_i>oP03C_h9
0005D]`00`00D]aBg00AD]`00`00D]aBg00AD]`00`00D]aBg00BD]`00`00D]aBg00BD]`00`00D]aB
g00AD]`01000D_eBoE;m1`002eJk00<005KKE]/04UKK00<005KLE]`04UKL00<005KlE_`04UKl00<0
05KlE_`015Kl10002eKl00<005KlE_`04eKl00<005LMEad04ULM100055/m00<005MNEeh02eMN0`00
1UMo00<005MoEgl03eMo0`000U>O00<005>ODil045>O0`000U>O00<005=oDgl045=o0`000U=o00@0
07ooOol002Yoo`00GGoo00<007ooOol0KGoo00<004LoAcl04TLo00@004LoAcm7?`H000a7?`030017
?dLo0197?`030017GdMO0157G`030017?dLo00=7?`T000A;7P03001:oT[n019:oP03001:oT[n011:
oP03001:oT[n015:oP03001>oTkn015>oP03001>oTkn015>oP03001>oTkn00e>oPX000mBg003001B
g5;L015Bg003001Bg5;L015Bg003001Bg5;L015Bg003001Bg5;L019Bg003001Bg5;L00mBg0H0019F
^`03001FfeKK019Ff`03001Fg5KL019Fg003001Fo5Kl019Fo003001Fo5Kl00@0011Fo003001Fo5Kl
019Fo003001G7ELM00mG7@<0009K?@03001K?E/m01AK?@03001GGUMN00IGGPD000UGO`03001GOeMo
00]GO`<000ICW`03001CWe>O00aCW`<000ICW`03001COe=o00aCO`<000ICO`03001oo`0002Yoo`00
GGoo1000KGoo00<004LoAcl03DLo20004dLo0P004dLo00<004MOAel03DMO2@003T/N00<004[nB_h0
4T[n00<004[nB_h044[n00<004[nB_h04D[n00<004knC_h04Dkn00<004knC_h04Dkn00<004knC_h0
0dkn2@001E;L00<005;LD]`04E;L00<005;LD]`04E;L00<005;LD]`04E;L00<005;LD]`04U;L00<0
05;LD]`04U;L00<005;LD]`01e;L1`000eJk00<005JkE[/04UJk00<005KKE]/04UKK00<005KLE]`0
4eKL00<005KlE_`045Kl100055Kl00<005KlE_`04eKl00<005LMEad02eLM0`001U/m00<005/mFcd0
4e/m00<005MNEeh00eMN0`0015Mo00<005MoEgl025Mo00<005MoEgl01eMo0`002U>O00<005>ODil0
1e>O10002U>O00<005=oDgl01e=o10002E=o00@007ooOol002Uoo`00G7oo00<007ooOol0L7oo00<0
04LoAcl00dLo2@001dLo00<004LoAcl04dLo00<004LoAcl04DLo00<004MOAel00dMO2@0014/O00<0
04/NBah04D/N00<004[nB_h04D[n00<004[nB_h04D[n00<004[nB_h044[n00<004knC_h04Dkn00<0
04knC_h03Dkn2P003e;L00<005;LD]`04E;L00<005;LD]`04E;L00<005;LD]`04E;L00<005;LD]`0
4E;L00<005;LD]`04U;L00@005;LD]aBg0H000]F^`03001F^eJk019F^`03001FfeKK019Ff`03001F
g5KL019Fg003001Fo5Kl00]Fo0D0009Ff`03001Fo5Kl01=Fo003001Fo5Kl01=Fo003001G7ELM00MG
7@@000UK?@03001K?E/m01=K?@03001GGUMN00<000MGO`03001GOeMo00QGO`03001GOeMo00AGO`<0
00eCW`03001CWe>O00ACW`<000iCW`03001COe=o00ACO`<000iCO`03001oo`0002Uoo`00G7oo00<0
07ooOol0LGoo1@004DLo00<004LoAcl04dLo00<004LoAcl03DLo2@003T/O00<004/NBah04D/N00<0
04[nB_h04D[n00<004[nB_h044[n00<004[nB_h04D[n00<004knC_h04Dkn00<004knC_h00dkn2@00
1DkL00<005;LD]`04E;L00<005;LD]`04E;L00<005;LD]`04E;L00<005;LD]`04E;L00<005;LD]`0
4U;L00<005;LD]`03e;L1P004EJk00<005JkE[/04UJk00<005KKE]/04UKK00<005KLE]`04UKL00<0
05KlE_`01UKl1@0025KK00<005KlE_`04eKl00<005KlE_`04eKl00<005LMEad00eLM0`003E/m00<0
05/mFcd04e/m0`002UMo00<005MoEgl02EMo00<005MoEgl00`004E>O00<005>ODil00`004U>O00<0
05=oDgl00`004E=o00@007ooOol002Qoo`00G7oo00<007ooOol0Lgoo00<004LoAcl04TLo0P0054Lo
00<004LoAcl00dLo2@0014LO00<004/OBal04D/O00<004/NBah04D/N00<004[nB_h04D[n00<004[n
B_h044[n00<004[nB_h04D[n00<004knC_h024kn3P003dkL00<005;LD]`04E;L00<005;LD]`04E;L
00<005;LD]`04E;L00<005;LD]`045;L00<005;LD]`04U;L00<005;LD]`025;L1`000eJk00<005Jk
E[/04EJk00<005JkE[/04UJk00<005KKE]/04eKK00<005KLE]`04UKL00<005KlE_`01@003EKK00<0
05KlE_`04eKl00<005KlE_`04eKl00<005LMEad00`004E/m00<005/mFcd03e/m0`0000=GOP00Egl0
2UMo00<005MoEgl02EMo0`004e>O100055>O100055=o00@007ooOol002Qoo`00G7oo00<007ooOol0
M7oo0P0054Lo00<004LoAcl03DLo2P003TLO00<004/OBal04D/O00<004/NBah044/N00<004[nB_h0
4D[n00<004[nB_h044[n00<004[nB_h03D[n3`002DkL00<004kLC]`04DkL00<005;LD]`04E;L00<0
05;LD]`04E;L00<005;LD]`04E;L00<005;LD]`04E;L00<005;LD]`04E;L00@005;LD]aBg0L000YF
^`03001F^eJk019F^`03001F^eJk019F^`03001FfeKK019Ff`03001Fg5KL011Fg0D0019Ff`03001F
o5Kl01AFo003001Fo5Kl015Fo0@001AK?@03001K?E/m00aK?@<000EGOP03001GOeMo00QGO`03001G
OeMo00IGO`<00003Dil005>O011CW`<0009CW`03001CWe>O011CW`<0009CO`03001COe=o019CO`<0
009oo`03001oogoo02Eoo`00G7oo00<007ooOol0MWoo00<004LoAcl04TLo00<004LoAcl00dLo2@00
1TLo00<004LOAal044LO00<004/OBal04D/O00<004/NBah044/N00<004[nB_h04D[n00<004[nB_h0
44[n00<004[nB_h00d[n2@001DkL00<004kLC]`04DkL00<004kLC]`04DkL00<005;LD]`04E;L00<0
05;LD]`04E;L00<005;LD]`045;L00<005;LD]`04E;L00<005;LD]`03e;L1P004UJk00<005JkE[/0
4EJk00<005JkE[/04UJk00<005KKE]/04UKK00<005KLE]`035KL10000UKK00<005KKE]/04eKK00<0
05KlE_`04eKl00<005KlE_`03EKl10000U/M00<005/mFcd04e/m00<005/mFcd02E/m0`002EMn00<0
05MoEgl025Mo00<005MoEgl00UMo0`001E>O00<005>ODil02e>O0`001U>O00<005>ODil035>O0`00
1U=o00<005=oDgl03U=o0`000UMo00@007ooOol002Moo`00G7oo00<007ooOol0Mgoo0P003dLo2@00
44Lo00<004LOAal044LO00<004/OBal044/O00<004/NBah04D/N00<004[nB_h04D[n00<004[nB_h0
1d[n3P003dkL00<004kLC]`044kL00<004kLC]`04DkL00<005;LD]`04E;L00<005;LD]`04E;L00<0
05;LD]`04E;L00<005;LD]`04E;L00<005;LD]`01e;L1`000eJj00<005JkE[/04UJk00<005JkE[/0
4EJk00<005JkE[/04UJk00<005KKE]/04eKK00<005KLE]`01eKL10001eKK00<005KKE]/04UKK00<0
05KlE_`055Kl00<005KlE_`025Kl10001e/M00<005/mFcd04e/m00<005/mFcd01E/m0`0035Mn00<0
05MoEgl025Mo00<005Mo00000P002E>O00<005>ODil01e>O0`002U>O00<005>ODil01e>O10002E=o
00<005=oDgl02e=o0`001UMo00@007ooOol002Ioo`00G7oo00<007ooOol0NGoo00<004LoAcl00dLo
2@001T<o00<004LoAcl04DLo00<004LOAal044LO00<004/OBal044/O00<004/NBah04D/N00<004[n
B_h024[n4P002DkM00<004kLC]`04DkL00<004kLC]`04DkL00<004kLC]`04DkL00<005;LD]`04E;L
00<005;LD]`045;L00<005;LD]`04E;L00<005;LD]`04E;L00@005;LD]aBg0H000]F^P03001F^eJk
015F^`03001F^eJk019F^`03001F^eJk019F^`03001FfeKK019Ff`03001Fg5KL00AFg0<000]Ff`03
001FfeKK01=Ff`03001Fo5Kl01=Fo003001Fo5Kl00AFo0@000]K7@03001K?E/m01=K?@03001K?E/m
009K?@<0011GOP03001GOeMo00IGO`<000aCW`03001CWe>O00ACW`<000eCW`03001CWe>O00ACW`<0
00iCO`03001COe=o00MCO`<000UGO`04001oogoo000VOol005aoo`03001oogoo07Yoo`D00113?`03
0017?dLo0157?`0300177dLO01177`03001;7d/O011;7`03001;7T/N00e;7Ph000U:g@03001>gDkM
011>g@03001>g4kL015>g003001>g4kL011>g003001>g4kL015>g003001Bg5;L015Bg003001Bg5;L
015Bg003001Bg5;L015Bg003001Bg5;L00aBg0P0015F^P03001F^eJk019F^`03001F^eJk015F^`03
001F^eJk019F^`03001FfeKK019Ff`03001Fg5KL00@000iFf`03001FfeKK01=Ff`03001Fo5Kl01=F
o003001Fo5Kl00@000mK7@03001K?E/m01=K?@03001K?@00008001=GOP03001GOeMo00=GO`<00003
Dil005>O00eCW`03001CWe>O00<0015CW`03001CWe>O00<0019CO`03001COe=o00=CO`<000eGO`04
001oogoo000UOol005aoo`03001oogoo07aoo`030013?d<o0153?`030017?dLo0157?`0300177dLO
01177`03001;7d/O011;7`03001;7T/N00=;7PT000A:g@03001:gD[M015:g@03001>gDkM00m>g@03
001>g4kL015>g003001>g4kL015>g003001>g4kL015>g003001Bg5;L011Bg003001Bg5;L015Bg003
001Bg5;L015Bg003001Bg5;L00=Bg0T000EBVP03001F^UJj015F^P03001F^eJk019F^`03001F^eJk
015F^`03001F^eJk019F^`03001FfeKK015Ff`@001=Ff`03001FfeKK019Ff`03001Fo5Kl019Fo0@0
01AK7@03001K?E/m015K?@<001MGOP03001GO`00008000ACW`03001CWe>O00]CW`@001=CW`@001EC
O`03001COe=o00<0015GO`03001oo`0002Eoo`00G7oo00<007ooOol0OGoo00<004<o@cl04D<o00<0
04LoAcl04DLo00<004LOAal044LO00<004/OBal01d/O3P003T[M00<004[MB]d044[M00<004kMC]d0
44kM00<004kLC]`04DkL00<004kLC]`044kL00<004kLC]`04DkL00<005;LD]`04E;L00<005;LD]`0
4E;L00<005;LD]`035;L2P003U:J00<005JjE[X04UJj00<005JkE[/04EJk00<005JkE[/04UJk00<0
05JkE[/04UJk00<005KKE]/02eKK1@000UJj00<005KKE]/04UKK00<005KKE]/04eKK00<005KlE_`0
3UKl0`000U/L00<005/MFad04e/M00<005/mFcd03U/m0`000UMn00<005MnEgh055Mn0`001e>O00<0
05>ODil025>O0`000U>O00<005>ODil03e>O0`000U=o00<005=oDgl04e=o100055Mo00@007ooOol0
02Aoo`00G7oo1000OGoo0P004T<o00<004LoAcl04DLo00<004LOAal01dLO4P002DKn00<004[MB]d0
4D[M00<004[MB]d044[M00<004kMC]d044kM00<004kLC]`044kL00<004kLC]`04DkL00<004kLC]`0
44kL00<005;LD]`04E;L00<005;LD]`04E;L00<005;LD]`00e;L2@001E:J00<005:JDYX04E:J00<0
05JjE[X04EJj00<005JkE[/04UJk00<005JkE[/04EJk00<005JkE[/04UJk00<005KKE]/01UKK1@00
1eJj00<005KKE]/04UKK00<005KKE]/04eKK00<005KlE_`02eKl0`001U/L00<005/MFad04U/M00<0
05/mFcd02e/m0`001UMn00<005MnEgh045Mn0`000U>O00<005>ODil01E>O00<005>ODil01E>O0`00
1U>O00<005>ODil02e>O0`001U=o00<005=oDgl03e=o0`000UMo00<005MoEgl04UMo0`0000=oo`00
Ool08goo001LOol00`00Oomoo`20Ool00`00@cm3?`0@@cl00`00Acm7?`0=Acl=0009A_l00`00A_i6
oP0@A_h00`00B]e:g@0@B]d00`00B]e:g@0AB]d00`00C]e>g@0?C]d00`00C]a>g00AC]`00`00C]a>
g00@C]`00`00C]a>g00AC]`00`00D]aBg00AD]`00`00D]aBg00<D]`:000>DYX00`00DYYBVP0ADYX0
0`00E[YF^P0AE[X00`00E[]F^`0BE[/00`00E[]F^`0AE[/00`00E[]F^`0BE[/01000E]]FfeKK1@00
3EJj00<005KKE]/04UKK00<005KKE]/04eKK00<005KlE_`01UKl10002E/L00<005/MFad04e/M00<0
05/mFcd01U/m10002UMn00<005MnEgh035Mn0`001U>O00<005>ODil015>O00@005>ODimCW`@000YC
W`03001CWe>O00MCW`<000UCO`03001COe=o00aCO`<000IGO`03001GOeMo00iGO`<0009GO`04001o
ogoo000SOol005aoo`03001oogoo085oo`030013?d<o0113?`030017?dLo00=7?`T000@o7`030016
odKo0116o`030016oTKn0116oP03001:gD[M011:g@03001:gD[M011:g@03001>gDkM011>g@03001>
g4kL011>g003001>g4kL011>g003001>g4kL015>g003001Bg5;L015Bg003001Bg5;L00=Bg0T000EB
VP03001BVU:J015BVP03001BVU:J011BVP03001F^UJj019F^P03001F^eJk015F^`03001F^eJk019F
^`03001F^eJk011F^`D0019F^P03001FfeKK019Ff`03001FfeKK01=Ff`03001Fo5Kl00=Fo0<000eK
7003001K7E/M01=K7@03001K?E/m00=K?@<000mGOP03001GOUMn00MGOP@000YCW`03001CWe>O00=C
W`@000iCW`03001CWe>O00ACW`<000eCO`03001COe=o00MCO`@000UGO`03001GOeMo00]GO`<000IG
O`04001oogoo000ROol005aoo`03001oogoo089oo`030013?d<o00M3?`h000ho7`030016odKo0116
o`030016oTKn0116oP03001:gD[M00m:g@03001:gD[M015:g@03001>gDkM00m>g@03001>g4kL011>
g003001>g4kL015>g003001>g4kL015>g003001Bg5;L00aBg0X000iBVP03001BVU:J015BVP03001B
VU:J015BVP03001F^UJj015F^P03001F^eJk019F^`03001F^eJk015F^`03001F^eJk00]F^`D0009F
^P03001F^UJj019F^P03001FfeKK019Ff`03001FfeKK01=Ff`03001Fo5Kl00<0015K7003001K7E/M
019K7@03001K?E/m00<0019GOP03001GOUMn00AGOP<000mCW`03001CWe>O00<0019CW`03001CWe>O
00<0015CO`03001COe=o00=CO`<000iGO`03001GOeMo00IGO`@000UGO`04001oogoo000ROol005ao
o`03001oogoo08=oo`T000/k7`03000o7clO00lo7`030016odKo0116o`030016oTKn00m6oP03001:
gD[M011:g@03001:gD[M011:g@03001>gDkM011>g@03001>g4kL011>g003001>g4kL011>g003001>
g4kL015>g003001Bg5;L00=Bg0T000EBVP03001BVU:J015BVP03001BVU:J011BVP03001BVU:J015B
VP03001F^UJj015F^P03001F^eJk019F^`03001F^eJk015F^`03001F^eJk00IF^`D000MF^P03001F
^UJj01=F^P03001FfeKK019Ff`03001FfeKK015Ff`@001AK7003001K7E/M019K7@<001IGOP03001G
OUMn00<0019CW`<0009CW`03001CWe>O00mCW`@001ACO`03001COe=o00<0015GO`03001GOeMo00=G
O`<000iGO`04001oogoo000QOol005aoo`03001oogoo08Eoo`03000k7c/O010k7`03000o7clO00lo
7`030016odKo00m6o`030016oTKn0116oP03001:gD[M011:g@03001:gD[M011:g@03001>gDkM00m>
g@03001>g4kL011>g003001>g4kL015>g003001>g4kL00a>g0X000iBVP03001BVU:J015BVP03001B
VU:J015BVP03001BVU:J011BVP03001F^UJj019F^P03001F^eJk015F^`03001F^eJk019F^`03001F
^eJk00D000eF^P03001F^UJj019F^P03001FfeKK019Ff`03001FfeKK00iFf`<0009Jo003001K75/L
01AK7003001K7E/M00iK7@<00003Egh005Mn01IGOP<0019CW`<00003Cil005>O009CW`03001CWe>O
00aCW`<0009CO`03001COe=o019CO`@001AGO`03001GOeMo00<0015GO`04001oogoo000QOol005]o
o`03001oogoo08Moo`80014k7`80010o7`030016odKo00m6o`030016oTKn0116oP03001:gD[M00m:
g@03001:gD[M011:g@03001>gDkM011>g@03001>g4kL011>g003001>g4kL011>g003001>g4kL00=>
g0T000EBNP03001BVU:J015BVP03001BVU:J011BVP03001BVU:J015BVP03001BVU:J011BVP03001F
^UJj019F^P03001F^eJk019F^`03001F^eJk00mF^`D0019F^P03001F^UJj019F^P03001FfeKK019F
f`03001FfeKK00]Ff`<000IJo003001K75/L01=K7003001K7E/M00]K7@<000EGOP03001GOUMn015G
OP<00003Cil005>O00mCW`<000E?W`04001CWe>O000;Dil30006Dgl00`00DgmCO`0>Dgl30002Egl0
0`00EgmGO`0BEgl4000CEgl30002Ool00`00Oomoo`0NOol005]oo`03001oogoo08Uoo`03000k7c/O
010k7`03000o7clO00do7`030016odKo0116o`030016oTKn00m6oP03001:gD[M011:g@03001:gD[M
011:g@03001>gDkM011>g@03001>g4kL00m>g003001>g4kL00Q>g0h000iBNP03001BVU:J015BVP03
001BVU:J011BVP03001BVU:J015BVP03001BVU:J015BVP03001F^UJj015F^P03001F^eJk019F^`03
001F^eJk00YF^`D0009FVP03001F^UJj019F^P03001F^UJj019F^P03001FfeKK01=Ff`03001FfeKK
00IFf`@000UJo003001K75/L01=K7003001K7E/M00QK7@<000UGOP03001GOUMn00eGOP<000E?W`03
001CWe>O00YCW`<000U?W`03001CW`0000MCW`@000UCO`03001COe=o00]CO`<000IGO`03001GOeMo
00iGO`<0009GO`03001GOeMo00mGO`<0009CW`04001oogoo000POol005]oo`03001oogoo08Yoo`80
014k7`03000o7clO00do7`030016odKo00m6o`030016oTKn0116oP03001:gD[M00m:g@03001:gD[M
015:g@03001>gDkM00m>g@03001>g4kL00M>g1<000UBNP03001BNU9j015BNP03001BVU:J011BVP03
001BVU:J015BVP03001BVU:J011BVP03001BVU:J015BVP03001F^UJj019F^P03001F^eJk015F^`03
001F^eJk00EF^`D000QFVP03001F^UJj019F^P03001F^UJj019F^P03001FfeKK019Ff`03001FfeKK
00=Ff`<000eJo003001K75/L01AK7003001K7E/M00EK7@8000aGOP03001GOUMn00YGOP<000U?W`03
001CWe>O00ICW`<000a?W`03001CW`0000ACW`<000iCO`03001COe=o00MCO`<000UGO`03001GOeMo
00]GO`<000IGO`03001GOeMo00]GO`<000ICW`04001oogoo000OOol005]oo`03001oogoo08aoo`03
000k7c/O00lk7`03000o7clO00do7`030016odKo00m6o`030016oTKn0116oP03001:gD[M00m:g@03
001:gD[M011:g@03001>gDkM00M>gA8000U>NP03001BNU9j011BNP03001BNU9j015BNP03001BVU:J
011BVP03001BVU:J015BVP03001BVU:J015BVP03001BVU:J011BVP03001F^UJj019F^P03001F^eJk
019F^`03001F^`0000@000eFVP03001F^UJj019F^P03001F^UJj019F^P03001FfeKK019Ff`03001F
feKK00<0015Jo003001K75/L01=K7003001K7E/M009K7@<000mGOP03001GOUMn00IGOP<000a?W`03
001CWe>O00=CW`<0011?W`800004Dil00000000BDgl00`00DgmCO`03Dgl3000=Egl00`00EgmGO`07
Egl3000:Egl00`00EgmGO`07Egl30009Dil01000Oomoo`007goo001KOol00`00Oomoo`2=OolL0006
?al00`00A_m6o`0?A_l00`00A_i6oP07A_hg0009CWX00`00CWY>NP0?CWX00`00DWYBNP0ADWX00`00
DWYBNP0@DWX00`00DYYBVP0ADYX00`00DYYBVP0@DYX00`00DYYBVP0ADYX00`00DYYBVP0ADYX00`00
E[YF^P0AE[X00`00E[]F^`0@E[/4000BEYX00`00E[YF^P0BE[X00`00E[YF^P0BE[X00`00E]]Ff`0A
E]/4000DF_`00`00FaaK700CFa`00`00Fad00002000BEgh00`00EgiGOP03Egh3000@Cil00`00Dil0
0002000BCil4000EDgl00`00DgmCO`03000AEgl00`00EgmGO`03Egl3000=Egl00`00EgmGO`04Egl3
000=Dil01000Oomoo`007Woo001KOol00`00Oomoo`2?Ool00`007YhNWP0=7Yh00`00=[hf_P07=[hR
0009AY`00`00BW]:N`0?BW/00`00CWY>NP0@CWX00`00CWY>NP0?CWX00`00CWY>NP0@CWX00`00DWYB
NP0@DWX00`00DWYBNP0ADWX00`00DYYBVP0@DYX00`00DYYBVP0@DYX00`00DYYBVP0ADYX00`00DYYB
VP0ADYX00`00E[YF^P0BE[X00`00E[]F^`0:E[/50002EYT00`00EYYFVP0BEYX00`00E[YF^P0BE[X0
0`00E[YF^P0AE[X00`00E]]Ff`0>E]/30002F_/00`00F_aJo00DF_`00`00FaaK700AFa`3000FEgh0
0`00Egh00002000BCil3000BCil30002Dgl00`00DgmCO`0CDgl4000DEgl00`00EgmGO`03000AEgl0
0`00EgmGO`03000@Dil01000Oomoo`007Woo001KOol4002?Ool00`007YhNWP0=7Yh00`00=[hf_P0=
=[h00`00@Ye2W@0?@Yd00`00AYa6W00@AY`00`00BW]:N`0?BW/00`00CWY>NP0?CWX00`00CWY>NP0@
CWX00`00CWY>NP0?CWX00`00DWYBNP0@DWX00`00DWYBNP0ADWX00`00DYYBVP0@DYX00`00DYYBVP0A
DYX00`00DYYBVP0@DYX00`00DYYBVP0ADYX00`00E[YF^P0BE[X00`00E[]F^`05E[/50007EYT00`00
EYYFVP0BEYX00`00E[YF^P0BE[X00`00E[YF^P0BE[X00`00E]]Ff`0:E]/30006F_/00`00F_aJo00C
F_`00`00FaaK700>Fa`30002Egh00`00EgiGOP0CEgh3000BCil30003Cil00`00Cim?W`0<Cil30005
Dgl2000ADgl30002Egh00`00EgmGO`0BEgl4000CEgl4000BDil30002Ool00`00Oomoo`0KOol005]o
o`03001oogoo095oo`8000hNWP03000f_SJn00df_P030012WD:M00m2W@030016W4JL00m6W003001:
NdYk00m:N`03001>NTij011>NP03001>NTij00m>NP03001>NTij00m>NP03001BNU9j015BNP03001B
NU9j011BNP03001BVU:J011BVP03001BVU:J015BVP03001BVU:J015BVP03001BVU:J011BVP03001F
^UJj019F^P03001F^eJk00D000eFV@03001FVUJJ015FVP03001F^UJj019F^P03001F^UJj019F^P03
001FfeKK00IFf`@000UJn`03001Jo5[l01=Jo003001K75/L00]K70<000IGOP03001GOUMn00mGOP<0
00=?W`03001?WdnO00a?W`<000M?W`03001?WdnO00Q?W`<000QCO`8000iCO`<000IGOP03001GOeMo
00iGO`<0009GO`03001GOeMo00mGO`<0009CW`03001CWe>O00iCW`<0009?O`04001oogoo000MOol0
05]oo`03001oogoo09=oo`03000NWQjN00`NWP03000f_SJn00df_P030012WD:M00i2W@030016W4JL
00m6W003001:NdYk00m:N`03001>NTij011>NP03001>NTij00m>NP03001>NTij011>NP03001BNU9j
011BNP03001BNU9j011BNP03001BVU:J015BVP03001BVU:J011BVP03001BVU:J015BVP03001BVU:J
015BVP03001F^UJj011F^P@0019FV@03001FVUJJ019FVP03001F^UJj015F^P03001F^UJj019F^P03
001FfeKK00=Ff`<000iJn`03001Jo5[l01=Jo003001K75/L00IK70@000YGOP03001GOUMn00]GOP<0
00M?W`03001?WdnO00Q?W`<000]?W`03001?WdnO00A?W`<000]CO`03001CO`0000UCO`@000UGOP03
001GOeMo00]GO`<000IGO`03001GOeMo00]GO`<000ICW`03001CWe>O00YCW`<000I?O`04001oogoo
000LOol005]oo`03001oogoo09Aoo`03000NWQjN00`NWP03000f_SJn00`f_P030012WD:M00m2W@03
0016W4JL00m6W003001:NdYk00m:N`03001>NTij00m>NP03001>NTij011>NP03001>NTij00m>NP03
001BNU9j011BNP03001BNU9j015BNP03001BVU:J011BVP03001BVU:J015BVP03001BVU:J011BVP03
001BVU:J015BVP03001F^UJj00]F^PD0009FV@03001FVEJI015FV@03001FVUJJ019FVP03001F^UJj
019F^P03001F^UJj019F^P03001Ff`000080015Jn`03001Jo5[l01=Jo003001K75/L00=K70<000mG
OP03001GOUMn00MGOP<000]?W`03001?WdnO00A?W`<000m?W`03001?WdnO00<000iCO`04001COe=o
0005Dgl3000>Egh00`00EgmGO`07Egl3000:Egl00`00EgmGO`07Egl30009Dil00`00DimCW`07Dil3
000:Cgl00`00Ool0000LOol005]oo`03001oogoo09Eoo`<000/NWP03000f_SJn00df_P030012WD:M
00i2W@030016W4JL00m6W003001:NdYk00m:N`03001>NTij011>NP03001>NTij00m>NP03001>NTij
00m>NP03001BNU9j011BNP03001BNU9j015BNP03001BVU:J011BVP03001BVU:J015BVP03001BVU:J
015BVP03001BVU:J011BVP03001F^UJj00IF^PD000MFV@03001FVEJI015FV@03001FVUJJ019FVP03
001F^UJj019F^P03001F^UJj011F^P@001AJn`03001Jo5[l01=Jo003001K75/L00<0019GOP03001G
OUMn00AGOP<000m?W`03001?WdnO00<0015?W`@0015CO`04001COe=o0002Dgl3000BEgh00`00EgmG
O`03Egl3000=Egl00`00EgmGO`04Egl3000=Dil00`00DimCW`03Dil3000=Cgl01000Oomoo`006goo
001KOol00`00Oomoo`2GOol600077Yh00`00=[hf_P0==[h00`00@Ye2W@0>@Yd00`00AYa6W00?AY`0
0`00BW]:N`0>BW/00`00CWY>NP0@CWX00`00CWY>NP0?CWX00`00CWY>NP0?CWX00`00DWYBNP0ADWX0
0`00DWYBNP0@DWX00`00DYYBVP0@DYX00`00DYYBVP0ADYX00`00DYYBVP0ADYX00`00DYYBVP0ADYX0
0`00E[YF^P05000=EYT00`00EYUFV@0AEYT00`00EYYFVP0BEYX00`00E[YF^P0AE[X00`00E[YF^P0=
E[X30002F]/00`00F_]Jn`0DF_/00`00F_aJo00BF_`3000FEgh00`00EgiGOP03000ACil4000@Cil4
0002Dgl00`00DgmCO`0@Dgl00`00Dgl00003000EEgh00`00EgmGO`03000AEgl00`00EgmGO`03000@
Dil00`00DimCW`03000ACgl00`00Ool0000KOol005]oo`03001oogoo09Qoo`8000=<@0@000@NWP03
000f_SJn00`f_P030012WD:M00i2W@030016W4JL00m6W003001:NdYk00m:N`03001>NTij00m>NP03
001>NTij011>NP03001>NTij00m>NP03001BNU9j011BNP03001BNU9j015BNP03001BVU:J011BVP03
001BVU:J011BVP03001BVU:J015BVP03001BVU:J00iBVPH0019FV@03001FVEJI015FV@03001FVUJJ
019FVP03001F^UJj019F^P03001F^UJj00UF^P<000IJf`03001Jne[k01=Jn`03001Jo5[l00mJo0<0
0003Fgh005Mn01IGOP<0015?W`<000=;W`03001?WdnO00Y?W`@000MCO`03001COe=o00eCO`@0009G
GP03001GOUMn01=GOP@001=GO`@0019CW`@001=?O`<00003Ool007oo01Uoo`00Fgoo00<007ooOol0
VWoo00<004a0C40014a01P003SJn00<004:M@Yd03T:M00<004JLAY`03dJL00<004YkBW/03TYk00<0
04ijCWX044ij00<004ijCWX03dij00<004ijCWX03dij00<0059jDWX0459j00<0059jDWX04E9j00<0
05:JDYX045:J00<005:JDYX04E:J00<005:JDYX045:J00<005:JDYX01e:J1`000eIh00<005JIEYT0
4UJI00<005JIEYT04EJI00<005JJEYX04UJJ00<005JjE[X04UJj00<005JjE[X01UJj0`002E[K00<0
05[kF_/055[k00<005[lF_`02e[l0`001E]n00<005MnEgh04EMn0`0000=;_`00Cil03TnO0`001d^O
00<004nOCil01DnO100035=o00<005=oDgl025=o10000UMN00<005MNEeh00UMN00<005MnEgh03eMn
0`000UMo00<005MoEgl03eMo0`000TnO00<005>ODil03U>O0`000T^O00<004moCgl03Tmo10000T]o
00<007oo00006Woo000QOol4000>Ool3000=Ool6000BOol00`00Oomoo`2KOol20009C405000;=[h0
0`00@Ye2W@0>@Yd00`00AYa6W00>AY`00`00BW]:N`0?BW/00`00CWY>NP0?CWX00`00CWY>NP0?CWX0
0`00CWY>NP0?CWX00`00DWYBNP0ADWX00`00DWYBNP0@DWX00`00DYYBVP0@DYX00`00DYYBVP0ADYX0
0`00DYYBVP0ADYX00`00DYYBVP06000:EWP00`00EYUFV@0BEYT00`00EYUFV@0AEYT00`00EYYFVP0C
EYX00`00E[YF^P0AE[X00`00E[YF^P03E[X3000<F]/00`00F_]Jn`0DF_/00`00F_aJo008F_`30009
Fgh00`00EgiGOP0=Egh30005Bkl00`00Cim?W`08Cil4000;Bil00`00Cim?W`04000@Dgl00`00DgmC
O`05Dgl30006Eeh00`00EeiGGP02Eeh00`00EgiGOP0<Egh30006Egl00`00EgmGO`0;Egl30006Cil0
0`00DimCW`0:Dil30006Bil00`00Cgm?O`09Cgl40007Bgl00`00Ool0000IOol001moo`P000]oo`D0
00Yoo`X000moo`03001oogoo09ioo`03001<@4a000M<@004000MVQfJ7IX60005=[h00`00@Ye2W@0>
@Yd00`00AYa6W00>AY`00`00BW]:N`0?BW/00`00CWY>NP0?CWX00`00CWY>NP0@CWX00`00CWY>NP0?
CWX00`00DWYBNP0@DWX00`00DWYBNP0ADWX00`00DYYBVP0?DYX00`00DYYBVP0ADYX00`00DYYBVP0>
DYX6000AEWP00`00EYUFV@0BEYT00`00EYUFV@0AEYT00`00EYYFVP0BEYX00`00E[YF^P0BE[X00`00
E[X00002000@F]/00`00F_]Jn`0DF_/00`00F_aJo005F_`2000<Fgh00`00EgiGOP0:Egh30009Bkl0
0`00Cim?W`04Cil3000>Bil4000EDgl00`00DgmCO`040009Eeh00`00EeiGGP03Eeh00`00EgiGOP07
Egh40009Egl00`00EgmGO`07Egl40009Cil00`00DimCW`07Dil3000:Bil00`00Cgm?O`05Cgl3000;
Bgl00`00Ool0000IOol001moo`8000Aoo`8000]oo`D000Yoo`<000Eoo`<000ioo`03001oogoo09mo
o`03001<@4a000M<@003000MVQfJ00HMVPD00003=[h004:M00m2W@030016W4JL00i6W003001:NdYk
00i:N`03001>NTij011>NP03001>NTij00m>NP03001>NTij00m>NP03001BNU9j011BNP03001BNU9j
015BNP03001BVU:J011BVP03001BVU:J011BVP03001BVU:J00MBVPL000=FN003001FN5Ih015FN003
001FVEJI019FV@03001FVEJI015FV@03001FVUJJ019FVP03001F^UJj011F^P@001=Jf`03001Jne[k
01AJn`03001Jo5[l009Jo0<000mKOP03001GOUMn00IGOP<000e;_`03001?WdnO00<000i;W`<0009G
O`03001COe=o01=CO`@000iGGP03001GGUMN00=GGP03001GOUMn00=GOP<000iGO`03001GOeMo00=G
O`<000i?W`03001CWe>O00=CW`<000i;W`03001?Odmo00@000m;O`03001oo`0001Qoo`007Woo0P00
1Woo0P002Woo1@004goo0P003Woo1`00W7oo00<004a0C4001Ta000<001fJ7IX02afJ1P0034:M00<0
04JLAY`03TJL00<004YkBW/03dYk00<004ijCWX03dij00<004ijCWX03dij00<004ijCWX03dij00<0
059jDWX04E9j00<0059jDWX0459j00<005:JDYX045:J00<005:JDYX04E:J00<005:JDYX01P002UIh
00<005IhEWP04EIh00<005JIEYT04UJI00<005JIEYT04EJI00<005JJEYX04eJJ00<005JjE[X02eJj
10000U[K00<005[KF]/04e[K00<005[kF_/04e[k00<005[l00000P004U]n00<005MnEgh00eMn0`00
3d^o10003T^O0`001UMo00<005=oDgl03e=o0`000UMN00<005MNEeh03EMN00<005MNEeh00eMN00<0
05MnEgh00`004EMo00<005MoEgl00`004DnO00<005>ODil00`0044^O10004d]o00<007oo000067oo
000NOol20006Ool2000;Ool3000EOol2000=Ool00`00Oomoo`2QOol00`00C41<@005C4000`007IXM
VP0=7IX01000?OTmnCgi1P001d:M00<004JLAY`03TJL00<004YkBW/03TYk00<004ijCWX03dij00<0
04ijCWX03dij00<004ijCWX044ij00<0059jDWX0459j00<0059jDWX0459j00<005:JDYX045:J00<0
05:JDYX03U:J1P004EIh00<005IhEWP045Ih00<005JIEYT04UJI00<005JIEYT04UJI00<005JJEYX0
4UJJ00<005JjE[X01eJj10001e[K00<005[KF]/04U[K00<005[kF_/04e[k0P005U]n00<005Mn0000
0P003d^o0`0014^O00<004^OBil024^O0`002UMo00<005=oDgl02e=o0`001UMN00<005MNEeh035MN
00<005MNEeh00UMN10004eMo10004dnO10003d^O10000TMo00<004]oBgl04D]o0`0000=oo`00Ool0
5Woo000MOol20008Ool2000ROol2000=Ool00`00Oomoo`2ROol00`00C41<@005C4000`007IXMVP0<
7IX00`00?OTmn@07?OT600000d:M0016W00?AY`00`00BW]:N`0?BW/00`00CWY>NP0?CWX00`00CWY>
NP0?CWX00`00CWY>NP0?CWX00`00DWYBNP0@DWX00`00DWYBNP0ADWX00`00DYYBVP0?DYX00`00DYYB
VP07DYX70003EUP00`00EWQFN00AEWP00`00EWQFN00AEWP00`00EYUFV@0BEYT00`00EYUFV@0AEYT0
0`00EYYFVP0BEYX00`00E[YF^P04E[X3000;F]/00`00F]]Jf`0BF]/00`00F_]Jn`0@F_/300000e]n
001KOP0EFgh3000>Bkl30008Bil00`00Bim;W`04Bil3000>Egl00`00DgmCO`07Dgl30009Eeh00`00
EeiGGP0<Eeh00`00Eeh000020002Egl00`00EgmGO`0?Egl30002Cil00`00Cim?W`0>Cil40003Ail0
0`00Bim;W`09Bil40007Agl00`00Bgm;O`0;Bgl50002Ael00`00Ool0000GOol001eoo`8000Qoo`80
029oo`8000eoo`03001oogoo0:=oo`03001<@4a000A<@003000MVQfJ00dMVP03000mnCgi00`mn@H0
00e6W003001:NdYk00i:N`03001>NTij00m>NP03001>NTij00m>NP03001>NTij00m>NP03001BNU9j
011BNP03001BNU9j015BNP03001BVU:J011BVP03001BVU:J00H000YFF003001FN5Ih015FN003001F
N5Ih015FN003001FVEJI019FV@03001FVEJI015FV@03001FVUJJ01=FVP03001F^P0000<000iJf`03
001Jfe[K01=Jf`03001Jne[k00aJn`<000EKOP03001KOU]n011KOP<000=7_P03001;_d^o00Q;_`<0
00a;W`03001;Wd^O00<0015GO`03001COe=o00ACO`<000eGGP03001GGUMN00YGGP<000IGO`03001G
OeMo00]GO`<000I?W`03001?WdnO00U?W`@000Q7W`03001;Wd^O00E;W`<000a7O`03001;Od]o00E;
O`D000Q7G`03001oo`0001Ioo`007Goo0P0027oo0P008Woo0P003Goo00<007ooOol0Y7oo00<004a0
C40014a000<001fJ7IX031fJ00<003gi?OT03Sgi00@004HGAQM65`H000M6W003001:NdYk00i:N`03
001>NTij00m>NP03001>NTij00m>NP03001>NTij00m>NP03001BNU9j015BNP03001BNU9j011BNP03
001BVU:J00aBVPL0015FF003001FN5Ih011FN003001FN5Ih015FN003001FVEJI019FV@03001FVEJI
015FV@03001FVUJJ015FVP@001=Jf`03001Jfe[K019Jf`03001Jne[k00UJn`<000UKOP03001KOU]n
00aKOP<000M7_P03001;_d^o00A;_`<000i;W`@001EGO`03001COe=o00<0011GGP03001GGUMN00MG
GP<00003Egl005Mo00MGO`03001GOeMo00MGO`<000Y?W`03001?WdnO00E?W`<000e7W`03001;Wd^O
00@000m7O`03001;Od]o00D000e7G`04001oogoo000EOol001eoo`8000Qoo`80029oo`8000eoo`03
001oogoo0:Eoo`03001<@4a000=<@003000MVQfJ00`MVP03000mnCgi00hmn@0300165dHG00M65`H0
0003AY`004Yk011:N`03001>NTij00m>NP03001>NTij00m>NP03001>NTij00m>NP03001BNU9j011B
NP03001BNU9j015BNP03001BVU:J009BVPT000AFE`03001FF5IH015FF003001FN5Ih015FN003001F
N5Ih011FN003001FVEJI019FV@03001FVEJI019FV@03001FVUJJ00eFVP<0009J^P03001Jfe[K019J
f`03001Jfe[K01=Jf`03001Jne[k00EJn`<000aKOP03001KOU]n00UKOP<000]7_P03001;_d^o00<0
00e;W`@0009GO`03001GOeMo01=GO`@001AGGP03001GGUMN00=GGP<000AGO`03001GOeMo00IGO`03
001GOeMo00AGO`<000i?W`03001?WdnO00@000m7W`@00197O`@001=7G`03001oo`0001Eoo`007Goo
0P0027oo0P008Goo0P003Woo00<007ooOol0YWoo00<004a0C4000Ta000<001fJ7IX031fJ00<003gi
?OT03Sgi00<004HGAQL03DHG20002dYk00<004ijCWX03dij00<004ijCWX03dij00<004ijCWX03dij
00<0059jDWX0459j00<0059jDWX0359j2P003EIG00<005IHEUP04EIH00<005IhEWP04EIh00<005Ih
EWP04EIh00<005JIEYT04EJI00<005JIEYT04UJI00<005JJEYX02UJJ0`001EZj00<005[KF]/04U[K
00<005[KF]/04e[K00<005[kF_/00U[k0`0045]n00<005]nFgh01U]n0P003DNn100034^O10001eMo
00<005MoEgl03eMo0`000UMN00<005MNEeh04eMN00<005MNEeh00`001eMo00<005MoEgl01eMo00<0
05MoEgl00`0044nO10003dNO10000Smo00<004MoAgl034Mo1@000T=o00<004MOAel04TMO00@007oo
Ool001Aoo`007Goo0P0027oo0P006Goo0P001Goo0`003Woo00<007ooOol0Ygoo00<004a0C4000Ta0
00<001fJ7IX031fJ00<003gi?OT03Sgi00<004HGAQL03THG00<004hGCQL00dhG2@000TYk00<004ij
CWX03dij00<004ijCWX03dij00<004ijCWX03dij00<0059jDWX04E9j00<0059jDWX00U9j2@001EIG
00<005IGEUL03eIG00<005IHEUP04EIH00<005IhEWP04EIh00<005IhEWP04EIh00<005JIEYT04UJI
00<005JIEYT04EJI00<005JJEYX01UJJ10002EZj00<005[KF]/04U[K00<005[KF]/04U[K00<005[k
00000P004e]n00<005]nFgh00e]n0`0034Nn0`0014NO0P001d^O0`0035Mo00<005MoEgl02eMo0`00
1UMN00<005MNEeh04EMN10002UMo00<005MoEgl01eMo0`0044nO0`000d>N00<004NOAil02DNO1000
1cmo00<004MoAgl01TMo1@0024=o00<004MOAel03dMO100000=oo`00Ool04goo000MOol20008Ool2
000IOol9000?Ool00`00Oomoo`2XOol01@00C41<@4a000003QfJ00<003gi?OT03Sgi00<004HGAQL0
3THG00<004hGCQL034hG3@0024ij00<004ijCWX03dij00<004ijCWX03dij00<0059jDWX01e9j3P00
3UIG00<005IGEUL045IG00<005IHEUP045IH00<005IhEWP04EIh00<005IhEWP04EIh00<005JIEYT0
4UJI00<005JIEYT04EJI00<005JJEYX00eJJ0`003EZj00<005[KF]/04U[K00<005[KF]/04U[K0P00
5e]n00<005]n00000P0034Nn0`002DNO00<004^OBil0100045Mo00<005MoEgl01eMo0`002EMN00<0
05MNEeh03UMN0`000UMn00<005MoEgl02EMo00<005MoEgl015Mo0`0000=?W`00Cil03DnO0`001d>N
00<004NOAil01DNO0`0033mo00<004MoAgl01@003T=o00<004MOAel01dMO1`000dMO00@007ooOol0
01=oo`007Goo0P0027oo0P006Goo0P0000=oo`0000000`0047oo00<007ooOol0Z7oo0P000Ta000<0
01fJ7IX031fJ00<003gi?OT03Sgi00<004HGAQL03THG00<004hGCQL03dhG00<004hGCQL01dhG=P00
2E8g00<005IGEUL045IG00<005IGEUL045IG00<005IHEUP04EIH00<005IhEWP045Ih00<005IhEWP0
4UIh00<005JIEYT04EJI00<005JIEYT04UJI00<005JJ00000P0045Zj00<005[KF]/04e[K00<005[K
F]/03U[K0`0000=KOP00Fgh05U]n0`002dNn0`002dNO100055Mo00<005MoEgl015Mo0`003EMN00<0
05MNEeh02UMN0`001UMn00<005MoEgl025Mo00@005MoEgmGO`<000E?W`03001?WdnO00Q?W`<000]3
WP030017WdNO00@000hoO`@001=3O`040017GdMOAel6000;Ael00`00Ool0000COol001ioo`8000Io
o`8001Yoo`8001Ioo`03001oogoo0:Qoo`03001jJ@00009<@003000MVQfJ00`MVP03000mnCgi00dm
n@0300165dHG00i65`03001>5dhG00m>5`03001>5dhG00m>5`03001B=e8g00mB=`03001B=e8g00mB
=`03001B=e8g011B=`03001FEeIG015FE`03001FEeIG00mFE`03001FF5IH015FF003001FN5Ih015F
N003001FN5Ih015FN003001FVEJI015FV@03001FVEJI011FV@@001=J^P03001Jfe[K01=Jf`03001J
fe[K00]Jf`<000EKOP03001KOU]n015KOP<000<oW@8000I7_P<000]7W`<0009GO`03001GOeMo01AG
O`03001GOeMo00<0011GGP03001GGUMN00MGGP<000UGOP03001GOeMo00QGO`@000U?W`03001?WdnO
00A?W`<000e3WP@000doO`D0008oO`030013Od=o0113O`H00157G`04001oogoo000BOol001ioo`80
00Ioo`8001Yoo`8001Ioo`03001oogoo0:Uoo`05001jJ@00C400000>7IX00`00?OTmn@0=?OT00`00
AQM65`0?AQL00`00CQM>5`0>CQL00`00CQM>5`0?CQL00`00DSMB=`0?DSL00`00DSMB=`0?DSL00`00
DSMB=`0@DSL00`00EUMFE`0AEUL00`00EUMFE`0?EUL00`00EUQFF00AEUP00`00EWQFN00AEWP00`00
EWQFN00AEWP00`00EYUFV@0BEYT00`00EYUFV@0<EYT30002F[X00`00F[YJ^P0CF[X00`00F]]Jf`0B
F]/00`00F]]Jf`08F]/30009Fgh00`00FgiKOP0=Fgh30008?id00`00Aki7_P03000;Ail30006Egl0
0`00EgmGO`0BEgl4000DEeh00`00EeiGGP03Eeh3000=Egh00`00EgmGO`06Egl2000=Cil00`00Cim?
W`03000;@ih50003=gh00`00?gloO`06?gl50008?gl00`00@gm3O`08@gl70003@el00`00Aem7G`0B
Ael00`00Ool0000BOol001moo`8000Aoo`8001]oo`8001Eoo`D00:Qoo`06001jJGYY001<@0003AfJ
00<003gi?OT03Cgi00<004HGAQL03dHG00<004hGCQL03ThG00<004hGCQL03dhG00<0058gDSL03e8g
00<0058gDSL03e8g00<0058gDSL04E8g00<005IGEUL045IG00<005IGEUL03eIG00<005IHEUP04EIH
00<005IhEWP04EIh00<005IhEWP04EIh00<005JIEYT04UJI00<005JIEYT02EJI0`001EZj00<005Zj
F[X04eZj00<005[KF]/04e[K00<005[KF]/01E[K0P003E]n00<005]nFgh02E]n0`002SnM10002dNO
0`002UMo00<005MoEgl03EMo10000U/n00<005MNEeh04eMN00<005MNEeh00`004EMn00<005MoEgl0
0UMo0`0000=?W`00Cil02dnO10002D>N1@002CMn00<003mo?gl01@003Smo00@004=o@gm3O`H000]3
G`030017GdMO0157G`04001oogoo000AOol001moo`P001]oo`X000ioo`03001oogoo0:Uoo`04001j
JGYYNVT2000=7IX00`00?OTmn@0>?OT00`00AQM65`0>AQL00`00CQM>5`0?CQL00`00CQM>5`0>CQL0
0`00DSMB=`0@DSL00`00DSMB=`0?DSL00`00DSMB=`0@DSL00`00EUMFE`0@EUL00`00EUMFE`0@EUL0
0`00EUQFF00@EUP00`00EWQFN00AEWP00`00EWQFN00BEWP00`00EYUFV@0AEYT00`00EYUFV@06EYT3
0009F[X00`00F[YJ^P0BF[X00`00F]]Jf`0CF]/00`00F]]Jf`02F]/3000?Fgh00`00FgiKOP07Fgh2
000:?id30004?ih20006Ail3000>Egl00`00EgmGO`08Egl40007Fch00`00EeiGGP0AEeh4000DEgh0
0`00Egl000020004Cil00`00Cim?W`07Cil30004=gd20002@ih5000==gh4000A?gl6000A@el00`00
Aem7G`0?Ael400000goo001oo`0@Ool0025oo`@001eoo`X000eoo`03001oogoo0:]oo`05001jJGYY
NVT0000>7IX00`00?OTmn@0=?OT00`00AQM65`0>AQL00`00CQM>5`0?CQL00`00CQM>5`0?CQL00`00
DSMB=`0?DSL00`00DSMB=`0?DSL00`00DSMB=`0@DSL00`00EUMFE`0@EUL00`00EUMFE`0@EUL00`00
EUQFF00AEUP00`00EWQFN00AEWP00`00EWQFN00AEWP00`00EYUFV@0AEYT00`00EYUFV@03EYT3000<
F[X00`00F[YJ^P0CF[X00`00F]]Jf`0BF]/00`00F]/00002000CFgh00`00FgiKOP03Fgh30009?id3
0009?ih00`00Aim7W`03000AEgl00`00EgmGO`05Egl3000;Fch00`00EeiGGP0>Eeh30002Egh00`00
EgiGOP0CEgh20007Cil00`00Cim?W`04Cil30007=gd4000==gh50004>gl00`00?gloO`08?gl60003
?el00`00@em3G`0B@el00`00Aem7G`07Ael70003Ael4000@Ool005Uoo`03001oogoo0:]oo`03001j
JGYY009jJ@8000`MVP03000mnCgi00dmn@0300165dHG00i65`03001>5dhG00m>5`03001>5dhG00m>
5`03001B=e8g00mB=`03001B=e8g00mB=`03001B=e8g011B=`03001FEeIG011FE`03001FEeIG011F
E`03001FF5IH015FF003001FN5Ih015FN003001FN5Ih015FN003001FVEJI019FV@03001FV@000080
00mJ^P03001J^UZj01=J^P03001Jfe[K019Jf`8001MKOP03001KOP00008000ToW@<000/oWP@001EG
O`03001GOeMo00@000mK?P03001GGUMN00YGGP<000IGOP03001GOUMn00mGOP<0009;_`03001?WdnO
00A?W`04001?WdnOCil30006=gd40004;e`00`00=ghgOP06=gh4000:>gl01000?gloOcmo1P002SmO
00<004=O@el04D=O00@004MOAem7G`H000]7G`03001oo`00011oo`00FGoo00<007ooOol0Zgoo00<0
07YYNVT00WYY00<0000A00002afJ00<003gi?OT03Cgi00<004HGAQL03THG00<004hGCQL03dhG00<0
04hGCQL03dhG00<0058gDSL03e8g00<0058gDSL03e8g00<0058gDSL0458g00<005IGEUL045IG00<0
05IGEUL045IG00<005IHEUP04EIH00<005IhEWP04EIh00<005IhEWP04EIh00<005JIEYT045JI1000
4eZj00<005ZjF[X04UZj00<005[KF]/03e[K0`0000=KOP00Fgh05U]n0`0023nM0`002SnN10000UMo
00<005MoEgl04eMo10004e/n00<005MNEeh01eMN0`002UMn00<005MnEgh02eMn0`001T^o00<004nO
Cil00dnO10001CMm10002BmL00<003Mn=gh01@0033]o1P004CmO00<004=O@el03D=O1`004DMO00<0
07oo000047oo001IOol00`00Oomoo`2/Ool01@00NVUjJGYY00000P0A00<001fJ7IX021fJ00<003gi
?OT03Cgi00<004HGAQL03THG00<004hGCQL03dhG00<004hGCQL03dhG00<0058gDSL03e8g00<0058g
DSL03e8g00<0058gDSL0458g00<005IGEUL04EIG00<005IGEUL03eIG00<005IHEUP04EIH00<005Ih
EWP04EIh00<005IhEWP04UIh00<005JIEYT035JI0`000UZI00<005ZjF[X04UZj00<005ZjF[X04UZj
00<005[KF]/03E[K0P001E]n00<005]nFgh04E]n0`000c=k0`000SnM0`002CnN10001eMo00<005Mo
Egl03UMo10000U/m00<005/nFch04e/n00<005MNEeh00eMN0`003UMn00<005MnEgh01eMn0`002T^o
00<004nOCil00`001CMm0`002bmL1@002S]o1`000c]O00<003mO?el04SmO00<004=O@el00d=O2@00
14=O00<004MOAel04TMO0P0047oo001IOol00`00Oomoo`2/Ool01@00NVUjJGYY00000`0A00<001fJ
7IX021fJ00<003gi?OT03Cgi00<004HGAQL03THG00<004hGCQL03ThG00<004hGCQL03dhG00<0058g
DSL03e8g00<0058gDSL03e8g00<0058gDSL04E8g00<005IGEUL045IG00<005IGEUL045IG00<005IH
EUP04EIH00<005IhEWP04EIh00<005IhEWP04EIh00<005JIEYT02EJI0`001EZI00<005ZjF[X04UZj
00<005ZjF[X04eZj00<005[KF]/02E[K0`0025]n00<005]nFgh03E]n0`001c=k10002CnN0`0035Mo
00<005MoEgl02EMo10001e/m00<005/nFch04U/n00<005MNEeh00`004EMn00<005MnEgh015Mn0`00
34^o1@0000<gO@00=gd010001bmL1`001C=M00@003]o>glkO`H000/kG`03000oGcmO00doG`X000i3
G`030017GdMO0157G`80011oo`00FGoo00<007ooOol0[7oo00<007YYNVT00WYY00D0000A01404@00
00TMVP03000mnCgi00dmn@0300165dHG00i65`03001>5dhG00i>5`03001>5dhG00m>5`03001B=e8g
00mB=`03001B=e8g00mB=`03001B=e8g015B=`03001FEeIG011FE`03001FEeIG011FE`03001FF5IH
015FF003001FN5Ih015FN003001FN5Ih015FN003001FVEJI00IFV@<000UJV@03001J^UZj015J^P03
001J^UZj01=J^P03001Jfe[K00MJf`8000]KOP03001KOU]n00YKOP<000LcN`<000@gO0<0008oWP@0
011GO`03001GOeMo00EGO`<000]K?@03001K?U/n019K?P<001EGOP03001GOUMn00<000a;_`<000@_
F`D000@_G0H000XcG@H0018kG`03000oGcmO00<oG`T000DoG`030013Gd=O0153G`030017GdMO00a7
G`H0011oo`00FGoo00<007ooOol0[Goo00D007YYNVUjJ@0000@04@8000LMVP03000mnCgi00dmn@03
00165dHG00i65`03001>5dhG00i>5`03001>5dhG00m>5`03001B=e8g011B=`03001B=e8g00mB=`03
001B=e8g011B=`03001FEeIG011FE`03001FEeIG011FE`03001FF5IH015FF003001FN5Ih015FN003
001FN5Ih015FN003001FVEJI00=FV@<000aJV@03001J^UZj019J^P03001J^UZj019J^P03001Jfe[K
00AJf`<000iKOP03001KOU]n00IKOP<000LcN`<000PgO0@001EGO`03001GOeMo00@000mK?@03001K
?U/n00iK?P<00003Fgh005Mn01AGOP@000];_`@000@_F`<0008O6@03000O6@0000@000XcG@H000@g
G`03000kGc]O00lkG`P000loG`030013Gd=O0113G`030017GdMO00=7G`T000Eoo`03001oogoo00io
o`00FGoo00<007ooOol0[Goo00D007YYNVUjJ@0000H04@03000MVQfJ00@MVP03000mnCgi00dmn@03
00165dHG00i65`03001>5dhG00m>5`03001>5dhG00i>5`03001B=e8g011B=`03001B=e8g00mB=`03
001B=e8g011B=`03001FEeIG011FE`03001FEeIG011FE`03001FF5IH015FF003001FN5Ih015FN003
001FN5Ih019FN003001FV@00008000mJV@03001J^UZj019J^P03001J^UZj019J^P03001Jfe[K009J
f`80015KOP03001KOU]n00=KOP<000LcN`<000LgO0@0009CG`03001GOeMo01=GO`@001AK?@03001K
?U/n00YK?P<000EKOP03001GOUMn00mGOP<000A;_`03001;_d^o00A;_`@000@_F`@0008O6@D000@W
?08000<cG@H000/gG`03000kGc]O00PkG`H000<oG`03000oGcmO018oG`030013Gd=O00a3G`T000io
o`03001oogoo00ioo`00FGoo00<007ooOol0[Goo00D007YYNVUjJ@0000L04@03000MVQfJ00@MVP03
000mnCgi00`mn@0300165dHG00i65`03001>5dhG00m>5`03001>5dhG00m>5`03001B=e8g00mB=`03
001B=e8g00mB=`03001B=e8g011B=`03001FEeIG011FE`03001FEeIG011FE`03001FF5IH015FF003
001FN5Ih015FN003001FN5Ih011FN0@0019JV@03001J^UZj019J^P03001J^UZj01=J^P@001AKOP03
001KOP00008000LcN`<000HgO0@000MCG`03001GOeMo00mGO`<0009K7@03001K?E/m01=K?@03001K
?U/n00MK?P<000UKOP03001GOUMn00]GOP<000Q;_`03001;_d^o00<000@_F`@0008O6@@000<W?003
000W?2Ll008W?0H0018gG`04000kGc]O>el6000:?el00`00?eloG`0A?el00`00@em3G`03@el9000G
Ool00`00Oomoo`0>Ool005Uoo`04001oo`00002/Ool01@00NVUjJGYY0000200A00<001fJ7IX00afJ
00<003gi?OT033gi00<004HGAQL03THG00<004hGCQL03dhG00<004hGCQL03dhG00<0058gDSL03e8g
00<0058gDSL03e8g00<0058gDSL0458g00<005IGEUL04EIG00<005IGEUL045IG00<005IHEUP04EIH
00<005IhEWP04EIh00<005IhEWP035Ih0`000UZH00<005ZIFYT04UZI00<005ZjF[X04UZj00<005Zj
F[X04EZj0P005e]n1@0013=k0`001SMl0`0035=O00<005MoEgl02eMo0`001U/M00<005/mFcd04e/m
00<005/nFch00e/n0`003E]n00<005MnEgh01eMn0`002T^o1@000bmK0`0000<O6@0000000`001RLl
1P001C=N00<003MO=el03CMO1`004CmO00<003mO?el03CmO2@0087oo00<007ooOol03Woo001IOol2
002_Ool01@00NVUjJGYY0000200A00<001fJ7IX00QfJ00<003gi?OT03Cgi00<004HGAQL03DHG00<0
04hGCQL03dhG00<004hGCQL03dhG00<0058gDSL03e8g00<0058gDSL03e8g00<0058gDSL04E8g00<0
05IGEUL045IG00<005IGEUL045IG00<005IHEUP04EIH00<005IhEWP04EIh00<005IhEWP02EIh0`00
1EZH00<005ZIFYT04UZI00<005ZjF[X04UZj00<005ZjF[X03UZj0`0000=KOP00Fgh04e]n0`001B<G
1P000cMl100045=O00<005MoEgl01eMo0`002E/M00<005/mFcd04e/m00<005/nFch00`0045]n00<0
05MnEgh015Mn0`002T^o0`0011lH2@0012Ll1P0000<cGP00<eh02C=N00<003MO=el00cMO2@0013]O
00<003mO?el04SmO00<003mO?el00cmO2@00:Goo00<007ooOol03Woo001IOol00`00Oomoo`2^Ool0
1@00NVUjJGYY00002@0A0P000afJ00<003gi?OT033gi00<004HGAQL03DHG00<004hGCQL03dhG00<0
04hGCQL03dhG00<0058gDSL03e8g00<0058gDSL03e8g00<0058gDSL04E8g00<005IGEUL045IG00<0
05IGEUL045IG00<005IHEUP04EIH00<005IhEWP04EIh00<005IhEWP01UIh0`002EZH00<005ZIFYT0
4EZI00<005ZjF[X04UZj00<005ZjF[X035Zj0P001E]n00<005]nFgh03e]n0P0012<G10001BLj1000
55=O00<005MoEgl015Mo0`003E/M00<005/mFcd04E/m100055]n00<005MnEgh00`002T^o0`000alH
20000a[i1P001c=N00<003=N<eh013=N2P003S]O00<003mO?el03CmO2P00<goo00<007ooOol03Goo
001IOol00`00Oomoo`2^Ool01@00NVUjJGYY00002`0A00@001fJ7IX000hmn@0300165dHG00i65`03
001>5dhG00i>5`03001>5dhG00m>5`03001B=e8g00mB=`03001B=e8g011B=`03001B=e8g011B=`03
001FEeIG011FE`03001FEeIG011FE`03001FF5IH015FF003001FN5Ih015FN003001FN5Ih00=FN0<0
00aJV003001JVEZI015JV@03001J^UZj019J^P03001J^UZj00YJ^P8000QKOP03001KOU]n00aKOP80
008S5`@000@W>PD0009CGP03001CGe=O01ACG`03001GOeMo00<0011K7@03001K?E/m00iK?@<0009K
GP03001KOU]n01=KOP<000Y;_`<0008O60L000036_T0000000D000D[?@03000cGS=N00<cGPT000Hg
G`03000kGc]O010kG`03000oGcmO00<oG`T003eoo`03001oogoo00eoo`00FGoo00<007ooOol0[goo
00@007YYNVT000`04@03000MVP0000hmn@0300165dHG00i65`03001>5dhG00i>5`03001>5dhG00m>
5`03001B=e8g011B=`03001B=e8g00mB=`03001B=e8g011B=`03001FEeIG011FE`03001FEeIG011F
E`03001FF5IH015FF003001FN5Ih019FN003001FN000008000mJV003001JVEZI019JV@03001J^UZj
019J^P03001J^UZj00IJ^P<000]KOP03001KOU]n00QKOP<000048aL0000000039cX50008Deh00`00
DemCG`0BDel4000DFad00`00FceK?@0:Fcd30006Feh00`00FgiKOP0?Fgh30003Akh00`00Bkm;_`04
Bkl300027aP;000::cd80003=el00`00=elgG`0:=el00`00>elkG`07>el>0016Ool00`00Oomoo`0=
Ool005Uoo`03001oogoo0:moo`04001jJGYY000=0142000>?OT00`00AQM65`0>AQL00`00CQM>5`0>
CQL00`00CQM>5`0?CQL00`00DSMB=`0@DSL00`00DSMB=`0?DSL00`00DSMB=`0@DSL00`00EUMFE`0@
EUL00`00EUMFE`0AEUL00`00EUQFF00AEUP00`00EWQFN00?EWP4000BFYP00`00FYUJV@0BFYT00`00
F[YJ^P0BF[X00`00F[YJ^P04F[X2000>Fgh00`00FgiKOP06Fgh600000bLj00000003000>Deh00`00
DemCG`0=Del40002Fa`00`00FaeK7@0CFad00`00FceK?@07Fcd30009Feh00`00FgiKOP0<Fgh30007
Akh00`00Bkm;_`0300000alH00000007000::cd60005<eh00`00=elgG`03=el00`00=elgG`07=el=
001DOol00`00Oomoo`0=Ool005Qoo`03001oogoo0;1oo`04001jJGYY000>0142000=?OT00`00AQM6
5`0>AQL00`00CQM>5`0?CQL00`00CQM>5`0>CQL00`00DSMB=`0@DSL00`00DSMB=`0?DSL00`00DSMB
=`0@DSL00`00EUMFE`0@EUL00`00EUMFE`0AEUL00`00EUQFF00AEUP00`00EWQFN00<EWP30002FWP0
0`00FYQJV00BFYP00`00FYUJV@0AFYT00`00F[YJ^P0BF[X00`00F[YJ^P02F[X2000AFgh00`00FgiK
OP03Fgh9000DDeh00`00DemCG`08Del40007Fa`00`00FaeK7@0CFad00`00FceK?@03Fcd3000=Feh0
0`00FgiKOP08Fgh3000:Akh:00059a`20003:cd6000<<eh00`00=elgG`02=el:001QOol00`00Oomo
o`0=Ool005Qoo`03001oogoo0;5oo`04001jJGYY000>0142000=?OT00`00AQM65`0=AQL00`00CQM>
5`0?CQL00`00CQM>5`0>CQL00`00DSMB=`0@DSL00`00DSMB=`0?DSL00`00DSMB=`0ADSL00`00EUMF
E`0@EUL00`00EUMFE`0@EUL00`00EUQFF00AEUP00`00EWQFN009EWP30005FWP00`00FYQJV00BFYP0
0`00FYUJV@0BFYT00`00F[YJ^P0BF[X4000DFgh00`00Fgh000070002Deh00`00DeiCGP0CDeh00`00
DemCG`05Del3000;Fa`00`00FaeK7@0CFad00`00FceK?@03000@Feh00`00FgiKOP06Fgh2000:Akh7
00099a`7000?<eh9001ZOol00`00Oomoo`0=Ool005Qoo`03001oogoo0;5oo`04001jJGYY000>0140
0`00:A@0000<?OT00`00AQM65`0=AQL00`00CQM>5`0?CQL00`00CQM>5`0?CQL00`00DSMB=`0?DSL0
0`00DSMB=`0?DSL00`00DSMB=`0ADSL00`00EUMFE`0@EUL00`00EUMFE`0@EUL00`00EUQFF00AEUP0
0`00EWQFN006EWP30009FWP00`00FYQJV00AFYP00`00FYUJV@0BFYT00`00F[YJ^P0AF[X2000GFgh7
0006Deh00`00DeiCGP0CDeh00`00DemCG`04000?Fa`00`00FaeK7@0AFad4000DFeh00`00FgiKOP02
Fgh30009Akh400069a`90006;ch20005<eh90008Ool00`00Oomoo`1XOol00`00Oomoo`0=Ool005Qo
o`03001oogoo0;5oo`04001jJGYY000>01401000:A@Y50002cgi00<004HGAQL03DHG00<004hGCQL0
3dhG00<004hGCQL03dhG00<0058gDSL03e8g00<0058gDSL03e8g00<0058gDSL04E8g00<005IGEUL0
45IG00<005IGEUL045IG00<005IHEUP04EIH00<005IhEWP00eIh0`0035Yh00<005ZHFYP04EZH00<0
05ZIFYT04UZI00<005ZjF[X03UZj0`0000=KOP00Fgh04e]n1P002e=N00<005=NDeh04E=N10004e/L
00<005/MFad03U/M0`000U]N00<005]NFeh04e]N00<005]n00000P002DNn0`0000<Nn`0000001`00
3Bln2@004Goo00<007ooOol0J7oo00<007ooOol03Goo001HOol00`00Oomoo`2bOol00`00NVT0000>
01401000:A@Y52TD0P002Cgi00<004HGAQL03DHG00<004hGCQL03dhG00<004hGCQL03dhG00<0058g
DSL03e8g00<0058gDSL0458g00<0058gDSL0458g00<005IGEUL045IG00<005IGEUL04EIG00<005IH
EUP04EIH00<005Ih00000P003eYh00<005ZHFYP04EZH00<005ZIFYT04UZI00<005ZjF[X035Zj0P00
1E]n00<005]nFgh03U]n1@0045=N00<005=NDeh03E=N0`000U[l00<005/LFa`04e/L00<005/MFad0
2U/M0`001U]N00<005]NFeh04U]N0`0024Nn1`001R/m0P001Bln2@006Woo00<007ooOol0J7oo00<0
07ooOol03Goo001HOol00`00Oomoo`2bOol00`00NVT0000>01400`00:A@Y5003:A@00`00?OTmn@06
?OT00`00AQM65`0>AQL00`00CQM>5`0>CQL00`00CQM>5`0?CQL00`00DSMB=`0@DSL00`00DSMB=`0?
DSL00`00DSMB=`0@DSL00`00EUMFE`0@EUL00`00EUMFE`0AEUL00`00EUQFF00?EUP4000BFWP00`00
FYQJV00BFYP00`00FYUJV@0BFYT00`00F[YJ^P09F[X20008Fgh00`00FgiKOP0:Fgh5000CDeh00`00
DeiCGP09Deh40006F_`00`00FaaK700BFa`00`00FaeK7@07Fad3000:Feh00`00FeiKGP0>Feh30003
@ih30002Akh3000;:cd9000SOol00`00Oomoo`1XOol00`00Oomoo`0=Ool005Qoo`@00;5oo`04001j
JGYY000=01400`00:A@Y5004:A@00`00?OTmn@06?OT00`00AQM65`0=AQL00`00CQM>5`0>CQL00`00
CQM>5`0?CQL00`00DSMB=`0@DSL00`00DSMB=`0?DSL00`00DSMB=`0@DSL00`00EUMFE`0@EUL00`00
EUMFE`0AEUL00`00EUQFF00<EUP30002FWL00`00FWQJN00AFWP00`00FYQJV00BFYP00`00FYUJV@0B
FYT00`00F[YJ^P06F[X3000;Fgh00`00FgiKOP07Fgh30002Deh00`00DeiCGP0CDeh00`00DeiCGP04
Deh4000:F_`00`00FaaK700CFa`00`00FaeK7@03Fad3000=Feh00`00FeiKGP0;Feh30007@ih50004
:cd9000/Ool00`00Oomoo`1XOol00`00Oomoo`0=Ool005Qoo`03001oogoo0;=oo`03001jJ@0000d0
4@03000Y52TD00DY508000Hmn@0300165dHG00e65`03001>5dhG00i>5`03001>5dhG00m>5`03001B
=e8g011B=`03001B=e8g00mB=`03001B=e8g015B=`03001FEeIG011FE`03001FEeIG011FE`03001F
F5IH00UFF0<000EJM`03001JN5Yh019JN003001JV5ZH015JV003001JVEZI019JV@03001J^UZj00AJ
^P8000mKOP03001KOU]n00=KOP<000ICGP03001CGU=N01=CGP03001CGU=N00<000mJo003001K75/L
019K7003001K7E/M00<0015KGP03001KGU]N00MKGP<000M3WP<000039ad0000000H003Eoo`03001o
ogoo06Qoo`03001oogoo00eoo`00F7oo00<007ooOol0/goo00<007YY00003@0A00<002TD:A@01bTD
00<003gi?OT00cgi00<004HGAQL03DHG00<004hGCQL03ThG00<004hGCQL03dhG00<0058gDSL0458g
00<0058gDSL03e8g00<0058gDSL04E8g00<005IGEUL045IG00<005IGEUL045IG00<005IHEUP01UIH
0`0025Yg00<005YhFWP04UYh00<005ZHFYP04EZH00<005ZIFYT04UZI00<005ZjF[X00UZj0P004U]n
00<005]n00000P002U=N00<005=NDeh04E=N10004U[l00<005/LFa`04U/L0`0055]N00<005]NFeh0
15]N0`001d>N1`00?Goo00<007ooOol0J7oo00<007ooOol03Goo001HOol00`00Oomoo`2cOol00`00
NVT0000>01400`00:A@Y5007:A@00`00?OTmn@02?OT00`00AQM65`0=AQL00`00CQM>5`0?CQL00`00
CQM>5`0>CQL00`00DSMB=`0@DSL00`00DSMB=`0?DSL00`00DSMB=`0ADSL00`00EUMFE`0@EUL00`00
EUMFE`0AEUL00`00EUQFF002EUP3000<FWL00`00FWQJN00AFWP00`00FYQJV00BFYP00`00FYUJV@0B
FYT4000DFgh2000>Deh00`00DeiCGP0;Deh50002F_/00`00F_aJo00BF_`00`00FaaK700>Fa`30000
0e/m001KGP0EFeh00`00FeiKGP030007@ih30014Ool00`00Oomoo`1XOol00`00Oomoo`0=Ool005Qo
o`03001oogoo0;=oo`03001jJ@0000h04@03000Y52TD00PY5005000mnCgi?OT0000?AQL00`00CQM>
5`0?CQL00`00CQM>5`0?CQL00`00DSMB=`0?DSL00`00DSMB=`0?DSL00`00DSMB=`0ADSL00`00EUMF
E`0@EUL00`00EUMFE`0AEUL00`00EUP00002000?FWL00`00FWQJN00AFWP00`00FYQJV00BFYP00`00
FYUJV@0AFYT2000DFgh3000@Deh00`00DeiCGP06Deh50008F_/00`00F_aJo00AF_`00`00FaaK700<
Fa`20005Fcd00`00FeiKGP0CFeh30007@ih30017Ool00`00Oomoo`1XOol00`00Oomoo`0=Ool005Qo
o`03001oogoo0;Aoo`03001jJ@0000d04@03000Y52TD00TY50800003?OT004HG00i65`03001>5dhG
00m>5`03001>5dhG00m>5`03001B=e8g00mB=`03001B=e8g011B=`03001B=e8g011B=`03001FEeIG
011FE`03001FEeIG00mFE`@0019JM`03001JN5Yh015JN003001JV5ZH019JV003001JVEZI00mJV@80
0003Ggh005]n015KOP8001ACGP03001CGU=N00D000eJn`03001Jo5[l019Jo003001K75/L00QK70<0
00MK?@03001KGU]N011KGP<000<oW@800093WP<004Yoo`03001oogoo06Qoo`03001oogoo00eoo`00
F7oo00<007ooOol0]7oo00<007YY00003@0A00<002TD:A@02bTD00<003gi00003dHG00<004hGCQL0
3ThG00<004hGCQL03dhG00<0058gDSL0458g00<0058gDSL03e8g00<0058gDSL0458g00<005IGEUL0
45IG00<005IGEUL02eIG10000UYG00<005YgFWL04EYg00<005YhFWP04UYh00<005ZHFYP04EZH00<0
05ZIFYT03EZI0P0015mn00<005]nFgh03E]n0P0000=C?P00Deh04U=N10004U[k00<005[lF_`04U[l
00<005/LFa`01E/L0`002e/m00<005]NFeh035]N0`001cnM0`00CGoo00<007ooOol0J7oo00<007oo
Ool03Goo001HOol00`00Oomoo`2dOol00`00NVT0000=01400`00:A@Y500<:A@2000?AQL00`00CQM>
5`0>CQL00`00CQM>5`0?CQL00`00DSMB=`0@DSL00`00DSMB=`0?DSL00`00DSMB=`0ADSL00`00EUMF
E`0?EUL00`00EUMFE`07EUL40006FUL00`00FWMJM`0AFWL00`00FWQJN00BFWP00`00FYQJV00BFYP0
0`00FYUJV@0:FYT20007Ggh00`00FgiKOP09Fgh30004Dch00`00DeiCGP0=Deh30002F]/00`00F_]J
n`0BF_/00`00F_aJo00BF_`00`00FaaK7002Fa`2000?Fcd00`00FeiKGP08Feh30007?id3001@Ool0
0`00Oomoo`1XOol00`00Oomoo`0=Ool005Qoo`03001oogoo0;Eoo`8000d04@03000Y52TD00dY5080
00i65`03001>5dhG00i>5`03001>5dhG00m>5`03001B=e8g011B=`03001B=e8g00mB=`03001B=e8g
015B=`03001FEeIG011FE`03001FEeIG00=FE`<000YJE`03001JMeYg019JM`03001JN5Yh015JN003
001JV5ZH019JV003001JVEZI00MJV@<000YOOP03001KOU]n00IKOP8000MC?P03001CGU=N00UCGP@0
00IJf`03001Jne[k015Jn`03001Jo5[l019Jo003001K70000080015K?@03001KGU]N00IKGP8000Lo
W@<005=oo`03001oogoo06Qoo`03001oogoo00eoo`00F7oo00<007ooOol0]Goo0P003@0A00<002TD
:A@03BTD00@003fE000000a65`03001>5dhG00i>5`03001>5dhG00m>5`03001B=e8g011B=`03001B
=e8g00mB=`03001B=e8g015B=`03001FEeIG011FE`03001FE`0000<000iJE`03001JMeYg015JM`03
001JN5Yh015JN003001JV5ZH019JV003001JVEZI00EJV@8000iOOP03001KOU]n00=KOP8000YC?P03
001CGU=N00ACGP@000YJf`03001Jne[k019Jn`03001Jo5[l011Jo0<001EK?@03001KGU]N009KGP<0
00HoW@<005Ioo`03001oogoo06Uoo`03001oogoo00aoo`00Egoo00<007ooOol0]Woo0P003@0A00<0
02TD:A@03BTD00@003fE?IDmU@8000Y65`03001>5dhG00i>5`03001>5dhG00m>5`03001B=e8g011B
=`03001B=e8g00mB=`03001B=e8g015B=`03001FEeIG00iFE`@0019JE`03001JMeYg015JM`03001J
N5Yh015JN003001JV5ZH019JV003001JVEZI00=JV@80015OOP03001KOP00008000eC?P03001CGU=N
00<000iJf`03001Jne[k019Jn`03001Jo5[l00eJo0<0009K?@03001K?E/m01=K?@03001KGP000080
00HoW@<005Uoo`03001oogoo06Uoo`03001oogoo00aoo`00Egoo00<007ooOol0]goo0P00300A00<0
02TD:A@03BTD00<003fE?ID00cfE0P0024HG00<004hGCQL03dhG00<004hGCQL03ThG00<0058gDSL0
458g00<0058gDSL0458g00<0058gDSL0458g00<005IGEUL02eIG0`000UYG00<005YGFUL04EYG00<0
05YgFWL04EYg00<005YhFWP04UYh00<005ZHFYP04EZH00@005ZIFYUJV@8001=OOP8000mC?P@0019J
f`03001Jne[k015Jn`03001Jo5[l00YJo0<000IK?@03001K?E/m019K?@D000<oW@<005aoo`03001o
ogoo06Uoo`03001oogoo00aoo`00Egoo1000]Woo0P00300A00<002TD:A@03BTD00<003fE?ID01CfE
0P001THG00<004hGCQL03dhG00<004hGCQL03dhG00<0058gDSL03e8g00<0058gDSL0458g00<0058g
DSL0458g00<005IGEUL01eIG10001EYG00<005YGFUL04EYG00<005YgFWL04EYg00<005YhFWP04UYh
00<005ZHFYP04UZH0`004emn0P0035<n1@000UZj00<005[KF]/04E[K00<005[kF_/04U[k00<005[l
F_`01U[l0`002E/m00<005/mFcd03e/m0`001C^K0`00Ggoo00<007ooOol0JGoo00<007ooOol037oo
001GOol00`00Oomoo`2gOol2000<01400`00:A@Y500=:A@00`00?IDmU@07?ID00`00AQM65`03AQL0
0`00CQM>5`0?CQL00`00CQM>5`0?CQL00`00DSMB=`0@DSL00`00DSMB=`0?DSL00`00DSMB=`0ADSL0
0`00EUMFE`02EUL40009FUL00`00FUMJE`0AFUL00`00FWMJM`0AFWL00`00FWQJN00BFWP00`00FYQJ
V00AFYP2000CGgh30008Dch50007F[X00`00F]]Jf`0BF]/00`00F_]Jn`0AF_/00`00F_aJo003F_`3
000=Fcd00`00FceK?@0<Fcd20005>i/3001ROol00`00Oomoo`1YOol00`00Oomoo`0<Ool005Moo`03
001oogoo0;Qoo`0300004@0A00X04@03000Y52TD00dY5003000mUCfE00PmU@8000A65`03001>5dhG
00i>5`03001>5dhG00m>5`03001B=e8g011B=`03001B=e8g00mB=`03001B=e8g015B=`03001FE`00
008000iJE`03001JEeYG015JE`03001JMeYg015JM`03001JN5Yh015JN003001JV5ZH00mJV0800003
Gih005mn011OOP8000=C?P03001C?U<n00D000eJ^P03001Jfe[K015Jf`03001Jne[k015Jn`03001J
o5[l00<0015K?@03001K?E/m00QK?@<000@kV`<006Eoo`03001oogoo06Uoo`03001oogoo00aoo`00
Egoo00<007ooOol0^7oo00<0000A01402P0A00<002TD:A@03BTD00<003fE?ID02SfE0P000THG00<0
04hGCQL03ThG00<004hGCQL03dhG00<0058gDSL0458g00<0058gDSL03e8g00<0058gDSL03e8g1000
4EYG00<005YGFUL04EYG00<005YgFWL04EYg00<005YhFWP04EYh00<005ZHFYP03EZH0P0015nN00<0
05mnGgh02emn0`0015<n10004UZj00<005[KF]/04E[K00<005[kF_/04E[k0`0055/m00<005/mFcd0
1E/m0`0013^K0`00J7oo00<007ooOol0JGoo00<007ooOol037oo001GOol00`00Oomoo`2hOol2000;
01400`00:A@Y500=:A@00`00?IDmU@0<?ID3000@CQL00`00CQM>5`0?CQL00`00DSMB=`0@DSL00`00
DSMB=`0?DSL00`00DSMB=`0;DSL40002FSH00`00FUMJE`0@FUL00`00FUMJE`0AFUL00`00FWMJM`0A
FWL00`00FWQJN00BFWP00`00FYQJV00:FYP20007Gih00`00GgiOOP08Ggh20002Dch50002FYT00`00
F[YJ^P0AF[X00`00F]]Jf`0BF]/00`00F_]Jn`0=F_/300000elL001K?@0EFcd00`00FceK?@02Fcd2
0004>i/3001[Ool00`00Oomoo`1YOol00`00Oomoo`0<Ool005Moo`03001oogoo0;Uoo`0300004@0A
00T04@03000Y52TD00dY5003000mUCfE00hmU@<000i>5`03001>5dhG00m>5`03001B=e8g011B=`03
001B=e8g00mB=`03001B=e8g00MB=`@000IJ=P03001JEeYG011JE`03001JEeYG015JE`03001JMeYg
015JM`03001JN5Yh019JN003001JV5ZH00MJV0<000YOWP03001OOUmn00EOOPH000MJV@03001J^UZj
019J^P03001Jfe[K015Jf`03001Jne[k00YJn`<000EO7003001K?E/m01=K?@03001K?@00008000<k
V`<006ioo`03001oogoo06Uoo`03001oogoo00aoo`00Egoo00<007ooOol0^Goo00<0000A01402P0A
00<002TD:A@032TD00<003fE?ID03SfE00<005HEEQD00`002dhG00<004hGCQL03dhG00<0058gDSL0
458g00<0058gDSL0458g00<0058gDSL00e8g0`002UXf00<005YGFUL045YG00<005YGFUL04EYG00<0
05YgFWL04EYg00<005YhFWP04UYh00<005ZHFYP01EZH0P003UnN00<005mnGgh00Umn100035ZI00<0
05ZjF[X04EZj00<005[KF]/04U[K00<005[kF_/01U[k0`0025lL00<005/mFcd04e/m2000LWoo00<0
07ooOol0J7oo00<007ooOol037oo001GOol00`00Oomoo`2iOol00`0001404@0:01400`00:A@Y500<
:A@00`00?IDmU@0>?ID00`00EQEF5@03EQD40008CQL00`00CQM>5`0>CQL00`00DSMB=`0@DSL00`00
DSMB=`0@DSL00`00DSL00003000=FSH00`00FUMJE`0@FUL00`00FUMJE`0AFUL00`00FWMJM`0BFWL0
0`00FWQJN00AFWP00`00FYQJV003FYP2000AGih01000Ggh0000045ZI00<005ZjF[X04EZj00<005[K
F]/04U[K00<005[kF_/00e[k0`0035lL00<005/mFcd03e/m0`000S=j0`00MGoo00<007ooOol0J7oo
00<007ooOol037oo000;Ool4000>Ool3000?Ool3000=Ool6000BOol00`00Oomoo`2iOol00`000140
4@0:01400`00:A@Y500<:A@00`00?IDmU@0>?ID00`00EQEF5@07EQD40004CQL00`00CQM>5`0>CQL0
0`00DSMB=`0ADSL00`00DSMB=`0<DSL5000BFSH00`00FUMJE`0?FUL00`00FUMJE`0BFUL00`00FWMJ
M`0AFWL00`00FWQJN00AFWP01000FYQJV5ZH0P004enN0P004UZI00<005ZjF[X04UZj00<005[KF]/0
4E[K00<005[kF_/00`003elL00<005/mFcd035/m0`000S=j0`00N7oo00<007ooOol0J7oo00<007oo
Ool037oo0009Ool8000;Ool5000>Ool3000;Ool:000@Ool00`00Oomoo`2jOol00`0001404@090140
0`00:A@Y500<:A@00`00?IDmU@0>?ID00`00EQEF5@0;EQD300000dhG001>5`0@CQL00`00DSMB=`0@
DSL00`00DSMB=`06DSL60003ESH00`00FSIJ=P0AFSH00`00FUMJE`0@FUL00`00FUMJE`0AFUL00`00
FWMJM`0AFWL00`00FWQJN00BFWP3000CGih200000eZI001JV@0BFYT00`00F[YJ^P0AF[X00`00F]]J
f`0@F]/4000CGa`00`00FceK?@08Fcd30002<gX3001kOol00`00Oomoo`1XOol00`00Oomoo`0<Ool0
00Uoo`8000Aoo`8000]oo`D000moo`8000]oo`<000Eoo`<000moo`03001oogoo0;Yoo`0300004@0A
00T04@03000Y52TD00`Y5003000mUCfE00hmU@03001F5EHE00iF5@L000a>5`03001B=e8g011B=`03
001B=e8g00H000UF=P03001J=UXf015J=P03001JEeYG011JE`03001JEeYG015JE`03001JMeYg015J
M`03001JN5Yh015JN08001=OWP8000AJV@03001JVEZI011JV@03001J^UZj015J^P03001Jfe[K00eJ
f`<0009Nn`03001O75lL019O7003001K?E/m00IK?@8000<cNP8007ioo`03001oogoo06Qoo`03001o
ogoo00aoo`0027oo0P001Woo0P002Woo1@003goo0`004goo0P003goo00<007oo00000`00]goo00<0
000A01402@0A00<002TD:A@03BTD00<003fE?ID03CfE00<005HEEQD03eHE00<005HEEQD00eHE2@00
0dhG00<0058gDSL01e8g30003eHf00<005XfFSH04EXf00<005YGFUL045YG00<005YGFUL04EYG00<0
05YgFWL04EYg00<005YhFWP03eYh0P000UnN00<005nNGih03UnN0P001UZI00<005ZIFYT045ZI00<0
05ZjF[X04UZj00<005[KF]/02E[K0`001Ukk00<005lLGa`04UlL00<005/mFcd00U/m0`000S=j0`00
P7oo00<007ooOol0J7oo00<007ooOol037oo0008Ool20006Ool2000;Ool3000@Ool3000DOol2000=
Ool3002lOol00`0001404@0801400`00:A@Y500=:A@00`00?IDmU@0=?ID00`00EQEF5@0?EQD00`00
EQEF5@0<EQD=0009ESD00`00ESIF=P0?ESH00`00FSIJ=P0AFSH00`00FUMJE`0@FUL00`00FUMJE`0A
FUL00`00FWMJM`0AFWL00`00FWQJN00=FWP20005Gih00`00GiiOWP0;Gih20008FYT00`00FYUJV@0A
FYT00`00F[YJ^P0AF[X00`00F]]Jf`06F]/30009G_/00`00GaaO700BGa`00`00Fcd000020002<gX3
0023Ool00`00Oomoo`1XOol00`00Oomoo`0<Ool000Moo`8000Qoo`8001ioo`8001Aoo`8000eoo`03
001oogoo0;aoo`0300004@0A00P04@03000Y52TD00dY5003000mUCfE00dmU@03001F5EHE00mF5@03
001F5EHE00mF5@03001F=EHe011F=@03001F=UHf00mF=P03001J=UXf015J=P03001JEeYG011JE`03
001JEeYG019JE`03001JMeYg015JM`03001JN5Yh00YJN08000QOWP03001OWUnN00QOWP8000]JV@03
001JVEZI011JV@03001J^UZj015J^P03001Jfe[K00=Jf`<000aNn`03001O75lL019O70L008Ioo`03
001oogoo06Qoo`03001oogoo00aoo`001goo0P0027oo0P007Woo0`004goo0P003Goo00<007ooOol0
_7oo00<0000A0140200A00<002TD:A@03BTD00<003fE?ID03CfE00<005HEEQD03eHE00<005HEEQD0
3eHE00<005HeESD045He00<005HfESH045Hf00<005XfFSH045Xf00<005YGFUL045YG00<005YGFUL0
4UYG00<005YgFWL04EYg00<005YhFWP025Yh0P002enN00<005nNGih01EnN0P003EZI00<005ZIFYT0
45ZI00<005ZjF[X04UZj00<005[K00000P0045kk00<005lLGa`03elL0P000R/g0`00R7oo00<007oo
Ool0J7oo00<007ooOol037oo0007Ool20008Ool2000OOol2000COol2000=Ool00`00Oomoo`2mOol0
0`0001404@0701400`00:A@Y500=:A@00`00?IDmU@0=?ID00`00EQEF5@0?EQD00`00EQEF5@0?EQD0
0`00ESEF=@0@ESD00`00ESIF=P0@ESH00`00FSIJ=P0@FSH00`00FUMJE`0AFUL00`00FUMJE`0AFUL0
0`00FWMJM`0AFWL00`00FWQJN007FWP00`00GiiOWP0<Gih00`00GiiOWP02Gih2000?FYT00`00FYUJ
V@0AFYT00`00F[YJ^P0@F[X3000CG_/00`00GaaO700<Ga`3000012/g00000000Rgoo00<007ooOol0
J7oo00<007ooOol037oo0007Ool20008Ool2000OOol2000COol2000=Ool00`00Oomoo`2mOol00`00
01404@0701400`00:A@Y500=:A@00`00?IDmU@0=?ID00`00EQEF5@0?EQD00`00EQEF5@0?EQD00`00
ESEF=@0@ESD00`00ESIF=P0@ESH00`00FSIJ=P0@FSH00`00FUMJE`0AFUL00`00FUMJE`0AFUL00`00
FWMJM`0AFWL00`00FWQJN005FWP2000@Gih01000Gih000004EZI00<005ZIFYT04EZI00<005ZjF[X0
3EZj0`0000=Nn`00G_/055kk00<005lLGa`02ElL0P0000@[=`00000008ioo`03001oogoo06Uoo`03
001oogoo00]oo`001goo0P0027oo0P007goo0`004Goo0P003Woo00<007ooOol0_Goo00<0000A0140
1`0A00<002TD:A@03BTD00<003fE?ID03CfE00<005HEEQD03eHE00<005HEEQD03eHE00<005HeESD0
45He00<005HfESH045Hf00<005XfFSH04EXf00<005YGFUL045YG00<005YGFUL04EYG00<005YgFWL0
4EYg00<005YhFWP00eYh0P004UnN0P0000=FN000FYT04EZI00<005ZIFYT045ZI00<005ZjF[X02eZj
0P001Ekk00<005kkG_/04Ukk00<005lLGa`01elL1@00TGoo00<007ooOol0JGoo00<007ooOol02goo
0007Ool20008Ool2000POol20009Ool20005Ool3000>Ool00`00Oomoo`2nOol00`0001404@060140
0`00:A@Y500=:A@00`00?IDmU@0=?ID00`00EQEF5@0?EQD00`00EQEF5@0?EQD00`00ESEF=@0@ESD0
0`00ESIF=P0@ESH00`00FSIJ=P0AFSH00`00FUMJE`0@FUL00`00FUMJE`0BFUL00`00FWMJM`0AFWL0
0`00FWQJN002000BGih20003EWP00`00FYUJV@0@FYT00`00FYUJV@0AFYT00`00F[YJ^P07F[X30007
G_/00`00G_]Nn`0CG_/00`00GaaO7004Ga`4002DOol00`00Oomoo`1YOol00`00Oomoo`0;Ool000Mo
o`8000Qoo`80021oo`8000Uoo`T000moo`03001oogoo0;ioo`0300004@0A00H04@03000Y52TD00dY
5003000mUCfE00dmU@03001F5EHE00mF5@03001F5EHE00mF5@03001F=EHe015F=@03001F=UHf00mF
=P03001J=UXf015J=P03001JEeYG011JE`03001JEeYG019JE`03001JMeYg015JM`<0019OWP8000EF
N003001JVEZI011JV@03001JVEZI015JV@03001J^UZj00AJ^P<000]Nn`03001Nnekk019Nn`04001O
75lLGa`4002BOol6001[Ool00`00Oomoo`0;Ool000Moo`8000Qoo`80025oo`8000Qoo`800003Ool0
000000<0011oo`03001oogoo0;ioo`0300004@0A00L04@03000Y52TD00`Y5003000mUCfE00dmU@03
001F5EHE00mF5@03001F5EHE00mF5@03001F=EHe015F=@03001F=UHf00mF=P03001J=UXf015J=P03
001JEeYG011JE`03001JEeYG019JE`03001JMeYg011JM`<0015OWP8000MFN003001JVEZI015JV@03
001JVEZI011JV@03001J^UZj009J^P8000iNn`03001Nnekk019Nn`03001O7000008008Yoo`/000Eo
o`03001oogoo06Uoo`03001oogoo00]oo`0027oo0P001Woo0P008Woo0P0027oo0P005Woo00<007oo
Ool0_goo00<0000A01401P0A00<002TD:A@032TD00<003fE?ID03CfE00<005HEEQD03eHE00<005HE
EQD045HE00<005HeESD045He00<005HfESH03eHf00<005XfFSH04EXf00<005YGFUL04EYG00<005YG
FUL04EYG00<005YgFWL03eYg00D006>nHkiS_P0000eOWP<000YFN003001JVEZI011JV@03001JVEZI
015JV@@0011Nn`03001Nnekk019Nn`8008=oo`X0015oo`03001oogoo06Qoo`03001oogoo00]oo`00
27oo0P001Woo0P006Goo0P001goo0P0027oo0P005Woo00<007ooOol0_goo00<0000A01401P0A00<0
02TD:A@032TD00<003fE?ID03CfE00<005HEEQD03eHE00<005HEEQD045HE00<005HeESD045He00<0
05HfESH03eHf00<005XfFSH04EXf00<005YGFUL04EYG00<005YGFUL04EYG00<005YgFWL03EYg0P00
1F>n00<005nNGih025nN0P003EIh00<005ZIFYT045ZI00<005ZIFYT045ZI0P0055kk00<005kkG_/0
3ekk0P00NWoo2`0077oo00<007ooOol0Igoo00<007ooOol02goo0009Ool20004Ool2000JOol20008
Ool20007Ool2000FOol01000Ool00000_Woo00<0000A01401P0A00<002TD:A@032TD00<003fE?ID0
3CfE00<005HEEQD03eHE00<005HEEQD045HE00<005HeESD045He00<005HfESH03eHf00<005XfFSH0
4EXf00<005YGFUL04EYG00<005YGFUL04EYG00<005YgFWL02eYg0P0026>n00<005nNGih01EnN0P00
3eIh00<005ZIFYT045ZI00<005ZIFYT03EZI0`0000=NfP00G_/04ekk00<005kkG_/035kk0`00LWoo
2P00:7oo00<007ooOol0IWoo00<007ooOol02goo0009Ool8000JOol<0007Ool:000>Ool20031Ool0
0`0001404@0501400`00:A@Y500<:A@00`00?IDmU@0=?ID00`00EQEF5@0@EQD00`00EQEF5@0?EQD0
0`00ESEF=@0@ESD00`00ESIF=P0?ESH00`00FSIJ=P0AFSH00`00FUMJE`0AFUL00`00FUMJE`0BFUL0
0`00FWMJM`09FWL00`00HkiS_P09Hkh00`00GiiOWP02Gih2000AEWP00`00FYUJV@0AFYT00`00FYUJ
V@09FYT30005G]X00`00G_]Nn`0BG_/00`00G_]Nn`09G_/2001ZOol;000bOol00`00Oomoo`1VOol0
0`00Oomoo`0;Ool000]oo`@001aoo``000Moo`X000ioo`03001oogoo0<1oo`0300004@0A00D04@03
000Y52TD00`Y5003000mUCfE00hmU@03001F5EHE00mF5@03001F5EHE00mF5@03001F=EHe011F=@03
001F=UHf011F=P03001J=UXf011J=P03001JEeYG015JE`03001JEeYG019JE`03001JMeYg00MJM`80
00eS_P06001OWP00001FN0004EIh00<005ZIFYT04EZI00<005ZIFYT01UZI0`0025kJ00<005kkG_/0
4Ukk00<005kkG_/01ekk0P00HWoo2P00?Woo00<007ooOol0IGoo00<007ooOol02goo001FOol00`00
Oomoo`30Ool00`0001404@0501400`00:A@Y500<:A@00`00?IDmU@0>?ID00`00EQEF5@0?EQD00`00
EQEF5@0?EQD00`00ESEF=@0@ESD00`00ESIF=P0@ESH00`00FSIJ=P0AFSH00`00FUMJE`0@FUL00`00
FUMJE`0BFUL00`00FWMJM`05FWL2000?Hkh20003EWP00`00EWQFN00@EWP00`00FYUJV@0@FYT00`00
FYUJV@03FYT3000;G]X00`00G_]Nn`0CG_/00`00G_]Nn`04G_/2001IOol;0019Ool00`00Oomoo`1T
Ool00`00Oomoo`0;Ool005Ioo`03001oogoo0<5oo`0300004@0A00@04@03000Y52TD00`Y5003000m
UCfE00hmU@03001F5EHE00mF5@03001F5EHE00mF5@03001F=EHe011F=@03001F=UHf011F=P03001J
=UXf015J=P03001JEeYG011JE`03001JEeYG019JE`03001JMeYg00AJM`03001S_V>n00eS_P8000EF
N003001FN5Ih011FN003001JVEZI015JV@03001JV@00008000mNfP03001Nnekk019Nn`04001Nnekk
G_/3001AOol:001DOol00`00Oomoo`1TOol00`00Oomoo`0;Ool005Ioo`03001oogoo0<5oo`030000
4@0A00@04@03000Y52TD00`Y5003000mUCfE00hmU@03001F5EHE00mF5@03001F5EHE00mF5@03001F
=EHe011F=@03001F=UHf011F=P03001J=UXf015J=P03001JEeYG015JE`03001JEeYG015JE`03001J
MeYg009JM`8000iS_P8000MFN003001FN5Ih011FN003001JVEZI011JV@<0019NfP03001Nnekk019N
n`04001Nn`000019Ool;001OOol00`00Oomoo`1SOol00`00Oomoo`0;Ool005Eoo`03001oogoo0<9o
o`0300004@0A00@04@03000Y52TD00`Y5003000mUCfE00hmU@03001F5EHE00mF5@03001F5EHE00mF
5@03001F=EHe011F=@03001F=UHf011F=P03001J=UXf015J=P03001JEeYG015JE`03001JEeYG019J
E`04001JM`00000>Hkh20009EWP00`00EWQFN00@EWP00`00FYUJV@0=FYT300000eji001NfP0CG]X0
0`00G_]Nn`0AG_/20011Ool:001[Ool00`00Oomoo`1ROol00`00Oomoo`0;Ool005Eoo`03001oogoo
0<=oo`0300004@0A00<04@03000Y52TD00`Y5003000mUCfE00hmU@03001F5EHE00mF5@03001F5EHE
00mF5@03001F=EHe011F=@03001F=UHf011F=P03001J=UXf015J=P03001JEeYG015JE`03001JEeYG
019JE`8000iS_P8000aFN003001FN5Ih011FN003001JVEZI00YJV@8000EN^@03001NfUkJ015NfP03
001Nnekk00mNn`8003Uoo`X007Ioo`03001oogoo065oo`03001oogoo00]oo`00EGoo00<007ooOol0
`goo00<0000A01400`0A00<002TD:A@032TD00<003fE?ID03SfE00<005HEEQD03eHE00<005HEEQD0
3eHE00<005HeESD045He00<005HfESH045Hf00<005XfFSH04EXf00<005YGFUL04EYG00<005YGFUL0
4EYG0`003F>n00<005IhEWP035Ih00<005IhEWP045Ih00<005ZIFYT01eZI0`001eji00<005kJG]X0
4EkJ00<005kkG_/035kk0`00<7oo2`00P7oo00<007ooOol0HGoo00<007ooOol02goo001EOol00`00
Oomoo`33Ool00`0001404@0301400`00:A@Y500<:A@00`00?IDmU@0>?ID00`00EQEF5@0?EQD00`00
EQEF5@0?EQD00`00ESEF=@0AESD00`00ESIF=P0?ESH00`00FSIJ=P0AFSH00`00FUMJE`0AFUL00`00
FUMJE`0@FUL01@00HkiS_V>n00002V>n0P003eIh00<005IhEWP045Ih00<005ZIFYT015ZI0`002Uji
00<005kJG]X04UkJ00<005kkG_/02Ekk0P00:Goo2P00S7oo00<007ooOol0H7oo00<007ooOol02goo
001EOol00`00Oomoo`33Ool00`0001404@0301400`00:A@Y500<:A@00`00?IDmU@0>?ID00`00EQEF
5@0?EQD00`00EQEF5@0?EQD00`00ESEF=@0AESD00`00ESIF=P0?ESH00`00FSIJ=P0AFSH00`00FUMJ
E`0AFUL00`00FUMJE`0>FUL20005Hkh00`00HkiS_P05Hkh2000AEWP00`00EWQFN00@EWP00`00FYUJ
V@02FYT2000>G[T00`00G]YNfP0AG]X00`00G_]Nn`07G_/2000POol;002GOol00`00Oomoo`1OOol0
0`00Oomoo`0;Ool005Eoo`03001oogoo0<Aoo`0300004@0A00804@03000Y52TD00`Y5003000mUCfE
00hmU@03001F5EHE00mF5@03001F5EHE00mF5@03001F=EHe015F=@03001F=UHf00mF=P03001J=UXf
015J=P03001JEeYG019JE`03001JEeYG00]JE`8000QS_P03001S_V>n009S_P<0019FN003001FN5Ih
015FN0@0011N^@03001NfUkJ019NfP03001Nnekk00ANn`8001Qoo`X00:=oo`03001oogoo05ioo`03
001oogoo00]oo`00EGoo00@007oo00000<=oo`0300004@0A00<04@03000Y52TD00/Y5003000mUCfE
00hmU@03001F5EHE00mF5@03001F5EHE00mF5@03001F=EHe015F=@03001F=UHf00mF=P03001J=UXf
019J=P03001JEeYG015JE`03001JEeYG00YJE`03001S_V>n00US_P04001S_P000003EUL00`00EWQF
N00@EWP00`00EWQFN00?EWP2000CG[T00`00G]YNfP0BG]X01000G_]Nnekk0`003goo2`00[Goo00<0
07ooOol0Ggoo00<007ooOol02Woo001EOol20035Ool00`0001404@0301400`00:A@Y500;:A@00`00
?IDmU@0>?ID00`00EQEF5@0?EQD00`00EQEF5@0?EQD00`00ESEF=@0AESD00`00ESIF=P0@ESH00`00
FSIJ=P0AFSH00`00FUMJE`0AFUL00`00FUMJE`08FUL2000<Hkh20005EUL00`00EWQFN00@EWP00`00
EWQFN00<EWP300000ejH001N^@0CG[T00`00G]YNfP0AG]X01000G_/0000027oo2P00^Goo00<007oo
Ool0GWoo00<007ooOol02Woo001EOol00`00Oomoo`35Ool00`0001404@0201400`00:A@Y500;:A@0
0`00?IDmU@0>?ID00`00EQEF5@0?EQD00`00EQEF5@0?EQD00`00ESEF=@0AESD00`00ESIF=P0@ESH0
0`00FSIJ=P0AFSH00`00FUMJE`0AFUL00`00FUMJE`07FUL00`00HkiS_P0;Hkh00`00EUMFE`05EUL0
0`00EWQFN00@EWP00`00EWQFN009EWP30004GYP00`00G[UN^@0BG[T00`00G]YNfP0AG]X<0034Ool0
0`00Oomoo`1MOol00`00Oomoo`0:Ool005Eoo`03001oogoo0<Eoo`0300004@0A00804@03000Y52TD
00/Y5003000mUCfE00hmU@03001F5EHE00mF5@03001F5EHE011F5@03001F=EHe011F=@03001F=UHf
011F=P03001J=UXf015J=P03001JEeYG015JE`03001JEeYG00EJE`8000aS_P8000QFE`03001FN5Ih
011FN003001FN5Ih00IFN0<000QNV003001N^Eji015N^@03001NfUkJ00QNfPX00<moo`03001oogoo
05eoo`03001oogoo00Yoo`00EGoo00<007ooOol0aGoo00<0000A01400P0A00<002TD:A@02bTD00<0
03fE?ID03SfE00<005HEEQD03eHE00<005HEEQD045HE00<005HeESD045He00<005HfESH045Hf00<0
05XfFSH04EXf00<005YGFUL04EYG00<005YGFUL015YG00<006>nHkh02f>n00<005IGEUL025IG00<0
05IhEWP045Ih00<005IhEWP00eIh0`002ejH00<005jiG[T04Eji2`001EkJ0P00dgoo00<007ooOol0
G7oo00<007ooOol02Woo001EOol00`00Oomoo`36Ool01@0001404@0A00003RTD00<003fE?ID03CfE
00<005HEEQD03eHE00<005HEEQD045HE00<005HeESD045He00<005HfESH045Hf00<005XfFSH04EXf
00<005YGFUL04EYG00<005YGFUL00UYG0P0036>n0P002eIG00<005IhEWP04EIh00<005Ih00000P00
3UjH00<005jiG[T01eji2P0000=N^@00G]X02ekJ0P00eWoo00<007ooOol0Fgoo00<007ooOol02Woo
001EOol00`00Oomoo`36Ool01@0001404@0A00003RTD00<003fE?ID03CfE00<005HEEQD03eHE00<0
05HEEQD045HE00<005HeESD045He00<005HfESH045Hf00<005XfFSH04EXf00<005YGFUL04UYG00@0
05YG000000eS_P03001FEeIG00aFE`03001FN5Ih00mFN0<0011NV0/000]N^@03001NfUkJ00QNfP80
0=Uoo`03001oogoo05Yoo`03001oogoo00Yoo`00EGoo00<007ooOol0aWoo00D0000A01404@0000hY
5003000mUCfE00dmU@03001F5EHE00mF5@03001F5EHE011F5@03001F=EHe011F=@03001F=UHf011F
=P03001J=UXf015J=P03001JEeYG019JE`8000eS_P8000mFE`03001FN5Ih00aFN0<00003FYP005jH
00INV0X0009NV003001N^Eji019N^@03001NfUkJ00ENfP800=]oo`03001oogoo05Yoo`03001oogoo
00Yoo`00EGoo00<007ooOol0agoo00@0000A014000hY5003000mUCfE00dmU@03001F5EHE00mF5@03
001F5EHE011F5@03001F=EHe011F=@03001F=UHf011F=P03001J=UXf015J=P03001JEeYG015JE`<0
00aS_P03001FEeIG00mFE`03001FN5Ih00YFN0800003FYP0000000T000aNV003001N^Eji019N^@03
001NfUkJ00=NfP800=ioo`03001oogoo05Uoo`03001oogoo00Yoo`00E7oo00<007ooOol0b7oo00@0
000A014000hY5003000mUCfE00dmU@03001F5EHE00mF5@03001F5EHE011F5@03001F=EHe011F=@03
001F=UHf011F=P03001J=UXf019J=P03001JEeYG00mJE`05001WgFOMImd00009Hkh2000BEUL00`00
EWQFN003EWP:0004FYP00`00GYQNV00@GYP00`00G[UN^@0BG[T01000G]YNfUkJ0P00hGoo00<007oo
Ool0F7oo00<007ooOol02Woo001DOol00`00Oomoo`38Ool0100001404@003RTD00<003fE?ID03CfE
00<005HEEQD03eHE00<005HEEQD045HE00<005HeESD04EHe00<005HfESH03eHf00<005XfFSH04UXf
00<005YGFUL03UYG00<006OMImd00fOM0P001V>n00@005IGEUL000aFE`/00004EWP00000000:FYP0
0`00GYQNV00AGYP00`00G[UN^@0BG[T3003TOol00`00Oomoo`1GOol00`00Oomoo`0:Ool005Aoo`03
001oogoo0<Uoo`0300004@0000hY5003000mUCfE00dmU@03001F5EHE00mF5@03001F5EHE011F5@03
001F=EHe015F=@03001F=UHf011F=P03001J=UXf015J=P03001JEeYG00aJE`8000QWg@04001S_V>n
Hkh20003EUL00`00EUMFE`0:0006EUL01000EWQFN5Ih0P003EZH00<005jHGYP04EjH00<005jiG[T0
4Eji0P00iWoo00<007ooOol0Egoo00<007ooOol02Woo001DOol40038Ool00`000140000>:A@00`00
?IDmU@0=?ID00`00EQEF5@0?EQD00`00EQEF5@0@EQD00`00ESEF=@0AESD00`00ESIF=P0@ESH00`00
FSIJ=P0AFSH00`00FUMJE`0;FUL00`00ImeWg@09Imd;000@EUL4000?FYP00`00GYQNV00AGYP00`00
G[UN^@0?G[T2003YOol00`00Oomoo`1FOol00`00Oomoo`0:Ool005Aoo`03001oogoo0<Uoo`030000
4@0000hY5003000mUCfE00dmU@03001F5EHE00mF5@03001F5EHE011F5@03001F=EHe015F=@03001F
=UHf011F=P03001J=UXf015J=P03001JEeYG00YJE`03001WgFOM00`000IFE`03001FEeIG00mFE`80
01=JV003001NV5jH015NV003001N^Eji00aN^@800>aoo`03001oogoo05Eoo`03001oogoo00Yoo`00
E7oo00<007ooOol0bWoo0P003RTD00<003fE?ID03CfE00<005HEEQD045HE00<005HEEQD03eHE00<0
05HeESD04EHe00<005HfESH045Hf00<005XfFSH04EXf00<005YGFUL00UYG2`002FOM00<005IGEUL0
1UIG00<005IGEUL035IG0`0000=JM`00FYP04UZH00<005jHGYP04EjH00<005jiG[T02eji00<007oo
Ool0kGoo00<007ooOol0E7oo00<007ooOol02Woo001DOol00`00Oomoo`3:Ool00`000140000=:A@0
0`00?IDmU@0=?ID00`00EQEF5@0@EQD00`00EQEF5@0?EQD00`00ESEF=@0AESD00`00ESIF=P0@ESH0
0`00FSIJ=P0<FSH:0005FUL00`00ImeWg@0:Imd20009EUL00`00EUMFE`09EUL30004FWL00`00FYQJ
V00AFYP00`00GYQNV00AGYP00`00G[UN^@09G[T2003`Ool00`00Oomoo`1DOol00`00Oomoo`0:Ool0
05Aoo`03001oogoo0<Yoo`0300004@0000dY5003000mUCfE00dmU@03001F5EHE011F5@03001F5EHE
00mF5@03001F=EHe015F=@03001F=UHf011F=P03001J=UXf009J=PX000EJ=P03001JEeYG00EJE`80
00]Wg@8000]FE`03001FEeIG00IFE`<000MJM`03001JV5ZH015JV003001NV5jH015NV003001N^Eji
00MN^@800?=oo`03001oogoo05=oo`03001oogoo00Yoo`00E7oo00<007ooOol0bgoo0P003BTD00<0
03fE?ID03CfE00<005HEEQD045HE00<005HEEQD03eHE00<005HeESD04EHe00<005HfESH02UHf2`00
3eXf00<005YGFUL015YG00<006OMImd02VOM00<005IGEUL035IG00<005IGEUL00UIG0`002eYg00<0
05ZHFYP045ZH00<005jHGYP04UjH00<005jiG[T015ji0P00mWoo00<007ooOol0DWoo00<007ooOol0
2Woo001DOol00`00Oomoo`3;Ool2000=:A@00`00?IDmU@0=?ID00`00EQEF5@0@EQD00`00EQEF5@0?
EQD00`00ESEF=@0AESD00`00ESIF=P0:0006ESH00`00FSIJ=P0BFSH00`00FUMJE`02FUL00`00ImeW
g@09Imd2000?EUL00`00EUL00002000>FWL00`00FYQJV00AFYP00`00GYQNV00AGYP00`00G[UN^@02
G[T2003hOol00`00Oomoo`1BOol00`00Oomoo`0:Ool005Aoo`03001oogoo0<]oo`8000dY5003000m
UCfE00dmU@03001F5EHE011F5@03001F5EHE011F5@03001F=EHe00QF=@/0011F=P03001J=UXf019J
=P03001JEeYG008000]Wg@03001FEeIG00iFE`<0015JM`03001JV5ZH015JV003001NV5jH015NV005
001N^EjiG[T0003kOol00`00Oomoo`1BOol00`00Oomoo`09Ool005Aoo`03001oogoo0<aoo`03000Y
52TD00/Y5003000mUCfE00dmU@03001F5EHE011F5@03001F5EHE011F5@/000QF=@03001F=UHf011F
=P03001J=UXf019J=P03001JE`0000]Wg@8000iFE`<00003FUL005Yg015JM`03001JV5ZH015JV003
001NV5jH019NV0<00?eoo`03001oogoo055oo`03001oogoo00Uoo`00E7oo00<007ooOol0c7oo00<0
02TD:A@02bTD00<003fE?ID03CfE00<005HEEQD045HE00<005HEEQD01UHE2`004UHe00<005HfESH0
45Hf00<005XfFSH04UXf0P002fOM00<005Hg00002eIG0`0015YG00<005YgFWL045Yg00<005ZHFYP0
4EZH00<005jHGYP04EjH0P00ogoo0Goo00<007ooOol0D7oo00<007ooOol02Goo001DOol00`00Oomo
o`3<Ool00`00:A@Y500;:A@00`00?IDmU@0=?ID00`00EQEF5@0?EQD:000:EQD00`00ESEF=@0@ESD0
0`00ESIF=P0AESH00`00FSIJ=P0@FSH30009Imd20003ESL00`00EUMFE`05EUL30007FUL00`00FWMJ
M`0AFWL00`00FYQJV00AFYP00`00GYQNV00?GYP00`00Oomoo`3oOol1Ool00`00Oomoo`1@Ool00`00
Oomoo`09Ool005Aoo`03001oogoo0<aoo`03000Y52TD00/Y5003000mUCfE00dmU@03001F5EHE00AF
5@/00003EQD005HE015F5@03001F=EHe015F=@03001F=UHf011F=P03001J=UXf00mJ=P04001WgFOM
Imd30004Imd20005ESL00`00EUMFE`02EUL3000;FUL00`00FWMJM`0@FWL00`00FYQJV00AFYP00`00
GYQNV00=GYP2003oOol5Ool00`00Oomoo`1?Ool00`00Oomoo`09Ool005=oo`@00<eoo`03000Y52TD
00XY5003000mUCfE00XmU@X000aF5@03001F5EHE011F5@03001F=EHe015F=@03001F=UHf011F=P03
001J=UXf00iJ=P03001WgFOM00EWg@800003Imd005Hg00IF=`03001FE`00008000iJE`03001JMeYg
011JM`03001JV5ZH015JV003001NV5jH00]NV0800?moo`Qoo`03001oogoo04ioo`03001oogoo00Uo
o`00Dgoo00<007ooOol0cWoo00<002TD:A@02RTD00<003fE00002P000cfE00<005HEEQD045HE00<0
05HEEQD045HE00<005HeESD04EHe00<005HfESH045Hf00<005XfFSH03EXf00<006OMImd01fOM0P00
1eHg0`004EYG00<005YgFWL045Yg00<005ZHFYP04EZH00<005jHGYP02UjH00<007ooOol0ogoo2Goo
00<007ooOol0CGoo00<007ooOol02Goo001COol00`00Oomoo`3>Ool00`00:A@Y5002:A@:000>?ID0
0`00EQEF5@0@EQD00`00EQEF5@0@EQD00`00ESEF=@0AESD00`00ESIF=P0@ESH00`00FSIJ=P0;FSH2
0009Imd00`00ESMF=`04ESL300000eYF001JE`0AFUL00`00FWMJM`0@FWL00`00FYQJV00BFYP00`00
GYQNV007GYP2003oOol<Ool00`00Oomoo`1=Ool00`00Oomoo`09Ool005=oo`03001oogoo0<Qoo`/0
00PY5003000mUCfE00dmU@03001F5EHE011F5@03001F5EHE011F5@03001F=EHe015F=@03001F=UHf
011F=P03001J=UXf00YJ=P03001WgFOM00QWg@03001F=eHg009F=`<000AJEP03001JEeYG011JE`03
001JMeYg015JM`03001JV5ZH015JV003001NV5jH00ENV0800?moo`moo`03001oogoo04aoo`03001o
ogoo00Uoo`00Dgoo00<007ooOol0_Woo2P001goo00<002TD:A@02BTD00<003fE?ID03SfE00<005HE
EQD03eHE00<005HEEQD045HE00<005HeESD04EHe00<005HfESH045Hf00<005XfFSH02EXf00<006OM
Imd01fOM0P000UHg0`001eYF00<005YGFUL045YG00<005YgFWL04EYg00<005ZHFYP04EZH00<005jH
GYP015jH00<007ooOol0ogoo47oo00<007ooOol0Bgoo00<007ooOol02Goo001COol00`00Oomoo`2c
Ool;000AOol00`00:A@Y5009:A@00`00?IDmU@0>?ID00`00EQEF5@0?EQD00`00EQEF5@0@EQD00`00
ESEF=@0AESD00`00ESIF=P0@ESH00`00FSIJ=P07FSH20009Imd00`00ESL00002000:FUH00`00FUMJ
E`0@FUL00`00FWMJM`0AFWL00`00FYQJV00AFYP00`00GYQNV002GYP2003oOolCOol00`00Oomoo`1;
Ool00`00Oomoo`09Ool005=oo`03001oogoo0:Uoo`X001aoo`03000Y52TD00TY5003000mUCfE00hm
U@03001F5EHE00mF5@03001F5EHE011F5@03001F=EHe015F=@03001F=UHf011F=P03001J=UXf00IJ
=P03001WgFOM00QWg@<000iJEP03001JEeYG011JE`03001JMeYg011JM`03001JV5ZH015JV003001N
V5jH00800?mooaIoo`03001oogoo04Yoo`03001oogoo00Uoo`00Dgoo00<007ooOol0WWoo2`009goo
00<002TD:A@022TD00<003fE?ID03SfE00<005HEEQD03eHE00<005HEEQD045HE00<005HeESD04EHe
00<005HfESH045Hf00<005XfFSH01EXf00<006OMImd01fOM0P004EYF00<005YGFUL045YG00<005Yg
FWL045Yg00<005ZHFYP04UZH0P00ogoo6Goo00<007ooOol0BGoo00<007ooOol02Goo000jOol:000?
Ool00`00Oomoo`2DOol:000bOol00`00:A@Y5008:A@00`00?IDmU@0>?ID00`00EQEF5@0?EQD00`00
EQEF5@0@EQD00`00ESEF=@0AESD00`00ESIF=P0@ESH00`00FSIJ=P04FSH00`00ImeWg@07Imd00`00
FSH0000AFUH00`00FUMJE`0@FUL00`00FWMJM`0AFWL00`00FYQJV00@FYP2003oOolKOol00`00Oomo
o`18Ool00`00Oomoo`09Ool003Yoo`X000moo`03001oogoo08Uoo`/003aoo`03000Y52TD00PY5003
000mUCfE00hmU@03001F5EHE00mF5@03001F5EHE011F5@03001F=EHe015F=@03001F=UHf015F=P04
001J=UXfFSH20008Imd20002FSH00`00FUIJEP0?FUH00`00FUMJE`0@FUL00`00FWMJM`0AFWL00`00
FYQJV00?FYP00`00Oomoo`3oOolKOol00`00Oomoo`18Ool00`00Oomoo`09Ool003ioo`8001=oo`03
001oogoo07moo`X004Qoo`03000Y52TD00PY5003000mUCfE00dmU@03001F5EHE00mF5@03001F5EHE
011F5@03001F=EHe015F=@03001F=UHf015F=P04001J=UXf0009Imd00`00FSIJ=P02FSH00`00FUIJ
EP0?FUH00`00FUMJE`0@FUL00`00FWMJM`0AFWL00`00FYQJV00=FYP2003oOolOOol00`00Oomoo`17
Ool00`00Oomoo`09Ool003ioo`8001=oo`03001oogoo07Aoo`/0059oo`03000Y52TD00PY5003000m
UCfE00dmU@03001F5EHE00mF5@03001F5EHE011F5@03001F=EHe015F=@03001F=UHf015F=P03001J
=P0000UWg@03001J=UXf00=J=P03001JEUYF00mJEP03001JEeYG011JE`03001JMeYg015JM`03001J
V5ZH00aJV003001oogoo0?moob1oo`03001oogoo04Ioo`03001oogoo00Uoo`00?Woo0P004Woo1`00
Igoo2P00GGoo00<002TD:A@022TD00<003fE?ID03CfE00<005HEEQD03eHE00<005HEEQD04EHE00<0
05HeESD04EHe00<005HfESH045Hf0P0026OM0P001UXf00<005YFFUH03eYF00<005YGFUL04EYG00<0
05YgFWL045Yg00<005ZHFYP02UZH0P00ogoo97oo00<007ooOol0AGoo00<007ooOol02Goo000nOol2
000COol00`00Oomoo`1POol:001XOol00`00:A@Y5007:A@00`00?IDmU@0=?ID00`00EQEF5@0?EQD0
0`00EQEF5@0AEQD00`00ESEF=@0AESD00`00ESIF=P0@ESH30006Imd00`00FSIJ=P07FSH00`00FUIJ
EP0>FUH00`00FUMJE`0AFUL00`00FWMJM`0AFWL00`00FYQJV008FYP00`00Oomoo`3oOolTOol00`00
Oomoo`15Ool00`00Oomoo`09Ool003ioo`8001=oo`03001oogoo05Eoo`/0079oo`03000Y52TD00LY
5003000mUCfE00dmU@03001F5EHE00mF5@03001F5EHE015F5@03001F=EHe015F=@03001F=UHf00mF
=P04001[o6_lJo`30002Imd00`00FSIJ=P08FSH00`00FUIJEP0?FUH00`00FUMJE`0@FUL00`00FWMJ
M`0AFWL00`00FYQJV006FYP2003oOolXOol00`00Oomoo`15Ool00`00Oomoo`08Ool003ioo`8001=o
o`03001oogoo04]oo`X007eoo`03000Y52TD00LY5003000mUCfE00dmU@03001F5EHE00mF5@03001F
5EHE015F5@03001F=EHe015F=@03001F=UHf00iF=P03001[o6_l00E[o08000]J=P03001JEUYF00mJ
EP03001JEeYG011JE`03001JMeYg015JM`03001JV5ZH00EJV003001oogoo0?moobUoo`03001oogoo
04Aoo`03001oogoo00Qoo`00?Woo0P004Woo00<007ooOol0@Goo2`00Qgoo00<002TD:A@01bTD00<0
03fE?ID03CfE00<005HEEQD045HE00<005HEEQD045HE00<005HeESD04EHe00<005HfESH03EHf00<0
06_lJo`01F_l00<005XfFSH02eXf00<005YFFUH03eYF00<005YGFUL045YG00<005YgFWL04EYg00<0
05ZHFYP00eZH0P00ogoo;7oo00<007ooOol0A7oo00<007ooOol027oo000nOol2000BOol00`00Oomo
o`0gOol:002COol00`00:A@Y5006:A@00`00?IDmU@0=?ID00`00EQEF5@0@EQD00`00EQEF5@0@EQD0
0`00ESEF=@0AESD00`00ESIF=P0<ESH00`00Joa[o005Jo`00`00FSIJ=P0<FSH00`00FUIJEP0?FUH0
0`00FUMJE`0@FUL00`00FWMJM`0AFWL00`00FYQJV002FYP00`00Oomoo`3oOol]Ool00`00Oomoo`13
Ool00`00Oomoo`08Ool003ioo`80019oo`03001oogoo02aoo`/009eoo`03000Y52TD00HY5003000m
UCfE00dmU@03001F5EHE011F5@03001F5EHE011F5@03001F=EHe015F=@03001F=UHf00]F=P03001[
o6_l00E[o003001J=UXf00eJ=P03001JEUYF00mJEP03001JEeYG011JE`03001JMeYg019JM`04001J
V000003oOolaOol00`00Oomoo`12Ool00`00Oomoo`08Ool003ioo`80019oo`03001oogoo029oo`X0
0:Qoo`03000Y52TD00HY5003000mUCfE00dmU@03001F5EHE011F5@03001F5EHE011F5@03001F=EHe
015F=@03001F=UHf00YF=P03001[o6_l00E[o003001J=UXf00iJ=P03001JEUYF00mJEP03001JEeYG
015JE`03001JMeYg015JM`800?moocAoo`03001oogoo045oo`03001oogoo00Qoo`00?Woo0P004Woo
00<007ooOol05goo2`00/goo00<002TD:A@01BTD00<003fE?ID03CfE00<005HEEQD045HE00<005HE
EQD045HE00<005HeESD04EHe00<005HfESH02EHf00<006_lJo`01F_l00<005XfFSH03eXf00<005YF
FUH03eYF00<005YGFUL04EYG00<005YgFWL045Yg0P00ogoo=Goo00<007ooOol0@Goo00<007ooOol0
27oo000nOol2000BOol00`00Oomoo`0=Ool:002nOol00`00:A@Y5005:A@00`00?IDmU@0=?ID00`00
EQEF5@0@EQD00`00EQEF5@0@EQD00`00ESEF=@0AESD00`00ESIF=P08ESH00`00Joa[o005Jo`2000A
FSH00`00FUIJEP0?FUH00`00FUMJE`0AFUL00`00FWMJM`0?FWL00`00Oomoo`3oOolfOol00`00Oomo
o`10Ool00`00Oomoo`08Ool003ioo`80019oo`03001oogoo009oo`/00<Qoo`03000Y52TD00DY5003
000mUCfE00dmU@03001F5EHE011F5@03001F5EHE011F5@03001F=EHe015F=@03001F=UHf00MF=P03
001[o6_l00E[o003001F=@00015J=P03001JEUYF011JEP03001JEeYG011JE`03001JMeYg00iJM`03
001oogoo0?moocQoo`03001oogoo03moo`03001oogoo00Qoo`00>Woo0`0000=oo`0000004Woo1@00
dgoo00<002TD:A@01BTD00<003fE?ID03CfE00<005HEEQD045HE00<005HEEQD045HE00<005HeESD0
4EHe00<005HfESH01UHf00<006_lJo`01F_l00@005HeESD0019J=P03001JEUYF00mJEP03001JEeYG
011JE`03001JMeYg00aJM`800?moocaoo`03001oogoo03ioo`03001oogoo00Qoo`00>Woo1P0057oo
0`00e7oo00<002TD:A@012TD00<003fE?ID03CfE00<005HEEQD045HE00<005HEEQD045HE00<005He
ESD04EHe00<005HfESH01EHf00<006_lJo`01F_l00D005HeESEF=@00019J=P03001JEUYF00mJEP03
001JEeYG011JE`03001JMeYg00]JM`03001oogoo0?moocaoo`03001oogoo03ioo`03001oogoo00Qo
o`00?Goo0`005Woo0P00dgoo00<002TD:A@012TD00<003fE?ID03CfE00<005HEEQD045HE00<005HE
EQD045HE00<005HeESD04UHe00<005HfESH00eHf00<006_lJo`01F_l00<005HeESD00UHe00<005Xf
FSH045Xf00<005YFFUH03eYF00<005YGFUL04EYG00<005YgFWL02EYg00<007ooOol0ogoo?Woo00<0
07ooOol0?Goo00<007ooOol027oo001FOol01000Ool00000dGoo00<002TD:A@012TD00<003fE?ID0
3CfE00<005HEEQD045HE00<005HEEQD045HE00<005HeESD04UHe00<005HfESH00UHf00<006_lJo`0
1F_l00<005HeESD00eHe00<005XfFSH045Xf00<005YFFUH03eYF00<005YGFUL04EYG00<005YgFWL0
25Yg00<007ooOol0ogoo@7oo00<007ooOol0?7oo00<007ooOol027oo001JOol2003@Ool00`00:A@Y
5003:A@00`00?IDmU@0=?ID00`00EQEF5@0@EQD00`00EQEF5@0@EQD00`00ESEF=@0BESD01@00ESIF
=UHf00001f_l00<005HeESD015He00<005XfFSH045Xf00<005YFFUH03eYF00<005YGFUL04EYG00<0
05YgFWL01UYg0P00ogooA7oo00<007ooOol0>goo00<007ooOol027oo001LOol2003>Ool00`00:A@Y
5003:A@00`00?IDmU@0=?ID00`00EQEF5@0@EQD00`00EQEF5@0AEQD00`00ESEF=@0AESD01000ESIF
=P001f_l00<005HeESD01EHe00<005XfFSH045Xf00<005YFFUH03eYF00<005YGFUL04EYG00<005Yg
FWL01EYg00<007ooOol0ogooA7oo00<007ooOol0>goo00<007ooOol027oo001NOol2003<Ool00`00
:A@Y5003:A@00`00?IDmU@0=?ID00`00EQEF5@0@EQD00`00EQEF5@0AEQD00`00ESEF=@0AESD00`00
ESH00007Jo`00`00ESEF=@06ESD00`00FSIJ=P0@FSH00`00FUIJEP0?FUH00`00FUMJE`0AFUL00`00
FWMJM`04FWL00`00Oomoo`3oOom6Ool00`00Oomoo`0jOol00`00Oomoo`08Ool0061oo`8000Aoo`03
001oogoo0<=oo`03000Y52TD00<Y5003000mUCfE00dmU@03001F5EHE011F5@03001F5EHE015F5@03
001F=EHe015F=@8000M[o003001F=EHe00QF=@03001J=UXf00mJ=P03001JEUYF011JEP03001JEeYG
011JE`03001JMeYg009JM`800?moodYoo`03001oogoo03Uoo`03001oogoo00Qoo`00HWoo0P000Woo
00<007ooOol0a7oo00<002TD:A@00RTD00<003fE?ID03CfE00<005HEEQD045HE00<005HEEQD04EHE
00<005HeESD04EHe1@000f_l00<005HeESD02EHe00<005XfFSH03eXf00<005YFFUH045YF00<005YG
FUL045YG00D005YgFWMJM`000?moodaoo`03001oogoo03Uoo`03001oogoo00Qoo`00I7oo0P00agoo
00<002TD:A@00RTD00<003fE?ID03CfE00<005HEEQD045HE00<005HEEQD04EHE00<005HeESD04EHe
00<007?jLoX00W?j0`0035He00<005XfFSH03eXf00<005YFFUH045YF00<005YGFUL04EYG00<005Yg
0000ogooCWoo00<007ooOol0>7oo00<007ooOol027oo001UOol30035Ool00`00:A@Y5002:A@00`00
?IDmU@0=?ID00`00EQEF5@0@EQD00`00EQEF5@0AEQD00`00ESEF=@0@ESD00`00LoYcnP05LoX00`00
ESEF=@0:ESD00`00FSIJ=P0@FSH00`00FUIJEP0?FUH00`00FUMJE`0AFUL2003oOom@Ool00`00Oomo
o`0gOol00`00Oomoo`08Ool006Qoo`800<Aoo`05000Y52TD:A@0000??ID00`00EQEF5@0@EQD00`00
EQEF5@0AEQD00`00ESEF=@0?ESD00`00LoYcnP05LoX00`00ESEF=@0;ESD00`00FSIJ=P0@FSH00`00
FUIJEP0?FUH00`00FUMJE`0@FUL2003oOomBOol00`00Oomoo`0gOol00`00Oomoo`07Ool006Yoo`80
0<9oo`05000Y52TD:A@0000??ID00`00EQEF5@0@EQD00`00EQEF5@0AEQD00`00ESEF=@0>ESD00`00
LoYcnP05LoX00`00ESEF=@0<ESD00`00FSIJ=P0@FSH00`00FUIJEP0?FUH00`00FUMJE`0?FUL00`00
Oomoo`3oOomBOol00`00Oomoo`0gOol00`00Oomoo`07Ool006aoo`8000Ioo`03001oogoo0;Moo`05
000Y52TD:A@0000??ID00`00EQEF5@0@EQD00`00EQEF5@0AEQD00`00ESEF=@0=ESD00`00LoYcnP05
LoX00`00ESEF=@0=ESD00`00FSIJ=P0@FSH00`00FUIJEP0?FUH00`00FUMJE`0>FUL00`00Oomoo`3o
OomDOol00`00Oomoo`0fOol00`00Oomoo`07Ool006ioo`8000Aoo`03001oogoo0;Moo`05000Y52TD
:A@0000??ID00`00EQEF5@0@EQD00`00EQEF5@0AEQD00`00ESEF=@0<ESD00`00LoYcnP05LoX00`00
ESEF=@0>ESD00`00FSIJ=P0@FSH00`00FUIJEP0?FUH00`00FUMJE`0=FUL00`00Oomoo`3oOomFOol0
0`00Oomoo`0eOol00`00Oomoo`07Ool0071oo`80009oo`03001oogoo0;Qoo`04000Y52TD000??ID0
0`00EQEF5@0@EQD00`00EQEF5@0AEQD00`00ESEF=@0;ESD00`00LoYcnP05LoX00`00ESEF=@0?ESD0
0`00FSIJ=P0@FSH00`00FUIJEP0@FUH00`00FUMJE`0;FUL00`00Oomoo`3oOomHOol00`00Oomoo`0d
Ool00`00Oomoo`07Ool0079oo`<00;Yoo`05000Y52TD:A@0000>?ID00`00EQEF5@0@EQD00`00EQEF
5@0AEQD00`00ESEF=@0:ESD00`00LoYcnP05LoX2000AESD00`00FSIJ=P0@FSH00`00FUIJEP0@FUH0
0`00FUMJE`09FUL2003oOomKOol00`00Oomoo`0dOol00`00Oomoo`07Ool007Aoo`800;Uoo`05000Y
52TD:A@0000>?ID00`00EQEF5@0@EQD00`00EQEF5@0AEQD00`00ESEF=@09ESD00`00LoYcnP05LoX0
1000EQEF5@0045He00<005XfFSH045Xf00<005YFFUH045YF00<005YGFUL025YG00<007ooOol0ogoo
G7oo00<007ooOol0<goo00<007ooOol01goo001dOol01000Ool00000^7oo00@002TD:A@000hmU@03
001F5EHE011F5@03001F5EHE015F5@03001F=EHe00QF=@03001cnW?j00EcnP05001F5EHEEQD0000@
ESD00`00FSIJ=P0@FSH00`00FUIJEP0@FUH00`00FUMJE`07FUL00`00Oomoo`3oOomNOol00`00Oomo
o`0bOol00`00Oomoo`07Ool007Qoo`800;Ioo`04000Y52TD000??ID00`00EQEF5@0@EQD00`00EQEF
5@0@EQD00`00ESEF=@07ESD00`00LoYcnP05LoX00`00EQEF5@02EQD00`00ESEF=@0?ESD00`00FSIJ
=P0@FSH00`00FUIJEP0?FUH00`00FUMJE`06FUL00`00Oomoo`3oOomOOol00`00Oomoo`0bOol00`00
Oomoo`07Ool007Yoo`800;Aoo`04000Y52TD000??ID00`00EQEF5@0@EQD00`00EQEF5@0@EQD00`00
ESEF=@07ESD00`00LoYcnP04LoX00`00EQEF5@03EQD00`00ESEF=@0?ESD00`00FSIJ=P0@FSH00`00
FUIJEP0?FUH00`00FUMJE`05FUL00`00Oomoo`3oOomQOol00`00Oomoo`0aOol00`00Oomoo`07Ool0
07aoo`800;=oo`03000Y500000lmU@03001F5EHE011F5@03001F5EHE011F5@03001F=EHe00IF=@03
001cnW?j00EcnP03001F5EHE00=F5@03001F=EHe00mF=@03001J=UXf011J=P03001JEUYF00mJEP03
001JEeYG00=JE`800?moofEoo`03001oogoo031oo`03001oogoo00Moo`00OWoo00D007ooOomoo`00
0:ioo`03000Y500000lmU@03001F5EHE011F5@03001F5EHE015F5@03001F=EHe00AF=@03001cnW?j
00EcnP03001F5EHE00AF5@03001F=EHe00mF=@03001J=UXf011J=P03001JEUYF00mJEP03001JEeYG
009JE`03001oogoo0?moofIoo`03001oogoo02moo`03001oogoo00Moo`00Ogoo0P0000=oo`00Ool0
[Goo00<002TD00003cfE00<005HEEQD045HE00<005HEEQD04EHE00<005HeESD00eHe00<007?jLoX0
1G?j00<005HEEQD01EHE00<005HeESD03eHe00<005XfFSH045Xf00<005YFFUH045YF00@005YGFUL0
0?moofUoo`03001oogoo02moo`03001oogoo00Moo`00PGoo0P00[Woo00<002TD00003cfE00<005HE
EQD045HE00<005HEEQD04EHE00<005HeESD00UHe00<007?jLoX01G?j00<005HEEQD01UHE00<005He
ESD03eHe00<005XfFSH045Xf00<005YFFUH045YF00<005YG0000ogooJgoo00<007ooOol0;Woo00<0
07ooOol01goo0022Ool3002]Ool2000??ID00`00EQEF5@0@EQD00`00EQEF5@0AEQD01@00ESEF=EHe
00001g?j00<005HEEQD01eHE00<005HeESD03eHe00<005XfFSH045Xf00<005YFFUH045YF0P00ogoo
KGoo00<007ooOol0;Goo00<007ooOol01goo0025Ool2002[Ool2000??ID00`00EQEF5@0@EQD00`00
EQEF5@0AEQD01000ESEF=@001g?j00<005HEEQD025HE00<005HeESD03eHe00<005XfFSH045Xf00<0
05YFFUH045YF00<007ooOol0ogooKGoo00<007ooOol0;7oo00<007ooOol01goo0027Ool2002YOol2
000??ID00`00EQEF5@0@EQD00`00EQEF5@0AEQD00`00ESD00007LoX00`00EQEF5@09EQD00`00ESEF
=@0?ESD00`00FSIJ=P0@FSH00`00FUIJEP0?FUH00`00Oomoo`3oOom^Ool00`00Oomoo`0/Ool00`00
Oomoo`07Ool008Uoo`800:Qoo`03000mUCfE00dmU@03001F5EHE011F5@03001F5EHE015F5@8000Mc
nP03001F5EHE00YF5@03001F=EHe00mF=@03001J=UXf011J=P03001JEUYF00iJEP03001oogoo0?mo
og1oo`03001oogoo02]oo`03001oogoo00Moo`00Rgoo0P000goo00<007ooOol0X7oo00<003fE?ID0
3CfE00<005HEEQD045HE00<005HEEQD04EHE1@000g?j00<005HEEQD02eHE00<005HeESD03eHe00<0
05XfFSH04EXf00<005YFFUH035YF00<007ooOol0ogooLWoo00<007ooOol0:Woo00<007ooOol01goo
002=Ool200000goo001oo`2QOol00`00?IDmU@0=?ID00`00EQEF5@0@EQD00`00EQEF5@0AEQD00`00
MkUg^@02MkT3000>EQD00`00ESEF=@0?ESD00`00FSIJ=P0AFSH00`00FUIJEP0;FUH00`00Oomoo`3o
OomcOol00`00Oomoo`0[Ool00`00Oomoo`06Ool008moo`800:=oo`03000mUCfE00`mU@03001F5EHE
011F5@03001F5EHE011F5@03001g^GNi00Eg^@03001F5EHE00aF5@03001F=EHe00mF=@03001J=UXf
015J=P03001JEUYF00YJEP03001oogoo0?moogEoo`03001oogoo02Yoo`03001oogoo00Ioo`00T7oo
0`00XGoo00<003fE?ID033fE00<005HEEQD045HE00<005HEEQD03eHE00<007NiMkT01GNi00<005HE
EQD03EHE00<005HeESD045He00<005XfFSH045Xf00<005YFFUH02EYF00<007ooOol0ogooMgoo00<0
07ooOol0:Goo00<007ooOol01Woo002COol2002OOol00`00?IDmU@0<?ID00`00EQEF5@0@EQD00`00
EQEF5@0?EQD00`00MkUg^@04MkT00`00EQEF5@0>EQD00`00ESEF=@0@ESD00`00FSIJ=P0@FSH00`00
FUIJEP08FUH00`00Oomoo`3oOomiOol00`00Oomoo`0XOol00`00Oomoo`06Ool009Eoo`8009ioo`03
000mUCfE00/mU@03001F5EHE011F5@03001F5EHE00iF5@03001g^GNi00Eg^@03001F5EHE00iF5@03
001F=EHe011F=@03001J=UXf011J=P03001JEUYF00MJEP03001oogoo0?moogYoo`03001oogoo02Qo
o`03001oogoo00Ioo`00Ugoo0P00W7oo00<003fE?ID02cfE00<005HEEQD045HE00<005HEEQD03EHE
00<007NiMkT01GNi00<005HEEQD03eHE00<005HeESD045He00<005XfFSH045Xf00<005YFFUH01UYF
00<007ooOol0ogooO7oo00<007ooOol09goo00<007ooOol01Woo001IOol<000;Ool4000>Ool4000C
Ool20003Ool00`00Oomoo`2DOol00`00?IDmU@0;?ID00`00EQEF5@0@EQD00`00EQEF5@0<EQD00`00
MkUg^@05MkT2000BEQD00`00ESEF=@0?ESD00`00FSIJ=P0@FSH00`00FUIJEP05FUH00`00Oomoo`3o
OomnOol00`00Oomoo`0VOol00`00Oomoo`06Ool005Uoo``000Uoo`P000Yoo`P001=oo`800003Ool0
07oo09Ioo`03000mUCfE00XmU@03001F5EHE011F5@03001F5EHE00aF5@03001g^GNi00Eg^@80019F
5@03001F=EHe00mF=@03001J=UXf011J=P03001JEUYF00AJEP03001oogoo0?mooh1oo`03001oogoo
02Eoo`03001oogoo00Ioo`00FWoo0`001Woo0P002Goo0P0017oo0P002Woo0P0017oo0P005Goo0P00
Ugoo00<003fE?ID02SfE00<005HEEQD045HE00<005HEEQD02eHE00<007NiMkT01GNi00<003fE0000
4UHE00<005HeESD03eHe00<005XfFSH045Xf00<005YFFUH00eYF00<007ooOol0ogooPGoo00<007oo
Ool09Goo00<007ooOol01Woo001KOol3000?Ool20006Ool20008Ool20006Ool2000EOol3002FOol0
0`00?IDmU@09?ID00`00EQEF5@0@EQD00`00EQEF5@0:EQD00`00MkUg^@06MkT00`00?ID0000BEQD0
0`00ESEF=@0?ESD00`00FSIJ=P0AFSH01@00FUIJEUYF0000ogooQGoo00<007ooOol097oo00<007oo
Ool01Woo001LOol3000>Ool20006Ool20008Ool20006Ool2000HOol2002DOol00`00?IDmU@09?ID0
0`00EQEF5@0@EQD00`00EQEF5@0:EQD00`00MkUg^@05MkT01000?IDmU@004UHE00<005HeESD03eHe
00<005XfFSH04EXf00@005YFFUH00?moohMoo`03001oogoo02=oo`03001oogoo00Ioo`00GGoo0`00
37oo0P0027oo0P001Woo0P0027oo0P006Goo0P00TWoo00<003fE?ID02CfE00<005HEEQD045HE00<0
05HEEQD02EHE00<007NiMkT01GNi00<003fE?ID00SfE00<005HEEQD03eHE00<005HeESD03eHe00<0
05XfFSH04EXf00<005YF0000ogooRGoo00<007ooOol08Woo00<007ooOol01Woo001NOol3000;Ool2
0008Ool20006Ool20008Ool2000KOol20004Ool00`00Oomoo`2:Ool00`00?IDmU@08?ID00`00EQEF
5@0@EQD00`00EQEF5@08EQD00`00MkUg^@06MkT00`00?IDmU@02?ID00`00EQEF5@0?EQD00`00ESEF
=@0?ESD00`00FSIJ=P0AFSH2003oOon:Ool00`00Oomoo`0ROol00`00Oomoo`06Ool005moo`<000Yo
o`8000Qoo`8000Ioo`8000Qoo`8001eoo`80009oo`03001oogoo08Yoo`03000mUCfE00PmU@03001F
5EHE011F5@03001F5EHE00MF5@03001g^GNi00Ig^@03000mUCfE00<mU@03001F5EHE00mF5@03001F
=EHe00mF=@03001J=UXf015J=P03001oogoo0?moohYoo`03001oogoo025oo`03001oogoo00Ioo`00
H7oo0`002Goo0P0027oo0P001Woo0P0027oo0P007goo0`00S7oo00<003fE?ID023fE00<005HEEQD0
4EHE00<005HEEQD01UHE00<007NiMkT01GNi00<003fE?ID013fE00<005HEEQD03eHE00<005HeESD0
45He00<005XfFSH045Xf00<007ooOol0ogooRgoo00<007ooOol087oo00<007ooOol01Woo001QOol3
0008Ool20008Ool20006Ool20008Ool2000QOol2002<Ool00`00?IDmU@07?ID00`00EQEF5@0AEQD0
0`00EQEF5@05EQD00`00MkUg^@06MkT00`00?IDmU@04?ID00`00EQEF5@0?EQD00`00ESEF=@0@ESD0
0`00FSIJ=P0?FSH00`00Oomoo`3oOon<Ool00`00Oomoo`0POol00`00Oomoo`06Ool0069oo`8000Qo
o`8000Qoo`8000Ioo`8000Qoo`8002=oo`8008Yoo`03000mUCfE00LmU@03001F5EHE015F5@03001F
5EHE00AF5@03001g^GNi00Ig^@03000mUCfE00DmU@03001F5EHE00mF5@03001F=EHe011F=@03001J
=UXf00iJ=P03001oogoo0?moohioo`03001oogoo01moo`03001oogoo00Ioo`00Hgoo0P001goo0P00
27oo0P001Woo0P0027oo0P009Goo0P001goo00<007ooOol0OWoo00<003fE?ID01cfE00<005HEEQD0
4EHE00<005HEEQD015HE00<007NiMkT01GNi00<003fE?ID01SfE00<005HEEQD03eHE00<005HeESD0
45He00<005XfFSH03EXf00<007ooOol0ogooT7oo00<007ooOol07Woo00<007ooOol01Woo001SOol2
0007Ool20008Ool20006Ool20008Ool2000WOol20005Ool00`00Oomoo`1oOol00`00?IDmU@06?ID0
0`00EQEF5@0AEQD00`00EQEF5@03EQD00`00MkUg^@06MkT00`00?IDmU@06?ID00`00EQEF5@0?EQD0
0`00ESEF=@0@ESD00`00FSIJ=P0<FSH00`00Oomoo`3oOonBOol00`00Oomoo`0MOol00`00Oomoo`06
Ool005Yoo`8000Moo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8002Yoo`8000=oo`03001oogoo07mo
o`03000mUCfE00HmU@03001F5EHE015F5@03001F5EHE009F5@03001g^GNi00Ig^@03000mUCfE00Lm
U@03001F5EHE00mF5@03001F=EHe011F=@03001J=UXf00]J=P03001oogoo0?mooi=oo`03001oogoo
01ioo`03001oogoo00Eoo`00FWoo0`001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P00;7oo0P00
00=oo`00Ool0PGoo00<003fE?ID01CfE00<005HEEQD04EHE00<005HEEQD00UHE00<007NiMkT01GNi
00<003fE?ID023fE00<005HEEQD03eHE00<005HeESD045He00<005XfFSH02UXf00<007ooOol0ogoo
UGoo00<007ooOol07Goo00<007ooOol01Goo001JOol40004Ool2000:Ool20004Ool2000:Ool20004
Ool2000_Ool20022Ool00`00?IDmU@05?ID00`00EQEF5@0AEQD01@00EQEF5EHE000027Ni00<003fE
?ID023fE00<005HEEQD03eHE00<005HeESD045He00<005XfFSH02EXf00<007ooOol0ogooUgoo00<0
07ooOol077oo00<007ooOol01Goo001KOol8000;Ool8000:Ool8000`Ool30020Ool00`00?IDmU@05
?ID00`00EQEF5@0AEQD01000EQEF5@0027Ni00<003fE?ID02CfE00<005HEEQD03eHE00<005HeESD0
45He00<005XfFSH025Xf00<007ooOol0ogooVGoo00<007ooOol06goo00<007ooOol01Goo001MOol5
000>Ool4000>Ool4000eOol2001oOol00`00?IDmU@04?ID00`00EQEF5@0AEQD00`00EQD00009MkT0
0`00?IDmU@09?ID00`00EQEF5@0?EQD00`00ESEF=@0@ESD00`00FSIJ=P07FSH00`00Oomoo`3oOonJ
Ool00`00Oomoo`0KOol00`00Oomoo`05Ool00;eoo`8007eoo`03000mUCfE00@mU@03001F5EHE015F
5@03001F5@0000Qg^@03000mUCfE00XmU@03001F5EHE00mF5@03001F=EHe011F=@03001J=UXf00IJ
=P03001oogoo0?mooiaoo`03001oogoo01Yoo`03001oogoo00Eoo`00_goo0P0017oo00<007ooOol0
M7oo00<003fE?ID013fE00<005HEEQD04EHE0P0027Ni00<003fE?ID02cfE00<005HEEQD03eHE00<0
05HeESD045He00<005XfFSH01EXf00<007ooOol0ogooWWoo00<007ooOol06Goo00<007ooOol01Goo
0031Ool20002Ool00`00Oomoo`1eOol00`00?IDmU@03?ID00`00EQEF5@0AEQD30007MkT00`00?IDm
U@0;?ID00`00EQEF5@0@EQD00`00ESEF=@0?ESD00`00FSIJ=P04FSH00`00Oomoo`3oOonOOol00`00
Oomoo`0IOol00`00Oomoo`05Ool00<=oo`8007Qoo`03000mUCfE00@mU@03001F5EHE00mF5@04001c
VW>JLiX40002MkT2000=?ID00`00EQEF5@0@EQD00`00ESEF=@0@ESD00`00FSIJ=P02FSH00`00Oomo
o`3oOonQOol00`00Oomoo`0HOol00`00Oomoo`05Ool00<Aoo`<007Moo`03000mUCfE00<mU@03001F
5EHE00iF5@03001cVW>J00IcVP800003Ool003fE00`mU@03001F5EHE011F5@03001F=EHe011F=@05
001J=UXfFSH0003oOonUOol00`00Oomoo`0GOol00`00Oomoo`05Ool00<Moo`8007Eoo`03000mUCfE
00<mU@03001F5EHE00eF5@03001cVW>J00QcVP03001oo`0000dmU@03001F5EHE011F5@03001F=EHe
011F=@04001J=UXf003oOonWOol00`00Oomoo`0FOol00`00Oomoo`05Ool00<Uoo`8007=oo`03000m
UCfE00<mU@03001F5EHE00aF5@03001cVW>J00QcVP04001oogoo000=?ID00`00EQEF5@0@EQD00`00
ESEF=@0@ESD00`00FSH0003oOonXOol00`00Oomoo`0FOol00`00Oomoo`05Ool00<]oo`8000Aoo`03
001oogoo06]oo`03000mUCfE008mU@03001F5EHE00]F5@03001cVW>J00QcVP03001oogoo009oo`03
000mUCfE00XmU@03001F5EHE011F5@03001F=EHe011F=@800?moojYoo`03001oogoo01Eoo`03001o
ogoo00Eoo`00cGoo0P000Woo00<007ooOol0Jgoo00<003fE?ID00SfE00<005HEEQD02UHE00<007>J
LiX027>J00<007ooOol00goo00<003fE?ID02SfE00<005HEEQD045HE00<005HeESD045He00<007oo
Ool0ogooZWoo00<007ooOol057oo00<007ooOol01Goo003?Ool3001]Ool00`00?IDmU@02?ID00`00
EQEF5@09EQD00`00LiYcVP08LiX00`00Oomoo`04Ool00`00?IDmU@0:?ID00`00EQEF5@0@EQD00`00
ESEF=@0@ESD00`00Oomoo`3oOon[Ool00`00Oomoo`0COol00`00Oomoo`05Ool00=5oo`8006eoo`05
000mUCfE?ID0000:EQD00`00LiYcVP08LiX00`00Oomoo`06Ool00`00?IDmU@09?ID00`00EQEF5@0@
EQD00`00ESEF=@0?ESD00`00Oomoo`3oOon/Ool00`00Oomoo`0COol00`00Oomoo`05Ool00==oo`80
06]oo`05000mUCfE?ID00009EQD00`00LiYcVP08LiX00`00Oomoo`07Ool00`00?IDmU@0:?ID00`00
EQEF5@0?EQD00`00ESEF=@0>ESD00`00Oomoo`3oOon^Ool00`00Oomoo`0BOol00`00Oomoo`05Ool0
0=Eoo`03001oogoo06Qoo`05000mUCfE?ID00008EQD00`00LiYcVP08LiX2000:Ool00`00?IDmU@09
?ID00`00EQEF5@0?EQD00`00ESEF=@0=ESD00`00Oomoo`3oOon`Ool00`00Oomoo`0AOol00`00Oomo
o`05Ool00=Ioo`8000Eoo`03001oogoo065oo`04000mUCfE0007EQD00`00LiYcVP08LiX00`00Ool0
000:Ool00`00?IDmU@09?ID00`00EQEF5@0?EQD00`00ESEF=@0<ESD00`00Oomoo`3oOonaOol00`00
Oomoo`0AOol00`00Oomoo`05Ool00=Qoo`8000=oo`03001oogoo065oo`04000mUCfE0006EQD00`00
LiYcVP08LiX01000Oomoo`002Woo00<003fE?ID02CfE00<005HEEQD03eHE00<005HeESD02eHe00<0
07ooOol0ogoo/goo00<007ooOol04Goo00<007ooOol017oo003JOol200000goo001oo`1SOol00`00
?ID00005EQD00`00LiYcVP08LiX01@00Oomoogoo00002goo00<003fE?ID023fE00<005HEEQD03eHE
00<005HeESD02eHe00<007ooOol0ogoo]7oo00<007ooOol047oo00<007ooOol017oo003LOol2001T
Ool00`00?ID00004EQD00`00LiYcVP09LiX01@00Oomoogoo00002goo00<003fE?ID023fE00<005HE
EQD03eHE00<005HeESD02UHe00<007ooOol0ogoo]Woo00<007ooOol03goo00<007ooOol017oo002O
Ool:0009Ool6000>Ool4000DOol2001ROol00`00?ID00003EQD00`00LiYcVP09LiX00`00Oomoo`02
Ool00`00Oomoo`0:Ool00`00?IDmU@07?ID00`00EQEF5@0?EQD00`00ESEF=@09ESD00`00Oomoo`3o
OongOol00`00Oomoo`0?Ool00`00Oomoo`04Ool009moo`X000Moo`X000Yoo`P001Aoo`80065oo`80
009F5@03001cVW>J00UcVP03001oogoo00=oo`03001oogoo00Yoo`03000mUCfE00LmU@03001F5EHE
00mF5@03001F=EHe00QF=@03001oogoo0?mookUoo`03001oogoo00ioo`03001oogoo00Aoo`00Xgoo
0P002goo0`001Goo0`002Goo0P0017oo0P005Woo0P0017oo00<007ooOol0F7oo0P0000=F5@00LiX0
2W>J00<007ooOol017oo00<007ooOol02Woo00<003fE?ID01cfE00<005HEEQD03eHE00<005HeESD0
1eHe00<007ooOol0ogoo^goo00<007ooOol03Goo00<007ooOol017oo002SOol2000DOol20008Ool2
0006Ool2000GOol20002Ool00`00Oomoo`1HOol3000;LiX00`00Oomoo`04Ool00`00Oomoo`0<Ool0
0`00?IDmU@06?ID00`00EQEF5@0?EQD00`00ESEF=@07ESD00`00Oomoo`3oOonlOol00`00Oomoo`0<
Ool00`00Oomoo`04Ool00:=oo`8001Eoo`8000Moo`8000Ioo`8001Uoo`<005]oo`8000YcVP03001o
ogoo00Eoo`03001oogoo00aoo`03000mUCfE00HmU@03001F5EHE011F5@03001F=EHe00EF=@03001o
ogoo0?mookeoo`03001oogoo00aoo`03001oogoo00Aoo`00Xgoo0P005Goo0P001Woo0P0027oo0P00
6Woo0P00G7oo0P001g>J00<007ooOol01Woo00<007ooOol03Goo00<003fE?ID01CfE00<005HEEQD0
45HE00<005HeESD015He00<007ooOol0ogoo_goo00<007ooOol02goo00<007ooOol017oo002SOol2
000EOol20006Ool20008Ool2000LOol20008Ool00`00Oomoo`1AOol20004LiX00`00Oomoo`07Ool0
0`00Oomoo`0=Ool00`00?IDmU@05?ID00`00EQEF5@0@EQD00`00ESEF=@03ESD00`00Oomoo`3oOoo1
Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00:=oo`8001Eoo`8000Ioo`8000Qoo`8001ioo`8000Io
o`03001oogoo05=oo`800003LiX007oo00Uoo`03001oogoo00eoo`03000mUCfE00DmU@03001F5EHE
011F5@03001F=EHe009F=@03001oogoo0?mool=oo`03001oogoo00Uoo`03001oogoo00Aoo`00Xgoo
0P005Goo0P001Woo0P0027oo0P0087oo0P0017oo00<007ooOol0EGoo00<007ooOol02Goo00<007oo
Ool03Woo00<003fE?ID013fE00<005HEEQD045HE00D005HeESEF=@000?moolIoo`03001oogoo00Uo
o`03001oogoo00Aoo`00Xgoo0P0057oo0P001goo0P0027oo0P008Woo0P000Woo00<007ooOol0HGoo
00<007ooOol03Woo00<003fE?ID013fE00<005HEEQD045HE00D005HeESEF=@000?moolMoo`03001o
ogoo00Qoo`03001oogoo00Aoo`00Xgoo0P0037oo0P001Goo0`001goo0P0027oo0P0097oo0`00Hgoo
00<007ooOol03goo00<003fE?ID00cfE00<005HEEQD045HE00@005HeESD00?moolUoo`03001oogoo
00Moo`03001oogoo00Aoo`00Xgoo0P0037oo2@0027oo0P0027oo0P009Woo0P00HWoo00<007ooOol0
3goo00<003fE?ID00cfE00<005HEEQD045HE00<005He0000ogoobWoo00<007ooOol01goo00<007oo
Ool017oo002SOol2000<Ool200000goo000000030009Ool20008Ool2000XOol2001POol00`00Oomo
o`0?Ool00`00?IDmU@03?ID00`00EQEF5@0@EQD2003oOoo<Ool00`00Oomoo`06Ool00`00Oomoo`04
Ool00:=oo`8000aoo`80011oo`8000Ioo`8002]oo`8005ioo`03001oogoo011oo`03000mUCfE008m
U@03001F5EHE00mF5@800?moolioo`03001oogoo00Eoo`03001oogoo00Aoo`00Xgoo0P0037oo0P00
47oo0P001Woo0P00;Goo0P000goo00<007ooOol0EWoo00<007ooOol047oo00<003fE?ID00SfE00<0
05HEEQD03UHE00<007ooOol0ogoocgoo00<007ooOol017oo00<007ooOol017oo002OOol300000goo
0000000<Ool2000AOol20004Ool2000`Ool200000goo001oo`1GOol00`00Oomoo`0AOol01@00?IDm
UCfE00003eHE00<007ooOol0ogood7oo00<007ooOol017oo00<007ooOol017oo002OOol6000<Ool:
0009Ool8000bOol2001HOol00`00Oomoo`0AOol01@00?IDmUCfE00003UHE00<007ooOol0ogoodWoo
00<007ooOol017oo00<007ooOol00goo002ROol3000<Ool:000;Ool4000eOol3001FOol00`00Oomo
o`0AOol00`00?IDmU@02?ID00`00EQEF5@0:EQD00`00Oomoo`3oOooDOol00`00Oomoo`03Ool00`00
Oomoo`03Ool00?moo`=oo`8005Aoo`03001oogoo019oo`05000mUCfE?ID0000:EQD2003oOooHOol0
0`00Oomoo`02Ool00`00Oomoo`03Ool00?moo`Eoo`8000Aoo`03001oogoo04]oo`03001oogoo019o
o`05000mUCfE?ID00009EQD00`00Oomoo`3oOooHOol00`00Oomoo`02Ool00`00Oomoo`03Ool00?mo
o`Moo`80009oo`03001oogoo04]oo`03001oogoo01=oo`04000mUCfE0008EQD00`00Oomoo`3oOooJ
Ool01@00Oomoogoo00001Goo003oOol9Ool3001=Ool00`00Oomoo`0COol01000?IDmU@001eHE00<0
07ooOol0ogoog7oo00@007ooOol000Eoo`00ogoo2goo0P00C7oo00<007ooOol04goo00@003fE?ID0
00IF5@03001oogoo0?moomeoo`04001oogoo0005Ool00?moo`eoo`8004Yoo`03001oogoo01Aoo`03
000mU@0000AF5@800?moon5oo`03001oo`0000Eoo`00ogoo3goo0P0017oo00<007ooOol0@Goo00<0
07ooOol057oo00<003fE00000eHE00<007ooOol0ogoohWoo0P001Goo003oOolAOol20002Ool00`00
Oomoo`11Ool00`00Oomoo`0EOol20002EQD00`00Oomoo`3oOooMOol80005Ool00?mooa=oo`<004=o
o`03001oogoo01Eoo`800003EQD007oo0?moom5oo`h000eoo`00ogoo5Goo0P00@Woo00<007ooOol0
5Goo0`00ogooa7oo3`006goo003oOolEOol01000Ool00000@7oo00<007ooOol05Woo00<007ooOol0
ogoo]Goo3P00:Woo003oOolIOol2000nOol00`00Oomoo`3oOoo0Ool>000hOol00=]oo`X000]oo`@0
00ioo`@001Aoo`8000=oo`03001oogoo03Ioo`03001oogoo0?mook5oo`l004Ioo`00fgoo2P002Goo
20002Woo200057oo0P0000=oo`00Ool0=goo00<007ooOol0ogooXgoo3P00EGoo003OOol2000=Ool2
0004Ool2000:Ool20004Ool2000FOol2000hOol00`00Oomoo`3oOonEOol>001SOol00=moo`8000ao
o`8000Ioo`8000Qoo`8000Ioo`8001Ioo`<000Moo`03001oogoo02aoo`03001oogoo0?moohIoo`l0
075oo`00ggoo0P0037oo0P001Woo0P0027oo0P001Woo0P006Goo0P001Goo00<007ooOol0;7oo00<0
07ooOol0ogooN7oo3P00P7oo003OOol2000;Ool20008Ool20006Ool20008Ool2000JOol20003Ool0
0`00Oomoo`0/Ool00`00Oomoo`3oOomZOol>002>Ool00=moo`8000]oo`8000Qoo`8000Ioo`8000Qo
o`8001aoo`800003Ool007oo02eoo`03001oogoo0?mooe]oo`l009aoo`00ggoo0P002goo0P0027oo
0P001Woo0P0027oo0P007Woo0P00;Woo00<007ooOol0ogooCGoo3P00Zgoo003OOol2000;Ool20008
Ool20006Ool20008Ool2000OOol3000/Ool00`00Oomoo`3oOoloOol>002iOol00=moo`8000]oo`80
00Qoo`8000Ioo`8000Qoo`80029oo`03001oogoo02Uoo`03001oogoo0?mooc5oo`h00<Moo`00ggoo
0P002goo0P0027oo0P001Woo0P0027oo0P008goo0P0017oo00<007ooOol08Woo00<007ooOol0ogoo
8Woo3`00eGoo003OOol2000;Ool20008Ool20006Ool20008Ool2000UOol20002Ool00`00Oomoo`0R
Ool00`00Oomoo`3oOolDOol>003TOol00=moo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8002Moo`<0
02=oo`03001oogoo0?moo`Moo`h00?9oo`00ggoo0P0037oo0P001Woo0P0027oo0P001Woo0P00:Woo
0P008Woo00<007ooOol0mgoo3`00ogoo0Goo003OOol2000<Ool20006Ool20008Ool20006Ool2000/
Ool2000POol00`00Oomoo`3YOol>003oOol@Ool00=]oo`<00003Ool0000000eoo`8000Aoo`8000Yo
o`8000Aoo`8002moo`8000Aoo`03001oogoo01Moo`03001oogoo0=]oo`h00?mooaioo`00fgoo1P00
3Goo20002Woo2000<Goo0P000Woo00<007ooOol05goo00<007ooOol0c7oo3`00ogoo;7oo003NOol3
000?Ool4000>Ool4000eOol2000JOol00`00Oomoo`2nOol>003oOolkOol00?mooceoo`<001Qoo`03
001oogoo0;1oo`h00?moodUoo`00ogoo@7oo0P001Goo00<007ooOol03Woo00<007ooOol0XWoo3P00
ogooEgoo003oOom2Ool20003Ool00`00Oomoo`0>Ool00`00Oomoo`2COol?003oOomUOol00?moodAo
o`800003Ool007oo00moo`03001oogoo08Eoo`h00?moogAoo`00ogooAWoo0P0047oo00<007ooOol0
Mgoo3P00ogooPWoo003oOom7Ool3000>Ool00`00Oomoo`1XOol?003oOon@Ool00?moodYoo`8000Ao
o`03001oogoo00Eoo`03001oogoo05Yoo`h00?mooimoo`00ogooC7oo0P000Woo00<007ooOol01Goo
00<007ooOol0C7oo3P00ogoo[Goo003oOolLOol6000>Ool4000JOol30007Ool00`00Oomoo`0mOol?
003oOonkOol00?mooaYoo`X000Yoo`P001Yoo`8000Ioo`03001oogoo02moo`h00?moolYoo`00ogoo
6Woo0`001Goo0`002Goo0P0017oo0P0077oo0P0017oo00<007ooOol08Goo3P00ogoof7oo003oOolS
Ool20008Ool20006Ool2000MOol20002Ool00`00Oomoo`0BOol?003oOooVOol00?moobAoo`8000Mo
o`8000Ioo`8001moo`<000Ioo`h00?moooEoo`00ogoo97oo0P001Woo0P0027oo0P0087oo1`00ogoo
ogoo17oo003oOolTOol20006Ool20008Ool2003oOoooOol[Ool00?moobAoo`8000Ioo`8000Qoo`80
0?mooomoob]oo`00ogoo97oo0P001Woo0P0027oo0P00ogooogoo:goo003oOolSOol20007Ool20008
Ool2003oOoooOol[Ool00?mooa]oo`8000Eoo`<000Moo`8000Qoo`800?mooomoob]oo`00ogoo6goo
2@0027oo0P0027oo0P00ogooogoo:goo003oOolKOol200000goo000000030009Ool20008Ool2003o
OoooOol[Ool00?mooa]oo`80011oo`8000Ioo`800?mooomoobaoo`00ogoo6goo0P0047oo0P001Woo
0P00ogooogoo;7oo003oOolKOol2000AOol20004Ool2003oOoooOol]Ool00?mooa]oo`X000Uoo`P0
0?mooomoobeoo`00ogoo6goo2P002goo1000ogooogoo;goo003oOoooOoooOomSOol00?mooomooomo
of=oo`00\
\>"], "Graphics",
  CellLabel->"From In[42]:=",
  Evaluatable->False,
  ImageSize->{288, 173.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
Control plot of interpolated potential, two conductors at potential \
1.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
u=Table[p[j/2,i/2],{i,1,nz},{j,1,ns}];
Timing[Do[{u=m;
If[Mod[i,100]==0,{err=Max[Abs[Flatten[u-m]]];
Print[i,\" residual error: \",err];
If[err<10^-6,Break[]]}]},{i,1,7000}]]
ListPlot3D[u,
ImageSize->400,PlotRange->All,ViewPoint\[Rule]{3.,1.,1.}];\
\>", "Input",
  CellLabel->"In[44]:=",
  CellFrame->True,
  PageBreakAbove->Automatic,
  ImageRegion->{{0, 1}, {0, 1}},
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(InterpolatingFunction::"dmval" \(\(:\)\(\ \)\) 
      "Input value \!\({1\/2, 1\/2}\) lies outside the range of data in the \
interpolating function. Extrapolation will be used."\)], "Message",
  CellLabel->"From In[44]:="],

Cell[BoxData[
    \(InterpolatingFunction::"dmval" \(\(:\)\(\ \)\) 
      "Input value \!\({1, 1\/2}\) lies outside the range of data in the \
interpolating function. Extrapolation will be used."\)], "Message",
  CellLabel->"From In[44]:="],

Cell[BoxData[
    \(InterpolatingFunction::"dmval" \(\(:\)\(\ \)\) 
      "Input value \!\({3\/2, 1\/2}\) lies outside the range of data in the \
interpolating function. Extrapolation will be used."\)], "Message",
  CellLabel->"From In[44]:="],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(InterpolatingFunction :: \"dmval\"\) will be \
suppressed during this calculation."\)], "Message",
  CellLabel->"From In[44]:="],

Cell[BoxData[
    InterpretationBox[\(100\[InvisibleSpace]" residual error: "\
\[InvisibleSpace]0.0004179878827132999`\),
      SequenceForm[ 100, " residual error: ", 0.0004179878827132999],
      Editable->False]], "Print",
  CellLabel->"From In[44]:="],

Cell[BoxData[
    InterpretationBox[\(6200\[InvisibleSpace]" residual error: "\
\[InvisibleSpace]1.0388272190797743`*^-6\),
      SequenceForm[ 6200, " residual error: ", 1.0388272190797743*^-06],
      Editable->False]], "Print",
  CellLabel->"From In[44]:="],

Cell[BoxData[
    InterpretationBox[\(6300\[InvisibleSpace]" residual error: "\
\[InvisibleSpace]9.82262858162386`*^-7\),
      SequenceForm[ 6300, " residual error: ", 9.8226285816238601*^-07],
      Editable->False]], "Print",
  CellLabel->"From In[44]:="],

Cell[BoxData[
    \({8891.7`\ Second, Null}\)], "Output",
  CellLabel->"Out[45]="],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000B`0002da000`40O003h00Oogooogooogooogoo
]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOooo
OoooOoooOondOol00?mooomooomooneoo`H000eoo`@00:moo`00ogooogooogook7oo20002Woo2000
[Goo003oOoooOoooOoo[Ool30004Ool30009Ool20004Ool2002]Ool00?mooomooomoonYoo`<000Io
o`<000Moo`8000Ioo`800:aoo`00ogooogooogoojWoo0P0027oo0P001goo0P001Woo0P00[7oo003o
OoooOoooOooZOol20008Ool20006Ool20008Ool2002[Ool00?mooomooomoonYoo`8000Qoo`8000Io
o`8000Qoo`800:]oo`00ogooogooogoojWoo0`001Woo0`001Woo0P0027oo0P00Zgoo003oOoooOooo
Ooo[Ool30004Ool30007Ool20008Ool2002[Ool00?mooomooomoonaoo`P000Qoo`8000Qoo`800:]o
o`00ogooogooogook7oo200027oo0P0027oo0P00Zgoo003oOoooOoooOoo[Ool30004Ool30007Ool2
0008Ool2002[Ool00?mooomooomoonYoo`8000Qoo`8000Ioo`8000Qoo`800:]oo`00ogooogooogoo
jWoo0P0027oo0P001goo0P001Woo0P00[7oo003oOoooOoooOooZOol20008Ool20007Ool20006Ool2
002/Ool00?mooomooomoon]oo`<000Aoo`@000Qoo`8000Aoo`800:eoo`00ogooogooogoojgoo2P00
2Goo2000[Goo003oOoooOoooOoo]Ool6000=Ool4002_Ool00?mooomooomooomookAoo`00ogooogoo
ogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo
003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOooo
OoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol0
0?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomo
oomookAoo`00ogooogoomWoo1@003Goo1000ogooYgoo003oOoooOoodOol8000:Ool8003oOonUOol0
0?mooomoooAoo`8000Aoo`<000Uoo`8000Aoo`800?moojEoo`00ogooogoolgoo0P001Woo0`001goo
0P001Woo0P00iWoo1@00^7oo003oOoooOoobOol20008Ool20007Ool20006Ool2003OOol70004Ool0
0`00Oomoo`2fOol00?mooomooo9oo`8000Qoo`8000Ioo`8000Qoo`800=Moo`L000]oo`800;Moo`00
ogooogoolWoo0P0027oo0P001Woo0P0027oo0P00d7oo1`004Woo0P00]goo003oOoooOoobOol20008
Ool20006Ool20008Ool20039Ool7000IOol00`00Ool0002fOol00?mooomooo9oo`<000Ioo`<000Io
o`8000Qoo`800<9oo`L0021oo`<00;Ioo`00ogooogoolWoo100017oo0`001goo0P0027oo0P00^Woo
20009goo0P0000=oo`00Ool0]7oo003oOoooOoobOol200000goo000000050008Ool20008Ool2002c
Ool7000_Ool200000goo001oo`2dOol00?mooomooo=oo`03001oogoo00D000Uoo`8000Qoo`800:ao
o`L003Ioo`80009oo`03001oogoo0;9oo`00ogooogoolgoo0P003goo0P0027oo0P00YGoo1`00>goo
10000Woo00<007ooOol0/Woo003oOoooOoocOol3000?Ool20006Ool2002OOol70005Ool00`00Oomo
o`0cOol;0003Ool00`00Oomoo`2aOol00?mooomoooAoo`<000ioo`8000Ioo`8009Qoo`L000aoo`03
001oogoo02Yooa000003Acl000000080009oo`03001oogoo0;5oo`00ogooogoomGoo0`003Woo0P00
17oo0P00TWoo1`004goo00<007ooOol087oo4`0000=7?`0000002@000goo00<007ooOol0/7oo003o
OoooOoofOol80008Ool8002:Ool8000JOol00`00Oomoo`0IOol700000dLo0000000700000dLo0000
000;00000dLo000000050003Ool00`00Oomoo`2_Ool00?mooomoooQoo`H000Yoo`@008Eoo`L003Qo
o`H00003Acl0000001800003Acl0000000l000=oo`03001oogoo0:moo`00ogooogooogooRgoo1`00
>Goo1P0000=7?`0000002`0000=7?`0000005@0000=7?`0000001@000goo00<007ooOol0[Woo003o
OoooOoooOon4Ool7000jOolC00000dLo0000000;00000dLo0000000400000dLo0000000@0002Ool0
0`00Oomoo`2^Ool00?mooomooomoogaoo`P003Yoo`d00003Acl0000000@00003Acl0000000@00003
Acl0000000@00003Acl0000001400003Acl0000000T000=oo`03001oogoo0:eoo`00ogooogooogoo
MWoo1`00>7oo2@0000=7?`000000100000=7?`0000002`0000=7?`0000004@0000=7?`0000001000
00=7?`0000002`0000=7?`0000000P000Woo00<007ooOol0[Goo003oOoooOoooOom^Ool80006Ool0
0`00Oomoo`0]Ool900000dLo0000000D00000dLo0000000;00000dLo0000000400000dLo0000000A
00000dLo000000090003Ool00`00Oomoo`2/Ool00?mooomooomoofMoo`L000moo`03001oogoo02Eo
oah00003Acl0000002800003Acl0000000@00003Acl0000000l000=oo`03001oogoo0:aoo`00ogoo
ogooogooH7oo1`005Woo00<007ooOol07goo1P0000=7?`000000100000=7?`000000;00000=7?`00
0000600000=7?`000000100000=7?`0000000P000goo00<007ooOol0Zgoo003oOoooOoooOomIOol7
000MOol00`00Oomoo`0IOol600000dLo0000000A00000dLo0000000400000dLo0000000E00000dLo
0000000D00000dLo0000000400000dLo0000000?0003Ool00`00Oomoo`2[Ool00?mooomooomooe9o
o`L003Yooa<00003Acl0000000@00003Acl0000001400003Acl0000000@00003Acl0000000/00003
Acl0000000L00003Acl0000001@00003Acl0000000@00003Acl00000008000=oo`03001oogoo0:Yo
o`00ogooogooogooBgoo1`00>Woo3@0000=7?`000000100000=7?`0000004@0000=7?`0000001000
00=7?`0000002`0000=7?`0000008P0000=7?`0000004P000goo00<007ooOol0ZWoo003oOoooOooo
Oom3Ool8000hOol=00000dLo0000000D00000dLo0000000400000dLo0000000A00000dLo0000000;
00000dLo0000000400000dLo0000000R00000dLo000000050003Ool00`00Oomoo`2YOol00?mooomo
oomoocaoo`L003Moob000003Acl0000001P00003Acl0000000@00003Acl0000000/00003Acl00000
01400003Acl0000000@00003Acl0000001`000=oo`03001oogoo0:Uoo`00ogooogooogoo=Goo1`00
0goo00<007ooOol0<Goo3@0000=7?`000000100000=7?`0000001`0000=7?`000000500000=7?`00
0000600000=7?`0000002`0000=7?`000000100000=7?`0000004@0000=7?`000000100000=7?`00
00001`0000=7?`0000001@000goo00<007ooOol0Z7oo003oOoooOoooOol^Ool7000:Ool00`00Oomo
o`0[Ool600000dLo0000000400000dLo0000000H00000dLo0000000700000dLo0000000D00000dLo
0000000;00000dLo0000000400000dLo0000000A00000dLo0000000400000dLo0000000H00000dLo
000000020002Ool00`00Oomoo`2XOol00?mooomooomoobMoo`L0015oo`03001oogoo02Eoo`H00003
Acl0000001400003Acl0000000@00003Acl0000001P00003Acl0000000L00003Acl0000000/00003
Acl0000001@00003Acl0000000@00003Acl0000001400003Acl0000000@00003Acl0000000l000=o
o`03001oogoo0:Moo`00ogooogoo37oo1`002Woo1000oWoo1`0067oo00<007ooOol077oo5P0000=7
?`000000100000=7?`0000004@0000=7?`000000100000=7?`000000100000=7?`000000100000=7
?`0000007P0000=7?`000000600000=7?`000000100000=7?`000000600000=7?`0000000P000Woo
00<007ooOol0Ygoo003oOoooOol<Ool70008Ool8003eOol7000OOol00`00Oomoo`0BOolC00000dLo
0000000;00000dLo0000000:00000dLo0000000400000dLo0000000400000dLo0000000400000dLo
0000000A00000dLo0000000400000dLo0000000700000dLo0000000D00000dLo0000000H00000dLo
0000000400000dLo0000000?0003Ool00`00Oomoo`2VOol00?mooomoo`moo`8000Yoo`8000Aoo`80
0>eoo`P003Eoo`H00003Acl0000000L00003Acl0000000/00003Acl0000001@00003Acl0000000@0
0003Acl0000001400003Acl0000000@00003Acl0000001P00003Acl0000000L00003Acl0000001@0
0003Acl0000001P00003Acl0000000@00003Acl000000080009oo`03001oogoo0:Ioo`00ogooogoo
3goo0P002Goo0P001Woo0P00iGoo1`00=goo1P0000=7?`000000100000=7?`0000008P0000=7?`00
0000500000=7?`000000100000=7?`0000004@0000=7?`000000100000=7?`000000600000=7?`00
00001`0000=7?`000000500000=7?`0000005P000goo00<007ooOol0YGoo003oOoooOol?Ool20009
Ool20006Ool2003NOol7000hOol600000dLo0000000A00000dLo0000000400000dLo0000000R0000
0dLo0000000D00000dLo0000000400000dLo0000000A00000dLo0000000400000dLo0000000H0000
0dLo0000000700000dLo0000000D00000dLo000000090002Ool00`00Oomoo`2UOol00?mooomoo`Mo
o``000Ioo`8000Qoo`800=Ioo`L003Uooa<00003Acl0000000@00003Acl0000001400003Acl00000
00@00003Acl0000002800003Acl0000001@00003Acl0000000@00003Acl0000001400003Acl00000
00@00003Acl0000001P00003Acl0000000L00003Acl00000018000=oo`03001oogoo0:Aoo`00ogoo
ogoo1goo30001Woo0P0027oo0P00cgoo1`001Woo00<007ooOol0<Goo300000=7?`000000100000=7
?`000000100000=7?`0000002P0000=7?`000000100000=7?`000000100000=7?`0000002P0000=7
?`000000100000=7?`0000007P0000=7?`000000600000=7?`000000100000=7?`0000004@0000=7
?`000000100000=7?`000000600000=7?`0000001`0000=7?`0000001@000Woo00<007ooOol0Y7oo
003oOoooOol7Ool20006Ool200000goo001oo`05Ool20008Ool20038Ool7000=Ool00`00Oomoo`0X
Ool<00000dLo0000000700000dLo0000000A00000dLo0000000400000dLo0000000400000dLo0000
000:00000dLo0000000400000dLo0000000:00000dLo0000000400000dLo0000000700000dLo0000
000D00000dLo0000000H00000dLo0000000400000dLo0000000A00000dLo0000000400000dLo0000
000H00000dLo000000020002Ool00`00Oomoo`2SOol00?mooomoo`Qoo`8000Eoo`8000Qoo`8000Qo
o`800<1oo`P001Aoo`03001oogoo01ioo`d00003Acl0000000L00003Acl0000001@00003Acl00000
01P00003Acl0000000@00003Acl0000000X00003Acl0000000@00003Acl0000001400003Acl00000
00L00003Acl0000001@00003Acl0000001P00003Acl0000000@00003Acl0000001400003Acl00000
00@00003Acl0000000l000=oo`03001oogoo0:9oo`00ogooogoo27oo0`0017oo0P0027oo0P0027oo
0P00^Goo1`0077oo00<007ooOol067oo1P0000=7?`000000100000=7?`0000004@0000=7?`000000
1`0000=7?`000000500000=7?`000000600000=7?`000000100000=7?`0000002P0000=7?`000000
100000=7?`0000004@0000=7?`0000001`0000=7?`000000500000=7?`000000600000=7?`000000
100000=7?`0000004@0000=7?`00000020000goo00<007ooOol0XWoo003oOoooOol9Ool20004Ool2
0008Ool20008Ool2002bOol7000SOol00`00Oomoo`0BOol600000dLo0000000400000dLo0000000:
00000dLo0000000400000dLo0000000400000dLo0000000:00000dLo0000000700000dLo0000000D
00000dLo0000000H00000dLo0000000400000dLo0000000:00000dLo0000000400000dLo0000000A
00000dLo0000000700000dLo0000000D00000dLo0000000H00000dLo0000000400000dLo0000000:
00000dLo000000020003Ool00`00Oomoo`2QOol00?mooomoo`Yoo`8000=oo`8000Qoo`8000Qoo`80
0:]oo`L002Yoo`03001oogoo00aoo`d00003Acl0000000X00003Acl0000000@00003Acl000000140
0003Acl0000000@00003Acl0000000X00003Acl0000000L00003Acl0000001@00003Acl0000001P0
0003Acl0000000@00003Acl0000000X00003Acl0000000@00003Acl0000001400003Acl0000000L0
0003Acl0000001@00003Acl0000002<000=oo`03001oogoo0:5oo`00ogooogoo2Woo0`000Woo0P00
27oo0P0027oo0P00Y7oo1`00<Goo00<007ooOol00goo3@0000=7?`000000500000=7?`0000002P00
00=7?`000000100000=7?`0000004@0000=7?`000000100000=7?`0000002P0000=7?`0000001`00
00=7?`000000500000=7?`000000600000=7?`000000100000=7?`0000002P0000=7?`0000006000
00=7?`0000001`0000=7?`000000500000=7?`0000002P0000=7?`000000100000=7?`0000000P00
0goo00<007ooOol0X7oo003oOoooOol;Ool20002Ool20009Ool20006Ool2002NOol7000eOolT0000
0dLo0000000D00000dLo0000000:00000dLo0000000400000dLo0000000A00000dLo000000040000
0dLo0000000:00000dLo0000000700000dLo0000000D00000dLo0000000H00000dLo0000000:0000
0dLo0000000400000dLo0000000H00000dLo0000000700000dLo0000000:00000dLo0000000B0003
Ool00`00Oomoo`2POol00?mooomoo`aoo`800003Ool0000000Uoo`8000Ioo`8009Ioo`P000=oo`03
001oogoo031oo`H00003Acl0000000X00003Acl0000002800003Acl0000001@00003Acl0000000X0
0003Acl0000000@00003Acl0000001400003Acl0000000@00003Acl0000000X00003Acl0000000L0
0003Acl0000001@00003Acl0000001400003Acl0000001400003Acl0000000@00003Acl0000001P0
0003Acl0000001@00003Acl0000000D000=oo`03001oogoo09moo`00ogooogoo3Goo10002Woo0P00
17oo0P00T7oo1`002goo00<007ooOol0:Woo1P0000=7?`0000002P0000=7?`000000100000=7?`00
00002P0000=7?`0000008P0000=7?`000000500000=7?`0000002P0000=7?`000000100000=7?`00
00004@0000=7?`000000100000=7?`0000002P0000=7?`0000001`0000=7?`000000500000=7?`00
00002P0000=7?`000000100000=7?`0000004@0000=7?`000000100000=7?`000000:P000Woo00<0
07ooOol0Wgoo003oOoooOol=Ool4000:Ool80029Ool7000BOol00`00Oomoo`0TOolC00000dLo0000
000400000dLo0000000:00000dLo0000000400000dLo0000000:00000dLo0000000R00000dLo0000
000D00000dLo0000000:00000dLo0000000400000dLo0000000A00000dLo0000000A00000dLo0000
000700000dLo0000000:00000dLo0000000700000dLo0000000:00000dLo0000000400000dLo0000
000A00000dLo0000000:00000dLo0000000400000dLo0000000?0003Ool00`00Oomoo`2NOol00?mo
oomoo`ioo`<000aoo`@008Aoo`L001Uoo`03001oogoo01]ooaH00003Acl0000001400003Acl00000
00@00003Acl0000000X00003Acl0000000@00003Acl0000000X00003Acl0000002800003Acl00000
02400003Acl0000000@00003Acl0000000X00003Acl0000000@00003Acl0000001400003Acl00000
00L00003Acl0000000X00003Acl0000001@00003Acl0000000@00003Acl0000000X00003Acl00000
01400003Acl0000000@00003Acl000000080009oo`03001oogoo09ioo`00ogooogooWWoo1`00=Goo
300000=7?`0000001`0000=7?`000000500000=7?`0000004@0000=7?`000000100000=7?`000000
2P0000=7?`000000100000=7?`0000002P0000=7?`000000:`0000=7?`000000600000=7?`000000
100000=7?`0000002P0000=7?`000000600000=7?`000000500000=7?`000000500000=7?`000000
2P0000=7?`000000100000=7?`0000003`000goo00<007ooOol0WGoo003oOoooOonGOol7000fOol<
00000dLo0000000400000dLo0000000D00000dLo0000000D00000dLo0000000A00000dLo00000004
00000dLo0000000:00000dLo0000000400000dLo0000000:00000dLo0000000D00000dLo0000000D
00000dLo0000000H00000dLo0000000:00000dLo0000000400000dLo0000000_00000dLo0000000Q
00000dLo0000000400000dLo000000020002Ool00`00Oomoo`2MOol00?mooomooi1oo`L003Moo``0
0003Acl0000000@00003Acl0000000X00003Acl0000000@00003Acl0000001@00003Acl0000001@0
0003Acl0000001400003Acl0000001400003Acl0000000@00003Acl0000000X00003Acl0000001@0
0003Acl0000001@00003Acl0000001400003Acl0000000@00003Acl0000000X00003Acl0000000@0
0003Acl0000000X00003Acl0000002/00003Acl0000001H000=oo`03001oogoo09aoo`00ogooogoo
R7oo2000>7oo300000=7?`000000100000=7?`000000100000=7?`0000000`0000=7?`0000001000
00=7?`0000002P0000=7?`000000100000=7?`000000500000=7?`000000500000=7?`0000002P00
00=7?`000000100000=7?`0000004@0000=7?`0000002P0000=7?`000000100000=7?`0000005000
00=7?`000000500000=7?`0000004@0000=7?`0000004@0000=7?`0000002P0000=7?`0000001000
00=7?`000000500000=7?`000000500000=7?`0000002@000Woo00<007ooOol0W7oo003oOoooOon1
Ool70002Ool00`00Oomoo`0bOolF00000dLo0000000A00000dLo0000000:00000dLo000000040000
0dLo0000000:00000dLo0000000400000dLo0000000:00000dLo0000000700000dLo0000000:0000
0dLo0000000700000dLo0000000:00000dLo0000000400000dLo0000000:00000dLo000000040000
0dLo0000000:00000dLo0000000400000dLo0000000:00000dLo0000000700000dLo0000000D0000
0dLo0000000:00000dLo0000000A00000dLo0000000A00000dLo0000000400000dLo0000000:0000
0dLo0000000700000dLo0000000B0003Ool00`00Oomoo`2KOol00?mooomoogYoo`L000Uoo`03001o
ogoo02UooaH00003Acl0000001@00003Acl0000000X00003Acl0000000@00003Acl0000000X00003
Acl0000000@00003Acl0000000X00003Acl0000000@00003Acl0000000X00003Acl0000000L00003
Acl0000000X00003Acl0000000L00003Acl0000000X00003Acl0000001400003Acl0000000@00003
Acl0000000X00003Acl0000000@00003Acl0000000X00003Acl0000000L00003Acl0000000X00003
Acl0000001@00003Acl0000000X00003Acl0000000@00003Acl0000001400003Acl0000001400003
Acl0000000X00003Acl000000080009oo`03001oogoo09]oo`00ogooogooLgoo1`0047oo00<007oo
Ool08goo1P0000=7?`0000002P0000=7?`000000500000=7?`000000500000=7?`0000002P0000=7
?`0000004@0000=7?`000000100000=7?`0000002P0000=7?`000000100000=7?`0000002P0000=7
?`0000001`0000=7?`0000002P0000=7?`000000500000=7?`0000004@0000=7?`0000004@0000=7
?`0000004@0000=7?`0000002P0000=7?`0000001`0000=7?`0000002P0000=7?`000000500000=7
?`000000100000=7?`0000002P0000=7?`0000004@0000=7?`00000020000goo00<007ooOol0VWoo
003oOoooOom/Ool7000GOol00`00Oomoo`0JOol900000dLo0000000:00000dLo0000000400000dLo
0000000:00000dLo0000000D00000dLo0000000:00000dLo0000000D00000dLo0000000A00000dLo
0000000400000dLo0000000:00000dLo0000000400000dLo0000000:00000dLo0000000D00000dLo
0000000D00000dLo0000000:00000dLo0000000400000dLo0000000:00000dLo0000000A00000dLo
0000000A00000dLo0000000D00000dLo0000000Q00000dLo0000000400000dLo0000000:00000dLo
000000020002Ool00`00Oomoo`2JOol00?mooomoofEoo`L001ioo`03001oogoo015oo`T00003Acl0
000001@00003Acl0000000X00003Acl0000000@00003Acl0000000X00003Acl0000000X00003Acl0
000001@00003Acl0000001@00003Acl0000001400003Acl0000001400003Acl0000000X00003Acl0
000000@00003Acl0000000X00003Acl0000000L00003Acl0000000X00003Acl0000001@00003Acl0
000000X00003Acl0000000@00003Acl0000000X00003Acl0000003P00003Acl0000002<000=oo`03
001oogoo09Uoo`00ogooogooGGoo2000<goo1P0000=7?`0000001`0000=7?`0000002P0000=7?`00
0000500000=7?`0000002P0000=7?`000000100000=7?`0000002P0000=7?`0000002P0000=7?`00
0000500000=7?`000000500000=7?`0000002P0000=7?`000000100000=7?`0000002P0000=7?`00
0000100000=7?`0000002P0000=7?`000000100000=7?`0000002P0000=7?`000000500000=7?`00
0000500000=7?`0000002P0000=7?`0000002P0000=7?`000000100000=7?`0000002P0000=7?`00
0000500000=7?`0000008@0000=7?`0000002@000Woo00<007ooOol0VGoo003oOoooOomFOol7000e
Ool600000dLo0000000400000dLo0000000:00000dLo0000000700000dLo0000000:00000dLo0000
000D00000dLo0000000:00000dLo0000000:00000dLo0000000400000dLo0000000:00000dLo0000
000D00000dLo0000000:00000dLo0000000700000dLo0000000:00000dLo0000000400000dLo0000
000:00000dLo0000000A00000dLo0000000A00000dLo0000000D00000dLo0000000Q00000dLo0000
000:00000dLo0000000:00000dLo0000000400000dLo0000000:00000dLo0000000700000dLo0000
000:00000dLo0000000B0003Ool00`00Oomoo`2HOol00?mooomoodmoo`L003Moo`D00003Acl00000
00@00003Acl0000000X00003Acl0000000@00003Acl0000000X00003Acl0000000L00003Acl00000
00X00003Acl0000001@00003Acl0000000X00003Acl0000000X00003Acl0000000@00003Acl00000
00X00003Acl0000000X00003Acl0000000L00003Acl0000000X00003Acl0000000L00003Acl00000
00X00003Acl0000000X00003Acl0000000@00003Acl0000000X00003Acl0000003`00003Acl00000
01X00003Acl0000001400003Acl0000001400003Acl0000000X00003Acl0000000L00003Acl00000
00D0009oo`03001oogoo09Qoo`00ogooogooB7oo2000=7oo5P0000=7?`0000000`0000=7?`000000
100000=7?`0000002P0000=7?`000000100000=7?`0000002P0000=7?`000000500000=7?`000000
2P0000=7?`000000500000=7?`0000002P0000=7?`0000002P0000=7?`000000100000=7?`000000
2P0000=7?`0000001`0000=7?`0000002P0000=7?`0000002P0000=7?`0000001`0000=7?`000000
2P0000=7?`0000002P0000=7?`000000100000=7?`0000002P0000=7?`000000>00000=7?`000000
2P0000=7?`000000100000=7?`0000002P0000=7?`0000004@0000=7?`0000004@0000=7?`000000
0P000Woo00<007ooOol0Ugoo003oOolVOol<000;Ool4003oOol70007Ool00`00Oomoo`0YOol90000
0dLo0000000:00000dLo0000000J00000dLo0000000400000dLo0000000:00000dLo0000000A0000
0dLo0000000:00000dLo0000000700000dLo0000000:00000dLo0000000D00000dLo000000030000
0dLo0000000400000dLo0000000:00000dLo0000000400000dLo0000000:00000dLo0000000:0000
0dLo0000000700000dLo0000000:00000dLo0000000D00000dLo0000000:00000dLo0000000:0000
0dLo0000000400000dLo0000000:00000dLo0000000D00000dLo0000000:00000dLo0000000D0000
0dLo0000000:00000dLo0000000400000dLo0000000:00000dLo0000000?0002Ool00`00Oomoo`2G
Ool00?moobIoo``000Uoo`P00?Ioo`L000ioo`03001oogoo02=oo`H00003Acl0000000X00003Acl0
000001@00003Acl0000000H00003Acl0000001400003Acl0000000@00003Acl0000000<00003Acl0
000000@00003Acl0000000X00003Acl0000000@00003Acl0000000X00003Acl0000001@00003Acl0
000001X00003Acl0000000@00003Acl0000000X00003Acl0000000X00003Acl0000000@00003Acl0
000000X00003Acl0000001@00003Acl0000002400003Acl0000000X00003Acl0000000X00003Acl0
000000@00003Acl0000000X00003Acl0000001@00003Acl0000002400003Acl0000000X00003Acl0
000000P000=oo`03001oogoo09Ioo`00ogoo9goo0`001Woo0P002Goo0P0017oo0P00kWoo20005Goo
00<007ooOol07Goo1P0000=7?`0000002P0000=7?`0000004@0000=7?`000000500000=7?`000000
1P0000=7?`0000007P0000=7?`000000100000=7?`0000002P0000=7?`0000004@0000=7?`000000
7@0000=7?`0000007P0000=7?`000000100000=7?`0000002P0000=7?`0000004@0000=7?`000000
8@0000=7?`0000006P0000=7?`0000004@0000=7?`000000=@0000=7?`0000006P0000=7?`000000
0P000goo00<007ooOol0UGoo003oOolXOol3000?Ool20006Ool2003VOol7000MOol00`00Oomoo`0G
Ool=00000dLo0000000300000dLo0000000400000dLo0000000300000dLo0000000400000dLo0000
000A00000dLo0000000Q00000dLo0000000600000dLo0000000A00000dLo0000000400000dLo0000
000300000dLo0000000400000dLo0000000J00000dLo0000000Q00000dLo0000000A00000dLo0000
000:00000dLo0000001500000dLo0000000:00000dLo0000000400000dLo0000000:00000dLo0000
000:00000dLo0000000h00000dLo000000080003Ool00`00Oomoo`2EOol00?moobUoo`<000ioo`80
00Ioo`800=moo`L003Ioo``00003Acl0000001X00003Acl0000000@00003Acl0000000<00003Acl0
000000@00003Acl0000001h00003Acl0000001@00003Acl0000000H00003Acl0000001400003Acl0
000000X00003Acl0000000@00003Acl0000000<00003Acl0000002400003Acl0000001@00003Acl0
000000X00003Acl0000000X00003Acl0000000@00003Acl0000000X00003Acl0000000X00003Acl0
000001@00003Acl0000000X00003Acl0000001@00003Acl0000000X00003Acl0000000X00003Acl0
000000@00003Acl0000000X00003Acl0000000X00003Acl0000000L00003Acl0000000X00003Acl0
000000D000=oo`03001oogoo09Aoo`00ogoo:Woo0`0037oo0P0027oo0P00egoo1`00=7oo300000=7
?`0000001`0000=7?`0000002P0000=7?`0000001P0000=7?`0000004@0000=7?`000000100000=7
?`0000000`0000=7?`000000100000=7?`0000000`0000=7?`000000100000=7?`0000004@0000=7
?`0000007@0000=7?`0000002P0000=7?`0000004@0000=7?`0000002P0000=7?`0000002P0000=7
?`000000500000=7?`0000002P0000=7?`0000001`0000=7?`0000002P0000=7?`0000002P0000=7
?`0000002P0000=7?`000000100000=7?`0000002P0000=7?`0000002P0000=7?`000000500000=7
?`0000002P0000=7?`0000008@0000=7?`0000002P0000=7?`0000004@0000=7?`0000003`000Woo
00<007ooOol0U7oo003oOol[Ool3000;Ool20008Ool2003?Ool8000eOol<00000dLo000000040000
0dLo0000000:00000dLo0000000D00000dLo0000000600000dLo0000000N00000dLo000000040000
0dLo0000000300000dLo0000000400000dLo0000000J00000dLo0000000Q00000dLo0000000:0000
0dLo0000000:00000dLo0000000400000dLo0000000:00000dLo0000000:00000dLo000000070000
0dLo0000000:00000dLo0000000:00000dLo0000000D00000dLo0000000:00000dLo0000000:0000
0dLo0000000A00000dLo0000000:00000dLo0000000M00000dLo0000000A00000dLo0000000:0000
0dLo0000000L0003Ool00`00Oomoo`2COol00?moobaoo`<000Yoo`8000Qoo`800<Uoo`L003=oo`T0
0003Acl0000000<00003Acl0000000@00003Acl0000000X00003Acl0000001400003Acl0000001@0
0003Acl0000000X00003Acl0000000H00003Acl0000001400003Acl0000000X00003Acl0000000@0
0003Acl0000000<00003Acl0000002400003Acl0000000X00003Acl0000000L00003Acl0000000X0
0003Acl0000000X00003Acl0000000X00003Acl0000000@00003Acl0000000X00003Acl0000000X0
0003Acl0000001@00003Acl0000001X00003Acl0000000X00003Acl0000001400003Acl0000001X0
0003Acl0000001@00003Acl0000000X00003Acl0000000X00003Acl0000000X00003Acl0000000@0
0003Acl000000080009oo`03001oogoo09=oo`00ogoo;Goo0`002Goo0P0027oo0P00`Woo1`001Woo
00<007ooOol0:7oo2@0000=7?`0000001`0000=7?`0000002P0000=7?`0000000`0000=7?`000000
100000=7?`0000000`0000=7?`000000100000=7?`0000004@0000=7?`0000002P0000=7?`000000
500000=7?`0000001P0000=7?`0000002P0000=7?`0000004@0000=7?`0000002P0000=7?`000000
2P0000=7?`0000002P0000=7?`0000001`0000=7?`0000002P0000=7?`0000008@0000=7?`000000
2P0000=7?`0000002P0000=7?`0000004@0000=7?`0000007@0000=7?`0000002P0000=7?`000000
2P0000=7?`000000100000=7?`0000002P0000=7?`0000002P0000=7?`0000002P0000=7?`000000
1`0000=7?`0000002P0000=7?`0000002P0000=7?`0000007`000goo00<007ooOol0TWoo003oOol^
Ool30008Ool20008Ool2002jOol8000=Ool00`00Oomoo`0SOol500000dLo0000000700000dLo0000
000:00000dLo0000000D00000dLo0000000:00000dLo0000000300000dLo0000000400000dLo0000
000:00000dLo0000000A00000dLo0000000Z00000dLo0000000:00000dLo0000000:00000dLo0000
000400000dLo0000000:00000dLo0000000:00000dLo0000000D00000dLo0000000:00000dLo0000
000J00000dLo0000000:00000dLo0000000400000dLo0000000J00000dLo0000000:00000dLo0000
000:00000dLo0000000700000dLo0000000:00000dLo0000000:00000dLo0000000:00000dLo0000
000A00000dLo0000000:00000dLo0000000M00000dLo000000080003Ool00`00Oomoo`2BOol00?mo
obmoo`8000Qoo`8000Qoo`800;=oo`L001Eoo`03001oogoo01eoo`H00003Acl0000000<00003Acl0
000000X00003Acl0000000L00003Acl0000000X00003Acl0000000X00003Acl0000001@00003Acl0
000000<00003Acl0000000@00003Acl0000000<00003Acl0000000@00003Acl0000002L00003Acl0
000001@00003Acl0000000X00003Acl0000000X00003Acl0000000X00003Acl0000001400003Acl0
000000X00003Acl0000001d00003Acl0000000X00003Acl0000001400003Acl0000000X00003Acl0
000000X00003Acl0000000X00003Acl0000000L00003Acl0000000X00003Acl0000002L00003Acl0
000002h00003Acl0000000X00003Acl0000000D000=oo`03001oogoo095oo`00ogoo<7oo0P001goo
0P0027oo0P00[7oo1`0077oo00<007ooOol05goo4`0000=7?`0000002P0000=7?`0000002P0000=7
?`0000002P0000=7?`0000001`0000=7?`0000002P0000=7?`0000009`0000=7?`000000100000=7
?`0000000`0000=7?`000000100000=7?`0000000`0000=7?`000000500000=7?`0000002P0000=7
?`000000500000=7?`0000002P0000=7?`0000000`0000=7?`000000100000=7?`0000002P0000=7
?`0000006P0000=7?`0000002P0000=7?`000000500000=7?`0000002P0000=7?`0000002P0000=7
?`0000002P0000=7?`0000004@0000=7?`000000:P0000=7?`0000002P0000=7?`0000002P0000=7
?`000000100000=7?`0000002P0000=7?`0000002P0000=7?`0000003`000Woo00<007ooOol0TGoo
003oOol`Ool20007Ool20008Ool2002UOol7000SOol00`00Oomoo`0?Ool<00000dLo000000060000
0dLo0000000:00000dLo0000000400000dLo0000000:00000dLo0000000:00000dLo0000000:0000
0dLo0000000700000dLo0000000:00000dLo0000000:00000dLo0000000600000dLo0000000A0000
0dLo0000000:00000dLo0000000:00000dLo0000000:00000dLo0000000700000dLo0000000:0000
0dLo0000000:00000dLo0000000J00000dLo0000000:00000dLo0000000400000dLo000000030000
0dLo0000000:00000dLo0000000D00000dLo0000000:00000dLo0000000W00000dLo000000040000
0dLo0000000W00000dLo0000000:00000dLo0000000Q00000dLo0000000:00000dLo0000000E0003
Ool00`00Oomoo`2@Ool00?moobMoo`8000Moo`8000Qoo`8000Ioo`8009moo`L002Yoo`03001oogoo
00Ioo``00003Acl0000000L00003Acl0000000X00003Acl0000000H00003Acl0000000X00003Acl0
000000X00003Acl0000000@00003Acl0000000X00003Acl0000000X00003Acl0000000X00003Acl0
000000L00003Acl0000000X00003Acl0000000H00003Acl0000000X00003Acl0000000X00003Acl0
000000@00003Acl0000000X00003Acl0000000X00003Acl0000000X00003Acl0000001@00003Acl0
000000H00003Acl0000000X00003Acl0000001400003Acl0000000X00003Acl0000000X00003Acl0
000000X00003Acl0000002400003Acl0000000H00003Acl0000001400003Acl0000000X00003Acl0
000000X00003Acl0000000X00003Acl0000002400003Acl0000001X00003Acl0000000X00003Acl0
00000080009oo`03001oogoo091oo`00ogoo9goo0`001Woo0P0027oo0P001Woo0P00Ugoo2000<Goo
00<007ooOol01P0000=7?`0000002P0000=7?`0000002P0000=7?`000000500000=7?`0000001P00
00=7?`0000002P0000=7?`0000002P0000=7?`0000002P0000=7?`0000002P0000=7?`0000001000
00=7?`0000002P0000=7?`000000:P0000=7?`0000002P0000=7?`0000002P0000=7?`0000002P00
00=7?`0000004@0000=7?`000000:P0000=7?`0000002P0000=7?`0000002P0000=7?`0000002P00
00=7?`0000007P0000=7?`0000007@0000=7?`0000002P0000=7?`0000002P0000=7?`0000002P00
00=7?`000000B`0000=7?`00000020000goo00<007ooOol0Sgoo003oOolWOol40004Ool2000:Ool2
0004Ool2002AOol8000cOol800000dLo0000000:00000dLo0000000:00000dLo0000000A00000dLo
0000000Z00000dLo0000000:00000dLo0000000:00000dLo0000000:00000dLo0000000W00000dLo
0000000D00000dLo0000000:00000dLo0000000:00000dLo0000000300000dLo0000000400000dLo
0000000W00000dLo0000000:00000dLo0000000W00000dLo0000000400000dLo0000000300000dLo
0000000400000dLo0000000J00000dLo0000000:00000dLo0000000W00000dLo0000000:00000dLo
0000000:00000dLo0000000:00000dLo0000000D00000dLo0000000:00000dLo000000050002Ool0
0`00Oomoo`2?Ool00?moobQoo`P000]oo`P008Yoo`L000Moo`03001oogoo02Qoo`T00003Acl00000
00H00003Acl0000000X00003Acl0000000X00003Acl0000000<00003Acl0000000@00003Acl00000
02L00003Acl0000002400003Acl0000000X00003Acl0000000<00003Acl0000000@00003Acl00000
00<00003Acl0000000@00003Acl0000000<00003Acl0000001@00003Acl0000000X00003Acl00000
00X00003Acl0000001X00003Acl0000000X00003Acl0000000X00003Acl0000000X00003Acl00000
00L00003Acl0000000X00003Acl0000000X00003Acl0000000H00003Acl0000001400003Acl00000
00X00003Acl0000000X00003Acl0000000X00003Acl0000002X00003Acl0000000X00003Acl00000
00X00003Acl0000000X00003Acl0000002l000=oo`03001oogoo08ioo`00ogoo:Woo1@003Woo1000
QGoo1`003Woo00<007ooOol08Woo1P0000=7?`000000:P0000=7?`0000002P0000=7?`0000000`00
00=7?`000000100000=7?`0000000`0000=7?`000000100000=7?`0000000`0000=7?`0000008@00
00=7?`0000002P0000=7?`0000009`0000=7?`0000002P0000=7?`0000002P0000=7?`0000002P00
00=7?`0000001`0000=7?`0000002P0000=7?`0000001P0000=7?`0000002P0000=7?`0000002P00
00=7?`0000002P0000=7?`000000100000=7?`0000002P0000=7?`0000002P0000=7?`0000007@00
00=7?`0000002P0000=7?`0000002P0000=7?`0000002P0000=7?`0000009`0000=7?`0000002P00
00=7?`0000009`0000=7?`0000002P0000=7?`0000002P0000=7?`0000002P0000=7?`0000000P00
0Woo00<007ooOol0SWoo003oOonoOol7000EOol00`00Oomoo`0LOol600000dLo0000000W00000dLo
0000000D00000dLo0000000:00000dLo0000000:00000dLo0000000300000dLo0000000400000dLo
0000000300000dLo0000000400000dLo0000000300000dLo0000000:00000dLo0000000700000dLo
0000000:00000dLo0000000:00000dLo0000000600000dLo0000000:00000dLo0000000400000dLo
0000000:00000dLo0000000:00000dLo0000000:00000dLo0000000Z00000dLo0000000:00000dLo
0000000:00000dLo0000000:00000dLo0000000J00000dLo0000000:00000dLo0000000:00000dLo
0000000J00000dLo0000000:00000dLo0000000:00000dLo0000000:00000dLo0000000Z00000dLo
0000000:00000dLo0000000:00000dLo0000000:00000dLo000000080003Ool00`00Oomoo`2=Ool0
0?mookQoo`L001aoo`03001oogoo01Moo``00003Acl0000000X00003Acl0000000<00003Acl00000
00@00003Acl0000000<00003Acl0000001@00003Acl0000000X00003Acl0000000X00003Acl00000
02L00003Acl0000000X00003Acl0000000X00003Acl0000000X00003Acl0000000L00003Acl00000
00X00003Acl0000000H00003Acl0000000X00003Acl0000000X00003Acl0000000X00003Acl00000
02L00003Acl0000000X00003Acl0000002L00003Acl0000000X00003Acl0000000X00003Acl00000
00X00003Acl0000001d00003Acl0000000X00003Acl0000000X00003Acl0000000X00003Acl00000
02L00003Acl0000000X00003Acl0000000X00003Acl0000001X00003Acl000000080009oo`03001o
ogoo08eoo`00ogoo/Goo1`00=Goo300000=7?`0000002P0000=7?`0000001P0000=7?`0000002P00
00=7?`0000000`0000=7?`000000100000=7?`0000000`0000=7?`0000002P0000=7?`0000002P00
00=7?`0000001`0000=7?`0000002P0000=7?`0000002P0000=7?`0000001P0000=7?`0000002P00
00=7?`0000002P0000=7?`000000100000=7?`0000002P0000=7?`0000002P0000=7?`000000:P00
00=7?`0000002P0000=7?`0000000`0000=7?`000000100000=7?`0000000`0000=7?`0000001000
00=7?`0000000`0000=7?`0000002P0000=7?`0000001`0000=7?`0000002P0000=7?`0000002P00
00=7?`0000001P0000=7?`0000002P0000=7?`0000002P0000=7?`0000002P0000=7?`0000006P00
00=7?`0000002P0000=7?`0000002P0000=7?`0000009`0000=7?`0000002P0000=7?`0000002P00
00=7?`0000002P0000=7?`0000007@0000=7?`00000020000goo00<007ooOol0S7oo003oOonZOol7
000cOol<00000dLo0000000:00000dLo0000000M00000dLo0000000:00000dLo0000000:00000dLo
0000000300000dLo0000000400000dLo0000000300000dLo0000000:00000dLo0000000:00000dLo
0000000700000dLo0000000:00000dLo0000000600000dLo0000000:00000dLo0000000:00000dLo
0000000:00000dLo0000000W00000dLo0000000:00000dLo0000000W00000dLo0000000:00000dLo
0000000:00000dLo0000000:00000dLo0000000M00000dLo0000000M00000dLo0000000:00000dLo
0000000:00000dLo0000000:00000dLo0000000Z00000dLo0000000:00000dLo0000000:00000dLo
0000000:00000dLo0000000J00000dLo0000000:00000dLo000000050002Ool00`00Oomoo`2<Ool0
0?mooj9oo`P003Aoo``00003Acl0000000X00003Acl0000001X00003Acl0000000X00003Acl00000
00X00003Acl0000001X00003Acl0000000X00003Acl0000000X00003Acl0000000X00003Acl00000
02X00003Acl0000000X00003Acl0000000<00003Acl0000000@00003Acl0000000<00003Acl00000
00@00003Acl0000000<00003Acl0000000X00003Acl0000000L00003Acl0000000X00003Acl00000
01<00003Acl0000000X00003Acl0000000X00003Acl0000000X00003Acl0000001X00003Acl00000
00X00003Acl0000000X00003Acl0000000H00003Acl0000000X00003Acl0000000X00003Acl00000
00X00003Acl0000002L00003Acl0000000X00003Acl0000002L00003Acl0000000X00003Acl00000
00X00003Acl0000000X00003Acl000000080009oo`03001oogoo08]oo`00ogooVgoo1`0000=oo`00
Ool0<Goo200000=7?`0000002P0000=7?`0000002P0000=7?`0000000`0000=7?`000000100000=7
?`0000000`0000=7?`0000002P0000=7?`0000002P0000=7?`0000001`0000=7?`0000002P0000=7
?`0000001P0000=7?`0000002P0000=7?`0000002P0000=7?`0000002P0000=7?`0000009`0000=7
?`0000002P0000=7?`0000009`0000=7?`0000002P0000=7?`0000002P0000=7?`0000004`0000=7
?`0000002P0000=7?`0000002P0000=7?`0000006P0000=7?`0000002P0000=7?`0000002P0000=7
?`0000002P0000=7?`000000?@0000=7?`0000002P0000=7?`0000002P0000=7?`0000002P0000=7
?`000000:P0000=7?`0000002P0000=7?`0000002P0000=7?`0000005@000Woo00<007ooOol0Rgoo
003oOonDOol70008Ool00`00Oomoo`0WOol900000dLo0000000:00000dLo0000000:00000dLo0000
000600000dLo0000000:00000dLo0000000300000dLo0000000400000dLo0000000300000dLo0000
000400000dLo0000000300000dLo0000000:00000dLo0000000700000dLo0000000:00000dLo0000
000:00000dLo0000000600000dLo0000000:00000dLo0000000:00000dLo0000000300000dLo0000
000400000dLo0000000300000dLo0000000:00000dLo0000000700000dLo0000000:00000dLo0000
000:00000dLo0000000600000dLo0000000:00000dLo0000000:00000dLo0000000:00000dLo0000
000300000dLo0000000:00000dLo0000000:00000dLo0000000700000dLo0000000:00000dLo0000
000600000dLo0000000:00000dLo0000000:00000dLo0000000:00000dLo0000000W00000dLo0000
000:00000dLo0000000600000dLo0000000:00000dLo0000000:00000dLo0000000:00000dLo0000
000W00000dLo0000000:00000dLo0000000:00000dLo0000000C00000dLo000000080003Ool00`00
Oomoo`2:Ool00?mooheoo`L000moo`03001oogoo029oo`D00003Acl0000000X00003Acl0000000X0
0003Acl0000000L00003Acl0000001<00003Acl0000000X00003Acl0000000X00003Acl0000000<0
0003Acl0000000@00003Acl0000000<00003Acl0000000X00003Acl0000000X00003Acl0000002X0
0003Acl0000000X00003Acl0000000<00003Acl0000000X00003Acl0000000X00003Acl0000000X0
0003Acl0000002X00003Acl0000001000003Acl0000000X00003Acl0000000X00003Acl0000000X0
0003Acl0000004X00003Acl0000000X00003Acl0000000X00003Acl0000002000003Acl0000002L0
0003Acl0000000X00003Acl0000000X00003Acl0000002000003Acl00000018000=oo`03001oogoo
08Uoo`00ogooQWoo1`005Woo00<007ooOol06Goo700000=7?`0000002P0000=7?`0000004`0000=7
?`0000002P0000=7?`0000002P0000=7?`000000;@0000=7?`0000009`0000=7?`0000002P0000=7
?`0000004`0000=7?`0000002P0000=7?`0000002P0000=7?`0000009`0000=7?`0000002P0000=7
?`0000001P0000=7?`0000002P0000=7?`0000002P0000=7?`0000002P0000=7?`0000009`0000=7
?`0000002P0000=7?`0000002P0000=7?`0000001P0000=7?`0000002P0000=7?`0000002P0000=7
?`0000007@0000=7?`0000001`0000=7?`000000800000=7?`0000002P0000=7?`0000002P0000=7
?`000000400000=7?`0000002P0000=7?`00000070000Woo00<007ooOol0RGoo003oOomoOol7000M
Ool00`00Oomoo`0@Ool900000dLo0000000:00000dLo0000000600000dLo0000000:00000dLo0000
000:00000dLo0000000300000dLo0000000:00000dLo0000000:00000dLo0000000700000dLo0000
000:00000dLo0000000:00000dLo0000000600000dLo0000000:00000dLo0000000300000dLo0000
000400000dLo0000000300000dLo0000000400000dLo0000000300000dLo0000000:00000dLo0000
000700000dLo0000000:00000dLo0000000:00000dLo0000000600000dLo0000000:00000dLo0000
000:00000dLo0000000300000dLo0000000400000dLo0000000300000dLo0000000:00000dLo0000
000Z00000dLo0000000:00000dLo0000000@00000dLo0000000:00000dLo0000000:00000dLo0000
000:00000dLo0000000C00000dLo0000000W00000dLo0000000:00000dLo0000000P00000dLo0000
000:00000dLo0000000P00000dLo0000000:00000dLo0000000R0003Ool00`00Oomoo`28Ool00?mo
ogMoo`P0039oo`D00003Acl0000000X00003Acl0000000L00003Acl0000000X00003Acl0000000H0
0003Acl0000000X00003Acl0000000X00003Acl0000000<00003Acl0000000@00003Acl0000000<0
0003Acl0000000X00003Acl0000000X00003Acl0000000L00003Acl0000000X00003Acl0000000H0
0003Acl0000000X00003Acl0000000X00003Acl0000000<00003Acl0000000@00003Acl0000000<0
0003Acl0000000X00003Acl0000000X00003Acl0000002000003Acl0000001X00003Acl0000002d0
0003Acl0000000X00003Acl0000000X00003Acl0000000H00003Acl0000000X00003Acl0000000X0
0003Acl0000000X00003Acl0000001000003Acl0000000L00003Acl0000002000003Acl0000000X0
0003Acl0000000X00003Acl0000000<00003Acl0000000X00003Acl0000000X00003Acl0000004X0
0003Acl0000000X00003Acl000000080009oo`03001oogoo08Qoo`00ogooL7oo1`00<Woo200000=7
?`0000000`0000=7?`000000100000=7?`0000000`0000=7?`0000002P0000=7?`0000001`0000=7
?`0000002P0000=7?`0000002P0000=7?`0000001P0000=7?`0000002P0000=7?`0000002P0000=7
?`0000000`0000=7?`000000100000=7?`0000000`0000=7?`0000002P0000=7?`000000800000=7
?`000000800000=7?`0000002P0000=7?`0000007@0000=7?`0000001`0000=7?`0000002P0000=7
?`0000001P0000=7?`0000002P0000=7?`0000002P0000=7?`0000000`0000=7?`000000100000=7
?`0000000`0000=7?`0000002P0000=7?`0000002P0000=7?`0000007@0000=7?`0000007@0000=7
?`0000002P0000=7?`000000800000=7?`0000002P0000=7?`0000002P0000=7?`0000004`0000=7
?`0000002P0000=7?`000000BP0000=7?`0000002P0000=7?`00000020000goo00<007ooOol0Qgoo
003oOomYOol7000`Ool900000dLo0000000600000dLo0000000:00000dLo0000000300000dLo0000
000400000dLo0000000300000dLo0000000:00000dLo0000000:00000dLo0000000P00000dLo0000
000P00000dLo0000000M00000dLo0000000700000dLo0000000:00000dLo0000000:00000dLo0000
000600000dLo0000000:00000dLo0000000:00000dLo0000000300000dLo0000000400000dLo0000
000300000dLo0000000:00000dLo0000001@00000dLo0000000J00000dLo0000000:00000dLo0000
000:00000dLo0000000600000dLo0000000:00000dLo0000000:00000dLo0000000300000dLo0000
000400000dLo0000000300000dLo0000000:00000dLo0000000:00000dLo0000000m00000dLo0000
000]00000dLo0000000:00000dLo0000000A0003Ool00`00Oomoo`27Ool00?moof9oo`L000=oo`03
001oogoo02aoo`D00003Acl0000000L00003Acl0000000X00003Acl0000000H00003Acl0000000X0
0003Acl0000001000003Acl0000002<00003Acl0000000L00003Acl0000000X00003Acl0000000X0
0003Acl0000000H00003Acl0000000X00003Acl0000000<00003Acl0000000@00003Acl0000000<0
0003Acl0000000X00003Acl0000000X00003Acl0000003d00003Acl0000002d00003Acl0000000X0
0003Acl0000000X00003Acl0000000H00003Acl0000000X00003Acl0000000X00003Acl0000000<0
0003Acl0000000X00003Acl0000000X00003Acl0000002000003Acl0000002000003Acl0000000X0
0003Acl0000001X00003Acl0000002000003Acl0000000X00003Acl0000001000003Acl0000000X0
0003Acl0000000X00003Acl0000001<00003Acl0000000D000=oo`03001oogoo08Ioo`00ogooFgoo
1`002Woo00<007ooOol09Woo1P0000=7?`0000000`0000=7?`0000002P0000=7?`0000004`0000=7
?`0000002P0000=7?`0000001P0000=7?`0000002P0000=7?`0000002P0000=7?`0000000`0000=7
?`000000100000=7?`0000000`0000=7?`0000002P0000=7?`0000002P0000=7?`0000001`0000=7
?`0000002P0000=7?`0000001P0000=7?`0000002P0000=7?`000000400000=7?`000000;@0000=7
?`0000002P0000=7?`0000001P0000=7?`0000002P0000=7?`0000002P0000=7?`0000000`0000=7
?`000000100000=7?`0000000`0000=7?`0000002P0000=7?`0000002P0000=7?`0000004`0000=7
?`0000002P0000=7?`0000004`0000=7?`0000002P0000=7?`0000007@0000=7?`0000001`0000=7
?`000000800000=7?`0000007@0000=7?`000000800000=7?`0000002P0000=7?`0000002P0000=7
?`0000001P0000=7?`0000002P0000=7?`0000002P0000=7?`000000400000=7?`0000002P0000=7
?`0000000P000Woo00<007ooOol0QWoo003oOomDOol7000AOol00`00Oomoo`0QOol<00000dLo0000
000L00000dLo0000000:00000dLo0000000700000dLo0000000:00000dLo0000000:00000dLo0000
000600000dLo0000000:00000dLo0000000:00000dLo0000000300000dLo0000000400000dLo0000
000300000dLo0000000:00000dLo0000000C00000dLo0000000:00000dLo0000000600000dLo0000
000:00000dLo0000000:00000dLo0000000300000dLo0000000400000dLo0000000300000dLo0000
000:00000dLo0000000700000dLo0000000i00000dLo0000000:00000dLo0000000@00000dLo0000
000:00000dLo0000000700000dLo0000000C00000dLo0000000:00000dLo0000000@00000dLo0000
000:00000dLo0000000P00000dLo0000000:00000dLo0000000C00000dLo0000000:00000dLo0000
000300000dLo0000000:00000dLo0000000:00000dLo0000000:00000dLo0000000C00000dLo0000
000:00000dLo0000000C00000dLo0000000:00000dLo000000080003Ool00`00Oomoo`25Ool00?mo
odaoo`P001Qoo`03001oogoo01UooaP00003Acl0000000H00003Acl0000000X00003Acl0000000<0
0003Acl0000000@00003Acl0000000<00003Acl0000000X00003Acl0000000X00003Acl0000000L0
0003Acl0000000X00003Acl0000002`00003Acl0000001000003Acl0000000X00003Acl0000000L0
0003Acl0000000X00003Acl0000000X00003Acl0000000H00003Acl0000001d00003Acl000000200
0003Acl0000000X00003Acl0000000X00003Acl0000000H00003Acl0000000X00003Acl0000000X0
0003Acl0000000<00003Acl0000000X00003Acl0000001<00003Acl0000000X00003Acl0000000X0
0003Acl0000000H00003Acl0000000X00003Acl0000000X00003Acl0000000<00003Acl0000000@0
0003Acl0000000<00003Acl0000000X00003Acl0000001<00003Acl0000000X00003Acl0000001<0
0003Acl0000000X00003Acl0000000X00003Acl0000001000003Acl0000000X00003Acl000000200
0003Acl000000180009oo`03001oogoo08Eoo`00ogooAGoo1`00<goo600000=7?`0000001`0000=7
?`0000002P0000=7?`0000001P0000=7?`0000002P0000=7?`0000002P0000=7?`0000000`0000=7
?`000000100000=7?`0000000`0000=7?`0000002P0000=7?`0000004`0000=7?`0000002P0000=7
?`0000002P0000=7?`0000001P0000=7?`0000002P0000=7?`0000000`0000=7?`000000100000=7
?`0000000`0000=7?`0000002P0000=7?`0000002P0000=7?`0000004`0000=7?`0000002P0000=7
?`0000001P0000=7?`0000002P0000=7?`0000002P0000=7?`0000000`0000=7?`0000002P0000=7
?`0000002P0000=7?`0000004`0000=7?`0000002P0000=7?`0000004`0000=7?`0000002P0000=7
?`0000000`0000=7?`0000002P0000=7?`0000002P0000=7?`000000800000=7?`000000800000=7
?`0000002P0000=7?`0000000`0000=7?`0000002P0000=7?`000000@`0000=7?`0000002P0000=7
?`0000007@0000=7?`0000006`000goo00<007ooOol0Q7oo003oOolnOol7000dOol<00000dLo0000
000300000dLo0000000400000dLo0000000300000dLo0000000:00000dLo0000000700000dLo0000
000:00000dLo0000000:00000dLo0000000600000dLo0000000F00000dLo0000000:00000dLo0000
000300000dLo0000000:00000dLo0000000:00000dLo0000000700000dLo0000000:00000dLo0000
000600000dLo0000000S00000dLo0000000@00000dLo0000000:00000dLo0000000700000dLo0000
000i00000dLo0000000@00000dLo0000000:00000dLo0000000700000dLo0000000i00000dLo0000
000M00000dLo0000000700000dLo0000001S00000dLo0000001600000dLo0000000M00000dLo0000
00020002Ool00`00Oomoo`24Ool00?moocEoo`03001oo`0000H003=oo``00003Acl0000000H00003
Acl0000000X00003Acl0000000X00003Acl0000000<00003Acl0000000X00003Acl0000000X00003
Acl0000001<00003Acl0000000X00003Acl0000000H00003Acl0000000X00003Acl0000000X00003
Acl0000000<00003Acl0000000@00003Acl0000000<00003Acl0000000X00003Acl0000001<00003
Acl0000000X00003Acl0000000H00003Acl0000000X00003Acl0000000X00003Acl0000000<00003
Acl0000000@00003Acl0000000<00003Acl0000002000003Acl0000000X00003Acl0000000H00003
Acl0000000X00003Acl0000000X00003Acl0000000<00003Acl0000000X00003Acl0000002000003
Acl0000000X00003Acl0000001<00003Acl0000000X00003Acl0000000<00003Acl0000000X00003
Acl0000002000003Acl0000000X00003Acl0000001<00003Acl0000001000003Acl0000000X00003
Acl0000002000003Acl0000002000003Acl0000002<00003Acl0000000P000=oo`03001oogoo08=o
o`00ogoo<7oo1`00<Goo300000=7?`0000001`0000=7?`0000002P0000=7?`0000002P0000=7?`00
00001P0000=7?`0000002P0000=7?`000000700000=7?`0000002P0000=7?`0000001`0000=7?`00
00002P0000=7?`0000002P0000=7?`0000001P0000=7?`0000005P0000=7?`000000400000=7?`00
00002P0000=7?`0000001`0000=7?`0000002P0000=7?`000000;00000=7?`0000000`0000=7?`00
0000100000=7?`0000000`0000=7?`0000002P0000=7?`000000800000=7?`0000004`0000=7?`00
00002P0000=7?`0000000`0000=7?`000000100000=7?`0000000`0000=7?`0000002P0000=7?`00
00004`0000=7?`0000002P0000=7?`0000004`0000=7?`0000002P0000=7?`0000000`0000=7?`00
00002P0000=7?`0000002P0000=7?`0000004`0000=7?`0000002P0000=7?`0000001P0000=7?`00
00002P0000=7?`0000002P0000=7?`0000000`0000=7?`0000002P0000=7?`000000800000=7?`00
0000800000=7?`0000005@000Woo00<007ooOol0Pgoo003oOolYOol70005Ool00`00Oomoo`0[Ool<
00000dLo0000000300000dLo0000000:00000dLo0000000:00000dLo0000000700000dLo0000000F
00000dLo0000000600000dLo0000000:00000dLo0000000:00000dLo0000000300000dLo0000000:
00000dLo0000000:00000dLo0000000C00000dLo0000000:00000dLo0000000600000dLo0000000:
00000dLo0000000:00000dLo0000000300000dLo0000000:00000dLo0000000C00000dLo0000000:
00000dLo0000000:00000dLo0000000600000dLo0000000:00000dLo0000000Y00000dLo00000007
00000dLo0000000:00000dLo0000000C00000dLo0000000F00000dLo0000000:00000dLo00000003
00000dLo0000000:00000dLo0000000P00000dLo0000000C00000dLo0000000:00000dLo0000000:
00000dLo0000000300000dLo0000000:00000dLo0000000C00000dLo0000000:00000dLo0000000C
00000dLo0000000:00000dLo0000000300000dLo0000000:00000dLo0000000P00000dLo0000000N
0003Ool00`00Oomoo`22Ool00?moob9oo`L000aoo`03001oogoo02=oo``00003Acl0000000H00003
Acl0000000X00003Acl0000000<00003Acl0000000@00003Acl0000000<00003Acl0000001H00003
Acl0000000L00003Acl0000000X00003Acl0000000X00003Acl0000000H00003Acl0000000X00003
Acl0000001`00003Acl0000000X00003Acl0000000L00003Acl0000000X00003Acl0000001l00003
Acl0000000X00003Acl0000000<00003Acl0000000X00003Acl0000000X00003Acl0000001<00003
Acl0000000X00003Acl0000000H00003Acl0000000X00003Acl0000000X00003Acl0000000<00003
Acl0000000X00003Acl0000001<00003Acl0000000X00003Acl0000000X00003Acl0000000H00003
Acl0000000X00003Acl0000002T00003Acl0000000L00003Acl0000003T00003Acl0000001000003
Acl0000000X00003Acl0000002000003Acl0000001<00003Acl0000000X00003Acl0000000<00003
Acl0000000X00003Acl0000002000003Acl0000000D0009oo`03001oogoo089oo`00ogoo6Woo2000
4goo00<007ooOol06Woo300000=7?`0000001`0000=7?`0000002P0000=7?`0000001P0000=7?`00
00002P0000=7?`0000003`0000=7?`000000100000=7?`0000000`0000=7?`0000002P0000=7?`00
00002P0000=7?`0000001`0000=7?`0000005P0000=7?`0000001P0000=7?`0000002P0000=7?`00
00002P0000=7?`0000000`0000=7?`0000002P0000=7?`0000004`0000=7?`0000002P0000=7?`00
00002P0000=7?`0000001P0000=7?`0000002P0000=7?`000000700000=7?`0000002P0000=7?`00
00001`0000=7?`000000;00000=7?`0000002P0000=7?`0000000`0000=7?`0000002P0000=7?`00
00002P0000=7?`0000004`0000=7?`0000002P0000=7?`0000001P0000=7?`0000002P0000=7?`00
0000400000=7?`000000800000=7?`0000002P0000=7?`000000;00000=7?`0000007@0000=7?`00
0000800000=7?`0000004`0000=7?`0000002P0000=7?`0000000`0000=7?`0000002P0000=7?`00
00003P000goo00<007ooOol0PGoo003oOolCOol7000KOol00`00Oomoo`0EOol500000dLo00000004
00000dLo0000000300000dLo0000000:00000dLo0000000700000dLo0000000:00000dLo00000009
00000dLo0000000600000dLo0000000:00000dLo0000000:00000dLo0000000300000dLo00000004
00000dLo0000000300000dLo0000000F00000dLo0000000700000dLo0000000:00000dLo0000000:
00000dLo0000000600000dLo0000000F00000dLo0000000300000dLo0000000:00000dLo0000000:
00000dLo0000000C00000dLo0000000:00000dLo0000000600000dLo0000000:00000dLo0000000:
00000dLo0000000300000dLo0000000P00000dLo0000000:00000dLo0000000C00000dLo0000000F
00000dLo0000000@00000dLo0000000:00000dLo0000000P00000dLo0000000600000dLo0000000:
00000dLo0000000:00000dLo0000000300000dLo0000000:00000dLo0000000C00000dLo0000000:
00000dLo0000000C00000dLo0000000f00000dLo0000000P00000dLo0000000C00000dLo0000000:
00000dLo0000000300000dLo000000020002Ool00`00Oomoo`21Ool00?moo`aoo`L0029oo`03001o
ogoo00eoo`P00003Acl0000000X00003Acl0000000X00003Acl0000000<00003Acl0000000X00003
Acl0000000T00003Acl0000000L00003Acl0000000X00003Acl0000000X00003Acl0000000H00003
Acl0000000X00003Acl0000000T00003Acl0000000<00003Acl0000000@00003Acl0000000<00003
Acl0000000X00003Acl0000000X00003Acl0000001<00003Acl0000000X00003Acl0000000H00003
Acl0000000X00003Acl0000001`00003Acl0000000X00003Acl0000000L00003Acl0000002`00003
Acl0000000X00003Acl0000000<00003Acl0000000X00003Acl0000001<00003Acl0000000X00003
Acl0000000X00003Acl0000000H00003Acl0000003H00003Acl0000002000003Acl0000001<00003
Acl0000000X00003Acl0000000<00003Acl0000000X00003Acl0000001<00003Acl0000000X00003
Acl0000001<00003Acl0000003H00003Acl0000001<00003Acl0000000X00003Acl00000014000=o
o`03001oogoo081oo`00ogoo1Goo1`00:Goo00<007ooOol01Goo200000=7?`0000002P0000=7?`00
00002P0000=7?`0000001P0000=7?`0000002P0000=7?`0000002@0000=7?`0000000`0000=7?`00
00002P0000=7?`0000002P0000=7?`0000001`0000=7?`0000005P0000=7?`0000001P0000=7?`00
00002P0000=7?`0000002P0000=7?`0000000`0000=7?`0000005P0000=7?`0000002P0000=7?`00
00001`0000=7?`0000005P0000=7?`0000001P0000=7?`0000002P0000=7?`0000000`0000=7?`00
0000100000=7?`0000000`0000=7?`000000800000=7?`0000002P0000=7?`0000004`0000=7?`00
00005P0000=7?`0000000`0000=7?`0000002P0000=7?`0000002P0000=7?`0000004`0000=7?`00
00002P0000=7?`0000001P0000=7?`0000002P0000=7?`000000:@0000=7?`0000001`0000=7?`00
00005P0000=7?`0000004`0000=7?`0000002P0000=7?`0000000`0000=7?`0000002P0000=7?`00
00004`0000=7?`0000002P0000=7?`000000;00000=7?`000000400000=7?`0000002P0000=7?`00
00004`0000=7?`0000001@000Woo00<007ooOol0P7oo003mOol7000`Ool00`00Oomoo`0A00000dLo
0000000:00000dLo0000000700000dLo0000000:00000dLo0000000900000dLo0000000600000dLo
0000000:00000dLo0000000:00000dLo0000000300000dLo0000000F00000dLo0000000700000dLo
0000000:00000dLo0000000:00000dLo0000000B00000dLo0000000:00000dLo0000000300000dLo
0000000400000dLo0000000300000dLo0000000F00000dLo0000000700000dLo0000000:00000dLo
0000000600000dLo0000000F00000dLo0000000300000dLo0000000400000dLo0000000300000dLo
0000000:00000dLo0000000C00000dLo0000000:00000dLo0000000:00000dLo0000000600000dLo
0000000F00000dLo0000000@00000dLo0000000:00000dLo0000000C00000dLo0000000:00000dLo
0000000600000dLo0000000:00000dLo0000000@00000dLo0000000F00000dLo0000000700000dLo
0000000F00000dLo0000000C00000dLo0000000:00000dLo0000000300000dLo0000000:00000dLo
0000000C00000dLo0000000i00000dLo0000000@00000dLo0000000:00000dLo000000020002Ool0
0`00Oomoo`1oOol00?Ioo`L00003Ool007oo02mooa@00003Acl0000000X00003Acl0000000<00003
Acl0000000X00003Acl0000000T00003Acl0000000L00003Acl0000000X00003Acl0000000X00003
Acl0000000H00003Acl0000001H00003Acl0000000<00003Acl0000000X00003Acl0000000X00003
Acl0000001<00003Acl0000000X00003Acl0000000H00003Acl0000000X00003Acl0000000T00003
Acl0000000<00003Acl0000000@00003Acl0000000<00003Acl0000000X00003Acl0000001<00003
Acl0000000X00003Acl0000000H00003Acl0000000X00003Acl0000001H00003Acl0000000<00003
Acl0000000X00003Acl0000000X00003Acl0000001<00003Acl0000000X00003Acl0000000H00003
Acl0000000X00003Acl0000001`00003Acl0000000X00003Acl0000002000003Acl0000000H00003
Acl0000000X00003Acl0000001000003Acl0000001H00003Acl0000000L00003Acl0000001H00003
Acl0000001<00003Acl0000000X00003Acl0000000<00003Acl0000002000003Acl0000003T00003
Acl0000000P0009oo`03001oogoo07moo`00kWoo200027oo00<007ooOol09Goo5@0000=7?`000000
2P0000=7?`0000001P0000=7?`0000002P0000=7?`0000002@0000=7?`0000000`0000=7?`000000
2P0000=7?`0000002P0000=7?`0000001`0000=7?`0000002@0000=7?`0000002P0000=7?`000000
1P0000=7?`0000002P0000=7?`000000700000=7?`0000002P0000=7?`0000001`0000=7?`000000
5P0000=7?`0000001P0000=7?`0000002P0000=7?`000000700000=7?`0000002P0000=7?`000000
1`0000=7?`0000005P0000=7?`0000002P0000=7?`0000001P0000=7?`0000002P0000=7?`000000
0`0000=7?`0000005P0000=7?`0000002P0000=7?`0000004`0000=7?`0000002P0000=7?`000000
1P0000=7?`0000002P0000=7?`0000000`0000=7?`0000008`0000=7?`000000800000=7?`000000
1P0000=7?`0000002P0000=7?`000000400000=7?`0000005P0000=7?`000000800000=7?`000000
4`0000=7?`000000400000=7?`000000>@0000=7?`0000004@000goo00<007ooOol0OWoo003WOol7
000@Ool00`00Oomoo`0POol500000dLo0000000F00000dLo0000000700000dLo0000000:00000dLo
0000000900000dLo0000000600000dLo0000000:00000dLo0000000:00000dLo0000000300000dLo
0000000900000dLo0000000:00000dLo0000000700000dLo0000000:00000dLo0000000B00000dLo
0000000:00000dLo0000000:00000dLo0000000300000dLo0000000F00000dLo0000000700000dLo
0000000:00000dLo0000000B00000dLo0000000:00000dLo0000000:00000dLo0000000300000dLo
0000000F00000dLo0000000:00000dLo0000000700000dLo0000000O00000dLo0000000:00000dLo
0000000L00000dLo0000000:00000dLo0000000Y00000dLo0000000:00000dLo0000000Y00000dLo
0000000P00000dLo0000000600000dLo0000000:00000dLo0000000Y00000dLo0000000C00000dLo
0000000:00000dLo0000000600000dLo0000000:00000dLo0000000Y00000dLo0000000K0002Ool0
0`00Oomoo`1nOol00>1oo`L001Moo`03001oogoo01Qoo`P00003Acl0000001H00003Acl0000000<0
0003Acl0000000X00003Acl0000000X00003Acl0000000H00003Acl0000000X00003Acl0000000X0
0003Acl0000000H00003Acl0000000T00003Acl0000000X00003Acl0000000<00003Acl0000000X0
0003Acl0000001<00003Acl0000000X00003Acl0000000X00003Acl0000000H00003Acl0000000T0
0003Acl0000000X00003Acl0000000<00003Acl0000000X00003Acl0000001<00003Acl0000000X0
0003Acl0000001l00003Acl0000000X00003Acl0000000X00003Acl0000000<00003Acl0000001<0
0003Acl0000000X00003Acl0000001H00003Acl0000000H00003Acl0000000X00003Acl0000002H0
0003Acl0000002<00003Acl0000000H00003Acl0000000X00003Acl0000002T00003Acl0000001<0
0003Acl0000000X00003Acl0000000H00003Acl0000002T00003Acl0000000X00003Acl0000001<0
0003Acl0000001<00003Acl0000003H00003Acl000000080009oo`03001oogoo07eoo`00fGoo1`00
7Woo00<007ooOol03goo2@0000=7?`0000005P0000=7?`0000001P0000=7?`0000002P0000=7?`00
00002P0000=7?`0000003`0000=7?`0000002P0000=7?`0000001`0000=7?`0000002@0000=7?`00
00002P0000=7?`0000001P0000=7?`0000002P0000=7?`0000002@0000=7?`0000000`0000=7?`00
00002P0000=7?`0000002P0000=7?`0000004`0000=7?`0000002P0000=7?`0000001P0000=7?`00
00005P0000=7?`0000000`0000=7?`0000002P0000=7?`0000004`0000=7?`0000002P0000=7?`00
00002P0000=7?`0000007`0000=7?`000000400000=7?`0000005P0000=7?`0000001`0000=7?`00
00005P0000=7?`0000001P0000=7?`0000002P0000=7?`000000:@0000=7?`0000004`0000=7?`00
00002P0000=7?`0000001P0000=7?`0000002P0000=7?`000000700000=7?`0000002P0000=7?`00
00004`0000=7?`0000002P0000=7?`0000001P0000=7?`0000005P0000=7?`000000400000=7?`00
00004`0000=7?`0000002P0000=7?`000000;00000=7?`00000020000goo00<007ooOol0O7oo003B
Ool7000bOol500000dLo0000000:00000dLo0000000:00000dLo0000000600000dLo0000000:0000
0dLo0000000:00000dLo0000000B00000dLo0000000:00000dLo0000000300000dLo0000000F0000
0dLo0000000700000dLo0000000:00000dLo0000000900000dLo0000000600000dLo0000000:0000
0dLo0000000:00000dLo0000000?00000dLo0000000:00000dLo0000000700000dLo0000000F0000
0dLo0000000600000dLo0000000:00000dLo0000000L00000dLo0000000:00000dLo0000000C0000
0dLo0000000:00000dLo0000000O00000dLo0000000:00000dLo0000000300000dLo0000000F0000
0dLo0000000700000dLo0000000F00000dLo0000000600000dLo0000000:00000dLo0000000L0000
0dLo0000000:00000dLo0000000C00000dLo0000000:00000dLo0000000600000dLo0000000Y0000
0dLo0000000:00000dLo0000000C00000dLo0000000/00000dLo0000000300000dLo0000000:0000
0dLo0000000C00000dLo0000000Z0003Ool00`00Oomoo`1lOol00<Qoo`03001oogoo00L0035oo`P0
0003Acl0000000X00003Acl0000000X00003Acl0000000l00003Acl0000000X00003Acl0000001<0
0003Acl0000000X00003Acl0000000H00003Acl0000001H00003Acl0000001000003Acl0000000T0
0003Acl0000000L00003Acl0000000X00003Acl0000000X00003Acl0000001800003Acl0000000X0
0003Acl0000001`00003Acl0000000L00003Acl0000001H00003Acl0000000X00003Acl0000000H0
0003Acl0000001H00003Acl0000000<00003Acl0000000X00003Acl0000001<00003Acl0000000X0
0003Acl0000001l00003Acl0000000X00003Acl0000000<00003Acl0000001H00003Acl0000000L0
0003Acl0000001H00003Acl0000000H00003Acl0000000X00003Acl0000001`00003Acl0000000X0
0003Acl0000001<00003Acl0000000X00003Acl0000000H00003Acl0000001H00003Acl000000100
0003Acl0000001<00003Acl0000002`00003Acl0000000X00003Acl0000000<00003Acl0000003@0
00=oo`03001oogoo07]oo`00`goo2000<7oo200000=7?`0000002P0000=7?`0000002P0000=7?`00
00004P0000=7?`0000002P0000=7?`0000003`0000=7?`0000002P0000=7?`0000001`0000=7?`00
00005P0000=7?`0000002P0000=7?`0000001P0000=7?`0000002@0000=7?`000000400000=7?`00
00002P0000=7?`0000004`0000=7?`0000002P0000=7?`0000004P0000=7?`0000002P0000=7?`00
0000700000=7?`0000002P0000=7?`0000001`0000=7?`0000002@0000=7?`0000002P0000=7?`00
00001P0000=7?`0000005P0000=7?`0000000`0000=7?`0000002P0000=7?`0000004`0000=7?`00
00002P0000=7?`0000007`0000=7?`0000002P0000=7?`0000000`0000=7?`0000005P0000=7?`00
00001`0000=7?`0000005P0000=7?`0000001P0000=7?`0000002P0000=7?`000000700000=7?`00
00002P0000=7?`0000004`0000=7?`000000;00000=7?`0000000`0000=7?`000000800000=7?`00
00005P0000=7?`0000004`0000=7?`000000:@0000=7?`0000000P000Woo00<007ooOol0Ngoo002l
Ool70005Ool00`00Oomoo`0[Ool500000dLo0000000900000dLo0000000:00000dLo0000000C0000
0dLo0000000:00000dLo0000000B00000dLo0000000:00000dLo0000000@00000dLo000000090000
0dLo0000000:00000dLo0000000700000dLo0000000900000dLo0000000:00000dLo000000060000
0dLo0000000:00000dLo0000000?00000dLo0000000:00000dLo0000000C00000dLo0000000:0000
0dLo0000000O00000dLo0000000:00000dLo0000000300000dLo0000000900000dLo0000000:0000
0dLo0000000700000dLo0000000900000dLo0000000:00000dLo0000000600000dLo0000000F0000
0dLo0000000300000dLo0000000:00000dLo0000000C00000dLo0000000:00000dLo0000000O0000
0dLo0000000:00000dLo0000000300000dLo0000000F00000dLo0000000C00000dLo0000000:0000
0dLo0000000600000dLo0000000F00000dLo0000000@00000dLo0000000C00000dLo0000000/0000
0dLo0000000@00000dLo0000000F00000dLo0000000C00000dLo0000000:00000dLo000000060000
0dLo0000000F00000dLo000000080003Ool00`00Oomoo`1jOol00;Eoo`L000aoo`03001oogoo02=o
o`P00003Acl0000000T00003Acl0000000X00003Acl0000001000003Acl0000000T00003Acl00000
00X00003Acl0000000H00003Acl0000000X00003Acl0000000X00003Acl0000000H00003Acl00000
00T00003Acl0000000X00003Acl0000000<00003Acl0000001H00003Acl0000000L00003Acl00000
00X00003Acl0000000T00003Acl0000000H00003Acl0000000X00003Acl0000000l00003Acl00000
00X00003Acl0000001<00003Acl0000000X00003Acl0000000X00003Acl0000001800003Acl00000
00X00003Acl0000000<00003Acl0000000T00003Acl0000000X00003Acl0000000L00003Acl00000
00T00003Acl0000000X00003Acl0000000H00003Acl0000001H00003Acl0000000<00003Acl00000
00X00003Acl0000001<00003Acl0000000X00003Acl0000001l00003Acl0000001`00003Acl00000
00X00003Acl0000001<00003Acl0000001<00003Acl0000001H00003Acl0000000<00003Acl00000
02000003Acl0000001H00003Acl0000000H00003Acl0000000X00003Acl0000001`00003Acl00000
00X00003Acl0000001<00003Acl0000001H00003Acl0000000D0009oo`03001oogoo07Yoo`00[Woo
1`004goo00<007ooOol06Woo2@0000=7?`0000002@0000=7?`0000002P0000=7?`0000002P0000=7
?`0000001P0000=7?`0000002@0000=7?`0000002P0000=7?`0000000`0000=7?`0000002@0000=7
?`0000002P0000=7?`0000001`0000=7?`0000002@0000=7?`0000002P0000=7?`0000001P0000=7
?`0000005P0000=7?`0000000`0000=7?`0000002P0000=7?`0000002@0000=7?`0000001`0000=7
?`0000002P0000=7?`0000002@0000=7?`0000001P0000=7?`0000002P0000=7?`0000003`0000=7
?`0000002P0000=7?`0000002P0000=7?`0000004`0000=7?`0000002P0000=7?`0000004P0000=7
?`0000002P0000=7?`0000000`0000=7?`0000002@0000=7?`0000002P0000=7?`0000001`0000=7
?`0000002@0000=7?`0000002P0000=7?`0000001P0000=7?`0000005P0000=7?`0000000`0000=7
?`0000002P0000=7?`0000004`0000=7?`0000005P0000=7?`0000001P0000=7?`0000002P0000=7
?`000000700000=7?`0000004`0000=7?`0000002P0000=7?`0000007`0000=7?`0000002P0000=7
?`0000000`0000=7?`0000005P0000=7?`0000004`0000=7?`0000004`0000=7?`0000005P0000=7
?`000000400000=7?`0000005P0000=7?`0000003P000goo00<007ooOol0NGoo002WOol7000JOol0
0`00Oomoo`0EOolB00000dLo0000000F00000dLo0000000700000dLo0000000900000dLo0000000:
00000dLo0000000600000dLo0000000900000dLo0000000:00000dLo0000000300000dLo0000000:
00000dLo0000000900000dLo0000000700000dLo0000000F00000dLo0000000600000dLo0000000:
00000dLo0000000900000dLo0000000300000dLo0000000:00000dLo0000000900000dLo00000007
00000dLo0000000:00000dLo0000000B00000dLo0000000:00000dLo0000000L00000dLo0000000:
00000dLo0000000C00000dLo0000000:00000dLo0000000B00000dLo0000000:00000dLo00000003
00000dLo0000000900000dLo0000000:00000dLo0000000C00000dLo0000000:00000dLo00000006
00000dLo0000000F00000dLo0000000300000dLo0000000F00000dLo0000000700000dLo0000000F
00000dLo0000000600000dLo0000000F00000dLo0000000300000dLo0000000:00000dLo0000000C
00000dLo0000000F00000dLo0000000C00000dLo0000000L00000dLo0000000C00000dLo0000000:
00000dLo0000000O00000dLo0000000Y00000dLo000000020002Ool00`00Oomoo`1iOol00:1oo`L0
035oo``00003Acl0000000H00003Acl0000001H00003Acl0000000<00003Acl0000000X00003Acl0
000000T00003Acl0000000L00003Acl0000000T00003Acl0000000X00003Acl0000000H00003Acl0
000000X00003Acl0000000T00003Acl0000000<00003Acl0000000X00003Acl0000000T00003Acl0
000000L00003Acl0000000X00003Acl0000000T00003Acl0000000H00003Acl0000000X00003Acl0
000000T00003Acl0000000<00003Acl0000000X00003Acl0000001<00003Acl0000000X00003Acl0
000001800003Acl0000000X00003Acl0000001`00003Acl0000000X00003Acl0000001<00003Acl0
000001l00003Acl0000000X00003Acl0000000l00003Acl0000000X00003Acl0000001<00003Acl0
000000X00003Acl0000001800003Acl0000000X00003Acl0000000<00003Acl0000001H00003Acl0
000001<00003Acl0000000X00003Acl0000000H00003Acl0000001H00003Acl0000000<00003Acl0
000001H00003Acl0000002000003Acl0000000H00003Acl0000001H00003Acl0000000<00003Acl0
000000X00003Acl0000001<00003Acl0000001H00003Acl0000002X000=oo`03001oogoo07Qoo`00
VGoo1`00<7oo300000=7?`0000001P0000=7?`0000005P0000=7?`0000001P0000=7?`0000002P00
00=7?`0000002@0000=7?`0000000`0000=7?`0000002P0000=7?`0000004`0000=7?`0000002P00
00=7?`0000002@0000=7?`0000001P0000=7?`0000002P0000=7?`0000002@0000=7?`0000004000
00=7?`0000004`0000=7?`0000002P0000=7?`0000002@0000=7?`0000001P0000=7?`0000002P00
00=7?`000000700000=7?`0000004`0000=7?`0000002P0000=7?`0000005P0000=7?`0000001P00
00=7?`000000700000=7?`0000004`0000=7?`0000002P0000=7?`0000005P0000=7?`0000001P00
00=7?`000000700000=7?`0000002P0000=7?`0000004`0000=7?`0000007`0000=7?`0000007000
00=7?`0000002P0000=7?`0000004`0000=7?`0000007`0000=7?`000000:@0000=7?`0000004`00
00=7?`0000007`0000=7?`000000?`0000=7?`0000005P0000=7?`0000001@000Woo00<007ooOol0
N7oo002AOol8000bOol<00000dLo0000000?00000dLo0000000:00000dLo0000000600000dLo0000
000:00000dLo0000000900000dLo0000000600000dLo0000000:00000dLo0000000L00000dLo0000
000:00000dLo0000000600000dLo0000000:00000dLo0000000900000dLo0000000:00000dLo0000
000600000dLo0000000L00000dLo0000000C00000dLo0000000:00000dLo0000000F00000dLo0000
000600000dLo0000000L00000dLo0000000F00000dLo0000000700000dLo0000000F00000dLo0000
000600000dLo0000000L00000dLo0000000F00000dLo0000000700000dLo0000000900000dLo0000
000:00000dLo0000000600000dLo0000000L00000dLo0000000C00000dLo0000000F00000dLo0000
000:00000dLo0000000600000dLo0000000L00000dLo0000000C00000dLo0000000F00000dLo0000
000:00000dLo0000000600000dLo0000000L00000dLo0000000C00000dLo0000000F00000dLo0000
000C00000dLo0000000F00000dLo0000000300000dLo0000000F00000dLo0000000>0003Ool00`00
Oomoo`1gOol008Yoo`L000=oo`03001oogoo02aoo``00003Acl0000000T00003Acl0000000H00003
Acl0000000X00003Acl0000000l00003Acl0000000X00003Acl0000000H00003Acl0000000X00003
Acl0000001H00003Acl0000000H00003Acl0000000X00003Acl0000000l00003Acl0000000X00003
Acl0000000T00003Acl0000000L00003Acl0000001H00003Acl0000000H00003Acl0000001`00003
Acl0000001H00003Acl0000000L00003Acl0000001H00003Acl0000000H00003Acl0000001H00003
Acl0000000<00003Acl0000001H00003Acl0000000L00003Acl0000000T00003Acl0000000X00003
Acl0000000H00003Acl0000000T00003Acl0000000X00003Acl0000000<00003Acl0000000T00003
Acl0000000X00003Acl0000001<00003Acl0000000X00003Acl0000001800003Acl0000001`00003
Acl0000000X00003Acl0000001<00003Acl0000001l00003Acl0000001`00003Acl0000000X00003
Acl0000001<00003Acl0000001l00003Acl0000001`00003Acl0000001<00003Acl0000002`00003
Acl0000001H00003Acl0000000<00003Acl000000080009oo`03001oogoo07Moo`00Pgoo1`002Woo
00<007ooOol097oo2`0000=7?`0000002P0000=7?`0000001P0000=7?`0000002P0000=7?`000000
2@0000=7?`0000001P0000=7?`0000002P0000=7?`0000003`0000=7?`0000002P0000=7?`000000
2P0000=7?`0000001P0000=7?`0000002P0000=7?`0000002@0000=7?`0000001P0000=7?`000000
2P0000=7?`0000002@0000=7?`0000000`0000=7?`0000002P0000=7?`0000002@0000=7?`000000
1`0000=7?`0000005P0000=7?`0000001P0000=7?`0000005P0000=7?`0000000`0000=7?`000000
5P0000=7?`0000001`0000=7?`0000002@0000=7?`0000002P0000=7?`0000001P0000=7?`000000
2@0000=7?`0000002P0000=7?`0000003`0000=7?`0000002P0000=7?`0000004`0000=7?`000000
2P0000=7?`0000004P0000=7?`0000002P0000=7?`0000003`0000=7?`0000002P0000=7?`000000
4`0000=7?`0000007`0000=7?`000000700000=7?`0000004`0000=7?`0000005P0000=7?`000000
1P0000=7?`0000002P0000=7?`000000700000=7?`0000004`0000=7?`0000005P0000=7?`000000
1P0000=7?`0000005P0000=7?`0000000`0000=7?`000000;00000=7?`000000:P000goo00<007oo
Ool0MWoo001lOol7000@Ool00`00Oomoo`0POol;00000dLo0000000:00000dLo0000000300000dLo
0000000900000dLo0000000:00000dLo0000000600000dLo0000000:00000dLo0000000B00000dLo
0000000:00000dLo0000000:00000dLo0000000?00000dLo0000000:00000dLo0000000600000dLo
0000000:00000dLo0000000900000dLo0000000600000dLo0000000:00000dLo0000000900000dLo
0000000@00000dLo0000000900000dLo0000000700000dLo0000000F00000dLo0000000600000dLo
0000000F00000dLo0000000?00000dLo0000000:00000dLo0000000700000dLo0000000900000dLo
0000000:00000dLo0000000900000dLo0000000600000dLo0000000:00000dLo0000000?00000dLo
0000000:00000dLo0000000C00000dLo0000000O00000dLo0000000L00000dLo0000000C00000dLo
0000000F00000dLo0000000600000dLo0000000F00000dLo0000000L00000dLo0000000700000dLo
0000000F00000dLo0000000600000dLo0000000F00000dLo0000000300000dLo0000000F00000dLo
0000000C00000dLo0000000O00000dLo0000000L00000dLo0000000/00000dLo000000050002Ool0
0`00Oomoo`1fOol007Eoo`L001Moo`03001oogoo01Qoo`/00003Acl0000000X00003Acl0000000H0
0003Acl0000000T00003Acl0000000X00003Acl0000001000003Acl0000000T00003Acl0000000H0
0003Acl0000000X00003Acl0000000X00003Acl0000000T00003Acl0000000H00003Acl0000000X0
0003Acl0000000l00003Acl0000000X00003Acl0000000H00003Acl0000000X00003Acl0000000T0
0003Acl0000000X00003Acl0000000H00003Acl0000000T00003Acl0000001000003Acl0000000T0
0003Acl0000000L00003Acl0000001H00003Acl0000001800003Acl0000000X00003Acl0000000l0
0003Acl0000000X00003Acl0000000T00003Acl0000000L00003Acl0000001H00003Acl0000000H0
0003Acl0000001`00003Acl0000001<00003Acl0000000X00003Acl0000000T00003Acl0000000X0
0003Acl0000001800003Acl0000001`00003Acl0000000L00003Acl0000000T00003Acl0000000X0
0003Acl0000001800003Acl0000000X00003Acl0000001`00003Acl0000001<00003Acl0000001l0
0003Acl0000001`00003Acl0000001<00003Acl0000001H00003Acl0000001l00003Acl0000001`0
0003Acl0000000h000=oo`03001oogoo07Eoo`00KWoo1`00;Woo3P0000=7?`0000002P0000=7?`00
00001P0000=7?`0000002@0000=7?`0000002P0000=7?`0000002P0000=7?`0000001P0000=7?`00
00002@0000=7?`000000400000=7?`0000002@0000=7?`0000002P0000=7?`0000001P0000=7?`00
00002P0000=7?`0000002@0000=7?`0000001P0000=7?`0000002P0000=7?`0000003`0000=7?`00
00002P0000=7?`0000002@0000=7?`0000001`0000=7?`0000002@0000=7?`0000002P0000=7?`00
00001P0000=7?`0000002@0000=7?`000000700000=7?`0000002P0000=7?`0000001P0000=7?`00
00002P0000=7?`0000004P0000=7?`0000002P0000=7?`0000002@0000=7?`0000000`0000=7?`00
00005P0000=7?`0000001`0000=7?`0000005P0000=7?`0000001P0000=7?`0000002@0000=7?`00
0000400000=7?`0000002@0000=7?`0000002P0000=7?`0000004`0000=7?`0000007`0000=7?`00
00003`0000=7?`0000002P0000=7?`0000004`0000=7?`0000005P0000=7?`0000001P0000=7?`00
0000700000=7?`0000004`0000=7?`0000005P0000=7?`0000007`0000=7?`000000700000=7?`00
00004`0000=7?`0000005P0000=7?`0000001P0000=7?`0000005P0000=7?`00000020000Woo00<0
07ooOol0MGoo001ZOol4000]Ool800000dLo0000000600000dLo0000000:00000dLo0000000?0000
0dLo0000000:00000dLo0000000900000dLo0000000700000dLo0000000900000dLo0000000:0000
0dLo0000000600000dLo0000000900000dLo0000000:00000dLo0000000300000dLo000000090000
0dLo0000000:00000dLo0000000600000dLo0000000:00000dLo0000000900000dLo000000060000
0dLo0000000:00000dLo0000000900000dLo0000000L00000dLo0000000700000dLo000000090000
0dLo0000000:00000dLo0000000B00000dLo0000000:00000dLo0000000?00000dLo0000000C0000
0dLo0000000:00000dLo0000000900000dLo0000000600000dLo0000000F00000dLo0000000L0000
0dLo0000000C00000dLo0000000:00000dLo0000000B00000dLo0000000L00000dLo0000000C0000
0dLo0000000F00000dLo0000000600000dLo0000000F00000dLo0000000300000dLo0000000F0000
0dLo0000000C00000dLo0000000O00000dLo0000000L00000dLo0000000C00000dLo0000000F0000
0dLo0000000600000dLo0000000F00000dLo0000000300000dLo0000000F00000dLo0000000C0000
0dLo0000000F00000dLo000000040003Ool00`00Oomoo`1dOol006Yoo`03001oo`0002Uoo`D00003
Acl0000000H00003Acl0000000X00003Acl0000000T00003Acl0000000H00003Acl0000000X00003
Acl0000000T00003Acl0000001000003Acl0000000T00003Acl0000000L00003Acl0000000T00003
Acl0000000X00003Acl0000000H00003Acl0000000T00003Acl0000000X00003Acl0000000l00003
Acl0000000X00003Acl0000000H00003Acl0000000X00003Acl0000000T00003Acl0000000X00003
Acl0000001800003Acl0000001`00003Acl0000001<00003Acl0000000X00003Acl0000000T00003
Acl0000000H00003Acl0000001`00003Acl0000000T00003Acl0000000L00003Acl0000001H00003
Acl0000001800003Acl0000000X00003Acl0000000l00003Acl0000000X00003Acl0000001<00003
Acl0000001H00003Acl0000000H00003Acl0000000T00003Acl0000001`00003Acl0000000L00003
Acl0000000T00003Acl0000000X00003Acl0000001800003Acl0000001`00003Acl0000001<00003
Acl0000001H00003Acl0000000H00003Acl0000001H00003Acl0000000<00003Acl0000001H00003
Acl0000001<00003Acl0000001l00003Acl0000001`00003Acl0000001H00003Acl0000000h0009o
o`03001oogoo07Aoo`00JWoo00@007ooOol0021oo`P00003Acl0000001000003Acl0000000T00003
Acl0000000H00003Acl0000000X00003Acl0000000T00003Acl0000000X00003Acl0000000H00003
Acl0000000T00003Acl0000001000003Acl0000000T00003Acl0000000L00003Acl0000000T00003
Acl0000000X00003Acl0000000T00003Acl0000000H00003Acl0000000X00003Acl0000000l00003
Acl0000000X00003Acl0000000T00003Acl0000001<00003Acl0000000X00003Acl0000001800003
Acl0000000l00003Acl0000000X00003Acl0000000T00003Acl0000000L00003Acl0000001H00003
Acl0000000H00003Acl0000000T00003Acl0000001`00003Acl0000001<00003Acl0000000X00003
Acl0000000T00003Acl0000000H00003Acl0000001`00003Acl0000001H00003Acl0000001<00003
Acl0000001l00003Acl0000000l00003Acl0000000X00003Acl0000001<00003Acl0000000T00003
Acl0000000H00003Acl0000001H00003Acl0000001`00003Acl0000001<00003Acl0000001l00003
Acl0000001`00003Acl0000001<00003Acl0000001H00003Acl00000048000=oo`03001oogoo07=o
o`00JWoo00@007ooOomoo`8001Ioo`P00003Acl0000000X00003Acl0000000H00003Acl0000000T0
0003Acl0000001000003Acl0000000T00003Acl0000000X00003Acl0000000H00003Acl0000000T0
0003Acl0000000X00003Acl0000000H00003Acl0000000T00003Acl0000001`00003Acl0000000X0
0003Acl0000000H00003Acl0000000X00003Acl0000000T00003Acl0000000H00003Acl0000000X0
0003Acl0000000T00003Acl0000001`00003Acl0000001<00003Acl0000001800003Acl0000000X0
0003Acl0000000T00003Acl0000001`00003Acl0000000L00003Acl0000000T00003Acl0000000X0
0003Acl0000001800003Acl0000001`00003Acl0000000T00003Acl0000000L00003Acl0000001H0
0003Acl0000000H00003Acl0000000T00003Acl0000000X00003Acl0000000l00003Acl0000001<0
0003Acl0000001H00003Acl0000000H00003Acl0000001`00003Acl0000000T00003Acl0000000L0
0003Acl0000001H00003Acl0000000T00003Acl0000000H00003Acl0000001`00003Acl0000001<0
0003Acl0000001H00003Acl0000001l00003Acl0000001`00003Acl0000001l00003Acl0000001H0
0003Acl0000000H00003Acl0000000P0009oo`03001oogoo07=oo`00JWoo00<007ooOol00goo00<0
07ooOol03Woo1@0000=7?`0000002P0000=7?`0000001P0000=7?`0000002@0000=7?`0000002P00
00=7?`0000001P0000=7?`0000002@0000=7?`0000002P0000=7?`0000003`0000=7?`0000002P00
00=7?`0000001P0000=7?`0000002@0000=7?`0000002P0000=7?`0000002@0000=7?`0000001P00
00=7?`0000002P0000=7?`0000003`0000=7?`0000002P0000=7?`0000001P0000=7?`0000002P00
00=7?`0000002@0000=7?`0000002P0000=7?`0000004P0000=7?`0000003`0000=7?`0000002P00
00=7?`0000001P0000=7?`0000002P0000=7?`0000002@0000=7?`0000002P0000=7?`0000004P00
00=7?`0000003`0000=7?`0000002P0000=7?`0000004`0000=7?`0000005P0000=7?`0000001P00
00=7?`0000002@0000=7?`000000700000=7?`0000004`0000=7?`0000005P0000=7?`0000001P00
00=7?`0000002@0000=7?`000000700000=7?`0000001`0000=7?`0000002@0000=7?`0000007`00
00=7?`000000700000=7?`0000002@0000=7?`0000001`0000=7?`0000005P0000=7?`0000004P00
00=7?`000000700000=7?`0000004`0000=7?`0000005P0000=7?`0000001P0000=7?`000000:000
00=7?`0000005P0000=7?`0000004`0000=7?`0000001@000Woo00<007ooOol0LWoo001?Ool4000G
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool800000dLo0000000:00000dLo0000000?00000dLo0000
000:00000dLo0000000600000dLo0000000900000dLo0000000:00000dLo0000000900000dLo0000
000600000dLo0000000:00000dLo0000000?00000dLo0000000:00000dLo0000000900000dLo0000
000600000dLo0000000:00000dLo0000000900000dLo0000000600000dLo0000000:00000dLo0000
000?00000dLo0000000:00000dLo0000000900000dLo0000000C00000dLo0000000B00000dLo0000
000:00000dLo0000000X00000dLo0000000C00000dLo0000000B00000dLo0000000:00000dLo0000
000X00000dLo0000000700000dLo0000000900000dLo0000000O00000dLo0000000?00000dLo0000
000F00000dLo0000000700000dLo0000000900000dLo0000000O00000dLo0000000?00000dLo0000
000C00000dLo0000000:00000dLo0000000900000dLo0000000O00000dLo0000000L00000dLo0000
000O00000dLo0000000600000dLo0000000F00000dLo0000000L00000dLo0000000O00000dLo0000
000O00000dLo0000000L00000dLo0000000>0002Ool00`00Oomoo`1bOol004eoo`P001Eoo`03001o
ogoo00Aoo`P00003Acl0000000X00003Acl0000000T00003Acl0000000H00003Acl0000000X00003
Acl0000001`00003Acl0000000T00003Acl0000000H00003Acl0000000X00003Acl0000000T00003
Acl0000000H00003Acl0000000X00003Acl0000000T00003Acl0000001`00003Acl0000000H00003
Acl0000000X00003Acl0000000T00003Acl0000000H00003Acl0000000X00003Acl0000000T00003
Acl0000000l00003Acl0000000X00003Acl0000000H00003Acl0000000X00003Acl0000000T00003
Acl0000000X00003Acl0000001800003Acl0000000l00003Acl0000000X00003Acl0000000H00003
Acl0000000X00003Acl0000000T00003Acl0000000X00003Acl0000001800003Acl0000000l00003
Acl0000001<00003Acl0000000X00003Acl0000000T00003Acl0000000H00003Acl0000001H00003
Acl0000000l00003Acl0000001<00003Acl0000000X00003Acl0000000T00003Acl0000000H00003
Acl0000001`00003Acl0000000T00003Acl0000001<00003Acl0000001H00003Acl0000000H00003
Acl0000002P00003Acl0000001<00003Acl0000001H00003Acl0000000H00003Acl0000002P00003
Acl0000001<00003Acl0000001H00003Acl0000002T000=oo`03001oogoo075oo`00CGoo0P0017oo
0P005Goo00<007oo00004@0000=7?`0000002@0000=7?`0000001P0000=7?`0000002P0000=7?`00
00002@0000=7?`0000002P0000=7?`0000001P0000=7?`0000002@0000=7?`000000400000=7?`00
00002@0000=7?`0000001P0000=7?`0000002P0000=7?`0000002@0000=7?`0000002P0000=7?`00
00004P0000=7?`0000003`0000=7?`0000002P0000=7?`0000001P0000=7?`0000002P0000=7?`00
00002@0000=7?`0000004P0000=7?`0000002P0000=7?`0000003`0000=7?`0000002P0000=7?`00
00002@0000=7?`0000004`0000=7?`0000004P0000=7?`0000002P0000=7?`000000:00000=7?`00
00004`0000=7?`0000004P0000=7?`000000700000=7?`0000002@0000=7?`0000001`0000=7?`00
00005P0000=7?`0000002@0000=7?`0000001P0000=7?`000000700000=7?`0000002@0000=7?`00
00001`0000=7?`0000002@0000=7?`0000007`0000=7?`000000:00000=7?`0000004`0000=7?`00
00007`0000=7?`0000003`0000=7?`0000005P0000=7?`0000004`0000=7?`000000:`0000=7?`00
0000700000=7?`0000007`0000=7?`0000004@000Woo00<007ooOol0LGoo001<Ool20006Ool2000C
Ool700000dLo0000000600000dLo0000000900000dLo0000000L00000dLo0000000:00000dLo0000
000600000dLo0000000900000dLo0000000:00000dLo0000000600000dLo0000000900000dLo0000
000L00000dLo0000000900000dLo0000000C00000dLo0000000B00000dLo0000000:00000dLo0000
000L00000dLo0000000900000dLo0000000600000dLo0000000:00000dLo0000000900000dLo0000
000600000dLo0000000:00000dLo0000000900000dLo0000000?00000dLo0000000:00000dLo0000
000600000dLo0000000:00000dLo0000000900000dLo0000000:00000dLo0000000B00000dLo0000
000?00000dLo0000000C00000dLo0000000F00000dLo0000000600000dLo0000000900000dLo0000
000L00000dLo0000000900000dLo0000000700000dLo0000000F00000dLo0000000B00000dLo0000
000?00000dLo0000000C00000dLo0000000F00000dLo0000000O00000dLo0000000?00000dLo0000
000C00000dLo0000000F00000dLo0000000B00000dLo0000000L00000dLo0000000C00000dLo0000
000900000dLo0000000F00000dLo0000000600000dLo0000000X00000dLo0000000F00000dMO0000
00020002Ool00`00Oomoo`1`Ool004aoo`8000Ioo`8001=oo`03001oo`0000D00003Acl0000000T0
0003Acl0000000X00003Acl0000000T00003Acl0000000H00003Acl0000000X00003Acl0000000l0
0003Acl0000000X00003Acl0000000H00003Acl0000000T00003Acl0000000X00003Acl0000000T0
0003Acl0000000H00003Acl0000000T00003Acl0000001000003Acl0000000T00003Acl0000000H0
0003Acl0000000X00003Acl0000000T00003Acl0000000X00003Acl0000000H00003Acl0000000T0
0003Acl0000000l00003Acl0000000X00003Acl0000000H00003Acl0000000X00003Acl0000000T0
0003Acl0000001800003Acl0000000X00003Acl0000000l00003Acl0000001H00003Acl0000001<0
0003Acl0000000T00003Acl0000000H00003Acl0000002P00003Acl0000000L00003Acl0000000T0
0003Acl0000001H00003Acl0000000H00003Acl0000000T00003Acl0000001`00003Acl0000001<0
0003Acl0000000T00003Acl0000000H00003Acl0000002P00003Acl0000001<00003Acl0000001H0
0003Acl0000000H00003Acl0000000T00003Acl0000001`00003Acl0000001<00003Acl0000000T0
0003Acl0000001l00003Acl0000000l00003Acl0000001H00003Acl0000001<00003Acl000000180
0003Acl0000001H00003Acl0000001@000=oo`03001oogoo06moo`00Bgoo0P0027oo0P004Woo00<0
07ooOol05P0000=7?`0000002@0000=7?`0000001P0000=7?`0000002P0000=7?`0000002@0000=7
?`0000001P0000=7?`0000002P0000=7?`0000006`0000=7?`0000002P0000=7?`0000001P0000=7
?`0000002@0000=7?`0000002P0000=7?`0000001P0000=7?`0000002@0000=7?`000000700000=7
?`0000002@0000=7?`0000001`0000=7?`0000002@0000=7?`0000004P0000=7?`0000002P0000=7
?`000000:00000=7?`0000001P0000=7?`0000002P0000=7?`0000002@0000=7?`0000001P0000=7
?`0000005P0000=7?`0000003`0000=7?`0000004`0000=7?`0000005P0000=7?`0000004P0000=7
?`000000:00000=7?`0000001`0000=7?`0000002@0000=7?`0000004P0000=7?`000000:00000=7
?`0000001`0000=7?`0000002@0000=7?`0000005P0000=7?`0000001P0000=7?`0000002@0000=7
?`000000700000=7?`0000004`0000=7?`0000002@0000=7?`0000001P0000=7?`000000700000=7
?`0000002@0000=7?`0000004`0000=7?`0000005P0000=7?`0000004P0000=7?`000000700000=7
?`0000007`0000=7?`0000005P0000=7G`0000002@0000=7G`0000001@000Woo00<007ooOol0Kgoo
001;Ool20008Ool2000BOol01000Oomoogoo1`0000=7?`0000001P0000=7?`0000002@0000=7?`00
0000400000=7?`0000002@0000=7?`0000001P0000=7?`0000002P0000=7?`0000002@0000=7?`00
00004P0000=7?`0000002P0000=7?`0000003`0000=7?`0000002P0000=7?`0000001P0000=7?`00
00002@0000=7?`0000002P0000=7?`0000002@0000=7?`0000001P0000=7?`0000002@0000=7?`00
0000400000=7?`0000002@0000=7?`0000001P0000=7?`0000002P0000=7?`0000002@0000=7?`00
00002P0000=7?`0000004P0000=7?`0000009@0000=7?`0000005P0000=7?`0000002@0000=7?`00
00001P0000=7?`000000:00000=7?`0000004`0000=7?`0000005P0000=7?`0000004P0000=7?`00
00003`0000=7?`0000004`0000=7?`0000005P0000=7?`0000004P0000=7?`000000:00000=7?`00
00004`0000=7?`0000004P0000=7?`000000700000=7?`0000002@0000=7?`0000001`0000=7?`00
00002@0000=7?`0000007`0000=7?`0000002@0000=7?`000000700000=7?`0000007`0000=7?`00
0000BP0000=7?`0000002@0000=7G`0000003P000goo00<007ooOol0KWoo001;Ool20008Ool2000B
Ool00`00Oomoo`04Ool500000dLo0000000900000dLo0000000:00000dLo0000000600000dLo0000
000900000dLo0000000L00000dLo0000000:00000dLo0000000500000dLo0000000:00000dLo0000
000900000dLo0000000600000dLo0000000:00000dLo0000000X00000dLo0000000600000dLo0000
000900000dLo0000000:00000dLo0000000600000dLo0000000900000dLo0000000L00000dLo0000
000900000dLo0000000C00000dLo0000000900000dLo0000000:00000dLo0000000T00000dLo0000
000C00000dLo0000000F00000dLo0000000900000dLo0000000600000dLo0000000X00000dLo0000
000C00000dLo0000000B00000dLo0000000X00000dLo0000000C00000dLo0000000F00000dLo0000
000B00000dLo0000000?00000dLo0000000C00000dLo0000000F00000dLo0000000B00000dLo0000
000?00000dLo0000000C00000dLo0000000F00000dLo0000000900000dLo0000000600000dLo0000
000X00000dLo0000000C00000dLo0000000R00000dLo0000000600000dLo0000000R00000dMO0000
00080002Ool00`00Oomoo`1^Ool004]oo`8000Qoo`80019oo`03001oogoo00Eoo`T00003Acl00000
00T00003Acl0000000H00003Acl0000000T00003Acl0000000X00003Acl0000000T00003Acl00000
00H00003Acl0000000X00003Acl0000000l00003Acl0000000T00003Acl0000000H00003Acl00000
00X00003Acl0000000T00003Acl0000000X00003Acl0000001800003Acl0000001`00003Acl00000
00H00003Acl0000000T00003Acl0000001H00003Acl0000000H00003Acl0000000T00003Acl00000
01`00003Acl0000000T00003Acl0000001<00003Acl0000000T00003Acl0000000H00003Acl00000
02P00003Acl0000001<00003Acl0000001H00003Acl0000001800003Acl0000000l00003Acl00000
01<00003Acl0000001H00003Acl0000000T00003Acl0000000H00003Acl0000000T00003Acl00000
01`00003Acl0000001<00003Acl0000000T00003Acl0000000H00003Acl0000000T00003Acl00000
01`00003Acl0000001<00003Acl0000000T00003Acl0000000H00003Acl0000002P00003Acl00000
00T00003Acl0000001<00003Acl0000002/00003Acl0000002P00003Acl0000001l00003Acl00000
01H00003Ael0000000@000=oo`03001oogoo06eoo`00Bgoo0P0027oo0P004Woo00<007ooOol01Woo
0`0000=7?`0000002@0000=7?`000000700000=7?`0000002@0000=7?`0000001P0000=7?`000000
2P0000=7?`0000002@0000=7?`0000001P0000=7?`0000002@0000=7?`000000700000=7?`000000
2@0000=7?`0000004`0000=7?`0000002@0000=7?`0000002P0000=7?`0000001P0000=7?`000000
6`0000=7?`0000002P0000=7?`0000001P0000=7?`0000002@0000=7?`0000002P0000=7?`000000
2@0000=7?`0000001P0000=7?`0000002@0000=7?`000000700000=7?`0000001P0000=7?`000000
5P0000=7?`0000002@0000=7?`0000001P0000=7?`000000700000=7?`0000002@0000=7?`000000
4`0000=7?`0000002@0000=7?`0000001P0000=7?`000000:00000=7?`0000002@0000=7?`000000
1`0000=7?`0000002@0000=7?`0000004P0000=7?`000000700000=7?`0000002@0000=7?`000000
1`0000=7?`0000002@0000=7?`0000004P0000=7?`000000:00000=7?`0000004`0000=7?`000000
:`0000=7?`0000003`0000=7?`0000004`0000=7?`0000008P0000=7?`0000001P0000=7?`000000
2@0000=7?`000000:00000=7?`0000005P0000=7G`0000003P000Woo00<007ooOol0KGoo001;Ool2
0008Ool2000BOol00`00Oomoo`07Ool600000dLo0000000900000dLo0000000:00000dLo00000006
00000dLo0000000900000dLo0000000@00000dLo0000000900000dLo0000000600000dLo00000009
00000dLo0000000:00000dLo0000000900000dLo0000000600000dLo0000000900000dLo0000000L
00000dLo0000000C00000dLo0000000900000dLo0000000900000dLo0000000600000dLo0000000:
00000dLo0000000K00000dLo0000000:00000dLo0000000600000dLo0000000900000dLo0000000:
00000dLo0000000B00000dLo0000000K00000dLo0000000:00000dLo0000000600000dLo0000000F
00000dLo0000000600000dLo0000000900000dLo0000000U00000dLo0000000F00000dLo00000009
00000dLo0000000600000dLo0000000900000dLo0000000?00000dLo0000000C00000dLo0000000F
00000dLo0000000B00000dLo0000000U00000dLo0000000F00000dLo0000000900000dLo00000006
00000dLo0000000a00000dLo0000000F00000dLo0000000600000dLo0000000900000dLo0000000X
00000dLo0000000O00000dLo0000000[00000dLo0000000P0003Ool00`00Oomoo`1/Ool004]oo`80
00Qoo`80019oo`03001oogoo00Uoo`T00003Acl0000000T00003Acl0000000H00003Acl0000000T0
0003Acl0000000X00003Acl0000000H00003Acl0000000T00003Acl0000001`00003Acl0000000T0
0003Acl0000000H00003Acl0000000T00003Acl0000000X00003Acl0000000T00003Acl0000000H0
0003Acl0000001`00003Acl0000000T00003Acl0000000H00003Acl0000000X00003Acl0000000T0
0003Acl0000000T00003Acl0000000H00003Acl0000000X00003Acl0000000l00003Acl0000000T0
0003Acl0000001<00003Acl0000000T00003Acl0000001800003Acl0000000X00003Acl0000000l0
0003Acl0000000T00003Acl0000000L00003Acl0000000T00003Acl0000000T00003Acl0000000X0
0003Acl0000002@00003Acl0000000T00003Acl0000000L00003Acl0000000T00003Acl000000180
0003Acl0000002P00003Acl0000001<00003Acl0000000T00003Acl0000003400003Acl0000000T0
0003Acl0000001<00003Acl0000001800003Acl0000002P00003Acl0000001<00003Acl0000000T0
0003Acl0000000H00003Acl0000003@00003Acl0000001<00003Acl0000000T00003Acl0000001H0
0003Acl0000000T00003Ael0000000H00003Ael0000000P0009oo`03001oogoo06aoo`00Bgoo0P00
27oo0P004Woo00<007ooOol02Woo0`0000=7?`0000002@0000=7?`000000700000=7?`0000001P00
00=7?`0000002@0000=7?`0000002@0000=7?`0000002P0000=7?`0000001P0000=7?`0000002@00
00=7?`000000700000=7?`0000002@0000=7?`0000001P0000=7?`0000005P0000=7?`0000001P00
00=7?`0000002@0000=7?`000000700000=7?`0000002@0000=7?`0000001P0000=7?`0000002P00
00=7?`0000002@0000=7?`0000001P0000=7?`0000002@0000=7?`000000700000=7?`0000002@00
00=7?`0000001P0000=7?`0000002P0000=7?`0000002@0000=7?`0000001P0000=7?`0000002@00
00=7?`000000:00000=7?`0000004`0000=7?`0000002@0000=7?`0000001P0000=7?`0000002@00
00=7?`0000009@0000=7?`0000005P0000=7?`0000002@0000=7?`0000001P0000=7?`0000006`00
00=7?`0000004`0000=7?`0000005P0000=7?`0000004P0000=7?`0000003`0000=7?`0000004`00
00=7?`0000002@0000=7?`000000<@0000=7?`0000002@0000=7?`0000004`0000=7?`0000002@00
00=7?`000000:`0000=7?`000000:00000=7?`0000002@0000=7G`0000004`0000=7G`0000001000
0goo00<007ooOol0Jgoo001<Ool20006Ool2000COol00`00Oomoo`0;Ool600000dLo0000000:0000
0dLo0000000900000dLo0000000600000dLo0000000L00000dLo0000000900000dLo000000060000
0dLo0000000900000dLo0000000F00000dLo0000000600000dLo0000000900000dLo0000000L0000
0dLo0000000600000dLo0000000900000dLo0000000F00000dLo0000000600000dLo000000090000
0dLo0000000L00000dLo0000000600000dLo0000000900000dLo0000000F00000dLo000000060000
0dLo0000000900000dLo0000000U00000dLo0000000900000dLo0000000F00000dLo0000000B0000
0dLo0000000?00000dLo0000000900000dLo0000000700000dLo0000000900000dLo0000000F0000
0dLo0000000T00000dLo0000000900000dLo0000000700000dLo0000000900000dLo0000000B0000
0dLo0000000X00000dLo0000000C00000dLo0000000900000dLo0000000600000dLo000000090000
0dLo0000000?00000dLo0000000C00000dLo0000000[00000dLo0000000K00000dLo0000000C0000
0dLo0000000R00000dLo0000000B00000dLo0000000X00000dMO0000000900000dMO000000020002
Ool00`00Oomoo`1[Ool004aoo`8000Ioo`8001=oo`03001oogoo00eoo`T00003Acl0000000T00003
Acl0000000H00003Acl0000000T00003Acl0000000X00003Acl0000000H00003Acl0000000T00003
Acl0000001`00003Acl0000000T00003Acl0000000H00003Acl0000000T00003Acl0000000X00003
Acl0000000T00003Acl0000000H00003Acl0000001/00003Acl0000000X00003Acl0000000H00003
Acl0000000T00003Acl0000001H00003Acl0000000H00003Acl0000001/00003Acl0000001<00003
Acl0000000T00003Acl0000000T00003Acl0000000X00003Acl0000002@00003Acl0000000T00003
Acl0000001<00003Acl0000000T00003Acl0000000H00003Acl0000000T00003Acl0000001`00003
Acl0000000T00003Acl0000001<00003Acl0000000T00003Acl0000000H00003Acl0000000T00003
Acl0000000l00003Acl0000001<00003Acl0000001H00003Acl0000001800003Acl0000000l00003
Acl0000000T00003Acl0000001<00003Acl0000000T00003Acl0000000H00003Acl0000003400003
Acl0000001H00003Acl0000000T00003Acl0000000H00003Acl0000000T00003Acl0000002P00003
Acl0000001l00003Acl0000000T00003Acl0000002T000=oo`03001oogoo06Yoo`00CGoo0P0017oo
0P0057oo00<007ooOol03Woo0`0000=7?`0000002@0000=7?`000000700000=7?`0000001P0000=7
?`0000002@0000=7?`0000002@0000=7?`0000002P0000=7?`0000001P0000=7?`0000002@0000=7
?`000000700000=7?`0000002@0000=7?`0000001P0000=7?`0000002@0000=7?`0000004P0000=7
?`0000002P0000=7?`0000006`0000=7?`0000004`0000=7?`0000002@0000=7?`0000002@0000=7
?`0000001P0000=7?`000000:00000=7?`0000002@0000=7?`0000004`0000=7?`0000002@0000=7
?`0000001P0000=7?`0000002@0000=7?`0000009@0000=7?`0000002@0000=7?`0000002P0000=7
?`0000002@0000=7?`0000001P0000=7?`0000002@0000=7?`0000003`0000=7?`0000002@0000=7
?`0000001`0000=7?`0000002@0000=7?`0000004P0000=7?`000000:00000=7?`0000007`0000=7
?`0000004P0000=7?`0000006`0000=7?`0000001`0000=7?`0000002@0000=7?`000000?@0000=7
?`0000002@0000=7?`0000004`0000=7?`0000002@0000=7?`0000001P0000=7?`0000002@0000=7
?`000000:00000=7?`0000002@0000=7?`0000004`0000=7G`0000002@0000=7G`0000004@000Woo
00<007ooOol0JWoo001=Ool8000DOol00`00Oomoo`0?Ool600000dLo0000000:00000dLo00000009
00000dLo0000000600000dLo0000000X00000dLo0000000600000dLo0000000900000dLo00000009
00000dLo0000000:00000dLo0000000600000dLo0000000900000dLo0000000K00000dLo00000006
00000dLo0000000:00000dLo0000000900000dLo0000000900000dLo0000000600000dLo0000000X
00000dLo0000000600000dLo0000000F00000dLo0000000900000dLo0000000600000dLo00000009
00000dLo0000000L00000dLo0000000600000dLo0000000900000dLo0000000F00000dLo0000000`
00000dLo0000000700000dLo0000000900000dLo0000000900000dLo0000000600000dLo00000009
00000dLo0000000U00000dLo0000000F00000dLo0000000900000dLo0000000T00000dLo0000000C
00000dLo0000000900000dLo0000000B00000dLo0000000a00000dLo0000000F00000dLo0000000B
00000dLo0000000?00000dLo0000000900000dLo0000000C00000dLo0000000900000dLo0000000g
00000dLo0000000?00000dMO0000000J0003Ool00`00Oomoo`1YOol004moo`@001Ioo`03001oogoo
015oo`T00003Acl0000000T00003Acl0000000H00003Acl0000000T00003Acl0000000X00003Acl0
000000T00003Acl0000000H00003Acl0000001/00003Acl0000000X00003Acl0000000H00003Acl0
000000T00003Acl0000000T00003Acl0000001800003Acl0000001`00003Acl0000000T00003Acl0
000000H00003Acl0000001H00003Acl0000000T00003Acl0000000H00003Acl0000002P00003Acl0
000000H00003Acl0000000T00003Acl0000001H00003Acl0000000H00003Acl0000001/00003Acl0
000000T00003Acl0000001<00003Acl0000000T00003Acl0000001800003Acl0000002D00003Acl0
000000T00003Acl0000001H00003Acl0000002@00003Acl0000000T00003Acl0000001<00003Acl0
000000T00003Acl0000000H00003Acl0000001/00003Acl0000001<00003Acl0000000T00003Acl0
000001800003Acl0000002P00003Acl0000001l00003Acl0000001800003Acl0000000l00003Acl0
000000T00003Acl0000001<00003Acl0000000T00003Acl0000002800003Acl0000001800003Ael0
000001@0009oo`03001oogoo06Uoo`00J7oo00<007ooOol00`0047oo0`0000=7?`0000002@0000=7
?`000000700000=7?`0000002@0000=7?`0000001P0000=7?`0000002@0000=7?`0000004P0000=7
?`0000002P0000=7?`0000006`0000=7?`0000002P0000=7?`0000001@0000=7?`0000002P0000=7
?`0000002@0000=7?`0000001P0000=7?`0000002@0000=7?`000000700000=7?`0000002@0000=7
?`0000001P0000=7?`0000002@0000=7?`0000002P0000=7?`0000004P0000=7?`0000006`0000=7
?`0000004`0000=7?`0000002@0000=7?`0000002@0000=7?`0000001P0000=7?`0000002@0000=7
?`000000:00000=7?`0000001P0000=7?`0000005P0000=7?`000000900000=7?`0000002@0000=7
?`0000004`0000=7?`0000002@0000=7?`0000001P0000=7?`0000002@0000=7?`0000006`0000=7
?`0000001`0000=7?`0000002@0000=7?`0000004P0000=7?`0000002@0000=7?`0000003`0000=7
?`0000004`0000=7?`000000B@0000=7?`0000007`0000=7?`0000004P0000=7?`0000002@0000=7
?`0000003`0000=7?`0000008P0000=7?`000000:`0000=7G`0000001@000Woo00<007ooOol0J7oo
001XOol3000DOol600000dLo0000000:00000dLo0000000900000dLo0000000600000dLo00000009
00000dLo0000000L00000dLo0000000500000dLo0000000:00000dLo0000000900000dLo00000009
00000dLo0000000600000dLo0000000:00000dLo0000000K00000dLo0000000600000dLo00000009
00000dLo0000000F00000dLo0000000600000dLo0000000900000dLo0000000K00000dLo0000000C
00000dLo0000000900000dLo0000000900000dLo0000000600000dLo0000000X00000dLo00000006
00000dLo0000000900000dLo0000000F00000dLo0000000B00000dLo0000000K00000dLo0000000C
00000dLo0000000900000dLo0000000600000dLo0000000900000dLo0000000K00000dLo00000007
00000dLo0000000900000dLo0000000900000dLo0000000B00000dLo0000000U00000dLo00000009
00000dLo0000000B00000dLo0000000a00000dLo0000001900000dLo0000000[00000dLo00000006
00000dLo0000000900000dLo0000001000000dMO0000000>0002Ool00`00Oomoo`1XOol006Qoo`03
001oogoo01Ioo`T00003Acl0000000T00003Acl0000000H00003Acl0000000T00003Acl0000000T0
0003Acl0000000X00003Acl0000000H00003Acl0000002P00003Acl0000000D00003Acl0000000X0
0003Acl0000000T00003Acl0000000T00003Acl0000000H00003Acl0000002P00003Acl0000000H0
0003Acl0000000T00003Acl0000000T00003Acl0000001800003Acl0000002P00003Acl0000000H0
0003Acl0000001H00003Acl0000000T00003Acl0000000H00003Acl0000002L00003Acl0000001<0
0003Acl0000000T00003Acl0000001800003Acl0000001/00003Acl0000000L00003Acl0000000T0
0003Acl0000000T00003Acl0000001800003Acl0000001/00003Acl0000001<00003Acl0000001h0
0003Acl0000002D00003Acl0000000T00003Acl0000004H00003Acl0000002800003Acl000000300
0003Acl0000001l00003Acl0000000T00003Acl0000001800003Acl0000002`000=oo`03001oogoo
06Moo`00J7oo00<007ooOol05goo0`0000=7?`0000002@0000=7?`000000700000=7?`0000002@00
00=7?`0000001P0000=7?`0000002@0000=7?`0000002@0000=7?`0000002P0000=7?`0000001P00
00=7?`0000009`0000=7?`0000001P0000=7?`0000002@0000=7?`0000002P0000=7?`0000002@00
00=7?`0000001P0000=7?`0000009`0000=7?`0000001P0000=7?`0000002P0000=7?`0000002@00
00=7?`0000002@0000=7?`0000001P0000=7?`000000<@0000=7?`0000002@0000=7?`0000002@00
00=7?`0000004P0000=7?`000000:00000=7?`0000001P0000=7?`0000002@0000=7?`0000004P00
00=7?`000000:00000=7?`0000001P0000=7?`0000007P0000=7?`000000<@0000=7?`000000DP00
00=7?`000000B@0000=7?`000000DP0000=7?`0000002@0000=7?`0000007`0000=7?`0000002@00
00=7G`0000007@000Woo00<007ooOol0Igoo001XOol00`00Oomoo`0HOol600000dLo0000000:0000
0dLo0000000900000dLo0000000600000dLo0000000900000dLo0000000L00000dLo000000090000
0dLo0000000600000dLo0000000900000dLo0000000900000dLo0000000900000dLo000000060000
0dLo0000000L00000dLo0000000900000dLo0000000600000dLo0000000900000dLo000000090000
0dLo0000000B00000dLo0000000X00000dLo0000000600000dLo0000000900000dLo0000000F0000
0dLo0000000T00000dLo0000000900000dLo0000000600000dLo0000000F00000dLo0000000B0000
0dLo0000000K00000dLo0000000600000dLo0000000F00000dLo0000000900000dLo000000060000
0dLo0000000K00000dLo0000000600000dLo0000000F00000dLo0000000i00000dLo0000000F0000
0dLo0000000i00000dLo0000001B00000dLo0000000g00000dLo0000000K00000dLo000000090000
0dMO0000000V0003Ool00`00Oomoo`1VOol006Qoo`03001oogoo01YooaD00003Acl0000000H00003
Acl0000000T00003Acl0000000T00003Acl0000000X00003Acl0000000H00003Acl0000000T00003
Acl0000001/00003Acl0000001800003Acl0000001H00003Acl0000000H00003Acl0000000T00003
Acl0000001/00003Acl0000001800003Acl0000000X00003Acl0000000T00003Acl0000000T00003
Acl0000000H00003Acl0000001/00003Acl0000001l00003Acl0000000T00003Acl0000000H00003
Acl0000000T00003Acl0000001/00003Acl0000001<00003Acl0000000T00003Acl0000000T00003
Acl0000000H00003Acl0000001/00003Acl0000000T00003Acl0000000L00003Acl0000000T00003
Acl0000000T00003Acl0000000H00003Acl0000001/00003Acl0000001l00003Acl0000000T00003
Acl0000002@00003Acl0000005/00003Acl0000005800003Acl0000002h00003Acl0000001800003
Ael0000000T00003Ael0000000T00003Ael0000001@0009oo`03001oogoo06Ioo`00J7oo00<007oo
Ool06goo1P0000=7?`0000001P0000=7?`000000:00000=7?`0000001P0000=7?`0000002@0000=7
?`0000002@0000=7?`0000002@0000=7?`0000001P0000=7?`000000:00000=7?`0000001P0000=7
?`0000002@0000=7?`0000002@0000=7?`0000002@0000=7?`0000001P0000=7?`000000:00000=7
?`0000002@0000=7?`0000001P0000=7?`0000002@0000=7?`0000004P0000=7?`000000:00000=7
?`0000001P0000=7?`0000002@0000=7?`0000002@0000=7?`0000004P0000=7?`000000<@0000=7
?`0000002@0000=7?`0000004P0000=7?`0000002@0000=7?`0000009@0000=7?`0000002@0000=7
?`0000002@0000=7?`0000001P0000=7?`0000006`0000=7?`0000002@0000=7?`0000004`0000=7
?`0000002@0000=7?`000000;@0000=7?`000000DP0000=7?`0000007P0000=7?`000000@00000=;
?`000000:`0000=7G`0000002@0000=7G`000000300000=7G`0000000P000Woo00<007ooOol0IGoo
001XOol00`00Oomoo`0MOol500000dLo0000000:00000dLo0000000900000dLo0000000900000dLo
0000000600000dLo0000000X00000dLo0000000500000dLo0000000F00000dLo0000000900000dLo
0000000600000dLo0000000`00000dLo0000000F00000dLo0000000900000dLo0000000600000dLo
0000000900000dLo0000000K00000dLo0000000600000dLo0000000F00000dLo0000000900000dLo
0000000600000dLo0000000W00000dLo0000000600000dLo0000000F00000dLo0000000900000dLo
0000000T00000dLo0000000600000dLo0000000900000dLo0000000F00000dLo0000000]00000dLo
0000000900000dLo0000000900000dLo0000000600000dLo0000000900000dLo0000000K00000dLo
0000000C00000dLo0000000900000dLo0000000]00000dLo0000000N00000dLo0000000a00000dLo
0000000900000dLo0000000N00000dLo0000001000000d]O0000000900000d]O0000000900000dMO
0000000>0002Ool00`00Oomoo`1UOol006Qoo`03001oogoo01ioob800003Acl0000000D00003Acl0
000000T00003Acl0000001H00003Acl0000000H00003Acl0000002L00003Acl0000000H00003Acl0
000000T00003Acl0000000T00003Acl0000000X00003Acl0000003000003Acl0000000H00003Acl0
000000T00003Acl0000000T00003Acl0000001800003Acl0000002P00003Acl0000000H00003Acl0
000000T00003Acl0000000T00003Acl0000000T00003Acl0000000H00003Acl0000003d00003Acl0
000000T00003Acl0000000H00003Acl0000002L00003Acl0000001l00003Acl0000002d00003Acl0
000000T00003Acl0000000T00003Acl0000001800003Acl0000001/00003Acl0000001<00003Acl0
000000T00003Acl0000002d00003Acl0000001h00003Acl0000003d00003Bcl0000000T00003Bcl0
000001h00003Bcl0000004D0009oo`03001oogoo06Aoo`00J7oo00<007ooOol07goo1P0000=7?`00
00002P0000=7?`0000001P0000=7?`0000009`0000=7?`0000001P0000=7?`0000002@0000=7?`00
00002@0000=7?`0000002@0000=7?`0000001P0000=7?`000000:00000=7?`0000004P0000=7?`00
00002@0000=7?`0000002@0000=7?`0000001P0000=7?`0000009`0000=7?`0000001P0000=7?`00
00005P0000=7?`0000002@0000=7?`0000001P0000=7?`0000009`0000=7?`0000001P0000=7?`00
00002@0000=7?`0000005P0000=7?`000000;@0000=7?`0000002@0000=7?`0000002@0000=7?`00
00002@0000=7?`0000001P0000=7?`0000006`0000=7?`0000007`0000=7?`000000>@0000=7?`00
00002@0000=7?`0000004P0000=7?`0000006`0000=7?`0000007`0000=7?`000000;@0000=7?`00
00002@0000=7?`0000007P0000=7?`0000006`0000=;?`0000007`0000=;?`0000002@0000=;?`00
00002@0000=;?`000000=@000goo00<007ooOol0Hgoo001XOol00`00Oomoo`0QOol900000dLo0000
000600000dLo0000000900000dLo0000000900000dLo0000000900000dLo0000000600000dLo0000
000X00000dLo0000000500000dLo0000000900000dLo0000000:00000dLo0000000900000dLo0000
000600000dLo0000000W00000dLo0000000600000dLo0000000900000dLo0000000900000dLo0000
000B00000dLo0000000X00000dLo0000000600000dLo0000000900000dLo0000000900000dLo0000
000900000dLo0000000600000dLo0000000K00000dLo0000000900000dLo0000000O00000dLo0000
000`00000dLo0000000600000dLo0000000900000dLo0000000B00000dLo0000000K00000dLo0000
000O00000dLo0000000900000dLo0000000]00000dLo0000000900000dLo0000000B00000dLo0000
000K00000dLo0000001K00000d/o0000000900000d/o0000000900000d/o0000000600000d/o0000
000900000d/o0000000900000d/o0000000?00000d/o0000000900000d/o0000000X00000d]O0000
000900000d]O000000080002Ool00`00Oomoo`1SOol006Qoo`03001oogoo029oo`<00003Acl00000
02P00003Acl0000000D00003Acl0000000T00003Acl0000001H00003Acl0000000H00003Acl00000
02L00003Acl0000000H00003Acl0000000T00003Acl0000000T00003Acl0000000T00003Acl00000
00H00003Acl0000003000003Acl0000001H00003Acl0000000T00003Acl0000000H00003Acl00000
02L00003Acl0000000H00003Acl0000000T00003Acl0000001800003Acl0000000T00003Acl00000
03400003Acl0000000T00003Acl0000000T00003Acl0000000H00003Acl0000001/00003Acl00000
00H00003Acl0000000T00003Acl0000001800003Acl0000002L00003Acl0000001l00003Acl00000
02d00003Acl0000000T00003Acl0000000T00003Acl0000000H00003Acl0000002@00003Acl00000
01h00003Acl0000001/00003Bcl0000000T00003Bcl0000001<00003Bcl0000000T00003Bcl00000
00T00003Bcl0000001800003Bcl0000000T00003Bcl0000000T00003Bel0000002D00003Bel00000
00@000=oo`03001oogoo069oo`00J7oo00<007ooOol08goo1P0000=7?`0000002@0000=7?`000000
2P0000=7?`0000001P0000=7?`0000009`0000=7?`0000001P0000=7?`0000002@0000=7?`000000
2@0000=7?`0000002@0000=7?`0000001P0000=7?`000000<00000=7?`0000002@0000=7?`000000
5P0000=7?`000000<00000=7?`0000001P0000=7?`0000002@0000=7?`0000002@0000=7?`000000
2@0000=7?`0000001P0000=7?`000000900000=7?`0000002@0000=7?`0000005P0000=7?`000000
>@0000=7?`0000002@0000=7?`0000002@0000=7?`0000001P0000=7?`000000900000=7?`000000
2@0000=7?`0000002@0000=7?`0000004P0000=7?`0000006`0000=7?`0000007`0000=7?`000000
8`0000=7?`0000004`0000=7?`0000002@0000=7?`000000;@0000=;?`0000002@0000=;?`000000
2@0000=;?`0000001P0000=;?`0000002@0000=;?`0000003`0000=;?`0000002@0000=;?`000000
2@0000=;?`000000:`0000=;?`0000002@0000=;G`0000002@0000=;G`000000300000=;G`000000
2@0000=;G`0000000P000Woo00<007ooOol0HWoo001XOol00`00Oomoo`0UOolE00000dLo00000006
00000dLo0000000900000dLo0000000900000dLo0000000900000dLo0000000600000dLo0000000`
00000dLo0000000900000dLo0000000900000dLo0000000:00000dLo0000000`00000dLo0000000B
00000dLo0000000900000dLo0000000900000dLo0000000600000dLo0000000W00000dLo00000006
00000dLo0000000900000dLo0000000900000dLo0000000`00000dLo0000000O00000dLo00000009
00000dLo0000000]00000dLo0000000900000dLo0000000900000dLo0000000`00000dLo00000006
00000dLo0000000900000dLo0000000B00000dLo0000000K00000dLo0000000W00000dLo0000000?
00000dLo0000000900000dLo0000000K00000dLo0000000K00000d/o0000000900000d/o0000000C
00000d/o0000000900000d/o0000000N00000d/o0000000W00000d/o0000000900000d/o00000009
00000d]O0000000900000d]O0000000J0003Ool00`00Oomoo`1QOol006Qoo`03001oogoo02Ioo`H0
0003Acl0000000H00003Acl0000002P00003Acl0000000D00003Acl0000000T00003Acl0000000T0
0003Acl0000000X00003Acl0000003000003Acl0000001800003Acl0000000T00003Acl0000000T0
0003Acl0000000H00003Acl0000002L00003Acl0000000H00003Acl0000000T00003Acl0000000T0
0003Acl0000000T00003Acl0000000H00003Acl0000002L00003Acl0000000H00003Acl0000001h0
0003Acl0000003d00003Acl0000000T00003Acl0000003T00003Acl0000000T00003Acl0000000T0
0003Acl0000000H00003Acl0000002@00003Acl0000000T00003Acl0000000T00003Acl0000000H0
0003Acl0000002@00003Acl0000000T00003Acl0000000H00003Acl0000000T00003Acl0000001P0
0003Acl0000001h00003Bcl0000000T00003Bcl0000000l00003Bcl0000000T00003Bcl0000006@0
0003Bel0000000T00003Bel000000200009oo`03001oogoo065oo`00Igoo00<007ooOol0:Goo1@00
00=7?`0000002@0000=7?`0000002P0000=7?`0000002@0000=7?`0000001P0000=7?`0000009`00
00=7?`0000004P0000=7?`0000002@0000=7?`0000002@0000=7?`0000001P0000=7?`0000009`00
00=7?`0000001P0000=7?`0000002@0000=7?`0000002@0000=7?`0000002@0000=7?`0000001P00
00=7?`0000009`0000=7?`0000001P0000=7?`0000002@0000=7?`0000002@0000=7?`0000004P00
00=7?`0000006`0000=7?`0000001P0000=7?`0000008P0000=7?`0000008`0000=7?`0000007`00
00=7?`0000002@0000=7?`000000;@0000=7?`0000002@0000=7?`0000002@0000=7?`000000;@00
00=7?`0000002@0000=7?`0000002@0000=7?`0000008@0000=7?`0000002@0000=7?`0000002@00
00=7?`000000;@0000=;?`0000002@0000=;?`0000002@0000=;?`0000004P0000=;?`000000<000
00=;?`000000I@000goo00<007ooOol0H7oo001WOol00`00Oomoo`0ZOolQ00000dLo000000060000
0dLo0000000900000dLo0000000900000dLo0000000900000dLo0000000600000dLo0000000W0000
0dLo0000000600000dLo0000000900000dLo0000000900000dLo0000000900000dLo000000060000
0dLo0000000W00000dLo0000000600000dLo0000000900000dLo0000000900000dLo0000000B0000
0dLo0000000`00000dLo0000000N00000dLo0000000W00000dLo0000000W00000dLo0000000W0000
0dLo0000000O00000dLo0000000S00000dLo0000000O00000dLo0000000S00000dLo0000000C0000
0dLo0000000S00000dLo0000000O00000d/o0000000S00000d/o0000000O00000d/o0000001b0000
0d]O0000000900000d]O0000000D0002Ool00`00Oomoo`1POol006Moo`H002Qoo`H00003Acl00000
00T00003Acl0000000H00003Acl0000002P00003Acl0000000D00003Acl0000000T00003Acl00000
00T00003Acl0000000T00003Acl0000000H00003Acl0000002P00003Acl0000000D00003Acl00000
00T00003Acl0000000T00003Acl0000001800003Acl0000003000003Acl0000002800003Acl00000
02`00003Acl0000002X00003Acl0000002@00003Acl0000002X00003Acl0000001/00003Acl00000
02L00003Acl0000001/00003Acl0000002L00003Acl0000000l00003Acl0000002L00003Acl00000
01/00003Bcl0000002L00003Bcl0000001/00003Bcl0000003<00003Bcl0000000T00003Bcl00000
04T00003Bel00000010000=oo`03001oogoo05moo`00Igoo00<007ooOol0;Goo2@0000=7?`000000
1@0000=7?`0000002@0000=7?`0000002P0000=7?`0000002@0000=7?`0000001P0000=7?`000000
9`0000=7?`0000001@0000=7?`0000002@0000=7?`0000002P0000=7?`0000002@0000=7?`000000
1P0000=7?`0000009`0000=7?`0000001@0000=7?`0000005P0000=7?`0000002@0000=7?`000000
<00000=7?`0000007P0000=7?`0000002@0000=7?`000000;00000=7?`0000008P0000=7?`000000
8`0000=7?`0000001P0000=7?`0000007P0000=7?`0000006`0000=7?`0000001P0000=7?`000000
7P0000=7?`0000006`0000=7?`0000001P0000=7?`0000002@0000=7?`0000001P0000=7?`000000
900000=7?`0000002@0000=;?`0000002@0000=;?`000000;@0000=;?`0000002@0000=;?`000000
A@0000=;?`0000002@0000=;?`0000002@0000=;?`0000002@0000=;?`0000002@0000=;?`000000
900000=;G`0000002@0000=;G`0000002@0000=;G`0000000P000Woo00<007ooOol0Ggoo001WOol0
0`00Oomoo`0^Ool300000dLo0000000W00000dLo0000000600000dLo0000000900000dLo00000009
00000dLo0000000900000dLo0000000600000dLo0000000W00000dLo0000000600000dLo00000009
00000dLo0000000900000dLo0000000900000dLo0000000600000dLo0000000W00000dLo0000000B
00000dLo0000000900000dLo0000000900000dLo0000000600000dLo0000000W00000dLo0000000N
00000dLo0000000_00000dLo0000000W00000dLo0000000K00000dLo0000000600000dLo00000009
00000dLo0000000B00000dLo0000000K00000dLo0000000600000dLo0000000900000dLo00000009
00000dLo0000000600000dLo0000000H00000dLo0000000900000dLo0000000900000dLo0000000S
00000d/o0000000C00000d/o0000000S00000d/o0000000W00000d/o0000000K00000d/o00000009
00000d/o0000000900000d/o0000000900000d/o0000000900000d/o0000001:0003Ool00`00Oomo
o`1NOol006Moo`03001oogoo02moo`H00003Acl0000000T00003Acl0000000T00003Acl0000000H0
0003Acl0000002L00003Acl0000000H00003Acl0000000T00003Acl0000000T00003Acl0000000T0
0003Acl0000000H00003Acl0000002L00003Acl0000000H00003Acl0000000T00003Acl0000000T0
0003Acl0000000T00003Acl0000000H00003Acl0000002L00003Acl0000000H00003Acl0000000T0
0003Acl0000000T00003Acl0000000T00003Acl0000000H00003Acl0000005000003Acl0000001/0
0003Acl0000000H00003Acl0000000T00003Acl0000001800003Acl0000001/00003Acl0000000H0
0003Acl0000000T00003Acl0000000T00003Acl0000000H00003Acl0000002@00003Acl0000000T0
0003Acl0000000T00003Acl0000001L00003Acl0000002L00003Bcl0000000l00003Bcl0000002L0
0003Bcl0000002@00003Bcl0000000T00003Bcl0000000T00003Bcl0000000H00003Bcl0000000T0
0003Bcl0000000T00003Bcl0000000T00003Bcl0000000T00003Bcl0000000T00003Bcl0000000T0
0003Bcl0000000T00003Bel0000000T00003Bel0000001/00003Bel000000080009oo`03001oogoo
05ioo`00Igoo00<007ooOol0<Goo5@0000=7?`0000001@0000=7?`0000002@0000=7?`0000002@00
00=7?`0000004P0000=7?`000000<00000=7?`0000002@0000=7?`0000002@0000=7?`0000002@00
00=7?`0000001P0000=7?`000000<00000=7?`0000002@0000=7?`0000002@0000=7?`0000002@00
00=7?`0000001P0000=7?`0000009`0000=7?`0000001P0000=7?`0000002@0000=7?`0000002@00
00=7?`0000002@0000=7?`000000;00000=7?`0000007P0000=7?`000000900000=7?`0000002@00
00=7?`0000002@0000=7?`0000001P0000=7?`000000900000=7?`0000002@0000=7?`0000002@00
00=7?`0000008`0000=7?`0000006`0000=7?`0000006`0000=;?`0000001P0000=;?`0000004P00
00=;?`000000900000=;?`0000002@0000=;?`0000002@0000=;?`0000005`0000=;?`0000002@00
00=;?`000000:`0000=;?`000000;@0000=;?`0000002@0000=;G`0000007P0000=;G`0000002000
0Woo00<007ooOol0GGoo001WOol00`00Oomoo`0bOol600000dLo0000000600000dLo0000000_0000
0dLo0000000:00000dLo0000000900000dLo0000000900000dLo0000000900000dLo0000000/0000
0dLo0000000900000dLo0000000900000dLo0000000900000dLo0000000i00000dLo000000090000
0dLo0000000900000dLo0000000900000dLo0000000600000dLo0000000W00000dLo0000000B0000
0dLo0000000900000dLo0000000/00000dLo0000000900000dLo0000000900000dLo0000000]0000
0dLo0000000900000dLo0000000900000dLo0000000900000dLo0000001100000dLo0000000H0000
0dLo0000000900000dLo0000000900000d/o0000000600000d/o0000000H00000d/o000000090000
0d/o0000000900000d/o0000000G00000d/o0000000900000d/o0000000K00000d/o000000090000
0d/o0000000W00000d/o0000000]00000d/o0000000900000d/o0000000900000d]O000000090000
0d]O0000000J0002Ool00`00Oomoo`1MOol006Moo`03001oogoo03Aoo`D00003Acl0000000T00003
Acl0000000T00003Acl0000000T00003Acl0000000T00003Acl0000003000003Acl0000000H00003
Acl0000000T00003Acl0000000T00003Acl0000000T00003Acl0000003000003Acl0000000D00003
Acl0000000T00003Acl0000000T00003Acl0000003T00003Acl0000000T00003Acl0000000T00003
Acl0000000T00003Acl0000000H00003Acl0000006h00003Acl0000000H00003Acl0000000T00003
Acl0000000T00003Acl0000005l00003Acl0000000H00003Acl0000000T00003Acl0000000T00003
Acl0000002400003Bcl0000000T00003Bcl0000002<00003Bcl0000001/00003Bcl0000000T00003
Bcl0000001P00003Bcl0000000T00003Bcl0000000T00003Bcl0000008X00003Bel0000000L000=o
o`03001oogoo05aoo`00Igoo00<007ooOol0=Goo;@0000=7?`0000001@0000=7?`0000002@0000=7
?`0000002@0000=7?`0000002@0000=7?`0000001P0000=7?`0000009`0000=7?`0000001P0000=7
?`0000002@0000=7?`0000002@0000=7?`0000002@0000=7?`0000001P0000=7?`0000009`0000=7
?`0000001@0000=7?`0000002@0000=7?`0000002@0000=7?`0000002@0000=7?`000000900000=7
?`0000001P0000=7?`0000002@0000=7?`0000002@0000=7?`0000002@0000=7?`000000;00000=7
?`0000002@0000=7?`0000002@0000=7?`0000001P0000=7?`0000006`0000=7?`0000001P0000=7
?`0000002@0000=7?`0000002@0000=7?`0000008`0000=7?`0000001P0000=7?`0000004P0000=7
?`000000900000=7?`0000002@0000=7?`000000@@0000=;?`000000600000=;?`0000002@0000=;
?`0000002@0000=;?`0000005`0000=;?`0000002@0000=;?`0000009`0000=;?`0000002@0000=;
?`0000002@0000=;?`0000002@0000=;?`0000002@0000=;?`0000002@0000=;?`0000006`0000=;
G`0000002@0000=;G`0000003P000Woo00<007ooOol0G7oo001WOol00`00Oomoo`0fOol600000dLo
0000000900000dLo0000000900000dLo0000000600000dLo0000000W00000dLo0000000500000dLo
0000000900000dLo0000000900000dLo0000000900000dLo0000000600000dLo0000000`00000dLo
0000000900000dLo0000000900000dLo0000000900000dLo0000000600000dLo0000000_00000dLo
0000000900000dLo0000000900000dLo0000000600000dLo0000000W00000dLo0000000N00000dLo
0000000/00000dLo0000000900000dLo0000000900000dLo0000000600000dLo0000001400000dLo
0000000H00000dLo0000000900000dLo0000000900000dLo0000000G00000d/o0000001200000d/o
0000000900000d/o0000000G00000d/o0000000900000d/o0000000K00000d/o0000000900000d/o
0000000T00000d/o0000000900000d/o0000000900000d/o0000000900000d/o0000000900000d/o
0000000900000d/o0000000N00000d]O0000000900000d]O0000000C0003Ool00`00Oomoo`1KOol0
06Moo`03001oogoo03QooaD00003Acl0000000D00003Acl0000000T00003Acl0000000T00003Acl0
000000T00003Acl0000000H00003Acl0000002l00003Acl0000000T00003Acl0000000T00003Acl0
000000T00003Acl0000000T00003Acl0000002d00003Acl0000000T00003Acl0000000T00003Acl0
000000T00003Acl0000002`00003Acl0000000T00003Acl0000000T00003Acl0000000T00003Acl0
000000H00003Acl0000006/00003Acl0000000T00003Acl0000000T00003Acl0000002<00003Acl0
000000H00003Acl0000000T00003Acl0000000T00003Acl0000003D00003Bcl0000002@00003Bcl0
000000T00003Bcl0000001L00003Bcl0000001/00003Bcl0000000T00003Bcl0000001P00003Bcl0
000000T00003Bcl0000000T00003Bcl0000001L00003Bcl0000000T00003Bcl0000000T00003Bcl0
000000T00003Bcl0000000T00003Bcl0000000T00003Bcl0000000T00003Bcl0000000T00003Bcl0
000000T00003Bel0000002400003Bel000000080009oo`03001oogoo05]oo`00Igoo00<007ooOol0
>Goo1P0000=7?`0000001P0000=7?`000000;`0000=7?`0000002@0000=7?`0000002@0000=7?`00
00002@0000=7?`0000002@0000=7?`000000<00000=7?`0000001@0000=7?`0000002@0000=7?`00
00002@0000=7?`0000002@0000=7?`000000P00000=7?`0000002@0000=7?`0000002@0000=7?`00
00002@0000=7?`0000008`0000=7?`0000001P0000=7?`0000002@0000=7?`0000002@0000=7?`00
0000@@0000=7?`000000900000=7?`0000002@0000=7?`000000800000=;?`0000002@0000=;?`00
00002@0000=;?`0000005`0000=;?`0000006`0000=;?`000000600000=;?`0000002@0000=;?`00
00002@0000=;?`0000005`0000=;?`0000002@0000=;?`0000006`0000=;?`0000002@0000=;?`00
00002@0000=;?`0000002@0000=;?`0000002@0000=;?`0000005@0000=;?`000000;@0000=;G`00
00002@0000=;G`0000000`0000=;G`0000000P000Woo00<007ooOol0FWoo001WOol00`00Oomoo`0k
Ool500000dLo0000000900000dLo0000000900000dLo0000000900000dLo0000000900000dLo0000
000`00000dLo0000000500000dLo0000000900000dLo0000000900000dLo0000000900000dLo0000
000600000dLo0000000W00000dLo0000000500000dLo0000000900000dLo0000000900000dLo0000
000900000dLo0000000/00000dLo0000000900000dLo0000000900000dLo0000000900000dLo0000
000T00000dLo0000000V00000dLo0000000T00000dLo0000000900000dLo0000000900000dLo0000
000P00000dLo0000000900000dLo0000000900000dLo0000001`00000d/o0000000?00000d/o0000
000600000d/o0000000900000d/o0000000S00000d/o0000000K00000d/o0000000900000d/o0000
000H00000d/o0000000900000d/o0000000900000d/o0000001C00000d]O0000000900000d]O0000
000J0002Ool00`00Oomoo`1JOol006Moo`03001oogoo03aoocD00003Acl0000000T00003Acl00000
00T00003Acl0000000T00003Acl0000000H00003Acl0000002l00003Acl0000000T00003Acl00000
00T00003Acl0000000T00003Acl0000000H00003Acl0000002l00003Acl0000000T00003Acl00000
00T00003Acl0000000T00003Acl0000002`00003Acl0000000T00003Acl0000000T00003Acl00000
00H00003Acl0000002<00003Acl0000000T00003Acl0000000T00003Acl0000000T00003Acl00000
08h00003Acl0000000H00003Bcl0000000T00003Bcl0000002000003Bcl0000000T00003Bcl00000
00H00003Bcl0000003P00003Bcl0000001P00003Bcl0000000T00003Bcl0000001L00003Bcl00000
00T00003Bcl0000000T00003Bcl0000002X00003Bcl0000000T00003Bcl0000001h00003Bel00000
00T00003Bel0000001D00003Bel0000000P0009oo`03001oogoo05Uoo`00IWoo00<007ooOol0?Woo
1P0000=7?`0000002@0000=7?`0000002@0000=7?`0000002@0000=7?`000000;00000=7?`000000
2@0000=7?`0000002@0000=7?`0000002@0000=7?`0000002@0000=7?`000000;00000=7?`000000
2@0000=7?`0000002@0000=7?`0000002@0000=7?`000000;`0000=7?`0000001P0000=7?`000000
2@0000=7?`0000002@0000=7?`000000;00000=7?`0000002@0000=7?`0000002@0000=7?`000000
2@0000=7?`0000008`0000=7?`0000001P0000=7?`0000002@0000=7?`0000002@0000=7?`000000
800000=7?`0000002@0000=7?`0000002@0000=7?`0000005`0000=7?`0000001P0000=7?`000000
2@0000=7?`0000001P0000=7?`000000A`0000=;?`0000002@0000=;?`0000008`0000=;?`000000
1P0000=;?`0000002@0000=;?`0000005`0000=;?`0000006`0000=;?`0000002@0000=;?`000000
2@0000=;?`0000009P0000=;?`0000002@0000=;?`0000002@0000=;?`0000002@0000=;?`000000
2@0000=;?`0000008@0000=;G`0000003P000Woo00<007ooOol0FGoo001VOol00`00Oomoo`10OolP
00000dLo0000000600000dLo0000001C00000dLo0000000M00000dLo0000000900000dLo0000000h
00000dLo0000000900000dLo0000000900000dLo0000000600000dLo0000000W00000dLo00000005
00000dLo0000000900000dLo0000000900000dLo0000001400000dLo0000000600000dLo0000001c
00000dLo0000000H00000dLo0000000900000d/o0000000S00000d/o0000000600000d/o00000009
00000d/o0000000G00000d/o0000000600000d/o0000000900000d/o0000000600000d/o0000000>
00000d/o0000000K00000d/o0000000H00000d/o0000000900000d/o0000000900000d/o0000000M
00000d/o0000000900000d/o0000000900000d/o0000000900000d/o0000000900000d/o00000009
00000d/o0000000E00000d]O0000000900000d]O0000000300000d]O0000000>0002Ool00`00Oomo
o`1HOol006Ioo`03001oogoo045ooa400003Acl0000000H00003Acl0000002l00003Acl0000000T0
0003Acl0000000T00003Acl0000000T00003Acl0000000H00003Acl0000002l00003Acl0000000T0
0003Acl0000000T00003Acl0000000T00003Acl0000002`00003Acl0000000T00003Acl0000000T0
0003Acl0000000T00003Acl0000000H00003Acl0000002<00003Acl0000000T00003Acl0000000T0
0003Acl0000000T00003Acl0000002000003Acl0000000T00003Acl0000000T00003Acl0000002<0
0003Acl0000000H00003Acl0000000T00003Acl0000002000003Acl0000000T00003Acl0000000T0
0003Acl0000001L00003Bcl0000000H00003Bcl0000000T00003Bcl0000000H00003Bcl0000002`0
0003Bcl0000001P00003Bcl0000001400003Bcl0000001P00003Bcl0000000T00003Bcl0000001L0
0003Bcl0000000T00003Bcl0000001800003Bcl0000000T00003Bcl0000004L00003Bel0000000T0
0003Bel0000002H0009oo`03001oogoo05Qoo`00IWoo00<007ooOol00`00?goo4@0000=7?`000000
2@0000=7?`0000002@0000=7?`0000002@0000=7?`0000002@0000=7?`000000;00000=7?`000000
2@0000=7?`0000002@0000=7?`0000002@0000=7?`0000002@0000=7?`000000;00000=7?`000000
2@0000=7?`0000002@0000=7?`0000002@0000=7?`000000;00000=7?`0000002@0000=7?`000000
2@0000=7?`000000;`0000=7?`000000H@0000=7?`000000I`0000=;?`0000003`0000=;?`000000
1P0000=;?`0000002@0000=;?`0000005`0000=;?`0000001P0000=;?`0000002@0000=;?`000000
5`0000=;?`0000001P0000=;?`0000002@0000=;?`0000002`0000=;?`0000002@0000=;?`000000
6`0000=;?`0000002@0000=;?`0000003P0000=;?`0000002@0000=;?`000000B`0000=;G`000000
2@0000=;G`0000005@0000=;G`0000003`0000=;G`0000000P000Woo00<007ooOol0Egoo001VOol3
0013Ool600000dLo0000000`00000dLo0000000500000dLo0000000900000dLo0000000900000dLo
0000000900000dLo0000000h00000dLo0000000900000dLo0000000900000dLo0000000900000dLo
0000001?00000dLo0000000/00000dLo0000000900000dLo0000000900000dLo0000000600000dLo
0000000S00000dLo0000000900000dLo0000000900000dLo0000000P00000dLo0000000900000dLo
0000000900000dLo0000000P00000dLo0000000900000dLo0000000P00000d/o0000000900000d/o
0000000600000d/o0000000>00000d/o0000000B00000d/o0000000600000d/o0000000/00000d/o
0000000P00000d/o0000000900000d/o0000000H00000d/o0000000900000d/o0000000A00000d/o
0000000900000d/o0000000n00000dlo0000000900000dlo0000000900000dmO0000000E00000dmO
0000000J0003Ool00`00Oomoo`1FOol006Ioo`03001oogoo04Eoo`D00003Acl0000000T00003Acl0
000000T00003Acl0000000T00003Acl0000000H00003Acl0000002l00003Acl0000000T00003Acl0
000000T00003Acl0000000T00003Acl0000000T00003Acl0000004<00003Acl0000000T00003Acl0
000002`00003Acl0000000T00003Acl0000000T00003Acl0000000T00003Acl0000002000003Acl0
000000T00003Acl0000000T00003Acl0000000T00003Acl0000002000003Acl0000009H00003Bcl0
000001400003Bcl0000001P00003Bcl0000000T00003Bcl0000001L00003Bcl0000000H00003Bcl0
000000T00003Bcl0000000/00003Bcl0000000H00003Bcl0000000T00003Bcl0000001L00003Bcl0
000000T00003Bcl0000001800003Bcl0000001L00003Bcl0000000T00003Bcl0000000T00003Bcl0
000000T00003Ccl0000000l00003Ccl0000000T00003Ccl0000000T00003Cel0000000T00003Cel0
000000T00003Cel0000001D00003Bel0000000<00003Cel000000080009oo`03001oogoo05Ioo`00
IWoo00<007ooOol0AWoo:@0000=7?`0000002@0000=7?`0000002@0000=7?`0000002@0000=7?`00
00002@0000=7?`000000@`0000=7?`0000002@0000=7?`0000002@0000=7?`000000;00000=7?`00
00002@0000=7?`0000002@0000=7?`0000002@0000=7?`000000;00000=7?`000000C`0000=7?`00
00002@0000=7?`000000800000=7?`0000002@0000=7?`0000002@0000=7?`0000005`0000=7?`00
00001P0000=7?`0000002@0000=7?`0000005`0000=;?`0000001P0000=;?`0000002@0000=;?`00
0000500000=;?`0000002@0000=;?`0000002@0000=;?`0000002`0000=;?`0000004P0000=;?`00
00001P0000=;?`0000003P0000=;?`0000003`0000=;?`000000;00000=;?`0000002@0000=;?`00
0000;00000=;?`0000002@0000=;?`0000002@0000=;?`0000006P0000=??`0000004`0000=??`00
00002`0000=?G`0000002@0000=?G`0000005@0000=?G`000000100000=?G`0000001`000goo00<0
07ooOol0EGoo001VOol00`00Oomoo`17Ool600000dLo0000000900000dLo0000000900000dLo0000
000h00000dLo0000000900000dLo0000000D00000dLo0000000900000dLo0000000/00000dLo0000
000900000dLo0000000900000dLo0000000900000dLo0000001?00000dLo0000000P00000dLo0000
000900000dLo0000000900000dLo0000000900000dLo0000000P00000dLo0000000900000dLo0000
000900000dLo0000000P00000dLo0000000A00000dLo0000000/00000d/o0000001?00000d/o0000
000H00000d/o0000000A00000d/o0000000<00000d/o0000000900000d/o0000000G00000d/o0000
000600000d/o0000000900000d/o0000000G00000d/o0000000B00000d/o0000000900000dlo0000
000900000dlo0000000A00000dlo0000000900000dlo0000000?00000dlo0000000?00000dmO0000
000900000dmO0000000300000dmO0000000?00000dmO0000000300000dmO0000000900000dmO0000
00020002Ool00`00Oomoo`1EOol006Ioo`03001oogoo04Uooad00003Acl0000000T00003Acl00000
00T00003Acl0000000T00003Acl0000004<00003Acl0000000T00003Acl0000000T00003Acl00000
00T00003Acl0000002`00003Acl0000001@00003Acl0000000T00003Acl0000002`00003Acl00000
00T00003Acl0000000T00003Acl0000007800003Acl0000000T00003Acl0000001@00003Acl00000
00T00003Acl0000000T00003Acl0000001@00003Bcl0000000T00003Bcl0000000T00003Bcl00000
01@00003Bcl0000000T00003Bcl0000001@00003Bcl0000000T00003Bcl0000001L00003Bcl00000
00H00003Bcl0000000T00003Bcl0000000/00003Bcl0000001800003Bcl0000000H00003Bcl00000
00h00003Bcl0000001/00003Bcl0000000h00003Ccl0000000T00003Ccl0000000T00003Ccl00000
01800003Ccl0000000T00003Ccl0000001800003Ccl0000000h00003Ccl0000002400003Cel00000
00@00003Cel0000000T00003Cel0000000L000=oo`03001oogoo05Aoo`00IWoo00<007ooOol0BWoo
1P0000=7?`0000002@0000=7?`000000=`0000=7?`0000002@0000=7?`0000002@0000=7?`000000
2@0000=7?`0000002@0000=7?`000000;00000=7?`000000800000=7?`000000;00000=7?`000000
2@0000=7?`0000002@0000=7?`0000002@0000=7?`000000=`0000=7?`0000002@0000=7?`000000
800000=7?`0000002@0000=7?`0000002@0000=7?`000000800000=7?`000000]@0000=;?`000000
800000=;?`000000600000=;?`0000004@0000=;?`000000600000=;?`0000004@0000=??`000000
2@0000=??`0000002@0000=??`0000006P0000=??`0000002@0000=??`0000006`0000=??`000000
5@0000=?G`0000002@0000=?G`0000000`0000=?G`0000006P000Woo00<007ooOol0E7oo001VOol0
0`00Oomoo`1<OolA00000dLo0000000900000dLo0000000900000dLo0000000D00000dLo0000000h
00000dLo0000000900000dLo0000000900000dLo0000000g00000dLo0000000900000dLo00000009
00000dLo0000000900000dLo0000000g00000dLo0000000900000dLo0000000/00000dLo00000009
00000dLo0000001300000dLo0000000D00000dLo0000000900000dLo0000000900000dLo0000000D
00000d/o0000000900000d/o0000000G00000d/o0000000600000d/o0000000900000d/o0000000;
00000d/o0000000600000d/o0000000900000d/o0000000;00000d/o0000000600000d/o00000009
00000d/o0000000;00000d/o0000000600000d/o0000000900000d/o0000000;00000d/o00000009
00000d/o0000000600000d/o0000000G00000d/o0000000900000dlo0000000600000dlo0000000G
00000dlo0000000900000dlo0000000?00000dlo0000000900000dlo0000000900000dlo0000000>
00000dlo0000000E00000dmO0000000900000dmO0000000W0002Ool00`00Oomoo`1COol006Ioo`03
001oogoo04eoo`H00003Acl0000003L00003Acl0000000T00003Acl0000000T00003Acl0000000T0
0003Acl0000000T00003Acl0000002/00003Acl0000000T00003Acl0000000T00003Acl0000000T0
0003Acl0000004<00003Acl0000000T00003Acl0000002000003Acl0000000T00003Acl0000000T0
0003Acl0000002/00003Acl0000000T00003Acl0000000T00003Acl0000001L00003Acl0000000H0
0003Acl0000000T00003Acl0000001L00003Acl0000003d00003Bcl0000002000003Bcl000000200
0003Bcl0000002000003Bcl0000002000003Bcl0000000T00003Bcl0000002000003Bcl0000000T0
0003Ccl0000002000003Ccl0000000T00003Ccl0000000h00003Ccl0000000T00003Ccl0000000T0
0003Ccl0000000l00003Ccl0000001D00003Cel0000000T00003Cel0000000T00003Cel000000200
009oo`03001oogoo05=oo`00IWoo00<007ooOol0Cgoo1@0000=7?`0000002@0000=7?`0000005000
00=7?`0000002@0000=7?`000000>00000=7?`000000500000=7?`0000002@0000=7?`000000;000
00=7?`0000002@0000=7?`000000500000=7?`000000;00000=7?`0000002@0000=7?`000000=`00
00=7?`0000002@0000=7?`0000002@0000=7?`000000800000=7?`0000004@0000=7?`0000008`00
00=7?`0000001P0000=7?`0000005`0000=;?`0000002@0000=;?`000000500000=;?`0000002@00
00=;?`000000500000=;?`0000002@0000=;?`000000500000=;?`0000002@0000=;?`0000005000
00=;?`0000002@0000=;?`000000500000=;?`0000002@0000=;?`0000005`0000=;?`0000001P00
00=??`0000005`0000=??`0000004P0000=??`0000002@0000=??`0000004@0000=??`0000002@00
00=??`0000002@0000=??`0000009P0000=??`0000002@0000=?G`0000002@0000=?G`0000009P00
0goo00<007ooOol0DWoo001VOol00`00Oomoo`1@Ool600000dLo0000000[00000dLo000000090000
0dLo0000000900000dLo0000000900000dLo0000000g00000dLo0000000900000dLo000000090000
0dLo0000000g00000dLo0000000900000dLo0000000900000dLo0000000[00000dLo000000090000
0dLo0000000900000dLo0000000900000dLo0000000g00000dLo0000000D00000dLo000000090000
0dLo0000000900000dLo0000000D00000dLo0000000900000d/o0000002D00000d/o0000001<0000
0d/o0000000P00000dlo0000000>00000dlo0000000900000dlo0000000B00000dlo000000090000
0dlo0000000900000dlo0000000G00000dlo0000000?00000dlo0000000900000dmO000000090000
0dmO0000000K00000dmO0000000900000dmO000000020002Ool00`00Oomoo`1BOol006Ioo`03001o
ogoo059oo`D00003Acl0000000P00003Acl0000000T00003Acl0000000T00003Acl0000003L00003
Acl0000000T00003Acl0000000T00003Acl0000000T00003Acl0000002/00003Acl0000000T00003
Acl0000000T00003Acl0000000T00003Acl0000002/00003Acl0000000T00003Acl0000000T00003
Acl0000000T00003Acl0000003L00003Acl0000002000003Acl0000000T00003Acl0000004h00003
Bcl0000000T00003Bcl0000001@00003Bcl0000000T00003Bcl0000001@00003Bcl0000000T00003
Bcl0000000/00003Bcl0000000H00003Bcl0000001L00003Bcl0000000H00003Bcl0000001L00003
Bcl0000000H00003Bcl0000000/00003Bcl0000001800003Ccl0000000/00003Ccl0000001800003
Ccl0000001400003Ccl0000000T00003Ccl0000001X00003Ccl0000000T00003Ccl0000001/00003
Ccl0000000h00003Ccl0000000T00003Ccl0000000T00003Cel0000001D00003Cel0000000@00003
Cel0000000T00003Cel0000000L000=oo`03001oogoo055oo`00IGoo00<007ooOol0E7oo:00000=7
?`0000002@0000=7?`0000002@0000=7?`000000500000=7?`000000;00000=7?`000000500000=7
?`0000002@0000=7?`0000002@0000=7?`000000800000=7?`000000500000=7?`0000002@0000=7
?`000000@`0000=7?`000000800000=7?`0000002@0000=7?`000000:`0000=7?`0000002@0000=7
?`000000500000=7?`0000002@0000=;?`0000002@0000=;?`000000HP0000=;?`0000005`0000=;
?`0000001P0000=;?`0000005`0000=;?`0000001P0000=;?`000000500000=;?`0000003P0000=?
?`0000003`0000=??`0000003P0000=??`0000004P0000=??`0000002`0000=??`0000002@0000=?
?`0000003`0000=??`0000002@0000=??`0000003P0000=??`0000002@0000=??`0000002@0000=?
?`0000000`0000=??`0000002@0000=??`0000000`0000=??`0000000`0000=?G`0000005@0000=?
G`0000000`0000=?G`0000005@0000=?G`0000000P000Woo00<007ooOol0DGoo001UOol00`00Oomo
o`1EOol500000dLo0000000900000dLo0000000900000dLo0000000900000dLo0000000[00000dLo
0000000900000dLo0000000900000dLo0000000900000dLo0000000g00000dLo0000000900000dLo
0000000D00000dLo0000000P00000dLo0000000900000dLo0000000D00000dLo0000000P00000dLo
0000000900000dLo0000000[00000dLo0000000900000dLo0000000P00000dLo0000000g00000d/o
0000000D00000d/o0000000900000d/o0000000;00000d/o0000000600000d/o0000000D00000d/o
0000000900000d/o0000000D00000d/o0000000G00000d/o0000000600000d/o0000000D00000d/o
0000000A00000dlo0000000<00000dlo0000000A00000dlo0000000P00000dlo0000000900000dlo
0000000>00000dln0000000900000dln0000000900000dlo0000000300000dlo0000000900000dlo
0000000900000dlo0000000E00000dlo0000000>00000dmO0000000900000dmO0000000400000dmO
0000000E00000dmO000000070003Ool00`00Oomoo`1@Ool006Eoo`03001oogoo05IoobT00003Acl0
000001@00003Acl0000000T00003Acl0000003L00003Acl0000000T00003Acl0000000T00003Acl0
000000T00003Acl0000002/00003Acl0000000T00003Acl0000000T00003Acl0000002/00003Acl0
000000T00003Acl0000000T00003Acl0000001l00003Acl0000000T00003Acl0000000T00003Acl0
000001@00003Acl0000001@00003Acl0000001@00003Acl0000000T00003Bcl0000001L00003Bcl0
000000H00003Bcl0000001L00003Bcl0000000h00003Bcl0000003X00003Bcl0000000/00003Bcl0
000000H00003Bcl0000000H00003Bcl0000001L00003Bcl0000000/00003Ccl0000000H00003Ccl0
000001L00003Ccl0000000H00003Ccl0000001L00003Cch0000000H00003Cch0000000T00003Cch0
000000/00003Cch0000000<00003Cch0000000T00003Cch0000000T00003Ccl0000000h00003Cch0
000000T00003Ccl0000001D00003Ccl0000000l00003Cel0000000T00003Cel0000000@00003Cel0
000001D00003Cel0000000d0009oo`03001oogoo051oo`00IGoo00<007ooOol0Egoo1P0000=7?`00
00002@0000=7?`0000002@0000=7?`000000:`0000=7?`0000002@0000=7?`0000002@0000=7?`00
0000200000=7?`0000002@0000=7?`000000=`0000=7?`0000002@0000=7?`0000002@0000=7?`00
0000:`0000=7?`0000002@0000=7?`0000002@0000=7?`000000:`0000=7?`0000002@0000=7?`00
0000:`0000=7?`000000800000=7?`0000002@0000=7?`000000:00000=;?`0000005`0000=;?`00
00001P0000=;?`0000002`0000=;?`0000002@0000=;?`000000500000=;?`0000005`0000=;?`00
00003P0000=;?`000000300000=;?`000000:00000=??`000000800000=??`000000800000=??P00
00003P0000=??P0000003`0000=??P0000003P0000=??P0000002@0000=??P0000003`0000=??P00
00002@0000=??`0000005@0000=??`0000003P0000=??`0000002@0000=?G`0000001P0000=?G`00
00005@0000=?G`0000003P0000A?O`000000009oo`03001oogoo04moo`00IGoo00<007ooOol0FGoo
7@0000=7?`000000500000=7?`0000002@0000=7?`0000002@0000=7?`000000:`0000=7?`000000
2@0000=7?`0000002@0000=7?`000000200000=7?`000000;00000=7?`000000500000=7?`000000
2@0000=7?`000000:`0000=7?`0000002@0000=7?`000000800000=7?`000000500000=7?`000000
500000=7?`0000002@0000=7?`000000:`0000=;?`000000500000=;?`0000002@0000=;?`000000
500000=;?`000000@P0000=;?`0000001P0000=;?`0000002`0000=;?`0000002@0000=;?`000000
2`0000=;?`0000001P0000=;?`0000002`0000=??`0000001P0000=??`0000005`0000=??`000000
1P0000=??`0000002`0000=??P0000002@0000=??P0000001P0000=??P0000002`0000=??P000000
0`0000=??P000000300000=??P0000004@0000=??P0000002@0000=??P0000003P0000=??P000000
2@0000=??P0000005@0000=??P0000003`0000=??`0000002@0000=?G`000000200000=?G`000000
5@0000=?G`000000100000=?G`0000001P0000=?O`0000001@000Woo00<007ooOol0Cgoo001UOol0
0`00Ool00002001HOol600000dLo0000000900000dLo0000000g00000dLo0000000D00000dLo0000
000900000dLo0000000900000dLo0000000O00000dLo0000000900000dLo0000000900000dLo0000
000g00000dLo0000000D00000dLo0000000P00000dLo0000000D00000dLo0000000P00000dLo0000
000900000dLo0000000O00000dLo0000000900000dLo0000000D00000d/o0000000[00000d/o0000
000D00000d/o0000000900000d/o0000000;00000d/o0000000600000d/o0000000D00000d/o0000
000G00000d/o0000000>00000d/o0000000300000d/o0000000>00000dlo0000000P00000dlo0000
000D00000dln0000000900000dln0000000D00000dln0000000>00000dln0000000900000dln0000
000600000dln0000000900000dln0000000;00000dln0000000300000dln0000000900000dln0000
000E00000dln0000000>00000dlo0000000E00000dmO0000000900000e=O0000000900000e=O0000
000400000dmO0000000800000dmo00000005000015=o000000000Woo00<007ooOol0CWoo001UOol2
001MOolL00000dLo0000000900000dLo0000000900000dLo0000000900000dLo0000000g00000dLo
0000000800000dLo0000000900000dLo0000000900000dLo0000000O00000dLo0000000900000dLo
0000000900000dLo0000000[00000dLo0000000900000dLo0000000D00000dLo0000000D00000dLo
0000000900000dLo0000000[00000dLo0000000900000dLo0000000D00000dLo0000000O00000d/o
0000000900000d/o0000000D00000d/o0000000X00000d/o0000000G00000d/o0000000D00000d/o
0000000600000d/o0000000;00000d/o0000000600000d/o0000000;00000dlo0000000900000dlo
0000000;00000dln0000000600000dln0000000;00000dlN0000000600000dln0000000G00000dlN
0000000600000dln0000000A00000dln0000000900000dln0000000P00000dln0000000V00000dln
0000000900000dln0000000300000dlo0000000E00000dmO0000000900000e=O0000000900000e=O
0000000?00000e=O0000000600000e=o000000050002Ool00`00Oomoo`1>Ool006Eoo`03001oogoo
05eoo`H00003Acl0000003L00003Acl0000000P00003Acl0000000T00003Acl0000000T00003Acl0
000003L00003Acl0000001@00003Acl0000000T00003Acl0000001l00003Acl0000000T00003Acl0
000000T00003Acl0000002/00003Acl0000000T00003Acl0000001l00003Acl0000000T00003Acl0
000000T00003Acl0000001l00003Acl0000001@00003Bcl0000000T00003Bcl0000003H00003Bcl0
000000T00003Bcl0000000P00003Bcl0000000T00003Bcl0000000/00003Bcl0000000H00003Bcl0
000001@00003Bcl0000001@00003Bcl0000002P00003Cch0000001@00003Cah0000002000003Cah0
000001L00003Cah0000000/00003Cah0000000T00003Cch0000001800003Cch0000002T00003Cch0
000002H00003Dcl0000000T00003Del0000000H00003Del0000001<00003Del0000000P00003Dgl0
000000D00004Dgl000000002Ool00`00Oomoo`1=Ool006Eoo`03001oogoo05mooa000003Acl00000
00T00003Acl0000000T00003Acl0000000T00003Acl0000000P00003Acl0000002/00003Acl00000
00T00003Acl0000000T00003Acl0000000T00003Acl0000000P00003Acl0000002000003Acl00000
01@00003Acl0000000T00003Acl0000001l00003Acl0000000T00003Acl0000000T00003Acl00000
01l00003Acl0000000T00003Acl0000000T00003Acl0000001l00003Acl0000001@00003Acl00000
00T00003Bcl0000001l00003Bcl0000001@00003Bcl0000000T00003Bcl0000000/00003Bcl00000
02D00003Bcl0000001L00003Bcl0000001@00003Bcl0000000/00003Ccl0000000H00003Ccl00000
00/00003Cah0000000H00003Cah0000000/00003Cah0000000H00003Cah0000000/00003Cah00000
00T00003Cah0000000H00003Cah0000000/00003Cah0000001X00003Cah0000000T00003Cch00000
00h00003Cch0000000T00003Cch0000002000003Dch0000000T00003Dch0000001/00003Dcl00000
00T00003Del0000000P00003Del0000001400003Del0000001400003Dgl0000000D0009oo`03001o
ogoo04eoo`00IGoo00<007ooOol0H7oo1P0000=7?`000000200000=7?`000000:`0000=7?`000000
2@0000=7?`0000002@0000=7?`000000200000=7?`0000002@0000=7?`000000:`0000=7?`000000
2@0000=7?`0000002@0000=7?`000000200000=7?`000000800000=7?`000000500000=7?`000000
:`0000=7?`0000002@0000=7?`000000:`0000=7?`000000500000=7?`000000:`0000=;?`000000
500000=;?`000000:00000=;?`0000002`0000=;?`0000002@0000=;?`000000200000=;?`000000
2@0000=;?`0000002`0000=;?`0000001P0000=;?`0000002`0000=;?`0000003P0000=??`000000
0`0000=??`0000003P0000=?7P000000500000=?7P000000500000=?7P0000002@0000=?7P000000
500000=?7P0000003P0000=?7P0000001P0000=?7P0000002`0000=?7P0000002@0000=?7P000000
0`0000=??P0000002@0000=??P0000003P0000=??P0000002@0000=C?P0000000`0000=C?P000000
2@0000=C?P0000003P0000=C?P0000002@0000=C?P0000002P0000=C?P000000200000=CG`000000
4P0000=CG`0000004P0000=CO`0000002@000Woo00<007ooOol0C7oo001UOol00`00Oomoo`1ROol@
00000dLo0000000900000dLo0000000900000dLo0000000800000dLo0000000900000dLo0000000[
00000dLo0000000900000dLo0000000800000dLo0000000900000dLo0000000[00000dLo00000009
00000dLo0000000[00000dLo0000000900000dLo0000000800000dLo0000000P00000dLo0000000D
00000dLo0000000D00000dLo0000000O00000dLo0000000900000d/o0000000D00000d/o0000000O
00000d/o0000000900000d/o0000000800000d/o0000000900000d/o0000000;00000d/o0000000D
00000d/o0000000>00000d/o0000000D00000d/o0000000;00000dlo0000000600000dlo0000000;
00000dlN0000000;00000dlN0000000600000dlN0000000;00000dlN0000000600000dlN00000009
00000dlN0000000;00000dlN0000000600000dlN0000000;00000dlN0000000300000dlN0000000D
00000dlN0000000900000dlN0000000>00000dlN0000000900000e<n0000000300000dln00000009
00000e<n0000000>00000e<n0000000?00000e<n0000000900000e<n0000000E00000e=O0000000D
00000e=O0000000=00001E=O00000000Dgl03`000Woo00<007ooOol0C7oo001UOol00`00Oomoo`1R
Ool600000dLo0000000g00000dLo0000000900000dLo0000000800000dLo0000000900000dLo0000
000[00000dLo0000000900000dLo0000000800000dLo0000000900000dLo0000000O00000dLo0000
000900000dLo0000000900000dLo0000000O00000dLo0000000900000dLo0000000[00000dLo0000
000O00000dLo0000000900000dLo0000000f00000d/o0000000900000d/o0000000c00000d/o0000
000;00000d/o0000000600000d/o0000000;00000d/o0000000D00000d/o0000000D00000dlO0000
000L00000dlN0000000D00000dlN0000000P00000dlN0000000D00000dlN0000000>00000dlN0000
000600000dlN0000000;00000dlN0000000900000dlN0000000300000dlN0000000900000e<n0000
000>00000e<n0000000?00000e<n0000000>00000e<n0000000600000e<n0000000<00000e<n0000
000900000e<n0000000B00000e=O0000000B00000e=O0000000E0002Ool00`00Oomoo`1;Ool006Eo
o`03001oogoo06Aoo`D00003Acl0000000T00003Acl0000000T00003Acl0000000P00003Acl00000
00T00003Acl0000002/00003Acl0000001@00003Acl0000000T00003Acl0000000T00003Acl00000
01l00003Acl0000001@00003Acl0000000T00003Acl0000001l00003Acl0000000T00003Acl00000
01l00003Acl0000000T00003Acl0000001l00003Acl0000000T00003Acl0000001l00003Bcl00000
00T00003Bcl0000000P00003Bcl0000000T00003Bcl0000001l00003Bcl0000000P00003Bcl00000
00T00003Bcl0000000P00003Bcl0000001@00003Bcl0000003H00003Cah0000001@00003Cah00000
00P00003Cah0000000T00003Cah0000000P00003Cah0000000T00003Cah0000000/00003Cah00000
00H00003Cah0000000/00003Cah0000000H00003Cah0000000/00003Cah0000000<00003Cah00000
01@00003Cah0000000T00003Cah0000000h00003Dah0000000T00003Dah0000000<00003Dch00000
00h00003Dch0000000T00003Dch0000000<00003Dch0000000P00003Dch0000000X00003Dch00000
00T00003Dch0000001@00003Del0000001400003Del0000000T00003Dgl0000000d0009oo`03001o
ogoo04]oo`00IGoo00<007ooOol0IGoo1P0000=7?`000000:`0000=7?`0000002@0000=7?`000000
200000=7?`0000002@0000=7?`0000002@0000=7?`000000=P0000=7?`0000002@0000=7?`000000
:`0000=7?`000000200000=7?`0000002@0000=7?`0000007`0000=7?`0000002@0000=7?`000000
2@0000=7?`0000004`0000=7?`0000002@0000=7?`0000007`0000=7?`0000002@0000=;?`000000
=P0000=;?`000000500000=;?`000000:P0000=;?`000000500000=;?`0000002`0000=;?`000000
1P0000=;7`0000002`0000=?7P0000001P0000=?7P0000002`0000=?7P000000500000=?7P000000
9@0000=?7P000000500000=?7P000000500000=?7P0000003P0000=?7P0000001P0000=?7P000000
2`0000=?7P0000002@0000=C7P0000000`0000=C7P0000002@0000=C7P0000003P0000=C?P000000
0`0000=C?P0000002@0000=C?P0000003P0000=C?P0000002@0000=C?P0000002P0000=C?P000000
200000=CGP0000002@0000=CG`0000004P0000=CG`0000007P000Woo00<007ooOol0BWoo001UOol0
0`00Oomoo`1WOol500000dLo0000000900000dLo0000000800000dLo0000000900000dLo00000009
00000dLo0000000f00000dLo0000000900000dLo0000000800000dLo0000000900000dLo0000000O
00000dLo0000000900000dLo0000000D00000dLo0000000D00000dLo0000000D00000dLo00000009
00000dLo0000000O00000dLo0000000900000dLo0000000C00000dLo0000000900000dLo0000000O
00000d/o0000000800000d/o0000000900000d/o0000000D00000d/o0000000O00000d/o00000008
00000d/o0000000900000d/o0000000800000d/o0000000L00000d/o0000000D00000dlN0000000D
00000dlN0000000;00000dlN0000000600000dlN0000000;00000dlN0000000;00000dlN00000006
00000dlN0000000;00000dlN0000000600000dlN0000000;00000dlN0000000600000dlN0000000;
00000dlN0000000300000dlN0000000D00000dlN0000000900000e<N0000000>00000e<N0000000?
00000e<n0000000>00000e<n0000000900000e<n0000000300000e<n0000000900000e<n0000000E
00000e=N0000000900000e=O0000000D00000e=O0000000500000e=O0000000A00000e=o00000005
0003Ool00`00Oomoo`19Ool006Aoo`03001oogoo06Uoo`H00003Acl0000003H00003Acl0000000T0
0003Acl0000001@00003Acl0000002/00003Acl0000001@00003Acl0000000T00003Acl0000001l0
0003Acl0000000T00003Acl0000000P00003Acl0000002/00003Acl0000002/00003Acl0000001@0
0003Acl0000001l00003Bcl0000001l00003Bcl0000001@00003Bcl0000001@00003Bcl0000000/0
0003Bcl0000001`00003Bcl0000000P00003Bal0000000T00003Cah0000000P00003Cah0000001@0
0003Cah0000000/00003Cah0000000H00003Cah0000000/00003Cah0000000h00003Cah0000001@0
0003Cah0000001@00003Cah0000001@00003Cah0000000h00003Dah0000000H00003Dah0000000/0
0003Dah0000000l00003Dah0000000h00003Dah0000000T00003Dah0000000<00003Dch0000000T0
0003Dch0000000/00005Dch00000001C?P0:00000e<n0000000F00000e=N0000000900000e=O0000
000A00000e=O0000000B00000e=o00000005000015=o000000000Woo00<007ooOol0BGoo001TOol0
0`00Oomoo`1[Ool500000dLo0000000800000dLo0000000900000dLo0000000900000dLo00000008
00000dLo0000000[00000dLo0000000900000dLo0000000800000dLo0000000900000dLo0000000[
00000dLo0000000800000dLo0000000900000dLo0000000O00000dLo0000000900000dLo0000000O
00000dLo0000000D00000dLo0000000D00000dLo0000000O00000d/o0000000900000d/o0000000C
00000d/o0000000D00000d/o0000000O00000d/o0000000A00000d/o0000000;00000d/o0000000D
00000d/O0000000;00000dlN0000000`00000dlN0000000D00000dlN0000000;00000dlN0000000;
00000dlN0000000600000dlN0000000;00000dlN0000000600000dlN0000000;00000dlN00000006
00000dlN0000000;00000dlN0000000300000e<N0000000D00000e<N0000000>00000e<N00000009
00000e<N0000000300000e<N0000000900000e<N0000000>00000e<n0000000>00000e<n0000000:
00000e<n0000000G00000e=N0000000900000e=O0000000B00000e=O0000000A00000e=o00000005
00000e=o000000050003Ool00`00Oomoo`18Ool006Aoo`03001oogoo06aoo`H00003Acl0000002X0
0003Acl0000000T00003Acl0000001@00003Acl0000000T00003Acl0000002X00003Acl0000000T0
0003Acl0000000T00003Acl0000000P00003Acl0000001@00003Acl0000000P00003Acl0000000T0
0003Acl0000000T00003Acl0000001<00003Acl0000000T00003Acl0000001l00003Acl0000001l0
0003Acl0000000T00003Acl0000001l00003Bcl0000000P00003Bcl0000001l00003Bcl0000001@0
0003Bcl0000000P00003Bcl0000003<00003Cah0000000/00003Cah0000001@00003Cah0000000P0
0003Cah0000000/00003Cah0000000H00003Cah0000000/00003Cah0000000h00003Cah0000000<0
0003Cah0000000h00003Cah0000001@00003Cah0000001@00003Cah0000000h00003Dah0000000H0
0003Dah0000000/00003Dah0000000<00003Dah0000000T00003Dah0000000h00003Dah0000000l0
0003Dch0000000h00003Dch0000000T00003Dch0000000T00003Dch0000000T00003Dch000000080
0003Deh0000000@00003Deh0000000800003Del0000000@00003Deh0000000H00005Del00000001C
G`0C00000e=o0000000600000e=o00000005000015=o000000000Woo00<007ooOol0B7oo001TOol0
0`00Oomoo`1^Ool@00000dLo0000000900000dLo0000000800000dLo0000000900000dLo0000000f
00000dLo0000000900000dLo0000000800000dLo0000000900000dLo0000000O00000dLo00000009
00000dLo0000000800000dLo0000000[00000dLo0000000900000dLo0000000C00000dLo00000009
00000dLo0000000C00000dLo0000000900000dLo0000000O00000d/o0000000D00000d/o0000000C
00000d/o0000000900000d/o0000000800000d/o0000000Z00000d/o0000000D00000d/O00000008
00000dlN0000000D00000dlN0000000;00000dlN0000000I00000dlN0000000300000dlN0000000>
00000dlN0000000;00000dlN0000000600000dlN0000000;00000dlN0000000;00000dlN00000006
00000dlN0000000;00000dlN0000000600000e<N0000000;00000e<N0000000300000e<N0000000D
00000e<N0000000>00000e<N0000000900000e<N0000000300000e<N0000000>00000e<N00000009
00000e<n0000000300000e<n0000000900000e<n0000000900000e<n0000000900000e<n00000009
00000e=N0000000900000e=N0000000800000e=O0000000E00001E=o00000000Dgl00`0000=CO`00
00001@0000=CO`0000001@000goo00<007ooOol0Agoo000DOol4000>Ool3000:Ool<0009Ool6000F
Ool00`00Oomoo`1^Ool600000dLo0000000[00000dLo0000000D00000dLo0000000900000dLo0000
000800000dLo0000000[00000dLo0000000D00000dLo0000000900000dLo0000000C00000dLo0000
000900000dLo0000000800000dLo0000000[00000dLo0000000O00000dLo0000000900000dLo0000
000C00000dLo0000000D00000d/o0000000O00000d/o0000000Z00000d/o0000000800000d/o0000
000900000d/o0000000800000d/O0000000Z00000dlN0000000A00000dlN0000000;00000dlN0000
000800000dlN0000000600000dlN0000000;00000dlN0000000;00000dlN0000000600000dlN0000
000;00000dlN0000000>00000dlN0000000<0003Cah500000dlN0000000D00000e<N0000000>0000
0e<N000000060003Dah;00000e<N0000000300000e<N0000000900000e<N0000000>00000e<N0000
000300000e<N0000000900000e<n0000000?00000e<n0000000800000e<n0000000:00000e<n0000
000900000e<n0000000900000e=N0000000900000e=N0000000A00000e=o0000000600000e=o0000
000900000e=o00000005000015=o000000000Woo00<007ooOol0Agoo000BOol8000;Ool50009Ool<
0007Ool:000DOol00`00Oomoo`1`Ool500000dLo0000000900000dLo0000000800000dLo00000009
00000dLo0000000900000dLo0000000Z00000dLo0000000900000dLo0000000800000dLo00000009
00000dLo0000000f00000dLo0000000900000dLo0000000C00000dLo0000000900000dLo00000008
00000dLo0000000D00000dLo0000000800000dLo0000000900000dLo0000000O00000dLo00000008
00000dLo0000000O00000d/o0000000900000d/o0000000C00000d/o0000000800000d/o0000000D
00000d/o0000000;00000d/o0000000L00000d/N0000000800000dlN0000000D00000dlN00000008
00000dlN0000000;00000dlN0000000A00000dlN0000000;00000dlN0000000>00000dlN0000000D
00000dlN0000000;0003Cah;0003Cah01000Cai?7TlN400000=C7P0000001P000e<N2`0000=C7P00
00000`0000=C7P0000000`000e<N00<005<NDah02`0000=C7P0000003P0000=C7P0000002@0000=C
7P0000000`0000=C7P0000003P0000=C7P0000006`0000=C?P0000002`0000=C?P0000002@0000=C
?P0000002@0000=CGP0000002@0000=CGP0000004P0000=CO`0000001@0000=CO`0000001@0000EC
O`00000005=o00L00003Dgl0000000D000=oo`03001oogoo04Ioo`004Woo0P0017oo0P002goo1@00
2Woo0`001Woo0P001goo0`001Goo0`004goo00@007ooOomoo`@006aoo`H00003Acl0000003H00003
Acl0000000T00003Acl0000000P00003Acl0000000T00003Acl0000002X00003Acl0000000T00003
Acl0000003H00003Acl0000001l00003Acl0000001@00003Acl0000001@00003Acl0000000P00003
Acl0000001@00003Acl0000000P00003Bcl0000000P00003Bcl0000000T00003Bcl0000002X00003
Bcl0000000P00003Bcl0000001`00003Bcl0000000/00003Bal0000000/00003Bah0000000H00003
Cah0000000P00003Cah0000000/00003Cah0000001T00003Cah0000000/00003Cah0000001400003
Cah0000000/00003Cah0000000/00003Cah0000000H00003Cah0000000/000=?7P03001?7TlN00D0
0003Cah0000000<000A?7Pd00003Dah0000000<00003Dah0000000<0009C7P04001C7U<NDah;0000
0e<N000000090003Dah=00000e<N0000000900000e<N0000000300000e<N0000000900000e<N0000
000>00000e<N0000000300000e<N0000000>00000e<n0000000600001E<n00000000Dch03`0000=C
?P0000002@0000=C?P0000002@0000=CGP0000002@0000=CGP0000003@0000ECG`00000005=O00L0
0003Dgl0000000H00003Dgl0000000T00005Dgl00000001CO`03000015=o000000000Woo00<007oo
Ool0AWoo000AOol20006Ool2000:Ool5000;Ool3000GOol2000COol4001bOol500000dLo0000000D
00000dLo0000000900000dLo0000000800000dLo0000000900000dLo0000000O00000dLo00000008
00000dLo0000000900000dLo0000000800000dLo0000000900000dLo0000000C00000dLo00000009
00000dLo0000000D00000dLo0000000C00000dLo0000000900000dLo0000000O00000dLo0000000O
00000dLo0000000O00000d/o0000000O00000d/o0000000800000d/o0000000Z00000d/o00000008
00000d/o0000000900000d/O0000000@00000d/N0000000300000dlN0000000I00000dlN0000000;
00000dlN0000000800000dlN0000000;00000dlN0000000600000dlN0000000800000dlN0000000;
00000dlN0000000>00000dlN0000000D0003Cah800000dlN0000000D00000e<N000000090003Dah=
00000e<N0000000900000e<M0000000>00000e<N0000000900000e<N0000000>00000e<N0000000?
00000e<N0000000>00000e<N0000000300000e<n0000000800000e<n0000000:00000e<n0000000;
00001E<n00000000Dch01`0000EC?P00000005<n00L00005Deh00000001CGP0@00000e=O00000009
00000e=o0000000500000e=o0000000500001E=o00000000Dgl0100000=CO`00000020000goo00<0
07ooOol0AGoo000AOol20006Ool2000;Ool3000=Ool3000GOol2000BOol00`00Oomoo`1dOol60000
0dLo0000000800000dLo0000000[00000dLo0000000800000dLo0000000900000dLo000000080000
0dLo0000000900000dLo0000000O00000dLo0000000800000dLo0000000900000dLo0000000O0000
0dLo0000000800000dLo0000000900000dLo0000000C00000dLo0000000900000dLo0000000C0000
0dLo0000000900000dLo0000000C00000dLo0000000900000d/o0000000C00000d/o0000000D0000
0d/o0000000C00000d/o0000000800000d/o0000000900000d/o0000000800000d/o0000000N0000
0d/N0000000600000dlN0000000;00000dlN0000000800000dlN0000000;00000dlN0000000I0000
0dlN0000000300000dlN0000000I00000dlN0000000;00000dlN0000000;00000dlN000000060003
Cah800000dlN0000000;00000e<N0000000600000e<N0000000;00000e<M0000000>00000e<N0000
000900000e<M0000000;0003Dad;00000e<M0000000900000e<M0000000300000e<N0000000>0000
0e<N0000000900000e<N0000000300000e<N0000000>00000e<n0000000:00000e<n0000000=0000
0e<n0000000900000e<n0000000900000e=N0000000A00000e=N0000000500001E=O00000000Del0
400000=CO`0000003@0000ECO`00000005=o00<0009oo`03001oogoo04Eoo`0047oo0P0027oo0P00
6goo0`005Woo0P004Woo00<007ooOol0MWoo400000=7?`0000002@0000=7?`000000200000=7?`00
00002@0000=7?`000000200000=7?`000000:`0000=7?`000000200000=7?`0000002@0000=7?`00
0000200000=7?`000000500000=7?`000000200000=7?`0000002@0000=7?`000000200000=7?`00
0000500000=7?`000000200000=7?`0000002@0000=7?`0000004`0000=7?`0000002@0000=7?`00
00004`0000=7?`0000002@0000=7?`0000004`0000=;?`000000200000=;?`0000007`0000=;?`00
0000200000=;?`000000:P0000=;7`000000200000=;7P000000200000=;7P0000009`0000=?7P00
00002`0000=?7P000000200000=?7P0000001P0000=?7P0000002`0000=?7P000000200000=?7P00
00002`0000=?7P0000003P0000=?7P0000000`000dlN00<004lNCah01@0000=?7P0000003P0000=C
7P000000500000=C7@0000002`0000=C7@0000002`0000=C7@0000002@000e<M00<005<MDad01@00
00=C7@0000000`0000=C7@0000002@0000=C7@0000003P0000=C7@0000000`0000=C7P0000002@00
00=C7P0000003P0000=C7P0000000`0000=C?P0000002`0000=C?P000000300000=C?P0000002@00
00=C?P0000007P0000=CGP0000001P0000=CG`0000008P0000=CO`00000020000goo00<007ooOol0
A7oo000@Ool20008Ool2000LOol3000EOol2000BOol00`00Oomoo`1gOol500000dLo000000090000
0dLo0000000Z00000dLo0000000900000dLo0000000800000dLo0000000900000dLo000000080000
0dLo0000000O00000dLo0000000900000dLo0000000800000dLo0000000O00000dLo0000000D0000
0dLo0000000O00000dLo0000000O00000dLo0000000Z00000d/o0000000C00000d/o0000000D0000
0d/o0000000C00000d/o0000000800000d/O0000000]00000dlN0000000500000dlN000000080000
0dlN0000000800000dlN0000000900000dlN0000000800000dlN0000000800000dlN0000000;0000
0dlN0000000I00000dlN0000000;00000dlN000000060003Cah800000dlN0000000;00000e<M0000
000;00000e;m000000060003Dad;00000e<M000000060003Dad500000e<M000000090003Dad80000
0e<M0000000>00000e<M0000000900000e<M0000000300000e<M0000000300000e<M000000080002
Dad:00000e<N0000000300000e<N0000000>00000e<n0000000200000e<n0000000:00000e<n0000
000900000e<n0000000P00000e=N0000000500000eMO0000000Z00001E=o00000000Dgl00`000Woo
00<007ooOol0A7oo000@Ool20008Ool2000MOol3000DOol2000BOol00`00Oomoo`1hOolA00000dLo
0000000800000dLo0000000900000dLo0000000800000dLo0000000900000dLo0000000Z00000dLo
0000000900000dLo0000000800000dLo0000000900000dLo0000000C00000dLo0000000D00000dLo
0000000900000dLo0000000C00000dLo0000000D00000dLo0000000800000dLo0000000800000dLo
0000000900000dLo0000000800000dLo0000000800000dLo0000000800000d/o0000000O00000d/o
0000000800000d/o0000000Z00000d/O0000000800000d/O0000000800000d/O0000000800000d/N
0000000800000dlN0000000600000dlN0000000;00000dlN0000000800000dlN0000000;00000dlN
0000000T00000dlN0000000;00000dlN0000000800000dlN0000000;00000dlN000000060003Cah8
00000dlN0000000;00000e;m0000000>00000e;m000000030003D_d00`00DaeC7@0500000e;m0000
000300000e<M000000030002D_d01000DaeC7E<M400000=C7@0000001P000e<M2`0000=C7@000000
0`0000=C7@0000002@0000=C7@0000002@000U<M2@000e<M2@000U<N100000=C7@000000200000=C
7P0000000`0000=C?P0000002`0000EC?P00000005<n00/00003Ech0000000P00003Ech0000000X0
0003Eeh0000000D00005Eeh00000001GGP0e00000e=o000000090002Ool00`00Oomoo`13Ool0011o
o`8000Qoo`8001ioo`<001=oo`80019oo`03001oogoo07Uoo`H00003Acl0000000T00003Acl00000
02X00003Acl0000000P00003Acl0000000T00003Acl0000000P00003Acl0000000T00003Acl00000
01l00003Acl0000000P00003Acl0000000T00003Acl0000002X00003Acl0000001l00003Acl00000
00P00003Acl0000001l00003Acl0000000P00003Acl0000001<00003Bcl0000000T00003Bcl00000
00P00003Bcl0000000P00003Bcl0000000P00003Bcl0000000P00003Bcl0000002800003Bal00000
00D00003Bah0000000P00003Cah0000000P00003Cah0000002L00003Cah0000000/00003Cah00000
00P00003Cah0000000P00003Cah0000000/00003Cah0000001T00003Cah0000000<000=>o@03001?
7TlN00D00003C_d0000000h00003D_d0000000/000=Bo@H000=Bo@P00003D_d0000000T000=Bo@d0
0003D_d0000000<00003Dad0000000<000=Bo@03001C7E<M00D00003Dad0000000<00003Dad00000
00h00003Dad0000000T000=C7@03001C7@0000800004Dad000000002Dad00`00DaeC7@070002Dad0
0`00Dah0000200000e<M0000000700000e<N0000000>00000e<n0000000200000e<n0000000F0000
0eLn0000000D00000eMN0000000I00001EMo00000000Egl01`0000=CO`0000005P0000=CO`000000
1@000Woo00<007ooOol0@goo000@Ool20008Ool2000OOol3000AOol2000COol00`00Oomoo`1kOolL
00000dLo0000000D00000dLo0000000D00000dLo0000000O00000dLo0000000800000dLo00000009
00000dLo0000000800000dLo0000000O00000dLo0000000D00000dLo0000000C00000dLo00000009
00000dLo0000000C00000dLo0000000O00000dLo0000000C00000d/o0000000Z00000d/o00000008
00000d/o0000000C00000d/O0000000800000d/O0000000600000d/O0000000/00000dlN00000008
00000dlN0000000800000dlN0000000;00000dlN000000060003CahK00000dlN0000000;0003C_h8
00000dkn000000060003C_d800000dkm0000000;00000e;m0000000;0003D_d00`00D_eBo@050000
0e;m0000000600000e;m0000000;00000e;m0000000>00000e;m000000090003D_d800000e<M0000
000>00000e<M0000000300000e<M0000000300000e<M000000030006Dad4000015<M000000000e<M
200015<M100000=C7@0000001@0000=C7@000000200000=C7P0000000`0000=C?P0000002`0000EG
?P00000005Ln00L00005Ech00000001G?P0700001ELn00000000Ech01`0000EGGP00000005MN01<0
0003Eel0000000H00003Egl0000000T00003Dgl0000000D00003Dgl0000000h00003Dgl0000000T0
009oo`03001oogoo049oo`0047oo0P0027oo0P0087oo0P002Goo0P001Goo0`004Woo00<007ooOol0
OGoo1P0000=7?`000000200000=7?`0000002@0000=7?`000000:P0000=7?`000000200000=7?`00
00002@0000=7?`000000200000=7?`0000002@0000=7?`0000004`0000=7?`000000500000=7?`00
00007`0000=7?`000000200000=7?`0000002@0000=7?`0000004`0000=7?`0000004`0000=7?`00
00002@0000=7?`0000004`0000=;?`000000200000=;?`0000004`0000=;?`0000002@0000=;?`00
00007P0000=;7`000000200000=;7`000000200000=;7`000000200000=;7P000000200000=?7P00
0000200000=?7P000000<P0000=?7P0000000`000TlN00@004lNCai?7Pd00003Cah0000000P00003
Cah0000000/000=>oP03001>oTkn00D00003C_d0000000H00003C_d0000000P00003C_d0000000/0
0003D_d0000000H000=Bo@D000=Bo@P00003D_d0000001@00003D_d0000000/000=Bo@/00003D_d0
000000H000=Bo@/00003D_d0000000<00003Dad0000000T0009C7@@0009C7@04001C7E<MDad:0000
0e<M0000000300000e<M000000020002Dad=00000e<M000000070002Dah400000eLN0000000=0000
0eLn0000000900000eLn0000000900000eLn0000000900000eMN0000000E00000eMO000000050000
0eMo0000000500001EMo00000000Egl01`0000=CO`0000005P0000=CO`0000001@000Woo00<007oo
Ool0@Woo000@Ool20008Ool2000QOol20008Ool9000COol00`00Oomoo`1oOolL00000dLo00000008
00000dLo0000000900000dLo0000000800000dLo0000000f00000dLo0000000800000dLo00000009
00000dLo0000000N00000dLo0000000900000dLo0000000800000dLo0000000O00000dLo0000000C
00000dLo0000000900000dLo0000000C00000dLo0000000800000d/o0000000800000d/o00000008
00000d/o0000000N00000d/o0000000900000d/O0000000Y00000d/N0000000800000dlN00000008
00000dlN0000000;00000dlN0000000500000dlN0000000800000dlN0000000800000dlN00000006
0003Cah=00000dlN0000000I0003C_h800000dkm0000000300000dkm000000060003C_d@00000e;m
000000030002D_d01000D_eBoE;m3@0000=Bo@0000002`0000=Bo@0000001P000e;m2`000e;m00<0
05;mD_d01@0000=Bo@0000000`0000=Bo@0000000`000U;m00@005;mD_eBo@/00003D_d0000000h0
00=Bo@03001C7@00008000AC7A400003Dad0000000h00003Dad0000000800003Dad0000000D0009G
7@03001C7P0000800003Eah0000000`00003Ech0000000X00003Ech0000000T00003Ech0000000T0
0003Eeh0000001400005Eeh00000001GGP0700000eMo0000000600000eMo0000000900000e=o0000
000500000e=o0000000>00000e=o000000090002Ool00`00Oomoo`11Ool0011oo`8000Qoo`80025o
o`8000Qoo`800003Ool0000000<001Aoo`03001oogoo081oo`D00003Acl0000000T00003Acl00000
00P00003Acl0000000T00003Acl0000001h00003Acl0000000T00003Acl0000000P00003Acl00000
00T00003Acl0000000P00003Acl0000001l00003Acl0000001@00003Acl0000001<00003Acl00000
01@00003Acl0000000P00003Acl0000000P00003Acl0000001l00003Acl0000000P00003Bcl00000
00P00003Bcl0000000P00003Bcl0000000P00003Bcl0000000P00003Bcl0000000P00003Bcl00000
01h00003Bal0000000P00003Bah0000003800003Cah0000000/00003Cah0000000P00003Cah00000
00P00003Cah0000001000003Cah0000000<00003C_h0000000D00003C_h0000000P00003C_d00000
00P00003C_d0000000H00003C_d0000000<0009>o@04001>oDkmC_d=00000e;m000000060003D_d=
00000e;m000000060003D_d500000e;m000000030003D_d00`00D_eBo@0500000e;m000000030003
D_d800000e;m000000090003D_d=00000e;m0000000900000e;m000000030006D_d40002Dad@0000
0e<M0000000900000e<M0000000300000e<M0000000;0004Ead400000eLN0000000:00000eLn0000
000;00000eLn0000000E00000eMN0000000B00000eMN0000000900000eMo0000000A00000eMo0000
000N00000e=o000000050002Ool00`00Oomoo`11Ool0015oo`8000Ioo`8001Uoo`8000Moo`8000Qo
o`8001Yoo`03001oogoo085oobP00003Acl0000000P00003Acl0000000T00003Acl0000000P00003
Acl0000002X00003Acl0000001@00003Acl0000001l00003Acl0000000P00003Acl0000001l00003
Acl0000000P00003Acl0000000P00003Acl0000003D00003Bcl0000001<00003Bcl0000000P00003
Bcl0000000P00003Bcl0000000P00003Bal0000000P00003Bal0000000P00003Bal0000001<00003
Cah0000000P00003Cah0000000P00003Cah0000000P00003Cah0000000/00003Cah0000002H00003
Cah0000000H00003C_h0000000/000=>o@P00003C_d0000000P00003C_d0000000H000=>o@d00003
D_d0000000H000=BoA000003D_d0000000<0009Bo@04001BoE;mD_d;0003D_d800000e;m0000000;
0003D_d;00000e;m000000060003D_d500000e;m0000000900000e;m000000030002D_d01000D_eB
oE;m400000=C7@0000000`0000=C7@0000002@0000=C7@0000003P0000=G7@0000000P000ULM3@00
00EG7@00000005LM00X00003Ech0000000800003Ech0000000T00003Ech0000000T00003Eeh00000
00d00005Eeh00000001GGP0;00000eMN0000000R00000e=o0000000>00000e=o000000090002Ool0
0`00Oomoo`10Ool0015oo`8000Ioo`8001Uoo`<000Ioo`8000Qoo`8001Yoo`03001oogoo089oo`H0
0003Acl0000001@00003Acl0000003D00003Acl0000000T00003Acl0000000P00003Acl0000000T0
0003Acl0000001h00003Acl0000000T00003Acl0000000P00003Acl0000001<00003Acl0000000T0
0003Acl0000001<00003Acl0000001<00003Acl0000001<00003Acl0000000T00003Bcl0000001<0
0003Bcl0000000P00003Bcl0000001<00003Bal0000000P00003Bal0000000P00003Bal0000001<0
0003Bah0000000P00003Cah0000000P00003Cah0000000P00003Cah0000001000003Cah0000000<0
0003Cah0000000D00003Cah0000000P00003Cah0000000P00003C_h0000000P00003C_h0000000/0
00=>o@03001>oDkm00D00003C_d0000000H000=>oA/00003D_d0000000<0009Bo@04001BoE;mD_d=
00000e;m000000060003D_d=00000e;m000000060003D_d;0003D_d00`00D_eBo@0500000e;m0000
000300000e;m000000030002D_d01000D_eBoE;m400000=Bo@00000010001E;m2`0000=Bo@000000
0`0000=C7@0000003P0000=C7@0000003`0000=G7@0000003P0000=G7@0000000P0000=G7@000000
2P0000=G?P0000002`0000EG?P00000005Ln00L00005Ech00000001G?P0700000eMN000000060000
0eMN0000000U00000eMo0000000R00000e=o000000050002Ool00`00Oomoo`10Ool0019oo`8000Ao
o`8001Yoo`@000Aoo`8000Uoo`8001Yoo`03001oogoo08Aoo`H00003Acl0000001h00003Acl00000
00T00003Acl0000000P00003Acl0000000T00003Acl0000000P00003Acl0000002X00003Acl00000
01@00003Acl0000001<00003Acl0000001@00003Acl0000001<00003Acl0000001<00003Acl00000
01<00003Acl0000000T00003Bcl0000001h00003Bcl0000001h00003Bal0000002400003Bah00000
00D00003Cah0000002P00003Cah0000000H00003Cah0000003@000=>o@P00003C_d0000000<0009>
o@04001>oDkmC_d=0003D_d800000e;m000000060003D_d=00000e;m000000060003D_d@00000e;m
000000030003D_d00`00D_eBo@0500000e;m000000030003D_d800000e;m000000090003D_d=0000
0e;m0000000300000e;m000000030003D_d00`00D_eBo@0500000e;m0000000300000e;m0000000>
00000e;m0000000300000e<M0000000300000eLM000000080002Ead:00000eLM0000000300000eLM
0000000;00001ELM00000000Ead02P0000=G?P0000000P0000=G?P0000002@0000=G?P0000002@00
00=GGP0000001@0000=GGP0000004@0000EGG`00000005Mo00L00003Egl0000000H00003Egl00000
01400003Dgl0000000h00003Dgl0000000T0009oo`03001oogoo03moo`004Woo20006goo20002Woo
2P004Woo00<007ooOol0QWoo1@0000=7?`000000200000=7?`0000002@0000=7?`000000200000=7
?`000000=@0000=7?`0000002@0000=7?`000000200000=7?`0000002@0000=7?`0000004`0000=7
?`000000200000=7?`0000007`0000=7?`000000200000=7?`0000004`0000=7?`0000004`0000=7
?`0000002@0000=7?`0000004P0000=;?`0000007P0000=;?`0000007P0000=;7`000000200000=;
7P0000001P0000=;7P0000005@0000=?7P000000200000=?7P000000200000=?7P000000200000=?
7P0000002`0000=>oP0000001@0014kn1`0000=>oP000000200000=>o@000000200000=>o@000000
200000=>o@0000001P000dkm3@000e;m00<005;mD_d01@0000=Bo@0000006@0000=Bo@0000000`00
0U;m00@005;mD_eBo@d000=Bo@H000=Bo@P00003D_d0000000/000=Bo@/00003D_d0000000H000=B
o@D00003D_d0000000T000IBo@D00003D_d0000000h00003D_d0000000<00003D_d0000000<00003
D_d0000000<0009G7@T000=G7@T00003Ead0000000<00003Ead0000000P00003Ead0000000800003
Ead0000000X00003Ech0000000/00005Ech00000001G?P0700000eLn0000000900000eMN00000009
00000eMN0000000600000eMO0000000900000eMo0000000500000eMo0000000500000e=o0000000F
00001E=o00000000Dgl03`000Woo00<007ooOol0?goo000DOol4000OOol5000;Ool:000BOol00`00
Oomoo`27OolA00000dLo0000000N00000dLo0000000900000dLo0000000800000dLo0000000D0000
0dLo0000000Z00000dLo0000000800000dLo0000000900000dLo0000000700000dLo000000090000
0dLo0000000800000dLo0000000800000dLo0000000800000dLo0000000900000dLo000000070000
0dLo0000000N00000d/o0000000C00000d/o0000000800000d/o0000000C00000d/O000000080000
0d/O0000000800000d/N0000000800000d/N0000000800000dlN0000000800000dlN000000080000
0dlN0000000800000dlN0000000K00000dkn000000030002C_h01000C_i>oTkn3@000dkm200000=>
o@0000009P000e;m200000=Bo@0000002`000e;m200000=Bo@0000001P000e;m3@000e;m00<005;m
D_d01@0000=Bo@0000001P0000=Bo@0000002`000e;m00<005;mD_d01@0000=Bo@0000000`0000=B
o@0000000`000U;m00@005;mD_eBoA0000=Bo@04001BoE;mD_d@00000e;m0000000300000e;m0000
000300000e;m000000030002D_d40002E_d00`00Ead00002000015LM000000000ULM00<005LMEad0
1`0000=G7@0000000`000ULM2@0000=G7@0000002`0000EG7@00000005Lm00X00003Ech000000080
0003Ech0000000T00003Ech0000000T00003Eeh0000000T00005Eeh00000001GGP0300000eMN0000
000500001EMo00000000Egl0400000=CO`0000003@0000ECO`00000005=o00@00003Dgl0000000d0
0003Dgl0000000D0009oo`03001oogoo03ioo`00Hgoo00<007ooOol0R7oo4@0000=7?`0000002000
00=7?`0000002@0000=7?`000000200000=7?`000000200000=7?`0000007`0000=7?`0000002000
00=7?`0000002@0000=7?`000000200000=7?`000000:P0000=7?`000000200000=7?`0000002000
00=7?`000000200000=7?`0000007P0000=7?`0000004`0000=;?`0000004`0000=;?`0000002000
00=;?`0000004`0000=;7`000000200000=;7`000000200000=;7P0000007P0000=?7P000000:000
00=?7P000000200000=>oP0000001P000dkn3@000dkm00<004kmC_d01@0000=>o@0000001P000dkm
1`0000=>o@000000200000=>o@000000200000=Bo@000000200000=Bo@0000002`000e;m00<005;m
D_d01@0000=Bo@0000001P000e;m40000e;m200000=Bo@0000000`0000=Bo@0000001P000e;m1@00
0e;m200000=Bo@0000002@001E;m2`0000=Bo@0000000`001U;m2`0000=Bo@0000000`0000=Bo@00
00000`0000=Bo@0000000`000U;m10000UKm00<005;m00000P0015Km100000AG7@00000000=G7@P0
0003Ead000000080009G7@03001G7@0000H00003Ead0000000d00003Ead0000000X00003Ech00000
00h00003Ech0000000H00005Eeh00000001GGP0700001EMN00000000Eeh0100000=GGP0000002@00
00=GO`0000004@0000=GO`0000001@0000=CO`0000001P0000=CO`0000001@0000=CO`0000001@00
00=CO`0000001P0000=CO`00000020000Woo00<007ooOol0?Woo001SOol00`00Ool000020027Ool6
00000dLo0000000D00000dLo0000000N00000dLo0000000900000dLo0000000800000dLo0000000D
00000dLo0000000C00000dLo0000000800000dLo0000000900000dMO0000000800000dLo0000000C
00000dLo0000000C00000dLo0000000C00000dLo0000000C00000dLo0000000C00000d/o00000008
00000d/o0000000C00000d/O0000000800000d/O0000000800000d/O0000000B00000d/N00000009
00000dlN0000000B00000dlN0000000800000dlN0000000800000dlN0000000800000dkn00000008
00000dkn0000000@0003C_d800000dkm000000030002C_d01000C_e>oDkm3@000dkm20000dkm2000
00=Bo@00000040000e;m200000=Bo@0000000`000U;m00@005;mD_eBo@D00003D_d0000000D000AB
o@L00003D_d0000000H00003D_d0000000<0009Bo@04001BoE;mD_d=0003D_d;0003D_d00`00D_eB
o@0500000e;m0000000300000e;m000000030002D_d01000D_eBoE;m2`0000=Bo@0000002@000U;m
10000U;m00<005;m00000P0015Km10000UKm2P0000=G7@0000000`0000=G7@0000000P0000AG7@00
000000=G7@P00003Ead0000000`0009G7@/00003Ecd0000000h00003Ech0000001@00003Eeh00000
01T00003Egl0000001800005Dgl00000001CO`0D00000e=o0000000=00000e=o000000050002Ool0
0`00Oomoo`0mOol006=oo`8008aooa`00003Acl0000000P00003Acl0000001@00003Acl0000000P0
0003Acl0000001l00003Acl0000000P00003Acl0000001@00003Ael0000000P00003@el0000000P0
0003Acl0000000P00003Acl0000001<00003Acl0000001<00003Acl0000001<00003Acl0000000T0
0003Bcl0000000L00003Bcl0000000P00003Bcl0000000P00003Bcl0000000P00003Bal0000000P0
0003Bal0000001d00003Bah0000001h00003Cah0000000P00003Cah0000000P00003Cah0000002P0
0003C_d0000000P00003C_d0000000H000=>o@d000=>o@03001>oDkm00D000=>o@03001>oDkm00D0
0003D_d0000000H000=Bo@L000ABo@L00003D_d0000000H000=Bo@P00003D_d0000000<0009Bo@04
001BoE;mD_d=0003D_d60003D_d=0003D_`00`00D_eBo@0500000e;m000000030003D_d800000e;m
000000090005D_d;00000e;m000000090003D_d00`00D_d000020004D_d40002E_d@00000eKm0000
000300000eLM0000000800000eLM0000000300000eLM0000000200000eLM0000000:0003Ead;0000
0eLm0000000=00000eLn0000000500001ELn00000000Ech01`0000EGGP00000005MN01`00003Egl0
000001400003Dgl0000000800003Dgl0000001400003Dgl0000000h00003Dgl0000000T0009oo`03
001oogoo03aoo`00Hgoo00<007ooOol0S7oo1P0000=7?`000000200000=7?`000000500000=7?`00
00007P0000=7?`000000500000=7?`000000200000=7?`0000002@0000=7?`0000007P0000=7?`00
0000200000=7?`0000002@0000=7?`0000001`0000=7?`0000002@0000=7?`0000001`0000=7?`00
00002@0000=7?`0000001`0000=7?`0000002@0000=7?`0000004P0000=;?`000000200000=;?`00
0000200000=;7`000000200000=;7`0000004P0000=;7P000000200000=;7P0000004`0000=?7P00
0000200000=?7P000000200000=?7P0000007@0000=>oP000000200000=>oP000000200000=>o@00
0000200000=>o@000000200000=>o@00000040000dkm20000dkm200000=Bo@0000000`000U;m00@0
05;mD_eBo@D0009Bo@04001BoE;mD_d=0003D_d800000e;m000000060003D_d=0003D_`00`00D_eB
o@0500000e;l000000060003D_`50003D_`800000e;m0000000;0003D_`;0003D_`00`00D_eBo@05
00000e;l0000000300000e;m000000090006D_d40002D_d@00000eKm0000000300000eKm00000003
00000eKm0000000800000eLM0000000300000eLM0000000;000015LM000000000ULM00<005LMEad0
2`0000=G?@0000005@0000=G?P0000002@0000=GGP0000006@0000EGO`00000005Mo00L00003Egl0
000001H00003Dgl0000001X00003Dgl0000000D00003Dgl0000000D0009oo`03001oogoo03aoo`00
Hgoo00<007ooOol0SWoo9`0000=7?`000000200000=7?`000000500000=7?`000000200000=7?`00
0000:P0000=7G`000000200000=7?`000000500000=7?`0000004`0000=7?`0000004`0000=7?`00
00004`0000=7?`0000004P0000=;?`000000200000=;?`000000200000=;7`000000200000=;7`00
00004P0000=;7`000000200000=;7P000000200000=;7P000000200000=?7P000000200000=?7P00
00007@0000=>oP000000200000=>oP000000200000=>oP000000200000=>o@000000:00000=>o@00
0000200000=>o@000000200000=Bo@0000001P000e;m20000e;m3@000e;m00<005;mD_d01@0000=B
o@0000001P000e;m20000e;m1@000e;l200000=Bo00000000`000U;l00@005;lD_aBo0d000=Bo0/0
00=Bo003001Bo5;l00D00003D_`0000000<000IBo0D00003D_`0000000h000=Bo004001BoE;mD_d@
00000eKm0000000300000eKm0000000300000eKm000000030002E_d90003Ead300000eLM00000008
00000eLM00000002000015LM000000000eLM200000EG7@00000005LM00L00005Ecd00000001G?@07
00001ELn00000000Ech01`0000EG?P00000005MN00/00003Eeh0000000D00005Eeh00000001GGP04
00000eMo0000000900000eMo0000000F00000e=o0000000=00001E=o00000000Dgl0400000=CO`00
000020000goo00<007ooOol0>goo001SOol00`00Oomoo`2?Ool500000dLo0000000900000dLo0000
000800000dLo0000000800000dLo0000000900000dLo0000000N00000dLo0000000800000dLo0000
000900000dLo0000000800000dLo0000000D00000dLo0000000C00000dLo0000000800000dLo0000
000C00000dLo0000000C00000dLo0000000B00000d/o0000000C00000d/O0000000800000d/O0000
000B00000d/O0000000800000d/N0000000C00000d/N0000000800000dlN0000000B00000dlN0000
000800000dkn0000000800000dkn0000000800000dkn0000000M00000dkm0000000800000dkm0000
000800000dkm0000000800000dkm0000000800000e;m0000000V0003D_d800000e;m000000030002
D]`01000D_eBoE;m1@000U;L00@005;mD_eBo@d000=Bg0H000=Bo0d000=Bg003001Bo5;l00D00003
D_`0000000<000IBo0D00003D_`0000000<0009Bo004001Bo5;lD_`@00000e;l000000030006D_`;
00000eKl0000000300000eKm0000000300000eKm000000030002E_d40002E_d00`00E_d000020000
15Km000000000UKm00<005LMEad030000eLM0`0000=G7@0000000P0000=G7@0000000`0000=G7@00
00000P0000=G7@0000002@0000=G?@0000002@0000=G?P0000002@0000=G?P000000300000=GGP00
00001P0000=GGP0000004@0000=GO`0000001@0000=GO`0000005P0000=CO`0000001P0000=CO`00
00004@0000=CO`0000001@0000ECO`00000005=o00<0009oo`03001oogoo03]oo`00Hgoo00<007oo
Ool0T7oo1P0000=7?`000000:P0000=7?`000000200000=7?`000000200000=7?`0000002@0000=7
?`000000200000=7?`000000=@0000=7?`000000200000=7?`000000200000=7?`000000200000=7
?`000000200000=7?`000000200000=7?`000000200000=7?`0000001`0000=7?`0000004`0000=;
?`000000200000=;7`0000004P0000=;7`000000200000=;7P0000004`0000=;7P000000200000=?
7P0000004P0000=?7P000000200000=>oP000000200000=>oP0000007@0000=>o@000000200000=>
o@00000020000dkm20000dkm20000dkm20000dkm20000e;m1`0015;m1`0015;m1`0000=Bo@000000
200000=Bg@0000001P000e;L20000e;L3@000e;L00<005;LD]`01@0000=Bg00000001P000e;L1@00
0e;L200000=Bo00000000`000U;L00@005;lD_aBo0/000=Bo0d00003D_`0000000<000=Bo0<0009B
o004001Bo5;lD_`;00000eKl0000000300000eKl000000030002E_d40002E_`00`00E_d000020004
E_d4000015Km000000000eKm200000AG7@000000009G7@03001G7ELM00`00003Ead0000000/00005
Ead00000001G7@0700001ELn00000000Ech01`0000EG?P00000005Ln00l00005Eeh00000001GGP03
00000eMN0000000J00000eMo0000000500000e=o0000000>00000e=o0000000=00000e=o0000000B
00000e=o000000080003Ool00`00Oomoo`0jOol0069oo`03001oogoo09=oo`D00003Acl0000000P0
0003Acl0000000T00003Acl0000000P00003Acl0000000P00003Acl0000000T00003Acl0000001h0
0003Acl0000000P00003Acl0000001@00003Acl0000000P00003Acl0000001<00003Acl0000000P0
0003Acl0000000P00003Acl0000000P00003Acl0000000P00003Acl0000001<00003Bcl0000000L0
0003Bcl0000000P00003Bal0000001800003Bal0000000P00003Bal0000000P00003Bah0000000P0
0003Bah0000001d00003Cah0000000P00003C_h0000001d00003C_h0000000P000A>o@L000=>o@P0
00E>o@03001>oDkm00D000=>o@03001>oDkm00D0009>o@04001>oDkmC_d50002C_d01000C_e>oDkm
1@000U;m00@005;mD_eBo@D0009Bo@04001BoE;mD_d50002D]d01000D_eBoE;m3@000e;L20000e;L
20000e;L40000e;L200000=Bg00000000`000U;L00@005;LD]aBg0d000=Bg0H000=Bg0d00003D]`0
000000H000=Bo0D00003D_`0000000<0009Bo003001Bo5;l00<000=Bo0/00003E_`0000000@0009F
o0@0009Fo003001Fo@00008000AFo0@0009Fo@X00003E_d0000000<00003E_d0000000800004Ead0
00000003Ead800001ELM00000000Ead02P0000=G7@0000000P0000=G7@0000002@0000=G?P000000
2@0000=G?P000000300000EGGP00000005MN00@00003Eeh0000001d00003Egl0000001H00003Dgl0
000000h00003Dgl0000000d00005Dgl00000001CO`0700001E=o00000000Dgl00`000Woo00<007oo
Ool0>Woo001ROol00`00Oomoo`2DOol600000dLo0000000800000dLo0000000800000dLo0000000Z
00000dLo0000000800000dLo0000000800000dLo0000000900000dLo0000000800000dLo0000000N
00000dLo0000000C00000dLo0000000C00000dLo0000000C00000dLo0000000B00000d/O00000008
00000d/O0000000700000d/O0000000C00000d/N0000000800000d/N0000000B00000d/N00000008
00000dlN0000000800000dkn0000000B00000dkn0000000800000dkn000000080005C_d01000C_e>
oDkm1@000Tkm00<004kmC_d01@000dkm00<004kmC_d00Tkm20000dkm20000dkm20000dkm20000e;m
20000e;m20000e;M3@000e;L00<005;LD]`01@000U;L00@005;LD]aBg0D0009Bg004001Bg5;LD]`=
0003D]`80003D]`60003D]`=0003D]`00`00D]aBg00500000e;L000000060003D]`500000e;L0000
00030002D]`01000D_aBo5;l2`001E;l1@0000=Bo00000000`0000=Fo00000000`0000=Fo0000000
0`000eKl00<005Kl00000P0015Kl10000UKl400000=Fo@0000000`0000=Fo@000000200000=G7@00
00000`0000=G7@0000000P0000=G7@0000002P000eLM0`0000=G7@0000001@0000EG?@00000005Lm
00L00005Ech00000001G?P0?00000eMN0000000=00001EMN00000000Eeh01`0000=GO`0000006P00
00=CO`0000004P0000ECO`00000005=o00L00003Dgl0000000H00003Dgl0000000T00003Dgl00000
00P000=oo`03001oogoo03Uoo`00HWoo00<007ooOol0UWoo6`0000=7?`000000500000=7?`000000
200000=7?`000000200000=7?`000000:P0000=7?`000000200000=7?`000000500000=7?`000000
1`0000=7?`0000004`0000=7?`0000004`0000=7?`0000004P0000=;?`000000200000=;7`000000
4`0000=;7`0000001`0000=;7P000000200000=;7P0000004P0000=;7P000000200000=?7P000000
200000=?7P0000004P0000=>oP000000200000=>oP00000020001Dkm00<004kmC_d00dkm20000Tkm
20000dkm2P0000=>o@000000200000=>o@000000200000=>o@000000200000=Bo@0000009P000e;L
20000e;L20000e;L3@000e;L00<005;LD]`01@000e;L00<005;LD]`01@0000=Bg00000001P000e;L
1@001U;L1@0000=Bg00000000`000U;L00@005;LD]aBg0/000EBg0/000=Bg003001Bo5;l00D00003
E_`0000000<00003E_`0000000<00003E_`0000000<000EFo0D0009Fo1000003E_`0000000<00003
E_d0000000<00003E_d0000000P00003E_d0000000<00003Ead0000000<00003Ead0000000D00004
Ead000000002Ead00`00EaeG7@0;00000eLm0000000900000eLn0000000<00001ELn00000000Eeh0
400000=GGP0000002@0000=GO`0000003@0000=GO`0000006P0000=CW`0000000P0000=CO`000000
2@0000ECO`00000005=o00/00005Dgl00000001CO`0;000015=o000000000Woo00<007ooOol0>Goo
001ROol00`00Oomoo`2FOol600000dLo0000000D00000dLo0000000800000dLo0000000N00000dLo
0000000D00000dLo0000000800000dLo0000000D00000dLo0000000N00000dLo0000000700000dLo
0000000900000dLo0000000700000dLo0000000800000dLo0000000700000d/o0000000C00000d/O
0000000800000d/O0000000B00000d/N0000000800000d/N0000000700000d/N0000000800000d/N
0000000M00000dkn0000000800000dkn000000080005C_d00`00C_e>o@02C_dE00000dkm00000008
00000dkm0000000800000dkm0000000X00000e;M0000000800000e;L000000080003D]`80003D]`8
0003D]`@0003D]`80003D]`800000e;L000000030002D]`01000D]aBg5;L1@000U;L00@005;LD]aB
g0/000EBg0/000=Bg003001Bg5;L00D00003D]`0000000<000IBg0D00003E_`0000000T0009Fo0@0
009Fo003001Fo5Kl00D00003E_`0000000T00003E_`0000000<000=Fo0<00003E_`0000000<0009F
o@T000=Fo@<00003E_d0000000<0009G7@P00004Ead000000003Ead800001ELM00000000Ead02`00
00=G?@0000003@0000=G?P0000003@0000=GGP0000003@0000=GOP0000003P0000=GO`0000003@00
00=CO`0000003P0000=CW`0000001@0000ECO`00000005=o00@00003Dgl0000000T00003Dgl00000
01@000=oo`03001oogoo03Qoo`00HWoo00<007ooOol0V7oo1P0000=7?`0000007P0000=7?`000000
200000=7?`000000500000=7?`000000200000=7?`000000=@0000=7?`000000200000=7?`000000
4`0000=7?`0000004P0000=7?`0000004`0000=;7`0000001`0000=;7`000000200000=;7`000000
4P0000=;7P000000200000=;7P0000004P0000=;7P000000200000=?7P0000001`0000=>oP000000
200000=>oP000000200000=>oP00000020001Dkm00<004kmC_d00Tkm2P0000=>o@000000200000=>
o@000000200000=>o@0000007@0000=>g@000000200015;M1`0015;M1`000e;L20001E;L00<005;L
D]`01@000e;L00<005;LD]`01@000e;L00<005;LD]`01@0000=Bg00000001@0015;L1`0015;L1`00
15;L1@001U;L1@000e;L3@000e;L00<005;LD]`01@0000=Bg00000000`001U;L1@0000=Bg0000000
0`000U;L00@005;LD]aBg10000=Fg003001Fo000008000AFo0D00003E_`0000000<00003E_`00000
00<000=Fo0<0009Fo003001Fo5Kl00L0009Fo003001Fo@0000800004E_`000000002E_`00`00E_eF
o@070002E_d00`00Ead0000200001ELM00000000Ead0100000=G7@0000000`0000=G7@0000000P00
00=G7@000000300000=G?@0000002@0000EG?P00000005Ln00L00005Eeh00000001GGP0400000eMN
0000000M00000eMo0000000500000e=o0000000600000e=o0000000500000e>O0000000>00000e=o
0000000500000e=o0000000500001E=o00000000Dgl01`0000=CO`0000003@0000ACO`000000009o
o`03001oogoo03Qoo`00HWoo00<007ooOol0VWoo1@0000=7?`000000200000=7?`000000200000=7
?`0000002@0000=7?`000000200000=7?`000000200000=7?`0000007P0000=7?`000000500000=7
?`000000200000=7?`000000200000=7?`0000004`0000=7?`000000200000=7?`0000007@0000=;
7`0000004P0000=;7`000000200000=;7`0000001`0000=;7`000000200000=;7P0000004P0000=;
7P000000200000=;7P0000004P0000=>oP000000200000=>oP00000020001Dkn00<004kmC_d00Tkm
2P0000=>o@000000200000=>o@000000200000=>o@0000004P0000=>o@000000200014kM1`001E;M
00@005;MD]eBg@D0009Bg004001BgE;MD]d50002D]`00`00D]aBg0050003D]`00`00D]aBg002D]`8
0003D]`80003D]`800000e;L000000030002D]`01000D]aBg5;L1@000U;L00@005;LD]aBg0D0009B
g004001Bg5;LD]`50002D]`01000D]aBg5;L3@000e;L1@000e;L200000=Bg00000000`000U;L00@0
05;LD]aBg0/000EBg0/00003E]`0000000<000IFg0@0009Fo0/0009Fo0@0009Fo003001Fo5Kl00<0
00=Fo0P000AFo0@00004E_`000000003E_`80004E_d400000eLM0000000:00000eLM000000030000
0eLM0000000=00000eLm0000000900000eLn0000000900000eMN0000000I00000eMo0000000B0000
1E=o00000000Dgl0700000=CW`0000003P0000=CO`0000002@0000=CO`00000050000goo00<007oo
Ool0=goo001ROol00`00Oomoo`2KOolA00000dLo0000000Y00000dLo0000000800000dLo0000000D
00000dLo0000000800000dLo0000000800000dLo0000000Y00000dLo0000000800000dLo00000008
00000dLo0000000700000d/O0000000800000d/O0000000700000d/O0000000800000d/O0000000B
00000d/N0000000B00000d/N0000000800000d/N0000000B00000dkn0000000800000dkn00000008
0005C_h00`00C_i>oP02C_h:00000dkm0000000800000dkm0000000M00000dkm000000080005C]d0
1000C]e>gDkM1@000TkM00<005;MD]d00e;M20000e;L20000U;L20000e;L2P0000=Bg00000002000
00=Bg0000000200000=Bg00000001P000e;L20000e;L20000e;L20000e;L3@000U;L00@005;LD]aB
g0D00003D]`0000000D000ABg0D000EBg0/000=Bg003001Bg5;L00D00003E]`0000000<00003E]`0
000000<0009Fg004001Fg5KLE]`@0003E_`00`00E_`000020004E_`500000eKl0000000300000eKl
000000020002E_`:00000eKl0000000300000eKl000000020002E_d=00001ELM00000000Ead01@00
0ULM2`0000EG7@00000005Lm00L00005Ech00000001G?P0700001ELn00000000Ech04`0000=GGP00
00001P0000=GO`0000004@0000=CO`0000000P0000=CO`0000003@0000=CW`0000006P0000=CO`00
00002@0000=CO`0000001@0000=CO`0000004@000Woo00<007ooOol0=goo001ROol00`00Oomoo`2L
OolA00000dLo0000000800000dLo0000000800000dLo0000000800000dLo0000000900000dLo0000
000800000dLo0000000Y00000dLo0000000D00000dLo0000000M00000dLo0000000B00000d/O0000
000B00000d/O0000000B00000d/N0000000800000d/N0000000700000d/N0000000800000d/N0000
000B00000dkn0000000800000dkn0000000L00000dkm0000000800000dkm0000000B00000dkm0000
000800000dkm000000080005C]d00`00C]e>g@03C]d80002C]dP00000e;L000000080004D]`70003
D]`80003D]`80003D]`80003D]`80003D]`80003D]`80003D]`50003D]`800000e;L000000030002
D]`01000D]aBg5;L1@000U;L00<005;LD]`01@0000=Bg00000000`001U;L1@0000=Fg00000000`00
00=Fg00000000`001EKL2`0000=Fg00000000`001UKl10000UKl1@0000=Fo00000000`0000=Fo000
00000`0000=Fo0000000200000=Fo00000000`000eKl0`0000=Fo0000000200000=G7@0000000P00
00=G7@0000001@000ULM00<005LM00002P0000=G7@0000002@0000=G?P0000002@0000=G?P000000
5@0000EGGP00000005MN00<00003Egh0000000D00003Egl0000001H00003Dil0000000H00003Dil0
000000d00003Dil0000001h00005Dgl00000001CO`0C0002Ool00`00Oomoo`0fOol0069oo`03001o
ogoo09eoo`H00003Acl0000000P00003Acl0000001@00003Acl0000001h00003Acl0000000P00003
Acl0000000P00003Acl0000001@00003Acl0000000P00003Acl0000001<00003@cl0000000L00003
Acl0000000P00003Aal0000000L00003Bal0000003800003Bah0000001800003Bah0000001800003
B_h0000000P00003C_h00000018000E>oP03001>oDkm00=>o@X00003C_d0000001800003C_d00000
00P00003C_d0000000P000E>g@03001>gDkM00=>gA@00003D]`0000000P00003D]`0000000P000AB
g0L000EBg004001Bg5;LD]`50002D]`00`00D]aBg0050003D]`00`00D]aBg0050003D]`00`00D]aB
g0050002D]`01000D]aBg5;L1@000U;L00@005;LD]aBg0D0009Bg004001Bg5;LD]`50002D]`01000
D]aBg5;L3@000e;L1P001E;L1P000U;L200000=Bg00000000`000U;L00@005;LD]aBg0D00003E]`0
000000<0009Fg0@0009Fg003001Fg5KL00D00003E]`0000000<000=Fg0<0009Fg004001Fo5KlE_`5
00000eKl0000000300000eKl0000000300000eKl000000030002E_`90003E_`30002E_`00`00E_aF
o00<0002Ead400000eLM000000050003Ead800001ELM00000000Ead01`0000EG?@00000005Lm00L0
0005Ech00000001G?P0700001EMN00000000Eeh01`0000EGGP00000005MN00@00003Eeh0000000T0
0003Egl0000001H00003Dil0000000d00003Dil0000000H00005Dil00000001CW`0;00000e=o0000
000B00000e=o0000000D0002Ool00`00Oomoo`0fOol0069oo`03001oogoo09moo`H00003Acl00000
01h00003Acl0000000P00003Acl0000000P00003Acl0000000P00003Acl0000000T00003Acl00000
00P00003Acl0000001h00003Acl0000000P00003Acl0000003800003Bal0000001800003Bal00000
03400003Bah0000000P00003C_h0000001800003C_h0000001800003C_d0000001800003C_d00000
00P00003C_d0000000P000E>g@03001>gDkM009>gAD00003D]`0000000P000ABg0L000EBg004001B
g5;LD]`50002D]`00`00D]aBg003D]`80002D]`80003D]`80003D]`80003D]`80003D]`80003D]`8
0003D]`=0003D]`00`00D]aBg0050003D]`00`00D]aBg00500000e;L000000050004D]`50006D]`5
00000eKL000000030002E]`00`00E]`000020004E]`500000eKL000000030002E]`00`00E]aFg003
0004E]`500000eKl0000000300000eKl000000030002E_`40002E_`00`00E_`00002000015Kl0000
00000UKl00<005KlE_`00`000eKl30000UKl00<005LM00000P0000=G7@0000001P0000=G7@000000
0`0000=G7@0000000P0000=G7@0000002@0000=G?@0000002@0000=G?P0000002@0000=GGP000000
2@0000=GGP0000004@0000=GO`0000005P0000=CW`0000003P0000ECW`00000005>O00<00003Dil0
000000800003Dil0000000T00003Dgl0000001400003Dgl0000000D00005Dgl00000001CO`070000
0e=o000000050002Ool00`00Oomoo`0eOol0069oo`03001oogoo0:5oo`D00003Acl0000000P00003
Acl0000000P00003Acl0000000P00003Acl0000001@00003Acl0000001h00003Acl0000000P00003
Acl0000000P00003Acl0000000P00003Acl0000001<00003C_d0000001800003Bal0000000L00003
Bal0000000P00003Bal0000000L00003Bal0000000P00003Bal0000001800003Bah0000001400003
Bah0000000P00003B_h0000001800003C_h0000000P000E>o@03001>oDkm00=>oA@00003C_d00000
00P00003C_d0000000P000E>g@03001>gDkM009>g@X00003C]d0000000P00003C]`0000000P000EB
g004001Bg5;LD]`50002D]`00`00D]aBg003D]`80002D]`E00000e;L000000080004D]`70003D]`8
0003D]`80003D]`80003D]`80003D]`50006D]`50003D]`800000e;L000000030002D]`01000D]aB
g5;L1@000U;L00@005;LD]aBg0/000EFg0@0009Fg0D00003E]`0000000<000IFg0@0009Fg0D00003
E]`0000000<0009Fo0@0009Fo003001Fo000008000AFo0@00004E_`000000003E_`500000eKl0000
000;0004E_`400000eLM0000000:0003Ead300000eLM0000000500001ELM00000000Ead01`0000EG
?@00000005Lm00L00005Ech00000001G?P0;00000eMN0000000R00000e=o0000000B00001E>O0000
0000Dil0100000=CW`0000001@0000=CW`0000001@0000ECO`00000005=o00L00003Dgl000000180
0003Dgl0000000T00003Dgl0000000P0009oo`03001oogoo03Eoo`00HWoo00<007oo00000P00X7oo
1@0000=7?`000000500000=7?`000000:@0000=7?`000000200000=7?`000000200000=7?`000000
500000=7?`0000004P0000=;7P000000200000=;7P0000001`0000=;7`000000200000=;7`000000
1`0000=;7`0000004P0000=;7`0000004P0000=;7P000000700000=:oP0000004P0000=>oP000000
200000=>oP000000700000=>o@0000004`001DkM00<004kMC]d00TkM2P0000=>g@000000200000=>
g000000020001E;L00<005;LD]`00e;L20000U;L5@0000=Bg0000000200015;L1`001E;L00@005;L
D]aBg0D0009Bg003001Bg5;L00D000=Bg003001Bg5;L00D000=Bg003001Bg5;L00D0009Bg004001B
g5;LD]`50002D]`01000D]aBg5;L1@000U;L00@005;LD]aBg0d000=Bg0H000EBg0H000=Bg0d000=F
g003001Fg5KL00D00003E]`0000000<000=Fg0<0009Fg004001Fg5KLE]`;0002E]`40002E]`00`00
E_`000020004E_`40002E_`:00000eKl0000000300000eKl0000000800000eKl000000020002E_`5
00000eKl00000005000015LM000000000ULM00<005LMEad02`0000=G7@0000002@0000=G?@000000
2@0000=G?P0000009@0000=GO`0000006P0000=CW`0000000P0000=CW`0000001@0000=CW`000000
3P0000=CO`0000002@0000ECO`00000005=o00<00003Dgl0000000D00003Dgl0000000d00003Dgl0
000000D00003Dgl0000000D0009oo`03001oogoo03Aoo`00HWoo0P00Y7oo9`0000=7?`0000002000
00=7?`000000200000=7?`000000@00000=;?`0000001`0000=;7`0000004P0000=;7`0000004P00
00=;7`0000001`0000=;7`000000200000=;7`0000001`0000=;7P000000200000=;7P0000001`00
00=;7P000000700000=>oP000000200000=>oP000000700000=>o@0000004P001DkM00<004kMC]d0
0dkM2P0000=>g@000000200000=>g000000020001DkL00<005;LD]`00U;L5@0000=Bg00000002000
15;L1`001E;L00@005;LD]aBg0D0009Bg003001Bg5;L00=Bg0P0009Bg0P000=Bg0P000=Bg0P000=B
g0P000=Bg0P000=Bg0d000=Bf`03001Bg5;L00D000=Bf`03001Bg5;L00D00003D]/0000000H000=F
f`D000IFg0D00003E]`0000000<0009Fg003001Fg5KL00<000=Fg0/000=Fg003001Fg000008000AF
g0@0009Fo0D00003E_`0000000P00003E_`0000000<000=Fo0P000=Fo0<00003E_`0000000<0009F
o0P00004Ead000000003Ead800001ELM00000000Ead01`0000EG?@00000005Lm00L00005Ech00000
001G?P0C00001EMN00000000Eeh01`0000=GOP0000001P0000=GO`0000007P0000=CW`0000005P00
00=CW`0000002@0000=CO`0000000P0000=CO`0000002@0000=CO`0000005@0000=CO`0000002000
0Woo00<007ooOol0=7oo001ROol00`00Oomoo`2TOol600000dLo0000000800000dLo000000080000
0dLo0000000D00000dLo0000000M00000dLo0000000D00000dLo0000000800000d/o0000000B0000
0d/O0000001600000d/N0000000B00000d/N0000000L00000dkn0000000B0005C_d00`00C_e>o@03
C_d:00000dkm0000000700000dkM0000000B00000dkM0000000800000dkM000000080005C]`00`00
C]a>g002C]`:00000e;L0000000800000e;L000000080005D]`01000D]aBg5;L1@000U;L00<005;L
D]`00e;L20000U;L5@0015;L1`0015;L1`000e:k20000e:k20000e;K20000e;K1@001U;K1@001U;K
1@0000=Bf`0000000`000UKK00@005KKE]]Ff`D0009Ff`04001Fg5KLE]`;0005E]`500000eKL0000
000300000eKL000000030006E]`40002E]`;0002E_`90003E_`30002E_`00`00E_aFo0060002E_`0
0`00E_aFo0070002E_`00`00E_`0000200001EKl00000000Ead0100000=G7@0000000`0000=G7@00
00000P0000=G7@0000002@0000=G?@0000002@0000=G?P000000300000=GGP0000001P0000=GGP00
00002@0000=GOP0000001@0000=GO`0000005P0000=CW`0000004P0000=CW`0000006P0000=CO`00
00001@0000ECO`00000005=o00L00003Dgl0000000d00003Dgl0000000D00005Dgl00000001CO`03
0002Ool00`00Oomoo`0cOol0069oo`03001oogoo0:Iooa400003Acl0000002T00003Acl0000000P0
0003Acl0000000P00003Acl0000000P00003Acl0000001<00003Acl0000001800003Acl0000000P0
0003Aal0000000L00003Aal0000001800003Bal0000001`00003Bah0000000L00003Bah0000000P0
0003B_h0000000L000E:oP03001:oT[n00=:oPX00003C_h0000000L00003C_d0000001800003C_d0
0000018000E>g@03001>gDkM00=>gAD000E>g003001>g4kL009>g0X00003D]`0000000P00003D]`0
000000P000EBg003001Bg5;L00=Bg0P0009Bg1D000AB_0L000EB_004001Bg5;LD]`50002D[/01000
D]aBg5;L1@000U:k00<005:kD[/01@000e:k00<005:kD[/01@000e:k00<005;KD]/01@000U:k00@0
05;KD]]Bf`D0009B^`04001Bfe;KD]/50002D]/01000D]]Bfe;K2`001EKK1P001EKK2`000eKK00<0
05KLE]`01@0000=Ff`0000000`000eKL0`000UKL00@005KLE]aFg10000=Fg003001Fo00000800004
E_`000000002E_`00`00E_aFo0030003E_`80003E_`80004E_`400000eKl0000000:0003Ead30000
0eLM0000000500001ELM00000000Ead01`0000EG?@00000005Lm00L00003Ech0000000D00003Eeh0
000000D00003Eeh0000000T00003Egh0000000h00005Egl00000001CO`0Q00000e>O0000000R0000
0e=o0000000900000e=o0000000E00000e=o000000080002Ool00`00Oomoo`0cOol0065oo`03001o
ogoo0:Qooa`00003Acl0000000P00003Acl0000000P00003Acl0000000P00003Acl0000001h00003
Acl0000000P00003Acl0000000P00003Acl0000000P00003Acl0000000L00003Acl0000001800003
Aal0000000L00003Aal0000000P00003Bal0000000L00003Bal0000001`00003Bah0000001`00003
C_h00000018000E>o@03001>oDkm00=>oA@000E>g@03001>gDkM00=>gA@000E>g003001>g4kL00=>
g0X00003C]`0000000P00003D]`0000000P000EBg003001Bg5;L009Bg1D000AB_0L000EB_004001B
_5:lD[`50002D[/00`00D[aB_003D[`80003D[/80002D[/80006D[/50006D[/50006D[/50006D[/5
0003D]/=0003D[/00`00E]]Ff`050003E]/00`00E]]Ff`0500000eKK000000030006E]/500000eKK
000000030002E]/00`00E]aFg0030003E]`;00000eKL000000030006E]`4000015Kl000000000eKl
1@0000=Fo00000000`0000=Fo00000000P0000=Fo00000000`0000=Fo00000000P000UKl1@0000=F
o00000001@0000AG7@000000009G7@03001G7ELM00/00003Ead0000000T00003Ecd0000000T00003
Ech0000000@00003Ech0000001h00005Egl00000001GO`0400000e=o0000000J00000e>O0000000F
00000e=o0000000900000e=o0000000=00000e=o0000000500000e=o0000000I000015=o00000000
0Woo00<007ooOol0<Woo001QOol00`00Oomoo`2YOol600000dLo0000000800000dLo000000080000
0dLo0000000N00000dLo0000000800000dLo0000000800000dLo0000000N00000dLo0000000a0000
0dLO0000000B00000d/O0000000L00000d[n0000000700000d[n0000000L00000dkm0000000L0000
0dkM0000000L0005C]`00`00C]a>g003C]`:00000dkL0000000C0005D]`00`00D]aBg002D]`:0000
0e;L000000080005D[`01000D[aB_5:l1@000U:l00<005:lD[`00e:l20000e:k2P000e:k20000e:k
1`001E:k00@005:kD[]B^`D0009B^`04001B^e:kD[/50002D[/01000D[]B^e:k1@000U:k00@005:k
D[]B^`d000=B^`D000IB^`D000IFf`D00003E]/0000000<0009Ff`04001FfeKKE]/;0005E]/50000
0eKL0000000300000eKK000000030003E]`30002E]`01000E]aFg5KL2P0000=Fo00000000`0000=F
o00000000`000eKl20000eKl0`0000=Fo00000000`000UKl200000AG7@00000000AG7@L00005Ead0
0000001G7@0700001ELM00000000Ecd01`0000EG?@00000005Ln01<00005Eeh00000001GGP070000
0eMo0000000600000eMo0000000=00000e>O0000000:00000e>O0000000600000e>O0000000=0000
0e>O0000000600000e=o0000000900000e=o0000000E00000e=o0000000P0002Ool00`00Oomoo`0b
Ool0065oo`03001oogoo0:]oo`H00003Acl0000001d00003Acl0000001@00003Acl0000000P00003
Acl0000000P00003Acl0000000L00003Acl0000001h00003Acl0000000L00003Acl0000000P00003
Aal0000002H00003Bah0000000L00003Bah0000001`00003B_h0000001400003C_d0000000P00003
C_d0000001400003C]d0000000P000E>g@03001>gDkM00=>g@T00003C]`0000001800003C]`00000
018000EBg003001Bg5;L00=Bg0X00003D[`0000000P000EB_003001B_5:l00=B_0P000=B_0X000=B
^`P000EB^`03001B^e:k00D0009B^`04001B^e:kD[/50002D[/00`00D[]B^`03D[/80003D[/80003
D[/80003D[/=0003D[/00`00D[]B^`050002D[/01000D[]B^e:k1@000UJk00@005KKE]]Ff`/000EF
f`/000=Ff`03001FfeKK00D00003E]/0000000<000=Ff`<0009Ff`03001Fg5KL00<000=Fg0/00003
E]`0000000<000=Fo0<0009Fo003001Fo5Kl00H0009Fo003001Fo5Kl00L0009Fo003001Fo0000080
0005E_`00000001Fo0040003Ead800000eLM0000000900000eLM0000000900000eLm0000000<0000
0eMN0000000600000eMN0000000900000eMo0000000500000eMo0000000>00001E>O00000000Dil0
200000=CW`0000003@0000=?W`0000001P0000=CW`0000001@0000=?W`0000001@0000ECO`000000
05=o03/00004Dgl000000002Ool00`00Oomoo`0aOol0065oo`03001oogoo0:eooa000003Acl00000
00P00003Acl0000000P00003Acl0000000P00003Acl0000001h00003Acl0000000P00003Acl00000
00P00003Acl0000001800003Acl0000000L00003Acl0000001800003Aal0000000L00003Aal00000
01`00003Bah0000001400003B_h0000001`00003C_d0000000P000A>o@03001>gDkM00=>g@X00003
C]d0000001`000E>g003001>g4kL00=>g1@000EBg003001Bg5;L00=Bg0X00003D[`0000000P000EB
_003001B_5:l00=B_1D000EB^`03001B^e:k00D0009B^`03001B^e:k00=B^`P000=B^`P000=B^`X0
00=B^`P000=B^`P000=B^`P000=B^`D000IB^`D000IB^`D000IF^`X000=F^`03001FfeKK00D00003
E]/0000000<000IFf`D00003E]/0000000<0009Ff`03001FfeKK00<000=Ff`D00003E]`0000000<0
0003E]`0000000<000=Fg0<0009Fg003001Fo5Kl00<000=Fo0P000AFo0L000AFo0@00003E_`00000
00D0009Fo003001G7@0000800005Ead00000001G7@0700001ELM00000000Ead01`0000EG?@000000
05Lm00l00003Eeh0000002H00003Dgl0000001l00005Cil00000001?W`0300000dnO0000000>0000
0e=o0000000500000e=o0000000500000e=o0000000E00001E=o00000000Dgl01`0000=CO`000000
40000goo00<007ooOol0<7oo001QOol00`00Oomoo`2]Ool600000dLo0000000800000dLo0000000N
00000dLo0000000800000dLo0000000800000dLo0000000800000dLo0000000C00000dLo0000000a
00000dLO0000000700000dLO0000000`00000d[n0000000700000d[n0000000V00000dkM00000008
0005C]d00`00C]e>g@02C]d:0005C]`00`00C]a>g003C]`D0005C]`00`00D]aBg003D]`:00000e:l
000000080005D[`00`00D[aB_003D[`D0005D[/00`00D[]B^`03D[/80003D[/:0004D[/70003D[/8
0005D[/00`00D[]B^`050003D[/00`00D[]B^`050002D[/01000D[]B^e:k1@000U:k00@005:kD[]B
^`D0009B^`04001B^e:kD[/50002D[/01000D[]B^e:k1@000UJk00@005JkE[]F^`X000IF^`D00003
E]/0000000<0009Ff`04001FfeKKE]/500000eKK000000030005E]/500000eKK0000000300000eKK
000000030003E]`30002E]/00`00E]aFg0030003E]`500000eKl0000000300000eKl000000020002
E_`90002E_`500000eKl000000050004E_`400000eLM0000000900000eLM0000000900000eLm0000
000<00001ELn00000000Eeh01P0000=GGP0000006`0000=CO`0000000P0000=CO`0000006P0000E?
W`00000004nO00@00003Cil0000002800003Dgl0000001D00003Dgl0000000T00003Dgl0000001@0
009oo`03001oogoo031oo`00HGoo00<007ooOol0[goo6`0000=7?`0000007`0000=7?`0000004P00
00=7?`000000200000=7?`000000200000=7?`000000200000=3?`0000001`0000=7?`0000009P00
00=77`0000001`0000=;7P0000004@0000=:oP00000070001D[m00<004kmC_d00dkm2@001DkM00<0
04kMC]d00dkM7P0000=>g000000070001DkL00<004kLC]`00dkL2P0000=B_000000020001E:l00<0
05:lD[`00U:l2`000e:k1`001E:k00<005:kD[/00e:k2P0000=B^`00000020001E:k00@005:kD[]B
^`D0009B^`03001B^e:k00D000=B^`03001B^e:k009B^`P000=B^`P000IB^`D000IB^`D000EB^`H0
00EB^`H000=F^`d0009F^`04001F^eJkE[/500000eJk000000030005E]/60002E]/40002E]/00`00
E]]Ff`0500000eKK000000030003E]/30002E]/00`00E]aFg0030003E]/500000eKL000000030000
0eKL000000030003E_`300000eKl000000030002E_`300000eKl000000030002E_`80002E_`50000
0eLL0000000500001ELM00000000Ead01`0000AG7@000000009G?@H00003Ecd0000000D00003Ech0
000000P00003Eeh0000000800005Eeh00000001GGP0700000eMo0000000S00001E>O00000000Cil0
100000=?W`0000001@0000=?W`0000008P0000=CO`0000001@0000ECO`00000005=o00L00003Dgl0
000000T00005Dgl00000001CO`0700000e=o0000000A0002Ool00`00Oomoo`0_Ool0065oo`03001o
ogoo0;1oo`H00003Acl0000000P00003Acl0000000P00003Acl0000000P00003Acl0000002T00003
Acl0000001800003Acl0000004D00003Bah0000001400003B_h0000001400003B_h0000002H00003
C]d0000000L000E>g@03001>gDkM00=>g@X000E>g003001>g4kL009>g0X000E>g003001>g4kL00=>
g0X00003D[`0000000P000EB_003001B_5:l009B_0X000EB^`04001B^e:kD[/50002D[/00`00D[]B
^`03D[/:0003D[/80005D[/00`00D[]B^`03D[/80002D[/80006D[/70004D[/70005D[/01000D[]B
^e:k1@000U:k00@005:kD[]B^`D0009B^`03001B^e:k00D000=B^`03001B^e:k00D00003E[/00000
00H000=F^`D000IF^`D000=F^`<0009F^`03001FfeKK00D000=F^`03001Ff`00008000AFf`D000=F
f`<0009Ff`03001FfeKK00<000=Ff`D00003E]/0000000<00003E]/0000000<000=Fg0<0009Fg003
001Fo5Kl00L0009Fo003001Fo00000800004E_`000000002E_`00`00E_`0000200001EKl00000000
E_`01@000ULL200000=G7@0000002@0000AG7@000000009G?@H00003Ecd0000000@00003Ech00000
00D00005Eeh00000001GGP0400000eMN0000000900000eMo0000000J00001E>O00000000Dil01000
00=CW`0000001@0000=?W`0000004P0000=?W`0000007P0000=CO`0000002@0000=CO`0000002@00
00=CO`0000002@0000=CO`00000050000Woo00<007ooOol0;goo001QOol00`00Oomoo`2bOol50000
0dLo0000000N00000dLo0000000800000dLo0000000800000dLo0000000800000dLo0000000N0000
0dLo0000000700000d<o0000000700000d<O0000001400000d[n0000000A00000d[n0000000A0000
0dkM0000000V00000dkL0000000A00000dkL0000000B00000djl000000080005D[`00`00D[aB_002
D[`:0005D[/00`00D[]B^`03D[/80003D[/:0005D[/00`00D[]B^`050003D[/00`00D[]B^`02D[/;
0003D[/70005D[/01000D[]B^e:k1@000U:k00@005:kD[]B^`D0009B^`03001B^e:k00=B^`P000=B
^`P0009B^`P000=B^`P00003E[/0000000<0009F^`04001F^eJkE[/50002E[/01000E[]F^eJk1@00
0UJk00<005JkE[/00`000eJk1@001UJk10000UKK1@000UKK00<005KKE]/00`000eKK1@0000=Ff`00
00000`0000=Ff`0000000`000eKK0`000UKK00<005KLE]`00`000eKL200015Kl100000AFo0000000
00=Fo0@00003E_`0000000D0009Fo003001G700000800005Ea`00000001G7@07000015LM00000000
0ULM0`000ULm1P0000=G?@000000300000=GGP0000009P0000ECW`00000005>O00@00003Dil00000
00D00003Cil0000001/00005Cil00000001?W`0300000dmo0000000500000e=o0000000I00000e=o
0000000E00000e=o0000000500001E=o00000000Dgl01`0000=CO`00000010000goo00<007ooOol0
;Woo001QOol00`00Oomoo`2cOol@00000dLo0000000800000dLo0000000Y00000dLo000000080000
0dLo0000000800000dLo0000000j00000dLO0000000A00000d[n0000000j0005C]d00`00C]e>g@02
C]d:0005C]d00`00C]a>g003C]`:0005C]`00`00C]a>g002C]`:0005C[`00`00C[a>_003C[`:0005
D[`00`00D[aB_002D[`:0005D[/00`00D[]B^`03D[/:00000e:k000000080005D[/00`00D[]B^`02
D[/80003D[/:0005D[/01000D[]B^e:k1@000U:k00<005:kD[/00e:k20000e:k20001E:k20000e:k
20000e:k1`0015:k1`0015:k1@001EJk1P001EJk1P001EJk1@0000=F^`0000000`000UJk00@005Jk
E[]F^`D00003E[/0000000<000EFf`D00003E]/0000000<00003E]/0000000<000=Ff`<0009Ff`03
001FfeKK00<000=Ff`D00003E]`0000000<00003E]`00000008000AFo0<00003E_`00000008000=F
o0<00003E_`0000000D000AFo0@00003Ea`0000000T00004Ead000000002Ead300000eLM00000002
000015Lm000005Lm2@0000EG?P00000005MN02@00003Dgl0000000800003Dil0000000D00003Dil0
000001l00005Cil00000001?W`0400000dnO0000000900001E=o00000000Dgl06`0000=CO`000000
6@0000=CO`0000002@0000=CO`000000100000ACO`000000009oo`03001oogoo02ioo`00HGoo00<0
07ooOol0]7oo1P0000=7?`000000200000=7?`000000200000=7?`000000200000=7?`0000001`00
00=7?`000000:@0000=7?`000000200000=7?`0000001`0000=37`000000>@0000=:oP0000004@00
00=:oP0000004@001D[M00<004kMC]d00dkM4`0000=>g@0000009P001Djl00<004jlC[`00djl2P00
1Djl00<005:lD[`00U:l2P0000=B^`0000004P0000=B^`00000020001E:k00<005:kD[/00U:k2P00
00=B^`00000020001E:k00<005:kD[/00e:k20000e:k2P000e:k20001E:k00<005:kD[/01@000e:k
00<005:kD[/01@000U:k00@005:kD[]B^`D0009B^`04001B^e:kD[/50002D[/01000D[]B^e:k1@00
0UJk00<005JkE[/01@000eJk00<005JkE[/01@000eJk00<005JkE[/01@0000=F^`0000000`001UJk
1@0000=F^`0000000`000UJk00<005KKE]/01@0000=Ff`0000000`000eKK0`000UKK00<005KKE]/0
0`000eKK1@0000=Ff`0000000`0000=Ff`0000000`000eKL0`000UKL00<005KlE_`01`000UKl00<0
05Kl00000P0000=Fo00000001@0015Kl0`0000=Fo00000001@0000AG7@000000009G7@<0009G7@<0
009G7@<00003Ecd0000000X00003Ech0000000d00003Eeh0000000T00003Egl0000000h00003Dil0
000001l00003Cil0000000H00003Cil0000000D00003Cil0000000T00003Dgl0000000800003Dgl0
000003@00003Dgl0000000D00005Dgl00000001CO`0700000e=o000000040003Ool00`00Oomoo`0]
Ool0065oo`03001oogoo0;IoobH00003Acl0000000P00003Acl0000000P00003Acl0000000L00003
Acl0000000P00003Acl0000001<00003Acl0000001400003@al0000001400003Aal0000002l00003
B_h0000001/00003C]d00000014000E>g@03001>g4kL00=>g0T000E>_003001>_4jl00=>_2P00003
D[/0000000P000EB^`03001B^e:k00=B^`X000EB^`03001B^e:k009B^`X000AB^`L000EB^`03001B
^e:k00=B^`X000=B^`P000EB^`03001B^e:k00D000=B^`03001B^e:k009B^`P000=B^`P000IB^`D0
00EB^`H000EB^`H000EF^`D000IF^`D000IF^`D00003E[/0000000<0009F^`04001F^eJkE[/50000
0eJk000000030005E[/50003E]/30002E]/00`00E]]Ff`030003E]/500000eKK0000000300000eKK
000000030003E]/30002E]/00`00E]aFg0030003E]`80004E_`400000eKl000000040002E_`00`00
E_aFo00;000015LM000000000ULM0`0000=G7@0000000P000ULM0`0000=G7@000000100000=G?@00
00000`0000=G?P000000100000EGGP00000005MN00@00003Eeh0000000@00003Egh0000000800003
Egl0000002L00003Cil0000000H00005Cil00000001?W`0300000dnO0000000F00000e=o00000005
00001E=o00000000Dgl01`0000=CO`0000002@0000ECO`00000005=o00L00003Dgl0000001400003
Dgl0000000T00003Dgl0000000@00004Dgl000000002Ool00`00Oomoo`0]Ool0065oo`03001oogoo
0;Mooa000003Acl0000002T00003Acl0000000P00003Acl0000000P00003Acl0000000L00003Acl0
000000P00003Acl0000003T00003B_h0000001/000A:o@03001:gD[M00=:gA@000A>g@03001>gDkM
00=>gBP000E>_003001>_4jl00=>_0T000E>_003001>_4jl00=>_0X000EB^`03001B^e:k00=B^`X0
00EB^`03001B^e:k009B^`X000EB^`04001B^e:kD[/50002D[/00`00D[]B^`03D[/:0005D[/00`00
D[]B^`050003D[/00`00D[]B^`02D[/80006D[/70004D[/70005D[/01000D[]B^e:k1@000U:k00<0
05:kD[/01@000e:k00<005:kD[/01@000eJk00<005JkE[/01@000UJk00@005JkE[]F^`D0009F^`04
001F^eJkE[/;0005E[/60002E[/40002E[/00`00E[]F^`050002E[/00`00E]]Ff`030003E]/50000
0eKK0000000300000eKK000000030003E]/30002E]/00`00E]]Ff`030004E]/400000eKL00000003
00000eKl000000020002E_`500000eKl000000050004E_`700001ELL00000000Ea`010000ULM0`00
0ULM0`000ULM2P0000=G?@0000000`0000=G?P000000100000=GGP0000001P0000=GGP000000:P00
00=?W`0000001P0000E?W`00000004nO00<00003Cil0000000800003Cil0000002800003Dgl00000
00T00003Dgl0000000T00003Dgl0000000T00003Dgl0000001000003Dgl0000000T00003Dgl00000
00d0009oo`03001oogoo02aoo`00HGoo00<007ooOol0^7oo1P0000=7?`000000200000=7?`000000
200000=7?`0000004P0000=7?`000000200000=7?`0000004`0000=7?`000000200000=7?`000000
1`0000=7?`0000006`0000=77`000000@P0000=:g@0000006`0000=>g00000004@001Djl00<004jl
C[`00djl500014jl00<004jlC[`00djl2P001E:k00<005:kD[/00e:k2P001E:k00<005:kD[/00U:k
2P001E:k00<005:kD[/00e:k20000e:k2P001E:k00<005:kD[/00U:k20000e:k2P001E:k00@005:k
D[]B^`D0009B^`04001B^e:kD[/50002D[/00`00D[]B^`03D[/80005D[/50006D[/50006E[/50006
E[/50006E[/:0003E[/00`00E[]F^`050003E[/00`00E[/000020004E[/50006E[/400000eKK0000
000300000eKK000000030003E]/30002E]/00`00E]]Ff`030004E]/40003E]/90003E_`300000eKl
000000030002E_`80004E_`700000eLL000000050002Ead40002Ead300000eLM0000000500001ELm
00000000Ecd02`0000=GGP0000001`0000=GGP000000:P0000E?W`00000004nO00<00003Cil00000
00800003Cil0000001X00003Cgl0000001T00003Dgl0000000D00003Dgl0000000d00003Dgl00000
00D00003Dgl0000002P0009oo`03001oogoo02aoo`00H7oo1P00^7oo1P0000=7?`0000004P0000=7
?`000000200000=7?`000000200000=7?`0000004P0000=7?`000000200000=7?`000000C@001D[n
00<004[nB_h00d[n7@001D[M00<004kMC]d00TkM50001Djl00<004jlC[`00Tjl50001Djl00<004jl
C[`00Tjl50001Djk00<005:kD[/00e:k2P001E:k00<005:kD[/00U:k2P001E:k00<005:kD[/00e:k
2P0000=B^`00000020001E:K00<005:kD[/00U:k2P0015:K1`001E:K00<005:kD[/00e:k20000e:k
20001E:k20001E:j00<005:kD[/01@000U:j00@005:kD[]B^`D0009B^P04001F^eJkE[/50002E[X0
1000E[]F^eJk1@000UJk00@005JkE[]F^`X000IF^`D000IF^`@0009F^`D0009F^`04001F^eJkE[/:
0003E]/30002E]/00`00E]]Ff`030004E]/40003E]/40002E]/00`00E]/00002000015KK00000000
0UKK00<005KlE_`01`000UKl00<005Kl00000P0000AFo0000000009Fo003001Fo5Kl00H00003E_`0
000000D000AG7@<0009G7@/00003Ecd0000002D00003Egl0000000h00003Dil0000000l00003Cil0
000000D00003Cil0000001800003Cil0000000H00003Cgl0000002400003Dgl0000001D00003Dgl0
000002@00003Dgl0000000D0009oo`03001oogoo02]oo`00HGoo00<007ooOol0_7oo<00000=7?`00
0000200000=7?`000000200000=7?`0000001`0000=7?`000000200000=7?`0000001`0000=7?`00
0000@P0000=:oP00000090001DkM00<004kLC]`00dkL4`001Djl00<004jlC[`00djl4`001Djk00<0
04jkC[/00djk:0001E:k00<005:kD[/00e:k2P0000=BV`00000020001E:K00<005:KDY/00U:K2P00
1E:K00@005:KDY]BV`D0009BVP03001BVe:K00=BV`X000=BVPP000EBVP03001B^e:k00D0009BVP03
001B^U:j00=B^PP000=B^PP000IB^PD000EF^PH000EF^`H0009F^`<0009F^`04001F^eJkE[/50002
E[/01000E[]F^eJk1@0000=F^`0000000`001EJk1P000UJk0`000UJk00<005KKE]/00`0015KK1000
0eKK10000UKK00<005KK00000P0015KK100000AFf`00000000AFf`L000AFo0@00004E_`000000004
E_`700000eKl000000050004Ead300000eLM0000000500001ELM00000000Fad01`0000=G?@000000
2@0000EGGP00000005MN00/00003Egh0000000800003Egl0000001l00003Cil0000001/00005Cil0
0000001?W`0300000dmo0000000Q00000e=o0000000E00000e=o0000000500000e=o000000090000
0e=o0000000A00000e=o000000080002Ool00`00Oomoo`0[Ool0061oo`03001oogoo0;eoo`H00003
Acl0000000P00003Acl0000000P00003Acl0000000L00003Acl0000000P00003Acl0000000P00003
Acl0000001d00003Bcl0000000P00003Bcl00000044000A:g@03001:gD[M00=:gBL000A>_003001>
_4jl00=>_1@000A>_003001>_4jl00=>_1@000E>^`03001B^e:k009B^`X000EB^`03001B^e:k00=B
^al000EBV`03001BVe:K009BV`X000EBV`03001BVe:K00=BV`P000IBVPL000EBVP03001BVU:J00D0
00=BVP03001BVU:J009BVPP000IBVPL000ABVPL000EBVP04001B^U:jD[X50002E[X00`00E[YF^P05
0003E[X00`00E[]F^`050003E[X00`00E[/000020004E[/50006E[/50002E[/40002E[/00`00E[]F
^`050003E[/00`00E[/000020004E[/40004E]/30002E]/00`00E]/000020004E]/40002E]/50000
0eKK000000020003E]/80004E_`300000eKl000000020003E_`800000eKl000000040002Ea`00`00
EaeG7@0;00000eLM0000000900000eLm0000000900000eMN0000000=00000eMn0000000e00000dnO
0000000900000dnO0000000200000dnO0000000=00001E=o00000000Dgl01`0000=CO`0000002@00
00ECO`00000005=o00L00003Dgl0000001400003Dgl0000000T00003Dgl0000001000003Dgl00000
00D00005Dgl00000001CO`030002Ool00`00Oomoo`0ZOol0061oo`03001oogoo0;moo`H00003Acl0
000001800003Acl0000000P00003Acl0000000P00003Acl0000000L00003Acl0000000P00003Acl0
000000L00003Acl0000000P00003Bcl0000005D000E:g@03001:gD[M009:gBL000E>_003001>_4jl
00=>_1<000E>^`03001>^djk00M>^`03001>^djk00=>^`T000EBV`03001B^e:k00=B^`X000EBV`03
001BVe:K00=BV`T000EBV`03001BVe:K00=BV`X000EBVP03001BVe:K00=BV`X000EBVP04001BVU:J
DYX50002DYX00`00DYYBVP02DYX80006DYX70005DYX01000DYYBVU:J1@000U:J00@005:JDYYBVPD0
009BVP03001BVU:J00=BVPP000EF^PD000IF^PD000IF^P@0009F^`D0009F^P04001F^eJkE[/50002
E[/00`00E[/000020004E[/50006E[/40002E[/50002E[/00`00E]]Ff`030003E]/40002E]/50000
0eKK000000030002E]/40002E]/00`00E]/00002000015KK000000000UKK00<005KlE_`01`000UKl
00<005Kl00000P0000EFo000000005Kl00L000AG70L00005Fad00000001K7@0700001E/m00000000
Fcd0300000=GGP000000100000=GGP0000001P0000=GOP0000006P0000=?W`000000>@0000=CO`00
00002@0000=CO`0000002@0000=CO`0000002@0000=CO`000000400000=CO`0000001@0000ECO`00
000005=o00L00003Dgl0000000T00003Dgl0000000D00003Dgl0000000P0009oo`03001oogoo02Yo
o`00H7oo00<007ooOol0`Goo<00000=7?`000000200000=7?`0000001`0000=7?`000000200000=;
?`0000001`0000=;?`000000GP001D[M00<004jlC[`01djl00<004jlC[`00Tjl7P0014jl00<004jk
C[/01djk00<004jkC[/00djk500014jK00<005:KDY/00e:K2P001E:K00<005:KDY/00e:K2P0015:K
00<005:KDY/00e:K2P001E:J00<005:JDYX00e:J2P001E:J00<005:JDYX00e:J20001E:J1`001E:J
00@005:JDYYBVPD0009BVP03001BVU:J00=BVPP000EBVPH000EBVPP000EBVP03001F^UJj00D0009F
VP04001F^UJjE[X50002E[X01000E[YF^UJj2`001EJj1P001EJk100015Jk0`000UJk00@005JkE[]F
^`D00003E[/0000000<000EF^`D00003E]/0000000<00003E]/0000000<000=Ff`<0009Ff`03001F
f`00008000AFf`@00004E]/000000004E]/70004E_`400000eKl00000005000015Kl0000000015LL
1`0000=K7@0000002@0000=K?@0000003P0000=GGP000000100000=GGP0000001@0000=GOP000000
1@0000=GO`0000004`0000E?W`00000004nO04800003Dgl0000001D00003Dgl0000000D00003Dgl0
000001400003Dgl0000000T00003Dgl0000000T00003Dgl0000000@00003Dgl0000000D00005Dgl0
0000001CO`030002Ool00`00Oomoo`0YOol0061oo`03001oogoo0<5oo`H00003Acl0000000P00003
Acl0000000P00003Acl0000000L00003Acl0000000P00003Acl0000001d00003Bcl0000001800003
Bcl0000006H000E>_003001>_4jl00M>_003001>_4jl009>_1h000E>^`03001>^djk009>^a@000EB
V`03001BVe:K00=BV`X000EBV`03001BVe:K009BV`X000EBVP03001BVU:J00=BVPX000EBVP03001B
VU:J009BVP/000EBVP03001BVU:J00D0009BVP03001BVU:J00=BVPP000IBVPL000EBVP03001BVU:J
00D000=BVP03001BVU:J00D0009BVP03001BVU:J00=BVPP000IFVPD000IF^PX000=F^P03001F^UJj
00D000=F^P03001F^eJk00D0009F^P03001F^eJk00<000AF^`D0009F^`@0009F^`03001F^eJk00D0
0003E[/0000000<000=Ff`<0009Ff`03001FfeKK00<000=Ff`@0009Ff`D00003E]/00000008000=F
f`P000AFo0<00003E_`0000000D0009Fo0<00004F_`005LLEa`600000e/M0000000500001E/M0000
0000Fad01`0000EK?@00000005/m00/00003Eeh0000000h00003Egl0000001L00003Cil0000000h0
0003Cil0000000X00003Cil0000002800005Dgl00000001CO`0K00000e=o0000000@00000e=o0000
000500001E=o00000000Dgl01`0000ECO`00000005=o00l00003Dgl0000000P0009oo`03001oogoo
02Uoo`00H7oo00<007ooOol0`goo1P0000=7?`0000004P0000=7?`000000200000=7?`0000001`00
00=7?`000000200000=7?`0000001`0000=7?`000000200000=;?`0000001`0000=;?`000000Q000
1Djk00<004jkC[/01djk00<004jkC[/00djk4`001DjK00<005:KDY/00e:K50001E:K00<005:KDY/0
0U:K2P001E:J00<005:JDYX00e:J2P001E:J00<005:JDYX00U:J2P001E:J00<005:JDYX00e:J2000
1U:J1`001E:J00@005:JDYYBVPD0009BVP03001BVU:J009BVPP000IBVPD000IBVPL000EFVP04001F
VUJJEYX50002EYX01000E[YF^UJj2P001UJj1@001UJj1@001UJj10000UJk1@000UJk00<005Jk0000
0P0015Jk1@000eJk0`000UJk00<005KKE]/00`0015KK10000eKK0`0000=Ff`0000000`000UKK1000
0UKK00<005KK00000P0000AFg0000000009Fo003001Fo5Kl00/000=Fo08000=Jo0l00003Fad00000
00T00003Fcd0000001T00003Egl0000001/00003Cil0000000H00003Cil0000000H00003Cil00000
00X00005Cil00000001?W`0300000dnO0000000J00000e=o0000000L00000e=o0000000500000e=o
0000000A00000e=o0000000900000e=o0000000@00000e=o0000000=0002Ool00`00Oomoo`0XOol0
061oo`03001oogoo0<EoobD00003Acl0000001800003Acl0000000P00003Bcl0000000L00003Bcl0
000000L00003Bcl0000004/000=:_@03001:_4Zl00M:_003001>_4jl00I>_003001>_4jl00M>_003
001>_4jl00=>_2L000A>V`03001>VdjK00M>V`03001>VdjK00=>V`X000EBV`03001BVe:K00MBV`03
001BVe:K009BV`X000EBVP03001BVU:J00=BVPX000EBVP03001BVU:J009BVPX000EBVP03001BVU:J
00=BVPX000EBVP04001BVU:JDYX50002DYX00`00DYYBVP03DYX80005DYX70005DYX01000DYYBVU:J
1@000U:J00@005:JDYYBVPD0009BVP03001FVUJJ00=FVPP000=FVPP0009F^P<0009FVP04001F^UJj
E[X50002E[X01000E[YF^UJj1@000UJj00@005JjE[YF^PD00003E[X0000000<000EF^`@000AF^`<0
009F^`03001F^eJk00<000AF^`@000=Ff`@0009Ff`03001Ff`0000800004E]/000000002E]/00`00
E]/000020004E]/4000015KL0000000015Kl1`0000AFo0000000009Fo003001Fo00000800003F_`0
000000T00005Fad00000001K7@0700001E/m00000000Fcd01`0000=K?P0000002@0000=GGP000000
1P0000=GO`0000007`0000=?W`0000000P0000E?W`00000004nO00`00005Cil00000001?W`040000
0dnO0000000=00001E=o00000000Dgl01`0000=CO`0000003@0000=CO`0000001@0000=CO`000000
4@0000=CO`000000400000=GO`0000001@0000ECO`00000005=o00L00003Dgl0000001`0009oo`03
001oogoo02Qoo`00H7oo00<007ooOol0aGoo1P0000=7?`000000200000=7?`0000001`0000=7?`00
0000200000=7?`0000001`0000=7?`000000200000=7?`0000004P0000=;?`000000200000=;7`00
00001`0000=;7P000000;@000T[M00<004ZmB[d01dZm00<004ZmB[d00dZm9P0014jl00<004jkC[/0
1djk00<004jKCY/01djK00<004jKCY/00djK7@001DjK00<005:KDY/00U:K50001E:J00<005:JDYX0
0e:J2P001E:J00<005:JDYX00U:J2P001E:J00<005:JDYX00e:J2P001E:J00<005:JDYX00e:J2000
1E:J20001E:J00<005:JDYX01@000U:J00<005:JDYX00e:J20001U:J1@001E:J20000eJJ20001EJJ
00<005Jj00000P0015JJ1@001UJj1@001EJj1P000UJj10000UJj00<005JkE[/01@000UJj00<005Jk
E[/00`000eJk1@000eJk10000UJk00<005KK00000P0015KK100000AFf`00000000=Ff`@000AFf`<0
0003E]/00000008000=Fo0P00004E_`000000004E_`300001E[l00000000Fa`01`0000=K7@000000
1@0000EK7@00000005/m00/00003Fch0000000T00003Eeh0000000d00003Egl0000000X00003Dil0
000001@00003Cil0000000X00005Cil00000001?W`0P00000e=o0000000E00000e=o0000000@0000
0e=o0000000I00000e=o0000000900000e=o0000000L000015=o000000000Woo00<007ooOol09goo
001POol00`00Oomoo`37Ool600000dLo0000000700000dLo0000000800000dLo0000000B00000dLo
0000000700000dLo0000000B00000d/O0000000V0002@]h00`00A]i6gP03A]iY0004CY/00`00CY]>
V`07CY/00`00CY]>V`03CY/C0005DYX00`00DYYBVP07DYX00`00DYYBVP03DYX:0005DYX00`00DYYB
VP02DYX:0005DYX00`00DYYBVP03DYX:0005DYX00`00DYYBVP03DYX:0005DYX00`00DYYBVP050002
DYX00`00DYYBVP03DYX80006DYX70005DYX01000DYYBVU:J1@000U:J00<005:JDYX01@000eJJ00<0
05JJEYX01@000UJJ00<005JJEYX01UJJ100015JJ0`000UJJ00@005JjE[YF^PD0009F^P03001F^UJj
00D000=F^P03001F^P00008000AF^PD000IF^P@00003E[/0000000<000=F^`03001F^`00008000AF
^`@0009Ff`D00003E]/00000008000=Ff`<0009Ff`03001FfeKK00<00004E]/000000002E]/00`00
E_`0000200001EKl00000000E_`010000eKl200000=K7000000010000U/L1P000U/M0`0000=K?@00
0000100000EK?@00000005/m01800003Egh0000000L00005Egl00000001CW`0800001E>O00000000
Cil04@0000=;W`0000001P0000E;W`00000004^O00@00003Cil0000001d00003Dgl0000001D00003
Dgl0000001400003Dgl0000001P00003Egl0000000T00003Dgl0000001400003Dgl0000000T00003
Dgl0000000@0009oo`03001oogoo02Moo`00H7oo00<007ooOol0bGoo;`0000=7?`000000200000=;
?`0000001`0000=;7`0000001`0000=;7`0000001`0000=;7P0000001`0000=;7P00000090000TJm
00<004ZmB[d00dZm7@000dZl00<004jlC[`01djl00<004jLCY`01TjL00<004jKCY/01djK00<004jK
CY/01djK00<004jKCY/00TjK7P001DjK00<005:JDYX01U:J00<005:JDYX00e:J50001E:J00<005:J
DYX00U:J2P001E:J00<005:JDYX00e:J2P001E:J00<005:JDYX00e:J2P001E:J00<005:JDYX00U:J
20001U:J1`001E:J00@005:JDYYBVPD0009BVP03001BVU:J00IBVPD000EBVPD000IFVPD000QFVP03
001FVUJJ00D0009FVP03001FVUJJ00<000AFVPD000EF^PD000IF^P@000AF^P<0009F^P04001F^UJj
E[X:0006E[/40002E[/500000eJk000000030002E]/40002E]/00`00E]/000020004E]/4000015KK
000000000eKK100000=Fo00000001@000U[l00<005Kl00000P0000EJo000000005[l00L0009K70H0
00=K7@800003Fcd0000000@00003Fcd0000001@00003Egh0000000800003Egl0000000H00003Dil0
000000X00003Cil0000001<00003Bil0000000800003Bil0000002X00003Dgl0000000D00003Dgl0
000000T00003Dgl0000001400003Dgl0000001P00003Egl0000001d00003Dgl0000000T00003Dgl0
000000@00004Dgl000000002Ool00`00Oomoo`0VOol0061oo`03001oogoo0<Yoo`D00003Acl00000
00P00003Acl0000000L00003Acl0000001800003Acl0000001`00003Bah0000000L00003Bah00000
00L00003B_h0000003H0009:_003001:_4Zl00M:_003001:_4Zl00=:_2l000E>V`03001>VdjK00M>
V`03001>VdjK00M>V`03001>VdjK009>Va@000EBVP03001BVU:J00MBVP03001BVU:J00=BVPT000EB
VP03001BVU:J00=BVPX000EBVP03001BVU:J00=BVPX000EBVP03001BVU:J009BVPX000EBVP04001B
VU:JDYX50002DYX00`00DYYBVP06DYX50008DYX00`00DYYBVP050002DYX00`00DYYBVP050002EYX0
1000EYYFVUJJ1@000UJJ00<005JJEYX00eJJ20001UJJ10000eJJ10000UJJ00<005JjE[X01@000UJj
00@005JjE[YF^PD0009F^P03001F^UJj00<000AF^PD0009F^P<0009F^P04001F^eJkE[/500000eJk
000000030002E[/40002E]/00`00E]/000020004E]/40002E]/500000eKK000000020003E]/30000
0eKK000000050004F_`400000e[l00000005000015[l000000000e/L1@0000=K7@00Fad02@0000=K
?@000000100000EK?P00000005]N00L00005Eeh00000001GOP0400000eMo0000000K00000dnO0000
000;00001D^O00000000Bil0300000=?W`0000009P0000=CO`0000002@0000=CO`000000400000=G
O`0000001@0000=GO`0000004@0000=GO`000000400000=CO`0000004@0000ECO`00000005=o00l0
0003Ool007oo02Moo`00H7oo00<007ooOol0bgoo1P0000=7?`0000001`0000=7?`000000200000=7
?`0000001`0000=7?`0000001`0000=7?`0000001`0000=;7`0000001`0000=;7`000000700000=>
oP0000006P000TJm00<004JmA[d00dJm2P000dZm00<004ZlB[`00dZlG`001DjJ00<005:JDYX01e:J
00<005:JDYX00e:J500015:J00<005:JDYX00e:J2P001E:J00<005:JDYX00e:J2P001E:J00<005:J
DYX00U:J2P001E:J00<005:JDYX00e:J200025:J00<005:JDYX01@000U:J00<005:JDYX00e:J2000
1E:J1@001UJJ1@001UJJ1`001EJJ00@005JJEYYFVPD0009FVP03001FVP00008000AFVPD000IF^PD0
00IF^P@000=F^P@0009F^P03001F^P00008000AF^PD000=F^`<0009F^`03001F^`00008000AFf`@0
00AFf`<00003E]/0000000<0009Ff`@0009Ff`03001Ff`0000800005E]/00000001Fn`030004F_`3
00000e[l000000050002F_`300000e/L001K70050003Fad6000015/m000005/m1P0000=K?P000000
2@0000=GGP0000007`0000=?W`0000000P0000E?W`00000004^O00T00003Bil0000001800003Cil0
000000T00003Cgl0000001D00003Dgl0000000T00003Dgl0000000D00003Dgl0000001400003Egl0
000001000003Egl0000002D00003Dgl0000001@0009oo`03001oogoo02Eoo`00H7oo00<007ooOol0
cGooEP0000=>oP000000DP000dZK00<004jKCY/01djK00<004jKCY/01djK00<004jKCY/01TjK00<0
04jKCY/01djK00<004jKCY/01djK00<004jJCYX01djJ00<004jJCYX01TjJ00<004jJCYX00djJ5000
1E:J00<005:JDYX01e:J00<005:JDYX00U:J2P001E:J00<005:JDYX00e:J2P001E9j00<005:JDYX0
0U:J2P001E:J00<005:JDYX00e:J2P001E:J00<005:JDYX00e:J20001E:J20001E:J00<005:JDYX0
1@000U:J00@005JJEYYFVPD0009FVP04001FVUJJEYX50002EYX00`00EYYFVP05EYX60005EYX40004
EYX30002EYX01000E[YF^UJj1@000UJJ00@005JjE[YF^PD0009F^P03001F^P00008000AF^P@000AF
^P<0009F^P03001F^eJk00<000=F^`@000AFf`<0009Ff`03001FfeKK00L0009Ff`03001Ff`000080
00AFf`@00005E]/00000001Fn`03000015[l001Jo5[l1`0000AJo000000000=Jo08000=K70H0009K
7@H00003Fcd0000000L00003Fch0000000@00003Eeh0000000800003Eeh0000001400003Dil00000
01@00003Bil0000000H00003Bil0000000X00003Bil0000001800005Cgl00000001CO`0700000e=o
0000000900000e=o0000000A00000e=o0000000@00000eMo0000000500000eMo0000000`00000e=o
0000000A00000e=o000000040002Ool00`00Oomoo`0UOol0061oo`03001oogoo0<ioo`D00003@cl0
000001800003Acl0000000L00003Acl0000000L00003Bal0000002D00003C_h0000000L00003C_d0
000000H0008n_@L00092_A800096_003001:W4ZL00=:W0X000=:W003001:VdZK00I:V`03001>VdjK
00=>Vdd000E>VP03001BVU:J00MBVP03001BVU:J009BVQ@000EBNP03001BVU:J00=BVPX000EBNP03
001BNU9j009BNPX000EBNP03001BVU:J00IBVPL000EBVP03001BVU:J00=BVPX000EBVP03001BVU:J
00D0009BVP03001BVU:J00=BVPP000IBVPD000EFVPH000MFVP03001FVUJJ00D000=FVP03001FVUJJ
00D0009FVP03001FVUJJ00<000AFVPD000EFVPH000EF^P@0009F^PD0009F^P03001F^UJj00<000AF
^P@000=F^`<0009F^`03001FfeKK00<000AFf`L000AFf`@000AFf`<00003E]/000000080009Fn`80
00=Jo0L0009Jo0<00003F_`005[l00<00003Fa`0000000D0009K7@H00003Fcd0000000@00004Fcd0
0000Fch600000eMN0000000200000eMN0000000800000eMo0000000600001E>O00000000Dil04@00
00=;W`000000:@0000=?O`0000002@0000=CO`0000002@0000=CO`000000400000=GG`0000001@00
00=GG`0000004@0000=GO`000000400000=GO`0000004@0000=CO`0000002@0000=CO`0000004@00
00=CO`000000100000ACO`000000009oo`03001oogoo02Aoo`00H7oo00<007ooOol0cgoo1P0000=3
?`0000001`0000=7?`0000006`0000=;7`0000001`0000=;7P0000001`0000=:oP0000004@0000=>
o@0000001`0000=>g@0000002`000d:M1P001DJL4P000dZL00<004ZLBY`00dZL4`000djK00<004jK
CY/01djK00<004jKCY/01TjK00<004jKCY/01djK00<004jJCYX01djJ00<004jJCYX01djJ00<004jJ
CYX01TjJ00<004jJCYX01djJ00<004jJCYX00djJ4`001E9j00<0059jDWX01e9j00<0059jDWX00e9j
2P001E9j00<0059jDWX00U9j2P001E9j00<0059jDWX0259j00<005:JDYX01@000U9j00<005:JDYX0
1E:J20001E9j00<005:JDYX00U:J20001U:J1`001E:J00@005:JDYYBVPD0009FVP03001FVUJJ00D0
00=FVP03001FVUJJ00EFVPD000IFVPD000IFVP@000=FVP@0009FVP03001FVUJJ00D000=FVP03001F
^UJj00D00003E[X0000000<000EF^PD000=F^P@0009F^P03001F^`00008000AF^`@000=Ff`P000AF
f`<0009Ff`03001FfeKK00L0009Ff`@0009Jo0L000=Jo08000=Jo0<00005Fa`00000001K70030000
0e/M0000000500000e/m0000000400000e/m0000000=00000eMN0000000200000eMn000000020000
0eMo0000000:00001E>O00000000Cil07`0000=;W`0000008P0000=CO`0000004@0000=CO`000000
4@0000=GG`000000400000=GO`0000001@0000=GO`0000007@0000=CO`0000002@0000=CO`000000
400000=CO`0000001@0000=CO`00000010000goo00<007ooOol08goo001POol00`00Oomoo`3AOolg
00000d/N0000000700000d[n0000000K0004C]d01000?YdnWCjM2`000T:M1`000TJL00<004JLAY`0
0dJL70000dZK00<004jKCY/00djKC@001E9j00<0059jDWX01U9j00<0059jDWX00e9j50001E9j00<0
059jDWX00U9j2P001E9i00<0059jDWX0259j00<0059jDWX00U9j20001e9j00<005:JDYX01@000e9i
00<0059jDWX01E9j1`001E:I00@005:JDYYBVPD0009BV@03001BVU:J00IBVPD000EFVPD000QFVP03
001FVUJJ00D0009FVP04001FVUJJEYX50002EYX01000EYYFVUJJ1@000UJJ00<005JJ00000P0015JJ
1@001UJJ1@000eJj0`000UJj00<005JjE[X01@000eJj00<005Jj00000P0015Jj100015Jk0`000UJk
00<005KK00000P0000AFf`000000009Ff`03001FfeKK00<000AFf`L000AFf`<0009Jo0H0009Jo003
001Jo00000800003F_`0000000H00003Fa`0000000T00003Fcd0000000@00003Fcd0000000@00003
Feh0000000H00003Eeh0000000800003Egh0000001<00003Cil0000000l00003Bil0000003000005
Dgl00000001CO`0?00000e=o0000000@00000eMO0000000A00000eMo0000000500000eMo0000000L
00000e=o0000000500001E=o00000000Dgl04`0000=CO`0000001@0000=CO`000000100000ACO`00
0000009oo`03001oogoo02=oo`00Ggoo1P00d7oo6@0000=77`0000001`0000=77`0000004@0000=:
oP0000001`0000=>oP000000400000=>g@0000003`001CjM10000T:L1`000TJL2@000dJL00<004ZK
BY/00dZK2@000dZK00<004ZKBY/00dZK4`000djK00<004ikCW/01dik00<004ijCWX01dij00<004ij
CWX01Tij00<004ijCWX01dij00<004ijCWX01dij00<004ijCWX01dij00<0059jDWX00U9j50001E9j
00<0059jDWX01e9j00<0059jDWX00U9j2P001E9i00<0059iDWT0259i00<0059jDWX00U9j2P001E9i
00<0059jDWX00U9j2000259i00<0059jDWX01@000U9i00<005:IDYT01U:I1@0025:I00<005:JDYX0
1@000U:I00<005JJEYX01@000UJI00<005JJEYX01UJJ1@001UJJ1@001UJJ1@001EJJ100015JJ0`00
0UJJ00@005JJEYYFVPD0009FVP03001F^UJj00<000=F^PD000IF^P@000AF^P<0009F^P03001F^eJk
00<000=F^`@00004E]/000000004E]/40003E]/80004E]/300000e[k000000050004F_`300001E[l
00000000F_`00`0000=K700000001@0000EK7@00000005/M00L00003Fcd0000000@00003Feh00000
00800005Eeh00000001GGP0400000eMn0000000K00000d^O0000000700000d^O0000000600000d^O
0000000W00000e=o0000000@00000e=O0000000A00000eMO0000000A00000eMo0000000400000eMo
0000000A00000eMo0000000900000e=o0000000500000e=o0000000E00000e=o0000000400000e=o
0000000=0002Ool00`00Oomoo`0ROol005moo`03001oogoo0=Eoo`D00003@cl0000001X00003Aal0
000001/000A>g@03001>gDkM00=>g@T000E>g003001>g4kL009>g0`00004?Yd0049l@W`60003AW`6
0005BY/:0002BY/00`00BW]:N`03BW/:0003BY/00`00CW]>N`06CW/00`00CWY>NP03CWY30005DWX0
0`00DWYBNP07DWX00`00DWYBNP08DWX00`00DWYBNP02DWX90005DWT00`00DWUBN@08DWT00`00DWUB
N@02DWT:0005DWT00`00DWUBN@02DWT:0005DWT00`00DWUBN@03DWT80008DWT00`00DYUBV@050002
DWT00`00DYUBV@03DYT80005DYT50008EYT00`00EYYFVP050002EYT01000EYYFVUJJ1@000UJJ00@0
05JJEYYFVPD0009FVP03001FVUJJ00D0009FVP03001FVUJJ00<000AFVPD000IFVP@000=F^P<0009F
^P04001F^UJjE[X50002E[X00`00E[YF^P030003E[X500000eJk0000000300000eJk000000020004
E]/30002E]/00`00E]/00002000015KK000000000UKK00<005KKE]/01`0000AJn`00000000AJo0L0
0003F_`0000000D00005Fa`00000001K7@0700001E/m00000000Fcd01P0000=KGP0000000P0000=G
GP0000003@0000=GO`0000003`0000=?W`0000000P0000=;W`0000001P0000=7W`000000900000=?
O`0000005@0000=CO`0000002@0000=CG`0000003@0000=GG`000000400000=GG`0000001@0000=G
O`0000004@0000=GO`0000002@0000=CO`000000100000=CO`0000005@0000=CW`00000060000Woo
00<007ooOol08Woo001OOol00`00Oomoo`3FOole00000d[n0000000A00000dkM0000000@0005C[`0
0`00@Wa2O00;0002@W`70002AW`70003BY/00`00BW]:N`03BW/90003BW/00`00BW]:N`03BW/C0003
CWX00`00CWY>NP07CWX00`00CWY>NP06CWX00`00CWY>NP07CWX00`00CWY>NP07CWX00`00CWY>NP07
CWX00`00CWY>NP06CWX00`00DWYBNP08DWX00`00DWYBNP02DWXD0004DWT00`00DWUBN@08DWT00`00
DWUBN@02DWT:0005DWT00`00DWUBN@02DWT:0005DWT00`00DWUBN@03DWT:0005DWT00`00DWUBN@03
DWT80005DWT80005DWT00`00DYUBV@050002EYT00`00EYUFV@03EYT80006EYT50005EYX60005EYX5
0006EYX40004EYX30002EYX00`00EYYFVP02EYX40002EYX00`00E[X000020004E[X50006E[X40000
0eJj0000000300000eJj000000030003E[/30002E[/00`00E]]Ff`030003E]/4000015KK00000000
15KK1`000U[k0`0000AJo000F_aJo0H00003F_`0000000D0009K70<00003Fad0000000@0009K?@<0
0003Fcd0000000@00003Feh0000000800003Feh0000000d00003Egl0000002l00003Bil000000180
0005Cgl00000001CO`0C00000e=o0000000H00000eMN0000000500000eMN0000000A00000eMo0000
000@00000eMo0000000500001E=o00000000Dgl01`0000=CO`0000002@0000=CW`000000800000=C
O`00000010000goo00<007ooOol08Goo001OOol00`00Oomoo`3GOole00000d[M0000000A0004C[`0
0`00C[a>_003C[`A0004@W`40002AW`70002AW/70002BW/90003BW/00`00BW]:N`03BW/:0003BW/0
0`00CWY>NP06CWX00`00CWY>NP03CWY=0005DWT00`00DWUBN@07DWT00`00DWUBN@02DWTD0005DWT0
0`00DWUBN@03DWT90005DWT00`00DWUBN@03DWT:0005DWT00`00DWUBN@03DWT:0005DWT00`00DWUB
N@050002DWT00`00DWUBN@06DWT50006EYT70005EYT01000EYUFVEJI1@000UJI00<005JJEYX01@00
0eJI00<005JJEYX01@000UJJ00@005JJEYYFVPD0009FVP03001FVUJJ00<000EFVP03001FVP000080
00AFVP@000AF^P<0009F^P04001F^UJjE[X:0003E[X30002E[X00`00E[]F^`030004E[/40003E]/3
00000eKK000000020003E]/80003F_/20003F_`700001E[l00000000F_`00`000e/L0P0000=K7@00
000010000e/m0P0000=K?@000000100000=KGP0000000P0000=KGP000000200000=GO`0000009P00
00=7W`000000800000=?O`0000005@0000=CO`000000300000EGG`00000005MN00l00003Eeh00000
01000003Egl0000000D00003Egl0000000T00003Egl0000000D00005Dgl00000001CO`0700000e=o
0000000900000e>O0000000H00000e=o0000000500000e=o00000004000014mo000000000Woo00<0
07ooOol08Goo001OOol00`00Oomoo`3IOold0004B]d00`00C]e>g@03C]dC0004C[/00`00C[]>^`03
C[/=0002AW/5000014Il0016NdIk1P000dYk1P001DYk2P000dYk00<004YjBWX00dYj4`000dij00<0
04ijCWX01Tij00<004ijCWX01dij00<004ijCWX01dij00<004ijCWX01dij00<004ijCWX01Tij00<0
04iiCWT01dii00<0059iDWT01e9i00<0059iDWT01e9i00<0059iDWT00U9i2P001E9i00<0059iDWT0
1e9i00<0059iDWT00e9i2P00159i00<0059iDWT01U9i1`001E9i00<0059iDWT01U9i1`001E9i00<0
059iDWT00U9i2000259i00<0059iDWT01@000U9i00@005JIEYUFV@D0009FN@03001FVEJI00EFV@H0
00EFV@D000IFV@D000IFVPD000EFVPD000IFVP@000AFVP<0009FVP03001F^UJj00<000AF^PD0009F
^P<0009F^P03001F^UJj00<000AF^P@000=F^`@0009Ff`03001Ff`0000800004E]/000000002F]/0
0`00E]/00002000015[K000000000U[K00<005[k00000P0000=Jo00000001P0000EJo000000005[l
00<00003Fa`005/L00T00003Fcd005/m01@00003Egh0000000800003Egl0000001`00003Ail00000
00L00003Ail0000000H00003Bil0000002800003Dgl0000001400003Del0000000D00003Eel00000
01000003Eeh0000001400003Egl0000000D00003Egl0000000T00003Egl0000000@00003Dgl00000
00800003Dgl0000000@00003Dgl0000000T00003Dil0000000D00003Dil0000000T00003Dil00000
00D00003Dgl0000000@00003Cgl0000000d0009oo`03001oogoo021oo`00Ggoo00<007ooOol0fWoo
?@0014jl00<004jlC[`00djl4`0014jK00<0049K@U/00`000T9k100014Ik1@0014Ik1@0014Yk1`00
0dYk00<004YjBWX00dYj2@000dYj00<004ijCWX01dij00<004ijCWX00dij4`0014ij00<004ijCWX0
1Tij00<004ijCWX01dij00<004ijCWX01dij00<004iiCWT00Tii7@001E9i00<0059iDWT0259i00<0
059iDWT00U9i2P001E9i00<0059iDWT01e9i00<0059iDWT01@000U9i00<0059iDWT0259i00<0059i
DWT01@000U9i00<0059iDWT01E9i1`001E9i00<0059iDWT00e9i20001U9i1@001eIi00<005JIEYT0
1@000eJI00<005JIEYT01@000UJI00@005JIEYUFV@D0009FV@04001FVUJJEYX50002EYT00`00EYYF
VP050003EYX00`00EYYFVP050002EYX00`00EYYFVP030004EYX40003E[X40002E[X00`00E[X00002
0004E[X40003E[X40002E[X00`00E[/000020004E]/4000015KK000000000e[K100000AJf`000000
00AJf`<00005F_`00000001Jo0030002F_`30002F_`20003Fa`600000e/M00000003Fcd600000e/m
0000000@00000eMo0000000L00000dNO0000000600000dNO0000000/00001E=o00000000Dgl03`00
00=CG`000000100000=GGP0000000P0000=GGP000000300000=GGP0000004@0000=GO`0000001000
00=GO`0000001@0000EGO`00000005Mo00L00005Dgl00000001CO`0700000e=o0000000900000e>O
0000000500000e>O0000000900000e>O0000000400000dnO0000000H0002Ool00`00Oomoo`0POol0
05moo`03001oogoo0=]oodH000A>^`03001>VdjK00=>Va400092F`@00096F`H000=6FPH000=:NPH0
00E:NPT000=:NP03001>NTij00=>NPX000=>NP03001>NTij00I>NP03001>NTij00M>NP03001>NTij
00=>NRH000EBN@03001BNE9i00MBN@03001BNE9i00IBN@03001BNE9i00=BNA@000EBN@03001BNE9i
00MBN@03001BNE9i009BN@P000QBN@03001BNE9i009BN@P000MBN@03001BNE9i00D0009BN@03001B
NE9i00IBN@L000EBN@04001BNE9iDWT50002DWT00`00EWUFN@05EWT50006EYT50006EYT50006EYT5
0005EYT50006EYX50006EYX40004EYX30002EYX00`00E[X000020004E[X40004E[X30002E[X00`00
E[X000020004E[X40004E]/300000eKK000000020003F]/30002F]/30003F]/8000015[l00000000
0U[l0`0000=Jo00000000P000U/L1P0000EK7@00000005/m00L00003Fcd0000000800003Feh00000
00/00003Egl0000001H00003Bkl0000001h00003Bil0000001X00003Dgl0000001000003Del00000
00T00003Eeh0000000d00003Eeh0000001000003Eeh0000000D00003Egl0000000D00005Egl00000
001GO`0700000e=o0000000900000e=o0000000900000e>O0000000400000e>O0000000900000dnO
0000000P000014mo000000000Woo00<007ooOol07goo001OOol00`00Oomoo`3MOom>0004CY/00`00
CYY>VP07CYX00`00@UY2FP030002@U/40004AU/50004AUX40005BWX70002BWX00`00BWY:NP03BWX:
0003CWX00`00CWY>NP03CWXC0004CWX00`00CWY>NP06CWX00`00CWU>N@06CWT00`00CWU>N@07CWT0
0`00CWU>N@07CWT00`00DWUBN@07DWT00`00DWUBN@07DWT00`00DWUBN@02DWT:0005DWT00`00DWUB
N@07DWT00`00DWUBN@07DWT00`00DWUBN@02DWT:0005DWT00`00DWUBN@03DWT:0005DWT00`00DWUB
N@02DWT80008DWT00`00DWUBN@050002DWT00`00DWUBN@06DWT50007DWT00`00EWUFN@050002EWT0
1000EYUFVEJI1@000UIi00<005JIEYT00eJI0`000UJI00<005JIEYT00eJI0`000UJI00<005JIEYT0
0UJI0`000UJI00<005JJEYX00eJJ0`000UJJ00@005JJEYYFVPD0009FVP03001FVUJJ00<000=FVP@0
00AF^P<0009F^P03001F^UJj00<000=F^P@000AF^P<0009F^P03001FfeKK00L0009Jf`03001Jf`00
0080009Jf`<00003F]/005[K00<00004F_/000000002F_/30002F_`30002F_`30002Fa`600001E/M
00000000Fcd00`0000EK?@00000005/m00@00003Feh0000001X00003Dil0000000L00003Bkl00000
02h00003Cgl0000001D00003Del0000000D00003Del0000001P00003Eeh0000000D00003Eeh00000
01400003Egl0000000@00003Egl0000000800003Egl0000000@00003Egl0000000D00005Dgl00000
001CO`0;00000e>O0000000A00000dnO0000000H00000dmo0000000<0002Ool00`00Oomoo`0OOol0
05moo`03001oogoo0=ioob0000=6g@03001:_4Zl00I:_003001>_4jl00I>_003001>VdjK00M>V`03
001>VdjK00I>V`03001>VdjK00=>Va400092FP<000=6FPH000=6FPH0009:FPD00003BWX004YJ00A:
FPT000=:NP03001>FTiJ00=>FPX0009>NP03001>NTij00M>NP03001>FDiI00=>FD<000EBN@03001B
NE9i00MBN@03001BNE9i009BNA@000EBN@03001BNE9i00=BN@X000EBN@03001BNE9i00EBN@L000EB
N@03001BNE9i00=BN@P000QBN@03001BNE9i00D0009BN@03001BNE9i00EBN@D000IFN@D000QFN@03
001FV@00008000IFV@03001FV@00008000EFV@03001FV@00008000IFV@03001FVP00008000AFVPD0
00EFVPD000=FVP<0009F^P03001F^UJj00<000AF^P@000=F^P<0009F^P03001F^UJj00<000AF^PL0
00AJf`@000=Jf`80009Jf`@00004F_/000000002F_/300000e[l000000020002F_`300000e[l0000
000500000e/M0000000500000e/m0000000600000e]N0000000J00000e>O0000000l00000e=o0000
000A00000e=O0000000500000e=O0000000@00000eMN0000000=00000eMN0000000<00001EMN0000
0000Egl01`0000=GO`0000002@0000=GO`0000001@0000=CO`0000003@0000=CW`0000004@0000=?
W`000000400000=?O`00000060000Woo00<007ooOol07Woo001OOol00`00Oomoo`3OOom=0004DWX0
0`00CWY>NP07CWX00`00@SY2>P030002@UX30005AUX40005AUX40004BUX70003BUX00`00BUY:FP03
BUX:0003CUX00`00CUU>F@03CUT90004CWX00`00CUU>F@06CUT00`00CUU>F@06CUT00`00CUU>F@07
CUT00`00CUU>F@07CUT00`00CUU>F@07CUT00`00DWUBN@06DWT00`00DWUBN@07DWT00`00DWUBN@08
DWT00`00DWUBN@02DWT90005DWT00`00DWUBN@07DWT00`00DWUBN@03DWT:0005DWT00`00DWUBN@07
DWT00`00DWUBN@050002DWT00`00DWUBN@06DWT70005DWT00`00DWUBN@03DWT80007DWT00`00DWUB
N@050002EWT01000EWUFNEIi1@000UIi00<005IiEWT01UIi10001UJI1@001UJI10001eJI100015JJ
0`000UJJ00<005JJEYX01@000eJJ00<005JJ00000P0015Jj10000eJj10000UJj00<005Jj00000P00
15Jj100015Jj0`0000AF^`00000000AJf`<0009Jf`03001Jf`0000800004F]/000000002F]/30003
F_/20002F_`30002F_`700001E/L00000000Fad01P0000=K?@0000001`0000=KGP000000<P0000=3
WP000000>00000=CG`000000100000=GGP0000001@0000=GGP0000002@0000=GGP000000300000=G
GP0000003@0000EGGP00000005Mo00L00003Egl0000000T00003Egl0000000@00003Dgl0000000h0
0003Dil0000001000003Cil0000000T00003Cil0000002<0009oo`03001oogoo01ioo`00Ggoo00<0
07ooOol0hGoo5P000T:n00<004JlA[`00dJl4`000TjK00<004jKCY/01TjK00<004jJCYX01djJ00<0
059jDWX00U9j4000148j0`000THj0`000dIJ00<004IJAUX00`000dIJ00<004YJBUX01P001DYJ1`00
1TYJ00<004iICUT00diI2@000diI00<004iICUT00diI7@0014iI00<004iICUT01TiI00<004iICUT0
1diI00<0059iDWT00U9i7P00159I00<0059iDWT0259i00<0059iDWT00U9i2P001E9i00<0059iDWT0
1e9i00<0059iDWT00U9i2000259i00<0059iDWT01@000U9i00<0059iDWT01U9i1`001E9i00<0059i
DWT00U9i20001UIi1@0025Ii00<005IiEWT01@000UIi00<005JIEYT01@000eJI00<005JIEYT01@00
0UJI00@005JIEYUFV@D0009FV@03001FVUJJ00<000=FVPD000IFVP@000AF^P<0009F^P03001F^P00
008000AF^P@000AF^P<0009F^P03001F^UJj00<00006E[/00000001Ff`000U[K0`0015[K0`0000AJ
f`000000009Jf`<00003F_/005[k00<00004F_`000000002F_`60002Fa`300000e/L000000040000
1E/m00000000Fcd0300000=KGP000000:`0000=3WP0000004`0000=?W`0000005@0000=CO`000000
2@0000=CG`0000003@0000=GGP0000002@0000=GGP000000300000=GGP000000300000=GGP000000
0P0000=GO`000000100000=GO`0000001@0000EGO`00000005Mo00L00003Dgl0000000d00003Dil0
000000T00003Cil0000003L00004Cgl000000002Ool00`00Oomoo`0MOol005moo`03001oogoo0>9o
oah00096_003001:VdZK00M:V`03001>VdjK00=>VaX000EBNP03001BNE9i00IBN@030012>@000080
00A2>P<00096>P<00003AUX004IJ00=6FP@000M:FP@000I:FP03001:FDYI00D00003BUX004iI00M>
F@03001>FDiI00=>F@X000=>F@03001>FDiI00I>F@03001>FDiI00M>F@03001>FDiI00=>FA`000EB
F@03001BFE9I00MBF@03001BFE9I00MBF@03001BFE9I00MBF@03001BNE9i009BN@X000EBN@03001B
NE9i00MBN@03001BNE9i009BN@X000EBN@03001BNE9i00=BN@P000QBN@03001BNE9i00D0009BN@03
001BNE9i00EBN@L000EBN@04001FNEIiEWT50002EWT00`00EWUFN@06EWT50005EWT50006EYT50006
EYT50005EYT50003EYX30002EYX01000EYYFVUJJ1@000UJJ00<005JjE[X00`000eJj100015Jj0`00
0UJj00<005JjE[X00`0015Jj10000UJk0P000eKK10000e[K20000e[K0P000e[k0`0000AJo0000000
009Jo0H000=K70800003Fa`0000000@00005Fcd00000001K?@09000015]N000005]N9`0000=3WP00
00000P0000=3WP0000002`0000=;W`0000002P0000=?O`0000001@0000=CO`0000003@0000=CG`00
00001@0000=CG`000000300000=GGP0000002@0000=GGP000000700000EGGP00000005Mn00L00003
Egl0000000D00005Egl00000001GO`0700000e=o0000000=00000e>O0000000900000dnO0000000_
00000dmo0000000<0002Ool00`00Oomoo`0MOol005moo`03001oogoo0>Aoo`T0008fWPH00092WA/0
00=>V`03001>NTij00I>NP03001>NTij00I>NP03001BNU9j00QBNP03001BNE9i009BN@H00092>@80
0092>P030016>DHi00<00096>P@000E6FP@000E:FP03001:FDYI00D00003BUX004YI00I:F@L000A>
F@03001>FDiI00I>F@03001>FDiI00=>F@T000A>F@03001>FDiI00M>F@03001>FDiI00I>F@03001>
FDiI00I>F@03001>FDiI00M>F@03001BFE9I00QBF@03001BFE9I00IBF@03001BFE9I009BFA@000EB
F@03001BNE9i00QBN@03001BNE9i009BN@T000EBN@03001BNE9i00=BN@X000EBN@03001BNE9i00IB
N@D000MBN@03001BNE9i00D0009BN@03001BNE9i00IBN@D000QFN@03001FNEIi00D0009FN@03001F
NEIi00D0009FN@04001FVEJIEYT50002EYT01000EYUFVEJI1@000UJI00<005JIEYT01@000eJI00<0
05JJ00000P0015JJ1@001UJJ10000eJj0`000UJj00<005JjE[X00`0015Jj10000eJj10000UJj1000
0UKK0`000U[K00<005[K00000P0000AJf`000000009Jf`03001Jf`0000800003F_/0000000800004
F_/000000003F_`500000e/L001K7009000015/m000000000U/m200000=KGP000000:00000=3WP00
0000500000=;W`0000003P0000=CO`0000003@0000=CG`0000001@0000=CG`000000300000=GGP00
0000600000=GGP0000001@0000=GGP0000001@0000=GGP0000002@0000=GO`000000100000=GO`00
00000P0000=GO`000000100000=CO`0000003P0000=CW`0000002@0000=?W`000000700000=;W`00
00003P0000=?O`0000003P0000A?O`000000009oo`03001oogoo01aoo`00Ggoo00<007ooOol0i7oo
3`000T:L1@0000=2W@00AW/014Ik2@000TYk00<004ijCWX00dij9@00159I00@0048I00000092>@@0
00A6>@@0009:>@H000=:>@D00003BUX004YI00E:F@L000=:F@03001>FDiI00=>F@X000=>F@03001>
FDiI00I>F@03001>FDiI00=>FD<000EBF@03001BFE9I00MBF@03001BFE9I00QBF@03001BNE9i009B
N@X000ABF@03001BNE9i00IBN@L000EBN@03001BNE9i00QBN@03001BNE9i00D0009BN@03001BNE9i
00EBN@D000QBN@03001BNE9i00D0009FN@03001FNEIi00EFN@H000EFN@D000IFN@D000IFV@D000EF
V@D000IFV@@000AFVP<0009FV@03001FVUJJ009FVP@0009FVP03001F^P00008000AF^P@000AF^P<0
009F^P03001F^P00008000AF^P<0009Ff`<000=Jf`@00004F]/000000004F]/3000015[k00000000
0U[k0`0000=Jo000F_`01@000e/L1P0000AK7@00001K?@<00003Fcd0000000L00003Feh0000002L0
0003?ih0000000`00003Ail0000001H00003Dgl0000000h00003Del0000000`00003Eeh0000000D0
0003Eeh0000000`00005Eeh00000001GGP0700000eMN0000000500000eMN0000000400000eMN0000
000500001EMn00000000Egl01`0000EGO`00000005Mo00L00003Dgl0000000T00005Dil00000001C
W`0;00000dnO0000000900000dnO0000000900000d^O0000000D00000d]o0000000>00000dmo0000
00060002Ool00`00Oomoo`0LOol0021oo`@000ioo`<000eoo`H001Moo`03001oogoo0>Iooa0000A2
W0L000=6N`03001:NTYj00=:NPT000=>NP03001>NTij00I>NP03001>NDii00I>N@03001BNE9i00MB
N@03001BFE9I00MBF@0300126D8I00<00092>@<000E6>@<000E:>@@000E:>@L0009:F@03001:FDYI
00=:F@P000E>F@03001>FDiI00=>F@T000A>F@03001>FDiI00I>F@03001>FDiI00M>F@03001>FDiI
00I>F@03001>FDiI00M>F@03001BFE9I00MBF@03001BFE9I00MBF@03001BFE9I00IBF@03001BFE9I
00QBF@03001BFE9I009BFA@000EBF003001BFE9I00MBF@03001BNE9i00D0009BF003001BNE9i00QB
N@03001BNE9i009BN@P000MBN@03001BNE9i00D0009BN@03001BNE9i00IBN@D000MFN@03001FNEIi
00D000=FN@03001FNEIi00D0009FN@03001FNEIi00=FN@<0009FN@03001FVEJI00=FV@<0009FV@03
001FVEJI009FV@<0009FV@03001FVEJI00=FV@<0009FV@03001FVUJJ00<000EFV@03001FVP000080
00AFVP@000AF^P<0009F^P03001F^UJj00<000=F^P@000AF^P<0009F^P<000=Jf`<0009Jf`<000AJ
f`<00004F]/000000003F_/20003F_`60002Fa`600000e/M000000040002Fcd800000e]N00000008
00000eMo0000000L00000cnN0000000Y00000e=o0000000900000e=O0000000=00000eMN00000004
00000eMN0000000=00001EMN00000000Eeh01`0000=GGP000000100000=GGP0000003@0000EGOP00
000005Mo00L00005Egl00000001GO`0700000e=o0000000900001E>O00000000Dil02`0000=?W`00
0000900000=;O`000000500000=;O`000000200000A;O`000000009oo`03001oogoo01]oo`007Woo
20002goo1@002Woo2P0057oo00<007ooOol0jGoo0P0000<1=`00000010000S9m2@001DIk2@000dYj
00<004ijCWX00dij:`00148I0`000THi0`000THi00<004XiBST00`000dXi00<004XiBST01@0000=:
>@00BST014Xi1`001DYI00@004iICUU>F@D00003CUT004iI00I>F@03001>FDiI00=>FA@000=>F@03
001>FDiI00M>F@03001>FDiI00M>F@03001BFE9I00MBF@03001BFE9I00IBF@03001BFE9I00MBF@03
001BFE9I009BF@X000EBF003001BF59H00MBF003001BF59H00MBF003001BFE9I009BF@P000QBF003
001BNE9i009BN@X000EBN@03001BNE9i009BN@P000QBN@03001BNE9i00D0009BN@03001FNEIi00EF
N@D000IFN@D000QFN@03001FN@00008000IFN@03001FV@00008000EFV@03001FV@00008000IFV@03
001FV@00008000AFV@@000IFV@@000AFVP<0009FVP03001F^UJj00<000AF^P@000=F^P<0009F^P03
001F^UJj00<0009F^P<00003F[X005[K00<0009Jf`<00004F]/005[KF]/300001e[K00000000F_/0
05[k00<00003F_`0000000D0009K70H0009K70D0009K?@P00003Feh0000000P00003Egl0000001`0
0003?ih0000000L00003@ih0000001<00003Cgl0000000d00003Del0000001@00003Eeh0000000<0
0003Eeh0000000<00003Eeh0000000P00003Eeh0000000800003Eeh0000000@00003Eeh0000000D0
0003Eeh0000000`00003Eeh0000000800003Egl0000000@00003Egl0000000800003Egl0000000@0
0003Dgl0000000T00003Dil0000000800003Dil0000000T00003Cil0000002800003Bgl0000001@0
0003Bgl0000000P00003Bgl0000000H0009oo`03001oogoo01]oo`007Woo0P0017oo0P002goo1@00
2Woo0`001Goo0`004goo00@007ooOomoo`D00>=oo`<00081=`<00003;Ud0000000800092F`/00096
N`03001:FTYJ00=:FPX0009>NP03001>FDiI00M>F@03001>FDiI00I>F@03001BFE9I00IBF@03001B
F59H00MBF004001660000004@QT20004AST40004BST300000dXi001:>@05BST50005BST01000BSQ:
>4Xh1@0000=:F@00CUT01TiI1`000diI00<004iICUT01TiI00<004iHCUP01diH00<004iHCUP00diH
>@001E9H00<0059HDUP01e9H00<0059HDUP01e9H00<0059HDUP00U9H2P001E9H00<0059HDUP01U9H
1`001E9H00<0059iDWT01E9i1`001E9i00<0059iDWT01U9i1@001e9i00<005IiEWT01@000UIi00@0
05IiEWUFN@D0009FN@03001FNEIi00IFN@@000IFN@D000IFV@@000MFV@@000AFV@<0009FV@03001F
VEJI00D0009FV@03001FVUJJ00<000AFVP@000=F^P@0009F^P03001F^P00008000AF^P@0009F^P<0
009J^P@000=Jf`8000=Jf`@0009Jf`8000=Jn`<00005F_`00000001Jo0030002F_`60002Fa`50002
Fcd800000e]N0000000V00000c^M0000000N00000dmo0000000=00000e=O0000000<00000eMN0000
000900000eMN0000000D00000eMN0000000=00000eMN0000000<00001EMN00000000Egh01`0000=G
O`0000002@0000=CO`0000002@0000ECW`00000005>O00/00003Cil0000003P00003Bgl0000000P0
0003Bgl0000000P00004Bel000000002Ool00`00Oomoo`0JOol001eoo`8000Ioo`8000Yoo`D001=o
o`8001=oo`@00>Uoo`D00003:Q`0000000800004;Ud000000005@U/40002AUX60006BUX00`00CUU>
F@03CUT90003CUT00`00CUU>F@07CUT00`00DUUBF@06DUT00`00DUQBF006DUP01000AQQ664HH0`00
00=26@00AQP00`0014Hi0`001DXi10001DXi00@004XhBSQ:>0D00003BST004Xh00I:>0@000I>F@03
001>>4hh00=>>0T000A>F@03001>F4iH00I>F003001>F4iH00I>F003001>F4iH00M>F003001>F4iH
00M>F003001BF59H00MBF003001BF59H00IBF003001BF59H00MBF003001BF59H00QBF003001BF59H
009BF1<000EBF003001BF59H00QBF003001BF59H00D0009BF003001BF59H00MBF003001BNE9i00D0
009BN003001BNE9i00QBN@03001BNE9i00D0009BN@03001BNE9i00EBN@D000IFN@D000QFN@03001F
NEIi00D0009FN@03001FNEIi00D000=FN@03001FVEJI00D0009FV@04001FVEJIEYT50002EYT00`00
EYUFV@030003EYT50006EYT40004EYX30002EYX00`00E[X000020004E[X40004E[X30002E[X40002
F[X30002F]/00`00F]/0000200000e[K000000020002F]/40002F_/7000015[l000000000U[l1P00
0e/L1@0000=K?@0000000`0000AK?@00001KGTP00003Cgl0000000h00003Del0000000`00003Eeh0
000000T00003Eeh0000000P00003Eeh0000000T00003Eeh0000000`00003Eeh0000000d00005Eeh0
0000001GOP0700000eMo0000000900000e=o0000000900001E>O00000000Dil02`0000=?W`000000
3@0000=;W`0000002@0000=;W`0000006P0000=;O`000000200000=;O`000000200000=;G`000000
1`0000=oo`00Ool06goo000MOol20006Ool2000;Ool3000EOol2000BOol00`00Oomoo`3[Ool00`00
F:0000020002:Q`40002?U/30003@U/00`00AUY6FP030002AUX00`00BUU:F@0500000dYJ001>F@07
CUT00`00CUU>F@03CUTQ0005AQP30003AQP20002AST00`00BQQ:60030003BST00`00BSQ:>0050000
0dXi001:>006BSP40006BSP00`00CSQ>>00500000diI001>>007CSP00`00CSQ>>003CSPC0004CUP0
0`00CUQ>F007CUP00`00CUQ>F006CUP00`00DUQBF007DUP00`00DUQBF007DUP00`00DUQBF007DUP0
0`00DUQBF002DUP:0004DUP00`00DUQBF007DUP00`00DUQBF008DUP00`00DUQBF002DUP80007DUP0
0`00DUQBF002DUP80008DWP00`00DWUBN@02DWT80007DWT00`00DWUBN@050002EWT01000EWUFNEIi
1@000UIi00<005IiEWT01UIi1@001EIi1@001UIi1@001UJI1@001UJI10000eJI0`000UJI00<005JI
EYT00eJI0`000UJI00<005JJEYX00`000eJJ100015Jj0`000UJj00<005JjE[X00`000eJj0`000UZj
0`0015[K0`0000AJf`00000000AJf`<0009Jn`H0009Jo0<0009Jo0H00003Fa`005/L00D00003Fcd0
000000<00003Fcd0000004d00003Cgl0000001400003Deh0000000D00003Eeh0000000T00003Eeh0
000000P00003Eeh0000000T00003Eeh0000000`00003Eeh0000000`00003Eeh0000000800003Egh0
000000@00003Egl0000000D00005Egl00000001CO`0;00000e>O0000000200000e>O000000090000
0dnO0000000A00000d^O0000000900000dNO0000000D00000d]o0000000800000d]o0000000G0002
Ool00`00Oomoo`0IOol001aoo`8000Qoo`80029oo`80019oo`03001oogoo0>aoo`03001HX00000<0
008Z7003000^?0000080008nF`@000E6FP@000I:F@L000A>F@03001>FDiI00E>F@03001>F4iH00M>
F003001BF59H00IBF003001BF59H00IBF0040015n0000005AQP20004AQP40004BQP40007BSP40006
BSP00`00CSQ>>00500000dXh001>>006CSP70004CSP00`00CSQ>>006CSP00`00CSQ>>006CSP00`00
CUQ>F003CUPj0005DUP00`00DUQBF007DUP00`00DUQBF007DUP00`00DUQBF002DUP:0005DUP00`00
DUQBF002DUP:0005DUP00`00DWQBN006DWP70005DWP00`00DWUBN@02DWT80006EWT50008EWT00`00
EWUFN@050002EWT00`00EWUFN@050002EWT00`00EWUFN@03EWT30002EWT00`00EYUFV@03EYT30002
EYT00`00EYUFV@02EYT40002EYT00`00EYT000020006EYT00`00EYT000020004EYT40003EYX30002
E[X00`00E[YF^P030004E[X40003E[X30002F[X30004F]/3000015[K0000000015[K0`000U[K1P00
0U[l0`0000=Jo00000000P0000=K700000000e/L1P0000=K?@0000000`0000=K?@0000000`0000=K
GP000000BP0000=CO`0000003@0000=CGP000000100000=GGP0000002@0000=GGP000000200000=G
GP0000002@0000=GGP0000003@0000=GGP000000300000EGGP00000005Mn00L00003Egl0000000D0
0005Egl00000001CO`0;00001E>O00000000Dil02`0000=?W`000000;@0000=7O`0000000`0000=;
O`000000200000=;O`00000070000Woo00<007ooOol06Goo000LOol20008Ool2000ROol2000BOol0
0`00Oomoo`3]Ool01000F:00026k0`0000<Z700000000Shj0`000SiK10001DIJ1P000TYI00<004iI
CUT00diI2P000diI00<004iHCUP01TiH00<0059HDUP01e9H00<0059HDUP01U9H00<004GhAOP00P00
0dHH00@004HH000000E660<000E:60@000E:>003001:>4Xh00D00003BSP004hh00I>>0D000E>>003
001>>4hh00=>>0X000=>>003001>>4hh00M>>003001>F4iH00I>F003001>F4iH00M>F003001>F4iH
00I>F003001BF59H00MBF003001BF59H00MBF003001BF59H00MBF003001BF59H00MBF003001BF59H
009BF1@000EBF003001BF59H00EBF0L000EBF003001BF59H00QBF003001BN59h00D0009BF003001B
N59h00EBN0L000EBN004001FNEIiEWT50002EWP00`00EWUFN@06EWT50005EWT50008EWT00`00EWT0
00020006EWT00`00EYT000020005EYT00`00EYT000020004EYT40007EYT40003EYT40002EYX00`00
EYX000020004E[X40004E[X30002E[X00`00E[X000020002F[X3000015Zj001Jfe[K0`0000IJf`00
000005[K0002F]/30002F]/60003F_`20002F_`300001E/L00000000Fa`01`0000=K?@0000000`00
00=K?@0000000`0000=KGP0000000P0000=KOP000000700000<gO00000000`0000<kO@0000002`00
00=;W`0000008@0000=CGP0000000`0000=GGP0000000`0000=GGP0000001@0000=GGP0000003000
00=G?P0000001@0000=GGP000000300000=GGP0000003@0000EGGP00000005Mn00L00003Egl00000
00@00003Egl0000000800003Dgl0000000T00005Dil00000001CW`0?00000d^O0000000W00000dMo
0000000300000dMo0000000800000d]o0000000R0002Ool00`00Oomoo`0HOol001aoo`8000Qoo`80
029oo`80019oo`03001oogoo0>eoo`800003F:00000000<0008Z708000<n>P<000=6>@H000E:>@H0
00I>F@03001>>4hh00=>>24000=5n004001664HH0003AQP30002AQP00`00BQQ:60030002BQP01000
BQQ:64XH1@0000=:>000BSP01DXh1@001Dhh00@004hhCSQ>>0D00003CSP004hh00M>>003001>>4hh
00=>>1<000A>F003001>F4iH00I>F003001>F4iH00M>F003001BF59H00MBF003001BF59H00MBF003
001BF59H00IBF003001BF59H009BF0X000EBF003001BF59H00MBF003001BF59H00MBF003001BF59H
00D0009BF003001BF59H00QBF003001BF59H009BF0P000MBF003001BN59h00D0009BN003001BN59h
00IBN0D000QFN003001FNEIi00D0009FN@03001FNEIi009FN@<0009FN@03001FNEIi00IFN@@000MF
N@@000IFV@@000AFV@<0009FV@03001FVEJI00=FV@<0009FV@03001FV@00008000AFVP@000AF^P<0
009F^P03001F^UJj00<000=F^P@000=J^P8000=J^P@0009Jf`8000=Jf`@0009Jf`H00003F_/005[l
00<00004F_`000000002F_`200001E/L00000000Fa`00`0000=K?@000000100000=K?@0000001`00
00=KOP000000700000<gO00000005@0000=;W`0000005@0000=CG`0000002@0000=GGP0000001@00
00=GGP0000001@0000=GGP000000300000=G?P0000001@0000=GGP000000300000=GGP0000003000
00=GGP0000000P0000=GOP000000300000EGO`00000005=o00/00003Dil0000000800003Dil00000
00d00005Bil00000001;W`0S00000dMo0000000>00000d]o0000000>00000d]o0000000G00000goo
001oo`0IOol001aoo`8000Qoo`80029oo`80019oo`03001oogoo0>ioo`800004F:0000008K/40000
0chJ00000004?SX30005AST40005BST00`00CSQ>>00500000diI001>>007CSP00`00CSQ>>006CSP0
0`00DSQB>007DSP00`00DSQB>006DSP01000AOL000000TGh0`001THH0`001DXH10001dXH10001DXh
00@004hhCSQ>>0D00003CSP004hh00I>>0L000=>>003001>>4hh00I>>003001>>4hh00M>>003001>
>4hh00=>>3T000EBF003001BF59H00MBF003001BF59H00MBF003001BF59H009BF0P000MBF003001B
F59H00IBF0L000EBF003001BF59H00EBF0D000QBN003001BN59h00D0009FN003001FN5Ih00IFN0D0
00MFN@03001FN@00008000IFN@03001FNEIi00D0009FN@04001FNEIiEWT50002EWT00`00EYUFV@05
0002EYT00`00EYUFV@030006EYT00`00EYT000020003EYT40004EYX30002EYX00`00E[YF^P030004
E[X40003E[X30002F[X00`00F[X0000200000eZj000000020002F]X40002F]/30002F]/400000e[k
00000003F_/3000015[l000000000U[l1P0000EK7000000005/m00H00003Fcd0000000L00003Fgh0
000001/00003<g/0000001X00003Cgl0000001d00003Eeh0000000D00003Eeh0000001@00003Ech0
000000@00003Ech0000000d00003Eeh0000000`00005Eeh00000001GGP0700000eMo000000050000
1EMo00000000Dgl02`0000ECW`00000004nO01000005Bil00000001;W`0Q00000dMo0000000O0000
0d]o0000000L0002Ool00`00Oomoo`0GOol001aoo`8000Qoo`80025oo`8001=oo`03001oogoo0>io
o`@000036IX0026k00@0008n6P<00004?SX004HIAQT30003AST00`00BSQ:>00500000dXi001>>005
CSP70004CSP00`00CSQ>>005CSP00`00DSQB>007DSP00`00DSQB>006DSP01000AOM5mdGg0P000TGh
0P001dHH0P001dXH0`001TXH00<004XHBQP00`000TXh00<004hhCSP01Thh10001Thh00<004hhCSP0
0dhh2@0014hh00<004hhCSP01Thh00<004hhCSP01dhh00<004hhCSP01Thh00<0058hDSP01e8h00<0
059HDUP01e9H00<0059HDUP01e9H00<0059HDUP01U9H00<0059HDUP0259H00<0059HDUP01e9H00<0
059HDUP00U9H2@001E9H00<0059HDUP0259H00<0059HDUP01@000U9H00<0059HDUP01e9H00<0059H
DUP01@000U9H00<0059hDWP01U9h1@0025Ih00<005IhEWP01@000UIh00<005IiEWT01EIi10001eIi
1@001UIi1@001EIi1@001UJI10001eJI10000eJI0`000UJI00<005JJEYX00`0015JJ10000eJj1000
0UJj00<005Jj00000P0015Zj0`0000AJ^P00000000AJfP<0009Jf`<000=Jf`<00005F_/00000001J
n`04000015[l000000000e[l1@0000EK7000000005/m00H00003Fcd0000000L00003Fgh0000003`0
0003Cgl0000000D00003Del0000001400003Eeh0000000@00003Ech0000000P00003Ech0000000T0
0003Ech0000000D00003Ech0000000`00003Eeh0000000D00003Eeh0000000D00003Eeh0000000T0
0003Egl0000000@00003Egl0000000800003Dgl0000000T00005Dil00000001?W`0?00000d^O0000
000200000d^O0000000A00000d>O0000000f00000d]O0000000F0003Ool00`00Oomoo`0FOol001ao
o`8000Qoo`8001Uoo`8000Eoo`<001=oo`03001oogoo0>moo`@000066IX000008K/003Wi0P000chJ
0`0014HI10001dXh10001Dhh00<004hhCSP00dhh2P000dhh00<0058hDSP01U8h00<0058hDSP01e8h
00<004GgAOL00TGg00@004Gh00165`<000A66003001:5`00008000A:6003001:64XH00<000=:6003
001:64XH00=:60@000Q>>003001>>4hh00D00003CSP004hh00M>>003001>>4hh00=>>0X000A>>003
001>>4hh00I>>003001>>4hh00I>>003001B>58h00MB>003001BF59H00MBF003001BF59H00MBF003
001BF59H00MBF003001BF59H009BF1@000ABF003001BF59H00QBF003001BF59H009BF0P000MBF003
001BF59H009BF0P000QBF003001BN59h00D0009BF003001FN5Ih00IFN0D000MFN003001FNEIi00D0
009FN003001FNEIi00=FN@<0009FN@03001FNEIi00=FN@<0009FN@03001FNEIi009FN@<0009FN@03
001FVEJI00=FV@<0009FV@04001FVEJIEYT50002EYT00`00EYT000020004EYT40004EYX30002EYX0
0`00E[X000020004E[X40004F[X3000015Zj0000000015[J0`000U[K0`000e[K0`000U[K0P0000AJ
n`000000009Jo0<00003F_`005[l00D00005Fa`00000001K7@0600000e/m0000000800000e]n0000
001300000e=O0000000@00000eMN0000000>00000eLn0000000300000eLn0000000500000eLn0000
000500000eLn0000000400000eLn0000000500000eMN0000000500000eMN0000000400000eMN0000
000500001EMn00000000Egl01`0000EGO`00000005=o01000003Cil0000001400003Ail0000001H0
0003@il0000003000003Bel0000001D00003Bel0000000@0009oo`03001oogoo01Ioo`0077oo0P00
27oo0P006Goo2@0057oo00<007ooOol0kgoo0`0000HEF@006IXIVP008K/200000cWi00000003?QX3
0005AQT30006BSP00`00BSQ:>00500000dhh001>>007CSP00`00CSM>=`03CSLH0004AOL30003AQL2
0002AQP00`00BQM:5`02BQL20002BQP00`00BQQ:6003BQP40008BQP40005CSP00`00CSQ>>005CSP7
0004CSP00`00CSQ>>006CSP00`00CSQ>>003CSPC0004CSP00`00DSQB>007DSP00`00DUQBF006DUP0
0`00DUQBF002DUPD0005DUP00`00DUQBF007DUP00`00DUQBF007DUP00`00DUQBF002DUP:0005DUP0
0`00DUQBF005DUP70005DUP00`00DUQBF006DUP50008DUP00`00EWQFN0050002EWP00`00EWQFN005
EWP50008EWP00`00EWT000020006EWT00`00EWT000020005EWT00`00EWT000020006EWT00`00EYT0
00020004EYT50005EYT40004EYT30002EYT00`00EYYFVP030004EYX30004E[X30002F[X00`00F[YJ
^P0300001UZj00000000F[X0009JfP<0009Jf`<00003F]/005[K00<0009Jf`H000=Jo08000=Jo0H0
0004Fa`00000Fad600000e/m0000000800000e]n0000000Z00000dNO0000000E00000e=O00000009
00000e=N0000000D00000eLn0000000500000eLn0000000500000eLn0000000400000eLn00000005
00000eLn0000000500000eMN0000000400000eMN0000000500000eMN0000000500001EMn00000000
Egl01`0000EGO`00000005=o00l00003Cil0000001H00003Ail0000001000003@il0000000<00003
@gl0000004l0009oo`03001oogoo01Eoo`0077oo0P0027oo0P006Goo0P0000=oo`0000000`005Goo
00<007ooOol0l7oo0`0000@EF@006IXIVP800005>OT003Wi>OT00002?QX00`00AQQ660030002AQT0
0`00BQQ:60030003BSP00`00BSQ:>005BSP40006CSP00`00CSM>=`06CSL00`00CSM>=`06CSL00`00
DSMB=`07DSL00`00AOL00005AOL20004AQL40005BQL40007BQP30006BQP01000CQM>5dhG1@0000=>
>000CSP01Thh00<004hhCSP00dhh20001Dhh00<004hhCSP01dhh00<004hhCSP01Thh00<004hhCSP0
0dhh70001E8h00<0059HDUP01e9H00<0059HDUP01e9H00<0059HDUP01e9H00<0059HDUP00U9H2P00
1E9H00<0059HDUP0259H00<0059H000010000U9H00<0059HDUP0259H00<0059HDUP01@000U9H00<0
059HDUP01U9H1@001eIh00<005IhEWP01@000UIh00<005IhEWP01UIh10001UIi1@001UIi10001eIi
10000eJI10000UJI00<005JIEYT00UJI0`000UJI00<005JIEYT00`001EJI0`0015JJ0`0000AF^P00
E[YF^P<000AJ^P@0009J^P8000AJ^P<0009Jf`<000=Jf`<000=Jf`D00003F_/005[l00<0009Jo0H0
0003Fa`0000000L00003Fcd0000000T00003Fgh0000002d00003Bil0000000l00003Del0000000<0
0003Del0000001`00003Ech0000000D00003Ech0000000@00003Ech0000000D00003Ech0000000D0
0003Ech0000000@00003Eeh0000000D00003Eeh0000000D00003Eeh0000000@00003Eeh000000080
0003Egl0000000@00003Egl0000000800003Dgl0000000@00003Dil0000000H00003Cil0000002L0
0003@il0000000<00003@gl0000000<00003@gl0000004h0009oo`03001oogoo01Eoo`007Goo0P00
1Woo0P006Woo0P006goo00<007ooOol0lGoo0`0000@EF@006IXIVP800004>OT00000>OT30005AQP4
0004BQP40008BSP00`00CQM>5`0500000dhh001>=`07CSL00`00CSM>=`06CSL00`00DSMB=`07DSL0
0`00AOM5m`020003AOL01000BOL000001DHG0P001dXG0`001DXH00<004XGBQL00`000dXH00<004hG
CQL01ThG10001Dhh00<004hhCSP01dhh00@004hgCSM>=`D00003CSP004hh00M>>003001>>4hh00I>
>003001>>4hh00M>>003001B>58h00MB>003001B>58h00IB>003001B>58h00MB>003001BF59H00QB
F003001BF59H00IBF003001BF59H009BF0X000EBF003001BF59H00QBF003001BF59H009BF0L000MB
F003001BF59H00IBF0D000QBF003001BF59H00D0009FF003001FN5Ih00EFN0D000QFN003001FN5Ih
00D0009FN003001FNEIi00D000=FN003001FNEIi009FN@<0009FN@03001FNEIi00=FN@<0009FN@03
001FV@00008000IFV@03001FV@00008000AFV@@000EFV@<00003EYT005JJ009FVP8000AF^P<000=J
^P@0009J^P@000=J^P<00003F]X00000008000=Jf`<00003F]/005[K00D000AJn`80009Jo0H0009K
70D00004Fcd00000Fcd;00001E]n00000000Eil0>`0000=CG`000000900000=G?P000000100000=G
?P0000001@0000=G?P0000001@0000=G?P000000100000=G?P0000001@0000=GGP0000001@0000=G
GP000000100000=GGP0000001@0000=GGP0000002@0000=GO`0000004P0000=?W`000000:`0000<o
O`0000000`0000=3O`000000E0000Woo00<007ooOol057oo000MOol20006Ool2000JOol2000KOol0
0`00Oomoo`3aOol4000011EI000IVQVJ0P000SWi00<003Wi>OT00P001dHH0P001TXH10001DXh00<0
04hGCQL01DhG1`000dhg00<004hgCSL01dhg00<0058gDSL01U8g00<004GgAOL00TGg00@004GgAOL0
00=9m`8000=65`04001:5`000005BQL00`00BQM:5`030002BQP00`00BQM:5`03BQL300000dXH001>
5`07CQL00`00CQM>5`0500000dhh001>>007CSP00`00CSM>=`06CSL@0004CSP00`00CSQ>>007CSP0
0`00DSQB>006DSP00`00DSQB>007DSP00`00DSQB>007DSP00`00DUQBF002DUPC0005DUP00`00DUQB
F008DUP00`00DUQBF002DUP:0005DUP00`00DUQBF007DUP00`00DUQBF0050002DUP00`00DUQBF006
DUP50007EUP00`00EWQFN0050002EUP00`00EWQFN006EWP50005EWP50008EWP00`00EWT000020006
EWT00`00EWT000020003EWT40007EYT40004EYT30002EYT01000EYUFVEJI0`0015JI10000eJj0`00
00=F^P00F[X00`0015Zj0`0015Zj0P000e[J0P0015[K0P000e[K1P000e[k0`0000=Jo00000001000
0U/L1@0000=K?@0000001`0000=KGP0000000`0000AKOP00001GWc<00003Cgl0000002000003Ech0
000000P00003Ech0000000D00003Ech0000000D00003Ech0000000@00003Ech0000000D00003Ech0
000000D00003Eeh0000000@00003Eeh0000000D00005Eeh00000001GGP0300000eMN000000090000
0eMo0000000900000e>O0000000500000dnO0000000`00000cmo0000000m00000dMO0000000I0002
Ool00`00Oomoo`0DOol001ioo`8000Aoo`8001]oo`8001Yoo`03001oogoo0?=oo`@000065ET001VJ
000if0000SWi0`0000=5n00000001DHH00@004XG000000A:6004001:5dXGBQL500000dXh001>5`06
CQL00`00CQM>5`03CQLH0004AOL200000dGg0019m`03BOL01000AQM65`000dXG0`000TXG00<004XG
BQL00dXG10001dXG10001ThG00<004hGCQL01DhG1`0014hh00<004hgCSL01Thg00<004hgCSL01Thg
00<004hgCSL00dhg<0001E8h00<0059HDUP01U9H00<0059HDUP0259H00<0059HDUP00U9H2P001E9H
00<0059HDUP01e9H00<0059HDUP00U9H2000259H00<0059HDUP01@000U9H00<005IHEUP01EIH1@00
25IH00<005IhEWP01@000UIh00<005IhEWP00UIh0`000UIh00<005IhEWP01UIh10001eIi10000eIi
0`000UIi00<005JIEYT00eJI0`000UJI00<005JIEYT00`001EJI10001EJI0`0015Jj0P000eJj0`00
15Zj0`000UZj00<005Zj00000P000U[J0`0000=Jf`00F]/00`000U[K0`0000=Jf`00000015[k0P00
00=Jo000000010000e/L1@0000=K?@0000000`0000AKG@00001KGPD00005Fgh00000001GW`0Z0000
0dmo0000000300000dmo0000000J00000eLn0000000500000eLn0000000800000eLn000000050000
0eLn0000000400000eLn0000000300000eLn0000000700000eLn0000000400000eLn000000050000
0eMN0000000500001EMN00000000Eeh03P0000=GO`0000002@0000=CW`0000001P0000=?W`000000
6`0000<oWP000000400000<oO`0000000`0000<oO`000000F@000Woo00<007ooOol04goo000NOol8
000KOol:000BOol00`00Oomoo`3cOol500000aEI00000002>MP20002>OT20002AOP30002AQP01000
BQM:5dXG0`0000=:6000BQL01dXG10001DhG00<004hGCQL01ThG00<004hgCSL01dhg00<004hGCQL0
1ThG00<004Gg00001DGg0P001DWg0`001TXG0`0024XG0`001TXG00<004hGCQL01@0000=>5`00CQL0
1dhG00<004hgCSL00dhg2P000dhg00<004hgCSL01Thg00<004hgCSL01dhg00<004hgCSL01dhg00<0
058gDSL01U8g00<0058gDSL01e8g00<0058gDSL01e8g00<0058hDSP01e8h00<0059HDUP01e9H00<0
059HDUP00U9H2P001E9H00<0059HDUP01e9H00<0059HDUP01E9H1`001E9H00<0059HDUP01U9H1@00
1e9H00<005IHEUP01@000UIH00<005IHEUP01UIH1@001eIh00<005Ih00000P001UIh00<005IhEWP0
1@000UIh00@005IiEWUFN@D0009FN@03001FN@00008000IFN@03001FV@00008000AFV@@000IFV@<0
00EFV@<0009FV@03001F^P000080009F^P<00004F[X005ZjF[X30004F[X30003F]X20003F]/30002
F]/300001e[K00000000F_/005[k00T00003Fa`005/L00D00003Fcd0000000<00003Fed0000000X0
0003Eil0000001l00003@il0000000X00003Cgl0000001@00003Deh0000000d00003Ech0000000P0
0003Ech0000000@00003Ech0000000T00003Ecd0000000P00003Ech0000000D00003Ech0000000D0
0003Eeh0000000@00003Eeh0000000800003Eeh0000000`00003Egl0000000T00005Dil00000001C
W`0400000dnO0000000B00000d>N0000000G00000cmn0000000300000cmo0000001200000dMO0000
000I0002Ool00`00Oomoo`0COol0021oo`@001eoo`X0019oo`03001oogoo0?Aoo`030000]@000080
00035ET0000000<if003000inCWi008000A5n0<000I:5`<000Q:5`03001>5dhG00D00003CQL004hG
00I>5`03001>=dhg00M>=`03001>5dhG00I>5`040015mdGg0005AOL20006BOL20007BQL30006BQL0
0`00BQM:5`030003BQL00`00CQM>5`05CQL50005CQL00`00CSM>=`07CSL00`00CSM>=`03CSL90004
CSL00`00CSM>=`06CSL00`00CSM>=`07CSL00`00DSMB=`06DSL00`00DSMB=`07DSL00`00DSMB=`07
DSL00`00DSQB>007DSP00`00DUQBF002DUP:0005DUP00`00DUQBF007DUP00`00DUQBF007DUP00`00
DUQBF0050002DUP00`00DUQBF008DUP00`00DUQBF0050002DUP00`00DUQBF005DUP50008EUP00`00
EUQFF0050002EUP00`00EWQFN005EWP40007EWP50006EWP50005EWT40007EWT40004EYT30002EYT0
0`00EYUFV@02EYT30002EYT00`00EYUFV@030004EYT30003E[X20004F[X30004F[X30002F[X40002
F]/30002F]/30002F]/20003F_/600000e[l00000003Fa`600000e/m0000000300000e]M00000003
00000e]N0000000400000eNO0000000D00000bmL0000000S00000e=N0000000D00000eLn00000008
00000eLn0000000300000eLn0000000;00000eLm0000000800000eLn0000000500000eLn0000000<
00000eMN0000000A00000eMo0000000900001E>O00000000Dil00`0000=?W`0000002P0000=7W`00
0000600000<kOP0000000`0000<oOP000000H`0000=7G`00000010000Woo00<007ooOol04Woo001M
Ool00`00Oomoo`3dOol300001PCg00000000=KP000<if0<00003@OL0000000A5n08000M:5`<000I:
5`03001>5dhG00E>5`L000=>5`03001>=dhg00I>=`03001>5dhG00M>5`030015mdGg008000=5m`04
0019m`000004BOL00`00BOL000020004BQL00`00BQM:5`030003BQL00`00BQM:5`03BQL40008CQL0
1000CQM>5dhG1@0000=>5`00CSL01dhg00<004hgCSL01Thg00<004hgCSL00dhg2P0014hg00<004hg
CSL01Thg00<0058gDSL01e8g00<0058gDSL01e8g00<0058gDSL01U8g00<0058hDSP00U8h2P001E8g
00<0059HDUP01e9H00<0059HDUP01e9H00<0059HDUP00U9H20001e9H00<0059HDUP01U9H1@001e9H
00<0059HDUP01@000U9H00<005IHEUP01UIH1@001eIH00<005IhEWP01@000UIh00<005IhEWP00eIh
0`000UIh00<005IhEWP00eIh0`000UIh00<005IiEWT00UIi0`000UIi00<005IiEWT00eIi0`000UIi
00<005JIEYT00`001EJI00<005JI00000P0015JI100015JI0`000UJI10000eZj0`0000AJ^P00F[YJ
^P<000=J^P<0009Jf`<0009Jf`<00003F]/000000080009Jn`<00004F_/00000F_`300000e/L0000
0002000015/L000005/m1@0000=KG@0000000`0000=KGP000000100000=GW`000000<P0000=CG`00
00000`0000=CGP000000500000=G?P0000000`0000=G?P0000000P0000=G?P0000000`0000=G?@00
00003@0000=G?@000000200000=G?P000000100000=G?P0000003@0000=GGP000000700000=CW`00
00000P0000ECW`00000004nO00`00003Ail0000000l00003>gd0000007`0009oo`03001oogoo019o
o`00GGoo00<007ooOol0m7oo1@0000D=>000000e^00000@if0800091m`800095n0030019m`000080
00A:5`03001:5dXG00<000=:5`03001>5dhG00I>5`03001>5dhG00=>5`T000=>=`03001>5dhG00M>
5`030015mdGg0095m`040015mdGg0003BOL20002BOL00`00BOM9m`02BOL20002BQL00`00BQM:5`03
BQL300000dXG001:5`06BQL40005CQL00`00CQM>5`06CQL70003CSL00`00CSM>=`06CSL00`00CSM>
=`07CSL00`00CSM>=`03CSL_0005DSL00`00DSMB=`07DSL00`00DUQBF007DUP00`00DUQBF002DUP:
0005DUP00`00DUQBF008DUP00`00DUQBF0050002DUP00`00DUQBF005DUP50007DUP00`00EUQFF003
EUP30002EUP00`00EUQFF005EUP50008EWP00`00EWP000020006EWP00`00EWP000020005EWP00`00
EWT000020006EWT00`00EWT000020005EWT30006EYT40004EYT30002EYT00`00EYUFV@030003EYT3
0004F[X20004F[X30003F[X30002F]X30002F]/30003F]/20002F_/300001E[k00000000F_`00P00
00AK70000000009K70<00003Fcd0000000<00003Fed0000002X00003Ail0000000l00003Del00000
00<00003Deh0000001@00003Ech0000000D00003Ech0000000P00003Ecd0000000`00003Ecd00000
00P00003Ecd0000000D00003Ech0000000`00003Eeh0000001d00005Dil00000001CW`0400000dnO
0000000500000d^O0000000200000dNO0000001f00000dMO0000000B00000dMO00000007000COol0
05eoo`H00?9oo`<000041?L000dh0002=KP00`00>MPif002>MP20003@OL00`00AOP00004BOL20002
BQL00`00BQM:5`03BQL40008CQL00`00CQM>5`06CQL00`00CQI>5P03CQH?0004AOL00`00AOL00005
BOL01000BOM9m`001DWg10001dXG10001DXG00@004hGCQM>5`D00003CQL004hG00M>5`03001>5dhG
00=>5`T000A>=`03001>=dhg00I>=`03001>=dhg00M>=`03001B=e8g00IB=`03001B=e8g00MB=`03
001B=e8g00MB=`03001B=e8g00IB=`03001B=e8g00MB=`03001B=e8g00QB=`03001BF59H009BF0T0
00EBE`03001BF59H00QBF003001BF59H009BF0P000MBF003001BF59H00D0009BF003001BF59H00QB
F003001FF000008000EFF003001FF5IH009FF0<0009FF003001FN5Ih00IFN0@000MFN0@000IFN0@0
00MFN@@000EFN@<00003EWT005JI00=FV@<0009FV@03001FVEJI00<000AFV@@000=FV@<0009J^P03
001J^P00008000=J^P<00003F[X005Zj00<0009JfP<00003F]X00000008000=Jf`<00004F]/00000
0002F_/200000e[l000000040003Fa`200000e/m0000000300000e]M0000000700000e]n0000000G
00000c]n0000000:00000d]o0000000A00000e=N0000000<00000eLn0000000500000eLn00000005
00000eLn0000000800000eLm0000000400000eLm0000000500000eLm0000000800000eLm00000005
00000eLn0000000<00000eMN0000000M00001E>O00000000Dil0300000E;W`00000004NN01/00003
=gh0000007X0009oo`03001oogoo015oo`00GGoo00<007ooOol0mGoo100000@4m`000000008e^007
000if3WH>MP0047G00000d7g0`001DWg10001dXG0`001ThG00<004hGCQL01ThG00<004hFCQH01ThF
00<004hFCQH01dhF00<004GF000014Gg0P001TWg0`0024Wg0P001dXG00<004hGCQL00`000TXG00<0
04hGCQL01ThG10001ThG00<004hGCQL01ThG00<004hGCQL00dhG2P000dhg00<004hgCSL01dhg00<0
058gDSL01U8g00<0058gDSL01e8g00<0058gDSL01e8g00<0058gDSL01U8g00<0058gDSL0258g00<0
058gDSL00U8g2P00158g00<0059GDUL01e9G00<0059HDUP01U9H1`001E9H00<0059HDUP01E9H1@00
1e9H00<0059HDUP01U9H100025IH00<005IH00000P001UIH00<005IhEWP01@000UIh00<005IhEWP0
0eIh0`000UIh00<005IhEWP00UIh0`000UIh00<005IiEWT00eIi0`000UIi00<005IiEWT00UIi0P00
15Ii00<005JI00000P0015JI100015JI0`000UJI00<005JI00000P0015Zj0`000eZj0`000eZj0`00
0e[J0P000e[J0P0015[K0P0000EJf`00000005[k00@00003F_`0000000<00003Fa`005/L00<00003
Fcd0000000<00003Fcd0000000H00003Fgh0000002800003Bgl0000000<00003Cgl0000000d00003
Deh0000000@00003Dch0000000d00003Ech0000000@00003Ecd0000000P00003Ecd0000000D00003
Ecd0000000D00003Ecd0000000P00003Ecd0000000@00003Ecd0000000d00003Eeh0000001000003
Egl0000000h00003Dil0000000D00003Bil0000000800003Bil0000001/00003=gh0000004l00003
Ael0000001800003Ael0000001T00003Ool007oo019oo`00GGoo00<007ooOol0mWoo0P0000<0]@00
1?L00`000SFh00@003WH>MP00091e`030011md7g0091m`8000M9m`8000I:5`03001>5dhG00D00003
CQL004hG00Q>5`03001>5ThF00E>5P03001>5ThF00M>5P040015eTGF0004AOL20007BOL20007BOL0
1000BOL000001DXG00<004hGCQL00dhG100024hG00<004hGCQL01@0000=>5`00CQL01dhG00<004hG
CQL01dhG00<004hgCSL00dhg2@0014hg00<0058gDSL01e8g00<0058gDSL01e8g00<0058gDSL01U8g
00<0058gDSL01e8g00<0058gDSL00U8g2P001E8g00<0058gDSL01U8g00<0059GDUL0259G00<0059H
DUP01@000U9G00<0059HDUP01e9H00<0059HDUP01@000U9H00<0059HDUP0259H00<0059HDUP01@00
0UIH00<005IHEUP01EIH10001eIH1@0025Ih00<005Ih00000P001EIh00<005Ih00000P001UIh00<0
05Ii00000P001UIi100015Ii100015JI0`000UJI00<005JIEYT00`0015JI0`0015Zj0`000UZj1000
0eZj0`0000=J^P00F]X00`000U[J0`0000=Jf`00F]/00`0000=Jf`0000000e[k0P0000=Jo0000000
0`0015/L0P0000=K?@0000000`0000=K?@0000001`0000=KOP000000100000=C_`000000600000=;
O`0000000`0000=?O`0000000`0000=CG`000000200000=CGP0000000`0000=C?P0000003P0000=G
?P0000001@0000=G?@000000200000=G?@0000001@0000=G?@000000100000=G?@000000200000=G
?@0000001@0000=G?@000000300000=GGP0000004@0000=GO`0000003@0000=CW`0000001P0000E;
W`00000004NO09<00003Ael0000000h00003Ool007oo019oo`00GGoo00<007ooOol0mWoo10000PCg
00<003FG00000SFh00<003WH00000d7G0P000T7g00@004Gg000000E9m`040019m`000004BQL00`00
CQM>5`05CQL70004CQL00`00CQI>5P06CQH00`00CQI>5P06CQH01000AMI5eTGF0P000TGg00@004Wf
000000E9m`040019mP000005BOL01000BOM9mdWg0`000TXG00<004hGCQL01ThG0`001ThG00<004hG
CQL01DhG1@001ThG00<004hGCQL01ThG00<004hgCSL01Thg00<004hgCSL00dhg<0001E8g00<0058g
DSL01e8g00<0058gDSL01e8g00<0059GDUL00U9G20001e9G00<0059HDUP01E9H1@001e9H00<0059H
DUP01U9H1@001eIH00<005IHEUP01@000UIH00<005IHEUP00eIH0`000UIH00<005IhEWP01UIh1000
1UIh10001eIh10001eIi0`0015Ii0`000UJI00<005JIEYT00`001EJI0`0015JI0`0000AJV@00F[YJ
^P<000=J^P<000AJ^P8000AJ^P8000=JfP8000=Jf`<00004F]/000000002F_/300000e[k00000003
0003Fa`300000e/L0000000300000e/m0000000600000e]n0000000400000e>o0000000L00000dmo
0000000300000e=O0000000800000e=N0000000300000e<n0000000>00000eLn0000000700000eLm
0000000800000eLm0000000400000eLM0000000500000eLm0000000800000eLm0000000500000eLm
0000000<00000eMN0000000A00000eMo0000000=00001E>O00000000Cil0100000E;W`00000004NO
01<00003;e`0000008/00003Ael0000000D001=oo`00GGoo00<007ooOol0mWoo1@0000D4m`00=ILe
U`00008e^08000E1e`030011m`0000=5m`8000=9m`040019mdWgBOL30002BQL00`00CQM>5`05CQL0
0`00CQI>5P03CQH:0003CQH00`00CQI>5P06CQH00`00AMI5eP03AMH00`00AOL00003BOH20003BOL0
1000BOI9mTWf0`000TWg00<004WgBOL014Wg0`0024hG00<004hGCQL00`000dhG00<004hGCQL01ThG
00@004hGCQM>5`D00003CQL004hG00M>5`03001>=dhg00I>=`03001>=dhg00M>=`03001B=e8g00MB
=`03001B=e8g00MB=`03001B=e8g00IB=`03001B=e8g00MB=`03001B=e8g00MB=`03001B=e8g00MB
=`03001B=e8g009B=`X000EB=`03001BEe9G00MBE`03001BF59H00D0009BE`03001BF59H00QBF003
001BF59H00D0009BF003001FF5IH00EFF0D000QFF003001FF000008000IFF003001FN5Ih00D0009F
N003001FN5Ih009FN0<0009FN003001FN5Ih00=FN0<0009FN003001FNEIi00=FN@<0009FN@03001F
N@00008000EFV@<000EFV@<00003EYT005JI009FV@8000AJV@<000=J^P<0009J^P03001J^P000080
00=J^P<00003F]X000000080009Jf`<0009Jf`8000=Jn`800003F_/0000000<000AK70800003Fa`0
000000<00003Fcd0000000L00003Fih0000000@00003Dkl0000001T00003Cgl0000000<00003Cel0
000000P00003Deh0000001@00003Ecd0000000P00003Ead0000000P00003Ead0000000D00003Ead0
000000D00003Ecd0000000@00005Ecd00000001G?@0600000eLm0000000=00000eMN0000000@0000
0eMn0000000>00001E>O00000000Cil00`0000=;W`0000000P0000=7W`000000F@0000=3G`000000
<P0000=7G`0000006@004goo001MOol00`00Oomoo`3gOol400000`Cg00000002=IL00`00=KPe^002
0005@ML00`00@OL00004AOL01000BOM9m`001TWg0`001dhG00<004hFCQH01dhF00<004hFCQH00dhF
2@000dhF00<004GFAMH014GF00<004Gg000014Wf0P000TWg00<004WfBOH00dWf0`0024Wg0`001ThG
00<004hGCQL00dhG100024hG00<004hGCQL01ThG1`000dhG00<004hgCSL01dhg00<004hgCSL01Thg
00<0058gDSL01e8g00<0058gDSL01e8g00<0058gDSL01U8g00<0058gDSL01e8g00<0058gDSL01e8g
00<0058gDSL00U8g2P001E8g00<0058gDSL0258g00<0059GDUL00U9G1`001e9G00<0059HDUP01U9H
1@001e9H00<005IHEUP01@000UIH00<005IHEUP01UIH10001eIH1@001eIh00<005Ih00000P001UIh
00<005Ih00000P001UIh00<005Ii00000P000eIi10001EJI0`0000=FV@00EYT00UJI0`0015JI1000
0eZI0`0000=JV@00F[X00`001EZj0P0015Zj0P000e[J0P000U[K0`000U[K0`0000=Jn`0000000P00
00=Jn`0000000`0000=K7000Fa`02@0000=K?@0000001P0000EKWP00000005NO00800003Dkl00000
00X00003>gh0000000X00003Cgl0000000h00003Deh0000000h00003Ech0000000D00003Ecd00000
00H00003Ead0000000<00003Ead0000000800003Ead0000000L00003Ead0000000@00003Ead00000
00D00003Ecd0000000P00003Ecd0000000`00003Eeh0000000T00003Eeh0000000D00005Egh00000
001GO`0;00000e>O0000000200001DnO00000000Bil00`0000=7WP000000L`0000=7G`0000009`00
00=7G`0000003P004goo001MOol00`00Oomoo`3gOol600002C6G000eUcFG000e^000@ML00005@ML2
0005AOL30008BOL30006CQL00`00CQI>5P06CQH00`00CQI>5P06CQH00`00CQI>5P03CQH50006AMH2
0006BOH30007BOH20007BOL00`00CQI>5P030004CQL00`00CQM>5`05CQL40006CQL00`00CQM>5`06
CQL00`00CQM>5`03CQL90004CSL00`00CSM>=`07CSL00`00DSMB=`06DSL00`00DSMB=`07DSL00`00
DSMB=`07DSL00`00DSMB=`07DSL00`00DSMB=`02DSL90005DSL00`00DSMB=`07DSL00`00DSMB=`06
DSL70004DUL00`00DUMBE`08DUL00`00DUQBF0050002DUL00`00DUQBF005DUP50008EUP00`00EUQF
F0050002EUP00`00EUQFF003EUP30002EUP00`00EWQFN005EWP40007EWP40007EWP40003EWT30002
EWT00`00EYUFV@02EYT20004EYT40005EYT30004FYT20003FYT30005F[X300000eZj001J^P030002
F]X3000015[J000000000U[K0`000e[k0P0000=Jn`0000000`0015/L1@0000AK?@00001K?@T00004
Fih00000Eilg00000eLn0000000200000eLn0000000700000eLm0000000400000eLM000000050000
0eLM0000000;00000eLM0000000500000eLM0000000500000eLm0000000800000eLm0000000<0000
0eMN0000000900000eMN0000000500001EMn00000000Egl02`0000ECW`00000004nO00@00003Bil0
000000H00003?id0000007`00003Ael0000001800003Ael0000001T0019oo`00GGoo00<007ooOol0
n7oo0`0000D0]@00<ILaU`00008eU`800091e`030011ed7G00=1e`8000I5m`8000M9m`03001=mTgf
00D00003CQL004hF00M>5P03001>5ThF00I>5P03001>5ThF00I>5P030015eP0000I5eP8000M9mP80
00I9mP030019mP00008000A9m`03001>5ThF00=>5P<00003CQL004hG00I>5`04001>5dhGCQL50000
0dhG001>5`07CQL00`00CQM>5`06CQL00`00CQM>5`03CQLD0003DSL00`00DSMB=`02DSLN0004DSL0
0`00DSMB=`07DSL00`00DSMB=`08DSL00`00DSMB=`050002DSL00`00DUMBE`06DUL00`00DUMBE`06
DUL50007DUL00`00DUQBF0050002EUP00`00EUQFF006EUP50008EUP00`00EUP000020005EUP00`00
EWQFN002EWP30002EWP00`00EWQFN003EWP30002EWP00`00EWQFN002EWP40002EWP00`00EWT00002
0006EWT40004EYT30005EYT30002FYT00`00FYT000020002FYT300000eZj001J^P03F[X20003F[X3
0003F]X200001E[J00000000F]/010000e[k0`0000=Jn`0000000`000e/L1@0000=K?@0000002P00
00EKWP00000005NO02h00003Dch0000000D00003Ech0000000/00003Ead0000000D00003Ead00000
00D00003Ead0000000@00003Ead0000000800003Ead0000000L00003Ead0000000@00003Ead00000
00P00003Ecd0000000T00005Ecd00000001GGP0;00000eMN0000000400000eMn0000000200000eMo
0000000400000e>O0000000200001E>O00000000Cil00`0000=;_`000000E@0000=3G`000000D@00
00=7G`000000200017oo00<007ooOol04Goo001MOol00`00Oomoo`3hOol50003<IL00`00=ILeU`02
0002@ML20003@ML00`00AOH00005AOL01000BOH000001DWg00<004gfCOH01Dgf10001ThF00<004hF
CQH01ThF00<004hFCQH01ThF00<004GFAMH00P0014GF00<004Wf00001TWf00@004Wf000000A9mP03
0019mTWf0099mP8000=9m`03001>5ThF00E>5P@000E>5`03001>5dhG00I>5`L000=>5`03001>5dhG
00I>5`03001>5dhG00M>5`03001>5dhG00M>5`03001B=e8g00=B=`P000EB=`03001B=e8g00MB=`03
001B=e8g00MB=`03001B=e8g00IB=`03001B=e8g00QB=`03001B=e8g009B=`P000MB=`03001BEe9G
00MBE`03001BEe9G00D0009BE`03001BEe9G00EBE`D000MFF003001FF5IH00=FF0<0009FF003001F
F5IH00IFF0@000QFF003001FN000008000IFN003001FN000008000EFN003001FN000008000EFN0<0
00MFN@<000AFV@<0009FV@03001FVEJI00<000EJV@8000=JV@8000EJ^P@00003F[X000000080009J
^P@00003F]X0000000=Jf`8000AJn`800003F_/0000000<000AK70D00003Fcd0000000<00003Fed0
000000@00004Fih00000EilV00000e=N0000000300000e<n0000000700000eLn0000000900000eLM
0000000700000eLM0000000400000eLM0000000500000eLM0000000;00000eLM0000000500000eLM
0000000800000eLm0000000900000eLm0000000<00000eMN0000000500000eMn0000000900000e>O
0000000600001DnO00000000Bkl0L00000=3G`0000004P0000=3G`0000004P0000=7G`0000004P00
3Woo00<007ooOol04Goo001MOol00`00Oomoo`3iOol50003<IL01000=ILeU`00147G00@0047G@ML0
0095mP8000=5m`040019mTWfBOH30002BOL00`00COI=mP06COH00`00COI=mP0500000dhF001>5P08
CQH00`00CQI>5P05CQH00`00AMI5eP02AMH01@00AMI5eTGF00000TWf0P0014Wf00@004WfBOI9mP80
0099mP030019mTWf00A9mP@000Q>5P03001>5ThF00<000=>5`03001>5dhG00I>5`03001>5dhG00=>
5`L000I>5`03001>5dhG00I>5`03001>5dhG00M>5`03001B=e8g00IB=`03001B=e8g00MB=`03001B
=e8g00MB=`03001B=e8g00MB=`03001B=e8g00MB=`03001B=e8g009B=`X000EB=`03001B=e8g00MB
=`03001BEe9G009BE`P000QBE`03001BE`0000@0009BE`03001FF5IH00QFF003001FF000008000EF
F003001FF5IH00=FF0<0009FF003001FF5IH00EFF0@000MFN0@000IFN0@000EFN0<00003EWP005Ii
00AFN@<0009FN@03001FV@00008000EFV@<000EJV@<00003FYT00000008000EJ^P<00004F[X00000
0004F[X3000015[J000000000U[K0`0000=Jf`00F_/00`0000=Jn`0000000`0000=K7000Fa`01@00
00=K?@0000000`0000=KG@000000100000EKWP00000005No02<00003Deh0000000<00003Dch00000
00P00003Ech0000000P00003Ead0000000P00003Ead0000000D00003Ead0000000D00003Ead00000
00T00003Ead0000000L00003Ead0000000@00005Ead00000001G?@0;00000eLm0000000<00000eMN
0000000500000eMn0000000900000e>O0000000500000dnO0000000200000d^o0000001B00000cmO
0000001A000IOol00`00Oomoo`0@Ool005aoo`03001oogoo0?Yoo`H0008aU`03000eUcFG008000A1
e`030011e`0000A5mP040015mdGg0006BOH30008COH00`00COI=mP05COH70004CQH00`00CQI>5P06
CQH00`00AMI5eP02AMH01000AMI5eP0014Wf00D004WfBOI9mP0000E9mP040019mTWf0008BOH20007
CQH00`00CQI>5P03CQH40008CQL00`00CQM>5`06CQL01000CQM>5dhG1@0000=>5`00CQL024hG00<0
04hGCQL01ThG00<0058gDSL01U8g00<0058gDSL0258g00<0058gDSL01U8g00<0058gDSL01e8g00<0
058gDSL00U8g2P001E8g00<0058gDSL01e8g00<0058gDSL01E8g1`001E8g00<0059GDUL01U9G1000
1e9G00<005IHEUP01UIH10002EIH00<005IH00000P001EIH00<005IHEUP01@000UIH00<005IhEWP0
0eIh0`000UIh00<005IhEWP00UIh0`000UIh00<005IhEWP00UIh0P001EIh00<005Ii00000P0015Ii
0`001EJI0`0000=FV@00FYT00eZI0P000eZI0P001EZj0`0000AJ^P00000000AJ^P<0009JfP8000=J
f`8000AJf`800003F_/0000000<000AK70D00003Fcd0000000<00003Fed0000000@00004Fih00000
EklQ00000e<n0000000>00000eLn0000000C00000eLM0000000700000eLM0000000400000eLM0000
000800000eLM0000000800000eLM0000000500000eLM0000000<00000e/m0000000800000eMN0000
000200000eMN0000000400000eMn0000000900000e>O0000000600000dnO0000001`00000d=O0000
000B00000d=O0000000L000SOol00`00Oomoo`0@Ool005aoo`03001oogoo0?Yoo`80000501400000
;GH00002<IL01@00=IL003ff0000147G0P001DGf0P0000=5m`00BOH01TWf0P001dgf00<004gfCOH0
1Tgf00<004hFCQH00dhF2P000dhF00<004GFAMH00dGF0P0000=5eP00BOH00dWf0P0000=9mP00BOH0
1DWf0`0024Wf00@004gf000000E>5P03001>5ThF00I>5P@000I>5`03001>5dhG00E>5`03001>5dhG
00I>5a4000=>5`03001B=e8g00MB=`03001B=e8g00MB=`03001B=e8g00IB=`03001B=e8g009B=`X0
00EB=`03001B=e8g00MB=`03001B=e8g00MB=`03001B=e8g00D0009B=`03001B=e8g00QB=`03001B
Ee9G00D0009BE`03001BEe9G00MBE`03001FF5IH00D0009FE`03001FF5IH00IFF0@000IFF0D000QF
F003001FN000008000EFN003001FN000008000IFN0@000EFN0@000AFN@<00003EYT005JI00=FV@80
00EFV@@0009JV@<00004FYT005ZjF[X300001UZj00000000F[X0009J^P<0009JfP<00003F]X00000
008000=Jf`<00003F_/0000000<000=K70D00003Fcd0000000<00003Fed0000000@00005Fih00000
001G_`0=00000d]o0000000>00000e<n0000000>00000eLN0000000C00000eLM0000000800000eLM
0000000500000eLM0000000800000eLM0000000600000eLM0000000700000eLM0000000<00000e/m
0000000800001EMN00000000Eeh01`0000=GOP0000002@0000ECW`00000005>O00@00003Cil00000
00H00003@ih0000004/00003?el0000003`00003@el0000000P002aoo`03001oogoo011oo`00G7oo
00<007ooOol0ngoo0P0000@04@00;GH000<aU`05000eU`00?KH00004@ML20006AOH20007BOH01000
COH000001Dgf00<004gfCOH01Tgf00<004hFCQH01dhF00<004hFCQH00dhF1@001TGF0P001TWf0P00
24Wf0P001dWf00@004gfCOI=mP<0009>5P03001>5ThF00I>5P04001>5ThFCQH500000dhG001>5`06
CQL00`00CQM>5`07CQL00`00CQM>5`07CQL00`00DQMB5`03DQLU0005DSL00`00DSMB=`07DSL00`00
DSMB=`07DSL00`00DSMB=`02DSL80007DSL00`00DSMB=`06DSL50007DUL00`00DUMBE`05DUL50008
EUL00`00EUQFF0050002EUP00`00EUQFF002EUP30002EUP00`00EUQFF006EUP40006EWP40007EWP3
0005EWP30002EWP01000EWUFNEIi0P001EJI10001EJI0`000eZI0P0015ZI0`000UZj0P0015Zj0`00
0e[J0P000e[J0P0015[K0P0000=Jn`0000000`0015/L1@0000=K?@0000000`0000=KG@0000001000
00AKWP00001G_`/00003Bgl0000000<00003Cel0000000P00003Dch0000000h00003Eah0000000h0
0003Ead00000008000=G7@P00003Ead0000000L00003Ead0000000@00005Ead00000001G7@060000
0eLM0000000800000eLM0000000=00000e/m0000000400001E/n00000000Eeh00`0000=GGP000000
1@0000=GOP0000002@0000ECW`00000005>O00d00003@ih0000006@00003@el0000002L003Ioo`03
001oogoo011oo`00G7oo00<007ooOol0ngoo0P0000D04@00000]MP0000<aU`80008m]P070011ed7G
@ML004GF00001TGf0P001TWf00@004gfCOI=mP<0009=mP03001=mTgf00I=mP03001>5ThF00M>5P03
001>5ThF00I>5P030015eP0000I5eP8000I9mP8000M9mP04001=mP000005BOH00`00COI=mP04COH3
0008CQH00`00CQI>5P06CQH40006CQL00`00CQM>5`06CQL00`00CQM>5`07CQL00`00DQMB5`06DQL0
0`00DQMB5`07DQL00`00DSMB=`07DSL00`00DSMB=`06DSL00`00DSMB=`07DSL00`00DSMB=`08DSL0
0`00DSMB=`02DSL90005DSL00`00DSMB=`08DSL00`00DSMB=`050002DSL00`00DUMBE`07DUL00`00
DUMBE`050002EUL00`00EUMFE`06EUL50007EUP00`00EUP000020005EUP00`00EUQFF003EUP30002
EUP00`00EWQFN002EWP30002EWP00`00EWQFN003EWP30002EWP00`00EWQFN0030005EWP40005EYT3
0005EYT30002FYT40003FYT300000eZi000000020003F[X300000eZj001JfP030002F]X300000e[K
001Jf`0900000e/L001K700500000e/m0000000300001E]M00000000Fgh00P0000EKWP00000005No
00h00003Cel0000000P00003Dch0000000h00003Ead0000000P00003Ead0000000D00006Ead00000
001G7@000ULM1P0000=G7@000000200000=G7@0000001@0000=G7@000000200000=G7@0000001P00
00=G7@0000003P0000=K?@0000001@0000=K?P0000001@0000=GGP0000005@0000=CW`0000002`00
00=3WP000000B00000<oG`0000007@0000=3G`0000001`0000=3G`0000004P00@7oo00<007ooOol0
47oo001LOol00`00Oomoo`3kOol300001@0A000002ef00000c6G00D003ff?KHm]P000091e`040015
eTGF0005AOH01000BOH0000014Wf00<004gfCOH014gf0`002Dgf00<004hFCQH01ThF00<004hFCQH0
1ThF00@004GFAMH000E5eP030019eP0000E9mP040019mP000005BOH01000COI=mTgf0`000TWf00<0
04gfCOH01Tgf10001ThF00<004hFCQH01ThF00<004hFCQH01@0000=>5`00CQL024hG00<004hGCQL0
1ThG00<0058GDQL01U8G00<0058GDQL01e8G00<0058gDSL01e8g00<0058gDSL01U8g00<0058gDSL0
258g00<0058gDSL00U8g2P00158g00<0058gDSL01e8g00<0058gDSL01U8g1@001e8g00<0059GDUL0
1E9G1@001eIG00<005IGEUL00eIG0`000UIG00<005IHEUP01EIH10002EIH00<005IH00000P001EIH
00<005Ih00000P001UIh00<005Ih00000P001EIh0`001UIh0`001EJI0`000UJI00<005JIEYT00`00
15ZI0P0015ZI0P000eZi0P0015Zj0P0015Zj0P000e[J0P0015[K1@0000=Jn`00000015/L1@0000=K
?@0000000`0000AKG@00001KOP<00004Fih00000Ekl<00000dmO0000000C00000e<n000000030000
0eLM0000000800000eLM00000007000015LM000000000eLM1`0000=G7@0000001P0000=G7@000000
1`0000=G7@000000100000EG7@00000005LM00H00003Fad0000000P00003Fad0000000D00003Fcd0
000000D00003Fch0000002X00003?id0000004d00003?el0000002L00003@el0000000P004Uoo`03
001oogoo011oo`00G7oo00<007ooOol0o7oo0P0000<04@0000000Ref00@0036G<IL000@m]P030011
e`0000=5eP8000=5mP040019mTWfBOH20003BOH00`00COI=mP05COH40006COH00`00CQI>5P06CQH0
0`00CQI>5P06CQH01@00AMI5eTGF000014GF00@004WFBMH000A9mP040019mTWfBOH20003BOH00`00
COI=mP04COH30008COH01000COI=mTgf1@0000=>5P00CQH01dhF00<004hFCQH01DhF1`0014hG00<0
04hGCQL01ThG00<0058GDQL01e8G00<0058GDQL01e8G00<0058gDSL01U8g00<0058gDSL01e8g00<0
058gDSL00U8g2P001E8g00<0058gDSL01U8g00<0058gDSL0258g00<0058gDSL01@000U8g00<0058g
DSL01e8g00<0059GDUL01@000U9G00<005IGEUL025IG00<005IG00000P001EIG00<005IHEUP00UIH
0`000UIH00<005IHEUP01UIH10001UIH10001eIh10001EIh0`0000=FN000EWP00eIh0`000UIh00<0
05JIEYT00`001EJI0`0015ZI0`0000=JV@00FYT00`000UZi0`0000=J^P00F[X00`000eZj0`0000=J
fP0000000P000e[K1@0000AJn`00000000=K70D00003Fcd0000000<00005Fed00000001KOP020000
1E^N00000000Ekl02@0000=?G`0000000`0000=C?`000000200000=C?P0000000P0000=C?P000000
3P0000=G7@000000200000=G7@0000000P0000=G7@0000001`0000=G7@000000100000=Fo0000000
200000=G700000001@0000=G7@000000200000=K7@0000001P000e/M1`0000=K?@000000100000=K
?@0000008@0000=?W`0000001`0000<oW@000000D@0000<oG`0000004P0000=3G`0000004P00Dgoo
00<007ooOol047oo001LOol00`00Oomoo`3lOol6000012ef000aUc6G0P0013ff00<0047G000014GF
00@004GfAOH000E9mP040019mTWf0007COH01000COI=mTgf1@0000==mP00CQH01dhF00<004hFCQH0
1ThF00<004GFAMH00TGF00D004GFAMI5eP0000=9eP800099mP030019mTWf00=9mP040019mTWf0008
COH20007COH00`00COI=mP06COH40006CQH00`00CQI>5P06CQH00`00CQI>5P03CQH:0003CQL00`00
DQMB5`07DQL00`00DQMB5`07DQL00`00DSMB=`06DSL00`00DSMB=`02DSL:0005DSL00`00DSMB=`07
DSL00`00DSMB=`07DSL00`00DSMB=`05DSL50007DSL00`00DSMB=`05DSL50007DUL00`00EUMFE`06
EUL40008EUL00`00EUP000020005EUP00`00EUQFF003EUP30002EUP00`00EUQFF002EUP30002EWP0
0`00EWQFN003EWP30002EWP00`00EWQFN002EWP20004EWP00`00EWP000020005EWP30005EYT30000
0eZI001JV@02FYT20004FYT20003F[T20004F[X20004F[X20003F]X20004F]/500000e[k00000004
Fa`500000ell00000003000015]M000005]n0`0000AKWP00001G_`d00003Dcl0000000P00003Dch0
000000h00003Ead0000000800003Ead0000000P00003Ead0000000d00003E_`0000000D00003E_`0
000000H000=G70L00003Ead0000000P00003Fad0000000@0009K7@03001K7E/M00H00003Fcd00000
00D00003Fcd0000000`00003Eeh0000000T00003Egl0000000H00003Cil0000000L00003?id00000
02X00003>el0000000P00003>el0000003800003?el0000000L005eoo`03001oogoo011oo`00G7oo
1@00ngoo100000PUEP00;GH0036G000m]P0013ff0P001DGF00<004Gf00001TWf0`001dgf00<004gf
COH01Tgf10001ThF00<004hFCQH01ThF00<004GFAMH00dGF00@004GFAMH000E9eP040019mTWf0005
BOH30008COH00`00COH000020004COH00`00COI=mP07COH00`00CQI>5P030003CQH00`00CQI>5P06
CQH00`00CQI>5P07CQH00`00CQI>5P03CQHU0005DSL00`00DSMB=`07DSL00`00DSMB=`07DSL00`00
DSMB=`07DSL00`00DSMB=`050002DSL00`00DSMB=`07DSL00`00DSMB=`050002DSL00`00DUMBE`08
DUL00`00EUMFE`050002EUL00`00EUMFE`05EUL40009EUP00`00EUP000020005EUP00`00EUP00002
0006EWP00`00EWP000020006EWP40005EWP30005EWP300000eIi001FV@02EYT30004FYT40003FYT3
00000eZI000000020003F[X300000eZj001J^P030002F]X300000e[J001Jf`050002F_/200000e[l
001K700500000ell0000000300001E]M00000000Fgh00P0000EKWP00000005No00X00003Ccl00000
00P00003Dch0000000P00003Dad0000000D00003Ead0000000/00003E_d0000000P00003E_`00000
00800003E_`0000000L00003E_`0000000@0009Fo003001G75LL00H00003E_`0000000P00003Fa`0
000000D000AK7@L00003Fcd0000000D00003Fcd0000000@00003Fch0000000D00003Eeh0000000T0
0005Egl00000001CW`0400000dnO0000001300000c]O0000000B00000cmO0000000M001VOol00`00
Oomoo`0@Ool005aoo`03001oogoo0?eoo`<000037AH00000008]MP80008m]P03000m]Sff008m]P80
00E5eP8000Q9mP8000I=mP03001=mTgf00M=mP03001=mTgf00D00003CQH004hF00M>5P030015eTGF
00A5eP030015eP0000I9eP030019mP0000M9mP8000M=mP03001=mTgf009=mP8000==mP03001=mTgf
00I=mP03001>5ThF00=>5P@000U>5P03001>5ThF00I>5P03001>5ThF00I>5P03001B5U8F00MB5P03
001B5U8F00MB5P03001B5e8G00IB5`03001B=e8g00MB=`03001B=e8g00MB=`03001B=e8g00MB=`03
001B=e8g009B=`P000MB=`03001B=e8g00EB=`D000MB=`03001BEe9G00IBE`D000MFE`03001FEeIG
009FE`<0009FE`03001FF5IH00IFF0@000IFF0@000MFN0@000MFN0<000EFN0<00003EWP005Ih00=F
N08000AFN@@000IJV@8000AJV@8000=JV@8000AJ^P8000AJ^P8000=JfP8000AJfPD0009Jn`8000=J
o0D00003Gc`0000000<00004Ged00000Fgh600000eNo0000000600000dlo0000000800000e<n0000
000800000e<M0000000700000eLM0000000400000eKm000000020003E_d800000eKl0000000=0000
0eKl000000050004E_`700000eKl0000000800000e/L000000050002Fad900000e/m000000040000
0e/m0000000500000e/n0000000500000eMN0000000900001EMo00000000Dil0CP0000<oG`000000
9`00L7oo00<007ooOol047oo001LOol00`00Oomoo`3mOol3000011dF000UEP000Ref00D003ff?KHm
]P0000<m]P030015eP0000E5eP8000M9mP04001=mP000005COH00`00COI=mP06COH00`00COI=mP05
COH70003CQH00`00AMI5eP05AMH20007BMH20007BOH01000COH000001Dgf00<004gfCOH014gf1000
24gf00<004hFCQH01ThF1P0014hF00<004hFCQH01ThF00<004hFCQH01ThF00<0058FDQH01e8F00<0
058FDQH01e8F00<0058GDQL01U8G00<0058gDSL0258g00<0058gDSL01U8g00<0058gDSL00U8g2P00
1E8g00<0058gDSL0258g00<0058g000010000U8g00<0058gDSL0258g00<0059GDUL00U9G0`000UIG
00<005IGEUL01eIG00<005IG00000P001EIG00<005IHEUP00eIH0`000UIG00<005IHEUP00UIH0`00
0UIH00<005IhEWP00eIh0`000UIh00<005IhEWP00eIh0`000UIh00@005IhEWQFN08000EFN0@000EF
N@8000IJV@<00003FYT005ZI00<0009JV@<00003F[T005Zj00<000=J^P<00003F[X00000008000=J
fPD000=Jn`80009Jo0D00003Gc`0000000<00005Ged00000001KOP0600000eNo0000000>00000e<n
0000000800000e<M0000000800000eLM0000000500001UKm00000000E_`0009Fo@H00003E_`00000
00<0009Fo0<00003E_`00000008000=Fo0<00004E_`000000002E_`900000eKl0000000400001E/L
00000000Fa`01P0000=K7@0000000`0000AK7@00001K7@800003Fad0000000@00003Fcd0000000D0
0003Fch0000000@00003Feh0000000h00003Dil00000070007Uoo`03001oogoo011oo`00G7oo00<0
07ooOol0oWoo0`0000<M5P0000000Ref00D003ff?KHm]P0000<m]P040015eTGF0004AMH00`00BMH0
0006BOH01000COI=mTgf0`000Tgf00<004gfCOH01Tgf00<004gfCOH01Tgf00<004geCOD00dge1@00
1dGF0P001dWF0P001TWf00@004gfCOI=mP8000A=mP03001=mTgf00I=mP<000I=mP03001>5ThF00I>
5P03001>5ThF00=>5PX000=>5P03001>5ThF00M>5P03001B5U8F00MB5P03001B5U8F00IB5P03001B
5e8G00MB5`03001B=e8g00MB=`03001B=e8g009B=`T000EB=`03001B=e8g00MB=`03001B=e8g00IB
=`@000MB=`03001B=e8g00QB=`03001BE`00008000EFE`03001FEeIG00EFE`@000UFE`03001FF000
008000EFE`03001FF000008000IFF003001FN000008000IFN003001FN000008000EFN0@000IFN080
00EFN@<00003FYT005ZI00=JV@8000AJV@8000=JV@8000AJ^@8000=J^P<000=J^P8000AJfPD00003
F_/005[k00800003F_`0000000@00003Ga`0000000<00003Ged0000000L00003Ekl0000000L00003
Dch0000000800003Dch0000000P00003Dad0000000P00003Ead0000000L00004E_d000000003E_`7
000015Kl000000000UKl00<005Kl00000P0000AFo0000000009Fo003001Fo00000800003E_`00000
00/00003E_`0000000D00003Fa`0000000P00004Fad000000002Fad=00000e/m0000000400000e/m
0000000500000e]N0000001500000c]O0000000M00000cmO0000000B0023Ool00`00Oomoo`0@Ool0
05aoo`03001oogoo0?ioo`<000057AH002EF000]MP020003?KH01000?KHm]P000dGF00D004GFAMI5
eP000099eP8000A9mP03001=mTgf00A=mP<000Q=mP03001=mTgf00I=mP03001=mDge00I=m@030019
e@0000I5eP030019e@0000I9eP030019mP0000E9mP03001=mTgf00==mP80009=mP03001=mTgf00I=
mP03001=mTgf00<000==mP03001>5ThF00I>5P03001>5ThF00M>5P03001>5ThF00=>5PT000A>5P03
001B5U8F00MB5P03001B5U8F00IB5P03001B5e8G00MB5`03001B=e8g009B=`X000AB=`03001B=e8g
00MB=`03001B=e8g00QB=`03001B=e8g00D0009B=`03001B=e8g00MB=`03001B=e8g00EB=`@000QF
E`03001FEeIG00D0009FE`03001FEeIG00IFE`@000IFE`@000QFF0<000QFN0<000IFN0<000IFN0<0
0003EWP005Ii009FN@8000EJV@@000=JV@<00003FYT00000008000=J^@<00003F[X00000008000=J
^P<00003F]X005[J00D000AJn`D00004Ga`00000Ga`500000emM0000000800000eNo000000040000
0e<n0000000=00000e<M0000000800000eKm0000000800000eKl0000000200000eKl000000070000
15Kl000000000eKl100000AFo000000000=Fo0@00003E_`0000000@00003E_`00000008000=Fo0L0
0003Fa`0000000@00005Fa`00000001K7@030003Fad3000015/M000005/M300000=K?@0000001@00
00=KGP0000004@0000=CW`0000007`0000<cGP0000004`0000<kG`000000:000S7oo00<007ooOol0
47oo001LOol00`00Oomoo`3oOol300000adF000UEP0200000cVF000m]P02?KH00`00?KH00004AMH0
1000AMI5eP0014WF00D004WfBOI9mP0000Q=mP<000I=mP03001=mTgf00I=mP03001=mDge00I=m@04
0019eDWE0005AMH01000BME9e@001DWF00<004WfBOH00P000dWf00<004gfCOH01Dgf0`0024gf00<0
04gfCOH00dgf100024hF00<004hFCQH01dhF00<004hFCQH01ThF00<0058FDQH00e8F9P001E8f00<0
058gDSL01U8g00<0058gDSL0258g00<0058gDSL01E8g1@001e8g00<0058gDSL01e8g00<0058gDSL0
1@000U8g00<005IGEUL01EIG1@0025IG00<005IGEUL01@000UIG00<005IGEUL00UIG0`000UIG00<0
05IHEUP015IH0`0000=FF000EWP01EIh0`0000=FN000EWP00eIh0`000UIh00<005IhEWP00UIh0P00
15Ih10001EZI0`0015ZI0P000eZI0P0015Zi0P000eZj0P0015Zj0P0015[J1@000e[k1@0000EO7000
000005lL00D00003Ged0000000L00003Ekl0000000X00003Dad0000000D00003Dad0000000P00003
E_d0000000P00003E_`0000000d00003E_`0000000800003E_`0000000<00003E_`0000000800003
E_`0000000<00003E_`0000000D00006E_`00000001Fo0000UKl1P0000=Jo00000001@0000EK7000
000005/L00<000=K7@<00003Fad0000000d00003Fcd0000001T00005Dil00000001;_`1200000c]O
0000000B002FOol00`00Oomoo`0@Ool005aoo`03001oogoo0?moo`<000087AH002EF000]MP00>IH0
00<m]P8000E5eP040015eTGF0004BMH200000dWf001=mP07COH00`00COE=m@030003COH00`00COI=
mP06COH00`00COE=m@06COD01@00BME9eDWE000014GF00D004WEBME9e@0000A9eP030019mTWf0099
mP050019mTWfBOH00008COH20007COH00`00COI=mP06COH40006CQH00`00CQI>5P06CQH00`00CQI>
5P06CQH00`00DQIB5P07DQH00`00DQIB5P07DQH00`00DQIB5P06DQH00`00DQIB5P07DQH00`00DSIB
=P07DSH00`00DSMB=`07DSL00`00DSMB=`07DSL00`00DSMB=`050002DSL00`00DSMB=`07DSL00`00
DSMB=`05DSL50007DSL00`00EUMFE`02EUL30002EUL00`00EUMFE`06EUL50007EUL00`00EUL00002
0005EUL00`00EUQFF002EUP20004EUP00`00EWQFN002EWP20004EWP00`00EWP000020006EWP40005
EWP20005FYT30002FYT00`00FYT000020002FYT300000eZI001J^@030003F[X200000eZj001J^P03
0003F]X50004F_/5000015lL000005lL1@0000=OG@000000400000=C7@0000004P0000=Fo@000000
200000=Fo0000000200000=Fo00000000P0000=Fo00000000`0000=Fo00000000P0000=Fo0000000
200000=Fo00000001`0000AFo000000000=Fo0L00003F_`0000000D00005Fa`00000001K70030000
0e/L001K7@0300000e/M0000000<00000e/m0000000900000e]N0000000900000eNO000000020000
1E>O00000000Bkl0D@001Woo00<007ooOol0UWoo00<007ooOol047oo001LOol00`00Oomoo`3oOol4
00000adF000UEP0200000cVF000m]P03?KH00`00AMI5eP04AMH00`00AMH00006BMH20008COH00`00
COE=m@03COD40009COH00`00COE=m@05COD00`00BME9e@02BMD01@00AMI5eTGF000014WE00D004WF
BMI9eP0000E9mP800003BOH004gf00M=mP04001=mP000005COH00`00COI=mP06COH01000COI=mTgf
1@0000=>5P00CQH01dhF00<004hFCQH01ThF00<0058FDQH01e8F00<0058FDQH01e8F00<0058FDQH0
1U8F00<0058FDQH01e8F00<0058fDSH01e8f00<0058gDSL01e8g00<0058gDSL00U8g20001e8g00<0
058gDSL01e8g00<0058gDSL01@000U8g00<0058gDSL01e8g00<005IG00000P001EIG00<005IGEUL0
0eIG0`000UIG00<005IGEUL01UIG0`002EIG10001eIH10001EIh0`0025Ih0P001EIh0`0000AFN000
FYUJV@<000EJV@8000=JV@8000AJV@8000AJ^P8000=J^P8000AJfP800006F]/00000F_/005[k1@00
0UlL0P0000=O700000000`0000=OG@0000006P0000=Bo@0000001@0000=Fo@0000000`0000=Fo000
00000P0000=Fo0000000200000=Fo000000020000eKl20000UKl0`0000=Fo00000000`000UKl0`00
00=Fo00000000P0000=Fo00000000`0000EFo000000005[l00H00003F_`000000080009K708000=K
70<00003Fad0000000`00003Fcd0000000T00003Feh0000000T00003Eil0000000H00003Bkl00000
03<00003>el000000180011oo`03001oogoo09Ioo`03001oogoo011oo`00Fgoo00<007ooOol0ogoo
0Woo0`0000DM5P009EHUEP00008iUP05000m]Sff?KH00007AMH20007BMH20007COH00`00COE=m@06
COD40006COH00`00COE=m@06COD00`00BME9e@02BMD01@00AMI5eTGF000014WE00@004WFBMH000M9
mP8000Q=mP04001=mTgfCOH30002COH00`00COI=mP06COH00`00COI=mP06COH70003CQH00`00CQI>
5P07CQH00`00DQIB5P06DQH00`00DQIB5P07DQH00`00DQIB5P06DQH00`00DQIB5P08DQH00`00DSIB
=P06DSH00`00DSMB=`02DSL:0005DSL00`00DSMB=`07DSL00`00DSMB=`05DSL50007DSL00`00DSMB
=`05DSL40009EUL00`00EUL000020005EUL00`00EUMFE`03EUL300000eIG001FE`07EUL30008EUP3
0005EWP300000eIh001FN005EWP300000eIh001FN002EWP20004EWP30005FYT300000eZI00000002
0004FYT2000015Zi001J^UZj0P000eZj0P0000=JfP00F]X00`0000=Jf`0000000e[k1@000UlL0P00
00=O700000000P0000=OG@0000005P0000=Bo@0000001@000eKl1@0000=Fo00000003@0000=Fo000
00000`000UKl0`000UKL00<005KlE_`01P000UKL00<005Kl00000P0000AFo0000000009Fo003001F
o00000800003E_`0000000H000=Fo0X00004F_`000000002F_`40002Fa`B00000e/m000000040000
0e]N0000000200000e]N0000000400000eMo0000000200000eNO0000000P00000cMO000000080000
0cMO0000000M000IOol00`00Oomoo`2FOol00`00Oomoo`0@Ool005]oo`03001oogoo0?moo`9oo`80
00065=D001dF000UEP000cVF00<003ff?KH00P001dGF0P001TWF00@004We000000E=mP03001=mDge
00I=m@04001=mDgeCOD500000dgf001=m@07COD00`00BME9e@03BMD01000AMI5eP001DWE00<004WF
000024Wf0P001dgf00<004gfCOH014gf0`0024gf00<004gfCOH01dgf00<004hFCQH00dhF2@0014hF
00<0058FDQH01U8F00<0058FDQH01e8F00<0058FDQH01e8F00<0058FDQH01e8F00<0058fDSH00U8f
2@001E8f00<0058gDSL01e8g00<0058gDSL01e8g00<0058gDSL01@000U8g00<0058gDSL0258g00<0
058g000010000UHg00<005IGEUL01UIG10002EIG00<005IG00000P0015IG00<005IGEUL00eIG0`00
0UIG00<005IHEUP00eIH0`000UIH00@005IhEWQFN08000AFN003001FN5Ih009FN08000AFN0@000=F
N0<00003FYP005ZI00=JV@8000=JV@8000EJV@8000=J^@<000=J^P8000=JfP80009Jf`80009Jn`D0
00=O70800003Ga`0000000800003Ged0000000h00003D_d0000000800003D_d0000000<0009Fo003
001Fo5Kl00D00003E_`0000000P00003E]`00000008000=Fo0<0009Fg003001Fo000008000AFg0L0
00=Fg0@00004E_`000000003E_`400000eKl000000040002E_`00`00E_aFo00:000015[l00000000
0e[l0`000U/L3`0000=K?@0000001`0000=KGP0000002@0000=GO`000000=00000<gG`0000002000
00<kG`0000001`008goo00<007ooOol0UWoo00<007ooOol047oo001KOol00`00Oomoo`3oOol2Ool4
00000adF000UEP020003>IH01@00?KH004Ff00001TGF00<004WE00001DWF00@004WeBOE9m@8000==
mP03001=mDge00I=m@03001=mDge00I=m@L000==m@030019eDWE00A9e@030015eP0000I9e@8000Q9
mP04001=m@000005COH00`00COI=mP06COH40006COH00`00COI=mP06COH00`00CQI>5P06CQH00`00
CQI>5P03CQH:0003DQH00`00DQIB5P07DQH00`00DQIB5P07DQH00`00DQIB5P02DQH:0004DQH00`00
DSIB=P07DSH00`00DSMB=`07DSL00`00DSMB=`05DSL50007DSL00`00DSMB=`06DSL40007ESL00`00
EUMFE`03EUL30002EUL00`00EUMFE`06EUL40008EUL00`00EUL000020006EUL00`00EUP000020005
EUP40007EWP40005EWP20004EWP20005FYP40003FYT200000eZI001JV@02FYT20004F[T20003F[X2
0002F]X3000015[J000000000U[k0P0000INn`00001O7000Ga`200000elL0000000200000emM0000
000200000e]n0000000A0003E_`700000eKl0000000800000eKL000000030002E]`00`00E_`00002
0003E]`40002E]`900000eKL0000000300000eKK0000000200000eKl0000000300000eKl00000005
0004E_`:00000e[l000000020003F_`300000e/L0000000800000e/M0000000900001E/m00000000
Feh02`0000=GO`0000008`0000<gG`0000007@00;7oo00<007ooOol0Ugoo00<007ooOol03goo001K
Ool00`00Oomoo`3oOol3Ool200000aCE000M5P030003>IH01P00?KHm]P00AKH000E5eP040019eDWE
0004BMH00`00BOE9m@03BOD01000COI=mP0024ge00<004geCOD01dge00<004geCOD00dge10001dWE
0P001dWE0P001dWf00@004geCOE=m@<0009=mP03001=mTgf00I=mP04001=mTgfCOH500000dgf001=
mP07COH00`00CQI>5P06CQH00`00CQI>5P07CQH00`00DQIB5P03DQHL0005DQH00`00DQIB5P06DQH0
0`00DSIB=P08DSH00`00DSMB=`06DSL00`00DSMB=`050002DSL00`00DSMB=`08DSL00`00DSMB=`02
DSL30002DSL00`00ESMF=`07ESL00`00EUL000020005EUL00`00EUMFE`03EUL30002EUL00`00EUMF
E`05EUL40008EUL30007EUP20008EWP30005EWP300000eIh001FN0030006FYP20004FYT20004FYT3
0003F[T300000eZj001J^P020002F]X20003F]X200001E[k00000000G_/00P000elL0P0000=O7000
00000P0000=OG@0000000P0000AOOP00001K_`d00003D_`0000000D000=Fg0X00003E]`0000000<0
00EFg0@00003E]`0000000<00003E]/0000000P00003E]/0000000800003E]/0000000<00003E]/0
0000008000=Fo0L0009Fo0`00004F_`000000002F_`00`00F_`0000200000e/L0000000800000e/M
0000000400000e/m0000000200000e/m0000001=000eOol00`00Oomoo`2GOol00`00Oomoo`0?Ool0
05]oo`03001oogoo0?moo`=oo`@000057AH00000>IH00003>IH00`00?KH00002AKH00`00AMI5eP02
AMH01@00BME9eDWE00000dWF00<004WeBOD014We0`0024ge00<004geCOD01dge00<004geCOD01Tge
00<004WEBMD01TWE0P001TWE00@004We000000E9mP03001=mDge00A=m@<000Q=mP03001=mTgf00I=
mP@000I=mP03001>5ThF00I>5P03001>5ThF00M>5P03001B5U8F00IB5P03001B5U8F00MB5P03001B
5U8F00MB5P03001B5U8F00MB5P03001B5U8F00IB5P03001B=U8f00QB=P03001B=e8g009B=`L000MB
=`03001B=e8g00QB=`03001B=`00008000EB=`03001F=eHg00EF=`@000UFE`03001FE`00008000EF
E`03001FEeIG009FE`<0009FE`03001FEeIG00AFE`<00003EUL005IH00AFF0<00003EWP005Ih00AF
N0<0009FN004001FN5IhEWP20004EWP20006FYP3000015ZI001JVEZI0P001EZI0P000eZi0P0015Zj
0P0000AJfP000000009JfP<00003F]/00000009Nn`80009O70<00003Ga`0000000800005Ged00000
001OOP0300000e^o0000000800000e;l000000030002E]`00`00E]aFg00500000eKL000000020000
0eKL000000030002E]/00`00E]aFg00500000eKK0000000200000eKK0000000300000eKK00000002
0003E]/80003E]/3000015KK001Fo5Kl1P0000=Fn`0000000`000U[l0`0000EJo000000005[l00<0
00=Jo0@00003Fa`0000000@00005Fa`00000001K7@0600000e/m0000000200000e/m000000040000
0e]N0000000900000eMo0000000Y00000cMO00000007000oOol00`00Oomoo`2GOol00`00Oomoo`0?
Ool005]oo`03001oogoo0?moo`=oo`<000045=D001dF0002>IH01000>IHiUSVF0P000dFf00D004GF
AMI5eP0000A9e@050019eTWFBMH00007BOD20008COD00`00COE=m@06COD00`00COE=m@06COD20007
BMD00`00BMD00005BMD01@00BOE9mDWe000014Wf00<004geCOD01Tge0P001dgf00<004gfCOH01dgf
00<004gfCOH00`000dgf00<004hFCQH01dhF00<004hFCQH01ThF00<0058FDQH01U8F00<0058FDQH0
1e8F00<0058FDQH01e8F00<0058FDQH01e8F00<0058FDQH01e8F00<0058fDSH01E8f1`00158f00<0
058gDSL0258g00<0058gDSL01E8g1000258g00<005HgESL00UHg0`000UHg00<005IGEUL01UIG1000
25IG00<005IG00000P001EIG00<005IGEUL00UIG0P0015IG00@005IHEUQFF08000EFN003001FN000
008000EFN0@000AFN0800003FWP005ZH00=JV08000AJV@<000AJV@<00003FYT00000008000=J^P<0
0003F[X0000000=JfP80009Jf`800004G_/000000002Ga`200000elL0000000300001EmM00000000
Ggh02`0000=Bg00000000`001EKL1@0000=Fg000000020001EKK1@0000=Ff`00000020000eKK0`00
00AFf`00E]]Ff`H0009Ff`03001FfeKK00<000=Ff`L00004E_/000000002F_/00`00F_`000020000
0e[l000000050003F_`300000e[l0000000500000e/L0000000800000e/m0000000200000e/m0000
000400000e]N0000000900000eMo0000000H00000cMO0000000B0018Ool00`00Oomoo`2GOol00`00
Oomoo`0?Ool005]oo`03001oogoo0?moo`Aoo`@000057AH003VF>IH00004>IH00`00AKI5]P02AKH0
1000AMI5eP001DWE00@004WFBMH000M9m@03001=m@00008000E=m@03001=mDge00I=m@03001=mDge
00I=m@030019e@0000I9e@040019eDWE0004BMD00`00BOE9m@02BOD20003BOH00`00COE=m@05COD0
0`00COD000020005COH00`00COI=mP06COH00`00COI=mP03COH40009CQH00`00CQI>5P06CQH00`00
DQIB5P06DQH00`00DQIB5P07DQH00`00DQIB5P07DQH00`00DQIB5P07DQH00`00DQIB5P07DQH00`00
DSIB=P050002DSH00`00DSIB=P06DSH00`00DSMB=`08DSL00`00DSMB=`050002DSL00`00DSMB=`07
DSL00`00ESL000020005ESL00`00EUMFE`03EUL30002EUL00`00EUMFE`06EUL30009EUL40006EUL4
0006EWP30007EWP20005EWP20004FWP40005FYT20004FYT20003FYT20004F[X20002F[X200000e[J
000000020002F]/20002G_/200001ElL00000000Ga`01@0000AOG@00001OOPl0009Fg003001Fg5KL
00D00003E]`0000000P0009Ff`03001FfeKK00D00003E]/0000000P0009Ff`03001FfeKK00<000=F
f`L000AFf`@00003E]/0000000<00005E]/00000001Fn`030003F_/400000e[l000000040002F_`0
0`00F_`0000200000e[l0000000500000e/L0000000400001E/L00000000Fcd0100000=K?@000000
100000=KGP000000100000=KOP0000000P0000=GO`0000009`00DGoo00<007ooOol0Ugoo00<007oo
Ool03goo001KOol00`00Oomoo`3oOol4Ool3000011CE000000000SVF00D003VF>IHiUP0000E5]P03
0015eP0000I9e@030019eP0000M9m@03001=mDge009=m@8000==m@03001=mDge00I=m@03001=mDge
00I=m@040019eDWE0005BMD01@00BME9eDWE00000dWE00<004WeBOD014We0P0000=9mP00COD01Tge
00<004geCOD00Tge0P000dgf00<004gfCOH01Tgf00<004gfCOH01Tgf1P0014hF00<004hFCQH01ThF
00<0058FDQH01e8F00<0058FDQH01e8F00<0058FDQH01U8F00<0058FDQH01e8F00<0058FDQH00U8F
20001e8f00<0058fDSH01e8f00<0058gDSL01E8g1@001e8g00<0058gDSL01E8g10002EHg00<005IG
00000P001EIG00<005IGEUL00eIG0`0000=FE`00EUL01eIG0`001eIG0`001UIh0`0000=FN000EWP0
15Ih0`0000=FN000EWP00UIh0P001EYh0P001EZI0`0000=JV@00FYT00`000UZI0`0000=J^@00F[X0
0`000UZj0P000U[J0P000e[K0P0000ENn`00000005kk00800003Ga`0000000<00005Ged00000001O
OP0<0003E]`700000eKL000000080006E]/400000eKK0000000300000eKK000000020006E]/40000
0eKK00000003000015KK000000000UKK2P000eKK1`000e[k0`0000=Jn`0000001@0015[l0`0000=J
o0000000100000=K700000001@0000=K700000001`0000=K?@0000002P0000=KOP0000009@00Fgoo
00<007ooOol0Ugoo00<007ooOol03goo001KOol00`00Oomoo`3oOol4Ool3000011CE000000000SVF
00@003VF>IHiUP8000E5]P8000M9e@8000M9m@03001=mDge00A=m@@000Q=m@03001=mDge00I=m@05
0019eDWEBMD00004BMD00`00BME9e@02BMD01@00BME9eDWE00001dWe0P001dge00<004geCOD014ge
100024gf00<004gfCOH01Tgf00<004hFCQH00dhF2P000dhF00<0058FDQH01e8F00<0058FDQH01e8F
00<0058FDQH01U8F00<0058FDQH00U8F2P001E8F00<0058fDSH01e8f00<0058fDSH01e8f00<0058g
DSL01@000U8f00<0058gDSL01e8g00<0058gDSL01@000UHg00<005HgESL01UHg100025IG00@005IG
EUMFE`8000AFE`03001FEeIG00=FE`<0009FE`03001FEeIG009FE`<0009FE`03001FN5Ih009FN080
00AFN004001FN5IhEWP20005EWP30004FWP300000eZH001JV@02FYT20004FYT20003FYT20004F[T2
0003F[X20002F]X200000e[J001Jf`0200000ekk00000002G_/200000elL0000000300001EmM0000
0000Ggh01@0000E?gP00000005KK00L000=Ff`X0009Ff`04001FfeKKE]/:0003E]/300000eKK001F
f`02E]/:0003E]/80002E]/30002E]/00`00E]]Ff`060002F]/00`00F_/0000200000e[k00000005
0004F_`:00000e/L0000000500000e/L00000004000015/m000005/m300000=KOP0000005@0000<c
G`0000001`00I7oo00<007ooOol0Ugoo00<007ooOol03goo001KOol5003oOol3Ool3000011CE0000
00000SVF00H003VF>IH0046e0005AKH00`00BME9e@06BMD20006BOD00`00COE=m@07COD30006COD0
0`00COE=m@06COD00`00BME9e@02BMD01@00BME9eDWE00001DWE00@004WEBMD000Q9m@8000I=m@03
001=mDge00M=m@<000I=mP03001=mTgf00I=mP03001>5ThF00M>5P03001B5U8F00=B5RD000EB5P03
001B5U8F00MB5P03001B=U8f00MB=P03001B=U8f00EB=PD000MB=P03001B=e8g00EB=`D000MF=`03
001F=eHg00=F=`<0009F=`03001FEeIG00MFE`@000MFE`03001FE`00008000EFE`03001FE`000080
00IFE`@000IFN0@000IFN08000AJN08000AJV0@000=JV@<00003FYT00000008000=J^@<00003F[X0
05Zj0080009JfP8000=JfPD0009Nn`800003Ga`0000000800003Ged0000000800003Ggh0000000<0
0003Cmd0000000@0009Ff`03001FfeKK00D00003E]/00000008000IFf`X0009F^`03001FfeKK00<0
00=Ff`X0009Ff`03001FfeKK00H0009Ff`03001Ff`00008000AFf`L000=Jf`@00003F_/0000000@0
009Jn`03001Jo5[l00H00005F_`00000001K700600000e/L0000000500000e/m0000000=00000e]n
0000000I001]Ool00`00Oomoo`2GOol00`00Oomoo`0?Ool005]oo`03001oogoo0?moo`Eoo`<00007
5=D00000=GD003VF00000SVF00@0046e@KD000A5]P8000M9e@030019e@0000E9m@03001=mDge00M=
m@03001=mDge00<000==m@03001=mDge00I=m@030019eDWE00=9e@040019eDWE0006BMD00`00BMD0
0008BOD01000COD000001Dge00<004geCOD01Tge00<004geCOD00`000dgf00<004gfCOH01Tgf00<0
04hFCQH01dhF00<0058FDQH01U8F00<0058FDQH01e8F00<0058FDQH01e8F00<0058FDQH01U8F00<0
058FDQH01e8F00<0058FDQH01e8F00<0058fDSH01e8f00<0058fDSH01@000U8f00<0058fDSH01e8f
00<0058gDSL00U8g0`000U8g00<005HgESL025Hg00<005Hg00000P001EHg00<005IGEUL01EIG0`00
2EIG0`001eIG0`0025IG0P0025Ih0P001UIh0`0000=FN000FWP00`001EZH0P0015ZI0P000eZI0P00
15Zi0P0015Zj0P000U[J0P000U[J1@000ekk1`0000=OG@0000000P0000=OOP0000001`000eKK1`00
00=Ff`0000000`000UJk00<005KKE]/02P001UJk100000=Ff`0000000`0000=F^`0000000P001UKK
1`0015KK0`000UKK2@0000=Jf`0000000`0000=Jf`0000001@0015[k1`0000=Jo0000000200000=K
700000001@0000=K?@000000100000=K?@0000007P00MGoo00<007ooOol0UWoo00<007ooOol03goo
001KOol00`00Oomoo`3oOol5Ool4000011CE000eM@000SVF00<003VF00000T6e00<004FfAKH00TFf
00<004GE00001TWE00<004WEBMD00P0014We00<004geCOD01Tge00<004geCOD00dge100024ge00<0
04WEBMD014WE00<004WE00001dWE0P0024We00@004geCOE=m@8000==m@03001=mDge00I=m@03001=
mDge00==m@@000U=mP03001>5ThF00I>5P03001B5U8F00IB5P03001B5U8F00MB5P03001B5U8F00MB
5P03001B5U8F00IB5P03001B5U8F00MB5P03001B5U8F00MB5P03001B=U8f009B=PP000MB=P03001B
=U8f00MB=P03001B=`00008000EB=`03001F=eHg00IF=`@000QF=`03001FEeIG009FE`<0009FE`03
001FEeIG00AFE`<00003EUL005IG00AFE`<00003EUL005IG00EFE`<00003EUP005Ih00AFN0<00003
EWP005Ih00=FN08000AFN08000EJV0<00003FYT005ZI00<000=JV@800003F[T005Zi00<000=J^P<0
0004F]X000000002F]X200001Ukk000005kk001Nn`@00004Gc`00000Ged400000emn0000000<0003
E[/50005E[/:0002E[/01000E[]F^eJk2P000eJk0`0000=F^`00E]/00UKK2@0015KK20000UKK0`00
00=Ff`0000000P000e[K0`0000AJf`00000000AJn`L00003F_`0000000@00005F_`00000001K7006
00000e/M0000000500000e/m0000000700000e]n0000000D001hOol00`00Oomoo`2FOol00`00Oomo
o`0?Ool005]oo`03001oogoo0?moo`Ioo`<000055=D003Ee=GD00002>IH20003@KD01@00AKI5]TFf
00000TGE00<004WEBMD00dWE00<004WEBMD00TWE00D004WeBOE9m@0000Q=m@03001=mDge00I=m@H0
00==m@030019eDWE00E9e@8000Q9e@8000M9m@03001=mDge00==m@04001=mDge0008COD00`00COE=
m@06COD40006COH00`00CQI>5P06CQH00`00DQIB5P06DQH00`00DQIB5P07DQH00`00DQIB5P07DQH0
0`00DQIB5P06DQH00`00DQIB5P08DQH00`00DQIB5P04DQH70005DSH00`00DSIB=P08DSH00`00DSIB
=P04DSH40009DSL00`00ESMF=`02ESL30002ESL00`00ESMF=`07ESL00`00EUL000020005EUL00`00
EUMFE`02EUL20004EUL01000EUMFEeIG0P0015IG00<005IGEUL00UIG0P0015IH00@005IhEWQFN080
00EFN0@000AFN0800003FWP005ZH009JV08000AJV@8000AJV@8000=J^@8000AJ^P8000=JfP800005
F]X00000001Nn`020003G_/4000015ll000005mM100000AOWP00001K_PH0009F^`03001F^eJk00D0
009F^`03001F^eJk00D00003E[/00000008000IF^`X0009F^`03001F^eJk00<000=F^`D0009Ff`<0
009F^`03001FfeKK00H0009Ff`03001Ff`0000800004E]/000000002F]/00`00F]/0000200001U[K
00000000F]/0009Jn`H00003F_`0000000D00005F_`00000001K700600000e/M0000000500000e/m
0000000N001kOol00`00Oomoo`2FOol00`00Oomoo`0?Ool005]oo`03001oogoo0?moo`Ioo`H00004
=GD003VF>IH20004@KD01000AKI5]P000dGE00<004WEBMD00TWE00<004WEBMD00dWE0P0000=9m@00
COD01dge00<004geCOD01Tge00<004geCOD00dge100024WE00<004WEBMD01TWE00<004gE00001TWe
00<004geCOD014ge0`0024ge00<004geCOD01Tge00@004geCOE=m@D00003COH004hF00M>5P03001B
5U8F00MB5P03001B5U8F00MB5P03001B5U8F00IB5P03001B5U8F00MB5P03001B5U8F00MB5P03001B
5P0000@0009B5P03001B=U8f00MB=P03001B=U8f00QB=P03001B=P0000@0009B=P03001B=e8g00QB
=`03001F=`00008000EF=`03001F=eHg00EF=`@000UFE`@000IFE`@000MFE`@000IFF0@000IFN080
00EFN08000=JN0@000AJV@800004FYT005ZIFYT20003F[T200000eZi001J^P030002F]X300000ekJ
00000002G_/20002G_/5000015ll000005mM1`0000=K_P0000000`000eJk1@001EJk1@0000=F^`00
00000`000UJj00<005JkE[/01@0000=F^P0000000P001UJk100000=F^`0000000`000UJk00<005KK
00000P0015Jk1`0015KK0`0000AFf`00000000=Jf`@00004F]/000000003F]/700001E[l00000000
F_`00`0000EJo000000005/L00H00003Fad0000000@00003Fcd0000001l007ioo`03001oogoo09Io
o`03001oogoo00moo`00Fgoo00<007ooOol0ogoo1Woo1P000SEe00@003VF>IH000E1]@040015]TFf
0003AMD01@00BME9eDWE00001dWE0P0024ge00<004geCOD01Tge00<004geCOD01Tge00<004WEBMD0
1TWE0P001dWE00<004gECMD00P0014We00<004geCOD01Tge0P001dge00<004geCOD01Tge00<004ge
COD01Tge1`000dhF00<0058FDQH01e8F00<0058FDQH01e8F00<0058FDQH01U8F00<0058FDQH01e8F
00<0058FDQH00U8F1`001e8F00<0058fDSH0258f00<0058fDSH01E8f10001e8f00<0058gDSL01U8g
100025Hg00<005HgESL00UHg0`000UHg00<005IGEUL01UIG0`0025IG0P002EIG0P0025IH0P001UIh
0`0000=FN000EWP00UIh0P0015Yh0P001EZI0P000eZI0`000eZi0P000eZi0P000e[J0P000UkJ0P00
00ANn`000000009Nn`800004Ga`00000Gc`200000emM0000000@0002E[X00`00E[]F^`0500000eJj
000000030005E[X50003E[X300000eJj001F^`02E[/500000eJj000000020005E[/40002E[/90004
E]/70003F]/300000e[K000000020003F]/300001E[K00000000F_`00`0000EJo000000005[l00<0
009K70800004Fa`00000Fa`600000e/m0000000N0022Ool00`00Oomoo`2FOol00`00Oomoo`0?Ool0
05Yoo`03001oogoo0?moo`Qoo`@00004;ED003Ee0002>IH00`00@KE1]@03@KD01000AKI5]P0014GE
00@004WEBMD000Q9e@8000M=m@03001=mDge00I=m@03001=mDge00I=m@8000M9e@030019e@0000I9
e@03001=eDgE009=e@050019mDWeBOD00008COD01000COD000001Dge00<004geCOD01Tge00<004ge
COD01dge00<004gfCOH00dgf2@00158F00<0058FDQH01e8F00<0058FDQH01U8F00<0058FDQH00U8F
2P001E8F00<0058FDQH01U8F00<0058fDSH0258f00<0058fDSH01@000U8f00<0058fDSH01e8f00<0
058gDSL00U8g0`000UHf00<005HgESL01eHg00<005Hg00000P001EHg00<005IGEUL00eIG0`000UIG
00<005IGEUL00eIG0`0000=FE`00EUL01EIG0`0000=FE`00EUP015IH0`0000=FN000EWP00eIh0P00
1EIh0`0015Yh0P0000=JV000FYT00UZI0P0015ZI0P000eZi0P000eZi0P0000=J^P0000000P000UkJ
0P000Ukk0P0000ENn`00000005lL00800004Gc`00000Ged?0003E[X700000eJj000000030002E[X0
0`00E[YF^P050002E[X00`00E[YF^P030003E[X50003E[X3000015Jj001F^eJk1@0000=F^P000000
0`000UJk0`000UJk00<005KKE]/01P000U[K00<005[K00000P0000AJf`000000009Jf`03001Jf`00
00800003F]/0000000D0009Jo0800005F_`00000001Jo00=00000e/m0000000400000e]M0000000G
0025Ool00`00Oomoo`2FOol00`00Oomoo`0?Ool005Yoo`03001oogoo0?moo`Qoo`@00006;ED003Ee
=GD003VF0P001D6e00<004Ff00001DGE00<004WE000024WE00@004ge000000E=m@03001=mDge00I=
m@03001=mDge00I=m@030019e@0000I9e@040019eDWE0005BMD00`00CME=e@03CMD200000dWe001=
m@07COD01000COE=mDge0`000Tge00<004geCOD01Tge00<004geCOD01dge00<004gfCOH01Tgf00<0
058FDQH00e8F70001E8F00<0058FDQH01e8F00<0058FDQH01e8F00<0058fDSH01E8f1@001e8f00<0
058fDSH01e8f00<0058g00000P001EHf00<005HgESL01UHg0`002EHg00<005IG00000P001EIG00@0
05IGEUMFE`8000AFE`03001FEeIG009FE`8000AFE`04001FF5IHEUP20005EWP40006EWP20004FWP2
0004FYP30003FYT300000eZI001J^@020003F[T20002F[X20003G]X20002G_/200000ekk00000002
Ga`2000015ll000005mM300000=F^P0000001@000eJj1@001UJj10001UJj100000=F^P0000000`00
0UJj00<005JjE[X00`000eJj10000eJj0`000UJj00<005Jk00000P0015Jk1`0015[K0`0000AJf`00
000000=Jf`@00003F]/0000000@0009Jn`@00003F_`00000009Jo0<00004Fa`00000Fa`2000015/M
000005/m1P0000=KG@0000005`00R7oo00<007ooOol0UWoo00<007ooOol03goo001JOol00`00Oomo
o`3oOol8Ool400002BeE000eMCEe000iUP00@KD00005@KD20006AMD20008BMD01000COE=mDge0P00
0dge00<004geCOD01Tge00<004geCOD01Tge00@004WEBMD000E9e@050019eDWEBMD00004BMD00`00
CME=e@05CMD20008COD00`00COE=m@04COD30009COD00`00COE=m@06COD00`00COI=mP06COH00`00
DQIB5P07DQH00`00DQIB5P07DQH00`00DQIB5P06DQH00`00DQIB5P07DQH00`00DQIB5P07DQH00`00
DQIB5P07DQH00`00DSIB=P050002DQH00`00DSIB=P07DSH00`00DSIB=P05DSH40009ESH00`00ESMF
=`02ESL300000eHg001F=`08ESL30008EUL40007EUL40006EUL40006EWP20006EWP3000015Yh001J
N5Yh0P001EZH0P000eZI0P0015ZI0P000eZi0P000UZj0P0000=NfP00G]X00P000Ukk0P0000ANn`00
001O6`<00004Gc`00000Ged?0002EYX00`00E[YF^P050002EYX01000E[YF^UJj1@000UJj00<005Jj
E[X01@0000=F^P0000000P001UJj10000eJj0`000UJj00<005Jj00000P000eJj10000UJk1@0000AF
^`00000000AJf`L000=Jf`<00003F]/0000000D000AJn`800005F_`00000001Jo00300000e/L0000
000=00000e]M0000000200000e]N0000000B002;Ool00`00Oomoo`2FOol00`00Oomoo`0?Ool005Yo
o`03001oogoo0?moo`Uoo`@00006;ED003Ee=GD003VF0P001T6e00<004GEAMD01DGE0P001dWE00<0
04geCOD00dge00@004geCOD000Q=m@03001=mDge00I=m@040019eDWE0005BMD00`00BME9e@02BMD0
1@00BME9eDWE000024gE0P001dge00<004geCOD01Tge10001Tge00<004geCOD01Tge00<004gfCOH0
1Tgf00<0058FDQH01e8F00<0058FDQH01e8F00<0058FDQH01U8F00<0058FDQH01e8F00<0058FDQH0
1e8F00<0058FDQH01E8F1@001e8F00<0058fDSH01e8f00<0058fDSH00U8f0`000U8f00<005HfESH0
25Hf00<005Hg00000P0015Hg00<005HgESL015Hg0`0000=F=`00EUL01eIG0P002EIG0P0025IG0P00
1UIh0`0000=FN000EWP00eIh0P0015Yh0`0015ZH0`0000=JV00000000P0015ZI0P0000=J^@00F[T0
0P000UZj0P000ekJ0P000Ukk0P0000=Nn`0000000UlK0P0000AO?000001OG@`000IFVP@000IFVPD0
00EF^PD000=F^P<00003E[X005Jj009F^PD0009F^P03001F^P00008000=F^P@00003E[X0000000<0
0003E[X0000000<000=F^`<00004E[X005[KF]/60002F]/00`00F]/0000200001E[K00000000F]/0
0`0015[k1P0000EJo000000005/L00H00004Fad00000Fcd2000015/m000005/m6@00SWoo00<007oo
Ool0UWoo00<007ooOol03goo001JOol00`00Oomoo`3oOol9Ool400000beE000eM@02=GD200000d6e
0011]@04@KD00`00AME5e@05AMD00`00BMD00006BMD00`00COE=m@04COD30008COD00`00COE=m@06
COD01@00BME9eDWE000014WE00<004WEBMD00dWE00@004WEBMD000Q=e@04001=m@000005COD00`00
COE=m@06COD01000COE=mDge1@0000==m@00COD01dge00<004gfCOH01Tgf00<0058FDQH01e8F00<0
058FDQH01e8F00<0058FDQH01U8F00<0058FDQH0258F00<0058FDQH01U8F00<0058FDQH01@000U8F
00<0058FDQH01e8F00<0058fDSH01e8f00<0058f00000P001E8f00<005HfESH01UHf100025Hg00@0
05HgESMF=`8000AF=`03001FEeIG00=FE`<00003EUL005IG00EFE`<00003EUL005IG00EFE`800003
EUL005Ih00=FN08000EFN0@000EJN08000AJV08000=JV08000EJV@8000=J^@80009J^P8000=NfP80
0005G]X00000001Nn`0200001ElK00000000Gc`00P0000=OG@00000020000UJJ00<005JJEYX01@00
0UJJ00<005JJEYX01@000UJJ00<005JjE[X01@000UJJ00<005JjE[X00`000eJj1@001EJj100000=F
^P0000000`0000=F^P0000000P000eJj0`000UJj00<005JkE[/00`000eJj1`0015[K0`0000EJf`00
000005[K00<00004F]/005[kF_/600001E[l00000000Fa`01P0000=K70000000300000=KGP000000
4@00TGoo00<007ooOol0Ugoo00<007ooOol03Woo001JOol00`00Oomoo`3oOol9Ool5000012eE000e
MCEe0P000T6e00<0046e@KD00T6e0P001TGE00@004WEBMD000E9e@03001=mDge00I=m@<000I=m@03
001=mDge00M=m@050019eDWEBMD00003BMD00`00BME9e@04BMD00`00BMD00008CMD01000COE=mDge
0P000dge00<004geCOD01Tge00<004geCOD01Tge10001Tge00<004gfCOH01dgf00<0058FDQH01U8F
00<0058FDQH01e8F00<0058FDQH01e8F00<0058FDQH01e8F00<0058FDQH0158F1@001e8F00<0058F
DQH01e8F00<0058fDSH01E8f10002E8f00<005HfESH00UHf0`000UHf00<005HgESL01eHg10001UHg
00@005IGEUMFE`8000AFE`03001FEeIG009FE`8000AFE`04001FEeIGEUL30004EUL40006EWP20005
FWP300000eYh001JV0030003FYP200000eZI001JV@02FYT20003F[T2000015Zi000000000ekJ0P00
0UkJ0P0000ANn`00001O6`80009O?0800004Ged00000Gih70002EYX50005EYX50005EYX50006EYX4
00000eJj000000030002EYX00`00E[YF^P0500000eJj000000020003E[X30002E[X00`00E[X00002
0004E[X40003E[X3000015Zj0000000015[K1`000U[K0P000e[K1`0000EJo000000005[l00H00003
Fa`0000000@00004Fcd00000FcdH002DOol00`00Oomoo`2GOol00`00Oomoo`0>Ool005Yoo`03001o
ogoo0?moo`Yoo`@00003;ED003Ee008eM@040011]D6e0004@KD00`00AKD00005AMD01@00BME9eDWE
000014WE00<004geCOD01Tge00<004geCOD00`000dge00<004geCOD01dge00<004WEBMD00TWE00@0
04WEBMD000M9e@8000Q=e@03001=mDge00==m@04001=mDge0008COD00`00COE=m@07COD00`00COE=
m@0500000dge001=mP08COH00`00DQIB5P07DQH00`00DQIB5P06DQH00`00DQIB5P07DQH00`00DQIB
5P07DQH00`00DQH000040002DQH00`00DQIB5P07DQH00`00DQIB5P07DQH00`00DSIB=P050002DSH0
0`00DSIB=P08DSH00`00ESH000020005ESH00`00ESMF=`05ESL30009ESL40007EUL40007EUL30006
EUL20007EWP200000eYh001JN002FWP20004FWP20004FYP20004FYT30003F[T20002F[T20003G]X2
0002G]X200000ekk000000030002Gc`2000015mM000005nN2`000UJJ00<005JJEYX01@000UJJ00<0
05JJEYX01@000UJJ00@005JJEYYFVPD00003EYX00000008000EFVPD000=F^P<0009F^P03001F^P00
008000AF^P<000AF^P<0009F^P03001F^P0000800006F[X00000001JfP000U[K1P000U[K10000U[K
0`0000EJn`00000005[l00<00003F_`0000000@00003Fa`0000000@00003Fcd0000001X009Ioo`03
001oogoo09Moo`03001oogoo00ioo`00FWoo00<007ooOol0ogoo2Woo00@0000>0000008]E@04000e
MCEe0003@KD01@00@KE1]D6e00000TFe00<004GEAMD00TGE00<004WEBMD00TWE00D004WEBME9e@00
00Q=m@03001=mDge00==m@@000U=m@030019eDWE0099e@040019eDWE0008BMD20007CMD00`00COE=
m@04COD30008COD00`00COE=m@07COD00`00COE=m@05COD70004COH00`00DQIB5P07DQH00`00DQIB
5P06DQH00`00DQIB5P07DQH00`00DQIB5P02DQH70007DQH00`00DQIB5P08DQH00`00DQIB5P05DQH4
0007DSH00`00DSIB=P06DSH40008ESH00`00ESMF=`02ESL30002ESL00`00ESMF=`06ESL20009EUL2
0009EUL20006EUL200000eIg001FN004EWP20003FWP40004FWP2000015ZH001JV5ZH0P001EZI0P00
0eZi0P000UZi0P0000=NfP00G]X00P000UkJ0P0000=Nn`0000000P000ell0P0000AOG@00001OWPP0
00IFVP@000IFVP@000IFVPD000=FVP<00004EYX005JJEYX50002EYX00`00E[YF^P030003E[X40004
E[X3000015Jj001F^UJj0`000eJj100000AJ^P00000000=JfPL000AJf`80009Jf`<00005F_/00000
001Jn`030002F_`2000015/L000005/L1P0000=K?@0000006P00VGoo00<007ooOol0Ugoo00<007oo
Ool03Woo001JOol00`00Oomoo`3oOol;Ool4000012eE000eMCEe0P000T6e00D0046e@KE1]@0000=5
]@050015eDGEAMD00005BMD01000BME9e@0024ge00<004geCOD01Tge10001Tge00<004WEBMD00dWE
00<004WE000024WE00<004gE00001TgE00<004geCOD01Tge0P0024ge00<004geCOD01Tge00<004ge
COD01Tge00<0057eDOD00e7e2P00158F00<0058FDQH00U8F4`001E8F00<0058FDQH01U8F00<0058F
DQH0258F00<0058FDQH00U8F0`0000=B5P00DSH02E8f00<0058fDSH00U8f0`000UHf00<005HfESH0
1eHf00<005Hg00000P001EHg00<005HgESL00eHg0`0000=FE`00EUL01EIG0`0000=FE`00EUL01EIG
0`0000=FE`00EUL00eIG0P000eIg00@005IhEWQFN08000AJN08000EJN08000=JV0<000EJV@800003
FYT005Zi0080009J^@8000=NfP80009NfP800008G_/00000Ga/005ll001O?0800004Ged00000Gih7
000015JI001FVUJJ1@000UJI00<005JJEYX01@000UJI00<005JJEYX01@000UJJ00<005JJEYX00`00
0eJJ10001UJJ10000eJj0`000UJj00<005JjE[X00`000eJj10000eJj0`0000=J^P0000000P000e[J
0`0000AJf`00000000AJf`L00005F_/00000001Jn`0300000e[l0000000;00000e/m0000000J002L
Ool00`00Oomoo`2GOol00`00Oomoo`0>Ool005Yoo`03001oogoo0?moo`]oo`@0008]E@04000eM@00
0003@KD01000@KE1]@0014Fe00D004GEAME5e@0000E9e@030019e@0000Q=m@03001=mDge00I=m@04
001=mDgeCOD500000dge0019e@05BMD20008BMD01000CME=e@001DgE00<004geCOD01Tge00<004ge
00000P001Dge00<004geCOD01Tge00<004geCOD01Tge00<0057eDOD01e7e00<0058EDQD00e8E2@00
158F00<0058FDQH01e8F00<0058FDQH01e8F00<0058FDQH01e8F00<0058FDQH01e8F00<0058F0000
0P00158F00<0058fDSH0258f00<0058f00000P001EHf00<005HfESH01UHf0`002EHg00<005Hg0000
0P0015IG00<005IGEUL00UIG0P0015IG00<005IGEUL00UIG0P0015IG00<005IGEUL00P001UIg0`00
15Yh0P0000=JN000FWP00UYh0P0015ZH0P001EZI0P000eZI0P000UZi0P000ekJ0P0000ENfP000000
05kk00800003Ga/00000009O?0800004Ged00000Gih=0005EYT50005EYT50006EYX40003EYX30002
EYX00`00EYYFVP050002EYX00`00E[X000020004E[X40003E[X30002E[X00`00E[X00002000015Zj
000000000UZj00<005[J00000P0000IJf`00000005[K0002F]/60002F]/30002F_/20003F_`20000
15/L000005/L0P0000AK7000001K?A/00:1oo`03001oogoo09Moo`03001oogoo00ioo`00FWoo00<0
07ooOol0ogoo2goo00/0000>000Q5@00;ED003Ee000mU@0000=1]@030011]@0000A5]@050015eDGE
AMD00006BMD20008COD00`00COE=m@06COD00`00COE=m@06COD20007BMD20007BMD01000CME=eDgE
0P000dgE00<004geCOD01Tge00<004geCOD00Tge0P000dge00<004geCOD01Tge00<004geCOD01Tge
00<0057eDOD01e7e00<0058EDQD01e8E00<0058FDQH01U8F00<0058FDQH01e8F00<0058FDQH01e8F
00<0058FDQH01e8F00<0058FDQH01E8F10001e8F00<0058fDSH01U8f100025Hf00<005HfESH00eHf
0`0000=F=P00ESL025Hg0`0025IG10001eIG10001UIG0`001eIg0P0015Yh0P0015Yh0`0015ZH0P00
00=JV000FYT00UZI0P000eZI0P0000AJ^@00000000=NfP80009NfP800003G_/00000009O6`03001O
?5ll00800004Ge`00000Gih70005EYT00`00EYUFV@050002EYT00`00EYUFV@050002EYT01000EYYF
VUJJ1@000UJI00<005JJ00000P0015JJ10001EJJ100015Jj0`000UJj00<005Jj00000P000eJj1000
00AJ^P00000000=J^P@00004F]/000000003F]/70002F]/300000e[k000000020002F_`W002SOol0
0`00Oomoo`2GOol00`00Oomoo`0>Ool005Yoo`03001oo`0000800?moo`Uoo`D00006;ED003Ee000m
U@000d6e00<0046e00001DFe00@004GEAMD000M9e@8000M=m@03001=mDge00I=m@03001=mDge00M=
m@030019eDWE00E9e@030019e@0000I9e@03001=eDgE00==e@04001=eDgE0008COD00`00COE=m@04
COD40008COD00`00COE=m@06COD00`00DOEAm@07DOD00`00DQEB5@07DQD00`00DQIB5P06DQH00`00
DQIB5P07DQH00`00DQIB5P07DQH00`00DQIB5P07DQH00`00DQIB5P050002DQH00`00DQIB5P07DQH0
0`00DSIB=P02DSH30002DSH00`00ESIF=P07ESH01000ESIF=UHf0P0015Hf00<005HgESL015Hg0`00
00=F=`00EUL01eIG0P002EIG0P0025IG0P001UIg0`0000AFN000FWQJN08000EJN08000AJV08000AJ
V0<000=JV@80009J^@8000=NfP80009NfP800003G_/00000009O6`800004Gc`00000Ge`2000015nN
000005_N10000eJI1`001UJI10001UJI1@001EJI100015JJ0`0000AFV@00EYYFVPD0009FVP03001F
^UJj00<000=F^P@00003E[X0000000<00003E[X00000008000=J^P<0009J^P<000=Jf`<00004F]/0
00000003F]/20002F_/30002F_`6000015/L000005/L0P0000AK?@00001K?@800003Fcd0000000H0
0003Fih0000000X00:Eoo`03001oogoo09Moo`03001oogoo00ioo`00FWoo0P00ogoo3Goo0`0000<Q
5@00;ED00P000SfE00@0046e@KE1]@8000I5]@030015e@0000M9e@03001=e@0000I=m@03001=mDge
00I=m@03001=mDge00M=m@8000I9e@040019eDWE0005BMD00`00CME=e@04CMD00`00CMD00008COD0
0`00COE=m@07COD30006COD00`00COE=m@07COD00`00DOEAm@06DOD00`00DQEB5@07DQD00`00DQIB
5P06DQH00`00DQIB5P07DQH00`00DQIB5P07DQH00`00DQIB5P05DQH50007DQH00`00DQIB5P07DQH0
0`00DSH000020005DSH00`00ESIF=P07ESH40007ESH01000ESMF=eHg0P0015Hg00<005IGEUL00eIG
0`0000=FE`00EUL01EIG0`0000=FE`00EUL015IG0`0000=FE`00EWL00eIg0P0015Ih0`001EYh0P00
00AJN000FYQJV08000EJV08000=JV@80009J^@800003G[X005kJ0080009NfP800008G_/00000G_/0
05lK001O?0800004Ge`00000Gih200000e_N000000070005EWT00`00EYUFV@050002EYT00`00EYUF
V@050002EYT00`00EYUFV@050002EYT00`00EYYFVP030003EYT40006EYX400000eJj000000030000
0eJj000000020003E[X30002F[X00`00F[X000020002F[X300000eZj001Jf`030002F]/200000e[K
001Jf`0300001E[k00000000F_/01`0000=K700000007`00Z7oo00<007ooOol0Ugoo00<007ooOol0
3Woo001JOol00`00Oomoo`3oOol<Ool300000b4E000]E@020002?ID00`00@KE1]@02@KD00`00AKE5
]@05AKD20007BMD01000CME=e@001Dge00<004geCOD01Tge00<004geCOD01dge00<004WE00001DWE
00D004WEBME9e@0000A9e@03001=eDgE00E=e@8000Q=m@03001=mDge00M=m@03001=mDge00<000==
m@03001=mDge00M=m@03001AmE7e00IAm@03001B5E8E00MB5@03001B5U8F00MB5P03001B5U8F00IB
5P03001B5U8F00MB5P03001B5U8F00D0009B5P03001B5U8F00MB5P03001B5U8F00EB5P@000QB=P03
001F=UHf00EF=P<000YF=P@000IF=`04001FEeIGEUL20004EUL00`00EUMFE`02EUL20004EUL01000
EUMFEeIG0P001EIG10001EIh0P001EYh0P000eYh0`001EZH0P0000=JV@00FYT00P000UZi0P000ejj
0P000UkJ0P0000=Nn`0000000ekk100000AOG000001OWP800003Fmh000000080009FN@03001FNEIi
00EFN@D000EFV@D000EFV@D000IFV@@000=FV@<0009FV@03001FVUJJ00D00003EYX00000008000=F
^P<0009F^P03001F^P00008000AJ^P<000=J^P80009J^P@0009Jf`<0009Jf`<00005F_/00000001J
n`0300001E[k00000000Fa`01P0000AK7000001K?@800003Fcd0000000H00003Fih0000000T00:]o
o`03001oogoo09Moo`03001oogoo00ioo`00FWoo00<007ooOol0ogoo37oo100000@Q5@00;ED000<m
U@050011]D6e@KD00008AKD00`00BME9e@05BMD01000CME=eDgE0P000dge00<004geCOD01Tge00<0
04geCOD01dge00<004WE00001DWE00<004WEBMD00TWE00<004WEBMD00TWE00<004gECMD01DgE0P00
24ge00<004geCOD01Tge00<004geCOD00dge10002Dge00<0057eDOD01U7e00<0058EDQD01e8E00<0
058FDQH01e8F00<0058FDQH01U8F00<0058FDQH00U8F20001e8F00<0058FDQH01e8F00<0058FDQH0
0U8F0`000U8F00<0058fDSH01e8f00<005HfESH00UHf0`000UHf00<005HfESH01eHf0P002EHg1000
1eIG10001UIG10001UIG0P001UIh0P0000=JN000FWP00UYh0P0015Yh0P001EZH0P000eZI0P000UZi
0P000ejj0P0000ENfP00000005kk008000=Nn`@00004Ge`00000Gih2000015_N000000001UIi00<0
05Ii000010000UIi00<005JIEYT01@000UIi00<005JIEYT01@000UJI00@005JIEYUFV@D0009FV@03
001FV@00008000AFV@@000=FVP<0009FV@03001F^P00008000AF^P<000AJ^P<00003F[X005Zj00<0
0004F[X000000002F]X01000F]/000000U[K0`0000EJf`00000005[k00<00005F_/00000001Jo006
00000e/L0000000:00000e]n0000000;002^Ool00`00Oomoo`2GOol00`00Oomoo`0>Ool005Uoo`03
001oogoo0?moo`ioo`070000D`008AD002eE000013fE00<0046e@KD00P001dFe00<004WEBMD01DWE
00<004gECMD00dgE00@004geCOD000Q=m@03001=mDge00M=m@040019eDWE0004BMD00`00BME9e@03
BMD01@00BME9eDWE00001dgE00@004ge000000I=m@03001=mDge00I=m@03001=mDge00I=m@H000A=
m@03001AmE7e00IAm@03001B5E8E00MB5@03001B5U8F00MB5P03001B5U8F009B5PT000EB5P03001B
5U8F00MB5P03001B5U8F00MB5P03001B5P00008000EB5P03001B=U8f00MB=P03001F=P00008000EF
=P03001F=UHf00AF=P<00003ESH005Hg00MF=`8000UFE`8000QFE`8000MFE`800003EUL005Ih00=F
N08000AJN0<000AJN0800003FYP005ZH009JV08000=JV@800004F[T000000003G[X20002G]X20000
0ekk00000003G_/4000016<l000005nN0P0000AKgP00000000=FN@L000IFN@@000IFN@@000IFV@D0
00EFV@@000AFV@<00004EYT005JJEYX30003EYT40004E[X3000015Zj001J^UZj0`000eZj0`0000AJ
^P00000000AJfP<00004F]/000000002F]/2000015[K000000000U[k0P0000=Jo0000000100000=K
70000000100000=K?@0000004@00/Goo00<007ooOol0Ugoo00<007ooOol03Woo001IOol00`00Oomo
o`3oOol>Ool300028AD30003?ID01P00@KE1]@00AKD000I5]@8000I9e@03001=eDgE00A=e@03001=
m@0000U=m@03001=mDge00I=m@050019eDWEBMD00003BMD00`00BME9e@04BMD01000BME9e@001dgE
00@004geCOE=m@8000A=m@03001=mDge00I=m@03001=mDge00I=m@03001=mDge00==m@X000=Am@03
001B5E8E00MB5@03001B5U8F009B5PX000AB5P03001B5U8F00MB5P03001B5U8F00MB5P03001B5U8F
00EB5P@000QB5P03001B=U8f00IB=P<000UF=P04001F=UHfESH20004ESH00`00ESMF=`03ESL30000
0eHg001FE`06EUL200000eIG001FE`05EUL200000eIG001FE`04EUL20003EUL00`00EWQFN0020005
FWP20004FWP20004FYP30003FYT20002F[T20003G[X20002G]X200000ekj00000003G_/4000016<l
000005nN0P0000=KgP0000001P001EIi00<005IiEWT01@000UIi00<005IiEWT01@000UIi00<005JI
EYT01@000UJI00<005JIEYT01@000UJI00<005JIEYT00`000eJI10000eJI0`000UJI00<005JjE[X0
0`000eZj10000eZj0`0000AJ^P00000000AJfP<00004F]X000000002F]/600000e[k000000020000
0e[l0000000300000e/L0000000400000e/m0000000400000e]n0000000400000e>o00000004002c
Ool00`00Oomoo`2GOol00`00Oomoo`0>Ool005Uoo`03001oogoo0?moo`ioo`@000048AD000000004
?ID01@00@KD004Fe00001TFe00<004WE00001DWE00<004gECMD01DgE0P002Dge00<004geCOD01Tge
00<004WEBMD00TWE00D004WEBME9e@0000I9e@030019e@0000M=e@03001=mDge00==m@80009=m@03
001=mDge00I=m@03001=mDge00I=m@03001=mDge00M=m@03001AmE7e00=AmA8000EB5@03001B5U8F
00IB5P03001B5U8F00MB5P03001B5U8F00MB5P03001B5U8F00D0009B5P03001B5U8F00QB5P03001B
=U8f009B=P<00003ESH005Hf00UF=P@000IF=P04001F=eHgESL20004ESL00`00EUMFE`03EUL20003
EUL00`00EUMFE`02EUL20003EUL01000EUMFEeIG0P001EIG0`001EYh0P0000=JN000FWP00UYh00<0
05ZHFYP00eZH0P000eZI0P000UZi0P0000=N^@00G[X00P000UkJ0P0000INnP00001Nn`00G_/40000
16<l000005nN0P0000AKgP000000009FN003001FNEIi00EFN@D000EFN@D000IFN@@000IFV@@000IF
V@@000=FV@<0009FV@03001FV@00008000AFV@@000=J^P<0009J^P03001J^P000080009J^P800004
F[X005[JF]X30002F]X200000e[K001Jf`0200000e[K00000003F_/200000e[l0000000300000e/L
0000000400000e/m0000000500000e]n0000000:002fOol00`00Oomoo`2GOol00`00Oomoo`0>Ool0
05Uoo`03001oogoo0?moo`moo`060000D`008AD002eE0P000cfE00<0046e00000TFe00<004FeAKD0
0dFe00@004WEBMD000E9e@03001=eDgE00E=e@8000Q=m@03001=mDge00I=m@030019eDWE0099e@05
0019eDWEBMD00007BMD20007CMD00`00COE=m@05COD30008COD00`00COE=m@06COD00`00COE=m@07
COD00`00DOEAm@06DOD00`00DOEAm@07DOD00`00DQEB5@07DQD00`00DQIB5P06DQH00`00DQIB5P08
DQH00`00DQIB5P05DQH40007DQH00`00DQIB5P08DQH00`00DSH000020004ESH00`00ESIF=P07ESH2
0009ESH40007ESL00`00EUMFE`020005EUL00`00EUMFE`020006EUL30006EUL20005FWP20004FWP3
0004FYP200000eZH001JV@020003F[T01000G[UN^Eji0P000UkJ0P000Ukj00@005kkG_]Nn`@00003
Hc`0000000L000EFN003001FN@0000@0009FN@03001FNEIi00D0009FN@03001FNEIi00=FN@<00003
EWT005JI00AFV@<0009FV@03001FVEJI009FV@<0009FV@03001FV@00008000AFV@<000AFV@<0009F
V@03001J^P00008000AJ^P<0009J^P<0009J^P@0009JfP<0009Jf`H0009Jn`<00003F_/0000000<0
0003Fa`0000000<00003Fcd0000000D00005Fgh00000001KW`0200000e>o00000003002iOol00`00
Oomoo`2GOol00`00Oomoo`0>Ool005Uoo`03001oogoo0?moo`moo`@000048AD000000004?ID00`00
@KD00002AKD00`00AKE5]@02AKD01@00BME9eDWE000014WE00<004gECMD01DgE00<004gE00000P00
1Dge00<004geCOD01Tge00<004WEBMD00dWE00@004WEBMD000Q9e@8000I=e@03001=mDge00M=m@80
00M=m@03001=mDge00I=m@03001=mDge00M=m@03001AmE7e00IAm@03001AmE7e00MAm@03001B5E8E
00MB5@03001B5U8F00IB5P03001B5U8F00QB5P03001B5U8F009B5P<00003DQH0058F00QB5P03001B
5U8F00IB5P@000MF=P03001F=UHf00AF=P<00003ESH005Hf00MF=P8000YF=`<000MFE`<000MFE`80
00IFE`800003FWL005Yh009JN08000EJN08000AJV08000=JV08000=J^@80009N^@800004G]X00000
0002G_X20002G_/400000f<l000000070005EWP40006EWT40008EWT00`00EWT000020005EWT00`00
EYT000020005EYT00`00EYT000020004EYT30004EYT3000015JI001FVEJI0`000eJI100015Zj0`00
00=J^P00F[X00P000UZj0`000UZj00@005[J0000009Jf`<00003F]/00000009Jn`<00003F_/00000
00<00003Fa`0000000<00003Fcd0000000H00004Fgh00000Fil9002kOol00`00Oomoo`2GOol00`00
Oomoo`0>Ool005Uoo`03001oogoo0?moo`moo`@000058AD00000>GD00003?ID00`00@KD00003AKD0
1@00AKE5]DFe000014WE00D004WEBME9e@0000M=e@03001=eDgE009=e@8000==m@03001=mDge00I=
m@030019eDWE00A9e@030019e@0000Q9e@03001=e@0000E=e@03001=mDge00M=m@04001=m@000005
COD00`00COE=m@06COD00`00COE=m@07COD00`00DOEAm@06DOD00`00DOEAm@07DOD00`00DQEB5@07
DQD00`00DQIB5P07DQH00`00DQIB5P07DQH00`00DQH000020004DQH00`00DQIB5P08DQH00`00DQIB
5P02DQH30002DSH00`00ESIF=P07ESH01000ESIF=UHf0P0015Hf00<005HfESH00eHf0`0000=F=P00
ESL025Hg0P0025IG0P001eIG0P0000=FE`00EUL00eIG0P0015Yg0`001EYh0P0000AJN000FYQJV080
00=JV0800003FYT005Zi008000=N^@03001NfUkJ0080009NnP80009Nn`@00003Hc`0000000L0009F
N0D0009FN003001FNEIi009FN@<0009FN003001FNEIi00EFN@@000IFN@@000IFV@@000AFV@<00004
EYT005JIEYT30003EYT40003EYT30002FYX00`00F[YJ^P030003F[X3000015Zj0000000015Zj0`00
00AJf`000000009Jf`800004F]/000000002F_/2000015[l000005/L1@0000=K?@0000001@0000EK
OP00000005^O00P00;ioo`03001oogoo09Moo`03001oogoo00ioo`00FGoo00<007ooOol0ogoo47oo
00<0001C00000R4E00<003Ue000013fE0P000dFe00D004FeAKE5]@0000E9e@040019eDWE0007CMD0
0`00CME=e@04CMD40008COD00`00BME9e@04BMD00`00BMD00008BMD01000CME=e@001DgE00<004ge
COD01Tge00@004geCOE=m@<0009=m@03001=mDge00M=m@03001=mDge00I=m@03001AmE7e00IAm@03
001AmE7e00MAm@03001B5E8E00MB5@03001B5U8F00MB5P03001B5U8F00EB5P@000MB5P03001B5U8F
00QB5P03001B5P00008000EB=P03001F=UHf00MF=P@000IF=P04001F=UHfESH20004ESH00`00ESMF
=`04ESL300000eIG001FE`04EUL300000eIG001FE`04EUL20003EUL00`00EUMFE`020005FWL20005
FWP20003FWP30004FYP01000FYUJVEZI0P000eji0P0000MNfP00001NfP00G_X00002G_/400000f<l
0000000300000enn000000050007EWP00`00EWT000020005EWP00`00EWUFN@050002EWT00`00EWUF
N@050002EWT00`00EYUFV@050002EYT00`00EYUFV@030003EYT40003EYT30002EYT00`00EYT00002
0004FYX40003F[X3000015Zj0000000015Zj0`0000AJfP000000009Jf`H00003F_/0000000X00003
Fcd0000000<00003Fed0000000<00003Fil0000000H00<9oo`03001oogoo09Ioo`03001oogoo00io
o`00FGoo00<007ooOol0ogoo47oo100000DQ5@00>GDiM@0000<mU@8000A5]@040015]DFe0006BMD0
0`00BMD00007CMD00`00CME=e@07CMD30006COD00`00BME9e@05BMD20008BMD01000CME=eDgE0P00
0dgE00<004geCOD01Tge00<004geCOD014ge0`002Dge00<004geCOD01Tge00<0057eDOD01e7e00<0
057eDOD01e7e00<0058EDQD01U8E00<0058FDQH01e8F00<0058FDQH01@000U8F00<0058FDQH01e8F
00<0058FDQH01E8F1000258f00<005HfESH01EHf0`002EHf10001eHf00@005HgESMF=`8000AFE`04
001FEeIGEUL20004EUL01000EUMFEeIG0P001EIG0`001EYg0P0000=JN000FWP00UYh0P0015Yh0P00
15ZH0P000eZI0P000Uji0P000UkJ00@005kJG]YNfP800003G_/0000000800003Hc`0000000<00004
Gmh000000003EWP00`00EWQFN003EWP60006EWP50006EWT40006EWT40006EYT40003EYT30002EYT0
0`00EYT000020004EYT30004FYX30002F[X00`00F[X000020002F[X2000015Zj001J^UZj0`0000MJ
fP00000005[J001Jf`0200000e[K00000003F_/2000015[l000005/L0P0000AK7000001O?@/00003
Fih0000000H00<Aoo`03001oogoo09Moo`03001oogoo00eoo`00FGoo00<007ooOol0ogoo47oo1000
00DQ5@00000iM@0000@mU@030015]DFe00=5]@030015]@0000M9e@8000M=e@03001=eDgE00M=e@03
001=mDge00<000==m@030019eDWE00I9e@030019eDWE00I9e@03001=eDgE00==e@04001=eDgE0008
COD00`00COE=m@06COD40006COD00`00COE=m@06COD00`00DOEAm@07DOD00`00DOEAm@07DOD00`00
DQEB5@06DQD00`00DQIB5P05DQH50007DQH00`00DQIB5P07DQH00`00DQIB5P02DQH30002DQH00`00
DSIB=P07DSH00`00ESIF=P02ESH30002ESH00`00ESIF=P06ESH2000:ESH40006EUL40007EUL30006
EUL20005FWL20004FWP30004FWP2000015ZH001JV5ZH0P000eZI0P0000AN^@00G[T0009NfP80009N
fP800003G_/0000000800003Hc`0000000<00004Gmh000000004EWP70004EWP00`00EWQFN0050002
EWP00`00EWUFN@03EWT300000eIh001FN@04EWT30002EWT00`00EYUFV@02EYT30002EYT00`00EYT0
00020004EYT30004EYT3000015ZI001JVUZJ0`0015Zj0`000UZj0`000eZj0`000U[J0P000e[J1P00
0U[k0`0000=Jn`0000002`0000=KG@0000003000agoo00<007ooOol0Ugoo00<007ooOol03Goo001I
Ool00`00Oomoo`3oOolAOol300000b4E00000002>GD01@00?IDmUCfE00001DFe00<004Fe000024WE
0P001TgE00<004gECMD01dgE00<004geCOD00dge100024WE00<004WEBMD01TWE00<004gECMD014gE
00<004gE000024ge00<004geCOD01Tge00@004geCOE=m@D00003COD004ge00M=m@03001AmE7e00MA
m@03001AmE7e00MAm@03001B5E8E00IB5@03001B5U8F00D0009B5@03001B5U8F00MB5P03001B5U8F
00MB5P03001B5P00008000EB5P03001B=U8f00MB=P03001F=P00008000EF=P03001F=UHf00AF=P80
0003ESH005Hf00QF=P8000QFE`8000UFE`8000IFE`800003FUL005Yg009JM`8000EJN08000AJN080
00AJV08000=JV@8000=N^@800003G]X00000009NfP800003G_/0000000800003Hc`0000000L00003
EWP0000000<0009FF003001FN5Ih00EFN0@000QFN003001FN@00008000EFN003001FN@00008000EF
N@03001FV@00008000AFV@<000AFV@<00004EYT005JIEYT30004FYT30004F[X300000eZj001J^P02
0003F[X300000eZj000000020002F]X300000e[K00000002F_/300000e[k00000003000015/L0000
05lm0P0000AO?@00001OG@D00003Fih0000000H00<Uoo`03001oogoo09Moo`03001oogoo00eoo`00
27oo10003Woo0`003goo0`003Goo1P005goo00<007ooOol0ogoo4Goo1P000SUe00@003fE?IDmU@80
00E5]@8000Q9e@030019e@0000E=e@03001=eDgE00M=e@03001=mDge00I=m@030019eDWE00I9e@80
00M9e@03001=eDgE00E=e@8000Q=m@03001=mDge00I=m@03001=mDge00I=m@L000==m@03001AmE7e
00MAm@03001AmE7e00MAm@03001B5E8E009B5@L000MB5@03001B5U8F00MB5P03001B5U8F00EB5P@0
00QB5P03001B=U8f00IB=P<000UF=P03001F=UHf00<000=F=P03001F=UHf00EF=P800003ESH005IG
00EFE`800003EUL005IG00IFE`800003EUL005IG00=FE`8000AJE`<000EJN0800004FWP005YhFWP2
0005FYP20002FYT20003G[T200000eji00000002G]X20002G_/300000f<l0000000:0007EUP00`00
EWQFN0050002EWP00`00EWQFN005EWP40006EWP40006EWT40004EYT3000015JI001FVEJI0`0015JI
0`0015ZI0`0000AJV@00F[YJ^P<000=J^P<000=J^P8000=J^P80009JfP<00005F]/00000001Jf`03
0002F_/2000015[l000005/L2`0000=KOP0000002000c7oo00<007ooOol0Ugoo00<007ooOol03Goo
0006Ool8000;Ool5000>Ool3000;Ool:000EOol00`00Oomoo`3oOolAOol50000135E000iM@000cfE
0P001TFe00<004WEBMD01TWE00@004WEBMD000E=e@03001=eDgE00I=e@03001=mDge00I=m@030019
eDWE00I9e@03001=e@0000I9e@03001=eDgE00I=e@8000M=m@03001=mDge00I=m@03001=mDge00M=
m@03001AmE7e00=AmA`000AB5@03001B5E8E00MB5@03001B5U8F00MB5P03001B5U8F009B5P<0009B
5P03001B5U8F00MB5P03001B=U8f00=B=P<00003ESH005Hf00UF=P<000IF=P03001F=UHf00=F=P80
00=F=P03001FEeIG009FE`8000=FE`03001FEeIG00=FE`8000=FE`05001FEeIGEUL00005FUL20006
FWP01000FWQJN5Yh0`001EZH0P0000AJV@00000000=N^@80009N^@800003G]X00000009Nn`<00003
Hc`0000000800003Hih000000080009FF003001FF5IH00EFF0D000MFN003001FN5Ih00D0009FN003
001FN5Ih00D0009FN003001FNEIi00D0009FN@03001FVEJI00<000=FV@@000AFV@<00003EYT005ZI
009JV@8000AJV@<000=J^P<0009J^P@0009J^P<00004F]X000000002F]/200001E[K00000000F_/0
300000AO?@00001OG@h00<ioo`03001oogoo09Moo`03001oogoo00eoo`001Woo0P0017oo0P002goo
1@003goo0P002goo0`001Goo0`0057oo00<007ooOol0ogoo4Woo100000DaE@00>GDiM@00008mU@03
0011U@0000E5]@030019eDWE00I9e@050019eDWEBMD00004CMD00`00CME=e@06CMD00`00COE=m@06
COD20007BMD01000CME=e@001DWE00<004gECMD01TgE00<004ge00001Tge00<004geCOD01Tge00<0
04geCOD01dge00<0057eDOD01U7e00<0057eDOD01e7e00<0057eDOD01e7e00<0058EDQD01U8E00<0
058EDQD01e8E00<0058FDQH01e8F00<0058F00000P001E8F00<0058FDQH01e8F00@0058fDSIB=P80
00AF=P03001F=UHf00MF=P8000UF=P03001F=UHf008000IF=P04001FEeIG0006EUL00`00EUMFE`02
0006EUL30004FUL200000eYg001JN003FWP20003FWP20005FYP20002FYT20003G[T20002G[T20000
0ekJ00000002G_/400001F<l00000000Hid01@0015IH00<005IH000010000UIH00<005IhEWP01EIh
1@001UIh10001UIh10001UIi10000eJI0`000UJI00@005JIEYUFV@8000AFV@@000=JV@<00003FYT0
05Zj00<000AJ^P80009J^P<00005F]X00000001JfP0400000e[K00000002F_/3000015[l000005/L
0P0000AO7000001O?@D00003Fgh0000000P00=5oo`03001oogoo09Moo`03001oogoo00eoo`001Goo
0P001Woo0P002Woo1@003goo0`004goo0P0057oo00<007ooOol01@00ogoo3Goo100000DaE@00>GDi
M@00008mU@030011U@0000E5]@8000M9e@030019eDWE0099e@05001=eDgECMD00008CMD00`00COE=
m@06COD00`00BM@00006BMD01@00CME=eDgE000014WE00<004gECMD01TgE00<004geCOD00P0014ge
00<004geCOD01Tge00<004geCOD01dge00<0057eDOD01U7e00<0057eDOD01e7e00<0057eDOD01e7e
00<0058EDQD01U8E00<0058EDQD01e8E00<0058FDQH01E8F1000258F00<0058FDQH01e8F10001UHf
00<005HfESH01EHf0P0000=F=P00ESH025Hf0`0025Hf0`001eIG0`001eIG0P001EYG00D005YgFWMJ
M`00009JN08000=JN0800003FYP005ZH009JV080009JV@800003G[T005ji0080009N^@800006G]X0
0000G_X005kk0`0000ES?000000006>M00D000AFF0@000QFF003001FN00000@0009FN003001FN5Ih
00=FN0<00003EWP005Ih00AFN0<0009FN003001FNEIi009FN@<0009FN@03001FV@00008000EFV@@0
00EFV@8000AJV@8000=JV@<000AJ^P<00004F[X000000002F]X20003F]X200001E[K00000000F_/0
0`000U[k6@00dgoo00<007ooOol0Ugoo00<007ooOol03Goo0005Ool20006Ool2000;Ool3000@Ool3
000DOol2000BOol4003oOolBOol40002<ED01P00>GDiM@00?ID00091U@030015]DFe0095]@030015
]@0000I9e@030019eDWE00=9e@04001=eDgE0008CMD00`00COE=m@06COD00`00BM@00006BMD00`00
CME=e@02CMD01@00BME9eDWE000024gE00<004geCOD00Tge00D004geCOE=m@0000Q=m@03001=mDge
00M=m@03001AmE7e00IAm@03001AmE7e00MAm@03001AmE7e00MAm@03001B5E8E00IB5@03001B5E8E
00MB5@03001B5U8F009B5P<0009B5P03001B5U8F00MB5P03001B5U8F00IB5P8000YF=P03001F=UHf
009F=P8000=F=P03001F=UHf00IF=P8000UF=P8000QFE`8000MFE`800003EUL005YG009JE`8000EJ
M`8000AJN003001JV5ZH009JV0<000=JV@04001N^EjiG[T20003G[T01000G]YNfP000ekj0`0000=S
?00000001`0000=FF00000000`000UIH00<005IHEUP01EIH100025Ih00<005Ih00000P001EIh00<0
05Ih00000P001EIh00<005Ii00000P0015Ii0`001eJI0P001EJI0`0000=JV@00FYT00`000eZI0P00
00AJ^@00F[YJ^P<00005F[X00000001J^P040002F]X3000015[K000005[k0`000U[k1@0000AO7000
001O?@800003Ged0000000/00=Ioo`03001oogoo09Moo`03001oogoo00eoo`0017oo0P0027oo0P00
7Woo0P0057oo0P004Woo00<007ooOol0ogoo57oo100000LaE@00>GDiM@00?ID00002@ID00`00AKE5
]@02AKD00`00AKD00006BMD00`00BME9e@04BMD00`00CMD00008CMD00`00COE=m@06COD01000BMA9
e0001DWE00<004gECMD00TgE00D004WEBME9e@0000Q=e@03001=mDge00==m@800003COD004ge00Q=
m@03001=mDge00I=m@03001AmE7e00IAm@03001AmE7e00MAm@03001AmE7e00MAm@03001B5E8E00MB
5@03001B5E8E00IB5@03001B5P00008000EB5P03001B5U8F00QB5P03001B5U8F00=B5P800003EQH0
05Hf00UF=P03001F=UHf008000EF=P03001F=UHf00=F=P<00003ESH005Hf00IF=P800003ESL005IG
00EFE`800003EUL005IG00AFE`8000=FE`04001JE`000006FWL20003FWP20004FYP20003FYT20002
G[T200000eji001N^@0200000ekJ00000002G_X400000f<l000000090007EUP00`00EUQFF0050002
EUP00`00EWQFN005EWP40006EWP40007EWP30004EWT300000eIh001FV@04EYT3000015JI001FVEJI
0`000eZI0`000eZI0`000eZi0`000UZj0P000eZj0P000U[J0`0000=Jf`00000010000e[k0P0000AO
7000001O70P00003Fgh0000000L00=Uoo`03001oogoo09Moo`03001oogoo00eoo`0017oo0P0027oo
0P007Woo0`004goo0P004Woo00<007ooOol0ogoo57oo10000S5E00<003Ue>GD00P000d6E00D004Fe
AKE5]@000095]@030019eDWE00=9e@030019eDWE00E9e@8000Q=e@03001=mDge00I=m@040019e4WD
0005BMD00`00CME=e@03CMD01000BME9e@0024gE00<004geCOD01Dge0P002Dge00<004geCOD01Tge
00<0057eDOD01U7e00<0057eDOD01e7e00<0057eDOD01e7e00<0058EDQD01e8E00<0058EDQD0158E
1000258F00<0058FDQH0258F00<0058FDQH00`000eHF00<005HfESH025Hf0`001eHf00@005HfESIF
=P8000AF=P03001F=UHf00=F=P8000=F=`03001FEeIG009FE`8000=FE`04001FEeIGEUL20005EUL2
0006FWL200000eYh001JN0020004FYP200000eZH001JV@020003G[T01000G[UN^Eji0P0000=NfP00
00000ekj0`0000=S?00000001P000UIH00<005IHEUP01EIH1@001eIH00<005IhEWP01@000UIh00<0
05IhEWP00UIh0`000UIh00<005IhEWP00eIh0`0000AFN000EWUFN@<000EFN003001FV@00008000=F
V@@000=JV@<0009JV@04001JV@000003F[T300000eZj000000020003F[X2000015[J000000000U[K
0P0000IJn`00001Jn`00F_/;00000emM0000000;003KOol00`00Oomoo`2GOol00`00Oomoo`0=Ool0
00Aoo`8000Qoo`8001moo`8001=oo`80019oo`03001oogoo0?mooaAoo`@0008aE@03000iMCUe0080
00=1U@050015]DFeAKD00003AKD00`00BME9e@02BMD00`00BME9e@06BMD20007CMD00`00COE=m@06
COD01@00BMA9e4WD000014WE00<004gECMD014gE00<004WE000024gE00<004geCOD01Tge0`001dge
00<004geCOD01Tge00<0057eDOD01e7e00<0057eDOD01U7e00<0057eDOD01e7e00<0058EDQD01e8E
00<0058E000010000U8E00<0058FDQH01e8F00<0058FDQH0258F0`001UHF00<005HfESH01eHf0P00
2EHf10001eHf00<005HfESH00P001EHg00<005IGEUL00P001UIG0`001UIG0P001EYg0P000eYh0P00
1EZH00@005ZHFYQJV08000=N^@80009N^@800003G]X0000000=NnP<00003Hc`0000000<00003Gmh0
000000EFF003001FF00000@0009FF003001FF5IH00EFF0D000MFN003001FN000008000IFN003001F
N000008000=FN0@000IFN0@000=FV@<0009FV@03001JV@00008000AJV@<000=J^@8000=J^P8000=J
^PH00003F]X0000000D000=Jn`800004Ga`00000Ga`2000015ll000005mM0P0000=KOP0000001`00
gWoo00<007ooOol0Ugoo00<007ooOol03Goo0004Ool20008Ool2000OOol2000COol2000BOol00`00
Oomoo`3oOolEOol400000c5E000iM@02>GD00`00@IE1U@02@ID01000AKE5]@0014Fe00D004WEBME9
e@0000Q9e@03001=e@0000I=e@03001=mDge00I=m@030019e4WD0099e0050019eDWEBMD00007CMD2
0008CMD00`00COE=m@06COD00`00COE=m@030004COD00`00COE=m@06COD00`00DOEAm@07DOD00`00
DOEAm@06DOD00`00DOEAm@07DOD00`00DQEB5@05DQD40007DQD00`00DQIB5P08DQH00`00DQIB5P05
DQH30009EQH00`00ESIF=P03ESH300000eHf001F=P07ESH2000:ESH30007ESL30007EUL20006EUL2
00000eYg001JM`02FWL20004FWP20004FYP20003FYP20002G[T20003G[T00`00G]YNfP020002G_X4
00000f<l001SO@02000015oN0000000015IH100025IH00<005IH000010000UIH00<005IhEWP01EIh
10001eIh10000eIh0`000UIh00<005IhEWP00UIh0`000UIh00<005JI00000P0015JI0`0015ZI0`00
0UZI10000eZj0P0000=J^P00F[X00P0000=JfP0000000e[J0P0000=Jn`0000000e[k0`0000=Nn`00
00002@0000=OOP0000001`00fgoo1P00VGoo00<007ooOol03Goo0004Ool20008Ool2000OOol3000A
Ool2000COol00`00Oomoo`3oOolEOol40002<ED01000>GDiM@00146E00@004FeAKD000A5]@050019
eDWEBMD00008BMD00`00CME=e@020004CMD00`00COE=m@06COD00`00BMA9e002BM@01@00BME9eDWE
000024gE0P001dgE00<004geCOD01Tge00<004geCOD00dge0`0000==m@00COD01dge00<0057eDOD0
1e7e00<0057eDOD01U7e00<0057eDOD01e7e00<0058EDQD01@000U8E00<0058EDQD01U8E00<0058F
DQH0258F00<0058FDQH00U8F0`000U8F00<005HFEQH01eHF00@005HfESIF=P8000AF=P03001F=UHf
00AF=P800003ESH005Hf00QF=P8000QF=`8000MFE`800003EUL005IG00=FE`8000AJM`<000AJN080
0004FWP005ZHFYP20003FYP2000015jI001N^@000eji0P0000INfP00001NnP00G_X300000f<l0000
000200001EoN00000000EUP01@000UIG00<005IHEUP01EIH100025IH00<005Ih000010000UIh00@0
05IhEWQFN0D0009FN003001FN000008000EFN003001FN000008000AFN0<000AFV@<00004FYT005ZI
FYT30003FYT30003F[X30002F[X60003F]X200000e[K00000003F_/200000ekk00000003000015ll
000005mM3000e7oo2P001Goo00<007ooOol0Ugoo00<007ooOol03Goo0004Ool20008Ool2000POol2
0009Ool20005Ool3000COol00`00Oomoo`3oOolFOol40000135E000iMCUe0P00146E00<004Fe0000
1DFe00@004WEBMD000Q9e@03001=eDgE009=e@05001=eDgECMD00008COD00`00BMA9e003BM@01000
BME9e@0024gE00<004gE00001TgE00<004geCOD01Tge00<004geCOD01Tge1`000dge00<0057eDOD0
1e7e00<0057eDOD01U7e00<0057eDOD00U7e20001e8E00<0058EDQD01U8E00<0058FDQH0258F00<0
058F00000P001E8F00<005HFEQH01eHF10001UHf00<005HfESH00UHf0P000eHf00<005HfESH01EHf
0P0000=F=P00ESL01EHg0P0000=FE`00EUL015IG0P000eIG00<005IGEUL00P001EYg0P001EYh00<0
05YhFWP00UYh0P0015ZH00@005jIGYUNV@80009N^@80009NfP04001NnUkjG_X3000016<l000006=m
0P0000=OgP0000000`001eIG00<005IHEUP00UIH0`000UIH00<005IHEUP01EIH10001UIh1@001UIh
0`001eIh0`0015Ih0`0000AFN@00EYUFV@<000AJV@<000=JV@<0009JV@04001J^P000002F[X30000
0eZj00000003F]X600000e[k0000000200000ekk0000000300000ell0000000600000e^N00000004
003;Ool;000@Ool00`00Oomoo`2FOol00`00Oomoo`0=Ool000Aoo`8000Qoo`80021oo`8000Uoo`T0
01Aoo`03001oogoo0?mooaIoo`@0008aE@04000iM@000004@ID00`00AKD00006AKD00`00BMD00008
BMD00`00CME=e@03CMD200000dgE001=m@07COD00`00BMA9e003BM@01000BME9e@0024gE00@004gE
CMD000E=e@03001=mDge00I=m@03001=mDge00M=m@03001AmE7e00=Am@T000AAm@03001AmE7e009A
m@T000EAm@03001B5E8E00MB5@03001B5E8E00MB5@03001B5U8F00EB5P@000QB5P03001F5UHF00IF
5P8000UF=P03001F=UHf008000EF=P03001F=UHf00=F=P8000=F=P03001F=eHg009F=`8000=FE`04
001FEeIGEUL20005EUL30005FWL200000eYg001JN002FWP20004FWP20003FYP20002GYT2000015ji
001N^@000UkJ0P000Ukj100000=S?000Hgd00P0000=OgP0000000UIG00<005IGEUL01eIG00<005IH
00000P001EIH00<005IHEUP00UIH0`000UIH00<005IhEWP00UIh0`000UIh00<005IhEWP00eIh0`00
00=FN000EWP015Ih0`0000AFN000EWQFN0<000AFN@<000AJV@<00003FYT005ZI00<000AJV@<00004
F[X000000002F[X200000e[J001JfP0200000e[K00000003F_/200000ekk0000000300000ell0000
000300000emM000000080033Ool:000LOol00`00Oomoo`2EOol00`00Oomoo`0=Ool000Aoo`8000Qo
o`80025oo`8000Qoo`800003Ool0000000<001Eoo`03001oogoo0?mooaIoo`@0008aE@05000iM@00
?ID00004@ID20006AKD00`00BMD00008BMD00`00CME=e@05CMD20008COD00`00BMA9e004BM@00`00
BMD00008CMD01000CME=eDgE0P000dgE00<004geCOD01Tge00<004geCOD01dge00<0057eDOD01U7e
00<0057eDOD00e7e2@00157e00<0057eDOD01e7e00<0058EDQD01e8E00<0058EDQD01e8E00<0058F
DQH00U8F0`000U8E00<0058FDQH01e8F00<005HFEQH00eHF0`0000=F5P00ESH025Hf0`0025Hf00<0
05HfESH00P001EHf00<005HgESL00P001UIG0`001UIG0P001UYg00H005YgFWMJM`00FWP20004FWP2
00000eZH001JV0020003GYT01000G[UN^Eji0P0000=NfP0000000ekj0`0000IS?000001SO@00Gmh2
0004EUL00`00EUMFE`05EUL40008EUP00`00EUP000020005EUP00`00EWP000020006EWP00`00EWP0
00020005EWP00`00EWP000020004EWP30004EWT300000eZI001JV@02FYT20003FYT30004FYT30000
15Zi000000000UZj0`000e[J1@000e[k0P0000=Nn`0000000`0000=O?00000000`0000AOG@00001K
WPL00;]oo`X002Moo`03001oogoo09Aoo`03001oogoo00eoo`001Goo0P001Woo0P008Woo0P0027oo
0P006goo00<007ooOol0ogoo5Woo1@0000HaE@00>GD003fE0004@ID20007AKD20008BMD00`00CME=
e@06CMD20007COD00`00BMA9e005BM@20008CMD00`00CME=e@03CMD01000CME=e@0024ge00<004ge
COD01dge00<0057eDOD01U7e00<0057eDOD01e7e00<0057eDOD01U7e00<0057eDOD01e7e00<0058E
DQD01e8E00<0058EDQD01e8E00<0058F00000P001E8E00<0058FDQH01e8F00@005HFEQIF5P8000AF
5P03001F=UHf00IF=P8000YF=P<000MF=P<000MFE`8000IFE`800003FUL005Yg00=JM`8000AJM`80
00EJN004001JV5ZHFYP20003GYT20002G[T200000ekI00000003G_X3000016<l000006=l0P0000=O
gP0000001UIG00<005IG000010000UIG00<005IHEUP01EIH10001eIH0`001eIh10001UIh100015Ih
0`0000=FN000EWT00UIi0P0015ZI10000eZI0P0000AJV@00FYUJV@<0009J^@800003F[X005Zj0080
00=JfPD000=Jn`P00003Gc`0000000<00005Ged00000001OWP06002cOol;000aOol00`00Oomoo`2D
Ool00`00Oomoo`0=Ool000Eoo`8000Ioo`8001Uoo`8000Moo`8000Qoo`8001]oo`03001oogoo0?mo
oaMoo`@0008aE@80008mU@030011UD6E0091U@030015]DFe00I5]@030019eDWE00I9e@03001=eDgE
00I=e@04001=e0000005COD00`00BMA9e005BM@20008CMD00`00CME=e@04CMD00`00CMD00008COD0
0`00COE=m@07COD00`00DOEAm@06DOD00`00DOEAm@07DOD00`00DOEAm@06DOD00`00DOEAm@07DOD0
0`00DQEB5@07DQD00`00DQEB5@06DQD30008DQD00`00DQIB5P07DQH40006EQH00`00ESIF=P04ESH2
00000eHf001F=P08ESH20008ESH20007EUL200000eIG001FE`04EUL01@00FUMJEeYG00000UYg0P00
1EYg0P0015Yh0P000eZH0P000UjI0P000eji00<005kIG]T00P000Ukj100000=S?000Hg`00P0000=O
gP0000001UIG100025IG00<005IH000010000UIG00<005IHEUP00eIH0`0000=FF000EWP015Ih0`00
0UIh00<005IhEWP00UIh0`000UIh00@005IhEWQFN08000AFN0@000EJV@8000=JV@<000=JV@<0009J
^@<000=J^P8000=JfP800006F]X00000F]/005[k0P0000ANn`00001O70800003Ga`0000000<00003
Ged0000000P00:]oo`X003eoo`03001oogoo09=oo`03001oogoo00eoo`001Woo0P0017oo0P006Woo
0P0027oo0P001goo0P006goo00<007ooOol0ogoo5goo0`0000<U5@00<ED00P000SfE00<0046E@ID0
0T6E00<004FeAKD01TFe00<004WEBMD01TWE00<004gECMD01TgE00@004gDCMA=e0<0009=m@030019
e4WD00I9e003001=eDgE00I=e@03001=eDgE00E=e@8000U=m@03001=mDge00I=m@03001AmE7e00IA
m@03001AmE7e00MAm@03001AmE7e00IAm@03001AmE7e00MAm@03001B5E8E00MB5@03001B5E8E00=B
5@<00003DQD0058E00QB5@03001B5U8F00IB5P8000YF5P04001F=UHfESH20003ESH00`00ESIF=P05
ESH200000eHf001F=P05ESH200000eHf001FE`05EUL01@00EUMFEeIG00000eIG0P001EYG0P001EYg
0P0000AJN000FWQJN08000AJV005001NV000GYT00003G[T200001UkI000005kj001NnP<00006Hc`0
0000Hg`005oN0`000UIG1@000UIG00<005IGEUL01EIG100025IG00<005IH00000P001EIH00<005Ih
00000P001EIh00<005Ih00000P001EIh10001EIh0P001EZI0`0000=JV@00FYT00P000eZI0`0000=J
V@00F[T00P000eZj0`0000=J^P0000000P0000=JfP0000000e[K3@0000EOG@00000005nN00L00:=o
o`X004Qoo`03001oogoo09=oo`03001oogoo00aoo`001Woo20006Woo30001goo2P004goo00<007oo
Ool0ogoo5goo1@0000<aE@0000000cfE00@0046E@IE1U@8000M5]@8000M9e@03001=eDgE00I=e@03
001=e4gD00A=e0<000Q9e003001=eDgE00I=e@03001=eDgE00I=e@8000Q=m@03001=mDge00I=m@03
001AmE7e00IAm@03001AmE7e00MAm@03001AmE7e00IAm@03001AmE7e00QAm@03001B5E8E00IB5@04
001B5E8EDQD20004DQD00`00DQEB5@07DQD00`00DQIB5P03DQH300000eHF001F5P09EQH01000ESIF
=P001EHf00<005HfESH00eHf0P000eHf00<005HfESH00eHf00D005HfESIF=P0000AFE`8000AFE`04
001FE`000006FUL20005FWL00`00FWQJN002FWP20004FYP20002GYP20002G[T20002G]T01000G_YN
nUkj0`0000AS?000001SO0800003Gmh0000000@000MFE`03001FEeIG009FE`<0009FE`03001FEeIG
00EFE`@000MFF0<000MFN0<000MFN08000EFN0<00004EWP005ZIFYT30004FYT20003FYT20004FYT2
0003F[X20003F[X20003F]X00`00F]]Jf`05000015lL000005lL0P0000AO?000001OG@/009Yoo`/0
059oo`03001oogoo09=oo`03001oogoo00aoo`0027oo100077oo30001goo2P004goo00<007ooOol0
ogoo67oo0`0000@U5@00<ED000<mU@040011UD6E@ID20007AKD00`00BMD00006BMD00`00CME=e@06
CMD00`00CMA=e006CM@00`00BMA9e006BM@20007CMD00`00CME=e@06CMD01000COD000001Tge00<0
04geCOD01Tge00<0057eDOD01U7e00<0057eDOD01e7e00<0057eDOD01e7e00<0057eDOD01e7e00<0
058EDQD01U8E10001U8E00<0058EDQD01e8E00@0058FDQIB5P8000AF5P03001F5UHF00QF5P<000MF
=P03001F=UHf008000EF=P04001F=UHfESH20005ESH01000EUL000001UIG0P001UYG0P0000=JM`00
FWL00UYg0P0015Yh0P0015ZH00<005jHGYP00P0000AN^@00G[T0009Nf@80009NnP@00003Hc`006=l
00800004Gmh000000002ESL00`00EUMFE`07EUL00`00EUL000020005EUL00`00EUMFE`02EUL30002
EUL00`00EUQFF003EUP300000eIH001FN004EWP300000eIh001FN004EWP3000015Ih001FN5Ih0`00
15Ih0`0015ZI0`0000=JV@0000000P000eZI0`0000=J^@0000000P000eZj0P0000=JfP00F]X00P00
00AJf`00001Nn`800003G_/00000014009=oo`X005ioo`03001oogoo099oo`03001oogoo00aoo`00
F7oo00<007ooOol0ogoo67oo0`0000@U5@00<ED000@mU@060011UD6E0015]@001TFe00@004WEBMD0
00E9e@03001=eDgE00I=e@03001=e4gD00I=e0030019e4WD00I9e003001=e00000I=e@03001=eDgE
00I=e@04001=mDgeCOD20004COD00`00COE=m@06COD00`00DOEAm@07DOD00`00DOEAm@06DOD00`00
DOEAm@07DOD00`00DOEAm@07DOD00`00DQEB5@04DQD30009DQD00`00DQEB5@07DQD40006EQH00`00
EQIF5P07EQH20009ESH30007ESH01000ESH000001eHf0P001eIG0P001UYG00H005YgFWMJM`00FWL2
0004FWP2000015ZH001JV5ZH0P000UjH00@005jiG[UN^@800003G]T0000000=NnP04001S6`00Hc/2
00000f=l001OgP030004ESL00`00EUMFE`05EUL40008EUL00`00EUL000020006EUL00`00EUP00002
0005EUP00`00EWP000020005EWP00`00EWP000020004EWP30004EWP300000eYh001JV@02FYT20003
FYT20004FYT20003F[T20003F[X30003F]X800000ekk00000002000015ll000005mM2`00Rgoo2P00
JGoo00<007ooOol0TGoo00<007ooOol037oo001GOol00`00Oomoo`3oOolIOol500000c5E00000003
?ID01000@IE1U@000TFe00<004FeAKD00dFe00D004WEBME9e@0000A9e@03001=eDgE00I=e@03001=
e4gD00I=e08000M9e004001=e4gD0005CMD00`00CME=e@06CMD00`00COE=m@03COD20002COD00`00
COE=m@06COD00`00DOEAm@07DOD00`00DOEAm@06DOD00`00DOEAm@07DOD00`00DOEAm@07DOD00`00
DQD000040002DQD00`00DQEB5@08DQD00`00DQEB5@05DQD2000:EQH00`00EQIF5P03EQH300000eHf
001F=P07ESH20009ESH20008ESH20006EUL200000eYG001JE`03FUL20004FWL20005FWP00`00FYQJ
V002FYP20002GYP20003G[T01000G]T000000ekj1P0000AWO000001OgP8000MF=`03001FE`0000@0
009FE`03001FEeIG00EFE`@000MFE`@000MFF0<000IFN0@000AFN0<00003EWP005Ih009FN08000AJ
N0@000=JV@800003FYT005ZI00<000=J^@800003F[T005Zj008000=JfPD00003G_/00000009Nn`@0
0003Gc`0000000`0089oo`/007Aoo`03001oogoo091oo`03001oogoo00aoo`00Egoo00<007ooOol0
ogoo6Woo0`0000@U5@00000000<mU@040011UD6E0002AKD00`00AKE5]@03AKD00`00BME9e@02BMD0
1@00BME9eDWE000024gE00<004gDCM@01TgD0P001dWD00D004gDCMA=e00000A=e@03001=eDgE00I=
e@03001=mDge00E=m@<000Q=m@03001AmE7e00MAm@03001AmE7e00IAm@03001AmE7e00MAm@03001A
mE7e00EAm@@000MB5@03001B5E8E00QB5@03001B5E8E00=B5@800003DQD005HF00UF5P04001F5UHF
EQH20004ESH00`00ESIF=P04ESH200000eHf001F=P07ESH20007ESH200000eIF001FE`04EUL01@00
FUMJEeYG00000UYG0P001EYg0P0015Yh0P0015ZH0P0000=NV00000000eji0P0000=Nf@0000000Ukj
0P0000ES6`00Hc/006Ml00800004Hmd000000006ESL40008EUL00`00EUL000040002EUL00`00EUMF
E`03EUL30002EUL00`00EUQFF003EUP300000eIH001FN003EWP30002EWP01000EWQFN5Ih0P0015Ih
10001EYh0P000eZI0`000eZI0P000eZi0`000eZi0P000e[J0P0000AJfP00001Nn`80009Nn`@00003
Gc`0000000800003Ggh0000000L007Yoo`X007moo`03001oogoo091oo`03001oogoo00aoo`00Egoo
1P00ogoo5goo0`0000@U5@00000000@mU@040011UD6E0002AKD00`00AKE5]@02AKD00`00BME9e@02
BMD01@00BME9eDWE000024gE00<004gDCM@01TgD00<004Vd00001TWD00<004gDCM@00TgD00D004gE
CME=e@0000Q=e@03001=mDge00M=m@<000I=m@03001AmE7e00MAm@03001AmE7e00IAm@03001AmE7e
00MAm@03001AmE7e00D0009B5@03001B5E8E00IB5@03001B5E8E00QB5@03001B5E8E00<000=B5@03
001F5UHF00QF5P@000IF=P03001F=UHf009F=P8000=F=P03001F=UHf00AF=P800003ESH005Hf00EF
=P05001FEUIFEUH00003EUL20005FUL20006FWL00`00FWL00002FWP20004FYP200000ejH00000004
G[T02@00G]UNf@00G]X005kj001S6`0400000fMl0000000300000e8g001F=`050002ESL00`00EUMF
E`06EUL30008EUL00`00EUL000020005EUL01000EUQFF5IH0P0015IH00<005Ih00000P001EIh1000
1EIh0P001UYh0P0000=JV000FYT00P000eZI0`0000=JV@00F[T00P000eZi0`0000=J^P0000001@00
00ANn`00001Nn`<00003Ga`005ll00@00004Ggd00000Fkh5001cOol:002:Ool00`00Oomoo`2?Ool0
0`00Oomoo`0<Ool005Moo`03001oogoo0?mooaYoo`@000049AD000000003?ID01000@IE1U@000TFe
00<004FeAKD00TFe00<004WEBMD00dWE00@004WEBMD000Q=e@03001=e4gD00I=e0030019]00000I9
e003001=e4gD009=e005001=eDgECMD00008CMD00`00COE=m@07COD00`00COE=m@0500000dge001A
m@08DOD00`00DOEAm@06DOD00`00DOEAm@05DOD50007DQD00`00DQEB5@06DQD00`00DQEB5@08DQD3
0006DQD00`00EQIF5P07EQH20009ESH00`00ESIF=P020005ESH00`00ESIF=P02ESH20003ESH00`00
ESIF=P02ESH20004EUH01000EUL000001UYG0P001EYg0P000eYg0P001EZH00<005jHGYP00P0015ji
00@005kI0000009NfP800005Ha/00000001WO002000016?M0000058g10001eHg00<005IGEUL00eIG
0`0000=FE`00EUL01eIG0`0025IG10001EIH0`001eIh0P001UIh0P0000=JN000FWP00UYh0`000eZH
0P000eZI0P0015ZI0P000eZi0P000eZj0P0000=JfP0000000Ukk0P000Ukk0P0000=O700000001`00
00=O_P0000000`00Jgoo2P00UGoo00<007ooOol0SWoo00<007ooOol037oo001GOol00`00Oomoo`3o
OolKOol3000012DE0000000013fE00<0046E00000dFe00D004FeAKE5]@0000I9e@030019e@0000Q=
e@03001=e4gD00I=e0040019]4Vd0005BM@00`00CMA=e003CM@01000CME=e@0024gE00<004geCOD0
1dge00<004geCOD01Dge1`00157e00<0057eDOD01U7e00<0057eDOD01@000U7e00<0058EDQD01e8E
00<0058EDQD01e8E00<0058EDQD01U8E0P00258E00<005HFEQH01EHF0P0000=F5P00ESH025Hf0`00
25Hf00@005HfESH000IF=P04001F=P000006EUH20006FUL200000eYG001JM`03FWL00`00FWMJM`02
FWL20004FYP20002GYP00`00G[T00002G[T200000ekI001NfP02G]X00`00HaX0000200000fMl0000
00060002ESL00`00ESMF=`07ESL00`00EUL000020004EUL00`00EUMFE`03EUL300000eIG001FE`07
EUL20006EUP200000eIH001FN005EWP200000eIh001FN002EWP30004FWP30003FYP300000eZI0000
00020004FYT200000eZi000000020003F[X200000e[J00000002G_/20002G_/200000elK00000002
00000emM00000008001ROol;002POol00`00Oomoo`2=Ool00`00Oomoo`0<Ool005Moo`03001oogoo
0?mooa]oo`<000059AD00000>GD00003?ID00`00@ID00003AKD01@00AKE5]DFe00001dWE0P0024gE
00<004gDCM@01TgD00@004VdBK@000E9e003001=e4gD00A=e003001=e@0000Q=e@03001=mDge00M=
m@03001=mDge00I=m@03001AmE7e00=AmA0000MAm@03001B5E8E00MB5@03001B5E8E00MB5@03001B
5E8E00=B5@<00003DQD0058E00QB5@03001F5UHF009F5P8000=F5P03001F=UHf00IF=P8000YF=P<0
00MF=P8000MFEP8000IJE`05001JEeYGFUL00002FWL20004FWL00`00FWP00002FYP20002GYP20003
G[T20002G]T00`00G]YNfP0200001F<J00000000Ig`01@001UHg00<005HgESL01EHg100025IG00<0
05IG00000P0015IG00<005IGEUL00eIG0`0000=FE`00EUP00UIH0`000eIH00@005IhEWQFN0<000AF
N0<000IJN08000=JV08000=JV@8000EJV@80009J^@8000=J^P<00004F]X00000G]X300000ekk0000
000600000emM00000007001KOol:002[Ool00`00Oomoo`2=Ool00`00Oomoo`0<Ool005Moo`03001o
ogoo0?mooa]oo`@000049AD003Ue0004?ID20004AKD01000AKE5]@0024WE0P001dgE00<004gDCM@0
1TgD00D004VdBKA9]00000A9e003001=e4gD00E=e08000Q=e@03001=mDge00M=m@03001=mDge00I=
m@03001AmE7e00MAm@03001AmE7e00IAm@03001AmE7e00MAm@03001B5E8E00MB5@03001B5E8E00MB
5@04001B5E8EDQD20004DQD00`00DQEB5@07DQD00`00EQIF5P020005EQH00`00ESIF=P04ESH20000
0eHf001F=P08ESH20008ESH20007EUH00`00FUL00004FUL20005FUL20004FWL20003FWP20003GYP0
0`00G[UN^@02G[T200000ekI00000002G]X00`00HaX0000200000fMl000000030008ESL00`00ESMF
=`050002ESL00`00EUMFE`05EUL40008EUL00`00EUL000020005EUL30007EUP30006EWP20005FWP3
00000eYh000000020003FYT200000eZI001JV@02FYT20002F[T200000eZi001J^P020002F]X20002
G]X2000015kk000005lK0P0000AO?000001O?@800003Gih0000000@005=oo`X00;Ioo`03001oogoo
08aoo`03001oogoo00aoo`00Egoo00<007ooOol0ogoo77oo0`0000@U5@00>GD000@mU@8000A5]@04
0015]DFe0008BMD00`00CM@00006CMD00`00CMA=e006CM@01@00BKA9]4Vd000014WD00<004gDCM@0
1TgD0P001dgE00<004geCOD01dge00<004geCOD01Tge00<0057eDOD01e7e00<0057eDOD01U7e00<0
057eDOD01e7e00<0058EDQD01e8E00<0058EDQD01e8E10001U8E00<0058EDQD01e8E0`001eHF00<0
05HfESH00eHf00D005HfESIF=P0000MF=P800003ESH005Hf00EF=P800003ESH005IF00AFEP80009J
E`03001JEeYG008000IJE`8000AJM`03001JN5Yh009JN08000=NV004001N^EjiG[T200000eji0000
0003G]X00`00HaX0000200000fMl000000030008ESL40007ESL00`00EUMFE`02EUL30002EUL00`00
EUMFE`05EUL40006EUL30007EUP30005EWP300000eIh001JN002FWP20003FWP20004FYT20004FYT3
0002F[T20003F[T20002F]X20002G]X200000ekk00000009000015nN000005ON1000BGoo2`00`Goo
00<007ooOol0Rgoo00<007ooOol037oo001GOol00`00Oomoo`3oOolLOol300001BDE000iMCUe0000
13fE00<004FeAKD00dFe00<004Fe000024WE00@004gDCM@000E=e@03001=e4gD00I=e0030019]4Vd
0099]0050019e4WDBM@00008CM@00`00CM@00006CMD00`00COE=m@07COD00`00COE=m@06COD00`00
DOEAm@07DOD00`00DOEAm@06DOD00`00DOEAm@07DOD00`00DQEB5@07DQD00`00DQEB5@06DQD20009
DQD00`00DQEB5@06DQD20009EQH01000ESIF=UHf0P0015Hf00<005HfESH015Hf00D005HfESIF=P00
00EF=P05001F=UHfESH00004EUH00`00FUMJE`03FUL20006FUL200000eYg001JM`02FWL00`00FWQJ
N002FWP01000GYP005jH0P000eji00<005jiG[T00P000UkJ0P0000AS6P00001WO0D0009B=`03001F
=eHg009F=`<00003ESL005Hg00QF=`03001FE`00008000EFE`03001FEeIG009FE`<0009FE`03001F
EeIG009FE`<0009FE`03001FF5IH009FF0<0009FN004001FN5IhEWP20004EWP40003FWP200000eZH
001JV@02FYT00`00FYUJV@03FYT20003F[T01000F[UJ^EZi0P0000EJ^P00000005kJ00<00003G_/0
000000800004Gc`00000Gcd3000015nN000005_N1000@Goo2P00c7oo00<007ooOol0Rgoo00<007oo
Ool037oo001GOol00`00Oomoo`3oOolLOol600000cUe000mU@03?ID00`00AKE5]@04AKD20008BMD0
1@00CMA=e4gD000014gE00<004gDCM@01TgD00<004VdBK@00TVd00D004WDBMA9e00000Q=e004001=
e4gD0005CMD00`00COE=m@07COD00`00COE=m@06COD00`00DOEAm@07DOD00`00DOEAm@06DOD00`00
DOEAm@07DOD00`00DQEB5@07DQD00`00DQEB5@03DQD300000e8E001B5@08DQD00`00DQEB5@04DQD2
00000eHE001F5P08EQH01000ESH000001eHf00@005HfESIF=P8000AF=P04001F=UHfESH20005ESH0
1000EUH000001EYG0P001UYG00H005YgFWMJM`00FWL20003FWP20002GYP20003G[T20002G[T01P00
H]X005kJ001S6P<00003Ig`00000008000AB=`03001F=`00008000AF=`03001F=eHg00IF=`<000QF
E`03001FE`00008000EFE`03001FE`00008000EFE`03001FF000008000EFN0@000EFN08000=JN0<0
00AJV0<000AJV@800003FYT005Zi0080009J^@80009J^P800003G]X00000009Nn`@00003Ga`00000
00@00003Gih0000000D003Uoo`X00=Moo`03001oogoo08Yoo`03001oogoo00aoo`00Egoo00<007oo
Ool0ogoo7Goo1@000SUe00@003fE?IDmU@8000E5]@8000Q9e@03001=e4gD009=e005001=eDgECMD0
0008CM@00`00BKA9]003BK@01000BMA9e00024gD00@004gDCMA=e08000==e@03001=mDge00M=m@03
001=mDge00I=m@03001AmE7e00MAm@03001AmE7e00IAm@03001AmE7e00MAm@03001B5E8E00MB5@04
001B5E8EDQD20004DQD00`00DQEB5@07DQD00`00DQEB5@02DQD20003EQD00`00EQIF5P07EQH20009
ESH01000ESH000001UHf00@005Hf000000MF=P8000IJE`03001JE`0000AJE`8000AJM`8000AJN004
001NV5jHGYP20002G[T20003G[T00`00H]YRfP0200001F<J00000000Ig`010000e8g100025Hg00<0
05HgESL00UHg0`0000=F=`00EUL01eIG0`001eIG0`001eIG0`001eIh0P001UIh0P0000=JN000FWP0
0P001UZH0P000eZI0`000eZI0P000UZi0P000UZj0P0000=NfP0000000Ukk100000=O700000000P00
00=OO@0000001P00<Goo2`00hWoo00<007ooOol0RGoo00<007ooOol037oo001GOol00`00Oomoo`3o
OolMOol50002>GD01000?IDmUCfE0P001TFe00<004WEBMD01TWE00<004gDCM@00dgD00@004gECMD0
00Q=e0030019]4Vd00=9]0040019e4WD0008CM@00`00CMA=e003CM@01000CME=e@002Dge00<004ge
COD01Tge00<0057eDOD01e7e00<0057eDOD01U7e00<0057eDOD01e7e00<0058EDQD01e8E10001U8E
00<0058EDQD01e8E00<0058EDQD00P001EHE00<005HFEQH01UHF0P002UHf0P0025Hf0P0025Hf0P00
1EYG0P000UYG00<005YGFUL00P001EYg0P0015Yh00T005jHGYQNV000GYP005ji00000eji0P0000AR
fP00001RnP<00003Ig`0000000L0009F=P03001F=eHg00MF=`03001F=`00008000AF=`03001FEeIG
00=FE`<00003EUL005IG00EFE`800003EUL005IG00EFE`800003EUL005Ih00AFN0<00003EWP005Ih
009FN0<000=JN08000EJV0<00003FYP005ZI008000=JV@<00005F[T00000001J^P03000015kJ0000
05kj0`0000=Nn`00Ga`0100000=OG@0000001P00:Goo2P00kWoo00<007ooOol0R7oo00<007ooOol0
37oo001GOol00`00Oomoo`3oOolMOol400001Bde000iMCUe00000SfE0P001TFe00<004WEBMD01TWE
00<004gDCM@014gD00<004gE000024gD00<004VdBK@014Vd00<004WD000024gD00<004gDCM@014gD
00<004gE00002Dge00<004geCOD01Tge00<0057eDOD01e7e00<0057eDOD01e7e00<0057eDOD01U7e
00<0058EDQD01E8E0`002E8E00<0058EDQD01e8E0`001eHE00<005HFEQH015HF0P0000=F=P00ESH0
25Hf0P0025Hf0P001eHf0P0000=FEP00FUL00eYG00<005YGFUL00eYG0P001EYg0P0000AJM`00FWQJ
N080009NV080009NV08000=N^@04001RfV;J0002H_X300000fMl000000030007ESH00`00ESMF=`05
ESL40008ESL00`00EUL000020004EUL01000EUMFEeIG0`000eIG00@005IGEUMFE`<000AFE`03001F
N000008000EFN0<000=JN0<00003FWP005ZH009JV08000AJV08000=JV@8000=J^@800003F[X00000
009NfP80009NnP800003G_/0000000@00003Ged0000000H0025oo`X00?Qoo`03001oogoo08Qoo`03
001oogoo00aoo`00Egoo00<007ooOol0ogoo7Woo0`0000D]=@00>GDiM@00008mU@030011U@0000E5
]@8000M9e@03001=e4gD00E=e08000Q=e0030019]4Vd00A9]0030019e00000Q=e003001=e4gD00E=
e08000U=m@03001=mDge00I=m@03001AmE7e00MAm@03001AmE7e00MAm@03001AmE7e00IAm@03001B
5E8E009B5@<0009B5@03001B5E8E00MB5@03001B5E8E00IB5@8000UF5@03001F5UHF009F5P8000=F
=P03001F=UHf00EF=P800003ESH005Hf00EF=P800003ESH005Hf00EF=P05001FEUIFEUH00003FUL0
0`00FUMJE`03FUL20005FWL00`00FWMJM`02FWL20003GYP01`00GYQNV5jH001N^@00009N^@05001R
fP00001RnP0300000fMl000000030009ESH00`00ESMF=`050002ESL00`00ESMF=`05ESL40008EUL3
0007EUL30006EUL30007EWP20003FWP20004FWP40003FYP300000eZI000000020003F[T200000eZi
00000002G]X20002G_X200000ekk0000000200000ell001OG@08000IOol:003oOol4Ool00`00Oomo
o`27Ool00`00Oomoo`0<Ool005Moo`03001oogoo0?mooaioo`<00005;CD003Ue>GD00002?ID00`00
@ID00005AKD00`00AK@00006BMD00`00CMA=e006CM@20007CM@00`00BKA9]005BK@20008CM@00`00
CMA=e006CM@20008COD00`00COE=m@06COD00`00DOEAm@07DOD00`00DOEAm@07DOD00`00DOEAm@06
DOD00`00DQD000020005DQD00`00DQEB5@07DQD00`00DQEB5@04DQD200000eHE001F5@08EQD00`00
EQIF5P020005ESH00`00ESIF=P04ESH01@00ESIF=UHf00001EHf00D005HfESIF=P0000AF=P8000AF
EP04001JE`000005FUL00`00FWL00003FWL20004FWL20003GYP00`00GYQNV0020003G[T40002H_X3
00000fMl0000000200000e8f001F=P07ESH40007ESL00`00ESMF=`02ESL30002ESL00`00EUMFE`05
EUL30007EUL30005EUL300000eIG001FN004EWP300000eYh000000020005FWP20004FYP20003FYT2
0003F[T3000015Zi000005kJ0`0000ENnP00000005kk00@00003Gc`0000000L0015oo`/00?moo`mo
o`03001oogoo08Moo`03001oogoo00]oo`00EWoo00<007ooOol0ogoo7goo100000L]=@00>GDiM@00
?ID00002@ID00`00AKE5]@02AKD00`00AK@00006BMD00`00CMA=e006CM@00`00CM@00006CM@00`00
BKA9]005BK@20008CM@00`00CMA=e006CM@00`00CO@000020005COD00`00COE=m@06COD00`00DOEA
m@07DOD00`00DOEAm@07DOD00`00DOEAm@05DOD30008DQD00`00DQEB5@07DQD00`00DQEB5@02DQD2
0003EQD00`00EQEF5@07EQD30008ESH01000ESIF=UHf0P0015Hf00@005HfESIF=P8000EF=P04001F
=P000006EUH20005FUL20002FWL01000FWL000001EYg00@005jH001NV080009NV003001N^Eji009N
^@<000=RnP800003Ig`00000008000AB=P03001F=UHf009F=P<00003ESH005Hg00QF=`03001F=`00
008000EF=`03001FEeIG009FE`<0009FE`03001FEeIG009FE`<0009FE`04001FEeIGEUL20004EUL0
1000EWQFN5Ih0P000eYh0P001UYh0P0000=JV000FYP00`000eZI0P0000=JV@00F[T00P000UZi0P00
0UkJ0P0000=NnP0000000Ukk100000=O?00000001`002Goo2P00ogoo6goo00<007ooOol0QWoo00<0
07ooOol02goo001FOol00`00Oomoo`3oOolOOol400001bde000iMCUe000mU@000091U@030015]DFe
0095]@040015]4Fd0005BMD00`00CMA=e006CM@01000CMA=e0001DgD00<004VdBK@01TVd00<004gD
CM@01TgD00<004gDCM@01TgD00<004gdCO@00Tgd0P000dge00<004geCOD01Tge00<0057eDOD01e7e
00<0057eDOD01e7e00<0057eDOD00U7e0`0000=Am@00DQD0258E00<0058EDQD01e8E00<0058EDQD0
0P001EHE00<005HEEQD01UHE0P002UHf00@005Hf000000IF=P04001F=P000007ESH20007EUH20005
FUL00`00FWMJM`02FWL20005FWL20002GYP20003GYP00`00G[UN^@02G[T30002H_X300000fMl0000
00020005DSH00`00ESH000020004ESH00`00ESMF=`06ESL30008ESL00`00EUL000020005EUL00`00
EUL000020005EUL40006EUL40003FWP200000eYh001JN002FWP30003FYP20004FYT20003FYT20002
F[T20002G]X200000ekJ00000002G_/400000ell0000000B003oOolUOol00`00Oomoo`26Ool00`00
Oomoo`0;Ool005Ioo`03001oogoo0?moob1oo`<00003;CD003Ue008iM@800091U@030015]DFe0095
]@040015]4Fd0005BMD00`00CMA=e006CM@01000CMA=e4gD0P000dgD00<004VdBK@01TVd00<004gD
CM@01TgD00<004gDCM@01TgD00<004gdCO@014gd100024ge00<0057eDOD01e7e00<0057eDOD01e7e
00<0057e00000P00157e00<0058EDQD01e8E00<0058EDQD01e8E0`001eHE00<005HEEQD01EHE00<0
05HE00002UHf0P0025Hf0P0025Hf0P001eIF00<005YG000015YG00<005YgFWL00UYg0P001EYg00@0
05jHGYQNV080009NV08000=N^@<00003H_X006;j00<00004Ig`000000005DSH40008ESH00`00ESMF
=`02ESL300000eHg001F=`07ESL30007EUL30007EUL20008EUL20004FWP20004FWP30004FYP20000
0eZH001JV@02FYT01000FYUJVEZI0P0000AJ^@000000009NfP800004G]X00000G_/300000elK001O
?00<003oOol`Ool00`00Oomoo`25Ool00`00Oomoo`0;Ool005Ioo`03001oogoo0?moob1oo`@00004
;CD003Ue>GD20003@ID01@00AKE5]DFe00000dFd00<004WEBMD00TWE00<004gDCM@01TgD00<004gD
CM@00dgD00@004gDCM@000Q9]08000M=e003001=e4gD00I=e003001=m4gd00M=m0<000I=m@03001A
mE7e00MAm@03001AmE7e009Am@L000MAm@03001B5E8E00QB5@03001B5E8E00EB5@8000YF5@03001F
5EHE009F5@80009F5@03001F=UHf00MF=P8000QF=P8000QF=P03001FEP0000EFEP80009JE`03001J
EeYG008000AJM`03001JM`0000AJM`09001NV5jHGYP005jH001NV00000AN^@03001Rf@00009RnP<0
0003Ig`0000000800003DSH0000000<0009F=P03001F=UHf00MF=P03001F=`00008000AF=`03001F
=eHg00=F=`<00003EUL005IG00EFE`800003EUL005IG00EFE`800003EUL005IG00EFE`800003EWL0
05Yh009JN003001JN5Yh00=JN08000AJV08000AJV0<0009JV@80009J^@8000=NfP03001NfP000180
0?moocEoo`03001oogoo08Aoo`03001oogoo00]oo`00EWoo00<007ooOol00`00ogoo7Goo100000@]
=@00>GDiM@8000=1U@050015]DFeAKD00004AK@01@00BME9eDWE000024gD00<004gDCM@014gD00<0
04gD000024Vd00<004gD00001TgD00<004gDCM@01TgD00<004gdCO@01dgd00<0057eDOD01@0000==
m@00DOD00e7e2P001E7e00<0057eDOD01U7e00<0058EDQD0258E00<0058EDQD00e8E0P0000=B5@00
EQD02EHE00D005HEEQEF5@0000AF5@03001F=UHf00EF=P800003ESH005Hf00IF=P03001F=P0000IF
=P80009FEP03001FEUIF009FEP03001JEeYG00=JE`8000EJM`04001JMeYg0002FWL20002GYP20002
GYP20004G[T00`00H]T00002H_X300000fMl000000040007ESH00`00ESIF=P05ESH40008ESL00`00
ESL000020004EUL01000EUMFEeIG0`000eIG00@005IGEUMFE`<000=FE`04001FEeIGEUL30004EWL3
0004FWP200000eYh001JV002FYP00`00FYQJV003FYP20002FYT20002F[T=00000elK000000020000
0f=M00000005003oOolhOol00`00Oomoo`23Ool00`00Oomoo`0;Ool005Ioo`<00?moob5oo`<00003
;CD003Ue008iM@030011UD6E0091U@040015]DFe0004AK@01@00BME9eDWE000024gD00<004gDCM@0
1DgD0P0024Vd00@004gDCM@000E=e003001=e4gD00I=e003001=m4gd00M=m003001AmE7e00EAm@H0
00EAm@03001AmE7e00MAm@03001AmE7e00IAm@03001B5E8E00QB5@04001B5E8EDQD20003DQD00`00
EQEF5@08EQD01000EQD000001EHE00<005HfESH015Hf00D005HfESIF=P0000EF=P80009F=P03001F
=UHf00=F=P03001FEUIF009FEP05001FEUIFEUH00005FUL20005FWL00`00FWMJM`02FWL20003GYP0
1`00GYQNV5jH001N^@00009N^@@00005H_X00000001WO0060009ESH00`00ESIF=P02ESH30002ESH0
0`00ESMF=`06ESL30008EUL30007EUL30007EUL30006EWL20004FWP20004FWP30003FYP<0002G[T4
0002G_/200000elK00000002000016=M000005nn1000ogoo>Woo00<007ooOol0Pgoo00<007ooOol0
2goo001FOol00`00Oomoo`3oOolQOol20000123d000]=@000SUe00<0046E@ID00T6E00@004FeAKD0
00E5]0040019eDWE0008CM@00`00CMA=e006CM@00`00BKA9]006BK@01000CMA=e0001DgD00<004gD
CM@01TgD00<004gdCO@01dgd00<0057eDOD01U7e00<0057eDOD01e7e00<0057eDOD01e7e00<0057e
DOD01U7e00<0058EDQD0258E00@0058EDQD000EB5@03001F5EHE00QF5@8000QF5@04001F=UHfESH2
0004ESH00`00ESIF=P02ESH00`00ESIF=P02ESH00`00ESIF=P02ESH00`00EUIFEP03EUH01000EUH0
00001EYG00<005YG00000eYg0P0015Yg0P000ejH00D005jHGYQNV00000=N^@800008H]T006;jH_X0
06Lk001WO0@0009B=P03001F=UHf00MF=P03001F=P00008000EF=P03001F=eHg00=F=`<00003ESL0
05IG00MFE`8000QFE`8000QFE`8000EFM`<00004FWP005YhFWP20003FWP:0002FYT20003F[T01000
G[UN^Eji10000ekk00<005lK00000`0000ASG000001O_P@00?mooceoo`03001oogoo089oo`03001o
ogoo00]oo`00EWoo00<007ooOol0ogoo8Goo100000@]=@00>GDiM@8000=1U@040015]DFe0005AK@0
1000BME9e@0024gD00<004gDCM@01TgD00<004VdBK@01TVd00D004gDCMA=e00000A=e003001=e4gD
00I=e003001=m4gd00M=m003001AmE7e00IAm@03001AmE7e00MAm@03001AmE7e00MAm@03001AmE7e
00MAm@03001B5E8E00MB5@<000IB5@03001F5EHE00MF5@8000UF5@04001F=P000006ESH01@00ESIF
=UHf00001UHf00@005Hf000000IFEP8000IJE`04001JEeYG0002FWL00`00FWMJM`03FWL01000FWP0
05jH0P000ejH00@005jiG[UN^@800004H]T006;jH_X80003DSH00`00ESIF=P06ESH30008ESH01000
ESMF=eHg0P0015Hg00<005IGEUL00eIG0`0000=FE`00EUL015IG0`0000=FE`00EUL015IG0`0000=F
E`00EWL00UIg0P000UYh300000=JV00000000P000eZI0P0000=J^@00F[T00P000Uji100000=NnP00
G_/01P0000ASG000001O_P@00?mood1oo`03001oogoo085oo`03001oogoo00]oo`00EWoo00<007oo
Ool0ogoo8Woo0`0000@]=@00>GDiM@8000A1U@030015]@0000I5]0030019e@0000Q=e003001=e4gD
00I=e08000M9]003001=e4gD009=e005001=e4gDCM@00008CM@00`00COA=m007CO@00`00DOEAm@06
DOD00`00DOEAm@07DOD00`00DOEAm@07DOD00`00DOEAm@07DOD00`00DQEB5@06DQD20008DQD00`00
EQEF5@05EQD200000eHE001F5@08EQD20008ESH01000ESH000001eHf0P001eIF0P001UYG00L005YG
FUMJE`00FWL00004FWL20002FWP20003GYP20003G[T01@00H]T00000H_X00`0000=WO000Ikd00P00
1U8f00<005HfESH00UHf0`0000=F=P00ESH025Hf10001UHg00@005IGEUMFE`8000AFE`04001FEeIG
EUL20004EUL01000EUMFEeIG0P0000=FE`0000002@0000=JN00000001EYh0P000UZH0P0015ZI0P00
0eZi0P000Uji10000ekj100000=S?000He`01`00ogoo@Woo00<007ooOol0PGoo00<007ooOol02goo
001FOol00`00Oomoo`3oOolROol200001B3d000]=@00>GD00P00146E00<004Fe00001dFd0P0024gD
00<004gDCM@01TgD0P001dVd00<004gDCM@00dgD00@004gDCM@000Q=e003001=m4gd00M=m003001A
mE7e00IAm@03001AmE7e00MAm@03001AmE7e00MAm@03001AmE7e00MAm@03001B5E8E00=B5@<00003
DQD0058E00QB5@03001F5EHE00=F5@05001F5EHEEQD00008EQD20009ESH20008ESH20007EUH00`00
FUH00004FUL20004FUL20004FWL01000FWQJN5Yh0P000ejH00@005jiG[UN^@800008H]T00000H_X0
06Lk001WO0@000MB=P03001F=P00008000AF=P03001F=UHf00IF=P8000UF=`@000IFE`@000=FE`X0
009FE`8000IJN0800003FWP005Yh009JN080009JV0800003FYP005ZI009JV@04001J^EZiF[T20000
1Uji00000000G]X000=NnP@00003Hc`0000000L00?moodEoo`03001oogoo081oo`03001oogoo00]o
o`00EWoo00<007ooOol0ogoo8Woo100000H]=@00>GD003ee0004@ID20007AK@20008CM@00`00CMA=
e006CM@00`00BK@00006BK@00`00CMA=e003CM@01000CMA=e0002DgD00<004gdCO@01Tgd00<0057e
DOD01U7e00<0057eDOD01e7e00<0057eDOD01e7e00<0057eDOD01e7e00@0058EDQEB5@8000AB5@03
001B5E8E00MB5@04001F5EHEEQD20004EQD00`00EQEF5@05EQD00`00ESH00008ESH20008ESH00`00
ESH00005EUH20002FUH01@00FUMJEeYG00001EYG0P0015Yg00L005YhFWQJN000GYP00002GYP01@00
G[UN^Eji00000V;I00D006;j000006Lk00H000MB=P<000QF=P03001F=UHf009F=P<00003ESH005Hg
00MF=`8000IFE`X0009FE`8000IFE`800003FWL005Yh009JN0<000AJN0<0009JV08000AJV0<0009J
^@80009N^@800003G]X00000009NnP@00003Ha/0000000L00?moodQoo`03001oogoo07moo`03001o
ogoo00]oo`00EWoo00<007ooOol0ogoo8goo0`0000H]=@00>GD003ee0004@ID20008AK@00`00CMA=
e006CM@00`00CMA=e006CM@00`00BK@00006BK@00`00CMA=e004CM@00`00CM@00009CM@00`00COA=
m006CO@00`00DOEAm@06DOD00`00DOEAm@07DOD00`00DOEAm@07DOD00`00DOEAm@07DOD40006DQD0
0`00DQEB5@07DQD01000EQD000001UHE00<005HEEQD00eHE0P000UHf00<005HfESH01EHf00<005Hf
00001eHf00@005HfESH000AFEP03001JEUYF00=JEP03001JE`0000EJE`03001JM`00009JM`8000=J
N004001NV5jHGYP20003G[T01`00H]T00000H_X006Lk00<00005Ikd00000DQH00004DSH300000eHf
001F=P08ESH00`00ESH000020004ESH00`00ESMF=`04ESL<00000eIG001FE`05EUL200000eIG001F
E`02EUL30004FWL30006FWP20003FYP00`00FYQJV003FYP20002F[T20002G[T200000ekJ00000002
G_X400000f<K0000000200000f=m00000003003oOom:Ool00`00Oomoo`1nOol00`00Oomoo`0;Ool0
05Ioo`03001oogoo0?moob=oo`8000038?@002de00800003?GD0046E00=1U@8000Q5]003001=e4gD
00I=e003001=e4gD00I=e0030019]00000I9]003001=e4gD00E=e08000U=e003001=m4gd00I=m003
001AmE7e00IAm@03001AmE7e00MAm@03001AmE7e00MAm@03001AmE7e00IAm@8000UB5@03001B5E8E
00MB5@8000QF5@03001F5EHE009F5@03001F=UHf009F=P03001F=UHf00AF=P04001F=UHf0006ESH0
1@00ESIF=UHf00000eIF00<005YFFUH015YF0P0015YG0P000eYg0P0015Yh00@005jHGYQNV080009N
^@800006H]T006;jH_X006Lk0`0000=W_@0000000U8F00<0058f00000P0015Hf00<005HfESH01UHf
0`000eHf2`000eHg00@005IGEUMFE`<000=FE`04001FEeIGEUL30004EUL30006FWL20006FWP20000
0eYh001JV0020004FYP2000015ZI000000000Uji0P0000ANfP00001NfP<00003G_/006<K00@00003
Hgd0000000<00?moodaoo`03001oogoo07ioo`03001oogoo00]oo`00EWoo00<007ooOol0ogoo8goo
100000<]=@0000000See00<0046E@ID00T6E00<004FdAK@01TFd0P001dgD00<004gDCM@01TgD00@0
04VdBK@000E9]003001=e4gD00I=e08000Q=e003001=m4gd00I=m003001AmE7e00IAm@03001AmE7e
00MAm@03001AmE7e00MAm@03001AmE7e00=Am@<00003DOD0058E00QB5@03001B5E8E00IB5@8000UF
5@05001F5EHEEQD00005ESH00`00ESIF=P02ESH20003ESH00`00ESIF=P02ESH20004ESH01000EUH0
00001UYF0P0015YG00<005YgFWL00UYg0P0015Yh00T005jHGYQNV000G[P005ji00000V;I00D006;j
H_X006Lk00800003Jkd00000009B5P@000QF=P04001F=UHfESH:0005ESH30007ESL30007EUL30006
EUL20006FWL200000eYg001JN002FWP30003FWP20004FYP20002FYT20003G[T01000G]YNfP000UkJ
0P0000=Nn`000000100000=SO@0000000`00ogooCgoo00<007ooOol0OGoo00<007ooOol02goo001F
Ool00`00Oomoo`3oOolTOol300000bde00000002?GD00`00@IE1U@02@ID00`00AKA5]006AK@00`00
BK@00006CM@00`00CMA=e006CM@01000BKA9]0001DVd00<004gDCM@01TgD00<004gD00001dgD00<0
04gdCO@01Tgd00<0057eDOD01e7e00<0057eDOD01U7e00<0057eDOD01e7e00@0057eDOEAm@8000AA
m@03001B5E8E00MB5@03001B5E8E00AB5@800003EQD005HE00QF5@04001F5@000007ESH01000ESIF
=P001UHf00@005HfESH000IF=P8000MJEP03001JE`0000=JE`03001JMeYg009JM`03001JM`0000=J
N005001NV5jHGYP00002G[P2000016;I000006;j0P0000AW>`00001[_@D0009B5P04001F=UHfESH;
0004ESH00`00ESIF=P06ESH20008ESL20008EUL20006EUL200000eIG001JM`03FWL20004FWL30004
FWP2000015ZH001JV5ZH0P000UZI0P0000=N^@00G[T00P0000ANfP00001NfP800003G_/000000080
0003He`006=m00D00?mooe9oo`03001oogoo07aoo`03001oogoo00]oo`00EGoo00<007ooOol0ogoo
9Goo0P0000@Pm000;CD000<mM@040011UD6E@ID20007AK@00`00BK@00006CM@00`00CMA=e006CM@0
1@00BKA9]4Vd000014Vd00<004gDCM@01TgD00<004gDCM@00P001DgD00<004gdCO@01Tgd00<0057e
DOD01e7e00<0057eDOD01U7e00<0057eDOD01e7e10001U7e00<0058EDQD01e8E00<0058EDQD00e8E
00D005HEEQEF5@0000UF5@8000UF=P03001F=P0000MF=P03001F=P0000IF=P8000IJEP80009JE`04
001JE`000004FWL01000FWMJM`000UYh00D005jHGYQNV000009N^004001Rf@000002H_X00`00Ic/0
000?0005ESH30008ESH00`00ESIF=P02ESH300000eHf001F=`05ESL200000eIG001FE`05EUL20000
0eIG001FE`03EUL20003EUL01@00FWMJMeYg00001EYg0P0015Yh0P000eZH0`000UZI0P000eji0P00
00ANfP00001NfP800003G_/0000000800004He`00000Hgd4003oOomEOol00`00Oomoo`1kOol00`00
Oomoo`0;Ool005Eoo`03001oogoo0?moobEoo`8000048?@002de0003?GD01000@IE1UD6E0P001dFd
00@004VdBK@000E=e003001=e4gD00I=e0050019]4VdBK@00004BK@00`00CMA=e006CM@00`00CMA=
e002CM@00`00CMA=e002CM@00`00COA=m006CO@00`00DOEAm@07DOD00`00DOEAm@06DOD00`00DOEA
m@06DOD20009DOD00`00DQEB5@07DQD01000DQEB5E8E0P0015HE00<005HEEQD01UHE0P002UHf0P00
25Hf0P001UHf00<005YF00001EYF00<005YGFUL00UYG0P001EYg00<005YgFWL00UYg0P000UjH0P00
0Ujh00<006;I00002`001e8F00<005HfESH00eHf0`0000=F=P00ESH025Hf00<005Hf00000P0015Hf
00@005HgESMF=`<000=FE`03001FEeIG009FE`8000=FE`05001FEeIGEUL00006EUL30004FWL20000
15Yh001JN5Yh0P0015ZH0P000eZI00@005jiG[UN^@800003G[T00000009NfP07001Nnekk001S6`00
Hc`00P0000=SO@0000000P00ogooEgoo00<007ooOol0Ngoo00<007ooOol02goo001EOol00`00Oomo
o`3oOolUOol400000bde000mM@02?GD01`00@IE1UD6E0015U00000I5]0050019]4VdBK@00004CM@0
0`00CMA=e006CM@00`00BKA9]002BK@01@00BKA9]4Vd000024gD00<004gDCM@00dgD00D004gDCMA=
e00000Q=m003001AmE7e00MAm@03001AmE7e00IAm@03001AmE7e00=Am@<00003DOD0057e00QAm@03
001B5E8E00MB5@04001B5@000006EQD00`00EQEF5@05EQD00`00EQD00009ESH20008ESH20006ESH0
1000FUIJEP0015YF00<005YGFUL00UYG0P0015Yg0P0015Yg0P0000=NV0000000200000=RnP00Ic/0
0P0000=[_@0000002E8F00@005HfESIF=P8000AF=P03001F=UHf00IF=P<000QF=P<000MFE`04001F
EeIG0006EUL30006EUL20004FWL20003FWP30004FYP200000eZH001JV@020002G[T20002G[T20000
15kJ000005kk100000=S?000Hgd00P0000=OgP00Ool0ogooFGoo00<007ooOol0Ngoo00<007ooOol0
2Woo001EOol00`00Oomoo`3oOolVOol20000123d000000000cee00H0046E@ID004FD0006AK@00`00
BKA9]002BK@01@00CMA=e4gD000024gD00<004VdBK@00TVd00D004VdBKA9]00000Q=e003001=e4gD
00A=e0800003CM@004gd00M=m003001AmE7e00MAm@03001AmE7e00IAm@04001AmE7eDOD20004DOD0
0`00DOEAm@07DOD00`00DQEB5@07DQD20008EQD00`00EQEF5@03EQD20002EQD00`00ESIF=P06ESH0
0`00ESH00007ESH00`00ESH00005ESH00`00FUIJEP02FUH01000FUH0000015YG00<005Yg00000UYg
30000Ujh0P0000ARf@00H_YRnP800003Ic/0000000800003DQH0058F00QB5P@000IF=P03001F=UHf
00=F=P<00003ESH005Hf00MF=P8000UFE`<000IFE`8000IFE`800004FWL005YgFWL20004FWP20004
FYP20003FYP20002G[T20002G[T2000015kJ000005kk0P0000=S6`00Hc`0100000=OgP000000ogoo
G7oo00<007ooOol0NWoo00<007ooOol02Woo001EOol00`00Oomoo`3oOolVOol20000123d00000000
0cee00H0046E@ID004FD0006AK@00`00BKA9]002BK@01@00CMA=e4gD000024gD00<004VdBK@00TVd
00D004VdBKA9]00000Q=e003001=e4gD00I=e08000Q=m003001AmE7e00MAm@03001AmE7e00IAm@@0
00IAm@03001AmE7e00MAm@03001B5E8E00IB5@8000UF5@03001F5EHE009F5@03001F5EHE009F5@03
001F=UHf00AF=P80009F=P03001F=UHf00=F=P80009F=P03001F=UHf009F=P03001JEUYF00=JEP80
0003FUL0000000T000EJM`03001NV5jH0080009N^004001RfF;I0002H_X00`00Ic/000040003DQH0
0`00DQIB5P05DQH20009ESH01000ESIF=UHf0P0015Hf00<005HfESH015Hf0P0000=F=P00EUL01eIG
0P001UIG0P0000=FE`00EUL00eIG0P000eYg0`0015Yh0P0000=JN000FYP00UZH00@005ZHFYQJV080
0004GYT000000002G[T2000015kJ000005kj0P0000AS6`00001S?0H00?mooeioo`03001oogoo07Yo
o`03001oogoo00Yoo`00EGoo00<007ooOol0ogoo9Woo1P000cee00@0046E@ID00095U0030015]4Fd
00=5]0030019]4Vd00=9]004001=e4gD0008CM@00`00BKA9]003BK@01000BKA9]00024gD00<004gD
CM@01dgD0`001Tgd00<0057eDOD01e7e00<0057eDOD0157e0`002E7e00<0057eDOD01e7e00<0058E
DQD0158E0P0000=F5@00EQD025HE00D005HEEQEF5@0000EF5@03001F=UHf00=F=P03001F=UHf009F
=P03001F=UHf009F=P03001F=UHf009F=P04001F=UHfESH:0003FUL00`00FWMJM`02FWL20005FWL0
0`00GYQNV0020002G[P01000H]T000000V;j00<006Lk00001000158F00<0058FDQH00U8F0`0000=F
=P00ESH025Hf10001UHf00<005HfESH00UHf0P000eHf00<005IGEUL00eIG0`0000=FE`00EUL00eIG
0P000eIG00<005IGEUL00P0015Yg0P0015Yh0P0015Yh0`000UZH0P000UjI0P000eji00@005kJG]X0
009NnP800003Ha/006<l00H00?moof5oo`03001oogoo07Uoo`03001oogoo00Yoo`00EGoo00<007oo
Ool0ogoo9goo0P0000@Pm000000000<mM@030011U@000095U0030015]4Fd00=5]0030019]4Vd00A9
]003001=e00000Q=e0030019]4Vd00=9]0040019]4Vd0008CM@00`00CMA=e007CM@00`00DOAAm003
0003CO@00`00DOEAm@07DOD00`00DOD000040002DOD00`00DOEAm@07DOD00`00DOEAm@07DOD00`00
DQEB5@03DQD01@00EQEF5EHE00002EHE00@005HE000000MF5@05001F=UHfESH00005ESH01000ESIF
=UHf2P001EYF00<005YF000015YG00<005YgFWL00UYg0P0015Yg0P000UjH00L005jh001N^000H]T0
0003H_X00`00Ic/000030006DQH00`00DQH000020004ESH00`00ESIF=P06ESH20009ESH00`00ESIF
=P020005ESH01000EUMFEeIG0P0015IG00<005IGEUL00P001EIG0`0015Yg0P0000=JM`00FWP00UYh
00<005YhFWP00eYh0P000UZH0P000ejI00@005ji001N^@800004G]X00000G_X2000016<K000006<l
1@00ogooI7oo00<007ooOol0N7oo00<007ooOol02Woo001EOol5003oOolUOol20000123d00000000
0cee00@0046E@ID00095U0030015]4Fd0095]0030019]4Vd00A9]003001=e00000Q=e0030019]4Vd
00A9]0030019]00000Q=e003001=e4gD00M=e003001Am57d00=Am0@000AAm@L000MAm@03001AmE7e
00MAm@03001AmE7e00MAm@04001B5E8EDQD20004EQD00`00EQEF5@07EQD20009EQD00`00ESH0000;
0007ESH20005FUH01000FUIJEP000eYG00<005YgFWL00UYg00<005Yg00000eYg00D005jHGYQNV000
009N^0800004H]T006;jH_X200000fLk000000020006DQH30007ESH00`00ESIF=P04ESH200000eHf
001F=P08ESH30007ESH40006EUL30006EUL20004FWL20004FWL30004FWP2000015ZH000000000ejI
0P000Uji0P0000ANfP00001NnP80009S6`05001S?000001S_P03003oOomVOol00`00Oomoo`1gOol0
0`00Oomoo`0:Ool005Eoo`03001oogoo0?moobMoo`8000048?@000000004?GD00`00@ID00002AI@0
0`00AKA5]002AK@00`00BKA9]005BK@20008CM@00`00BKA9]004BK@00`00BK@00008CM@00`00CMA=
e007CM@00`00DOAAm006DO@50005DO@00`00DOEAm@06DOD00`00DOEAm@07DOD00`00DOEAm@07DOD0
1000DQD000001UHE00<005HEEQD01UHE0P000eHE2P001eHf0P0025Hf0P001EYF00<005YFFUH00UYF
00<005YG000015Yg00@005YgFWL0009JM`05001NV5jHGYP00002G[P01000H]T000000V;j00<006Lk
00001000158F0`0000=F5P00ESH025Hf00<005HfESH00`000eHf00<005HfESH01UHf0P0025Hf0P00
25IG0P001UIG0P0000=JE`00FWL00UYg00<005YgFWL00eYg0P0015Yh0P000UZH0P0015jI00<005ji
G[T00P0000=Nf@0000000Ukj00<006<KHa/0100000AS_@0000000?moofQoo`03001oogoo07Moo`03
001oogoo00Yoo`00EGoo00<007ooOol0ogoo:7oo0P0000@Pm000<E@000<mM@030011U@0000=5U005
0015]4FdAK@00008BK@00`00CMA=e006CM@00`00BKA9]005BK@20008CM@00`00CMA=e007CM@00`00
DOAAm006DO@00`00DOAAm007DO@00`00DOEAm@06DOD00`00DOEAm@07DOD00`00DOEAm@07DOD20008
EQD01000EQEF5EHE2P001UHE0P0025Hf0P0025Hf00<005YF00000eYF0P001EYF0P0015Yg00<005Yg
FWL00UYg0P000UjH0P000Ujh00@006;IH]T0009RnP03001W>`0000D00004DQH000000004EQH00`00
ESIF=P07ESH30006ESH00`00ESIF=P04ESH200000eHf001F=P05ESH200000eHf001FE`05EUL20000
0eIG001FE`03EUL20004FUL30004FWL2000015Yh001JN5Yh0P000eZH00<005ZH00000UjI0P000Uji
00<005kIG]T00P0000=NnP0000000V<K00<006<l00001000ogooJgoo00<007ooOol0MWoo00<007oo
Ool02Woo001EOol00`00Oomoo`3oOolXOol20000123d000aE0000cee00<0046E00000dFD00D004Fd
AKA5]00000Q9]003001=e4gD00I=e0030019]4Vd00E9]08000Q=e003001=e4gD00M=e003001Am57d
00IAm003001Am57d00MAm003001AmE7e00IAm@03001AmE7e00MAm@03001AmE7e00IAm@80009F5@/0
009F5@80009F5@03001F5EHE00IF5@03001F=@0000MF=P03001F=P0000MF=P04001JEUYF0002FUH0
0`00FUIJEP04FUH20003FWL20004FWL20002GYP01@00G[QN^5jh00000V;I0P0000=RnP00Ic/02000
1eHF00<005HfESH01UHf0P002EHf00<005HfESH00`000eHf00<005HfESH00UHf0P000eHf00<005IG
EUL00UIG0P000eIG00D005IGEUMFE`0000EJE`8000EJM`04001JN5YhFWP30003FYP20003FYP20002
G[T20002G]T01000G_X000000V<K100000AS_@0000000?moofeoo`03001oogoo07Eoo`03001oogoo
00Yoo`00EGoo00<007ooOol0ogoo:7oo0P0000@Pm000<E@000@mM@8000=5U0050015]4FdAK@00008
BK@20007CM@00`00BKA9]005BK@20008CM@00`00CMA=e007CM@00`00DOAAm006DO@00`00DOAAm007
DO@00`00DOEAm@06DOD00`00DOEAm@07DOD00`00DOEAm@0:0007EQD00`00EQEF5@02EQD00`00EQEF
5@02EQD00`00EQEF5@05EQD01000ESEF=@001UHf00@005HfESH000IF=P07001JEUYFFUH005YF0000
1UYF00<005YG00000UYg00<005YgFWL00eYg00D005jH001NV000009N^080009Rf@05001Rn@00001W
>`050002DQH00`00EQIF5P06EQH00`00ESIF=P03ESH300000eHf001F=P08ESH30007ESH01000ESIF
=P001UHf00@005IGEUL000IFE`<000AJE`800003FWL005Yg009JM`8000=JN08000AJV003001JV5ZH
009JV0800003G[T00000009Nf@@00003Ha/006<K00L00?moog1oo`03001oogoo07Aoo`03001oogoo
00Yoo`00EGoo00<007ooOol0ogoo:7oo1@0000<aE000?GD00See0P0014FD00@004FdAK@000Q9]003
0019]00000I=e0030019]4Vd00I9]003001=e4gD00I=e003001=e4gD00M=e003001Am57d00IAm003
001Am57d00MAm003001AmE7e00IAm@03001AmE7e00X000=Am@05001B5E8EDQD00009EQD01@00EQEF
5EHE00001EHE00<005HEEQD015HE00D005HeESEF=@0000EF=P05001F=UHfESH00004ESH20004FUH2
0006FUH01P00FUMJE`00FWL000EJM`03001NV5jH0080009N^008001RfF;IH]T006;i001W>PD000AB
5P03001F5UHF00IF5P04001F=UHfESH20004ESH00`00ESIF=P06ESH20009ESH30007ESH30006EUL2
0005FUL01P00FWMJMeYg001JM`8000AJN003001JN000009JV08000=JV0800003G[T0000000=Nf@03
001NnP0000=S6`P00?moog5oo`03001oogoo07Aoo`03001oogoo00Yoo`00EGoo00<007ooOol0ogoo
:Goo100000<aE000?GD00See0P0014FD00@004FdAK@000Q9]0040019]4Vd0005CM@00`00BKA9]006
BK@00`00CMA=e006CM@00`00CMA=e007CM@00`00DOAAm006DO@00`00DOAAm007DO@<0007DOD01000
DOEAmE7e0P00158E00<005HEEQD01eHE00@005HE000000MF5@04001F5EHEEQD20004ESD01000ESIF
=UHf0P001EHf00@005HfESH000EJEP8000IJEP04001JEeYGFUL20005FWL00`00GYQNV0020002G[P0
2000H]URfF;I001Rn@00IcX50005DQH00`00EQIF5P06EQH40006ESH00`00ESIF=P03ESH300000eHf
001F=P07ESH20008ESH20006EUL200000eIG001JE`02FUL20004FWL20004FWP20003FWP20004FYP0
0`00G[UN^@020002G]T40002Ha/8003oOomdOol00`00Oomoo`1cOol00`00Oomoo`0:Ool005Eoo`03
001oogoo0?moobUoo`@00003<E@003ee00<mM@030015U4FD00=5U0030015]00000Q9]0040019]4Vd
0005CM@00`00BKA9]006BK@20007CM@00`00CMA=e007CM@00`00DOAAm006DO@;0009DOD00`00DOEA
m@06DOD01000DOD000001U8E00<005HEEQD01eHE0P002EHE00@005HEEQD000IF=@04001F=UHf0007
ESH00`00ESH00005FUH00`00FUH00004FUH20003FUL20004FWL20002GYP01@00G[P005jh00000f;I
00@006;i001W>P@000MB5P03001F5UHF00EF5P8000UF=P04001F=UHfESH20004ESH00`00ESIF=P03
ESH300000eHf001F=P05ESH200000eIG001FE`03EUL20003EUL01000FUL000001EYg0P0015Yh00<0
05YhFWP00UYh0P000eZH0P000Uji00@005ji001Nf@<0009S6`800003Hc/0000000@00?moogIoo`03
001oogoo079oo`03001oogoo00Yoo`00E7oo00<007ooOol0ogoo:Woo0`0000@U5000<E@000<mM@03
0015U4FD00=5U0030015]00000Q9]0050019]4VdBK@00004CM@00`00BKA9]006BK@00`00CM@00006
CM@00`00CMA=e007CM@:0009DO@00`00DOEAm@07DOD00`00DOEAm@06DOD20008DQD00`00EQEF5@06
EQD2000:EQD00`00EQD00007ESD00`00ESH00008ESH20005FUH01000FUIJEP000eYF00<005YGFUL0
0UYG00<005ig00000eYg00D005jHGYQNV000009N^08000=Rf@<00003IcX00000008000QB5P03001F
5UHF009F5P<00003EQH005Hf00QF=P@000IF=P04001F=UHfESH20004ESH00`00ESIF=P02ESH20003
EUL00`00EUMFE`020005EUL20005FWL2000015Yg001JN5Yh0P000eYh0P0000=JV000FYP00P000Uji
0P000Uji0`000V<K0P0000AS>`00001W_@<00?moogQoo`03001oogoo079oo`03001oogoo00Yoo`00
E7oo00<007ooOol0ogoo:goo0P0000@U5000<E@000<mM@030015U4FD00A5U08000Q9]0030019]4Vd
0099]005001=e4gDCM@00008BK@01000CMA=e00014gD3000257d00<0057dDO@01e7d00<0057eDOD0
1e7e00<0057eDOD01E7e0P002E8E00<005HEEQD01EHE00<005HE00002UHE0P0025He0P0025Hf0P00
1EYF00<005YFFUH00UYF00<005YF000015YG00@005igGWL0009JM`05001NV5jHGYP00002G[P00`00
H]T00002H]T200000fLj000000030009DQH00`00EQH000020004EQH00`00ESIF=P06ESH20009ESH4
0006ESH00`00ESIF=P020005EUL30006EUL20004FWL20004FWL20004FWP01000FYQJV5ZH0P000eji
00<005jiG[T0100000=S6`0000000V<k1@00ogooNgoo00<007ooOol0LGoo00<007ooOol02Woo001D
Ool00`00Oomoo`3oOol[Ool2000012DD000aE0000cee0P001DFD0P0024Vd00<004VdBK@00dVd00@0
04gDCM@000I9]0X00003CM@004gD00Q=e003001Am57d00IAm003001Am57d00MAm003001AmE7e00MA
m@03001AmE7e00AAm@03001Am@0000YB5@03001F5EHE00=F5@04001F5EHE0009EQD20008ESD20008
ESH00`00FSH00004FUH00`00FUIJEP03FUH20004FUL00`00GWMNM`02GWL20002GYP20002G[P01000
H]URfF;I0`0000=W>P00Jg/01000258F0`001eHF00<005HfESH015Hf0P0000=F=P00ESH01eHf0P00
2EHf0`001UIG0P001UIG0P0000=JE`00FWL00UYg00<005YgFWL00eYg0P000eYh0P000eZH0P000Uji
0P000Uji00@005kJ001RnP80009S>`800003Ikd000000?moogioo`03001oogoo071oo`03001oogoo
00Yoo`00E7oo00<007ooOol0ogoo:goo0P0000DU5000<E@aE000008mM@8000E5U08000Q9]0030019
]4Vd00=9]0X00099]005001=e4gDCM@00004CM@00`00CMA=e007CM@00`00DOAAm006DO@00`00DOAA
m007DO@00`00DOEAm@07DOD00`00DOEAm@02DOD20002DOD00`00DQEB5@08DQD00`00EQEF5@02EQD0
1@00EQEF5EHE000025HE00<005HE00001eHe00<005Hf00001eHf00@005XfFSH000=JEP03001JEUYF
00=JEP8000AJE`03001NMeig009NM`80009NV005001N^5jhG[P00003H]T300000fLj001[N`030002
DQD00`00DQIB5P03DQH200000eHF001F5P08EQH00`00ESIF=P030003ESH00`00ESIF=P04ESH20000
0eHf001F=P07ESH20006EUL200000eIG001FE`03EUL20004FUL30004FWL200000eYh001JN0020004
FYP01@00GYP005ji00000Uji100000MRnP00Hc/006<k001W_@03003oOon0Ool00`00Oomoo`1_Ool0
0`00Oomoo`0:Ool005Aoo`03001oogoo0?moob]oo`<000049A@0035D0002?GD20006AI@00`00BKA9
]002BK@:000014Vd001=e00024Vd00<004gDCM@00TgD00D004gDCMA=e00000U=e003001Am57d00IA
m003001Am57d00MAm003001AmE7e00MAm@05001AmE7eDOD00004DOD00`00DQEB5@08DQD01@00EQEF
5EHE000015HE00<005HEEQD01EHE00@005HEEQD000IF=@04001F=UHf0006ESH01@00FSIJ=UXf0000
0UYF00<005YFFUH00eYF00<005YG00000eYG00<005igGWL00Uig00D005jG001NV00000=N^004001R
fF;IH]T300000fLj001[N`030003DQD00`00DQIB5P030003EQH00`00EQIF5P07EQH30006ESH00`00
ESIF=P02ESH20003ESH00`00ESIF=P04ESH200000eHf001FE`03EUL20003EUL01@00EUMFEeIG0000
1EYG0P001EYg00@005YhFWQJN08000AJV080009NV0800005G[T00000G]X00002H_X00`00Hc]S>`02
00000fNm0000003oOon2Ool00`00Oomoo`1_Ool00`00Oomoo`0:Ool005Aoo`03001oogoo0?moobao
o`8000049A@0035D0002?GD00`00?G@0000:0004BK@00`00BKA9]005BK@20008BK@00`00CMA=e003
CM@01000CMA=e0002DgD00<0057dDO@01U7d00<0057dDO@01e7d00<0057eDOD01e7e00@0057e0000
00EAm@03001B5E8E00QB5@04001F5EHE0005EQD00`00EQEF5@04EQD01@00EQEF5EHE00001EHe00D0
05HfESIF=P0000EF=P03001J=UXf009J=P03001JEP0000EJEP04001JEeYG0002FUL00`00GWMNM`02
GWL00`00GYMNU`020003G[P01000H]URfF;I0P0000AW6P00001[N`<000AB5@<000IF5P03001F5UHF
00IF5P8000UF=P04001F=UHf0005ESH00`00ESIF=P02ESH20003ESH01@00EUMFEeIG00001UIG0`00
15YG0P0000=JM`00FWL00UYg0P000eYh0P0015ZH00<005jHGYP00P0000AN^@00001NfP800004H_X0
0000Hc/2000016Nm00000000ogooQ7oo00<007ooOol0Kgoo00<007ooOol02Goo001DOol00`00Oomo
o`3oOol/Ool;0005AI@20007BK@00`00BKA9]006BK@00`00BKA9]006BK@00`00CMA=e003CM@01000
CMA=e0002DgD00<0057dDO@01U7d00<0057dDO@01e7d00<0057eDOD01e7e0P001e7e00<0058EDQD0
258E00<005HE00001eHE00<005HEEQD00UHE00<005HEEQD00UHE00<005HeESD00UHe00<005HfESH0
0UHf00<005HfESH00UHf00<005XfFSH00eXf0P001EYF00L005YGFUMJE`00FUL00004GWL01@00GYMN
UejG00000ejh00@006;IH]URf@800003IaX006]k00@000=B5@<000QF5P03001F5UHF00AF5P800003
ESH005Hf00QF=P<000MF=P04001F=UHf0006ESH30006EUL20005FUL01P00FWMJMeYg001JM`8000AJ
N003001JV000009JV080009NV003001N^Eji00800005G]X006;jH_X00002Hc/5003oOon7Ool00`00
Oomoo`1^Ool00`00Oomoo`09Ool005Aoo`03001oogoo0?moob9oo`d000089A@0035D000mM@00?G@0
00E5U08000M9]0030019]4Vd00I9]0030019]4Vd00I9]003001=e4gD00A=e003001=e00000U=e003
001Am57d00IAm003001Am57d00MAm003001AmE7e00IAm@8000QAm@03001B5E8E00QB5@8000QF5@05
001F5EHEEQD00005EQD01@00ESEF=EHe00001UHf00@005HfESH000EJ=P8000EJEP03001JEeYG009J
E`8000ANM`04001NUejGGYL20002G[P00`00H]URf@0300000fLJ001[N`040000158E000000000U8E
00<005HFEQH01eHF00@005HFEQIF5P8000=F=P03001F=UHf00IF=P8000UF=P<000IF=P8000IFE`80
0003FUL005YG009JE`8000AJM`8000AJN08000=JV080009NV080009N^@04001Nf@000002H_X00`00
Hc/00004003oOon:Ool00`00Oomoo`1]Ool00`00Oomoo`09Ool005Aoo`03001oogoo0?mooaMoo`/0
00]oo`8000089A@0035D000mM@00?G@000E5U08000M9]0030019]4Vd00I9]08000M9]003001=e4gD
00E=e08000U=e003001Am57d00IAm003001Am57d00MAm003001AmE7e00AAm@800003DOD0057e00MA
m@03001B5E8E00MB5@8000UF5@04001F5EHE0006EQD01000ESEF=@001eHf00<005Hf00001EXf00<0
05YF000015YF00<005YGFUL00UYG0P0015ig00D005jGGYMNU`00009NV080009Rf@06001Rn@00IaX0
06]k1P001E8E00<005HFEQH01eHF00@005HFEQH000EF=P03001F=UHf00AF=P800003ESH005Hf00MF
=P8000IF=P800003EUH005IG00AFE`06001JEeYGFUL005YG0P001EYg0P0015Yh00<005ZHFYP00UZH
0P0000=NV00000000Uji0P0000ENf@00H_X006;j00L00?mooh]oo`03001oogoo06eoo`03001oogoo
00Uoo`00E7oo00<007oo00000P00ogoo2goo2P005Woo0P0000@U5000<E@aE080008mM0030015U4FD
0095U0030015U00000I9]0030019]4Vd00I9]08000M9]003001=e4gD00I=e08000Q=e003001Am57d
00IAm003001Am57d00MAm003001AmE7e009Am@8000=Am@03001AmE7e00MAm@03001B5E8E00EB5@03
001F5@0000UF5@03001F5@0000MF5@03001F=@0000QF=P8000EJ=P04001JEUYF0003FUH00`00FUMJ
E`02FUL00`00GWL00003GWL01@00GYMNUejG00000UjH0P000V;I00H006;i001W6P00Jg/40008DQD0
0`00EQIF5P07EQH30006ESH00`00ESIF=P02ESH20003ESH00`00ESIF=P04ESH200000eHf001F=P04
ESH01@00EUIFEUIF00000eIG0P0015YG0P001UYg00<005Yg00000UYh0P000eZH0P0000=NV0000000
0eji00@005kIG]T0009RnP<00004Ie`00000003oOon>Ool00`00Oomoo`1/Ool00`00Oomoo`09Ool0
05Aoo`800?moo`Aoo`X0021oo`@0008aE080008mM0030015U4FD0095U0030015U00000I9]0030019
]4Vd00I9]08000M9]003001=e4gD00I=e004001=e0000006CM@00`00DOAAm006DO@00`00DOAAm007
DO@00`00DOEAm@020005DOD00`00DOEAm@07DOD00`00DQEB5@04DQD01000EQEF5@002EHE0P0025HE
0P0025Hf0P001EXf00<005YFFUH00UYF00<005YF000015YG00@005igGWL0009NM`05001NUejGGYL0
0002GYP02P00H[P006;I001Rn@00IaX006]k10002E8E00<005HFEQH01UHF0P0025Hf00<005HfESH0
0P001EHf00<005HfESH00UHf0P000eHf00@005HfESIF=P8000AFEP04001FE`000005FUL20005FWL2
0003FWL20004FYP00`00GYQNV0020002G[T2000015kI000006;j100000AWG00000000?mooi1oo`03
001oogoo06]oo`03001oogoo00Uoo`00E7oo00<007ooOol0mgoo2`00:goo0P0000<U5000<E@00P00
0Sed00<004FDAI@00TFD00@004FDAI@000E9]0030019]4Vd00I9]003001=e00000I9]003001=e4gD
00I=e005001=e4gDCM@00005CM@00`00DOAAm006DO@00`00DOAAm007DO@30007DOD00`00DOEAm@07
DOD00`00DQEB5@03DQD01@00EQEF5EHE000025HE0P002EHE00<005HfESH01UHf00<005Xf000015Xf
00<005YFFUH00eYF0P0015YG00<005igGWL00Uig0P000ejG00@005jHGYP000=R^006001Rn@00IaX0
06]k0`0000=B5@00DQD0258E00<005HFEQH00eHF0`0000=F5P00ESH01eHf0`001eHf00<005HfESH0
0P001EHf00@005Hf000000IFEP8000IJE`03001JE`0000AJM`03001JMeYg009JM`8000=JV080009N
V005001N^@00G[T00002G]T01`00H_YRnP00Ha/006ML00@00?mooi5oo`03001oogoo06]oo`03001o
ogoo00Uoo`00E7oo00<007ooOol0kGoo2P00=Woo0P0000DU5000<E@aE00000<mM0050015U4FDAI@0
0002AI@00`00BKA9]003BK@00`00BKA9]006BK@00`00CM@00006BK@00`00CMA=e006CM@00`00CMA=
e002CM@20003CM@00`00DOAAm006DO@00`00DOAAm005DO@30009DOD00`00DOEAm@07DOD01000DQEB
5E8E0P0015HE00<005HEEQD01EHE00<005HE000025HE0P001eHf00@005XfFSH000=J=P03001JEUYF
00AJEP03001JEeYG009JE`03001NMeig009NM`8000=NU`04001NV5jH0003H[P300000fLJ001[N`03
0002DQD00`00DQEB5@07DQD01000EQIF5UHF0P0015HF00<005HfESH01EHf0P002EHf0`001eHf0P00
1eIF0P001EYG0P000UYG00<005YgFWL00P000eYg0P0000=JN000FYP00P000UjH0P000Uji0P000UkI
00<006;j00001`00ogooU7oo00<007ooOol0JWoo00<007ooOol02Goo001DOol00`00Oomoo`3SOol:
0010Ool40002<E@01@00?G@mM3ed00000dFD00@004FDAI@000E9]0030019]4Vd00I9]003001=e000
00I9]003001=e4gD00I=e003001=e4gD00A=e0800003CM@0057d00MAm003001Am57d009Am0<0009A
m003001AmE7e00MAm@03001AmE7e00MAm@04001B5E8E0006EQD00`00EQEF5@04EQD01000EQEF5@00
1eHE00<005He00001UHf00D005XfFSIJ=P00009J=P03001JEUYF00AJEP8000=JE`03001NMeig009N
M`03001NU`00009NU`04001NV5jH0003H[P01P00I_T006LJ001[N`<000=B5@03001B5E8E00MB5@@0
00IF5P03001F=UHf00=F=P800003ESH005Hf00MF=P8000QF=P8000MFEP03001JE`0000AJE`03001J
EeYG00=JE`8000AJM`04001JN5YhFWP20003GYP02000G[UN^Eji001Nf@00G]T300000f<K001WG004
003oOonFOol00`00Oomoo`1YOol00`00Oomoo`09Ool005Aoo`03001oogoo0=Uoo`X004Yoo`<00004
9A@0035D0003?G@01@00AIA5U4FD00000dFD00<004VdBK@00TVd00<004VdBK@01TVd00@004gDCM@0
00E9]003001=e4gD00I=e003001=e4gD00I=e08000QAm003001Am000008000EAm003001AmE7e00MA
m@03001AmE7e00MAm@03001B5@0000MF5@03001F5EHE00=F5@05001F5EHEEQD00006EQD01000ESEF
=@001EHf00<005XfFSH00UXf00<005Xf00001UYF00<005YF00000UYG00<005igGWL00Uig00@005jG
GYMNU`80009NV00:001R^6:hH[P006Ki001W6P00Jg/30005DQD00`00DQEB5@05DQD20009EQH01000
ESIF=UHf0P000eHf00<005HfESH01EHf00<005Hf00001eHf00<005Hf00001EIF0P000UYG00<005YG
FUL00P001EYG0P000eYg0P000eYh0P000UjH0P000eji00<005kIG]T00`0000=S6`0000001000ogoo
VGoo00<007ooOol0J7oo00<007ooOol02Goo001COol00`00Oomoo`3?Ool;001EOol200000bDD000a
E0020002?G@01@00AIA5U4FD00000dFD00<004VdBK@00TVd00<004VdBK@01TVd00@004gDCM@000E9
]003001=e4gD00I=e003001=e4gD00M=e0/000QAm003001AmE7e00MAm@03001AmE7e00MAm@8000QF
5@03001F5EHE009F5@03001F5EHE009F5@03001F5EHE00=F5@05001F=EHeESD00004ESH00`00FSIJ
=P03FSH20006FUH01P00FUIJEP00FUL000ANM`03001NUejG009NU`04001NV5jH0003H[P01P00I_T0
06LJ001[N`<000IB5@03001B5E8E00=B5@800003EQD005HF00QF5P04001F=UHf0005ESH00`00ESIF
=P03ESH20002ESH00`00ESIF=P03ESH20002ESH00`00EUIFEP02EUH00`00FUMJE`03FUL20005FUL2
00000eYg001JM`020004FWP01@00GYP005jH00000eji0P0000=Nf@0000000P0000=S6`0000001000
ogooVWoo00<007ooOol0J7oo00<007ooOol02Goo001COol00`00Oomoo`35Ool:001POol400000c5D
00000003?G@01000AIA5U00014FD00D004VdBKA9]00000Q9]004001=e4gD0005BK@00`00CMA=e006
CM@00`00CMA=e007CM@00`00DOAAm006DO@00`00DOAAm007DO@00`00DOEAm@07DOD00`00DOEAm@06
DOD20009EQD01@00EQEF5EHE00001EHE00<005HEEQD00UHE00<005HeESD00eHe00@005HfESH000IJ
=P03001JEUYF00AJEP04001JEUYFFUH20004GWL00`00GYMNU`02GYL200000ejH001R^002H[P01P00
I_T006LJ001[N`8000QB5@03001B5E8E00<000=F5@03001F5UHF00MF5P<000MF=P05001F=UHfESH0
0004ESH00`00ESIF=P02ESH00`00ESIF=P03ESH01000EUH000001EYG0P001EYG00@005YgFWMJM`80
00AJN080009NV08000=N^@07001NfEkI001RnP00Ha/00`0000=WW@000000ogooWGoo00<007ooOol0
Igoo00<007ooOol02Goo001COol00`00Oomoo`2kOol:001ZOol400000c5D00000003?G@01000AIA5
U00014FD00D004VdBKA9]00000Q9]005001=e4gDCM@00004BK@00`00CMA=e006CM@00`00CMA=e007
CM@00`00DOAAm006DO@00`00DOAAm007DO@00`00DOEAm@07DOD00`00DOEAm@05DOD00`00EQD00009
EQD01000EQEF5@001UHE00D005HEEQEF5@0000IF=@03001F=P0000IJ=P8000EJEP03001JEUYF009J
EP03001NMeig009NM`03001NUejG009NU`04001NV0000003H[P01P00I_T006LJ001[N`8000UB5@<0
00IF5@03001F5UHF00IF5P8000UF=P04001F=P000006ESH01000ESH000001UHf0P001UYG00<005YG
00000eYG0P000eYg0P0015Yh00L005jHGYQNV000G[P00002G[T01`00G]T00000H_X006<K00<00003
Iid000000?mooimoo`03001oogoo06Ioo`03001oogoo00Uoo`00Dgoo00<007ooOol0/7oo2`00MGoo
0P0000@U5000000000<mM0040015U4FD0005AI@01000BKA9]00024Vd00D004gDCMA=e00000A9]003
001=e4gD00I=e003001=e4gD00M=e003001Am57d00IAm003001Am57d00MAm003001AmE7e00MAm@03
001AmE7e00AAm@04001F5EHE0009EQD00`00EQD00007EQD01000EQEF5@001eHe0P001UXf00<005YF
000015YF00<005YFFUH00eYF00D005igGWMNM`0000ANU`04001NV5jH0003H[P01P00I_T006LJ001[
N`800003DQD0058E00IB5@8000QF5@03001F5UHF00AF5P800003EQH005Hf00QF=P8000QF=P8000MF
=P8000IJE`05001JEeYG001JE`020004FWL00`00FWL00002FWP20003GYP01000G[QN^5jh100000=R
nP0000000`0000AWW@0000000?mooj5oo`03001oogoo06Eoo`03001oogoo00Uoo`00Dgoo00<007oo
Ool0YWoo2P00P7oo1@0000<eE000?G@00Sed00<004FD00001DFD00@004VdBK@000Q9]003001=e4gD
009=e0050019]4VdBK@00008CM@00`00CMA=e007CM@00`00DOAAm006DO@00`00DOAAm007DO@00`00
DOEAm@07DOD00`00DOEAm@03DOD01@00EQEF5EHE00002EHE0P0025HE00<005HE000025He00<005Xf
FSH015Xf00@005YFFUH000=JEP03001JEUYF00=JEP80009NM`03001NUejG009NU`03001NV5jH0080
009R^006001Vn@00IaX006]k0P000U8E00<0058EDQD00e8E0P0000=F5@00EQD025HE00@005HFEQIF
5P8000=F5P03001F=UHf00IF=P8000QF=P8000MF=P03001JEP0000AJE`8000=JE`8000EJM`04001J
MeYgFWL20003GYP20003G[P30002H_X01P00Ha/006ML001WW@800?mooj=oo`03001oogoo06Eoo`03
001oogoo00Uoo`00Dgoo00<007ooOol0W7oo2P00RWoo1@0000<eE000?G@00Sed00<004FD00001DFD
00@004VdBK@000Q9]003001=e4gD009=e0050019]4VdBK@00008CM@00`00CMA=e007CM@00`00DOAA
m006DO@00`00DOAAm007DO@00`00DOEAm@07DOD01000DOEAmE7e0P0015HE00<005HEEQD01eHE00<0
05HEEQD01eHE0P0025He0P001EXf00<005YFFUH00UYF00<005YF00001EYF00<005igGWL00P0015jG
00@005jHGYP0009R^0800005I_T006LJ001[N`020003DQD01000DQEB5E8E0P000eHE00<005HEEQD0
1eHE00@005HFEQH000EF5P03001F=UHf00AF=P800003ESH005Hf00IF=P03001F=P0000EF=P80009J
EP05001JEeYGFUL00004FUL20004FWL20003FWL20003GYP00`00G[QN^002G[P30002H_X00`00Ha/0
000200000fNM0000003oOonUOol00`00Oomoo`1TOol00`00Oomoo`09Ool005=oo`03001oogoo095o
o`/009Eoo`8000049A@003ED0003?G@00`00AI@00006AI@00`00BK@00008BK@00`00CMA=e002CM@0
1@00BKA9]4Vd000024gD00<004gDCM@01dgD00<0057dDO@01U7d00<0057dDO@01e7d00<0057eDOD0
1e7e00@0057eDOD000IF5@03001F5EHE00IF5@8000UF5@03001F=EHe00IF=@03001J=P0000AJ=P03
001JEUYF00=JEP8000EJEP05001NMeigGWL00004GYL01000GYQNV0000V:h0P0000EVn@00IaX006]k
008000AB5@04001B5E8E0005EQD00`00EQEF5@07EQD30007EQH01000ESIF=UHf0P000eHf00<005Hf
ESH00eHf0P000UHf00<005HfESH00UHf00<005YFFUH00eYF00<005YG000015YG00<005Yg00000eYg
00<005YgFWL00UYg00<005jH00000UjH00@005jhG[QN^0<00003H_T006;j00@00004Iid00000003o
OonWOol00`00Oomoo`1SOol00`00Oomoo`09Ool005=oo`03001oogoo08Moo`X00:1oo`@00003=E@0
03ed008mM0030015U00000I5U0030019]00000Q9]003001=e4gD00==e0040019]4Vd0008CM@00`00
CMA=e007CM@00`00DOAAm006DO@00`00DOAAm007DO@00`00DOEAm@07DOD00`00DOD00007EQD00`00
EQEF5@05EQD00`00EQD00009EQD00`00ESEF=@05ESD01000FSIJ=P000eXf00<005YFFUH015YF00<0
05YFFUH00eYF00<005igGWL00Uig00D005jGGYMNU`00009NV004001R^6:h0002I_T01000IaX006]k
0P001E8E0`001UHE00<005HEEQD01UHE0P002EHF00@005HfESH000EF=P03001F=UHf009F=P03001F
=UHf00=F=P04001F=P000006FUH20004FUL01000FWMJM`000UYg00<005YgFWL00UYg00@005jHGYQN
V08000=N^003001N^@00009Rn@<00003Ie`006NM00800?moojYoo`03001oogoo06=oo`03001oogoo
00Qoo`00=Goo2P0057oo00<007ooOol0OGoo2P00ZWoo10000SED00@003ed?G@mM08000M5U08000Q9
]003001=e4gD00==e0040019]4Vd0008CM@00`00CMA=e007CM@00`00DOAAm006DO@00`00DOAAm007
DO@00`00DOEAm@07DOD20008EQD00`00EQEF5@04EQD01000EQEF5@0025HE0P001UHe00D005XfFSIJ
=P00009J=P03001JEUYF00EJEP03001JEUYF009JEP03001NMeig009NM`80009NU`04001NV5jH0002
H[P00`00I_UVn@0300000f]k00000005DQD20008EQD00`00EQEF5@04EQD200000eHE001F5P08EQH3
0007ESH01000ESH000001UHf0P001eYF0P000eYG0P0015Yg0P000eYg0P000ejH0P000ejh00<005ji
00000V;i0`0000=WG000Iid00P00ogooZgoo00<007ooOol0Hgoo00<007ooOol027oo000eOol:000D
Ool00`00Oomoo`1bOol;002eOol30002=E@01000?G@mM3ed0P001dFD0P0024Vd00<004gDCM@00dgD
00@004VdBK@000Q=e003001=e4gD00M=e003001Am57d00IAm003001Am57d00MAm003001AmE7e00IA
m@8000UF5@03001F5EHE00=F5@05001F5EHEEQD00007EQD00`00ESD00005ESD00`00FSIJ=P02FSH0
0`00FSH00007FUH20003FUH00`00GWMNM`02GWL00`00GYMNU`020002GYP01000H[QR^0000VKi00@0
06/J001[N`8000=B5@<00003DQD005HE00MF5@03001F5EHE00=F5@05001F5EHEEQD00008EQH20009
ESH20007ESH20007FUH00`00FUL00002FUL00`00FWMJM`03FWL20003FWL00`00GYQNV002GYP01000
GYP005jh0P0000=N^@00H_T00`0000AWF`00001WW@800?moojeoo`03001oogoo069oo`03001oogoo
00Qoo`00>Goo0P0067oo00<007ooOol0J7oo2P00`7oo100000<eE000?G@00Sed0P001dFD0P0024Vd
00<004gDCM@014gD00<004Vd000024gD00<004gDCM@01dgD00<0057dDO@01U7d00<0057dDO@01e7d
00<0057eDOD01E7e00<005Ge00002EHE00<005HEEQD00UHE00<005HEEQD00UHE00<005HEEQD015HE
00@005HeESD000AF=@03001J=UXf00=J=P8000MJEP06001JEUYF001JEP0015ig00D005jGGYMNU`00
009NV004001R^6:h0002I_T00`00JaX000030002DQD20004DQD00`00EQEF5@06EQD01000EQEF5EHE
0P0015HE00<005HFEQH015HF0P0000=F=P00ESH01eHf0P001eHf00<005Hf00001EYF0P000UYG00<0
05YG00001EYg00<005Yg00000UYg00@005jHGYQNV080009NV080009N^@08001Rn@00HaX006MK001[
W0<00?moojmoo`03001oogoo065oo`03001oogoo00Qoo`00>Goo0P0067oo00@007ooOomoo`@005Uo
o`X00<Yoo`@00003=E@003ed00<mM0030015U4FD00I5U0030019]4Vd00I9]003001=e4gD00A=e003
0019]00000Q=e003001=e4gD00M=e003001Am57d00IAm003001Am57d00MAm003001AmE7e00AAm@04
001EmEGe0009EQD01@00EQEF5EHE00001UHE00<005HEEQD00UHE00<005HeESD00UHe00@005HeESD0
00IJ=P03001JEUYF00EJEP04001JEUYFFUH20004GWL01000GYMNUejG0P0000ENV000H[QR^000009V
n@05001[6P00001_f`040006DQD00`00EQEF5@06EQD01000EQD000001UHE00<005HFEQH00eHF00D0
05HfESIF=P0000IF=P800003ESH005Hf00AF=P80009F=P03001JEUYF009JEP03001JEeYG009JE`80
00EJM`04001JMeYgFWL20003GYP01000GYQNV5jH0P000Uji00<006;i00000P0000=WF`00Ji`00P00
ogoo/Goo00<007ooOol0HGoo00<007ooOol027oo000iOol2000HOol4001COol:003EOol30002=E@0
1@00?G@mM3ed000024FD00<004VdBK@01TVd00<004gDCM@014gD00<004Vd000024gD00<004gDCM@0
1dgD00<0057dDO@01U7d00<0057dDO@01e7d00<0057eDOD00e7e00D005GeEOEEm@0000UF5@04001F
5EHE0007EQD01@00EQEF5EHE00001EHe00<005He00001eXf00<005YFFUH015YF00<005YFFUH00UYF
00<005igGWL00Uig00H005jGGYMNU`00HYP20002H[P01@00I_UVn@00JaX00P0000=_f`0000002E8E
00<005HEEQD01UHE0P0025HE00@005HFEQIF5P8000AF=P03001F=UHf00=F=P05001F=UHfESH00004
ESH00`00ESIF=P02ESH01@00FUIJEUYF000015YG0P0015Yg0P000eYg0P000ejH00P005jHGYQNV000
G[T005ji100000=WF`0000000`00ogoo/goo00<007ooOol0H7oo00<007ooOol027oo000iOol2000H
Ool00`00Oomoo`19Ool;003OOol400000cED000mM002?G@00`00AIA5U006AI@20007BK@00`00CMA=
e005CM@20008CM@00`00CMA=e007CM@00`00DOAAm006DO@00`00DOAAm007DO@00`00DOEAm@02DOD0
0`00EOEEm@02EOD00`00EQEF5@07EQD00`00EQD00008EQD01000EQEF5@001UHe0P001eXf0P001EYF
00<005YFFUH00eYF00D005igGWMNM`0000=NU`04001RV6:H0002H[P01@00I_UVn@00JaX00P0000A_
f`00DQD000UB5@03001F5EHE00EF5@8000UF5@04001F5P000006ESH01000ESIF=UHf0P0015Hf00D0
05HfESIF=P0000EF=P04001JEP000004FUL00`00FUL00003FWL00`00FWMJM`02FWL01000GWL005jH
0P000ejH00<005jiG[T00`0000ES6P00Ie/006^L00800?mookIoo`03001oogoo05moo`03001oogoo
00Qoo`00>Goo0P0067oo00<007ooOol0?goo2P00jWoo100000<eE000?G@00Sed00<004FDAI@01TFD
0P001dVd00<004gDCM@01DgD0P0024gD00<004gDCM@01dgD00<0057dDO@01U7d00<0057dDO@01e7d
00D0057eDOEAm@0000EEm@03001F5EHE00MF5@8000UF5@03001F5@0000MF=@03001J=UXf00EJ=P03
001JEP0000AJEP03001JEUYF00=JEP80009NM`05001NUejGGYL00002HYP200001V:h001VnFKi001[
6P800005Km/0058EDQD00009DQD00`00EQEF5@03EQD200000eHE001F5@08EQD20008ESH01000ESH0
00001UHf00@005Hf000000IF=P8000EJE`04001JEeYG0002FWL00`00FWMJM`02FWL00`00GWMNM`02
0003GYP20002G[T300001F<J001WF`00Ji`00P00ogoo^7oo00<007ooOol0GWoo00<007ooOol027oo
000iOol2000GOol00`00Oomoo`0fOol:003eOol30002=E@00`00?G@mM0020007AI@20007BK@00`00
CMA=e005CM@20008CM@00`00CMA=e007CM@00`00DOAAm006DO@00`00DOAAm007DO@01000DOEAm@00
1UGe00<005HEEQD01eHE00<005HEEQD025HE0P0025He00<005XfFSH015Xf00D005YFFUIJEP00009J
EP03001JEUYF00=JEP05001NM`00GWL00003GYL01000HYQRV0000V:h00D006KiI_T006/J00800003
Km/0058E009B5@03001B5E8E00MB5@04001F5EHEEQD20003EQD00`00EQEF5@06EQD20009ESH20008
ESH20007ESH20004FUL20004FUL20004FWL00`00GWMNM`020003GYP00`00G[UN^@03000016LJ0000
06MK1000ogoo^Goo00<007ooOol0GWoo00<007ooOol027oo000iOol2000GOol00`00Oomoo`0[Ool;
003oOol30002=E@00`00?G@mM0020007AI@00`00@G@00006BK@00`00CMA=e006CM@00`00CMA=e006
CM@00`00CMA=e007CM@00`00DOAAm006DO@00`00DOAAm007DO@00`00DOD00007EOD00`00EQEF5@07
EQD00`00EQEF5@08EQD00`00ESEF=@06ESD20005FSH00`00FUIJEP02FUH00`00FUH00005FUH00`00
GWMNM`020003GYL01000HYQRV0000f:h00@006Ki001[6P800003Km/0058E00=B5@03001B5E8E00MB
5@04001F5EHE0005EQD00`00EQEF5@05EQD00`00EQD00008ESH20008ESH20007ESH00`00FUH00003
FUL00`00FUMJE`03FUL20003FWL20002GWL00`00GYP00002GYP02@00G[UN^@00H]T006LJ001WF`04
003oOonlOol00`00Oomoo`1MOol00`00Oomoo`08Ool003Uoo`8001Moo`03001oogoo025oo`X00?mo
o`]oo`@00004=E@003ed?G@20007AI@00`00@G@00006BK@00`00CMA=e006CM@00`00CMA=e006CM@0
0`00CMA=e007CM@00`00DOAAm006DO@00`00DOAAm007DO@20008EOD00`00EQEF5@06EQD2000:EQD0
0`00ESEF=@05ESD00`00FSH00004FSH00`00FUIJEP03FUH20005FUH01@00GWMNMeig00000ejG00@0
06:HHYP000=R^004001Vn@00JaX200000foK001B5@04DQD00`00DQEB5@07DQD30006EQD00`00EQEF
5@04EQD01000EQEF5@001eHf00<005Hf00001eHf00<005Hf00001UHf00@005YFFUH0009JE`03001J
EeYG00=JE`03001JM`00009JM`05001NMeigGWL00003GYP20002G[T01P00H]T006LJ001WF`@00?mo
okioo`03001oogoo05aoo`03001oogoo00Qoo`00>Goo0P005goo00<007ooOol05goo2P00ogoo5Woo
0`0000@eE000?G@mM08000M5U0030011M00000I9]003001=e4gD00I=e08000M=e003001=e4gD00M=
e003001Am57d00IAm003001Am57d00IAm08000UEm@03001F5EHE00EF5@03001F5@0000UF5@8000IF
=@04001J=UXf0004FSH00`00FUIJEP03FUH00`00FUIJEP03FUH01000GWMNMeig0P000UjG00@006:H
HYP000=R^003001VnFKi00<00003Km/0058E00EB5@03001B5E8E00IB5@8000UF5@04001F5EHEEQD2
0003EQD00`00ESIF=P04ESH01000ESIF=P001UHf00@005HfESH000AF=P8000AJEP8000EJE`06001J
MeYg001JM`000eig00@005jHGYQNV0800008G[T00000H]T006LJ001WF`<00?mool5oo`03001oogoo
05]oo`03001oogoo00Qoo`00>Goo0P005goo00<007ooOol037oo2`00ogoo87oo0`000SED00@003ed
000000M5U0040011M45d0005BK@00`00CMA=e006CM@00`00CM@00006CM@00`00CMA=e007CM@00`00
DOAAm006DO@00`00DOAAm005DO@00`00DO@00009EOD00`00EQEF5@04EQD01000EQEF5@0025HE00<0
05He00001EHe00<005XfFSH00UXf00@005XfFSH000IJEP03001JEUYF009JEP05001NMeigGWL00002
GYL20002HYP01@00H[QR^6:h00000VKi0`0000=_f`00DQD01e8E00<0058EDQD0158E00<005HE0000
2EHE00@005HEEQD000EF5@03001F=UHf009F=P8000=F=P03001F=UHf009F=P8000=F=P05001F=UHf
ESH00005FUH20005FUL01000FWMJMeYg0P000eig00H005jHGYQNV000G[P20002H]T01000IaX006MK
0`00ogoo`Woo00<007ooOol0Fgoo00<007ooOol027oo000iOol2000GOol00`00Oomoo`02Ool:003o
Ool[Ool2000022DD000eE000?G@003ed0006AI@01000@GA1M0001DVd00<004gDCM@01TgD00@004gD
CM@000E=e003001=e4gD00M=e003001Am57d00IAm003001Am57d00AAm004001Am57d0009EOD00`00
EQEF5@03EQD01@00EQEF5EHE00001eHE00@005HeESD000AF=@03001J=UXf00=J=P03001J=P0000IJ
EP8000=JEP05001NMeigGWL00003GYL01000HYQRV0000f:h00<006KiI_T00P0000=_N`0000002E8E
00<0058EDQD00U8E0P000UHE00<005HEEQD01eHE00<005HE00001eHE00@005HfESH000IF=P04001F
=UHf0006ESH00`00ESH00005FUH00`00FUL00003FUL20003FWL20003GWL01P00GYQNV5jH001N^080
009Rf@03001W6P0000@00?moolAoo`03001oogoo05Yoo`03001oogoo00Qoo`00>Goo0P005goo1@00
0Woo00<007ooOol0ogoo<Goo0`0000HeE000?G@003ed0006AI@01000@GA1M0001DVd00<004gDCM@0
1TgD00@004gDCM@000E=e003001=e4gD00M=e003001Am57d00IAm003001Am57d00=Am005001Am57d
DO@00009EOD00`00EQEF5@02EQD00`00EQEF5@02EQD00`00EQEF5@04EQD01@00ESEF=EHe000015He
00<005XfFSH00eXf0P001UYF00H005YFFUH005YF0003GWL00`00GYMNU`02GYL00`00HYP00003H[P0
0`00I_UVn@02000016mk000000002E8E00D0058EDQEB5@0000AF5@03001F5EHE00MF5@8000QF5@03
001F=P0000MF=P03001F=P0000MF=P8000EJEP04001JEeYG0002FUL00`00FWMJM`02FWL00`00GWL0
0002GWL03000GYQNV5jH001N^000H]T006;I001W6P800003Ji`000000?moolIoo`03001oogoo05Uo
o`03001oogoo00Qoo`00>Goo0P006Goo0P000goo00<007ooOol0ogoo<Goo0`0000HeE000?G@003ed
0006AI@01@00@GA1M45d000014Vd00<004gDCM@01TgD00D004gDCMA=e00000A=e003001=e4gD00M=
e003001Am57d00IAm004001Am57dDO@20004DO@00`00EOEEm@07EOD01@00EQEF5EHE00001UHE00<0
05HEEQD00UHE00<005HeESD00UHe00D005HeESEF=@0000IJ=P03001JEUYF00AJEP04001JEUYFFUH2
0003GWL00`00GYMNU`02GYL30003H[P00`00I_UVn@0200001Fmk0000057e00002E8E00@0058E0000
00EF5@03001F5EHE00IF5@8000UF5@8000QF=P8000MF=P8000EJEP07001JEeYGFUL005YG000015Yg
00@005igGWMNM`80009NV0800004G[P006;IH]T200001FLJ000006^L0000ogoob7oo00<007ooOol0
FGoo00<007ooOol027oo000eOol300000goo0000000KOol200000goo001oo`3oOolbOol200000bDD
000eE00200000ced0015U005AI@01@00@GA1M45d000014Vd00<004gDCM@01TgD00<004gDCM@00TgD
00D004gDCMA=e00000U=e003001Am57d00IAm004001Am57d0006DO@00`00EOEEm@07EOD01000EQEF
5@001eHE00<005HEEQD00UHE00<005HeESD00UHe00@005HeESD000MJ=P03001JEUYF00=JEP03001J
EUYF009JEP05001NMeigGWL00004GYL00`00HYP00003H[P00`00I_UVn@0200000fmk00000002DOD0
0`00DQEB5@07DQD20007EQD00`00EQEF5@05EQD00`00EQD00008EQD20008ESH20007ESH00`00FUH0
0003FUH20004FUL20003FWL20003GWL20002GYP01000G[QN^0000V;I00<006LJ00000P0000=[W000
Ool0ogoobGoo00<007ooOol0F7oo00<007ooOol027oo000eOol6000MOol2003oOolcOol400000cED
00000002?G@00`00AIA5U003AI@01@00@GA1M45d000014Vd00<004gDCM@01TgD00<004gDCM@00dgD
00@004gDCM@000U=e003001Am57d00IAm003001Am00000MAm003001EmEGe00MEm@03001F5@0000QF
5@05001F5EHEEQD00005ESD00`00ESD00007FSH20004FUH00`00FUIJEP03FUH01000GWMNM`0015jG
00@006:HHYP0009R^003001VnFKi00800003Kg/0000000=Am@03001B5E8E00IB5@8000UF5@03001F
5EHE009F5@80009F5@03001F5EHE00EF5@03001F=P0000MF=P03001F=P0000EF=P80009JEP04001J
EUYF0005FUL20003FWL00`00GWMNM`02GWL01@00GYP005jH00000Ujh00D006;IH]T006LJ00<00003
Ji`007oo0?mool]oo`03001oogoo05Moo`03001oogoo00Qoo`00>7oo0`007goo0P00ogoo<Woo0`00
00<eE00000000Sed00<004FDAI@00dFD00<0045d@G@00T5d00D004VdBKA9]00000Q=e003001=e4gD
00==e004001=e4gD0009CM@00`00DOAAm006DO@20008DO@00`00EOEEm@07EOD20009EQD01000EQEF
5@001UHe0P001eXf00<005YF00000eYF00<005YFFUH00eYF0P0000=NM`00GYL00ejG00D006:HHYP0
06;H0080009Vn@800003Kg/0000000AAm@03001B5E8E00AB5@800003EQD005HE00QF5@05001F5EHE
EQD00004EQD00`00EQEF5@04EQD01000ESIF=P001UHf00@005HfESH000AF=P03001JEUYF009JEP03
001JEP0000EJE`03001JM`00009JM`03001NMeig009NM`03001NV5jH0080009N^005001RfF;I001W
6P0200000f^L0000003oOoo>Ool00`00Oomoo`1GOol00`00Oomoo`07Ool005aoo`800?mooc1oo`<0
0003=E@00000008mM0030015U4FD00=5U0030011M45d0091M0050019]4VdBK@00008CM@00`00CMA=
e004CM@00`00CM@00009CM@00`00DOAAm005DO@20009DO@00`00EOEEm@07EOD00`00EQEF5@08EQD0
0`00EQD00007ESD00`00FSIJ=P05FSH01000FUIJEP000UYF00<005YFFUH00eYF00@005ig000000AN
U`04001RV6:H0002H]P00`00I_UVn@0200000fmk00000005DOD00`00DQEB5@02DQD20003EQD00`00
EQEF5@07EQD01000EQD000001EHE00<005HEEQD00eHE00D005HfESIF=P0000EF=P05001F=UHfESH0
0003ESH00`00FUIJEP03FUH20005FUL01000FWMJMeYg0P0015ig00<005jHGYP00P000Ujh00D006;I
H]T006LJ00800003Ji`007oo0?moolmoo`03001oogoo05Moo`03001oogoo00Moo`00GWoo0P00ogoo
;Woo0P0000@U5000=E@0008mM0030015U4FD00=5U0030011M45d0091M0050019]4VdBK@00008CM@0
0`00CMA=e005CM@20009CM@00`00DOAAm003DO@200000e7d001Am008DO@00`00EOEEm@07EOD00`00
EQEF5@08EQD20008ESD00`00FSIJ=P04FSH01`00FUIJEUYF001JEP0000EJEP04001NMeig0004GYL0
1000HYQRV0000f;H00D006Ki000006mk008000IAm@03001B5E8E008000EF5@03001F5EHE00MF5@80
00MF5@04001F5EHEEQD20004ESH01000ESIF=UHf0P0015Hf00@005Hf000000EJEP8000AJE`8000=J
M`8000=NM`80009NV005001N^000G[P00002H]T400000f^L001oo`3oOooAOol00`00Oomoo`1FOol0
0`00Oomoo`07Ool0061oo`800?moobeoo`<00005=E@003ed?G@00005AI@00`00@GA1M003@G@01000
BKA9]00024gD00<004gDCM@01TgD0`001dgD00@0057dDOAAm08000=Am003001Am57d00MAm003001E
mEGe00IEm@8000YF5@03001F=EHe00IF=@8000EJ=P03001JEUYF009JEP8000EJEP05001NMeigGWL0
0003GYL01000HYQRV0000f;H00D006Ki000006mk008000MAm@<000MF5@03001F5EHE00IF5@8000QF
5@04001F5EHE0006ESH01000ESIF=P001UHf0P001UYF00<005YF00000eYG00<005YgFWL00UYg00<0
05ig00000Uig00D005jHGYQNV000009N^080009Rf@800004Ic/006^L003oOooDOol00`00Oomoo`1E
Ool00`00Oomoo`07Ool0069oo`800?moob]oo`<00003=E@003ed008mM0030015U4FD0095U0030011
M45d00=1M0040019]4Vd0008CM@00`00CMA=e006CM@00`00DOAAm0030004CM@01000DOAAm0001E7d
00<0057dDO@01e7d00<005GeEOD01EGe00<005HE00002UHE00<005HeESD01EHe00<005Xe00001EXf
00<005YFFUH00UYF00<005YFFUH00eYF00@005igGWMNM`80009NU`04001RV6:H0003H]P01@00I_UV
n@00Kg/00`001U7e0P002EHE00<005HEEQD01EHE00<005HE000025HE00<005HE00001eHf00<005Hf
00001UHf0P001UYF00@005YFFUH0009JE`03001JMeYg009JM`06001NMeig001NM`000ejH00L005jh
G[P006;I001Rf@02000016Lk00000000ogooeWoo00<007ooOol0E7oo00<007ooOol01goo001TOol2
003oOolYOol200000bDD00000003?G@01@00AIA5U4FD00001T5d00@004VdBK@000Q=e003001=e4gD
00I=e003001Am57d00=Am0<00004CM@000000006DO@00`00DOAAm007DO@00`00EOEEm@04EOD01000
EQEF5@002EHE0P001UHe00@005XeFSD000AJ=P03001JEUYF00=JEP03001JEUYF009JEP05001NMeig
GWL00002GYL20003HYP01000H]QRf0000VKi1@001E7e0P0000=B5@00EQD025HE00<005HEEQD00eHE
0P000UHE00<005HEEQD01UHE0P0025Hf0P001UHf00<005Xf00001EYF00<005YFFUH00UYF0P0015Yg
00@005igGWMNM`8000=NV004001N^5jh0002H]T3000016Lk00000000ogooegoo00<007ooOol0E7oo
00<007ooOol01goo001VOol20006Ool00`00Oomoo`3oOolNOol2000012DD000000000Sed00D004FD
AIA5U00000M1M0030019]00000Q=e003001=e4gD00I=e003001Am57d00IAm08000QAm003001Am57d
00MAm003001EmEGe00AEm@04001F5EHE0008EQD00`00EQD00006ESD01@00FSEJ=EXe00000UXf00<0
05YFFUH00eYF0P000eYF00D005igGWMNM`0000=NU`05001RV6:HHYP00002H]P00`00I_UVn@020000
16mj000000000e7e0P000e8E00<005HEEQD01eHE00<005HEEQD00UHE00<005HEEQD00UHE00<005HE
EQD01EHE0P0025Hf0P001UHf00@005XfFSH000AJEP03001JEUYF009JEP8000AJM`04001NMeigGWL2
0003GYP01000G[QN^0000V;I0`0000AW>`0000000?moomUoo`03001oogoo05=oo`03001oogoo00Mo
o`00J7oo0P0017oo00<007ooOol0ogoo7goo1@000Sed00D004FDAIA5U00000M1M0030019]00000Q=
e003001=e4gD00I=e003001Am57d00MAm003001Am57d00IAm003001Am57d00MAm003001EmEGe00=E
m@05001F5EHEEQD00007EQD01000EQEF5@001EHe00<005XeFSD00UXe00<005Xf00001EYF00H005YF
FUH005YF0003GWL00`00GYMNU`02GYL01000HYQRV0000V;H00<006KiI_T00P0000E_NP00001Am@00
009Am@03001B5E8E00=B5@03001F5EHE00MF5@05001F5EHEEQD00005EQD00`00EQEF5@04EQD00`00
ESD00007ESH00`00ESH00005ESH01@00FSIJ=UXf00000eYF00<005YFFUH00UYF00<005YG00000eYg
00L005igGWMNM`00GYL00002GYP01000G[QN^0000V;I0P0000=[>`0000000P00ogoofgoo00<007oo
Ool0DWoo00<007ooOol01goo001ZOol20002Ool00`00Oomoo`3oOolOOol50003?G@01000AIA5U000
1d5d00<004Vd000024gD00<004gDCM@01TgD00<0057dDO@01e7d00<0057dDO@01U7d00<0057dDO@0
1e7d00<005GeEOD00UGe00<005HEEQD00UHE00<005HEEQD01EHE00@005HEEQD000AF=@03001J=EXe
00=J=@8000EJEP04001JEUYFFUH20003GWL00`00GYMNU`02GYL01000H[L000000V;H00<006KiI_T0
0P0000=_NP0000000U7e0`001U8E00<005HEEQD01eHE00@005HE000000IF5@03001F5EHE00=F5@04
001F=EHe0006ESH01000ESIF=P0015Hf00<005XfFSH00eXf00<005YF000015YF00@005YGFUL0009J
M`05001NMeigGWL00003GYL20002G[P00`00H]URf@0200000f/k00000002003oOooLOol00`00Oomo
o`1BOol00`00Oomoo`07Ool006aoo`<00?moob5oo`8000039A@0000000<mM0040015U4FD0008@G@2
0008CM@00`00CMA=e006CM@00`00DOAAm007DO@00`00DOAAm006DO@00`00DOAAm007DO@01@00EOEE
mEGe00001EHE00<005HEEQD015HE00D005HEEQEF5@0000=F=@03001J=EXe00AJ=@03001JEUYF00=J
EP03001JEUYF009JEP03001NMeig009NM`05001NUejGGYL00002H[L01000H]QRf0000VKi0P0000=_
NP0000000U7e0P00258E00<005HEEQD01eHE0P0025HE00@005HEEQEF5@8000=F=@03001F=UHf00=F
=P05001F=UHfESH00003ESH00`00FSIJ=P04FSH20004FUH01`00FUMJEeYG001JM`0000=NM`04001N
UejGGYL20002G[P00`00H]T00002000016/k00000000ogooggoo00<007ooOol0DGoo00<007ooOol0
1goo001^Ool2003oOolQOol00`009A@000020002?G@01000AIA5U000245d0P0024gD00<004gDCM@0
1TgD00<0057dDO@01e7d00<0057dDO@01U7d00<0057dDO@01e7d00@005GeEOD000MF5@03001F5EHE
009F5@03001F5EHE009F5@04001F=EHe0007FSD00`00FUIJEP02FUH00`00FUIJEP03FUH01@00GWMN
Meig00000ejG00L006:gH[MR]`00H]P00002I_T2000016mj0000057e0P0000=Am@00DQD01e8E00<0
05HEEQD01UHE0P002EHE00@005HEEQD000EF=@03001F=UHf009F=P03001F=UHf00=F=P03001F=P00
00IJ=P8000AJEP03001JEeYG009JE`8000=NM`0>001NUejGGYL005jh001N^000H]T006Kj001[>`<0
0?moon5oo`03001oogoo051oo`03001oogoo00Moo`00L7oo0P00ogoo7goo1@000Sed00@004FDAI@0
00Q1M08000Q=e003001=e4gD00I=e003001Am57d00MAm003001Am57d00IAm003001Am57d00MAm004
001EmEGe0007EQD00`00EQEF5@02EQD00`00EQEF5@02EQD01000ESEF=@001UXe0P0015YF00<005YF
FUH00UYF0P000Uig00D005jGGYMNU`0000=R]`<0009Vn@800003KgX00000008000=Am@03001B5E8E
00IB5@03001F5EHE00EF5@03001F5@0000UF5@03001F5@0000MF=@04001F=UHf0006ESH20006FSH0
0`00FUH00003FUH00`00FUMJE`02FUL20003GWL01@00GYMNUejG00000Ujh0P0000=Rf@00I_X01@00
ogoohgoo00<007ooOol0Cgoo00<007ooOol01goo001bOol2003oOolMOol200000bDD00000002?G@0
1000AIA5U0002D5d00<004gDCM@01TgD00<004gDCM@01TgD00<0057dDO@01e7d00<0057dDO@01U7d
00<0057dDO@01e7d00<005Ge000025HE00D005HEEQEF5@0000EF5@03001F=@0000IJ=@03001JEP00
00=JEP03001JEUYF009JEP05001NM`00GWL00003GYL01`00H[MR]f:g001Vf000009Vn@800004KgX0
00000005DOD00`00DQEB5@07DQD00`00EQEF5@03EQD01000EQEF5@002EHE0P0025He00<005Hf0000
1UHf0P001UXf00@005YFFUH0009JEP03001JEeYG009JE`03001NM`00009NM`05001NUejGGYL00002
G[P01@00H]T00000I_X00P0000=[W0000000ogooi7oo00<007ooOol0Cgoo00<007ooOol01goo001d
Ool2000>Ool00`00Oomoo`3oOol:Ool200000bDD00000003?G@00`00AI@00009@G@00`00CMA=e006
CM@00`00CMA=e006CM@00`00DOAAm007DO@00`00DOAAm006DO@00`00DOAAm007DO@20009EQD01000
EQEF5@001UHE0P001UXe00@005YFFUH0009JEP03001JEUYF009JEP03001NMeig008000ANU`04001R
]f:g0002I]P01@00I_T00000KgX00`001U7e00<0058EDQD01e8E00<005HEEQD00UHE00D005HEEQEF
5@0000UF5@03001F=EHe00MF=@8000IF=P03001J=P0000EJ=P07001JEUYFFUH005YF000015YG00@0
05igGWMNM`8000=NU`04001N^5jh0002H]T01@00I_X00000Ji`00P00ogooiWoo00<007ooOol0CWoo
00<007ooOol01goo001fOol2000<Ool00`00Oomoo`3oOol;Ool300001c4d000mM3ed0015U00000U1
M003001=e4gD00I=e003001=e4gD00I=e003001Am57d00MAm003001Am57d00IAm003001Am57d00MA
m003001F5EHE00QF5@03001F5@0000MF5@03001J=EXe00EJ=@06001JEUYF001JEP001EYF00@005ig
GWL000ANU`04001R]f:g0002I]P01@00I_T00000KgX00`001e7e00<0058EDQD01e8E00D005HEEQEF
5@0000AF5@03001F5EHE00IF5@8000UF=@03001F=UHf00AF=P04001J=UXf0004FSH00`00FUIJEP02
FUH20004FUL00`00GWMNM`02GWL01@00GYMNUejG00000Ujh00<006;IH]T0100000=[W0000000ogoo
j7oo00<007ooOol0CGoo00<007ooOol01goo001hOol2000:Ool00`00Oomoo`3oOol;Ool300001c4d
000mM3ed0015U00000U1M08000I=e003001=e4gD00M=e003001Am57d00MAm003001Am57d00IAm003
001Am57d00MAm003001F5EHE00QF5@03001F5@0000MF5@03001J=EXe00AJ=@04001JEUYFFUH20005
FUH01@00GWMNMeig00000ejG00@006:gH[L0009Vf005001VnFKi001_NP030008DOD00`00DQEB5@07
DQD01000EQEF5@001EHE00<005HEEQD01EHE00<005HE000025He0P001EHf00D005XfFSIJ=P0000=J
=P03001JEUYF00=JEP03001JEeYG009JE`03001NMeig009NM`80009NU`04001N^5jh0002H]T20000
0f/j001[W002003oOooZOol00`00Oomoo`1<Ool00`00Oomoo`07Ool007Yoo`8000Qoo`03001oogoo
0?moo`]oo`D0008mM0030015U00000U1M08000I=e003001=e4gD00M=e003001Am57d00MAm003001A
m57d00IAm003001Am57d00IAm08000YF5@8000MF5@8000EJ=@03001JEUYF009JEP03001JEUYF00=J
EP04001NMeigGWL20002GYL01`00H[MR]f:g001Vf000009Vn@H000QAm@03001B5E8E00MB5@03001F
5@0000IF5@03001F5EHE00AF5@04001F5EHE0007ESD00`00ESH00004ESH00`00FSIJ=P02FSH01000
FSIJ=P001EYF0P000eYG00<005igGWL00Uig00<005jGGYL00P000Ujh00<006;IH]T00P0000=[>P00
Ki/00P00ogoojgoo00<007ooOol0C7oo00<007ooOol01goo001lOol20006Ool00`00Oomoo`3oOol<
Ool40003?G@20009@G@20006CM@00`00CMA=e007CM@00`00DOAAm007DO@00`00DOAAm006DO@00`00
DOAAm005DO@00`00EQ@0000:EQD00`00EQEF5@05EQD00`00FSD00005FSD00`00FUIJEP02FUH00`00
FUIJEP02FUH01@00GWMNMeig00000V:G0P000f:g00<006KH00000VKi0P0000=_NP0000000P00257e
00<0058EDQD01e8E0P0025HE00<005HEEQD00UHE00D005HEEQEF5@0000IF=@04001F=UHf0003ESH0
0`00FSIJ=P03FSH00`00FSH00005FUH00`00FUH00002FUL00`00GWMNM`02GWL00`00GYMNU`020002
G[P00`00H]URf@0200000f/j001_V`02003oOoo]Ool00`00Oomoo`1;Ool00`00Oomoo`07Ool007io
o`8000=oo`03001oogoo0?moo`eoo`<00004<C@003ed?G@20009@G@00`00DM@00005CM@00`00CMA=
e007CM@00`00DOAAm007DO@00`00DOAAm006DO@00`00DOAAm005DO@00`00EQ@0000:EQD00`00EQEF
5@05EQD00`00FSD00004FSD00`00FUIJEP02FUH20003FUH01@00GWMNMeig00000f:G00L006:gH[MR
]`00I]P00002I_T200001Vmj00000000DOD000QAm@03001B5E8E00IB5@8000UF5@05001F5EHEEQD0
0004EQD00`00ESEF=@03ESD01@00ESIF=UHf00000UHf00<005XfFSH015Xf0P001EYF00@005YFFUIJ
EP8000ANM`08001NUejG001R^000G[P0009Rf@800003JcX006nK00800?moonmoo`03001oogoo04]o
o`03001oogoo00Ioo`00P7oo0P0000=oo`00Ool0ogoo3Woo0`0000@a=000?G@mM08000U1M003001A
e00000E=e003001=e4gD00M=e003001Am57d00MAm003001Am57d00IAm003001Am57d00AAm004001F
55HD0009EQD20006EQD01@00FSEJ=EXe00000UXe00<005YFFUH00UYF00<005if00000eYF00@005ig
GWL000ARU`06001R]f:g001Vf0000VKi0P0000A_NP000000009Am@03001AmE7e00IAm@03001B5E8E
00EB5@03001F5@0000UF5@04001F5EHE0006EQD01@00ESEF=EHe000015Hf00<005Hf00001eXf00<0
05YFFUH00eYF00<005YFFUH00UYF00<005igGWL00Uig00@005jGGYL0009R^080009Rf@800003JcX0
06nK00800?mooo5oo`03001oogoo04Yoo`03001oogoo00Ioo`00PWoo0P00ogoo3goo0P0000<Ld`00
00000Sed0P002D5d00<0057D00001DgD00<004gDCM@01dgD00<0057dDO@01e7d00<0057dDO@01U7d
00<0057dDO@0157d00@005HDEQ@000UF5@8000EF5@03001J=EXe009J=@03001J=@0000AJEP07001N
MUifGWH005YF00000Uig00<006:GHYL00V:G00H006:h000006KH0002I_T2000016mj000000000e7e
00<0057eDOD01U7e00<0058EDQD0158E00@005HEEQD000UF5@03001F5@0000MF5@04001F=EHe0005
ESH20007FSH20004FUH00`00FUIJEP03FUH01@00GWMNMeig00000UjG00D006:hH[QR^000009Rf@80
0003JcX006nK00800?mooo9oo`03001oogoo04Yoo`03001oogoo00Ioo`00Pgoo0`00ogoo3Woo00@0
01cC0000008mM08000U1M004001Ae57D0004CM@00`00CMA=e007CM@00`00DOAAm007DO@00`00DOAA
m006DO@00`00DOAAm003DO@01@00EQAF55HD000025HE00<005Xe00001EHE00<005XeFSD00UXe00<0
05Xe000015YF00@005ifGWINMP8000=NM`05001RUf:GHYL00002H[P00`00I]P00002I_T2000016mj
00000000157e00<0057eDOD01U7e00<0058EDQD00e8E00D005HEEQEF5@0000UF5@8000QF5@03001F
=@0000IF=P03001J=UXf00EJ=P03001JEP0000=JEP03001JEUYF00=JEP80009NM`04001NUejG0003
H[P200001V;I000006/j001_V`800?moooAoo`03001oogoo04Uoo`03001oogoo00Ioo`00QWoo0P00
ogoo37oo0`0000Da=000?G@mM00000U1M004001Ae57D0004CM@00`00CMA=e007CM@00`00DOAAm007
DO@00`00DOAAm006DO@00`00DOAAm002DO@00`00EQAF5002EQ@00`00EQEF5@05EQD01000FSEJ=@00
15HE00<005XeFSD00eXe0P0015YF00<005ifGWH00Uif00D005igGWMNM`0000=RU`04001R^6:hH[P2
0002I_T00`00JcT000030005DOD00`00DOEAm@06DOD01000DQEB5E8E0P0015HE00<005HEEQD01UHE
0P002EHE0P001eHf00<005XfFSH015Xf00L005YFFUIJEP00FUH00005FUH00`00GWMNM`020002GYL0
1P00H[QR^6:h001Rf0<00003JcX006nK00800?moooIoo`03001oogoo04Qoo`03001oogoo00Ioo`00
R7oo0P00ogoo2Woo0`0000Da=000?G@mM00000U1M004001Ae57D0004CM@00`00CMA=e007CM@00`00
DOAAm007DO@00`00DOAAm006DO@00`00DOAAm002DO@00`00EQAF5002EQ@00`00EQEF5@05EQD01000
FSEJ=@000eHE00<005XeFSD015Xe00<005YFFUH00UYF00<005ifGWH00eif00@005igGWL000=RU`04
001R^6:hH[P20002I_T00`00JcT000030006DOD00`00DOEAm@06DOD01000DQEB5@001UHE00<005HE
EQD01EHE00<005HE000025HE0P001eHf0P001EXf00<005YFFUH00UYF0P001EYF00D005igGWMNM`00
009NU`0<001R^6:hH[P006;H001Vn@00JcX006nK0P00ogoomgoo00<007ooOol0B7oo00<007ooOol0
1Woo002:Ool2003oOol8Ool300001C4d000mM3ed00002D5d00D0057DDMAAe00000==e003001=e4gD
00M=e003001Am57d00MAm003001Am57d00IAm005001Am57dDO@00005EQ@00`00EQEF5@04EQD01@00
FSEJ=EXe00000eHE00<005XeFSD015Xe00<005YFFUH00UYF00<005ifGWH00Uif0P0000=NM`00HYL0
0V:G00X006:hH[QR^000I]P006Ki001[>@@000MAm@03001AmE7e00IAm@03001B5@0000MF5@03001F
5EHE00AF5@04001F5EHE0007EQD00`00ESD00006ESH00`00FSH00004FSH00`00FUIJEP03FUH00`00
FUIJEP03FUH01000GWMNMeig0P0000=NU`00H[P00V:h00<006;H00000VKi0P0000=_V`000000ogoo
nGoo00<007ooOol0Agoo00<007ooOol01Woo002<Ool2003oOol7Ool40002?G@00`00@GA1M007@G@0
1@00DMAAe57D00000dgD00<004gDCM@01dgD00<0057dDO@01e7d00<0057dDO@01U7d00@0057dDO@0
00MF5003001F5EHE00=F5@05001J=EXeFSD00002EQD00`00FSEJ=@04FSD20003FUH00`00GWINMP02
GWH01000GWL0000016:G00T006:hH[P006KH001Zn@00JcT01000257e00<0057eDOD01U7e0P0025HE
00<005HEEQD00eHE00D005HEEQEF5@0000IF5@04001F=EHe0005ESH01@00FSIJ=UXf00000UXf00<0
05YFFUH015YF00<005YFFUH00UYF00H005igGWMNM`00GYL20003H[P00`00H]P00002I_T00`00JcX0
0002003oOookOol00`00Oomoo`16Ool00`00Oomoo`06Ool008ioo`8000Qoo`03001oogoo0?Uoo`<0
0004<C@003ed0009@G@01@00DMAAe57D00000dgD00<004gDCM@01dgD00<0057dDO@01U7d00<0057d
DO@01e7d00@0057dDO@000MF5003001F5EHE009F5@03001J=EXe009J=@03001F5@0000IJ=@03001N
EP00009JEP03001NMUif009NMP04001NMeig0004HYL01P00H[QR^000I]P0009Zn@H000QAm@03001A
mE7e00EAm@8000UF5@03001F5EHE009F5@03001F5EHE009F5@03001F5EHE00=F5@05001F=EHeESD0
0004ESH00`00FSIJ=P02FSH00`00FSH00006FUH20003FUH01@00GWMNMeig00000UjG00L006:hH[QR
^000H]P00002I_T01000JcX00000ogoooWoo00<007ooOol0AGoo00<007ooOol01Woo002@Ool20006
Ool00`00Oomoo`3iOol30000134d000mM0002D5d00<0057DDM@00U7D00@004gDCM@000U=e003001A
m57d00IAm003001Am57d00MAm003001Am00000QF5005001F5EHEEQD00005FSD00`00EQD00006FSD0
1@00GUH005YF00001Eif00@005igGWL000=RU`06001R^6:h001Vf0000V[i00<006/i00000P0000=A
m000DOD01e7e00<0057eDOD0157e00<005HE00002EHE00D005HEEQEF5@0000EF5@03001F5EHE009F
5@03001F=EHe009F=@05001F=UHfESH00005FSH20006FUH01P00FUIJEP00FUH000=NM`05001NUejG
GYL00002H[P00`00H]P00002I_T01000JcX00000ogooogoo00<007ooOol0AGoo00<007ooOol01Woo
002BOol20004Ool00`00Oomoo`3jOol20000134d000mM0002D5d00<0057DDM@00U7D00@004gDCM@0
00U=e003001Am57d00IAm003001Am57d00MAm003001Am00000QF5005001F5EHEEQD00005FSD20006
FSD01P00GUINEP00FUH000ANMP03001NMeig0080009RU`04001R^6:hH[P20002J_T00`00JcT00003
00000e7d001Am@07DOD00`00DOEAm@03DOD01000EQEF5@002EHE00@005HEEQD000IF5@05001F5EHE
EQD00005ESD01000ESIF=P001UXf00<005YFFUH015YF00@005YFFUIJEP8000=NM`06001NUejGGYL0
06:h0P0000IRf000I_UVn@00JcX2003oOoooOol2Ool00`00Oomoo`14Ool00`00Oomoo`06Ool009Ao
o`80009oo`03001oogoo0?Yoo`@00003?G@0000000Q1M003001Ae57D009Ae004001=e4gD0009CM@0
0`00DOAAm006DO@00`00DOAAm007DO@20009EQ@01000EQEF5@001UXe00<005XeFSD015Xe00@005iF
GUINEP8000ANMP04001NMeig0002HYL20003H[P20002J_T00`00JcT000030002DO@00`00DOEAm@06
DOD00`00DOEAm@02DOD01@00EQEF5EHE00002EHE00<005HE00001eHE00@005HEEQD000IF=@03001F
=P0000MJ=P03001JEUYF00=JEP03001JEUYF009JEP05001NMeigGWL00003GYL01P00H[QR^000H]P0
009Vn@04001[>P00003oOoooOol4Ool00`00Oomoo`13Ool00`00Oomoo`06Ool009Ioo`<00?aoo`<0
0004<C@000000008@G@00`00DMAAe003DM@00`00CM@00009CM@00`00DOAAm006DO@00`00DOAAm007
DO@00`00EQAF5008EQ@01000EQEF5@001UXe00<005XeFSD015Xe00D005iFGUINEP0000ANMP04001N
Meig0003HYL02P00H[QR^6:h001Vf000J_T006/i10000e7d00<0057eDOD01U7e00D0057eDOEAm@00
00AF5@03001F5EHE00MF5@8000QF5@03001F5@0000MF=@8000MJ=P8000AJEP03001JEUYF009JEP80
009NM`05001NUejGGYL00002H[P30002I_T01000JcX00000ogooogoo1Woo00<007ooOol0@Woo00<0
07ooOol01Woo002HOol2003kOol30000134d00000000245d00<0057DDM@00e7D00<004gD00002DgD
00<0057dDO@01U7d00<0057dDO@01e7d00<005HDEQ@025HD00<005HE00001UXe0P001EXe00<005iF
GUH00UiF00D005ifGWINMP0000=NM`05001RUf:GHYL00002H[P01P00I]P006[i001[>@@000AAm003
001AmE7e00IAm@04001AmE7e0005EQD00`00EQEF5@07EQD00`00EQEF5@07EQD20008ESD00`00FSIJ
=P05FSH00`00FUH00003FUH00`00FUIJEP02FUH01@00GWL005ig00000ejG00H006:hH[P006;H0002
I_T01000JcX00000ogooogoo1goo00<007ooOol0@Woo00<007ooOol01Woo002JOol2003jOol20000
134d000mM000245d00<0057DDM@00e7D00<004gD00002DgD00<0057dDO@01U7d00<0057dDO@01U7d
0P002UHD0P001eXe0P0015Xe00<005iFGUH00UiF0P000eif00@005igGWL000=RU`06001V^000001V
f0000V[i1@001E7d00<0057eDOD01U7e00<0057e00001UHE00<005HEEQD01eHE00<005HEEQD01eHE
00<005HeESD01eHe00<005XfFSH015Xf00L005YFFUIJEP00FUH00004FUH00`00GWMNM`020003GYL0
1000H[QR^0000V;H00@006Ki001[>P800?mooomoo`Uoo`03001oogoo045oo`03001oogoo00Ioo`00
W7oo0P00n7oo100000<mM000@G@01d5d00<0057DDM@0157D0P002DgD00<0057dDO@01U7d00<0057d
DO@01E7d00<005Gd00002UHD0P001UXe00<005YE000015Xe00D005iFGUINEP00009NMP03001NMP00
009NM`05001RUf:GHYL00002I[P00`00I]P00002J_T00`00JcT000020006DO@00`00DOEAm@06DOD2
0007EQD00`00EQEF5@06EQD20009EQD00`00ESEF=@06ESD20005FSH00`00FUIJEP02FUH20004FUH0
1@00GWMNMeig00000ejG00@006:hH[P0009Rf004001Vn@00JcX2003oOoooOol;Ool00`00Oomoo`10
Ool00`00Oomoo`06Ool009ioo`800?Ioo`<00003<C@0000000Q1M003001Ae57D00AAe08000U=e003
001Am57d00IAm003001Am57d00EAm003001Em00000YF5003001J=EXe00EJ=@04001JEEYE0002FSD0
0`00GUINEP02GUH00`00GWINMP020003GWL01000HYMRU`000fJh0P000V[i00<006/i00000`001U7d
00<0057eDOD01E7e0P0025HE00<005HEEQD01EHE00<005HE000025HE0P001eHe00<005Xf000015Xf
00<005YFFUH00eYF00<005YFFUH00UYF00<005igGWL00Uig00@005jGGYL0009R^007001Rf6;H001V
n@00JcX00`00ogooogoo2goo00<007ooOol0@7oo00<007ooOol01Woo002POol2003eOol200000c4d
00000008@G@00`00DMAAe004DM@20009CM@00`00DOAAm006DO@00`00DOAAm004DO@01000EOAEm000
2UHD00<005XeFSD015Xe00L005YEFUEJE@00FSD00004GUH01@00GWINMUif00000eig00D006:GHYMR
U`00009V^080009Zn@03001[>@0000<000MAm003001AmE7e00AAm@03001Am00000UF5@03001F5EHE
00=F5@04001F5EHE0007EQD00`00ESD00006ESD01@00FSIJ=UXf00000UXf00<005YFFUH00eYF0P00
0eYF00<005igGWL00Uig00@005jG0000009R^007001Rf6;H001Vn@00JcX00`00ogooogoo3Goo00<0
07ooOol0?goo00<007ooOol01Woo002ROol2003cOol200000c4d00000007@G@00`00DMAAe006DM@0
0`00CMA=e007CM@00`00DOAAm006DO@00`00DOAAm003DO@01@00EOAEm5Gd00002EHD0P001UXe00L0
05YEFUEJE@00FSD00003GUH00`00GWINMP02GWH01000GWMNM`000f:G00T006JhI[P006Kh001Zn@00
JcT01000257d00<0057eDOD00e7e00@0057dDO@000UF5@03001F5EHE009F5@05001F5EHEEQD00006
EQD01000ESEF=@001EHe00<005XfFSH00UXf00<005Xf00001EYF00<005YF00000UYF00<005igGWL0
0Uig00@005jGGYL0009R^007001Rf6;H001Vn@00JcX00`00ogooogoo3goo00<007ooOol0?goo00<0
07ooOol01Goo002TOol20006Ool00`00Oomoo`3XOol50007@G@00`00DMAAe006DM@20008CM@00`00
DOAAm006DO@00`00DOAAm003DO@01@00EOAEm5Gd00002EHD0P001EXe00<005YEFUD00UYE0P0015iF
00@005ifGWINMP800003GWL006:G009RU`09001V^6Jh001Vn000JaT006/i00@000UAm004001AmE7e
DOD20003DO@00`00EQEF5@07EQD01@00EQEF5EHE000015HE00<005HEEQD015HE00@005HeESD000AF
=@03001J=UXf00=J=P8000EJEP06001JEUYF001JEP0015ig00<005jGGYL00P0000QR^000H]QRf000
I_T006/j0`00ogooogoo4Goo00<007ooOol0?Woo00<007ooOol01Goo002VOol20004Ool00`00Oomo
o`3YOol200000c4d0011M006@G@00`00DMAAe006DM@00`00DM@00007CM@00`00DOAAm006DO@00`00
DOAAm002DO@00`00EOAEm002EO@00`00EQAF5006EQ@00`00FSD00005FSD00`00FUEJE@02FUD00`00
GUINEP02GUH02@00GWINMUif001RU`00GWL00002HYL01000I[QV^6Jh0P000V/I1P002E7d00@0057e
DOD000EAm003001F5EHE00MF5@05001F5EHEEQD00005EQD00`00EQEF5@02EQD00`00ESEF=@02ESD0
1@00ESEF=EHe00001EXf00<005YFFUH00eYF00@005YFFUIJEP8000ANM`05001NUejG001R^0020002
H]P01000I_T006/j0`00ogooogoo4Woo00<007ooOol0?Woo00<007ooOol01Goo002XOol20002Ool0
0`00Oomoo`3YOol200000c4d00000006@G@00`00DMAAe006DM@01000DMAAe0001TgD00<0057dDO@0
1U7d00D0057dDOAAm00000EEm003001F55HD00IF5003001J=@0000AJ=@03001JEEYE00=JE@05001N
EUiFGUH00004GWH01000HYL000000V:G00@006JhI[QV^080009[6@03001_>@0000800003DO@0057d
00QAm003001Am@0000IAm003001F5EHE00MF5@04001F5EHE0006EQD01@00EQEF5EHE00001EHe00@0
05HeESD000IJ=P03001JEUYF009JEP03001JEUYF009JEP03001NMeig009NM`04001NUejG0002H[P0
1`00H]QRf000I_T006/j00<00?mooomooaAoo`03001oogoo03eoo`03001oogoo00Eoo`00ZWoo0`00
jgoo0P0000<a=00000001T5d00<0057DDM@01U7D00D0057DDMAAe00000E=e003001Am57d00IAm005
001Am57dDO@00005EO@00`00EQAF5005EQ@01000FSEJ=@000eXe00<005YEFUD00eYE0P000eiF00D0
05ifGWINMP00009RU`05001RUf:GHYL00002I[P01P00I_P006/I001_>@@00003DO@0057d00QAm080
00MAm003001F5EHE00MF5@03001F5@0000MF5@04001F5EHE0006ESD00`00ESD00006FSH20003FUH0
0`00FUIJEP03FUH01@00GWMNMeig00000UjG00X006:hH[QR^000H]P006Ki001[>P<00?mooomooaIo
o`03001oogoo03aoo`03001oogoo00Eoo`00[7oo0P00jWoo0P0000<a=00000001T5d00<0057DDM@0
1U7D00<0057DDM@00U7D00<004gDCM@00TgD00<0057dDO@01U7d00@0057dDO@000IEm003001F55HD
00EF5004001J=EXe0003FSD00`00FUEJE@03FUD20002GUH01@00GWINMUif00000f:G00@006:GHYL0
009V^006001Vn000JaT006li10000U7d00<0057dDO@01U7d0P00257d00<005HEEQD01eHE0P0025HE
00@005HEEQD000IF=@8000IJ=P03001JEP00009JEP03001JEUYF00=JEP80009NM`04001NUejG0003
H[P01P00H]P006Ki001[>P<00?mooomooaQoo`03001oogoo03]oo`03001oogoo00Eoo`00[Woo0P00
jGoo10001T5d00<0057DDM@01U7D00<0057DDM@00e7D00D004gDCMA=e00000QAm003001Am00000ME
m003001F55HD00EF5004001J=EXe0002FSD00`00FUEJE@03FUD01@00GWH005iF000015if00D006:G
HYL006:g0080009V^006001Vn000JaT006li10000e7d00<0057dDO@0157d0P0000=Am000DO@01e7d
00<005HEEQD01eHE00<005HEEQD01eHE00<005HE00001eHe00<005XfFSH015Xf00H005YFFUH005YF
0005FUH00`00GWMNM`020002GYL01@00H[QR^6:h00000V;H0P0000A[>P0000000?mooomooaUoo`03
001oogoo03]oo`03001oogoo00Eoo`00/7oo00<007ooOol0iWoo10001T5d00<0057DDM@01U7D00<0
057DDM@0157D00@004gDCM@000QAm003001Am00000MEm003001F55HD00AF5005001J=EXeFSD00002
FSD00`00FUEJE@02FUD01P00GWINMP00GUH000=NMP04001RUf:G0002H[L01000I[QV^6Jh0P0000A[
6@00KcU_>@<000AAm003001Am57d009Am08000=Am003001Am57d00IAm003001F5EHE00MF5@03001F
5EHE00MF5@8000QF=@03001J=UXf00=J=P04001JEUYFFUH20005FUH01@00GWMNMeig00000UjG00D0
06:hH[QR^000009Rf003001Vn@0000<00?mooomooa]oo`03001oogoo03Yoo`03001oogoo00Eoo`00
KWoo1`002Woo10003Woo100077oo0P00iWoo10001T5d00<0057DDM@01U7D00<0057DDM@01E7D00<0
04gD0000257d0P0025Gd00<005HDEQ@015HD00L005XeFSEJ=@00FSD00005FUD00`00GWINMP020003
GWH01000HYMRU`000f:g00<006JhI[P00P000V/I00@006li001c^P<000=Am003001Am57d008000EA
m003001Am57d00IAm003001F5EHE00IF5@8000UF5@03001F=EHe00IF=@8000AJ=P03001JEUYF009J
EP03001JEUYF00=JEP03001NMeig009NM`03001NU`0000=R^005001Rf6;H001Vn@04003oOoooOolM
Ool00`00Oomoo`0iOol00`00Oomoo`05Ool006ioo`L000Qoo`P000Yoo`P001aoo`800>Eoo`<000I1
M003001Ae57D00IAe003001Ae57D00IAe08000AAm0D000UEm003001F55HD00=F5003001J=EXe009J
=@03001J=@0000AJE@05001NMUifGWH00004GWH01000HYMRU`000V:g00`006KH000006Kh001[6@00
KcT007>j0003DO@60007DO@00`00DOAAm006DO@00`00EQEF5@05EQD00`00EQD00009EQD00`00ESEF
=@05ESD00`00FSD00004FSH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00GWMNM`02GWL30003H[P0
1`00H]QRf000I_T006/j00<00?mooomooaeoo`03001oogoo03Uoo`03001oogoo00Eoo`00LGoo0P00
2Woo0P0017oo0P002Woo0P0017oo0P007Woo0P0027oo00<007ooOol0f7oo0`001T5d00<0057DDM@0
1U7D00<0057DDM@01e7D1@00157D00<005GdEO@01eGd00<005HDEQ@00eHD00<005XeFSD00UXe0P00
1EYE00D005ifGWINMP0000=NMP04001RUf:G0002H[L02@00I]QVf000I_P006/I001_>@040006DO@0
0`00DOAAm007DO@00`00DOAAm006DO@00`00EQEF5@04EQD01000EQEF5@0025HE0P001UHe00@005Xe
FSD000=J=P03001JEUYF009JEP8000=JEP03001NMeig009NM`03001NU`0000=R^007001Rf6;H001V
n@00JcX00`00ogooogoo7goo00<007ooOol0>7oo00<007ooOol01Goo001aOol20009Ool20006Ool2
0008Ool20006Ool2000OOol20006Ool00`00Oomoo`3HOol30006@G@00`00DMAAe006DM@00`00DMAA
e007DM@00`00DMAAe006DM@00`00EOAEm007EO@00`00EQAF5002EQ@00`00FSEJ=@03FSD20004FUD0
1000GWINMUif0P000Uif00@006:GHYL0009R]`04001Vf6KHI]P200000f/I001_>@040007DO@00`00
DOAAm007DO@00`00DOAAm006DO@00`00EQEF5@03EQD01@00EQEF5EHE00001eHE00<005He00001EHe
00D005XeFSEJ=@00009J=P03001JEUYF009JEP06001NEUiF001JEP0015ig00@005jGGYL0009R^007
001Rf6;H001Vn@00JcX00`00ogooogoo8Goo00<007ooOol0=goo00<007ooOol01Goo001aOol20009
Ool20006Ool20008Ool20006Ool2000QOol20004Ool00`00Oomoo`3HOol30006@G@00`00DMAAe006
DM@00`00DMAAe007DM@00`00DMAAe006DM@00`00EOAEm007EO@00`00EQAF5002EQ@00`00FSEJ=@03
FSD00`00FUEJE@03FUD02@00GWINMUif001RU`00GWH00002HYL01000H[MR]`000VKH0P0000A[6@00
KcU_>@<000QAm003001Am57d00MAm003001Am57d00IAm003001F5EHE009F5@03001F5EHE009F5@03
001F5EHE00AF5@04001F=EHe0004ESD00`00FSEJ=@02FSD00`00FSH00004FUH01000GUINEUiF0P00
15ig00D005jGGYL006:h0080009Rf004001Vn@00JcX3003oOoooOolSOol00`00Oomoo`0fOol00`00
Oomoo`05Ool006Uoo``000Ioo`8000Qoo`8000Ioo`8000Qoo`80029oo`80009oo`03001oogoo0=Uo
o`<000E1M003001Ae57D00IAe003001Ae57D00MAe003001Ae57D00IAe003001Em5Gd00MEm005001F
55HDEQ@00006FSD00`00FUEJE@02FUD01@00GWINMUif00000V:G0P000V:G00@006:gH[L0009Vf004
001Zn0000002KcT01000LkX00000257d00<0057dDO@01e7d00<0057dDO@01U7d00<005HEEQD00UHE
00<005HEEQD00UHE00<005HEEQD015HE00@005HeESD000AF=@03001J=EXe009J=@8000EJEP05001N
EUiFGUH00004GWL01000GYMNU`000V:h00L006;HH]P006Ki001[>P03003oOoooOolTOol00`00Oomo
o`0fOol00`00Oomoo`05Ool006Uoo``000Ioo`8000Qoo`8000Ioo`8000Qoo`8002Aoo`<00=]oo`<0
00E1M003001Ae57D00IAe003001Ae57D00MAe003001Ae57D00IAe003001Em5Gd00MEm005001F55HD
EQ@00005FSD20004FUD01000GWINMP000f:G00@006:GHYL0009R]`0;001Vf6KH001Zn000JcT006li
001c^P030008DO@00`00DOAAm007DO@00`00DOAAm006DO@01@00EQEF5EHE00001EHE00<005HEEQD0
0eHE00D005HeESEF=@0000=F=@03001J=EXe00=J=@03001JEUYF00=JEP03001NEUiF009NEP05001N
MeigGWL00002GYL02P00H[QR^6:h001Rf000I_T006/j0`00ogooogoo9Woo00<007ooOol0=Goo00<0
07ooOol01Goo001YOol20006Ool200000goo001oo`05Ool20008Ool20006Ool20008Ool2000VOol2
003JOol30005@G@00`00DMAAe006DM@00`00DMAAe007DM@00`00DMAAe006DM@00`00EOAEm007EO@0
1000EQAF50001UXe0P000eYE00D005ifGWINMP0000=RU`03001RU`0000=R]`03001Vf6KH00800005
JcT006mI001c^P0200000dgD001Am007DO@00`00DOAAm007DO@00`00DOAAm006DO@01000EQEF5@00
1UHE00<005HEEQD00UHE00<005HeESD00UHe00@005HeESD000IJ=@03001JEUYF009JEP03001NEUiF
009NEP80009NM`04001NUejG0003H[P02@00I]P006Ki001[>P00Lo/0003oOoooOolXOol00`00Oomo
o`0dOol00`00Oomoo`05Ool006Yoo`8000Eoo`8000Qoo`8000Qoo`8000Ioo`8000Qoo`8002Qoo`80
0=Uoo`8000E1M003001Ae57D00IAe003001Ae57D00MAe003001Ae57D00IAe003001Em5Gd00MEm004
001F55HD0005FSD00`00GWH00002FUD01@00GWINMUif00000f:G0P0000ERU`00H[MR]`00009Vf080
0004JcT006mIKeT400000dgD001Am007DO@00`00DOAAm007DO@00`00DOAAm006DO@00`00EQD00007
EQD01@00EQEF5EHE00001EHe00<005He00001UXe0P000eYF00<005iFGUH00UiF00D005ig001NM`00
009NU`05001R^6:hH[P00002I]P2000016/j001cn`00ogooogoo:Woo00<007ooOol0<goo00<007oo
Ool01Goo001ZOol30004Ool20008Ool20008Ool20006Ool20008Ool2000ZOol2003GOol20005@G@0
0`00DMAAe006DM@00`00DMAAe007DM@00`00DMAAe006DM@00`00EOAEm007EO@01000EQAF50001EXe
00H005ifGWH005YE0003GWH01@00HYMRU`00I[L00P000V:g00D006KHI]P006[h0080009_F@04001c
^P000002CM@00`00DOAAm006DO@00`00DOAAm007DO@00`00DOAAm006DO@20008EQD01000EQEF5@00
1UHe0P001UXe00<005YF00000eYF00D005iFGUINEP00009NM`8000=NU`04001R^6:h0002I]P20000
16/j001cn`00ogooogoo:goo00<007ooOol0<goo00<007ooOol01Goo001[Ool20004Ool20008Ool2
0008Ool20006Ool20008Ool2000/Ool2003EOol20005@G@00`00DMAAe006DM@00`00DMAAe007DM@0
0`00DMAAe006DM@00`00EOAEm007EO@00`00EQ@00006FSD00`00GWINMP020003GWH01`00HYMRUf:G
001V]`00009R]`0;001Vf6KH001Zn000JcT006mI001c^P020003CM@00`00DOAAm006DO@00`00DOAA
m007DO@00`00DOAAm006DO@00`00EQEF5@07EQD01000EQEF5@001UHe00<005XeFSD015Xe00L005YF
FUIJEP00FUH00003GUH01@00GWMNMeig00000ejG00@006:hH[P0009Vf006001Vn@00001cn`00ogoo
ogoo;Goo00<007ooOol0<goo00<007ooOol017oo001/Ool20003Ool20008Ool20008Ool20006Ool2
0008Ool2000^Ool2003COol20005@G@00`00DMAAe006DM@00`00DMAAe007DM@00`00DMAAe006DM@0
0`00EOAEm007EO@00`00EQ@00005FSD01000GWINMUif0P000Uif00D006:GHYMRU`00009V]`0;001R
]f:g001Vf000J_P006/i001_F@040004CM@00`00DOAAm006DO@00`00DOAAm007DO@00`00DOAAm006
DO@00`00EQEF5@07EQD00`00EQD00007ESD00`00FSEJ=@04FSD01000FUIJEUYF0P000eiF00<005ig
GWL00Uig00@005jGGYL0009R^007001Vf6KH001Vn@00JcX00`00ogooogoo;Woo00<007ooOol0<Woo
00<007ooOol017oo001/Ool30002Ool20008Ool20008Ool20006Ool20008Ool2000`Ool20007Ool0
0`00Oomoo`37Ool20005@G@00`00DMAAe006DM@00`00DMAAe007DM@00`00DMAAe006DM@00`00EOAE
m007EO@20006FSD01@00GWINMUif00000eif00P006:GHYMRU`00I[L006KH0P000VKH0P0000=[>@00
KeT01@0014gD00<0057dDO@01U7d00<0057dDO@01e7d00<0057dDO@01E7d0P002EHE0P001eHe0P00
1EXe00<005YFFUH00UYF00<005iFGUH00UiF00H005igGWMNM`00HYL20002H[P02P00I]QVf000I_T0
06/j001cfP00ogooogoo;goo00<007ooOol0<Woo00<007ooOol017oo001]Ool20002Ool20009Ool2
0006Ool20008Ool20006Ool2000cOol20005Ool00`00Oomoo`37Ool20005@G@00`00DMAAe006DM@0
0`00DMAAe007DM@00`00DMAAe006DM@00`00EOAEm007EO@20005FSD00`00GWINMP02GWH01000GWIN
MP000f:G00<006Jg00000VKH00<006KHI]P00P0000=[>@00KeT01@001DgD00<0057dDO@01U7d00<0
057dDO@01e7d00<0057dDO@0157d00<005HE00002EHE00<005HeESD01EHe00<005Xe000015Xe00<0
05YFFUH00eYF00D005iFGUINEP0000=NM`04001RUf:G0002H[P02P00I]QVf000I_T006/j001cfP00
ogooogoo<Goo00<007ooOol0<Goo00<007ooOol017oo001^Ool200000goo00000009Ool20006Ool2
0008Ool20006Ool2000eOol20003Ool00`00Oomoo`38Ool00`00@GA1M003@G@00`00DMAAe006DM@0
0`00DMAAe007DM@00`00DMAAe006DM@00`00EOAEm007EO@00`00FSEJ=@04FSD01000GWINMUif0P00
0Uif00@006:GHYL0009V]`07001Vf6KH001Vf000J_P00P000VmI10001TgD00<0057dDO@01U7d00<0
057dDO@01e7d00<0057dDO@0157d00<005HE00002EHE00<005HeESD01EHe00<005Xe00000eXe00<0
05YFFUH00eYF0P000UiF00D005igGWMNM`0000=RU`03001R^000009Vf007001Vn@00JcX007?J0000
ogooogoo<goo00<007ooOol0<7oo00<007ooOol017oo001_Ool4000:Ool20004Ool2000:Ool20004
Ool2000hOol200000goo001oo`39Ool20004@G@00`00DMAAe006DM@00`00DMAAe007DM@00`00DMAA
e006DM@00`00EOAEm007EO@00`00FSEJ=@03FSD00`00GWINMP02GWH200000eif001RU`02HYL00`00
I[L00002I]P02000J_P006[h001[>@00KeT40007CM@00`00DOAAm006DO@00`00DOAAm007DO@00`00
DOAAm003DO@01000EQEF5@0025HE0P001UHe00D005XeFSEJ=@00009J=@03001JEUYF009JEP05001N
MP00GUH00003GWL01000HYMRUf:G0`000VKH00L006Ki001[>P00LmX0003oOoooOoleOol00`00Oomo
o`0_Ool00`00Oomoo`04Ool006moo`@000Yoo`P000Yoo`P003Yoo`800<Yoo`8000A1M003001Ae57D
00IAe003001Ae57D00MAe003001Ae57D00IAe003001Em5Gd00MEm003001J=EXe00=J=@06001NMUif
GWH006Jg0P000f:G00<006Jg00000VKH00<006[hJ_P00P0000=[>@00KeT0100024gD00<0057dDO@0
1U7d00<0057dDO@01e7d00<0057dDO@00U7d00D005HEEQEF5@0000QF5@8000EF=@03001J=EXe009J
=@03001J=@0000AJEP03001NMUif008000=NM`07001RUf:GHYL006:h00000VKH00<006KiI_T00P00
00=cfP00Ool0ogooogoo=Goo00<007ooOol0;goo00<007ooOol017oo001`Ool3000<Ool4000>Ool4
000nOol20038Ool20004@G@00`00DMAAe006DM@00`00DMAAe007DM@00`00DMAAe006DM@00`00EOAE
m006EO@20005FSD01P00GWINMUif001V]`80009RU`06001V]fJg001Vf0000V[h0P0000=[>@00KeT0
1@0024gD00<0057dDO@01U7d00<0057dDO@01e7d00<0057dDO@00U7d00D005HEEQEF5@0000MF5@03
001J=@0000EF=@03001J=EXe009J=@8000EJEP04001NMUif0004GWL01000HYMRU`000V:h00<006KH
00000VKi1000ogooogoo>7oo00<007ooOol0;Woo00<007ooOol017oo003EOol2000>Ool00`00Oomo
o`2eOol20004@G@00`00DMAAe006DM@00`00DMAAe007DM@00`00DMAAe006DM@00`00EOAEm006EO@2
0004FSD01@00GWINMUif00000VJg00L006:GHYMRU`00I[L00002I]P01000J_P006li0P0000=_F@00
LiX0100024gD00<0057dDO@01U7d00<0057dDO@01e7d00D0057dDOAAm00000AF5@03001F5EHE00AF
5@04001J=EXe0004ESD00`00FSEJ=@03FSD00`00FUIJEP03FUH01@00GWINMUif00000eig00@006:G
HYL0009R^003001Vf000009Vn@@00?mooomoocYoo`03001oogoo02eoo`03001oogoo00Aoo`00egoo
0P0037oo00<007ooOol0]Goo0P00145d00<0057DDM@01U7D00<0057DDM@01e7D00<0057DDM@01U7D
00<005GdEO@01UGd0P0015Xe00D005ifGWINMP00009V]`06001RUf:G001V]`000VKH00H006[h001_
>@00KeT200001W>J00000000CM@000Q=e003001Am57d00IAm003001Am57d00MAm005001Am57dDO@0
0004EQD00`00EQEF5@04EQD01@00FSEJ=EXe00000eHe00<005XeFSD00eXe00<005YFFUH00UYF00@0
05ifGWINMP80009NM`04001RUf:G0002H[P01@00I]QVf000I_T01000ogooogoo?7oo00<007ooOol0
;7oo00<007ooOol017oo003IOol2000:Ool00`00Oomoo`2eOol20004@G@00`00DMAAe006DM@00`00
DMAAe007DM@00`00DMAAe006DM@00`00EOAEm006EO@20003FSD01@00GWINMUif00000VJg0P000V:G
00D006Jg001Vf000009Zn0800003KeT007=i00@0009=e003001=e4gD00I=e003001Am57d00IAm003
001Am57d00MAm004001Am57d0006EQD00`00EQEF5@02EQD00`00FSEJ=@02FSD01000ESEF=@001EXe
0P000eYF00D005ifGWINMP00009NM`8000=RU`03001R^000009Vf003001[6@0000<00?mooomooceo
o`03001oogoo02aoo`03001oogoo00Aoo`00fgoo0P0027oo00<007ooOol0]Woo00<0045d@G@00T5d
00<0057DDM@01U7D00<0057DDM@01e7D00<0057DDM@01U7D00<005GdEO@01EGd00@007]fNgH0009J
=@05001NMUifGWH00002I[L01P00J]L00000I[L0009Vf009001Zn000001_F@00LgT007>J00<0009=
e003001=e4gD00I=e003001Am57d00IAm003001Am57d00MAm003001Am00000MF5@03001F5EHE009F
5@03001J=EXe009J=@03001F=@0000EJ=@03001NEP00009JEP03001NMUif009NMP04001NMeig0003
HYL00`00H[P00002I]P00`00JaU[6@04003oOoooOolnOol00`00Oomoo`0[Ool00`00Oomoo`04Ool0
0=eoo`8000Ioo`03001oogoo0;Ioo`030011M45d0091M003001Ae57D00IAe003001Ae57D00MAe003
001Ae57D00IAe003001Em5Gd00EEm006001kMW]f001J=@000eif00@006JgI[L0009Ze`03001V]`00
009Vf004001Zn000KcT200000g=i001cVP040002CM@00`00CMA=e006CM@00`00DOAAm006DO@00`00
DOAAm007DO@00`00DO@00007EQD01@00EQEF5EHE00001EXe00<005He00001EXe00<005iF00000UYF
00D005ifGWINMP0000=NM`06001RUf:G001R^0000VKH00<006/IJaT01000ogooogoo@7oo00<007oo
Ool0:Woo00<007ooOol017oo003OOol20003Ool00`00Oomoo`2gOol00`00@GA1M002@G@00`00DMAA
e006DM@00`00DMAAe007DM@00`00DMAAe006DM@00`00EOAEm005EO@01P00NgIkMP00FSD0009NMP05
001V]fJgI[L00002J]L01@00I[L006KH00000V[h0P0000A_F@00001cVP<00005DO@004gDCM@00008
CM@00`00DOAAm006DO@00`00DOAAm007DO@20008EQD01@00EQEF5EHE00001EXe0P001EXe00H005iF
GUH005YF0003GWH01000GWMNMeig0P0000MRU`00H[QR^000I]P00002JaT4003oOoooOom2Ool00`00
Oomoo`0YOol00`00Oomoo`04Ool00>5oo`800003Ool007oo0;Qoo`8000=1M003001Ae57D00IAe003
001Ae57D00MAe003001Ae57D00IAe003001Em5Gd00EEm006001kMW]f001J=@000Uif00@006JgI[L0
009Ze`<00004I]P006[hJ_P200000fmI001cN@040003DO@00`00CM@00008CM@00`00DOAAm006DO@0
0`00DOAAm007DO@00`00EQEF5@07EQD01000EQEF5@001UXe00<005XeFSD00eXe00@005iFGUINEP80
00=NMP06001NMeigGWL006:G0P000V:h00<006KH00000V/I1000ogooogoo@goo00<007ooOol0:Goo
00<007ooOol017oo003SOol2002iOol20003@G@00`00DMAAe006DM@00`00DMAAe007DM@00`00DMAA
e006DM@00`00EOAEm004EO@01000NgIkMW]f0P000Uif00D006JgI[MV]`00009Ze`80009Vf004001Z
n000KcT200000g=i001cVP030003DO@00`00CM@00008CM@00`00DOAAm006DO@00`00DOAAm007DO@0
0`00EQEF5@07EQD01000EQEF5@001UXe00<005XeFSD00eXe00D005iFGUINEP0000ANMP04001NMeig
0002HYL01000H[QR^0000VKH00<006/I00000`00ogooogooAGoo00<007ooOol0:7oo00<007ooOol0
17oo003TOol3002gOol20003@G@00`00DMAAe005DM@00`00DMAAe008DM@00`00DMAAe006DM@00`00
EOAEm004EO@01000NgIkMW]f0P000Uif00@006JgI[L0009Ze`0:001Zn000I]P006[h001_>@00KeT2
000017>J00000000157d00<004gD000024gD00<0057dDO@01U7d00<0057dDO@01U7d0P002EHE00<0
05HE00001UXe0P0015Xe00<005iFGUH00UiF00D005ifGWINMP0000=NM`06001RUf:G001R^0000VKH
00H006/I000007>J003oOoooOom7Ool00`00Oomoo`0WOol00`00Oomoo`04Ool00>Moo`800;Eoo`80
00=1M003001Ae57D00EAe003001Ae57D00QAe003001Ae57D00IAe003001Em5Gd00AEm005001kMW]f
NgH00002GWH02`00I[MV]fJg001Ze`00J_P006lH00000V[h0P0000=_F@00LgT010001U7d0P0024gD
00<0057dDO@01U7d00<0057dDO@01E7d00<005Gd00002EHE0P001eXe0P000eXe00<005iFGUH00UiF
0P000Uif00D005igGWMNM`00009RU`03001V^000009Vf005001[6@00001cVP02003oOoooOom7Ool0
0`00Oomoo`0WOol00`00Oomoo`04Ool00>Uoo`800;Aoo`050011M45d@G@00007DM@00`00DMAAe008
DM@00`00DMAAe006DM@00`00EOAEm004EO@01@00NgIkMW]f00000Uif00@006JgI[L0009Ze`80009_
6007001Zn000001_F@00LgT01@001U7d0P0024gD00<0057dDO@01U7d00<0057dDO@01E7d00<005Gd
00002EHE0P001UXe00<005YE00000eXe00D005iFGUINEP00009NMP03001NMP00009NM`04001RUf:G
0002I[P01P00I]P006/I001_>P<00?mooomoodUoo`03001oogoo02Moo`03001oogoo00=oo`00jgoo
0P00/Woo00D0045d@GA1M00000MAe003001Ae57D00QAe003001Ae57D00IAe003001Em5Gd00=Em004
001kMW]fNgH200001Eif001V]fJg00000V[G00P006[h001_6000KcT006li0P0000=cN@0000000`00
1e7d0P0024gD00<0057dDO@01U7d00<0057dDO@0157d00@005GdEO@000UF5@03001J=EXe00AJ=@04
001JEEYE0002FSD00`00GUINEP02GUH00`00GWINMP020002GWL01000HYMRU`000VJh00H006Kh001[
6@00KcX3003oOoooOom;Ool00`00Oomoo`0VOol00`00Oomoo`03Ool00>eoo`8000Qoo`03001oogoo
0:Eoo`050011M45d@G@00007DM@00`00DMAAe007DM@00`00DMAAe007DM@00`00EOAEm003EO@01000
NgIkMW]f0P0000ENMP00I[MV]`00009Ze`800004KaP006liKcT2000016mI000007>J1000257d00<0
04gDCM@01TgD00<0057dDO@01U7d00<0057dDO@00e7d00D005GdEOAEm00000UF5@03001J=EXe00AJ
=@06001JEEYE001J=@0015iF00D005ifGWINMP00009NM`07001RUf:GHYL006Jh00000VKh0P0000A_
>P00LiX00?mooomoodeoo`03001oogoo02Eoo`03001oogoo00=oo`00kgoo0P001Woo00<007ooOol0
YGoo00D0045d@GA1M00000MAe003001Ae57D00MAe003001Ae57D00MAe003001Em5Gd00=Em004001k
MW]fNgH30002I[L02@00J]MZe`00J_P006lH001_>@0200000fmI001cN@0400000d6D001Am007DO@0
0`00CMA=e006CM@00`00DOAAm006DO@00`00DOAAm003DO@01@00EOAEm5Gd000025HE0P001EXe00L0
05YEFUEJE@00FSD00003GUH00`00GWINMP02GWH01000GWMNM`000V:G00D006JhI[P006Kh00800004
KcX007>J003oOoooOom>Ool00`00Oomoo`0UOol00`00Oomoo`03Ool00?5oo`8000Aoo`03001oogoo
0:Eoo`050011M45d@G@00007DM@00`00DMAAe007DM@00`00DMAAe007DM@00`00EOAEm003EO@01@00
NgIkMP00NgL00P000VJg00X006[G001Zn000KaP006li001cF@800003LgT0000000<00003@I@0057d
00MAm08000M=e003001Am57d00IAm003001Am57d009Am003001Em5Gd009Em003001F5EHE00IF5@80
00EJ=@04001JEEYEFUD20004GUH01000GWINMUif0P0000ENM`00HYMRU`00009V^004001Vn000JaT2
00000g>J001oo`3oOoooOom?Ool00`00Oomoo`0TOol00`00Oomoo`03Ool00?=oo`800003Ool007oo
0:Moo`050011M45d@G@00007DM@00`00DMAAe007DM@00`00DMAAe007DM@00`00EOAEm002EO@01`00
NgIkMW]f001kM`00009V]`03001Zef[G00800004KaP006liKcT200000g=i000000040002@I@00`00
DOAAm006DO@00`00DO@00006CM@00`00DOAAm006DO@01@00DOAAm57d00001EGd00<005HEEQD01EHE
00<005Xe000015Xe00<005YEFUD00UYE00<005iFGUH00UiF00H005ifGWINMP00HYL20002HYL02@00
I[QV^000I_P006/I001_F@03003oOoooOomAOol00`00Oomoo`0SOol00`00Oomoo`03Ool00?Eoo`80
0:Qoo`800091M003001Ae57D00EAe003001Ae57D00MAe003001Ae57D00MAe003001Em5Gd009Em007
001kMW]fNgH007]g00000VJg00P006[G001Zn000KaP006li0P0000=cN@00LgX010000d6D00<0057d
DO@01U7d00@0057dDO@000E=e003001Am57d00IAm005001Am57dDO@00005EO@00`00EQEF5@05EQD0
0`00FSD00003FSD00`00FUEJE@03FUD00`00GUINEP02GUH01000GWINMP000V:G00l006:GHYMRU`00
I[P006Kh001[6@00KeT007>J0000ogooogooDgoo00<007ooOol08Woo00<007ooOol00goo003fOol3
002VOol20002@G@00`00DMAAe005DM@00`00DMAAe007DM@00`00DMAAe007DM@00`00EOAEm002EO@0
1@00NgIkMP00NgL00P0000AV]`00J]MZe`800003KaP006li00800003LgT007=j00D000=1U003001A
m57d00IAm005001Am57dDO@00004CM@00`00DOAAm006DO@01000DOAAm0001UGd00<005HEEQD01EHE
00<005Xe00000eXe00<005YEFUD00UYE0P000eiF00D005ifGWINMP00009RU`04001RUf:G0002I[P2
00001V/I001_F@00LiX00?mooomooeAoo`03001oogoo029oo`03001oogoo00=oo`00nGoo0P00YGoo
00@0045d@G@000MAe003001Ae57D00MAe003001Ae57D00MAe003001Em5Gd009Em007001kMW]f001k
M`00NiP00P0000EZe`00001_6000009_>@<00003LgX0000000<000A1U003001Am57d00IAm003001A
m57d009Am005001=e4gDCM@00008DO@00`00DO@00007EO@00`00EQEF5@04EQD01000FSEJ=@000UXe
00<005YEFUD00eYE0P000UiF00D005ifGWINMP00009RU`04001R]`000002I[P01000I_P006/I0P00
00=cVP00Ool0ogooogooEGoo00<007ooOol08Goo00<007ooOol00goo003kOol2002SOol00`00@G@0
0008DM@00`00DMAAe007DM@00`00DMAAe007DM@00`00EOAEm002EO@01@00NgH007]g00000W^H00P0
06[G001Zn000KaP006li0P0000=cN@00000010001D6D00<0057dDO@01U7d00<0057dDO@00e7d00@0
04gDCM@000QAm003001Am00000MEm003001F5EHE00AF5@04001J=EXe0002FSD00`00FUEJE@02FUD0
1P00GWINMP00GUH0009NMP04001RUf:G0002H[L01`00I[QV^000I_P006/I00800003LiX000000?mo
oomooeMoo`03001oogoo021oo`03001oogoo00=oo`00oGoo0P00XGoo00<0045d0000257D00<0057D
DM@01e7D00<0057DDM@01e7D00D005GdEOAEm000009kMP03001kM`00009kV007001Ze`00001_6000
KcT00P0000=cN@00LgX01@001D6D00<0057dDO@01U7d00<0057dDO@0157d00<004gD0000257d0P00
25Gd00<005HEEQD00eHE00L005XeFSEJ=@00FSD00005FUD00`00GWINMP020003GWH01000HYMRU`00
0V:g00<006JhI[P00P0000A[6@00001cVP800?mooomooeQoo`03001oogoo021oo`03001oogoo00=o
o`00ogoo0P001goo00<007ooOol0UGoo00<0045d0000257D00<0057DDM@01e7D00<0057DDM@01e7D
00D005GdEOAEm000009kMP08001kM`00NiP007NH001Zn080009_>@<00003LgX0000000@000E1U003
001Am57d00IAm003001Am57d00EAm08000AAm0D000UEm003001F5EHE00=F5@04001J=EXeFSD20005
FUD01@00GWINMUif00000eif00@006:GHYL0009R]`03001Vf00000800003JaT006mI00<00?mooomo
oeYoo`03001oogoo01moo`03001oogoo00=oo`00ogoo0Woo0P001Goo00<007ooOol0UGoo00<0045d
0000257D00<0057DDM@01e7D00<0057DDM@01e7D00T005GdEOAEm000NgH007]g00000W^H00L007NH
000006lH001_>@0300000g=j000000050005@I@00`00DOAAm006DO@00`00DOAAm006DO@50004DO@0
0`00EOAEm007EO@00`00EQEF5@02EQD00`00FSEJ=@02FSD20005FUD01@00GWINMUif00000Uif00@0
06:GHYL0009R]`03001Vf6KH0080009[6@@00?mooomooeaoo`03001oogoo01ioo`03001oogoo00=o
o`00ogoo17oo0P000goo00<007ooOol0UGoo00<0045d0000257D00<0057DDM@01e7D00<0057DDM@0
1e7D00`005GdEOAEm000NgH007]g001kV000MiP200000flH001_>@0300000g=j000000060005@I@0
0`00DOAAm006DO@00`00DOAAm006DO@00`00DOAAm006DO@00`00EOAEm007EO@00`00EQEF5@02EQD0
0`00FSEJ=@02FSD00`00FUEJE@03FUD01000GWINMUif0P0000ENMP00HYMRU`0000=R]`04001Vf6KH
0002JaT5003oOoooOomMOol00`00Oomoo`0MOol00`00Oomoo`03Ool00?moo`Ioo`800003Ool007oo
09Ioo`030011M00000QAe003001Ae57D00MAe003001Ae57D00MAe008001Em5Gd001kMP00NgL0009k
V003001gV0000080009_>@03001cN@0000T000E1U003001Am57d00IAm003001Am57d00IAm003001A
m57d00IAm003001Em5Gd00MEm003001F5EHE009F5@03001J=EXe009J=@03001JEEYE009JE@09001N
MUifGWH006:G001NMP00009RU`04001R]f:g0002I]P200000f/I00000003003oOoooOomNOol00`00
Oomoo`0MOol00`00Oomoo`03Ool00?moo`Qoo`8009Moo`030011M00000QAe003001Ae57D00MAe003
001Ae57D00MAe00;001Em5Gd001kMP00NgL007^H001gV00200000gNI001_>@0300000g=j00000003
000017oo000000001D6D00<0057dDO@01U7d00<0057dDO@01U7d00<0057dDO@01U7d00<005GdEO@0
1eGd00D005HEEQEF5@0000AJ=@8000AJE@06001NMUifGWH006:G0P000V:G00@006:gH[L0009Vf080
0003KcT0000000<00?mooomoof1oo`03001oogoo01aoo`03001oogoo00=oo`00ogoo2Goo0`00UGoo
0`00257D00<0057DDM@01e7D00<0057DDM@01e7D00D005GdEO@007]f0080009kV0<00003MiT007NI
00<00003LgX0000000@0009oo`8000E1U003001Am57d00IAm003001Am57d00IAm003001Am57d00IA
m003001Em5Gd00MEm005001F5EHEEQD00004FSD20003FUD01@00GWINMUif00000V:G00@006:GHYL0
009R]`03001Vf6KH0080009_>@@00?mooomoof9oo`03001oogoo01]oo`03001oogoo00=oo`00ogoo
37oo0P00U7oo0P00257D00<0057DDM@01e7D00<0057DDM@01e7D00<005GdEO@00P0000EkM`00NiP0
07NH00<0009gV@800003LgX0000000@000=oo`<000A1U003001Am57d00IAm003001Am57d00IAm003
001Am57d00IAm003001Em5Gd00MEm004001F5EHE0005FSD20003FUD01@00GWINMUif00000V:G00@0
06:GHYL0009R]`06001Vf000J_P006li1@00ogooogooHgoo00<007ooOol06goo00<007ooOol00Woo
003oOol>Ool2002BOol20008DM@00`00DMAAe007DM@00`00DMAAe007DM@02000EO@007]f001kM`00
NiP300000gNI001gV@0:0003Ool30004@I@00`00DOAAm006DO@00`00DOAAm006DO@00`00DOAAm006
DO@00`00EOAEm007EO@01000EQEF5@0015Xe00H005ifGWH005YE0003GWH01@00HYMRU`00I[L00P00
0V:g00H006KH001Zn000KcT5003oOoooOomTOol00`00Oomoo`0KOol00`00Oomoo`02Ool00?mooa1o
o`80091oo`8000QAe003001Ae57D00MAe003001Ae57D00MAe004001Em000NgH200000g^H001gV003
00001GNI00000000LiX01P0017oo0`00146D00<0057dDO@01U7d00<0057dDO@01U7d00<0057dDO@0
1U7d00<005GdEO@01eGd00<005HE00001EXe00H005ifGWH005YE0002GWH01000HYMRU`000VJg00@0
06:gH[L0009Vf0800003KcT0000000<00?mooomoofIoo`03001oogoo01Yoo`03001oogoo009oo`00
ogoo4Woo0P001Woo00<007ooOol0QGoo0P00257D00<0057DDM@01e7D00<0057DDM@01e7D00L005Gd
000007]g001kV00300000gNI0000000200000g>J000000050004Ool30004@I@00`00DOAAm006DO@0
0`00DOAAm006DO@00`00DOAAm006DO@00`00EOAEm007EO@00`00EQD00004FSD01000GWINMUif0P00
0eif00@006:GHYL0009V]`05001R]f:g001Vf00200000fli00000003003oOoooOomXOol00`00Oomo
o`0IOol00`00Oomoo`02Ool00<eoo`D000ioo`@000ioo`@001eoo`8000Aoo`03001oogoo08Eoo`80
00QAe003001Ae57D00MAe003001Ae57D00MAe003001Em00000800007NiP007NH001gV@00MiT00P00
00=cVP0000001@001Woo0P00146D00<0057dDO@01U7d00<0057dDO@01U7d00<0057dDO@01U7d00<0
05GdEO@01eGd00<005HE000015Xe00@005ifGWINMP80009NMP04001RUf:G0002I[L01`00I]P00000
I]P006[h00800003KeT0000000800?mooomoofQoo`03001oogoo01Uoo`03001oogoo009oo`00bgoo
2@002Woo20002Woo20007Goo0P000Woo00<007ooOol0QGoo0P00257D00<0057DDM@01e7D00<0057D
DM@01e7D0`0000=kM`00NiP0100000=gV@00000020001goo0P00146D00<0057dDO@01U7d00<0057d
DO@01U7d00<0057dDO@01U7d00<005GdEO@01eGd0P001EXe00D005ifGWINMP00009NMP07001RUf:G
HYL006Jg00000VKH00H006KH001Zn000KcT5003oOoooOomZOol00`00Oomoo`0HOol00`00Oomoo`02
Ool00<Yoo`@000Aoo`<000Uoo`8000Aoo`8000Yoo`8000Aoo`8001moo`<008Moo`8000QAe003001A
e57D00MAe003001Ae57D00MAe0@00005NiP007NH001gV@0400000g>J000000050007Ool20004@I@0
0`00DOAAm006DO@00`00DOAAm006DO@00`00DOAAm006DO@00`00EOAEm007EO@20004FSD00`00GWIN
MP02GWH01000GWINMP000V:G00@006JgI[L0009Vf0800003J_P006li00D00?mooomoofaoo`03001o
ogoo01Moo`03001oogoo009oo`00bWoo0P001goo0`001goo0P001Woo0P0027oo0P001Woo0P0087oo
0P00QWoo0P00257D00<0057DDM@01e7D00<0057DDM@01e7D100000IkV000001gV@00MiT200000g>J
000000050008Ool20004@I@00`00DOAAm006DO@00`00DOAAm006DO@00`00DOAAm006DO@00`00EOAE
m007EO@00`00FSEJ=@03FSD01000GWINMUif0P0000ENMP00HYMRU`00009V]`03001Vf6KH0080009Z
n0H00?mooomoofioo`03001oogoo01Ioo`03001oogoo009oo`00e7oo0P001goo0P001Woo0P0027oo
0P001Woo0P008Woo0P00Q7oo0P00257D00<0057DDM@01e7D00<0057DDM@01e7D0P0000=kM`000000
0`0000=gV@0000002@0027oo0P00146D00<0057dDO@01U7d00<0057dDO@01U7d00<0057dDO@01U7d
00<005GdEO@01eGd00<005XeFSD00UXe00<005ifGWH00Uif0P0000MNMP00HYMRU`00I[L00002I]P0
1000J_P006[h0P0000=_F@0000000P00ogooogooKWoo00<007ooOol05Woo00<007ooOol00Woo003D
Ool20006Ool20008Ool20006Ool20008Ool2000SOol20023Ool00`00DMAAe006DM@00`00DMAAe007
DM@00`00DMAAe007DM@3000017^H000007NI1@0000=cVP0000001@0027oo0P00146D00<0057dDO@0
1U7d00<0057dDO@01U7d00<0057dDO@01U7d00<005GdEO@01eGd00<005XeFSD00UXe00H005ifGWIN
MP00I[L20002HYL02@00I[MV]`00I]P006[h001_>@0200000fmI00000002003oOoooOom`Ool00`00
Oomoo`0EOol00`00Oomoo`02Ool00=Aoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8002Eoo`80085o
o`03001Ae57D00IAe003001Ae57D00MAe003001Ae57D009Ae1000003LiX007>J00D000Yoo`8000=1
U003001Am57d00IAm003001Am57d00IAm003001Am57d00IAm003001Em5Gd00IEm08000=J=@03001N
MUif009NMP03001V]`0000=RU`03001V]`00009Vf080009_>@03001_F@0000<00?mooomoog9oo`03
001oogoo01Aoo`03001oogoo009oo`00dgoo0`001Woo0P0027oo0P001Woo0P0027oo0P009goo0P00
1goo00<007ooOol0MGoo00<0057DDM@01U7D00<0057DDM@00U7D4@0000AkV000001gV@<00004LiX0
0000LiX6000:Ool20003@I@00`00DOAAm006DO@00`00DOAAm006DO@00`00DOAAm006DO@00`00EOAE
m006EO@20003FSD01@00GWINMUif00000VJg00H006:GHYL006Jg0002I]P01000J_P006li1P00ogoo
ogooM7oo00<007ooOol04goo00<007ooOol00Woo003BOol30007Ool20008Ool20006Ool20008Ool2
000YOol20005Ool00`00Oomoo`1eOol00`00DMAAe002DM@:00000c]O0000000?00000gNI00000009
00000gNH0000000:Ool20003@I@00`00DOAAm006DO@00`00DOAAm006DO@00`00DOAAm006DO@00`00
EOAEm006EO@20003FSD01P00GWINMUif001V]`80000:HYL006JgI[L006KH001Zn000KcT200000g=j
00000002003oOoooOomdOol00`00Oomoo`0COol00`00Oomoo`02Ool00<moo`D000Qoo`8000Qoo`80
00Ioo`8000Qoo`8002]oo`8000=oo`03001oogoo07EoobH00003LiX0000000L000Yoo`8000=1U003
001Am57d00IAm003001Am57d00IAm003001Am57d00IAm003001Em5Gd00IEm005001kMP00FSD00003
GWH01@00I[MV]`00J]L00P0000AV]`00I]QVf0800004KcT00000LgX4003oOoooOomfOol00`00Oomo
o`0BOol00`00Oomoo`02Ool00<moo`@000Uoo`8000Qoo`8000Ioo`8000Qoo`8002eoo`800003Ool0
07oo07Qoob<00003LiX007>J00L000]oo`8000=1U003001Am57d00IAm003001Am57d00IAm003001A
m57d00IAm003001Em5Gd00EEm006001kMW]f001J=@000eif00<006Jg00000V[G00<006Jg00000VKH
0P000Vli1P00ogooogooN7oo00<007ooOol04Goo00<007ooOol00Woo003BOol20008Ool20008Ool2
0006Ool20008Ool2000_Ool2001jOol600000c]O0000000800000c]O0000000800000c]O00000004
00000g>J00000006000;Ool20003@I@00`00DOAAm006DO@00`00DOAAm006DO@00`00DOAAm006DO@0
0`00EOAEm005EO@00`00NgIkMP020003GWH01000I[MV]`000V[G00P006Jg001Vf000J_P006li1P00
ogooogooNGoo00<007ooOol04Goo00<007ooOol00Woo003COol20007Ool20008Ool20006Ool20008
Ool2000`Ool3000=Ool00`00Oomoo`1ZOolW00000g]g0000000<Ool01@00@IA1U46D0000257d00<0
057dDO@01U7d00<0057dDO@01U7d00<005GdEO@01EGd00<007]fNgH00P000Uif00@006JgI[L0009Z
e`<00005I]P006[h001_>@0200000g=j00000002003oOoooOomjOol00`00Oomoo`0@Ool00`00Oomo
o`02Ool00==oo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8003Aoo`8000]oo`03001oogoo06aoo`H0
0003>el0000000P00003>el0000000P00003>el0000000@00003MiP00000008000aoo`050011U46D
@I@00008DO@00`00DOAAm006DO@00`00DOAAm006DO@00`00EOAEm004EO@01000NgIkMW]f0P000Uif
00P006JgI[L006[G001Zn0000VKH0P0000A_>@00001cNP@00?mooomoogaoo`03001oogoo00moo`03
001oogoo009oo`00bgoo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P00=Woo0P002Goo00<0
07ooOol0KWoo8P0000=kM`0000003Goo00D0046D@IA1U00000QAm003001Am57d00IAm003001Am57d
00IAm003001Em5Gd00AEm005001kMW]fNgH00002GWH01000I[MV]`000V[G00H006[h001Vf000J_P2
00000fmI00000003003oOoooOomnOol00`00Oomoo`0?Ool00`00Oomoo`01Ool00<]oo`<000Aoo`<0
00Uoo`8000Aoo`8000Yoo`8000Aoo`8003Uoo`8000Moo`03001oogoo071oob<000eoo`050011U46D
@I@00008DO@00`00DOAAm006DO@00`00DOAAm006DO@00`00EOAEm004EO@01@00NgIkMW]f00000Uif
00d006JgI[L006[G001Zn000KaP006[h001_>@06003oOoooOomoOol00`00Oomoo`0?Ool00`00Oomo
o`01Ool00<aoo`P000Yoo`P000Yoo`P003]oo`8000Eoo`03001oogoo075ooa`0009oo`03001oogoo
00ioo`050011U46D@I@00008DO@00`00DOAAm006DO@00`00DOAAm006DO@00`00EOAEm004EO@00`00
NgIkMP0200001Eif001V]fJg00000V[G0P000VlH0P0000A_>@00001cNP<00?mooomooh5oo`03001o
ogoo00ioo`03001oogoo005oo`00cGoo1@003Woo10003Woo1000?goo0P000goo00<007ooOol0Lgoo
1P0000<kG`0000001`0037oo00<007ooOol03Woo0P000T6D00<0057dDO@01U7d00<0057dDO@01U7d
00<0057dDO@01U7d00<005GdEO@00eGd00@007]fNgIkMP80000<GWH006JgI[L006[G001Zn000KaP0
06li0P0000=_F@0000000`00ogooogooPWoo00<007ooOol03Goo00<007ooOol00Goo003oOolhOol2
00000goo001oo`1fOol5000EOol00`00Oomoo`0?Ool01000@IA1U000257d00<0057dDO@01U7d00<0
057dDO@01U7d00<005GdEO@00eGd00@007]fNgIkMP<0009V]`08001Ze`00J_P006lH001_>@800003
KeT0000000<00?mooomoohAoo`03001oogoo00aoo`03001oogoo005oo`00ogoo>Woo0P00TGoo00<0
07ooOol03goo00@0046D@I@000QAm003001Am57d00IAm003001Am57d00IAm003001Em5Gd00=Em005
001kMW]f001kM`020002I[L01P00J]L006[h001_60800003KeT0000000@00?mooomoohEoo`03001o
ogoo00aoo`03001oogoo005oo`00ogoo>goo0`00Sgoo00<007ooOol03goo00@0046D@I@000QAm003
001Am57d00IAm003001Am57d00IAm003001Em5Gd00=Em006001kMW]f001kM`000VJg00H006[G001Z
n000KaP200000fmI001cN@05003oOoooOon6Ool00`00Oomoo`0;Ool00`00Oomoo`01Ool00?moocio
o`8008eoo`03001oogoo00moo`040011U46D0008DO@00`00DOAAm006DO@00`00DOAAm006DO@00`00
EOAEm002EO@01`00NgIkMW]f001kM`00009V]`800005J_P006lH001_>@0200000g=i00000003003o
OoooOon8Ool00`00Oomoo`0:Ool00`00Oomoo`01Ool00?mood1oo`8008]oo`03001oogoo00moo`04
0011U46D0008DO@00`00DOAAm006DO@00`00DOAAm006DO@00`00EOAEm002EO@01@00NgIkMP00NgL0
0P0000MV]`00J]L006[h001_600200000fmI00000004003oOoooOon:Ool00`00Oomoo`09Ool00`00
Oomoo`01Ool00?mood9oo`8000Moo`03001oogoo07moo`03001oogoo00moo`030011U00000UAm003
001Am57d00IAm003001Am57d00IAm003001Em5Gd009Em007001kMW]f001kM`00MiP00`0000=Zn000
KaP00P0000=_F@0000001@00ogooogooRWoo00<007ooOol02Goo00<007ooOol00Goo003oOom4Ool2
0005Ool00`00Oomoo`1oOol00`00Oomoo`0?Ool00`00@I@00009DO@00`00DOAAm006DO@00`00DOAA
m006DO@00`00EOAEm002EO@00`00NgIkMP020002MiP01P00J]L006[h001_60<00003LgT0000000<0
0?mooomoohaoo`03001oogoo00Qoo`03001oogoo005oo`00ogooAWoo0P000goo00<007ooOol0Ogoo
00<007ooOol03goo00<0046D00002E7d00<0057dDO@01U7d00<0057dDO@01U7d00D005GdEOAEm000
009kMP03001kM`00009gV0800003J_P006lH00<00003LgT0000000<00?mooomoohioo`03001oogoo
00Moo`03001oogoo005oo`00ogooB7oo0P0000=oo`00Ool0P7oo00<007ooOol03goo00<0046D0000
2E7d00<0057dDO@01U7d00<0057dDO@01U7d00D005GdEOAEm000009kMP80009gV0800003J_P006lH
00800003KeT0000000D00?mooomoohioo`03001oogoo00Moo`03001oogoo005oo`00ogooBWoo0P00
PGoo00<007ooOol03goo00<0046D00002E7d00<0057dDO@01U7d00<0057dDO@01U7d00D005GdEOAE
m000009kMP80009gV0800005J_P006lH001_F@07003oOoooOon@Ool00`00Oomoo`06Ool00`00Oomo
o`01Ool00?mood]oo`<007moo`03001oogoo011oo`8000UAm003001Am57d00IAm003001Am57d00IA
m00:001Em5GdEO@007]f001kM`00MiP200000gNI001_600500000g>J00000002003oOoooOonAOol0
0`00Oomoo`05Ool00`00Oomoo`01Ool00?moodioo`8007eoo`03001oogoo011oo`8000UAm003001A
m57d00IAm003001Am57d00IAm004001Em5Gd0002NgH200001GNH001gV000MiT00`0000=_F@000000
1@00ogooogooTgoo00<007ooOol017oo00<007ooOol00Goo003oOom@Ool2001kOol00`00Oomoo`0@
Ool20009DO@00`00DOAAm006DO@00`00DOAAm006DO@02@00EOAEm000NgH007]g001gV00200001GNI
001gV@00KeT01`00ogooogooU7oo00<007ooOol017oo00<007ooOol00Goo003oOomBOol20007Ool0
0`00Oomoo`1_Ool00`00Oomoo`0@Ool20009DO@00`00DOAAm006DO@00`00DOAAm006DO@01@00EOAE
m000NgH00P0000=gV000MiP00P0000=gV@0000000`0000=cVP0000000P00ogooogooUGoo00<007oo
Ool00goo00<007ooOol00Goo003oOomDOol20005Ool00`00Oomoo`1_Ool00`00Oomoo`0@Ool20009
DO@00`00DOAAm006DO@00`00DOAAm006DO@00`00EO@00002NgH2000017NH000007NI0`0000AcV@00
001cVP@00?mooomooiMoo`03001oogoo00=oo`40005oo`5oo`00ogooEWoo0P000goo00<007ooOol0
KWoo00<007ooOol04Goo0P002E7d00<0057dDO@01U7d00<0057dDO@01U7d00@005Gd001kMP800003
MiP007NH00@00003LiT0000000H00?mooomooiQoo`03001oogoo009oo`40005oo`5oo`00ogooF7oo
0P0000=oo`00Ool0Kgoo00<007ooOol04Goo0P002E7d00<0057dDO@01U7d00<0057dDO@01U7d00@0
05Gd001kMP800005MiP00000001gV@0500000g>J00000002003oOoooOonIOol00`00Oomoo`02Ool1
0001Ool1Ool00?mooeYoo`80071oo`03001oogoo015oo`8000UAm003001Am57d00IAm003001Am57d
00IAm006001Em000NgH007NH0P0000=gV@000000100000=cVP0000000`00ogooogooVWoo00D007oo
Oomoo`00009oo`00ogooFgoo0`00KWoo00<007ooOol04Goo0P002E7d00<0057dDO@01U7d00<0057d
DO@01U7d0P0000AkMP00001gV0D00003LiT0000000H00?mooomooiaoo`04001oogoo0002Ool00?mo
oeioo`8006aoo`03001oogoo015oo`8000UAm003001Am57d00IAm003001Am57d00IAm0800003NgH0
07NH00<00003MiT0000000T00?mooomooiaoo`04001oogoo0002Ool00?moof1oo`8006Yoo`03001o
ogoo015oo`8000UAm003001Am57d00IAm003001Am57d00IAm0800004NgH00000MiP=003oOoooOonN
Ool00`00Ool00002Ool00?moof9oo`8000Ioo`03001oogoo05moo`03001oogoo019oo`03001Am57d
00MAm003001Am57d00IAm003001Am57d00IAm0P00003MiT0000000P00?mooomooimoo`80009oo`00
ogooI7oo0P0017oo00<007ooOol0Ggoo00<007ooOol04Woo00<0057dDO@01e7d00<0057dDO@01U7d
00<0057dDO@01U7d00D007]f000007NH00800003MiT007>J00P00?mooomooiYoo`P0009oo`00ogoo
IWoo0P000Woo00<007ooOol0Ggoo00<007ooOol04Woo00<0057dDO@01e7d00<0057dDO@01U7d00<0
057dDO@00U7d1@0000=kMP0000003P00ogooogooS7oo3P002Woo003oOomXOol3001QOol00`00Oomo
o`0BOol00`00DOAAm007DO@00`00DOAAm002DO@@000017NH000007NI1P0000AgV@0000000?mooomo
ogioo`l001Qoo`00ogoo87oo30002goo10003Woo10007Goo0P00H7oo00<007ooOol04Woo8@0000=g
V@00LiX02@00ogooogooL7oo3P009goo003oOolPOol<0009Ool8000:Ool8000MOol2001NOol00`00
Oomoo`0COolQ000017>J000007>J1`00ogooogooHWoo3P00=Goo003oOolQOol30006Ool20009Ool2
0004Ool2000:Ool20004Ool2000OOol00`00Oomoo`1KOol00`00Oomoo`0EOolQ000017>J000007NI
1000ogooogooEGoo3P00@goo003oOolROol3000?Ool20006Ool20008Ool20006Ool2000OOol20008
Ool00`00Oomoo`1@Ool00`00Oomoo`0FOolR00000gNI00000003003oOoooOom7Ool>001AOol00?mo
ob=oo`<000ioo`8000Ioo`8000Qoo`8000Ioo`80025oo`8000Ioo`03001oogoo051oo`03001oogoo
01Qooa/00003>el0000000P00?mooomoocQoo`l005moo`00ogoo97oo0`0037oo0P0027oo0P001Woo
0P0027oo0P008Woo0P0017oo00<007ooOol0D7oo00<007ooOol06Woo1P0000<kG`0000006P00ogoo
ogoo:goo3P00KWoo003oOolUOol3000;Ool20008Ool20006Ool20008Ool2000TOol20002Ool00`00
Oomoo`1@Ool00`00Oomoo`0LOolQ003oOoooOolMOol>001lOol00?moobIoo`<000Yoo`8000Qoo`80
00Ioo`8000Qoo`8002Ioo`<0059oo`03001oogoo01iooaX00?mooomooaAoo`h008Yoo`00ogoo9goo
0`002Goo0P0027oo0P001Woo0P0027oo0P00:7oo0P003Goo00<007ooOol0@Goo00<007ooOol087oo
3`00ogooogoo3goo3P00V7oo003oOolXOol30008Ool20008Ool20006Ool20008Ool2000ZOol2000;
Ool00`00Oomoo`11Ool00`00Oomoo`3oOoooOol_Ool?002VOol00?moobUoo`8000Qoo`8000Qoo`80
00Ioo`8000Qoo`8002aoo`8000Uoo`03001oogoo045oo`03001oogoo0?mooomoob5oo`h00;Eoo`00
ogoo:Woo0P001goo0P0027oo0P001Woo0P0027oo0P00;Woo0P001goo00<007ooOol0@Goo00<007oo
Ool0ogooogoo4goo3P00`goo003oOolZOol20007Ool20008Ool20006Ool20008Ool2000`Ool20004
Ool00`00Oomoo`12Ool00`00Oomoo`3oOoooOol5Ool>003AOol00?moob5oo`8000Moo`8000Qoo`80
00Ioo`8000Qoo`8000Ioo`8003=oo`80009oo`03001oogoo049oo`03001oogoo0?moooIoo`h00=mo
o`00ogoo8Goo0`001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P00=Goo0`00A7oo00<007ooOol0
ogooigoo3`00kGoo003oOolQOol40004Ool2000:Ool20004Ool2000:Ool20004Ool2000hOol20013
Ool00`00Oomoo`3oOooIOol>003lOol00?moob9oo`P000]oo`P000Yoo`P003Yoo`80045oo`03001o
ogoo0?mool]oo`h00?moo`]oo`00ogoo97oo1@003Woo10003Woo1000?Woo0P00?goo00<007ooOol0
ogoo_Goo3P00ogoo6Goo003oOon=Ool20007Ool00`00Oomoo`0cOol00`00Oomoo`3oOon^Ool?003o
OolWOol00?moohmoo`8000Eoo`03001oogoo03=oo`03001oogoo0?mooj1oo`h00?moocIoo`00ogoo
TGoo0P000goo00<007ooOol0<goo00<007ooOol0ogooTWoo3P00ogooA7oo003oOonCOol200000goo
001oo`0dOol00`00Oomoo`3oOon4Ool>003oOomBOol00?mooiEoo`8003Eoo`03001oogoo0?moogIo
o`h00?moof1oo`00ogooUgoo0P00<goo00<007ooOol0ogooIgoo3`00ogooKWoo003oOonIOol2000a
Ool00`00Oomoo`3oOomIOol>003oOommOol00?mooi]oo`8000Moo`03001oogoo02Eoo`03001oogoo
0?mood]oo`h00?mooh]oo`00ogooWGoo0P001Goo00<007ooOol09Goo00<007ooOol0ogoo?Goo3P00
ogooVGoo003oOonOOol20003Ool00`00Oomoo`0UOol00`00Oomoo`3oOol_Ool>003oOonWOol00?mo
oj5oo`<002Qoo`03001oogoo0?moob1oo`l00?mookEoo`00ogooXgoo0P009goo00<007ooOol0ogoo
4Woo3P00ogooa7oo003oOonUOol2000TOol00`00Oomoo`3oOol5Ool>003oOooBOol00?moojMoo`80
029oo`03001oogoo0?Ioo`h00?moon1oo`00ogooZGoo0P001Woo00<007ooOol05goo00<007ooOol0
igoo3`00ogookWoo003oOon[Ool20004Ool00`00Oomoo`0GOol00`00Oomoo`3IOol>003oOoomOol0
0?moojeoo`80009oo`03001oogoo01Moo`03001oogoo0<]oo`h00?mooomoo`aoo`00ogoo[goo0`00
6Goo00<007ooOol0_Goo3P00ogooogoo6Woo003oOonaOol2000HOol00`00Oomoo`2_Ool>003oOooo
OolXOol00?mook=oo`8001Ioo`03001oogoo0:1oo`l00?mooomoocIoo`00ogooKgoo2P002goo1000
3Woo10006goo0P0027oo00<007ooOol02Goo00<007ooOol0TWoo3P00ogooogooAGoo003oOom_Ool:
0009Ool8000:Ool8000KOol20006Ool00`00Oomoo`09Ool00`00Oomoo`24Ool>003oOoooOomCOol0
0?moog=oo`8000eoo`8000Aoo`8000Yoo`8000Aoo`8001eoo`8000Aoo`03001oogoo00Uoo`03001o
ogoo07Ioo`h00?mooomoof5oo`00ogooLgoo0P0037oo0P001Woo0P0027oo0P001Woo0P007Woo0P00
00=oo`00Ool02goo00<007ooOol0J7oo3P00ogooogooKgoo003oOomcOol2000<Ool20006Ool20008
Ool20006Ool2000POol2000<Ool00`00Oomoo`1IOol?003oOoooOommOol00?moog=oo`8000]oo`80
00Qoo`8000Ioo`8000Qoo`80021oo`<000Yoo`03001oogoo04]oo`h00?mooomoohaoo`00ogooLgoo
0P002goo0P0027oo0P001Woo0P0027oo0P008goo0P0027oo00<007ooOol0?Goo3P00ogooogooVWoo
003oOomcOol2000;Ool20008Ool20006Ool20008Ool2000UOol20006Ool00`00Oomoo`0_Ool>003o
OoooOonXOol00?moog=oo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8002Moo`8000Aoo`03001oogoo
025oo`h00?mooomookIoo`00ogooLgoo0P002goo0P0027oo0P001Woo0P0027oo0P00:Goo0P000Woo
00<007ooOol04Woo3`00ogooogooa7oo003oOomcOol2000;Ool20008Ool20006Ool20008Ool2000[
Ool30006Ool>003oOoooOooCOol00?moog=oo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8002eoo`L0
0?mooomoon5oo`00ogooLgoo0P002goo0P0027oo0P001Woo0P0027oo0P00ogooogooogoo5Woo003o
OomcOol2000<Ool20006Ool20008Ool20006Ool2003oOoooOoooOolGOol00?moog=oo`8000aoo`80
00Ioo`8000Qoo`8000Ioo`800?mooomooomooaMoo`00ogooKgoo0`0000=oo`0000003Goo0P0017oo
0P002Woo0P0017oo0P00ogooogooogoo67oo003oOom_Ool6000=Ool8000:Ool8003oOoooOoooOolH
Ool00?moog9oo`<000moo`@000ioo`@00?mooomooomooaYoo`00ogooogooogooogoo]7oo003oOooo
OoooOoooOondOol00001\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  Evaluatable->False,
  ImageSize->{400, 241.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
Potential distribution of the pigtail including dielectrics, with \
the first two conductors set to potential 1.\
\>", "Text",
  PageBreakBelow->Automatic],

Cell[CellGroupData[{

Cell[BoxData[{
    \(cont = 
      ListContourPlot[u, ImageSize \[Rule] 400, PlotRange \[Rule] All, 
        ContourShading \[Rule] False, Contours \[Rule] 15, 
        DisplayFunction \[Rule] Identity]\), "\n", 
    \(\(\(wi = 
        ListInterpolation[Transpose[u], 
          InterpolationOrder \[Rule] 1];\)\(\[IndentingNewLine]\)
    \) (*\ column\ index\ counts\ increments\ in\ x\ direction, \ 
      row\ index\ counts\ increments\ in\ y\ direction\  \[Rule] \ 
        use\ Transpose\ *) \), "\n", 
    \(\(ex = \(Derivative[1, 0]\)[wi];\)\), "\n", 
    \(\(ey = \(Derivative[0, 1]\)[wi];\)\), "\n", 
    \(FieldLine[{ex_InterpolatingFunction, x0_}, {ey_InterpolatingFunction, 
          y0_}] := \[IndentingNewLine]Module[{x = x0, y = y0, 
          l = {{x0, y0}}, \[IndentingNewLine]xxmin = Part[ex, 1, 1, 1], 
          xxmax = Part[ex, 1, 1, 2], \[IndentingNewLine]yymin = 
            Part[ex, 1, 2, 1], yymax = Part[ex, 1, 2, 2], emod10, xn, 
          yn}, \[IndentingNewLine] (*\ 
          search\ uphill\ *) \[IndentingNewLine]Do[{emod10 = 
              10.  \[Sqrt]\((\((ex[x, y])\)\^2 + \((ey[x, y])\)\^2)\); 
            If[emod10 == 0. , Break[]]; \[IndentingNewLine]xn = 
              ex[x, y]/emod10 + x; 
            yn = ey[x, y]/emod10 + y; \[IndentingNewLine]If[
              xn < xxmin || xn > xxmax || yn < yymin || yn > yymax, 
              Break[]]; \[IndentingNewLine]\(l = Append[l, {xn, yn}]; x = xn; 
            y = yn\)}, {n, 1, 5000}]; \[IndentingNewLine]x = x0; 
        y = y0; \[IndentingNewLine] (*\ 
          search\ downhill\ *) \[IndentingNewLine]Do[{emod10 = \(-10. \) \
\[Sqrt]\((\((ex[x, y])\)\^2 + \((ey[x, y])\)\^2)\); 
            If[emod10 == 0. , Break[]]; \[IndentingNewLine]xn = 
              ex[x, y]/emod10 + x; 
            yn = ey[x, y]/emod10 + y; \[IndentingNewLine]If[
              xn < xxmin || xn > xxmax || yn < yymin || yn > yymax, 
              Break[]]; \[IndentingNewLine]\(l = Prepend[l, {xn, yn}]; 
            x = xn; y = yn\)}, {n, 1, 5000}]; \[IndentingNewLine]Line[
          l]]\), "\n", 
    \(Needs["\<Graphics`Arrow`\>"]\), "\n", 
    \(\(\(AddArrow[Line[opts_], d_, 
        num_:  8] := \[IndentingNewLine]Module[{arr = {}, n = 0, 
          pts = Chop[opts]}, \[IndentingNewLine]Fold[
          If[First[#1] \[GreaterEqual] d && 
                n < num, \(n++\); \[IndentingNewLine]AppendTo[arr, 
                Arrow[Last[#1], #2, HeadScaling \[Rule] Absolute, 
                  HeadCenter \[Rule] 0.5, 
                  HeadLength \[Rule] 
                    4]]; \[IndentingNewLine]{0, #2}, {First[#1] + 
                  Sqrt[Apply[Plus, \((Last[#1] - #2)\)^2]], #2}] &, {0, 
            First[pts]}, Rest[pts]]; arr]\)\(\n\)
    \) (*\(*\)\(\ \)\(1\)\ **) \), "\[IndentingNewLine]", 
    \({xe, ye} = {91, 12.5}; a = 13; b = 6;\), "\n", 
    \(\(n = 21;\) (*\ n/3\ is\ the\ number\ of\ angular\ bins\ *) \), "\n", 
    \(\(eps = ListInterpolation[Transpose[\[Epsilon]]];\) (*\ 
      sample\ the\ field\ strength\ on\ the\ ellipse\ *) \), "\
\[IndentingNewLine]", 
    \(\(ft = 
        Table[eps[a\ Cos[i\ 2  \[Pi]/n] + xe, 
              b\ Sin[i\ 2  \[Pi]/n] + 
                ye] \[Sqrt]\((ex[a\ Cos[i\ 2  \[Pi]/n] + xe, 
                      b\ Sin[i\ 2  \[Pi]/n] + ye]^2 + 
                  ey[a\ Cos[i\ 2  \[Pi]/n] + xe, 
                      b\ Sin[i\ 2  \[Pi]/n] + ye]^2)\), {i, 1, 
            n}];\)\), "\n", 
    \(\(\(s = Apply[Plus, ft];\)\(\[IndentingNewLine]\)
    \) (*\ nl[\([i]\)]\ is\ \((number\ of\ lines\  - \ 
            1)\)\ starting\ in\ the\ ith\ angular\ bin\ of\ the\ ellipse\ *) \
\), "\n", 
    \(\(nl = Round[Apply[Plus, Transpose[Partition[ft, 3]]]/s*n];\)\), "\n", 
    \(\(\(start = {};\)\(\[IndentingNewLine]\)
    \) (*\ 
      array\ of\ angles\ of\ the\ starting\ points\ on\ the\ ellipse\ *) \), \
"\n", 
    \(\(Do[
        Do[AppendTo[
            start, \((2  \[Pi]/\((n/3)\))\)\ \((\((i - 1)\) + 
                  j\ /\((nl[\([i]\)] + 1)\))\)], {j, 0, nl[\([i]\)]}], {i, 1, 
          n/3}];\)\), "\n", 
    \( (*\ calculate\ lines\ one\ after\ the\ other\ *) \(lines = 
        Table[FieldLine[{ex, a\ Cos[start[\([i]\)]] + xe}, {ey, 
              b\ Sin[start[\([i]\)]] + ye}], {i, 1, 
            Length[start]}];\)\[IndentingNewLine] (*\ 
      add\ single\ lines\ where\ appropriate\ *) \[IndentingNewLine] (*line1 \
= FieldLine[{ex, 25}, {ey, 34}]; AppendTo[lines, line1]; 
      line2 = FieldLine[{ex, 34}, {ey, 34}]; 
      AppendTo[lines, line2];*) \), "\n", 
    \(\(\(arrows = Map[AddArrow[#, 6] &, lines];\)\(\[IndentingNewLine]\)
    \) (*\ r1, r2\  : \ electrodes, \ r3 : \ dielectrics\ *) \), "\n", 
    \(r1 = Rectangle[{xl1, yd1}, {xr1, yu1}]; 
    r2 = Rectangle[{xl2, yd2}, {xr2, yu2}]; 
    r3 = Rectangle[{xl3, yd3}, {xr3, yu3}]; 
    r4 = Rectangle[{xl4, yd4}, {xr4, yu4}]; 
    r5 = {Line[{{exl, eyd}, {exl, eyu}}], Line[{{exl, eyu}, {exr, eyu}}], 
        Line[{{exr, eyu}, {exr, eyd}}], 
        Line[{{exr, eyd}, {exl, eyd}}]};\), "\n", 
    \(Show[Graphics[{GrayLevel[0.8], Thickness[0.015], r5}], cont, 
      Graphics[{lines, arrows, r1, r2, r3, 
          r4}], \[IndentingNewLine]ImageSize \[Rule] 400, Frame \[Rule] True, 
      DisplayFunction \[Rule] $DisplayFunction]\)}], "Input",
  CellLabel->"In[66]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  ContourGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[47]="],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000B`0002iA000`40O003h00Oogooogooogooogoo
]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOooo
OoooOoooOondOol005=oo`@00;1oo`H000ioo`@009aoo`X000]oo`@000ioo`@009Aoo`X000Uoo`H0
00ioo`@0095oo``000]oo`@000ioo`@0099oo``000Uoo`H000ioo`@008ioo`00DGoo2000[7oo2P00
2Woo2000VWoo2P002Goo20002Woo2000TWoo2P001goo2P002Woo2000Sgoo30002Goo20002Woo2000
T7oo30001goo2P002Woo2000S7oo001AOol20004Ool2002/Ool30005Ool30009Ool20004Ool2002N
Ool2000=Ool20004Ool2000:Ool20004Ool2002FOol2000;Ool30005Ool30009Ool20004Ool2002@
Ool30006Ool20009Ool20004Ool2000:Ool20004Ool2002AOol30006Ool20007Ool30005Ool30009
Ool20004Ool2002<Ool0051oo`8000Ioo`800;Aoo`8000Qoo`8000Ioo`8009eoo`8000aoo`8000Io
o`8000Qoo`8000Ioo`8009Eoo`8001Aoo`8000Qoo`8000Ioo`80091oo`<000moo`8000Ioo`8000Qo
o`8000Ioo`80095oo`<001Moo`8000Qoo`8000Ioo`8008]oo`00D7oo0P001Woo0P00]Goo0P001goo
0P001Woo0P00WGoo0P0037oo0P001Woo0P0027oo0P001Woo0P00UGoo0P005Goo0P001goo0P001Woo
0P00TGoo0`003Woo0P001Woo0P0027oo0P001Woo0P00TWoo0`005goo0P001goo0P001Woo0P00Rgoo
001?Ool20008Ool2002dOol20006Ool20008Ool2002LOol2000;Ool20008Ool20006Ool20008Ool2
002DOol2000EOol20006Ool20008Ool2002AOol3000<Ool20008Ool20006Ool20008Ool2002BOol3
000FOol20006Ool20008Ool2002:Ool004moo`8000Qoo`800;Aoo`8000Ioo`8000Qoo`8009aoo`80
00]oo`8000Qoo`8000Ioo`8000Qoo`8009Aoo`8001Eoo`8000Ioo`8000Qoo`80099oo`<000]oo`80
00Qoo`8000Ioo`8000Qoo`8009=oo`<001Eoo`8000Ioo`8000Qoo`8008Yoo`00Cgoo0P0027oo0P00
]7oo0P001Woo0P0027oo0P00W7oo0P002goo0P0027oo0P001Woo0P0027oo0P00U7oo0P005Goo0P00
1Woo0P0027oo0P00Tgoo0`002Woo0P0027oo0P001Woo0P0027oo0P00U7oo0`0057oo0P001Woo0P00
27oo0P00RWoo001?Ool20008Ool2002dOol20006Ool20008Ool2002LOol2000;Ool20008Ool20006
Ool20008Ool2002DOol2000EOol20006Ool20008Ool2002DOol30009Ool20008Ool20006Ool20008
Ool2002EOol3000COol20006Ool20008Ool2002:Ool004moo`8000Qoo`800;=oo`8000Moo`8000Qo
o`8009aoo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8009Aoo`8001Aoo`8000Moo`8000Qoo`8009Eo
o`<000Qoo`8000Qoo`8000Ioo`8000Qoo`8009Ioo`<0015oo`8000Moo`8000Qoo`8008Yoo`00Cgoo
0P0027oo0P00Zgoo0P001Goo0`001goo0P0027oo0P00W7oo0P002goo0P0027oo0P001Woo0P0027oo
0P00U7oo0P0037oo0P001Goo0`001goo0P0027oo0P00UWoo0P0027oo0P0027oo0P001Woo0P0027oo
0P00Ugoo0P002Goo0P001Goo0`001goo0P0027oo0P00RWoo001?Ool20008Ool2002[Ool90008Ool2
0008Ool2002LOol2000;Ool20008Ool20006Ool20008Ool2002DOol2000<Ool90008Ool20008Ool2
002GOol20007Ool20008Ool20006Ool20008Ool2002HOol20008Ool90008Ool20008Ool2002:Ool0
04moo`8000Qoo`800:]oo`800003Ool0000000<000Uoo`8000Qoo`8009aoo`8000]oo`8000Qoo`80
00Ioo`8000Qoo`8009Aoo`8000aoo`800003Ool0000000<000Uoo`8000Qoo`8009Moo`8000Moo`80
00Qoo`8000Ioo`8000Qoo`8009Qoo`8000Qoo`800003Ool0000000<000Uoo`8000Qoo`8008Yoo`00
D7oo0P001Woo0P00[7oo0P0047oo0P001Woo0P00WGoo0P0037oo0P001Woo0P0027oo0P001Woo0P00
UGoo0P0037oo0P0047oo0P001Woo0P00Sgoo0P001goo0P0027oo0P001Woo0P0027oo0P001Woo0P00
T7oo0P001goo0P0027oo0P0047oo0P001Woo0P00Rgoo001@Ool20006Ool2002/Ool2000@Ool20006
Ool2002MOol2000<Ool20006Ool20008Ool20006Ool2002EOol2000<Ool2000@Ool20006Ool2002?
Ool30006Ool20008Ool20006Ool20008Ool20006Ool2002@Ool30006Ool20008Ool2000@Ool20006
Ool2002;Ool0055oo`8000Aoo`800:eoo`80015oo`8000Aoo`8009Yoo`<00003Ool0000000eoo`80
00Aoo`8000Yoo`8000Aoo`80099oo`<00003Ool0000000aoo`80015oo`8000Aoo`80091oo`@000Ao
o`8000Yoo`8000Aoo`8000Yoo`8000Aoo`80095oo`@000Aoo`8000Uoo`80015oo`8000Aoo`8008ao
o`00DGoo2000[Goo2P002Goo2000VWoo1P003Goo20002Woo2000TWoo1P0037oo2P002Goo2000TGoo
20002goo20002Woo2000TWoo20002Woo2P002Goo2000S7oo001COol4002_Ool:000;Ool4002OOol3
000?Ool4000>Ool4002GOol3000<Ool:000;Ool4002EOol5000>Ool4000>Ool4002FOol5000;Ool:
000;Ool4002>Ool00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOond
Ool00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomo
oomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAo
o`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogoo
ogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo
003oOoooOoooOoooOondOol003Yoool00?l00?l00?l0074000Uoo`00>Woo00<007ooOol067oo00<0
07ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol097oo00<0
07ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<0
07ooOol08goo00<007ooOol08goo00<007ooOol097oo00<007ooOol08goo00<007ooOol08goo00<0
07ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<0
07ooOol097oo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<0
07ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol01goo000j
Ool00`00Oomoo`0HOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0S
Ool00`00Oomoo`0TOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0S
Ool00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`0S
Ool00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0S
Ool00`00Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0S
Ool00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0S
Ool00`00Oomoo`07Ool003Yoo`03001oogoo01Qoo`03001oogoo02=oo`03001oogoo02=oo`03001o
ogoo02=oo`03001oogoo02=oo`03001oogoo02Aoo`03001oogoo02=oo`03001oogoo02=oo`03001o
ogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001o
ogoo02Aoo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001o
ogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02Aoo`03001oogoo02=oo`03001o
ogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001o
ogoo02=oo`03001oogoo02=oo`03001oogoo00Moo`00>Woo00<007ooOol067oo00<007ooOol08goo
00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol097oo00<007ooOol08goo
00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo
00<007ooOol08goo00<007ooOol097oo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo
00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol097oo
00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo
00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol01goo000jOol00`00Oomo
o`0HOol00`00Oomoo`2lOol00`00Oomoo`2kOol00`00Oomoo`2lOol00`00Oomoo`2kOol00`00Oomo
o`2lOol00`00Oomoo`2EOol00`00Oomoo`07Ool003Yoo`03001oogoo01Qoo`03001oogoo0;aoo`03
001oogoo0;]oo`03001oogoo0;aoo`03001oogoo0;]oo`03001oogoo0;aoo`03001oogoo09Eoo`03
001oogoo00Moo`00>Woo00<007ooOol067oo00<007ooOol0_7oo00<007ooOol0^goo00<007ooOol0
_7oo00<007ooOol0^goo00<007ooOol0_7oo00<007ooOol0UGoo00<007ooOol01goo000jOol00`00
Oomoo`3oOoooOoooOoooOom]Ool00`00Oomoo`07Ool003Yoo`03001oogoo0?mooomooomooomoofeo
o`03001oogoo00Moo`008Goo10005Goo00<007ooOol0ogooogooogooogooKGoo00<007ooOol01goo
000OOol8000COol00`00Oomoo`3oOoooOoooOoooOom]Ool00`00Oomoo`07Ool001moo`8000Aoo`80
01=oo`03001oogoo0?mooomooomooomoofeoo`03001oogoo00Moo`007Woo0P001Woo0P004Woo00<0
07ooOol0ogooogooogooogooKGoo00<007ooOol01goo000NOol20006Ool2000BOol00`00Oomoo`3o
OoooOoooOoooOom]Ool00`00Oomoo`07Ool001eoo`8000Qoo`80015oo`03001oogoo0?mooomooomo
oomoofeoo`03001oogoo00Moo`007Goo0P0027oo0P004Goo00<007ooOol0ogooogooogooogooKGoo
00<007ooOol01goo000MOol20008Ool2000AOol8003oOoooOoooOoooOomQOol80009Ool001eoo`80
00Qoo`80015oo`03001oogoo01AooomW>OmW>OmW>OmW>F5W>@9oo`007Goo0P0027oo0P004Goo00<0
07ooOol057ooofLiofLiofLiofLiHFLi0Woo000MOol20008Ool2000AOol00`00Oomoo`0DOoooIcWo
IcWoIcWoIcUQIcT2Ool001eoo`8000Qoo`80015oo`03001oogoo01AooomW>OmW>OmW>OmW>F5W>@9o
o`007Goo0P0027oo0P004Goo00<007ooOol057ooofLiofLiofLiofLiHFLi0Woo000NOol20006Ool2
000BOol00`00Oomoo`0DOoooIcWoIcWoIcWoIcUQIcT2Ool001ioo`8000Ioo`80019oo`03001oogoo
01AooomW>OmW>OmW>OmW>F5W>@9oo`007goo0P0017oo0P004goo00<007ooOol057ooS6Li00<006Li
IcT0CVLi00<006LiIcT026Li00<006LiIcT03fLi00<006LiIcT01VLi00<006LiIcT05FLi00<006Li
IcT036Li00<006LiIcT01fLi00<006LiIcT03FLi00<006LiIcT01FLi00<006LiIcT01FLi00<006Li
IcT016Li00<006LiIcT01FLi00<006LiIcT016Li00<006LiIcT01FLi00<006LiIcT016Li00<006Li
IcT03fLi00<006LiIcT036Li00<006LiIcT08fLi00<006LiIcT016Li00<006LiIcT0ofLiofLiUFLi
0Woo000OOol8000COol00`00Oomoo`0DOon<IcT00`00IcUW>@1>IcT00`00IcUW>@08IcT00`00IcUW
>@07IcT00`00IcUW>@05IcT00`00IcUW>@06IcT00`00IcUW>@0EIcT00`00IcUW>@0<IcT00`00IcUW
>@07IcT00`00IcUW>@06IcT00`00IcUW>@04IcT00`00IcUW>@05IcT00`00IcUW>@05IcT00`00IcUW
>@04IcT00`00IcUW>@05IcT00`00IcUW>@04IcT00`00IcUW>@05IcT00`00IcUW>@04IcT00`00IcUW
>@05IcT00`00IcUW>@07IcT00`00IcUW>@0<IcT00`00IcUW>@0@IcT00`00IcUW>@0@IcT00`00IcUW
>@04IcT00`00IcUW>@0AIcT00`00IcUW>@0PIcT00`00IcUW>@3oIcWoIcUNIcT2Ool0025oo`@001Eo
o`03001oogoo01AoohaW>@03001W>FLi04iW>@03001W>FLi00QW>@03001W>FLi00MW>@03001W>FLi
00EW>@03001W>FLi00IW>@03001W>FLi01EW>@03001W>FLi00aW>@03001W>FLi00MW>@03001W>FLi
00IW>@03001W>FLi00AW>@03001W>FLi00EW>@03001W>FLi00EW>@03001W>FLi00AW>@03001W>FLi
00EW>@03001W>FLi00AW>@03001W>FLi00EW>@03001W>FLi00AW>@03001W>FLi00EW>@03001W>FLi
00MW>@03001W>FLi00]W>@03001W>FLi015W>@03001W>FLi011W>@03001W>FLi00AW>@03001W>FLi
015W>@03001W>FLi021W>@03001W>FLi0?mW>OmW>EiW>@9oo`00>Woo00<007ooOol057ooS6Li00<0
06LiIcT0CVLi00<006LiIcT026Li00<006LiIcT01fLi00<006LiIcT01FLi00<006LiIcT01fLi00<0
06LiIcT056Li00<006LiIcT036Li00<006LiIcT01fLi00<006LiIcT01VLi00<006LiIcT016Li00<0
06LiIcT01FLi00<006LiIcT01FLi00<006LiIcT016Li00<006LiIcT01FLi00<006LiIcT016Li00<0
06LiIcT01FLi00<006LiIcT016Li00<006LiIcT01FLi00<006LiIcT01fLi00<006LiIcT02fLi00<0
06LiIcT04FLi00<006LiIcT046Li00<006LiIcT016Li00<006LiIcT04FLi00<006LiIcT086Li00<0
06LiIcT0ofLiofLiGVLi0Woo000jOol00`00Oomoo`0DOon<IcT00`00IcUW>@1>IcT00`00IcUW>@08
IcT00`00IcUW>@07IcT00`00IcUW>@05IcT00`00IcUW>@07IcT00`00IcUW>@0DIcT00`00IcUW>@0<
IcT00`00IcUW>@07IcT00`00IcUW>@04IcU90007IcT00`00IcUW>@0;IcT00`00IcUW>@0AIcT00`00
IcUW>@0@IcT00`00IcUW>@04IcT00`00IcUW>@0AIcT00`00IcUW>@0PIcT00`00IcUW>@29IcU:003o
IcV:IcT2Ool003Yoo`03001oogoo01AoohaW>@03001W>FLi04iW>@03001W>FLi00QW>@03001W>FLi
00MW>@03001W>FLi00EW>@03001W>FLi00MW>@03001W>FLi01AW>@03001W>FLi00aW>@03001W>FLi
009W>@`0009W>@03001W>FLi00AW>@03001W>FLi00EW>@03001W>FLi00EW>@03001W>FLi00AW>@03
001W>FLi00EW>@03001W>FLi00AW>@03001W>FLi00EW>@03001W>FLi00AW>@03001W>FLi00EW>@03
001W>FLi00`000UW>@03001W>FLi015W>@03001W>FLi011W>@03001W>FLi00AW>@03001W>FLi015W
>@03001W>FLi021W>@03001W>FLi07iW>@/004YW>@/00?mW>GmW>@9oo`00>Woo00<007ooOol057oo
S6Li00<006LiIcT0CVLi00<006LiIcT026Li00<006LiIcT01fLi00<006LiIcT01FLi00<006LiIcT0
1fLi00<006LiIcT056Li00<006LiIcT02VLi1`001FLi00<006LiIcT01VLi00<006LiIcT016Li00<0
06LiIcT01FLi00<006LiIcT01FLi00<006LiIcT016Li00<006LiIcT01FLi00<006LiIcT016Li00<0
06LiIcT01FLi00<006LiIcT016Li00<006LiIcT01FLi00<006LiIcT01fLi00<006LiIcT00VLi1`00
0VLi00<006LiIcT04FLi00<006LiIcT046Li00<006LiIcT016Li00<006LiIcT04FLi00<006LiIcT0
86Li00<006LiIcT0MVLi2000H6Li2000ofLiMfLi0Woo000jOol00`00Oomoo`0DOon<IcT00`00IcUW
>@1>IcT00`00IcUW>@09IcT00`00IcUW>@06IcT00`00IcUW>@05IcT00`00IcUW>@07IcT00`00IcUW
>@0DIcT00`00IcUW>@06IcT40002IcT00`00IcUW>@07IcT00`00IcUW>@06IcT00`00IcUW>@04IcT0
0`00IcUW>@05IcT00`00IcUW>@05IcT00`00IcUW>@04IcT00`00IcUW>@05IcT00`00IcUW>@04IcT0
0`00IcUW>@05IcT00`00IcUW>@04IcT00`00IcUW>@05IcT00`00IcUW>@07IcT00`00IcUW>@09IcT4
000BIcT00`00IcUW>@0@IcT00`00IcUW>@04IcT00`00IcUW>@0AIcT00`00IcUW>@0PIcT00`00IcUW
>@1bIcT4001`IcT4003oIcUcIcT2Ool003Yoo`03001oogoo01AoohaW>@03001W>FLi04iW>@03001W
>FLi00UW>@03001W>FLi00IW>@03001W>FLi00EW>@03001W>FLi00MW>@03001W>FLi01AW>@03001W
>FLi009W>@@000IW>@03001W>FLi00MW>@03001W>FLi00IW>@03001W>FLi00AW>@03001W>FLi00EW
>@03001W>FLi00EW>@03001W>FLi00AW>@03001W>FLi00EW>@03001W>FLi00AW>@03001W>FLi00EW
>@03001W>FLi00AW>@03001W>FLi00EW>@03001W>FLi00MW>@03001W>FLi00]W>@03001W>@0000@0
00eW>@03001W>FLi011W>@03001W>FLi00AW>@03001W>FLi015W>@03001W>FLi021W>@03001W>FLi
06iW>@@007QW>@@00?mW>FmW>@9oo`00>Woo00<007ooOol057oo46LiO7oo00<007ooOol0CWoo00<0
07ooOol02Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01goo00<007ooOol057oo1@00
2Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01goo00<007ooOol02goo00<007ooOol017oo0`002Woo00<0
07ooOol047oo00<007ooOol017oo00<007ooOol04Goo00<007ooOol087oo00<007ooOol0Jgoo0`00
P7oo0`00ogooI7oo00<007ooOol01goo000jOol00`00Oomoo`0DOol@IcUlOol00`00Oomoo`1>Ool0
0`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`0BOol3
000>Ool00`00Oomoo`07Ool20007Ool00`00Oomoo`02Oolk0004Ool00`00Oomoo`07Ool00`00Oomo
o`0;Ool00`00Oomoo`07Ool30007Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool00`00Oomoo`0AOol0
0`00Oomoo`0POol00`00Oomoo`1XOol3000VOolj000VOol3003oOomQOol00`00Oomoo`07Ool003Yo
o`03001oogoo01Aooa1W>Gaoo`03001oogoo04ioo`03001oogoo00Uoo`03001oogoo00Ioo`03001o
ogoo00Eoo`03001oogoo00Moo`03001oogoo011oo`80009oo`03001oogoo00aoo`03001oogoo00Qo
o`03001oogoo00=oo`L0009oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogooOol70007Ool0
0`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool0
0`00Oomoo`0AOol00`00Oomoo`0POol00`00Oomoo`1VOol2000QOol8000jOol8000QOol2003oOomO
Ool00`00Oomoo`07Ool003Yoo`03001oogoo01Aooa1W>Gaoo`03001oogoo04ioo`03001oogoo00Uo
o`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00ioo`8000Aoo`03001o
ogoo00aoo`03001oogoo00Qoo`03001oo`0000<0009oo`03001oogoo00Eoo`03001oogoo00Aoo`03
001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00@000=oo`03001oogoo00]oo`03001oogoo00]o
o`8000Aoo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo015oo`03001oogoo021oo`03001o
ogoo06Aoo`8001moo`@004Yoo`@001moo`800?mooeeoo`03001oogoo00Moo`00>Woo00<007ooOol0
57oo46LiO7oo00<007ooOol0Cgoo00<007ooOol027oo00<007ooOol01goo00<007ooOol017oo00<0
07ooOol01goo00<007ooOol03Goo00<007ooOol017oo00<007ooOol03Goo00<007ooOol01Goo1000
1Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
17oo10003Goo00<007ooOol03Goo0P000Woo00<007ooOol03goo00<007ooOol01Goo00<007ooOol0
4Goo00<007ooOol087oo00<007ooOol0HWoo0P007Woo0`00DWoo0`007Woo0P00ogooFgoo00<007oo
Ool01goo000jOol00`00Oomoo`0DOol@IcUlOol00`00Oomoo`1?Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool20007Ool00`00Oomoo`0=Ool0
1000Oomoogoo10000Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01goo1@002Goo00<007ooOol03goo0`004Goo00<007ooOol0
17oo00<007ooOol04Goo00<007ooOol08Goo00<007ooOol0H7oo0P0077oo1000F7oo100077oo0P00
ogooFGoo00<007ooOol01goo000jOol00`00Oomoo`0DOol@IcUlOol00`00Oomoo`1?Ool00`00Oomo
o`08Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`09Ool20009Ool0
0`00Oomoo`0=Ool40006Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20007Ool00`00Oomoo`0AOol2
000@Ool00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`0QOol00`00Oomoo`1NOol2000KOol3
001POol3000KOol00`00Oomoo`3oOomFOol00`00Oomoo`07Ool003Yoo`03001oogoo01Aooa1W>Gao
o`03001oogoo04moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Mo
o`03001oogoo00Ioo`8000aoo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oo`0003000003Ool007oo00Ioo`03001oogoo00Moo`03001oogoo00Aoo`8000Eo
o`03001oogoo011oo`03001oogoo008000ioo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo
025oo`03001oogoo05eoo`03001oogoo01Uoo`8001]ooc4001Yoo`8001Yoo`800?mooeIoo`03001o
ogoo00Moo`00>Woo00<007ooOol057oo46LiO7oo00<007ooOol0Cgoo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol017oo0P003Woo00<007ooOol02Woo
0`002Goo00<007ooOol01Goo00<007oo00001`001Goo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol00goo200000=oo`00Ool027oo
00<007ooOol01Woo0P000goo00<007ooOol047oo00<007ooOol00Woo0P0037oo00<007ooOol017oo
00<007ooOol04Goo00<007ooOol08Goo00<007ooOol0Fgoo0P006Woo0P0057oo2@00<Goo200057oo
0P006Woo0P00ogooE7oo00<007ooOol01goo000jOol00`00Oomoo`0DOol@IcUlOol00`00Oomoo`1?
Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool2000@Ool00`00Oomoo`08Ool20002Ool00`00Oomoo`07Ool00`00Oomoo`03Ool40006Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool40007Ool00`00Oomoo`08Ool3000COol00`00
Oomoo`04Ool2000:Ool00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`0QOol00`00Oomoo`1I
Ool2000JOol2000BOol40012Ool4000BOol2000JOol2003oOomBOol00`00Oomoo`07Ool003Yoo`03
001oogoo01Aooa1W>Geoo`03001oogoo04ioo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo
00Eoo`03001oogoo00Moo`05001oogooOol0000BOol00`00Oomoo`06Ool20004Ool00`00Oomoo`07
Ool00`00Oomoo`030002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Oomoo`030004Ool00`00Oomoo`0:Ool2000BOol00`00Oomoo`06Ool00`00Oomoo`07
Ool00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`0QOol00`00Oomoo`1HOol00`00Oomoo`0H
Ool2000AOol3001:Ool3000AOol2000JOol00`00Oomoo`3oOom?Ool00`00Oomoo`07Ool003Yoo`03
001oogoo01Aooa1W>Geoo`03001oogoo04ioo`03001oogoo00Uoo`03001oogoo00Ioo`8000Ioo`03
001oogoo00Moo`04001oogoo000COol00`00Oomoo`04Ool20006Ool00`00Oomoo`07Ool30005Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`03Ool2
0002Ool00`00Oomoo`0:Ool01000Ool0000047oo00<007ooOol01goo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol04Goo00<007ooOol08Goo00<007ooOol0Egoo00<007ooOol05goo0P004Goo
0P00D7oo00<007ooOol047oo00<007ooOol067oo00<007ooOol0ogooCWoo00<007ooOol01goo000j
Ool00`00Oomoo`0DOol@IcUmOol00`00Oomoo`1?Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00
Oomoo`04Ool00`00Oomoo`07Ool3000DOol00`00Oomoo`02Ool20008Ool00`00Oomoo`05Ool30007
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05OolG0007Ool00`00Oomoo`04Ool00`00
Oomoo`05Ool00`00Oomoo`05Ool3000<Ool01000Oomoogoo0P003Woo00<007ooOol027oo00<007oo
Ool017oo00<007ooOol017oo0P004goo00<007ooOol08Goo00<007ooOol0EGoo0P006Goo00<007oo
Ool03goo0P0087oo50007goo0`0047oo0P006Goo0P00ogooCWoo00<007ooOol01goo000jOol00`00
Oomoo`0DOol@IcUmOol00`00Oomoo`1?Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`04
Ool20008Ool2000EOol01@00Oomoogoo00002Woo0P000goo0`000Woo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol00Woo2`001Woo00<007ooOol01Goo00<007ooOol017oo2`0017oo00<007oo
Ool01Goo00<007ooOol01Woo00@007oo000000Yoo`03001oogoo00=oo`03001oogoo00]oo`03001o
ogoo00Uoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo025oo`03001o
ogoo05Aoo`03001oogoo01Qoo`03001oogoo00eoo`<001Moo`/001Aoo`/001Moo`<000moo`03001o
ogoo01Qoo`03001oogoo0?mood]oo`03001oogoo00Moo`00>Woo00<007ooOol057oo46LiOGoo00<0
07ooOol0Cgoo00<007ooOol027oo00<007ooOol01goo00<007ooOol01Goo00<007ooOol01Goo00<0
07oo00005Woo00<007oo000037oo00@007ooOol000Eoo`03001oogoo00Eoo`03001oogoo009oo`P0
009oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00P000Aoo`03001oogoo00Ioo`05001oogooOol00009Ool00`00Oomoo`04Ool0
0`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0AOol0
0`00Oomoo`0ROol00`00Oomoo`1COol00`00Oomoo`0HOol00`00Oomoo`0=Ool00`00Oomoo`0@Ool8
000ZOol8000BOol00`00Oomoo`0=Ool00`00Oomoo`0HOol00`00Oomoo`3oOom:Ool00`00Oomoo`07
Ool003Yoo`03001oogoo01Aooa1W>Geoo`03001oogoo04moo`03001oogoo00Uoo`03001oogoo00Io
o`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo000FOol2000=Ool00`00Ool00006Ool20006
Ool00`00Ool000020003Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoogoo0`0000=oo`00
Ool01goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol027oo00<007oo
Ool037oo0P000Woo00<007ooOol017oo00<007ooOol04Goo00<007ooOol08Woo00<007ooOol0DWoo
00<007ooOol067oo00<007ooOol03Goo00<007ooOol03Goo1000>Woo10003goo00<007ooOol03Goo
00<007ooOol067oo00<007ooOol0ogooBGoo00<007ooOol01goo000jOol00`00Oomoo`0DOol@IcUm
Ool00`00Oomoo`1?Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`005Woo00<007ooOol037oo0P0027oo00<007ooOol00Woo10001Woo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol017oo10001Woo00<007ooOol00goo0`0017oo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol03Woo0`001Woo00<007ooOol04Goo00<007ooOol08Woo00<0
07ooOol0DGoo00<007ooOol067oo00<007ooOol02goo0`0037oo1000@Woo100037oo0`003Goo00<0
07ooOol067oo00<007ooOol0ogooB7oo00<007ooOol01goo000jOol00`00Oomoo`0DOol@IcUmOol0
0`00Oomoo`1?Ool2000:Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`03Ool01@00Oomo
ogoo00005Goo0P003Goo0P002Goo00<007oo00000P000Woo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol017oo00@007ooOomoo`<000=oo`03001oogoo00Ioo`05001oogoo
Ool0000:Ool00`00Oomoo`06Ool00`00Oomoo`0>Ool20007Ool00`00Oomoo`0AOol00`00Oomoo`0R
Ool00`00Oomoo`1@Ool00`00Oomoo`0HOol00`00Oomoo`0;Ool00`00Oomoo`0:Ool3001:Ool3000<
Ool00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`3oOom7Ool00`00Oomoo`07Ool003Yoo`03
001oogoo01Aooa1W>Geoo`03001oogoo051oo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo
00Aoo`03001oogoo009oo`03001oogoo009oo`8001=oo`03001oo`0000aoo`03001oo`0000Uoo`80
00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00EooaL000Moo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00Aoo`800003Ool007oo00Qoo`04001oogoo000;Ool00`00Oomoo`04
Ool2000AOol00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`0ROol00`00Oomoo`1?Ool00`00
Oomoo`0HOol00`00Oomoo`0;Ool00`00Oomoo`09Ool2000NOolD000NOol00`00Oomoo`0:Ool00`00
Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`3oOom6Ool00`00Oomoo`07Ool003Yoo`03001oogoo
01Aooa1W>Geoo`03001oogoo051oo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Eoo`04
001oogoo0006Ool00`00Oomoo`0@Ool00`00Oomoo`02000:Ool01000Oomoo`001goo0`001goo00<0
07ooOol017oo00<007ooOol00Woo2`001Woo00<007ooOol01Goo00<007ooOol017oo2`0017oo00<0
07ooOol017oo00<007ooOol01Woo0P002Woo00<007oo000037oo00<007ooOol00goo00<007ooOol0
47oo0P001Goo00<007ooOol04Woo00<007ooOol08Woo00<007ooOol0CWoo00<007ooOol067oo00<0
07ooOol02goo00<007ooOol02Goo00<007ooOol04goo2`0057oo2`0057oo0P002goo00<007ooOol0
2goo00<007ooOol067oo00<007ooOol0ogooAGoo00<007ooOol01goo000jOol00`00Oomoo`0DOol@
IcUnOol00`00Oomoo`1?Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`05Ool01000Oomo
o`001Woo00<007ooOol03goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00Woo00<007oo
Ool00goo00@007ooOol000Moo`04001oogooOol80002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`080003Ool00`00Oomoo`07
Ool2000:Ool2000<Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool00`00Ool00004Ool00`00Oomoo`0A
Ool00`00Oomoo`0SOol00`00Oomoo`1=Ool00`00Oomoo`0HOol00`00Oomoo`0;Ool00`00Oomoo`09
Ool00`00Oomoo`0<Ool8000ZOol8000>Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`0G
Ool00`00Oomoo`3oOom5Ool00`00Oomoo`07Ool003Yoo`03001oogoo01Aooa1W>Gioo`03001oogoo
04moo`03001oogoo00Uoo`03001oogoo00Ioo`8000Ioo`03001oo`0000Moo`03001oogoo00ioo`03
001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00007
Ool40003Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoogoo0P0000=oo`00Ool01goo00@0
07ooOol000Uoo`8000eoo`03001oogoo009oo`03001oogoo00moo`05001oogooOol00003Ool00`00
Oomoo`0AOol00`00Oomoo`0SOol00`00Oomoo`1<Ool00`00Oomoo`0HOol00`00Oomoo`0;Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool3000jOol3000<Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00
Oomoo`0GOol00`00Oomoo`3oOom4Ool00`00Oomoo`07Ool003Yoo`03001oogoo01Aooa1W>Gioo`03
001oogoo04moo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Aoo`8000Qoo`03001oogoo
00eoo`03001oogoo00Aoo`03001oogoo00Aoo`8000Ioo`03001oogoo008000Aoo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00=oo`8000Qoo`04001o
ogooOol20007Ool01000Ool0000037oo00D007ooOomoo`00015oo`03001oogoo009oo`03001oo`00
01Aoo`03001oogoo02=oo`03001oogoo04]oo`03001oogoo01Qoo`03001oogoo00]oo`03001oogoo
00Qoo`8000]oo`80041oo`8000]oo`8000Yoo`03001oogoo00]oo`03001oogoo01Moo`03001oogoo
0?mood=oo`03001oogoo00Moo`00>Woo00<007ooOol057oo46LiOWoo00<007ooOol0D7oo00<007oo
Ool027oo00<007ooOol01goo00<007ooOol017oo0P002Goo00<007ooOol02goo00<007ooOol01Woo
00<007ooOol00Woo00<007ooOol01Woo00<007oo00001Woo00<007ooOol00Woo10001Woo00<007oo
Ool017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007oo
Ool017oo00<007ooOol01Goo00<007ooOol017oo10001Goo00<007ooOol00goo00<007ooOol017oo
00D007ooOomoo`0000aoo`03001oo`00019oo`03001oogoo00=oo`8001Aoo`03001oogoo029oo`03
001oogoo04]oo`03001oogoo01Qoo`03001oogoo00]oo`03001oogoo00Moo`8000Yoo`<004Aoo`<0
00Yoo`8000Uoo`03001oogoo00]oo`03001oogoo01Moo`03001oogoo0?mood9oo`03001oogoo00Mo
o`00>Woo1@004Woo46LiOWoo00<007ooOol0D7oo00<007ooOol027oo00<007ooOol01goo00<007oo
Ool00Woo0P0000=oo`00Ool027oo00<007ooOol02goo00<007ooOol01Woo00D007ooOomoo`0000Uo
o`8000Moo`03001oo`00008000=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=ooa`0
00=oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogooOol30002Ool00`00Oomoo`04Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool2000BOol00`00Oomoo`04Ool00`00Oomoo`0B
Ool00`00Oomoo`0ROol00`00Oomoo`1:Ool00`00Oomoo`0HOol00`00Oomoo`0;Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool3000GOolL000GOol2000:Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00
Oomoo`0GOol00`00Oomoo`3oOollOol60009Ool003Yoo`03001oogoo01Aooa1W>Gioo`03001oogoo
051oo`03001oogoo00Uoo`03001oogoo00Moo`05001oogooOol00002Ool01000Oomoo`001Woo00<0
07oo00002goo00<007ooOol01Woo00D007oo001oo`0000Uoo`8000Qoo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo009oo`P0009oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Ao
o`04001oogooOol70004Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Ool00006Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01000Ool000003Woo00@007ooOol000Aoo`04001o
ogoo000COol00`00Oomoo`0SOol00`00Oomoo`1:Ool00`00Oomoo`0HOol00`00Oomoo`0:Ool00`00
Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`0AOol7000LOol7000BOol00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`0GOol00`00Oomoo`3oOom1Ool00`00Oomoo`07Ool0
03Yoo`03001oogoo01Aooa1W>Gmoo`03001oogoo04moo`800003Ool007oo00Moo`8000Qoo`04001o
o`000004Ool00`00Ool00007Ool2000:Ool00`00Oomoo`07Ool01000Ool000002Woo0P001goo0P00
1Woo00<007ooOol017oo1@000Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol017oo00@007ooOomoo`D000Ioo`03001oogoo00Eoo`8000Moo`05001o
o`00Ool00006Ool00`00Oomoo`07Ool01000Ool000003Woo00@007ooOol000Aoo`05001oo`00Ool0
000?Ool01000Oomoo`009Goo00<007ooOol0BGoo00<007ooOol067oo00<007ooOol02Woo00<007oo
Ool027oo00<007ooOol01Woo00<007ooOol03Woo1000:Woo10003goo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol02goo00<007ooOol05goo00<007ooOol0ogoo@7oo00<007ooOol01goo000j
Ool00`00Oomoo`0DOol@IcUoOol00`00Oomoo`1@Ool00`00Ool00008Ool20008Ool00`00Ool00002
Ool01P00Oomoo`00Ool000Moo`8000Uoo`03001oogoo00Eoo`04001oogooOol30009Ool00`00Ool0
0005Ool200000goo001oo`05Ool01000Oomoogoo10001Woo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo10000goo00<007oo
Ool01Woo0P001goo0P0000=oo`00Ool01Goo00<007ooOol01goo00L007oo001oo`00Ool0000;Ool0
1000Oomoo`0017oo00<007oo00000Woo0P003Goo00@007ooOol002Eoo`03001oogoo04Qoo`03001o
ogoo01Qoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00]oo`@0039o
o`@000aoo`8000Qoo`03001oogoo00Ioo`03001oogoo00aoo`03001oogoo01Moo`03001oogoo0?mo
ocmoo`03001oogoo00Moo`00>Woo00<007ooOol057oo46LiOgoo00<007oo0000C7oo00L007ooOomo
o`00Ool00009Ool00`00Oomoo`06Ool30002Ool2000017oo001oo`000Woo0P000goo0`0027oo00<0
07ooOol01Goo0P000Woo0P002Goo00@007ooOol0009oo`03001oo`0000=oo`03001oogoo00Aoo`@0
00=oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo009oo`@000Moo`04001oogoo0007Ool0
0`00Ool00003Ool01@00Oomoogoo000027oo00@007oo001oo`<000]oo`05001oogoo001oo`020000
1Goo001oo`00Ool00`003Goo00@007oo0000009oo`03001oogoo021oo`03001oogoo04Moo`03001o
ogoo01Uoo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Qoo`@003Yo
o`@000Yoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo01Moo`03001o
ogoo0?moocmoo`03001oogoo00Moo`00>Woo00<007ooOol057oo46LiNgoo00L007ooOomoo`00Ool0
001<Ool20002Ool00`00Ool00004Ool20003Ool20003Ool20003Ool20003Ool60002Ool20003Ool2
0007Ool00`00Oomoo`07Ool2000017oo000000001goo0P000Woo00<007ooOol00P0017oo00<007oo
Ool00Woo0`001Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo0`000Woo00@007oo
Ool000=oo`03001oogoo00Aoo`<0009oo`8000Aoo`03001oogoo00Aoo`@00003Ool0000000aoo`<0
0005Ool00000001oo`07000=Ool00`00Ool00002Ool2000ROol00`00Oomoo`17Ool00`00Oomoo`0H
Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool30012Ool30008
Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0GOol00`00Oomoo`3o
OolnOol00`00Oomoo`07Ool003Yoo`03001oogoo01Aooa1W>G]oo`80009oo`03001oo`0004eoo`80
009oo`<000=oo`<0009oo`8000=oo`<0009oo`<000=oo`D000=oo`<00003Ool0000000Moo`03001o
ogoo00Qoo`D000Moo`80009oo`@000=oo`03001oo`00009oo`<00003Ool007oo009oo`04001oogoo
0002Ool00`00Ool00002OolU0003Ool01000Oomoo`001goo00<007ooOol00`000Woo00H007ooOol0
07oo0005Ool20002Ool20005Ool00`00Oomoo`04Ool3000017oo0000000037oo1P000Woo1@000Woo
00<007ooOol02Woo0`0000=oo`0000008Goo00<007oo0000B7oo00<007ooOol06Goo00<007ooOol0
2Woo00<007ooOol01goo00<007ooOol01Goo00<007ooOol01Goo0P004Woo90004Woo0P001goo00<0
07ooOol01Goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol05goo00<007ooOol0ogoo?Woo
00<007ooOol01goo000jOol00`00Oomoo`0DOol@IcUlOol2000017oo001oo`00CWoo0P0000Aoo`00
000000Aoo`<00003Ool0000000Aoo`@00003Ool0000000=oo`D000Aoo`D000Ioo`03001oogoo00Uo
o`D000Ioo`04001oogoo0002Ool30003Ool01P00Ool007oo001oo`800003Ool007oo009oo`08001o
ogooOol007oo001oo`@0009oo`80009oo`03001oogoo0080009oo`06001oogoo001oo`000Woo00<0
07ooOol00P000Woo00L007ooOol007oo001oo`050002Ool02000Oomoo`00Ool007oo0005Ool01000
Oomoo`000Woo00<007oo00001Goo1@001goo00<007ooOol00goo1@000Woo00<007ooOol02Goo1@00
0goo1@000goo00<007ooOol02Goo1@008Woo00<007oo00000goo00<007ooOol0@Woo00<007ooOol0
67oo00<007ooOol02goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
3goo0`0097oo0`004Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol0
2goo00<007ooOol05goo00<007ooOol0ogoo?Goo00<007ooOol01goo000jOol00`00Oomoo`0DOol@
IcUlOol300000goo0000001?Ool50005Ool50005Ool60004Ool40005Ool50004Ool00`00Oomoo`0:
Ool50005Ool01000Oomoogoo0P0000Aoo`00000000Aoo`04001oo`00Ool400000goo001oo`030002
Ool600000goo001oo`0400000goo001oo`0400000goo001oo`0200001Goo001oogoo00000Woo0P00
0Woo00D007ooOol007oo00<0009oo`D0009oo`05001oo`00Ool00003Ool02000Ool00000Ool007oo
0003Ool00`00Oomoo`02Ool50008Ool00`00Oomoo`02Ool40004Ool00`00Oomoo`07Ool60002Ool5
0004Ool00`00Oomoo`09Ool5000ROol30003Ool00`00Oomoo`12Ool00`00Oomoo`0HOol00`00Oomo
o`0:Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool4000ZOol4
000>Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomo
o`0GOol00`00Oomoo`3oOolmOol00`00Oomoo`07Ool003Yoo`03001oogoo01Aooa1W>Geoo`D0051o
o`@000Ioo`D000Eoo`D000Eoo`<000Ioo`@000=oo`03001oogoo00]oo`03001oo`00008000Aoo`03
001oogoo00=oo`D000Aoo`<00008Ool00000Ool007oo001oo`P0009oo`05001oo`00Ool00002Ool0
1@00Ool007oo00000Woo00D007oo001oo`00009oo`800003Ool007oo00@00003Ool007oo00800005
Ool00000001oo`0400000goo000000060003Ool00`00Ool000050004Ool00`00Oomoo`060008Ool0
0`00Oomoo`02Ool40005Ool00`00Oomoo`06Ool50003Ool40006Ool00`00Oomoo`07Ool5000SOol3
0002Ool00`00Oomoo`12Ool00`00Oomoo`0HOol00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool2000;Ool4000bOol5000:Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0GOol00`00Oomoo`3oOollOol00`00Oomoo`07
Ool003Yoo`03001oogoo01Aooa1W>Geoo`D0051oo`@000Moo`@000Eoo`D000Ioo`8000Moo`<000=o
o`03001oogoo00]oo`03001oogoo008000=oo`03001oogoo00Aoo`D000=oo`@00004Ool007ooOol5
000017oo000007oo0P000goo1@000Woo1@000Woo1@000goo00D007oo001oo`00009oo`05001oo`00
Ool00003Ool200002Goo000007oo001oo`00Ool00002Ool30002Ool00`00Oomoo`0200000goo0000
0006Ool00`00Ool000030002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool30006Ool00`00Oomoo`06
Ool40004Ool30008Ool00`00Oomoo`06Ool4000TOol300000goo00000013Ool00`00Oomoo`0HOol0
0`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`07Ool4
000kOol30008Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool0
0`00Oomoo`0GOol00`00Oomoo`3oOollOol00`00Oomoo`07Ool003Yoo`03001oogoo01Aooa1W>Gio
o`@0055oo`<000Qoo`<000Aoo`03001oogoo00<000Ioo`<000Moo`80009oo`03001oogoo00]oo`04
001oogooOol30002Ool00`00Oomoo`04Ool50002Ool00`00Oomoo`0400000goo000000040002Ool4
0003Ool50002Ool50002Ool50003Ool50002Ool50003Ool40002Ool50002Ool60002Ool60005Ool0
0`00Ool000030002Ool00`00Oomoo`06Ool00`00Oomoo`030008Ool00`00Oomoo`05Ool30005Ool3
0008Ool00`00Oomoo`06Ool3000UOol50014Ool00`00Oomoo`0GOol00`00Oomoo`0;Ool00`00Oomo
o`06Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool30012Ool30006Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0GOol00`00Oomo
o`3oOolkOol00`00Oomoo`07Ool003Yoo`03001oogoo01Aooa1W>Gmoo`<0059oo`<000Qoo`<0009o
o`03001oogoo009oo`<000Ioo`8000Qoo`800003Ool007oo00]oo`03001oogoo00=oo`800003Ool0
07oo00Eoo`03001oogoo00<00003Ool007oo009oo`D00003Ool0000000<0009oo`@000=oobT0009o
o`D0009oo`D00004Ool007ooOol30002Ool00`00Oomoo`03Ool40004Ool00`00Oomoo`06Ool01000
Ool000002Goo00<007ooOol01Goo0`001Goo0P002Woo00<007ooOol01Goo0`009Goo1@00@goo00<0
07ooOol067oo00<007ooOol02goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol017oo00<007ooOol047oo90004Woo00<007ooOol017oo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol067oo00<007ooOol0ogoo>Woo00<007oo
Ool01goo000jOol00`00Oomoo`0DOol@IcUoOol3001COol20009Ool20002Ool00`00Oomoo`03Ool2
0007Ool00`00Oomoo`07Ool00`00Ool0000<Ool00`00Oomoo`04Ool00`00Ool00006Ool00`00Oomo
o`040004Ool40003Ool30003Ool;0004Ool30004Ool30004Ool50002Ool50003Ool;0002Ool50002
Ool00`00Ool000020003Ool00`00Oomoo`03Ool30004Ool00`00Oomoo`06Ool01000Ool000002Woo
00<007ooOol017oo0P001Woo00<007ooOol02Goo00<007ooOol01Goo0P009goo0`00A7oo00<007oo
Ool05goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol017oo00<007oo
Ool017oo00<007ooOol02Woo1`0097oo1`0037oo00<007ooOol017oo00<007ooOol017oo00<007oo
Ool017oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol067oo00<007ooOol0ogoo>Woo00<0
07ooOol01goo000jOol00`00Oomoo`0DOol@IcV0Ool2001COol2000:Ool30007Ool00`00Oomoo`05
Ool00`00Oomoo`07Ool2000<Ool00`00Oomoo`05Ool20006Ool00`00Oomoo`02Ool20006Ool30003
Ool30002Ool50004Ool30004Ool30004Ool30005Ool30004Ool30004Ool30004Ool50002Ool30004
Ool40004Ool00`00Oomoo`02Ool20006Ool00`00Oomoo`06Ool2000;Ool00`00Oomoo`04Ool00`00
Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0VOol30013Ool00`00Oomoo`0H
Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool2000:Ool3000bOol3000:Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00
Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0HOol00`00Oomoo`3oOoliOol00`00Oomoo`07Ool0
03Yoo`03001oogoo01Aooa1W>H1oo`8005Aoo`03001oogoo00Uoo`8000Qoo`03001oogoo00Aoo`80
00Uoo`03001oogoo00Uoo`03001oogoo00Ioo`8000Ioo`03001oogoo009oo`8000Eoo`@000=oo`D0
009oo`<000Aoo`<000Aoo`<000Aoo`<000Eoo`<000Aoo`<000Aoo`<000Aoo`<0009oo`03001oo`00
008000Eoo`8000Eoo`03001oogoo009oo`8000Moo`03001oogoo00Ioo`03001oogoo00Yoo`03001o
ogoo009oo`03001oogoo00Aoo`8000eoo`03001oogoo00Aoo`03001oogoo02Ioo`<0049oo`03001o
ogoo01Uoo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo00Qoo`8003Qoo`8000Uoo`03001oogoo00Aoo`03001oogoo00=oo`03001o
ogoo00Aoo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo01Moo`03001oogoo0?moocUoo`03
001oogoo00Moo`00>Woo00<007ooOol057oo46LiPGoo00<007ooOol0DWoo00<007ooOol02Goo0P00
27oo00<007ooOol01Goo00<007ooOol01goo00<007ooOol02Goo00<007ooOol01Woo0P001Goo00<0
07ooOol00goo0P0017oo00@007oo000000Aoo`<000Aoo`8000Eoo`<000Aoo`<000Aoo`<000Eoo`<0
00Aoo`<000Eoo`8000Aoo`<000=oo`@000Eoo`<000Eoo`04001oogoo0002Ool00`00Oomoo`04Ool0
0`00Oomoo`05Ool2000<Ool01000Oomoogoo0P001Woo00<007ooOol037oo00<007ooOol00goo0P00
:7oo0P00@goo00<007ooOol067oo00<007ooOol02goo00<007ooOol01Woo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol00goo00<007ooOol01goo0P00?7oo0`001goo00<007ooOol017oo00<0
07ooOol00goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol05goo00<0
07ooOol0ogoo>Goo00<007ooOol01goo000jOol00`00Oomoo`0DOol@IcV1Ool2001DOol00`00Oomo
o`08Ool20009Ool00`00Oomoo`05Ool00`00Oomoo`05Ool30009Ool00`00Oomoo`06Ool01000Oomo
o`000goo00<007ooOol00goo00<007oo00000goo00D007ooOomoo`00009oo`@000Ioo`03001oogoo
00Aoo`03001oogoo00AooaP000Eoo`03001oogoo00=oo`<000Aoo`D000=oo`04001oogoo0005Ool0
0`00Ool00003Ool00`00Oomoo`04Ool00`00Oomoo`03Ool200000goo001oo`0;Ool01000Oomoo`00
1goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol09goo0P00@Woo00<007ooOol06Goo00<0
07ooOol02Woo00<007ooOol01Goo0P001Goo00<007ooOol00goo00<007ooOol00goo00<007ooOol0
17oo10005Woo50005goo0`001Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol017oo00<0
07ooOol01Woo00<007ooOol02Woo00<007ooOol05goo00<007ooOol0ogoo>7oo00<007ooOol01goo
000jOol00`00Oomoo`0DOol@IcV2Ool00`00Oomoo`1BOol20009Ool20009Ool20006Ool00`00Oomo
o`05Ool00`00Ool00009Ool00`00Oomoo`06Ool01000Oomoo`000goo00<007ooOol00Woo00D007oo
Oomoo`00009oo`07001oogooOol007oo00000goo00<007ooOol017oo00@007ooOomoo`/000Ioo`03
001oogoo00Eoo`03001oogoo00Aoo`/000=oo`03001oogoo00=oo`8000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool00`00Ool00003Ool00`00Oomoo`04Ool00`00Oomoo`03Ool01000Oomoo`0037oo
00@007ooOol000Ioo`03001oogoo00ioo`03001oogoo009oo`03001oogoo02Moo`03001oogoo045o
o`03001oogoo01Uoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00=o
o`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00eoo`/001Aoo`/000moo`03001oogoo009o
o`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Yo
o`03001oogoo01Moo`03001oogoo0?moocQoo`03001oogoo00Moo`00>Woo00<007ooOol057oo46Li
PWoo00<007ooOol0Dgoo00<007ooOol01Woo00@007ooOol000Uoo`03001oogoo00Eoo`03001oogoo
00=oo`05001oogooOol00007Ool00`00Oomoo`06Ool01000Oomoogoo0P0000=oo`00Ool00goo00<0
07ooOol00Woo00<007oo000017oo0P001Goo00<007ooOol00goo10000goo00<007ooOol017oo00<0
07ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00@007ooOomoo`@000Eo
o`03001oogoo00=oo`03001oo`0000=oo`03001oogoo00=oo`8000Aoo`03001oogoo00Aoo`04001o
ogooOol20002Ool00`00Oomoo`0;Ool20006Ool2000AOol01000Oomoo`00:Woo00<007ooOol0@7oo
00<007ooOol06Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00goo
00<007ooOol00goo00<007ooOol00goo00<007ooOol02Woo1000:Woo100037oo00<007ooOol00Woo
00<007ooOol017oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol02Goo
00<007ooOol067oo00<007ooOol0ogoo=goo00<007ooOol01goo000jOol00`00Oomoo`0DOol@IcV2
Ool00`00Oomoo`1COol00`00Oomoo`06Ool01000Oomoo`002Goo0P001Woo0P0017oo00@007ooOomo
o`8000Ioo`03001oogoo00Ioo`03001oogoo009oo`03001oo`0000Aoo`03001oogoo009oo`8000Ao
o`8000Ioo`03001oo`0000@000Ioo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`D00003Ool007oo00Eoo`8000Aoo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo00Aoo`05001oogooOol00004Ool00`00Oomoo`0:Ool2
0006Ool00`00Oomoo`0@Ool01000Oomoo`00:Woo00<007ooOol0@7oo00<007ooOol06Goo00<007oo
Ool02Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool00Woo0P002Goo1000<Woo10002Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol017oo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol05goo00<007ooOol0ogoo
=goo00<007ooOol01goo000jOol00`00Oomoo`0DOol@IcV3Ool00`00Oomoo`1COol00`00Oomoo`04
Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`05Ool01@00Oomoogoo00001Goo00<007oo
Ool017oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool00Woo00<007oo00001Goo0`0017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol00Woo
0P001goo0P0017oo00@007ooOomoo`8000Eoo`03001oogoo00=oo`04001oogoo0005Ool00`00Oomo
o`0:Ool00`00Oomoo`04Ool2000COol3000ZOol00`00Oomoo`10Ool00`00Oomoo`0IOol00`00Oomo
o`0:Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomo
ogoo000027oo0`00>Woo0`001goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol067oo00<007ooOol0ogoo=Woo
00<007ooOol01goo000jOol00`00Oomoo`0DOol@IcV3Ool00`00Oomoo`1COol20005Ool00`00Oomo
o`02Ool20008Ool20006Ool20002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`06Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Ool00002Ool01@00Oomoogoo0000
0goo00<007oo00001Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol00goo0`0017oo00@0
07ooOol000Aoo`05001oo`00Ool00005Ool00`00Oomoo`04Ool00`00Ool00005Ool00`00Oomoo`09
Ool20006Ool00`00Oomoo`0BOol2000ZOol00`00Oomoo`10Ool00`00Oomoo`0IOol00`00Oomoo`0:
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo
00001goo0P00@7oo0P001Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool00goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol067oo00<007ooOol0ogoo=Woo00<0
07ooOol01goo000jOol00`00Oomoo`0DOol@IcV3Ool00`00Oomoo`1DOol00`00Oomoo`03Ool00`00
Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`05Ool01000Oomoo`001Woo00<007ooOol00Woo00<0
07ooOol01Woo00<007ooOol017oo0P000Woo00<007ooOol00goo00D007oo001oo`0000Aoo`04001o
o`000002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`02OolK0004Ool00`00Oomoo`04
Ool00`00Oomoo`03Ool00`00Oomoo`020002Ool01@00Oomoogoo00000goo00<007oo00000Woo00<0
07ooOol00Woo00<007ooOol017oo0P001Woo00<007ooOol02Goo00<007oo000017oo00<007ooOol0
4goo0P00:Woo00<007ooOol0@7oo00<007ooOol06Goo00<007ooOol02Woo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Ioo`8001Aooa`001Ao
o`8000Eoo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`06Ool0
0`00Oomoo`0:Ool00`00Oomoo`0HOol00`00Oomoo`3oOoleOol00`00Oomoo`07Ool003Yoo`03001o
ogoo01Aooa1W>H=oo`03001oogoo05Aoo`8000=oo`03001oogoo00Aoo`8000Uoo`03001oogoo00Eo
o`8000Qoo`05001oogooOol00008Ool00`00Oomoo`03Ool00`00Ool00002Ool00`00Oomoo`02Ool0
0`00Oomoo`020005Ool20004Ool00`00Oomoo`03Ool01000Oomoogoo20000Woo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol020000goo00<007ooOol00goo00<007ooOol0
0Woo0`000goo00<007ooOol00Woo0P000Woo00<007ooOol00goo00<007ooOol00goo0P001goo00<0
07ooOol01goo00@007ooOol000=oo`8001Eoo`8002Yoo`03001oogoo041oo`03001oogoo01Uoo`03
001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol00004
Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool7000LOol7000?Ool00`00Oomoo`03Ool01@00Oomoogoo
000017oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol02Woo00<007oo
Ool067oo00<007ooOol0ogoo=Goo00<007ooOol01goo000jOol00`00Oomoo`0DOol@IcV4Ool00`00
Oomoo`1DOol01@00Oomoogoo00001goo00<007ooOol01goo0P001Woo0P0027oo0P0000=oo`00Ool0
1goo00<007ooOol00goo00@007ooOomoo`8000Aoo`04001oogooOol20004Ool20005Ool00`00Oomo
o`02Ool50003Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool01000Oomoogoo1@0017oo00<007ooOol017oo00<007ooOol00Woo00@007ooOomo
o`8000=oo`03001oogoo00=oo`03001oogoo009oo`8000Moo`8000Moo`80009oo`05001oogooOol0
000EOol01000Oomoo`00:Goo00<007ooOol0?goo00<007ooOol06Goo00<007ooOol02Woo00<007oo
Ool01Goo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00=oo`03
001oogoo00Qoo`H002Yoo`D000]oo`03001oogoo00=oo`05001oogooOol00004Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0HOol00`00Oomoo`3o
OoldOol00`00Oomoo`07Ool003Yoo`03001oogoo01Aooa1W>HAoo`03001oogoo05Eoo`04001oogoo
0008Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`07Ool30008Ool00`00Oomoo`03Ool0
1000Oomoogoo0P0017oo00@007ooOomoo`8000=oo`<000Eoo`03001oo`0000800003Ool007oo00Eo
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ao
o`03001oogoo00=oo`03001oogoo00<00003Ool007oo00Eoo`8000=oo`04001oogooOol20003Ool0
0`00Oomoo`03Ool01000Oomoogoo0`0027oo00<007ooOol017oo0P000goo00<007ooOol00P005Goo
00@007ooOol002Uoo`03001oogoo03moo`03001oogoo01Uoo`03001oogoo00Yoo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol00004Ool01000Oomoogoo0P002Goo0`00
=7oo0`002Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo01Qoo`03001oogoo0?moocAoo`03001oogoo
00Moo`00>Woo00<007ooOol057oo46LiQ7oo00<007ooOol0EGoo0P0000=oo`00Ool01goo0P002Goo
00<007ooOol017oo0P002Goo0P001goo00<007ooOol017oo00@007ooOomoo`8000=oo`07001oogoo
Ool007oo00000Woo00@007ooOol000Aoo`<000Eoo`03001oogoo00=oo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001o
ogoo00=oo`<000Eoo`03001oo`0000=oo`05001oo`00Ool00004Ool00`00Oomoo`02Ool00`00Oomo
o`020002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`03Ool3000EOol01@00Oomoogoo
0000:Goo00<007ooOol0?Woo00<007ooOol06Woo00<007ooOol02Woo00<007ooOol01Goo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00Eoo`@0
03Yoo`<000Moo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo00001Woo00<007oo
Ool01Goo00<007ooOol02Woo00<007ooOol067oo00<007ooOol0ogoo=7oo00<007ooOol01goo000j
Ool00`00Oomoo`0DOol@IcV5Ool00`00Oomoo`1EOol2000:Ool20008Ool20004Ool01000Oomoo`00
27oo0P000goo00D007ooOomoo`0000Eoo`03001oogoo00=oo`05001oogooOol00003Ool01@00Ool0
07oo00000goo00L007ooOomoo`00Ool00006Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`0300000goo00000002Ool01000Oomoogoo0P000Woo00D007ooOomoo`0000Eo
o`03001oo`0000=oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00Aoo`8001Eoo`8000=o
o`03001oogoo02Moo`03001oogoo03ioo`03001oogoo01Uoo`03001oogoo00Yoo`03001oogoo00Io
o`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool01000Oomoo`001Goo0`00@Goo
0P001Woo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo00Ioo`03001oogoo00Yoo`03001oogoo01Qoo`03001oogoo0?mooc=oo`03001oogoo00Mo
o`00>Woo00<007ooOol057oo46LiQGoo00<007ooOol0EWoo00<007ooOol02Goo00<007ooOol01goo
0P000Woo0P000Woo0P0000=oo`00Ool017oo0`000Woo00D007ooOomoo`0000Eoo`03001oogoo00=o
o`800003Ool007oo009oo`05001oogooOol00005Ool30002Ool20005Ool00`00Oomoo`03OolU0005
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool20004Ool01@00Oomoogoo00000Woo00D007ooOomoo`00
00Eoo`8000Aoo`03001oogoo00Ioo`80009oo`03001oogoo00Eoo`03001oogoo01Aoo`03001oogoo
00=oo`03001oogoo02Eoo`03001oogoo03moo`03001oogoo01Uoo`03001oogoo00Yoo`03001oogoo
00Ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00003Ool01000Oomoo`001Goo00<0
07ooOol047oo900047oo0P001Goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool00`00Oomo
o`03Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0HOol00`00Oomoo`3oOolcOol00`00
Oomoo`07Ool003Yoo`03001oogoo01Aooa1W>HEoo`03001oogoo05Ioo`8000]oo`04001oogoo0006
Ool200000goo00000003Ool30005Ool01000Ool000000Woo00@007ooOol000Eoo`03001oogoo009o
o`03001oo`00008000=oo`05001oogooOol00004Ool20005Ool00`00Oomoo`02Ool80006Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool80004Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool00`00Oomoo`020002Ool00`00Oomoo`02Ool20003Ool20004Ool00`00Oomo
o`06Ool200000goo00000005Ool200000goo001oo`0COol00`00Oomoo`04Ool00`00Oomoo`0UOol0
0`00Oomoo`0nOol00`00Oomoo`0JOol00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol0
2Woo1`0097oo1`002goo0P000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol0
0006Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0HOol00`00Oomoo`3oOolcOol00`00
Oomoo`07Ool003Yoo`03001oogoo01Aooa1W>HIoo`03001oogoo05Eoo`80009oo`03001oogoo00Mo
o`03001oo`0000Moo`04001oogoo0004Ool30004Ool00`00Oomoo`0200001Goo000007oo00001Goo
00<007ooOol00Woo00<007ooOol00P000Woo00@007ooOomoo`8000=oo`03001oo`0000Eoo`D00003
Ool007oo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oo`0000@000Ioo`8000Aoo`05001oo`00Ool00002Ool0
1000Oomoogoo0P000Woo0P001Goo00<007ooOol01Woo00@007oo000000Eoo`<00003Ool007oo019o
o`8000Moo`03001oogoo02Aoo`03001oogoo03ioo`03001oogoo01Yoo`03001oogoo00Yoo`03001o
ogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00003Ool01000Oomoo`0017oo
00<007ooOol01goo1000<Woo10002Goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00001Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol06Goo00<007ooOol0ogoo
<Woo00<007ooOol01goo000jOol00`00Oomoo`0DOol@IcV6Ool00`00Oomoo`1DOol01P00Oomoo`00
Ool000Uoo`800003Ool007oo00Ioo`04001oo`000004Ool30003Ool600000goo00000006Ool00`00
Oomoo`02Ool00`00Oomoo`020002Ool01@00Oomoo`00Ool00P0000Eoo`00Oomoo`0000=oo`<000Eo
o`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00=oo`8000Eoo`03001oo`0000Aoo`04001o
ogoo0002Ool01000Oomoogoo0P000Woo0P001Woo00<007ooOol017oo10001Goo0`000Woo00<007oo
Ool03Goo00D007ooOomoo`0000Qoo`03001oogoo02Aoo`03001oogoo03ioo`03001oogoo01Yoo`03
001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00003
Ool01000Oomoo`000goo00<007ooOol01Goo0`00>Woo0`001Woo00<007ooOol00Woo00@007ooOol0
00=oo`05001oogooOol00003Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00
Oomoo`0IOol00`00Oomoo`3oOolbOol00`00Oomoo`07Ool003Yoo`03001oogoo01Aooa1W>HIoo`03
001oogoo05Aoo`03001oogoo00800003Ool007oo00Qoo`@000Moo`04001oo`000004Ool300000goo
001oo`02Ool60005Ool00`00Oomoo`02Ool01000Oomoogoo0P000Woo00@007ooOol0009oo`8000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool01000Ool000000goo00@007ooOol000=oo`04001oogoo0002Ool01000Oomoogoo0P0000Eoo`00
Oomoo`0000Eoo`03001oogoo00Aoo`03001oo`0000Eoo`<000Aoo`03001oogoo00aoo`04001oogoo
0009Ool00`00Oomoo`0TOol00`00Oomoo`0mOol00`00Oomoo`0JOol00`00Oomoo`0:Ool00`00Oomo
o`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@0
07ooOol000Ioo`80041oo`8000Eoo`05001oogooOol00002Ool01@00Oomoogoo000017oo00D007oo
Oomoo`0000Ioo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo01Qoo`03001oogoo0?mooc9o
o`03001oogoo00Moo`00>Woo00<007ooOol057oo46LiQgoo00<007ooOol0DWoo00<007ooOol00Woo
10001Goo0`0000Aoo`00000000=oo``00003Ool00000008000Eoo`D000Aoo`03001oogoo009oo`06
001oogooOol007oo0P000Woo00D007ooOomoo`0000Aoo`<000=oo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo009ooa/000Aoo`03001oogoo00=oo`03001oogoo00=oo`04001oogooOol20000
0goo001oo`02Ool00`00Oomoo`020002Ool01@00Oomoo`00Ool01@0000=oo`0000001Goo00<007oo
Ool00goo2`001Goo00<007ooOol02goo00@007ooOol000]oo`03001oogoo029oo`03001oogoo03io
o`03001oogoo01Yoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009o
o`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo0P0057oo700057oo0P0017oo
00D007ooOomoo`00009oo`05001oogooOol00003Ool01@00Oomoogoo00001Woo00<007ooOol01Goo
00<007ooOol02Woo00<007ooOol067oo00<007ooOol0ogoo<Woo00<007ooOol01goo000jOol00`00
Oomoo`0DOonGIcT00`00IcUW>@1BIcT00`00IcUW>@04IcT30006IcT60004IcT700000fLi00000005
0007IcT40003IcT00`00IcUW>@02IcT01P00IcUW>FLi001W>@80009W>@800003IcT0000000=W>@80
00EW>@03001W>FLi009W>@`0009W>@03001W>FLi00AW>@03001W>FLi00EW>@03001W>FLi00AW>@03
001W>FLi00`000AW>@03001W>FLi00=W>@8000AW>@800005IcT006LiIcT00002IcT00`00IcT00005
00000fLi001W>@04IcT00`00IcUW>@02IcT7000016Li000000000VLi1@0036Li0P0000=W>@00IcT0
2fLi00<006LiIcT08VLi00<006LiIcT0?VLi00<006LiIcT06VLi00<006LiIcT02VLi00<006LiIcT0
1FLi00<006LiIcT00fLi00<006LiIcT00VLi00D006LiIcUW>@0000=W>@06001W>FLi001W>@0016Li
0P002fLi2`0076Li2`002fLi0P000fLi00@006LiIcT0009W>@05001W>FLiIcT00003IcT01@00IcUW
>FLi00001VLi00<006LiIcT01FLi00<006LiIcT02VLi00<006LiIcT066Li00<006LiIcT0ofLi>VLi
0Woo000jOol00`00Oomoo`0DOonGIcT00`00IcUW>@1BIcT00`00IcT000020002IcT40007IcT50004
IcT00`00IcT000040003IcT50007IcT30003IcT00`00IcUW>@02IcT01P00IcUW>FLi001W>@800005
IcT006Li001W>@0200000fLi00000002IcT00`00IcUW>@02IcT500000fLi001W>@04IcT00`00IcUW
>@04IcT00`00IcUW>@04IcT00`00IcUW>@05IcT00`00IcUW>@04IcT00`00IcUW>@04IcT00`00IcUW
>@03IcT00`00IcT000040005IcT40002IcT20002IcT00`00IcT00002IcT70002IcT00`00IcUW>@03
IcT01000IcUW>FLi1P000VLi20000VLi00<006LiIcT02VLi100000=W>@0000002FLi00<006LiIcT0
8VLi00<006LiIcT0?FLi00<006LiIcT06fLi00<006LiIcT02VLi00<006LiIcT01FLi00<006LiIcT0
0fLi00<006LiIcT00VLi00D006LiIcUW>@00009W>@04001W>FLi0002IcT00`00IcUW>@020009IcT4
000bIcT40009IcT01000IcUW>@000fLi00@006LiIcT0009W>@05001W>FLiIcT00003IcT00`00IcUW
>@04IcT00`00IcUW>@05IcT00`00IcUW>@0:IcT00`00IcUW>@0HIcT00`00IcUW>@3oIcTjIcT2Ool0
03Yoo`03001oogoo01AooiQW>@03001W>FLi051W>@03001W>FLi009W>@L000UW>@@000=W>@04001W
>FLiIcT40005IcT30005IcT00`00IcUW>@0200000fLi001W>@03IcT01@00IcUW>FLi00000VLi00D0
06Li000006Li00800003IcT0000000AW>@03001W>FLi00<000EW>@03001W>FLi00=W>@03001W>FLi
00AW>@03001W>FLi00AW>@03001W>FLi00EW>@03001W>FLi00AW>@03001W>FLi00AW>@03001W>FLi
00=W>@03001W>FLi00=W>@<000=W>@06001W>FLiIcT006Li0P000VLi00<006Li00000fLi1@0016Li
00<006LiIcT00fLi00<006LiIcT00`000VLi00<006Li00001@001FLi00<006LiIcT02FLi1P0036Li
00<006LiIcT08FLi00<006LiIcT0?FLi00<006LiIcT06VLi00<006LiIcT02VLi00<006LiIcT01VLi
00<006LiIcT00VLi00<006LiIcT00fLi00@006LiIcT000=W>@06001W>FLi001W>@000VLi00<006Li
IcT01FLi1000>VLi10001VLi00@006LiIcT0009W>@04001W>FLi0003IcT01000IcUW>@0016Li00<0
06LiIcT00fLi00<006LiIcT01FLi00<006LiIcT02VLi00<006LiIcT06FLi00<006LiIcT0ofLi>FLi
0Woo000jOol00`00Oomoo`0DOonHIcT00`00IcUW>@1@IcT00`00IcUW>@05IcT50009IcT30003IcT0
0`00IcUW>@03IcT30004IcT01000IcT0000016Li00@006LiIcUW>@<000AW>@05001W>FLiIcT00002
IcT30002IcT200000fLi00000004IcT30002IcT00`00IcUW>@03IcT00`00IcUW>@03IcT00`00IcUW
>@04IcT00`00IcUW>@04IcT00`00IcUW>@05IcT00`00IcUW>@04IcT00`00IcUW>@04IcT00`00IcUW
>@03IcT00`00IcUW>@03IcT00`00IcUW>@040004IcT30002IcT01000IcUW>@000VLi0`0000=W>@00
IcT00fLi00<006LiIcT00fLi100016Li1@0026Li00<006LiIcT02FLi10003VLi00<006LiIcT086Li
0P00?fLi00<006LiIcT06VLi00<006LiIcT02VLi00<006LiIcT01VLi00<006LiIcT00VLi00<006Li
IcT00fLi00@006LiIcT000=W>@03001W>@00009W>@03001W>@0000EW>@<0049W>@<000AW>@03001W
>@0000=W>@03001W>@0000=W>@04001W>FLi0004IcT00`00IcUW>@03IcT00`00IcUW>@05IcT00`00
IcUW>@0:IcT00`00IcUW>@0IIcT00`00IcUW>@3oIcTiIcT2Ool003Yoo`03001oogoo01AooiQW>@80
055W>@03001W>FLi00MW>@@000YW>@<00003IcT006Li00IW>@80009W>@04001W>FLiIcT20003IcT0
0`00IcUW>@02IcT20004IcT02000IcUW>FLi001W>@00IcT300001VLi00000000IcT0009W>@<000AW
>@03001W>FLi00=W>@03001W>FLi00=W>@03001W>FLi00AW>@03001W>FLi00AW>@03001W>FLi00EW
>@03001W>FLi00AW>@03001W>FLi00AW>@03001W>FLi00=W>@03001W>FLi00=W>@03001W>FLi00=W
>@8000AW>@05001W>@00IcT00002IcT00`00IcT000020002IcT00`00IcUW>@02IcT00`00IcUW>@03
IcT20006IcT2000<IcT00`00IcUW>@07IcT4000?IcT00`00IcUW>@0PIcT00`00IcUW>@0mIcT00`00
IcUW>@0KIcT00`00IcUW>@0:IcT00`00IcUW>@05IcT00`00IcUW>@03IcT00`00IcUW>@02IcT01@00
IcUW>FLi00000VLi00P006LiIcT006Li001W>@0016Li0P00B6Li0P000fLi00<006Li00000VLi00@0
06LiIcT0009W>@05001W>FLiIcT00003IcT00`00IcUW>@04IcT00`00IcUW>@05IcT00`00IcUW>@09
IcT00`00IcUW>@0IIcT00`00IcUW>@3oIcTiIcT2Ool003Yoo`03001oogoo01AooiUW>@03001W>FLi
04mW>@03001W>FLi00UW>@<000]W>@8000UW>@800003IcT006Li00AW>@04001W>FLi0005IcT20003
IcT01`00IcUW>FLi001W>@00009W>@H00004IcT000000002IcT00`00IcUW>@02IcT00`00IcUW>@03
IcT00`00IcUW>@0[0002IcT00`00IcUW>@03IcT00`00IcUW>@03IcT01000IcT000000VLi00<006Li
00000VLi00<006Li00000`000fLi00<006LiIcT00VLi00<006LiIcT00VLi0P001VLi00<006Li0000
36Li00<006LiIcT01VLi0`004FLi00<006LiIcT086Li00<006LiIcT0?FLi00<006LiIcT06fLi00<0
06LiIcT02VLi00<006LiIcT01FLi00<006LiIcT00fLi00<006LiIcT00VLi00D006LiIcUW>@00009W
>@08001W>FLi001W>@00IcT000=W>@03001W>FLi00mW>BX0015W>@04001W>FLi0002IcT00`00IcT0
0002IcT01000IcUW>@000fLi00D006LiIcUW>@0000IW>@03001W>FLi00EW>@03001W>FLi00YW>@03
001W>FLi01QW>@03001W>FLi0?mW>CUW>@9oo`00>Woo00<007ooOol057ooVFLi00<006LiIcT0CVLi
00<006LiIcT036Li0P002fLi0P002FLi0`001VLi0P001FLi00H006LiIcT006Li0003IcT01@00IcUW
>@00IcT01P000VLi00<006LiIcT00VLi00<006LiIcT00VLi2@000fLi00<006LiIcT016Li00<006Li
IcT016Li00<006LiIcT01FLi00<006LiIcT016Li00<006LiIcT00fLi00<006LiIcT00VLi2@001FLi
00@006LiIcUW>@800003IcT00000009W>@04001W>@000002IcT01@00IcUW>FLi00000fLi00<006Li
IcT00P000VLi00@006LiIcUW>@80009W>@03001W>FLi00YW>@03001W>FLi00IW>@03001W>FLi019W
>@03001W>FLi01mW>@03001W>FLi03eW>@03001W>FLi01YW>@03001W>FLi00YW>@03001W>FLi00IW
>@03001W>FLi00=W>@03001W>FLi009W>@04001W>FLi0003IcT00`00IcT00002IcT20003IcT00`00
IcUW>@08IcT8000ZIcT8000:IcT01P00IcUW>@00IcT0009W>@03001W>@0000=W>@04001W>FLi0004
IcT00`00IcUW>@03IcT00`00IcUW>@05IcT00`00IcUW>@0:IcT00`00IcUW>@0IIcT00`00IcUW>@3o
IcThIcT2Ool003Yoo`D0019ooiYW>@03001W>FLi04eW>@03001W>FLi00eW>@8000YW>@04001W>@00
0009IcT20006IcT20004IcT01000IcUW>FLi0P000fLi00L006LiIcT006Li001W>@0400000fLi0000
0004IcT00`00IcUW>@030005IcT00`00IcUW>@03IcT00`00IcUW>@04IcT00`00IcUW>@04IcT00`00
IcUW>@05IcT00`00IcUW>@04IcT00`00IcUW>@03IcT00`00IcUW>@04IcT00`00IcUW>@03IcT40002
IcT00`00IcUW>@02IcT00`00IcUW>@0200000fLi001W>@020002IcT01@00IcUW>FLi00000fLi00@0
06Li000000=W>@03001W>FLi008000=W>@03001W>FLi00YW>@03001W>FLi00EW>@03001W>FLi01=W
>@03001W>FLi01mW>@03001W>FLi03eW>@03001W>FLi01YW>@03001W>FLi00YW>@03001W>FLi00IW
>@03001W>FLi00=W>@03001W>FLi009W>@04001W>FLi0002IcT02@00IcUW>@00IcT006Li001W>@02
0007IcT4000jIcT50006IcT02000IcUW>@00IcT006Li0002IcT01000IcUW>@000VLi00<006LiIcT0
0VLi00<006LiIcT00fLi00<006LiIcT01FLi00<006LiIcT02VLi00<006LiIcT06FLi00<006LiIcT0
ofLi>6Li0Woo000jOol00`00Oomoo`0DOonJIcT00`00IcUW>@1=IcT00`00IcUW>@0>IcT20009IcT0
0`00IcUW>@020008IcT30005IcT01000IcT000000VLi00<006LiIcT00VLi0P000VLi00L006LiIcT0
06Li001W>@050002IcT70002IcT00`00IcUW>@03IcT00`00IcUW>@03IcT00`00IcUW>@04IcT00`00
IcUW>@04IcT00`00IcUW>@05IcT00`00IcUW>@04IcT00`00IcUW>@03IcT00`00IcUW>@04IcT00`00
IcUW>@03IcT01000IcUW>FLi1P0000IW>@00001W>@00IcT300001FLi001W>FLi00000fLi00@006Li
IcUW>@8000EW>@<000EW>@03001W>FLi00YW>@03001W>FLi00AW>@03001W>FLi01AW>@03001W>FLi
01mW>@03001W>FLi03eW>@03001W>FLi01YW>@03001W>FLi00YW>@03001W>FLi00IW>@03001W>FLi
00=W>@03001W>FLi009W>@04001W>FLi0002IcT01`00IcUW>@00IcT006Li0080009W>@L004=W>@H0
0008IcT006Li001W>@00IcT0009W>@04001W>FLi0002IcT00`00IcUW>@02IcT00`00IcUW>@03IcT0
0`00IcUW>@05IcT00`00IcUW>@0:IcT00`00IcUW>@0IIcT00`00IcUW>@3oIcThIcT2Ool003Yoo`03
001oogoo01AooiYW>@8004iW>@03001W>FLi00mW>@8000QW>@04001W>FLiIcT20007IcT00`00IcUW
>@020003IcT01000IcUW>FLi0`0016Li00<006Li00000P000VLi00H006Li001W>@00IcT60003IcT0
0`00IcUW>@02IcT00`00IcUW>@02IcTc0004IcT00`00IcUW>@03IcT01000IcUW>FLi0`0000=W>@00
IcT00P000VLi00@006LiIcT000=W>@03001W>FLi008000EW>@<000IW>@03001W>FLi00YW>@03001W
>FLi009W>@8001MW>@03001W>FLi01iW>@03001W>FLi03eW>@03001W>FLi01]W>@03001W>FLi00YW
>@03001W>FLi00IW>@03001W>FLi00=W>@05001W>FLiIcT00003IcT01000IcUW>@000VLi00@006Li
001W>@@000mW>C8000mW>@800006IcT006Li001W>@000VLi00@006LiIcT0009W>@03001W>FLi009W
>@03001W>FLi00=W>@03001W>FLi00EW>@03001W>FLi00YW>@03001W>FLi01UW>@03001W>FLi0?mW
>CQW>@9oo`00>Woo00<007ooOol057ooVfLi00<006LiIcT0C6Li00<006LiIcT046Li0P001fLi00<0
06LiIcT00fLi0P001FLi00<006LiIcT00VLi0P0000=W>@00IcT00fLi0P0016Li00<006LiIcT00P00
00IW>@00IcUW>@00IcT50002IcT00`00IcUW>@0;00000fLi001W>@04IcT00`00IcUW>@04IcT00`00
IcUW>@04IcT00`00IcUW>@05IcT00`00IcUW>@04IcT00`00IcUW>@03IcT00`00IcUW>@04IcT00`00
IcT0000:0004IcT300000fLi0000000200001FLi001W>FLi00000fLi0`000VLi00@006LiIcUW>@<0
00MW>@03001W>FLi00]W>@03001W>FLi008001UW>@03001W>FLi01eW>@03001W>FLi03eW>@03001W
>FLi01]W>@03001W>FLi00YW>@03001W>FLi00IW>@03001W>FLi00=W>@05001W>FLiIcT00003IcT0
1P00IcUW>@00IcT0009W>@@000EW>@`0039W>@`000AW>@800003IcT00000009W>@03001W>@00009W
>@05001W>FLiIcT00003IcT00`00IcUW>@03IcT00`00IcUW>@06IcT00`00IcUW>@09IcT00`00IcUW
>@0JIcT00`00IcUW>@3oIcTgIcT2Ool003Yoo`03001oogoo01Aooi]W>@03001W>FLi04aW>@03001W
>FLi019W>@03001W>FLi00AW>@03001W>FLi00AW>@8000AW>@03001W>FLi00=W>@<000EW>@<0009W
>@04001W>FLiIcT30002IcT01@00IcT00000IcT00P0000=W>@0000000P0000=W>@00IcT00fLi00<0
06LiIcT00fLi00<006LiIcT00fLi00<006LiIcT016Li00<006LiIcT016Li00<006LiIcT01FLi00<0
06LiIcT016Li00<006LiIcT00fLi00<006LiIcT016Li00<006LiIcT00fLi00<006LiIcT00fLi2000
00MW>@00001W>@00IcT00002IcT01000IcUW>FLi0P000fLi00<006Li00000P0000=W>@00IcT01VLi
00<006LiIcT02fLi00@006Li000001YW>@03001W>FLi01eW>@03001W>FLi03eW>@03001W>FLi01]W
>@03001W>FLi00YW>@03001W>FLi00IW>@03001W>FLi00=W>@05001W>FLiIcT00003IcT02@00IcUW
>@00IcT006Li001W>@0300000fLi00000002001:IcT6000026Li001W>@00IcT006Li0002IcT01@00
IcUW>FLi00000fLi00<006LiIcT00fLi00<006LiIcT01VLi00<006LiIcT02FLi00<006LiIcT06VLi
00<006LiIcT0ofLi=fLi0Woo000jOol00`00Oomoo`0DOonIIcT00`00IcT00003IcT00`00IcUW>@17
IcT00`00IcUW>@0DIcT20003IcT00`00IcUW>@06IcT30002IcT00`00IcUW>@04IcT30003IcT00`00
IcUW>@0200000fLi001W>@02IcT00`00IcT0000200000fLi001W>@0500000fLi001W>@02IcT00`00
IcUW>@02IcT00`00IcUW>@03IcT00`00IcUW>@03IcT00`00IcUW>@04IcT00`00IcUW>@04IcT00`00
IcUW>@05IcT00`00IcUW>@04IcT00`00IcUW>@03IcT00`00IcUW>@04IcT00`00IcUW>@03IcT00`00
IcUW>@03IcT00`00IcUW>@02IcT5000016Li000006Li0P0000=W>@00IcT010000fLi0`0016Li00<0
06LiIcT016Li00<006LiIcT02fLi0`006fLi00<006LiIcT076Li0P00?VLi00<006LiIcT06fLi00<0
06LiIcT02fLi00<006LiIcT01FLi00<006LiIcT00fLi00<006LiIcT00VLi00L006LiIcUW>@00IcT0
0002IcT01000IcT006Li1000DVLi100000AW>@00IcT0009W>@03001W>@0000=W>@03001W>FLi009W
>@03001W>FLi00=W>@03001W>FLi00EW>@03001W>FLi00YW>@03001W>FLi01UW>@03001W>FLi0?mW
>CMW>@9oo`00>Woo00<007ooOol057ooVFLi00@006LiIcT0009W>@03001W>FLi04MW>@03001W>FLi
01EW>@80009W>@03001W>FLi00QW>@800003IcT006Li00EW>@03001W>@0000800003IcT006Li00=W
>@80009W>@H00004IcT00000IcT300000fLi0000001C00000fLi000000040002IcT200000fLi0000
0002IcT20006IcT00`00IcUW>@05IcT00`00IcUW>@09IcT2000MIcT00`00IcUW>@0LIcT00`00IcUW
>@0mIcT00`00IcUW>@0KIcT00`00IcUW>@0:IcT00`00IcUW>@06IcT00`00IcUW>@03IcT01@00IcUW
>FLi00000fLi00@006LiIcT0009W>@03001W>@0000@00003IcT0000005400003IcT006Li00800005
IcT006LiIcT00002IcT01000IcUW>@0016Li00<006LiIcT00fLi00<006LiIcT01FLi00<006LiIcT0
2VLi00<006LiIcT06FLi00<006LiIcT0ofLi=fLi0Woo000jOol00`00Oomoo`0DOonJIcT01000IcT0
06Li0P00BFLi00<006LiIcT05VLi0P0000=W>@00IcT02fLi0P001VLi00@006LiIcUW>@@000=W>@L0
009W>@@00003IcT0000000800003IcT006Li00=W>@05001W>FLiIcT00005IcT00`00IcUW>@03IcT0
0`00IcUW>@04IcT00`00IcUW>@04IcT00`00IcUW>@05IcT00`00IcUW>@04IcT00`00IcUW>@03IcT0
0`00IcUW>@04IcT00`00IcUW>@03IcT00`00IcUW>@03IcT00`00IcUW>@02IcT4000016Li000006Li
1P000VLi1`001FLi00<006LiIcT01FLi00<006LiIcT026Li0P0000=W>@00IcT076Li00<006LiIcT0
6fLi00<006LiIcT0?FLi00<006LiIcT06fLi00<006LiIcT02VLi00<006LiIcT01VLi00<006LiIcT0
0fLi00D006LiIcUW>@0000=W>@09001W>FLi001W>@00IcT006Li00D0059W>@<00008IcT006Li001W
>@00IcT0009W>@04001W>FLi0004IcT00`00IcUW>@03IcT00`00IcUW>@05IcT00`00IcUW>@0:IcT0
0`00IcUW>@0JIcT00`00IcUW>@3oIcTfIcT2Ool003Yoo`03001oogoo01AooiYW>@04001W>@00IcT2
0018IcT2000JIcT2000<IcT30005IcT00`00IcUW>@03IcT20003IcT70002IcT80002IcT00`00IcUW
>@02IcT01@00IcUW>FLi00001FLi00<006LiIcT00fLi00<006LiIcT016Li00<006LiIcT016Li00<0
06LiIcT01FLi00<006LiIcT016Li00<006LiIcT00fLi00<006LiIcT016Li00<006LiIcT00fLi00<0
06LiIcT00fLi00<006LiIcT00VLi00<006Li0000100000=W>@00IcT00P0000AW>@00001W>@<00004
IcT000000005IcT00`00IcUW>@05IcT00`00IcUW>@07IcT20002IcT00`00IcUW>@0KIcT00`00IcUW
>@0KIcT00`00IcUW>@0lIcT00`00IcUW>@0LIcT00`00IcUW>@0:IcT00`00IcUW>@06IcT00`00IcUW
>@03IcT01@00IcUW>FLi00000fLi00L006LiIcT006Li001W>@06001DIcT400001VLi001W>@00IcT0
009W>@04001W>FLi0004IcT00`00IcUW>@03IcT00`00IcUW>@05IcT00`00IcUW>@0:IcT00`00IcUW
>@0JIcT00`00IcUW>@3oIcTfIcT2Ool003Yoo`03001oogoo0:ioo`D004Qoo`03001oogoo01Yoo`80
00aoo`05001oo`00Ool00003Ool30003Ool20003Ool00`00Ool000040002Ool00`00Ool0001P0000
0goo0000000200000goo0000000400000goo001oo`04Ool00`00Oomoo`05Ool00`00Oomoo`07Ool0
1@00Oomoogoo00007Woo0P006goo00<007ooOol0>Woo0P007goo00<007ooOol02Woo00<007ooOol0
1Woo00<007ooOol00goo00D007ooOomoo`0000=oo`07001oogoo001oo`00Ool0F@0000=oo`000000
0P0000Ioo`00Ool007oo0002Ool01000Oomoo`0017oo00<007ooOol00goo00<007ooOol01Goo00<0
07ooOol02goo00<007ooOol06Woo00<007ooOol0ZgooE000;Goo00<007ooOol01goo000jOol00`00
Oomoo`2_Ool40017Ool00`00Oomoo`0KOol2000;Ool01P00Oomoo`00Ool000=oo`03001oogoo0080
0006Ool00000001oo`000goo1P0000=oo`00Ool0F00000=oo`00000020000Woo1P000Woo00<007oo
Ool017oo00<007ooOol01Goo00<007ooOol01Woo00D007ooOomoo`00021oo`8001Uoo`03001oogoo
03Uoo`03001oogoo01ioo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00Aoo`04001oogoo
0003Ool01000Oomoo`000Woo00<007oo0000F00000=oo`0000000P0000Ioo`00Ool007oo0003Ool0
1000Oomoo`000goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol02goo00<007ooOol06Woo
00<007ooOol0ZWooE000;Goo00<007ooOol01goo000jOol00`00Oomoo`2_Ool40015Ool2000MOol0
0`00Ool0000;Ool00`00Oomoo`030002Ool00`00Oomoo`02Ool500000goo001oo`02Ool600001Goo
00000000Ool0EP0000Aoo`00001oo`L0009oo`D000Aoo`03001oogoo00=oo`03001oogoo00Ioo`03
001oogoo00Aoo`8000Aoo`03001oogoo01moo`8001Moo`03001oogoo03Moo`80021oo`03001oogoo
00Yoo`03001oogoo00Moo`03001oogoo00=oo`05001oogooOol00003Ool01000Oomoo`000Woo0`00
00=oo`000000E@0000=oo`0000000`0000=oo`0000000Woo00@007ooOol0009oo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo01]oo`800:Yooe@002eo
o`03001oogoo00Moo`00>Woo00<007ooOol0[goo1000A7oo00<007ooOol07Goo00<007oo00002Woo
0P000goo0`0000=oo`00Ool017oo1P000goo00<007oo00000`0000Eoo`00000007oo05H00004Ool0
0000Ool5000017oo001oogoo1@0017oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol017oo00<007ooOol087oo0P005Goo00<007ooOol0=Goo0P008Goo00<007ooOol02goo
00<007ooOol01Woo00<007ooOol017oo00D007ooOomoo`0000=oo`07001oogoo001oo`00Ool00P00
00=oo`000000E@0000=oo`0000000`0000=oo`0000000Woo00@007ooOol0009oo`03001oogoo009o
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo01aoo`03001oogoo0:Mo
oe@002eoo`03001oogoo00Moo`00>Woo00<007ooOol0/7oo0`00@goo00<007ooOol07Goo00D007oo
Oomoo`0000Uoo`<0009oo`@000Ioo`D000=oo`03001oogoo00<00003Ool007oo05T00003Ool00000
00H0009oo`03001oo`000080009oo`05001oogooOol00006Ool00`00Oomoo`06Ool00`00Oomoo`03
Ool00`00Oomoo`05Ool00`00Oomoo`0QOol2000@Ool01000Oomoo`000Woo00<007ooOol0<7oo0P00
8Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol01Goo00@007ooOol000=oo`04001oogoo
0002Ool01@00Ool00000Ool00P0000=oo`000000DP0000Aoo`00001oo`800006Ool007oo001oo`00
0goo00@007ooOol000=oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo
01aoo`03001oogoo0:Iooe@002eoo`03001oogoo00Moo`00>Woo00<007ooOol0/7oo0`00@Goo0P00
7goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol00`0000=oo`0000001goo00<007ooOol0
0`000Woo00D007ooOol007oo00<00003Ool0000005L00003Ool0000000@0009oo`04001oo`00Ool2
0003Ool01@00Oomoogoo00001Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Woo00<0
07ooOol08Woo00<007ooOol03Goo00<007oo00000goo00<007ooOol0;Woo0P008goo00<007ooOol0
37oo00<007ooOol01Woo00<007ooOol01Goo00@007ooOol000=oo`06001oogoo001oo`000Woo0P00
00Aoo`00001ooe@00004Ool00000Ool2000017oo001oo`000Woo00@007ooOol0009oo`05001oogoo
Ool00007Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`0LOol2002VOomD000]Ool00`00
Oomoo`07Ool003Yoo`03001oogoo0;1oo`80045oo`03001oogoo01ioo`03001oogoo00=oo`03001o
ogoo00Ioo`04001oogooOol50006Ool00`00Oomoo`02Ool20002Ool01@00Oomoo`00Ool00`0000=o
o`00Ool0E`0000=oo`0000000`0000Eoo`00Ool007oo00@000=oo`03001oogoo009oo`03001oogoo
00Aoo`03001oogoo00Ioo`05001oogooOol0000:Ool00`00Oomoo`0ROol3000<Ool30002Ool00`00
Oomoo`0/Ool3000TOol00`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`05Ool01@00Oomoogoo
00000goo00T007ooOol007oo001oo`00Ool0100000=oo`000000DP0000Aoo`00001oo`80009oo`80
009oo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomo
o`0<Ool00`00Oomoo`0MOol00`00Oomoo`2SOomD000]Ool00`00Oomoo`07Ool003Yoo`03001oogoo
0;5oo`03001oogoo03ioo`03001oogoo01ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00=oo`D000Aoo`8000=oo`05001oo`00Ool00002Ool01000Ool007oo100000=oo`000000E@0000=o
o`0000000P0000Eoo`00001oo`00009oo`800003Ool007oo009oo`04001oogooOol20005Ool00`00
Oomoo`07Ool01000Oomoo`002goo00<007ooOol097oo0`002Goo0`0000=oo`000000:goo0`009Woo
00<007ooOol03Goo00<007ooOol01Woo00<007ooOol017oo0P000Woo00D007ooOomoo`00009oo`05
001oogoo001oo`0200001Goo00000000Ool0E00000Aoo`00001oo`<00006Ool007oo001oo`000goo
00@007ooOol000=oo`8000Ioo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo01ioo`03001o
ogoo0:9ooe@002eoo`03001oogoo00Moo`00>Woo00<007ooOol0/Goo00<007ooOol0?7oo0P0087oo
00<007ooOol01Woo0P0017oo00<007ooOol01Goo10000goo00<007ooOol00Woo00D007ooOomoo`00
009oo`05001oogoo001oo`0400000goo0000001J00001Goo001oo`00Ool010000Woo00D007ooOomo
o`0000Aoo`03001oogoo00=oo`03001oogoo00Moo`03001oo`0000aoo`03001oogoo02Ioo`@000Io
o`800003Ool0000002Moo`@002Qoo`03001oogoo00eoo`03001oogoo00Ioo`03001oogoo00Aoo`03
001oogoo009oo`05001oogooOol00002Ool00`00Ool00002Ool200001Goo00000000Ool0E00000Ao
o`00001oo`<00004Ool007oo0002Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol01goo00<007ooOol02goo00<007ooOol07Woo0P00XWooE000;Goo00<007ooOol01goo
000jOol00`00Oomoo`2aOol00`00Oomoo`0kOol00`00Oomoo`0POol00`00Oomoo`06Ool20004Ool0
0`00Oomoo`06Ool30003Ool00`00Oomoo`02Ool01000Oomoogoo0P0000Qoo`00Oomoo`00Ool007oo
FP0000=oo`0000000P0000Eoo`00Ool007oo00800005Ool007ooOol00003Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`07Ool3000=Ool00`00Oomoo`0YOol20004Ool4000WOol00`00Oomo
o`0YOol00`00Oomoo`0>Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000Woo00<007oo00000Woo0P0000Eoo`00000007oo05@00004Ool00000Ool3000017oo001o
o`000Woo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`03001o
ogoo00aoo`03001oogoo01moo`03001oogoo09mooe@002eoo`03001oogoo00Moo`00>Woo00<007oo
Ool0/Goo00<007ooOol0>Woo00<007ooOol087oo00<007ooOol01goo0`000Woo00<007ooOol01Woo
00@007oo0000009oo`03001oogoo00=oo`04001oogooOol40002Ool01000Ool007ooFP0000=oo`00
00000P0000=oo`00Ool00`000Woo00@007ooOol000=oo`03001oogoo00=oo`03001oogoo00=oo`03
001oogoo00Aoo`04001oogoo000?Ool00`00Oomoo`0ZOol300000goo00000002000TOol3000[Ool0
0`00Oomoo`0>Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00<007oo00000Woo0P0000Eoo`00000007oo05@00004Ool00000Ool300001goo001oogoo001o
o`00009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`03001o
ogoo00aoo`03001oogoo01moo`03001oogoo09iooe@002eoo`03001oogoo00Moo`00>Woo00<007oo
Ool0/Goo00<007ooOol0>Goo00<007ooOol087oo00<007ooOol017oo0P000goo0P0000=oo`00Ool0
27oo00<007ooOol00P0000=oo`00Ool00goo00D007ooOomoo`00009oo`80009oo`04001oo`00Ool2
00000goo0000001E00000goo0000000200000goo001oo`0200001Goo001oogoo00000Woo00D007oo
Oomoo`0000Aoo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo000@Ool00`00Oomoo`0/Ool5
000POol4000]Ool00`00Oomoo`0?Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000Woo00<007oo00000Woo00@007oo001oo`<00003Ool0000005800004Ool00000
Ool200001Woo001oo`00Ool0009oo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`07Ool00`00Oomoo`0=Ool00`00Oomoo`0OOol2002NOomD000]Ool00`00Oomoo`07Ool0
03Yoo`03001oogoo0;5oo`03001oogoo03Qoo`03001oogoo025oo`03001oogoo00Eoo`80009oo`80
0003Ool007oo00Moo`03001oogoo009oo`03001oo`0000Aoo`05001oogooOol00002Ool200001Woo
001oogoo001oo`800003Ool0000005D00003Ool0000000800004Ool000000002Ool01000Oomoo`00
0Woo00D007ooOomoo`0000Eoo`03001oogoo00=oo`03001oogoo00=oo`05001oo`00Ool0000@Ool0
0`00Oomoo`0/Ool6000JOol4000`Ool00`00Oomoo`0?Ool00`00Oomoo`06Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool01@00Oomoogoo00000Woo00<007oo00000Woo00@007oo001oo`<00003Ool00000
05800004Ool00000Ool200001Woo001oo`00Ool0009oo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`0=Ool00`00Oomoo`0QOol00`00Oomoo`2KOomD
000]Ool00`00Oomoo`07Ool003Yoo`03001oogoo0;5oo`03001oogoo03Moo`03001oogoo025oo`03
001oogoo00Moo`<00003Ool0000000Uoo`03001oogoo009oo`8000Eoo`05001oogooOol00002Ool0
2@00Ool00000Ool007oo001oo`0200000goo0000001D000017oo000007oo100000Aoo`00Ool0009o
o`04001oogoo0003Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Ool007oo
0P0047oo00<007ooOol0:goo0`000goo20002Woo2000<goo00<007ooOol03goo00<007ooOol01goo
00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oo`00009oo`800003Ool0
07oo05L00003Ool007oo00800005Ool00000Ool00002Ool00`00Ool00002Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`0=Ool00`00Oomoo`0QOol0
0`00Oomoo`2JOomD000]Ool00`00Oomoo`07Ool003Yoo`03001oogoo0;9oo`03001oogoo03Aoo`80
02=oo`03001oogoo00Uoo`D000Uoo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol00002
Ool02@00Oomoo`00Ool007oo001oo`0200000goo0000001D00000goo0000000300001Woo001oo`00
Ool0009oo`04001oogoo0003Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoogoo0P0000=o
o`0000000P0047oo00<007ooOol0;7oo0P002goo2P00>goo00<007ooOol03goo00<007ooOol01Woo
00<007ooOol017oo00<007ooOol00goo00D007ooOomoo`0000=oo`03001oo`00009oo`800003Ool0
07oo05L00003Ool007oo00800005Ool00000Ool00002Ool00`00Ool00002Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`0=Ool00`00Oomoo`0QOol0
0`00Oomoo`2IOomD000]Ool00`00Oomoo`07Ool003Yoo`03001oogoo0;9oo`03001oogoo03=oo`03
001oogoo029oo`03001oogoo00]oo`@000Qoo`03001oogoo00=oo`03001oo`0000=oo`05001oogoo
Ool00002Ool01000Oomoogoo0`0000=oo`00Ool00P0000=oo`000000E`0000Moo`00001oo`00Ool0
0002Ool01000Oomoo`000Woo00D007ooOomoo`0000Eoo`03001oogoo00=oo`04001oogooOol60000
0goo001oo`0?Ool00`00Oomoo`0[Ool00`00Oomoo`1>Ool00`00Oomoo`0?Ool00`00Oomoo`07Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00/007ooOol007oo001oo`00Ool0
07oo05L00003Ool007oo00800008Ool007oo001oo`00Ool0009oo`04001oogoo0003Ool00`00Oomo
o`03Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`0=Ool00`00Oomoo`0ROol00`00Oomo
o`2HOomD000]Ool00`00Oomoo`07Ool003Yoo`03001oogoo0;9oo`03001oogoo039oo`03001oogoo
029oo`03001oogoo00eoo`@000Ioo`03001oogoo00Aoo`04001oo`000002Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`<00004Ool00000OomF000017oo000007oo0P0000Aoo`00Ool0009oo`04
001oogoo0002Ool01@00Oomoogoo00001Goo00<007ooOol017oo00<007ooOol01@000goo00<007oo
Ool03Woo00<007ooOol0:Woo00<007ooOol0CGoo00<007ooOol03goo00<007ooOol01goo00<007oo
Ool017oo00<007ooOol00goo00D007ooOomoo`0000=oo`0;001oogoo001oo`00Ool007oo001oo`1G
00000goo001oo`02000027oo001oo`00Ool007oo0002Ool01000Oomoo`0017oo00<007ooOol00Woo
00<007ooOol017oo00<007ooOol01goo00<007ooOol03Goo00<007ooOol08Woo00<007ooOol0Ugoo
E000;Goo00<007ooOol01goo000jOol00`00Oomoo`2bOol00`00Oomoo`0aOol00`00Oomoo`0SOol0
0`00Oomoo`0=Ool40006Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Ool0001J000017oo000007oo0P0000Aoo`00Ool0009oo`04001oogoo0002
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`040004Ool00`00Oomo
o`0?Ool00`00Oomoo`0YOol00`00Oomoo`1=Ool00`00Oomoo`0?Ool00`00Oomoo`07Ool00`00Oomo
o`04Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00/007ooOol007oo001oo`00Ool007oo05L0
0003Ool007oo00800008Ool007oo001oo`00Ool0009oo`04001oogoo0004Ool00`00Oomoo`02Ool0
0`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`0=Ool00`00Oomoo`0SOol2002GOomD000]Ool0
0`00Oomoo`07Ool003Yoo`03001oogoo0;9oo`03001oogoo031oo`03001oogoo02=oo`03001oogoo
00eoo`03001oogoo008000Eoo`03001oogoo00Eoo`04001oogooOol20004Ool01000Oomoo`000Woo
00L007ooOol007oo001oo`0200000goo0000001D000017oo000007oo0P0000Aoo`00Ool0009oo`04
001oogoo0003Ool01@00Oomoogoo000017oo00<007ooOol01Goo00<007oo00000P001Woo00<007oo
Ool03goo00<007ooOol0:7oo00<007ooOol0C7oo00<007ooOol03goo00<007ooOol01goo00<007oo
Ool01Goo00<007ooOol00goo00@007ooOol000=oo`0<001oogooOol007oo001oo`00Ool007ooE`00
00=oo`00Ool00P0000Qoo`00Ool007oo001oo`000goo00<007oo000017oo00<007ooOol00goo00<0
07ooOol017oo00<007ooOol01goo00<007ooOol03Goo00<007ooOol097oo00<007ooOol0U7ooE000
;Goo00<007ooOol01goo000jOol00`00Oomoo`2bOol00`00Oomoo`0_Ool00`00Oomoo`0SOol00`00
Oomoo`0>Ool01000Oomoogoo0P0017oo00<007ooOol017oo00<007ooOol00Woo0P000goo00D007oo
Oomoo`00009oo`07001oogoo001oo`00Ool00P0000=oo`000000E00000Aoo`00001oo`800004Ool0
07oo0002Ool01000Oomoo`000goo00D007ooOomoo`0000Eoo`03001oogoo00Aoo`03001oo`000080
00Ioo`03001oogoo00moo`03001oogoo02Qoo`03001oogoo04]oo`03001oogoo011oo`03001oogoo
00Moo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0003Ool03000Oomoogoo001oo`00Ool0
07oo001ooeL00003Ool007oo00800008Ool007oo001oo`00Ool000=oo`04001oogoo0003Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00
Oomoo`2COomD000]Ool00`00Oomoo`07Ool003Yoo`03001oogoo0;9oo`03001oogoo02ioo`03001o
ogoo02Aoo`03001oogoo00eoo`03001oogoo009oo`8000Aoo`03001oogoo00Aoo`03001oogoo00=o
o`80009oo`05001oogooOol00002Ool00`00Oomoo`020002Ool200000goo0000001D000017oo0000
07oo0P0000Aoo`00Ool0009oo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`05Ool30008Ool00`00Oomoo`0?Ool00`00Oomoo`0WOol00`00Oomoo`1:Ool00`00Oomoo`0@
Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00`007oo
Oomoo`00Ool007oo001oo`00OomG00000goo001oo`02000027oo001oo`00Ool007oo0003Ool01000
Oomoo`0017oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol027oo00<007ooOol03Goo00<0
07ooOol09Goo00<007ooOol0TWooE000;Goo00<007ooOol01goo000jOol00`00Oomoo`2bOol00`00
Oomoo`0/Ool2000VOol00`00Oomoo`0>Ool00`00Oomoo`03Ool01@00Oomoogoo00001goo00<007oo
Ool00goo0`0000=oo`00Ool00Woo00<007oo00000Woo00P007oo001oo`00Ool007ooEP0000Aoo`00
001oo`800005Ool007ooOol00002Ool00`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`05Ool20009Ool00`00Oomoo`0@Ool00`00Oomoo`0VOol00`00Oomoo`19Ool00`00Oomo
o`0@Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00H0
07ooOol007oo0002Ool01000Ool007ooE`0000=oo`00Ool00P0000Ioo`00Ool007oo0002Ool01000
Oomoo`000Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol01goo00<0
07ooOol03Woo00<007ooOol09Goo00<007ooOol0TGooE000;Goo00<007ooOol01goo000jOol00`00
Oomoo`2bOol2000/Ool00`00Oomoo`0UOol00`00Oomoo`0>Ool00`00Oomoo`05Ool01000Oomoo`00
1goo00<007ooOol00Woo00<007ooOol00`000Woo00@007ooOol0009oo`08001oo`00Ool007oo001o
oeH00004Ool00000Ool200001Goo001oogoo00000Woo00@007ooOol000=oo`05001oogooOol00005
Ool00`00Oomoo`04Ool20009Ool00`00Oomoo`0AOol00`00Oomoo`0TOol2001:Ool00`00Oomoo`0A
Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000goo00L007ooOomo
o`00Ool00002Ool01000Ool007ooE`0000=oo`00Ool00P0000Ioo`00Ool007oo0002Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol027oo00<007oo
Ool03Woo00<007ooOol09Goo00<007ooOol0T7ooE000;Goo00<007ooOol01goo000jOol00`00Oomo
o`2cOol00`00Oomoo`0YOol00`00Oomoo`0VOol00`00Oomoo`0>Ool00`00Oomoo`05Ool01000Oomo
o`001Woo00<007ooOol00goo00D007ooOomoo`0000=oo`04001oogoo0002Ool02000Ool007oo001o
o`00OomF000017oo000007oo0P000Woo00<007oo00000Woo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo009oo`03001oogoo00=oo`<000Yoo`03001oogoo015oo`03001oogoo02=oo`03001o
ogoo04Qoo`03001oogoo015oo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo00=oo`05001o
ogooOol00003Ool01`00Oomoogoo001oo`00009oo`04001oo`00OomG00000goo001oo`0200001Woo
001oo`00Ool0009oo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`0UOol00`00Oomoo`2?OomD000]Ool00`00
Oomoo`07Ool003Yoo`03001oogoo0;=oo`03001oogoo02Qoo`03001oogoo02Ioo`03001oogoo00io
o`03001oogoo00Moo`8000Moo`03001oogoo00=oo`04001oogooOol300001Goo001oogoo00000Woo
00H007oo001oo`00OomK00000goo00000002Ool00`00Ool00002Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol00Woo00@007ooOol000Yoo`03001oogoo015oo`03001o
ogoo029oo`03001oogoo04Moo`03001oogoo015oo`03001oogoo00Uoo`03001oogoo00Eoo`03001o
ogoo00=oo`05001oogooOol00003Ool01`00Oomoogoo001oo`00009oo`04001oo`00OomG00000goo
001oo`0200001Woo001oo`00Ool0009oo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`0UOol2002?OomD000]
Ool00`00Oomoo`07Ool003Yoo`03001oogoo0;=oo`03001oogoo02Moo`03001oogoo02Moo`03001o
ogoo00ioo`03001oogoo00Moo`8000Ioo`03001oogoo00Aoo`06001oogooOol007oo0`000Woo00D0
07ooOol007oo00D00004Ool00000000<Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0@
Ool00`00Oomoo`0:Ool300000goo00000002Ool00`00Ool00002Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol00goo00D007ooOomoo`0000=oo`03001oogoo00Qoo`03001oogoo015oo`03
001oogoo029oo`03001oogoo04Moo`03001oogoo015oo`03001oogoo00Uoo`03001oogoo00Eoo`03
001oogoo00=oo`05001oogooOol00003Ool01`00Oomoogoo001oo`00009oo`04001oo`00Ool3001E
Ool02P00Ool00000Ool007oo001oo`000Woo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo00moo`03001oogoo02Ioo`03001oogoo
0?moo`moo`03001oogoo00Moo`00>Woo00<007ooOol0/goo00<007ooOol09Woo00<007ooOol09goo
00<007ooOol03Woo00<007ooOol027oo0P001Woo00<007ooOol017oo00D007ooOomoo`0000=oo`/0
0006Ool007oo001oo`0037oo00<007ooOol047oo00<007ooOol04Goo00<007ooOol047oo00<007oo
Ool02Woo00@007oo001oo`800005Ool007ooOol00002Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol00goo00D007ooOomoo`0000Aoo`03001oogoo00Qoo`03001oogoo015oo`03001oogoo
025oo`03001oogoo04Ioo`03001oogoo015oo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo
00Aoo`05001oogooOol00003Ool01`00Oomoogoo001oo`00009oo`04001oo`00Ool200000goo001o
o`1BOol02`00Ool007oo001oo`00Ool007oo00000Woo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo00moo`03001oogoo02Ioo`03
001oogoo0?moo`ioo`03001oogoo00Moo`00>Woo00<007ooOol0/goo00<007ooOol09Goo00<007oo
Ool09goo00<007ooOol03goo00<007ooOol027oo0`001Goo00<007ooOol00goo00<007ooOol00Woo
00@007ooOomoo`T0009oo`04001oo`00Ool4000:Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00
Oomoo`0@Ool00`00Oomoo`08Ool400001Woo001oo`00Ool0009oo`04001oogoo0002Ool01@00Oomo
ogoo00001Goo00<007ooOol00goo00<007oo00001Goo00<007ooOol027oo00<007ooOol04Woo00<0
07ooOol087oo00<007ooOol0AGoo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol01Goo00<0
07ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oo`00009oo`06001oo`00Ool0
07oo1000D7oo0P0000Yoo`00Ool007oo001oo`00Ool0009oo`04001oogoo0003Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`0W
Ool00`00Oomoo`3oOol=Ool00`00Oomoo`07Ool003Yoo`03001oogoo0;=oo`03001oogoo02Aoo`03
001oogoo02Moo`03001oogoo00moo`03001oogoo00Uoo`03001oo`0000Aoo`03001oogoo00Aoo`03
001oogoo009oo`03001oo`0000P00008Ool007ooOol007oo001oo`80009oo`@000Ioo`03001oogoo
011oo`03001oogoo015oo`03001oogoo011oo`03001oogoo00Aoo`@0009oo`800006Ool007oo001o
o`000Woo00@007ooOol0009oo`05001oogooOol00005Ool00`00Oomoo`03Ool30005Ool00`00Oomo
o`09Ool00`00Oomoo`0BOol00`00Oomoo`0OOol00`00Oomoo`14Ool00`00Oomoo`0BOol00`00Oomo
o`0:Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<0
07oo00000Woo00L007oo001oo`00Ool00003Ool40018Ool40002Ool02P00Oomoo`00Ool007oo001o
o`000Woo00@007ooOol000=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Aoo`03001o
ogoo00Uoo`03001oogoo00moo`03001oogoo02Moo`800?moo`eoo`03001oogoo00Moo`00>Woo00<0
07ooOol0]7oo00<007ooOol08goo00<007ooOol09goo00<007ooOol03goo00<007ooOol027oo00D0
07ooOomoo`0000=oo`03001oogoo00Aoo`05001oogooOol00003Ool01000Oomoogoo10000Woo00H0
07oo001oo`00Ool20006Ool40002Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0@Ool0
0`00Oomoo`040006Ool200000goo00000002Ool01000Oomoo`000Woo00D007ooOomoo`0000=oo`03
001oogoo009oo`03001oogoo00=oo`8000Moo`03001oogoo00Qoo`03001oogoo01=oo`03001oogoo
01ioo`03001oogoo04=oo`03001oogoo01=oo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo
00Aoo`05001oogooOol00003Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oo`000007
Ool40010Ool40006Ool01@00Ool007oo00000Woo00<007oo00000Woo00D007ooOomoo`0000=oo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo00moo`03
001oogoo02Uoo`03001oogoo0?moo`Yoo`03001oogoo00Moo`00>Woo00<007ooOol0]7oo00<007oo
Ool08Woo00<007ooOol09goo00<007ooOol03goo00<007ooOol02Goo00@007ooOomoo`80009oo`03
001oogoo00Aoo`05001oogooOol00003Ool01@00Oomoogoo00000Woo00T007ooOol007oo001oo`00
Ool00`002Goo0`004Woo00<007ooOol04Goo00<007ooOol047oo0`002Woo0P0000=oo`0000000Woo
00@007ooOol0009oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`06Ool00`00Oomoo`09Ool00`00Oomoo`0COol00`00Oomoo`0MOol00`00Oomoo`12Ool00`00Oomo
o`0COol00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01@00Oomoogoo00000goo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01@00Ool007oo00002Woo1000>7oo10002Woo00L007oo
001oo`00Ool00002Ool01000Oomoo`000goo00D007ooOomoo`0000Aoo`03001oogoo00=oo`03001o
ogoo00Eoo`03001oogoo00Uoo`03001oogoo00moo`03001oogoo02Uoo`03001oogoo0?moo`Uoo`03
001oogoo00Moo`00>Woo00<007ooOol0]7oo00<007ooOol08Goo00<007ooOol0:7oo00<007ooOol0
3goo00<007ooOol02Goo00<007ooOol00Woo00@007ooOol000Ioo`05001oogooOol00003Ool00`00
Oomoo`020002Ool01`00Oomoo`00Ool007oo00D000]oo`T000Yoo`03001oogoo015oo`03001oogoo
00Qoo`T000aoo`800003Ool00000009oo`04001oogoo0002Ool01@00Oomoogoo00000goo00<007oo
Ool00Woo00<007ooOol00Woo0P0027oo00<007ooOol02Goo00<007ooOol057oo00<007ooOol077oo
00<007ooOol0@Goo00<007ooOol057oo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol017oo
00D007ooOomoo`0000=oo`05001oogooOol00002Ool01000Oomoo`000Woo00D007oo001oo`0000io
o`P002Qoo`P000eoo`08001oogoo001oo`00Ool0009oo`04001oogoo0003Ool01@00Oomoogoo0000
17oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol047oo00<007ooOol0
:Goo00<007ooOol0ogoo27oo00<007ooOol01goo000jOol00`00Oomoo`2dOol00`00Oomoo`0POol0
0`00Oomoo`0YOol00`00Oomoo`0?Ool00`00Oomoo`08Ool00`00Oomoo`04Ool20006Ool00`00Oomo
o`02Ool02@00Oomoogoo001oo`00Ool00002Ool01000Oomoo`000Woo00<007oo00000`002goo00<0
07ooOol01Woo4`001goo3`0027oo00<007ooOol02Goo00H007oo000007oo0002Ool01000Oomoo`00
0Woo00D007ooOomoo`0000=oo`03001oogoo00=oo`03001oogoo00800003Ool007oo00Moo`03001o
ogoo00Uoo`03001oogoo01=oo`03001oogoo01aoo`03001oogoo045oo`03001oogoo01=oo`03001o
ogoo00Yoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol00003Ool0
1000Oomoo`000Woo00H007ooOol007oo0002Ool00`00Oomoo`0COol?0006OolC000DOol02@00Oomo
ogoo001oo`00Ool00002Ool01000Oomoo`000goo00D007ooOomoo`0000Eoo`03001oogoo00=oo`03
001oogoo00Eoo`03001oogoo00Qoo`03001oogoo011oo`03001oogoo02Uoo`03001oogoo0?moo`Qo
o`03001oogoo00Moo`00>Woo1@00/Woo00<007ooOol07goo00<007ooOol0:Goo00<007ooOol03goo
00<007ooOol02Goo00<007ooOol017oo0P001Woo00<007ooOol00Woo00@007ooOomoo`80009oo`04
001oogoo0002Ool01@00Oomoo`00Ool01P002Goo00<007ooOol047oo00<007ooOol01Woo1`0017oo
00<007ooOol047oo00<007ooOol01goo0P000goo00<007oo00000Woo00@007ooOol0009oo`05001o
ogooOol00003Ool00`00Oomoo`03Ool01000Ool000000Woo00<007ooOol01Woo00<007ooOol02Woo
00<007ooOol04goo00<007ooOol06goo00<007ooOol0@7oo00<007ooOol057oo00<007ooOol02Goo
00<007ooOol01Woo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0000=oo`04001oogoo
0002Ool01P00Oomoo`00Ool000=oo`80029oo`H002Ioo`03001oogoo009oo`05001oo`00Ool00002
Ool01000Oomoo`000goo00D007ooOomoo`0000Eoo`03001oogoo00=oo`03001oogoo00Eoo`03001o
ogoo00Uoo`03001oogoo011oo`03001oogoo02Uoo`800?moo`=oo`H000Uoo`00>Woo00<007ooOol0
]7oo00<007ooOol07Woo00<007ooOol0:Goo00<007ooOol047oo00<007ooOol02Goo00<007ooOol0
1Goo0P001Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`04
000017oo001oogoo0P001goo00<007ooOol047oo00<007ooOol04Goo00<007ooOol047oo00<007oo
Ool01Goo0P001Goo0`000Woo00@007ooOol0009oo`05001oogooOol00003Ool00`00Oomoo`03Ool3
0003Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0DOol00`00Oomoo`0JOol00`00Oomo
o`0oOol00`00Oomoo`0EOol00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00@007ooOol0009oo`06001oogoo001oo`001Goo0P00BWoo0P00
1Goo00D007oo001oo`00009oo`04001oogoo0003Ool01@00Oomoogoo00001Goo00<007ooOol00goo
00<007ooOol01Goo00<007ooOol02Woo00<007ooOol047oo00<007ooOol0:Woo00<007ooOol0ogoo
1Goo00<007ooOol01goo000jOol00`00Oomoo`2eOol00`00Oomoo`0LOol00`00Oomoo`0ZOol00`00
Oomoo`0@Ool00`00Oomoo`08Ool00`00Oomoo`06Ool30003Ool00`00Oomoo`03Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`03001oogoo00@00003Ool007oo00=oo`03001oogoo00Aoo`03001o
ogoo011oo`03001oogoo015oo`03001oogoo011oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`0000=oo`03001oogoo00=oo`8000Aoo`03001o
ogoo00Moo`03001oogoo00Yoo`03001oogoo01Aoo`03001oogoo01Uoo`03001oogoo03ioo`03001o
ogoo01Eoo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo009oo`05001o
ogooOol00003Ool01000Oomoo`000Woo00L007ooOomoo`00Ool00006Ool00`00Oomoo`16Ool00`00
Oomoo`04Ool00`00Ool00002Ool01000Oomoo`000Woo00D007ooOomoo`0000=oo`03001oogoo00=o
o`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo011oo`03001oogoo02]o
o`03001oogoo0?moo`Aoo`03001oogoo00Moo`00>Woo00<007ooOol0]Goo00<007ooOol06goo00<0
07ooOol0:Woo00<007ooOol04Goo00<007ooOol027oo00<007ooOol01Woo00@007oo0000009oo`03
001oogoo00=oo`05001oogooOol00003Ool01000Oomoo`000Woo00<007oo00000P0000=oo`00Ool0
0P0017oo00<007ooOol00goo00<007ooOol047oo00<007ooOol04Goo00<007ooOol047oo00<007oo
Ool00goo00<007ooOol01Goo00<007ooOol00P0000Eoo`00Oomoo`00009oo`05001oogooOol00003
Ool01000Oomoogoo0`001Woo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol05Goo00<007oo
Ool05goo00<007ooOol0?Woo00<007ooOol05Goo00<007ooOol02Woo00<007ooOol01Woo00<007oo
Ool017oo00<007ooOol00goo00D007ooOomoo`0000=oo`04001oogoo0003Ool01P00Oomoo`00Ool0
00Moo`03001oogoo04Aoo`03001oogoo00Aoo`04001oogoo0002Ool01000Oomoo`000Woo00D007oo
Oomoo`0000=oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Uoo`03
001oogoo015oo`03001oogoo02Yoo`03001oogoo0?moo`Aoo`03001oogoo00Moo`00>Woo00<007oo
Ool0]Goo00<007ooOol06Woo00<007ooOol0:goo00<007ooOol047oo00<007ooOol02Goo00<007oo
Ool01Woo1`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool50002Ool00`00Ool00005Ool2
0003Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0@Ool01000Oomoogoo0P001goo00@0
07ooOomoo`@0009oo`04001oogoo0003Ool01@00Oomoogoo00000Woo0P0000=oo`00Ool01Goo00<0
07ooOol01Woo00<007ooOol02Woo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol0?Woo00<0
07ooOol05Goo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00goo00D0
07ooOomoo`0000=oo`04001oogoo0003Ool01000Oomoo`000Woo00<007ooOol01Goo0P00@Woo0P00
1Woo00@007ooOol000=oo`04001oogoo0002Ool01@00Oomoogoo00000goo00<007ooOol00goo00<0
07ooOol017oo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol047oo00<007ooOol0:goo00<0
07ooOol0ogoo0goo00<007ooOol01goo000jOol00`00Oomoo`2eOol00`00Oomoo`0IOol00`00Oomo
o`0[Ool00`00Oomoo`0AOol00`00Oomoo`09Ool00`00Oomoo`05Ool01000Oomoogoo100017oo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`04001oo`000002Ool01P00Oomoo`00Ool000Moo`04001o
ogoo000BOol00`00Oomoo`0AOol00`00Oomoo`0@Ool01000Ool000002Goo00@007ooOol0009oo`80
0003Ool007oo009oo`05001oogooOol00004Ool70005Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool0
0`00Oomoo`0FOol00`00Oomoo`0EOol00`00Oomoo`0mOol00`00Oomoo`0EOol00`00Oomoo`0;Ool0
0`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00@007ooOol0009oo`04001oogoo0009Ool2000nOol20008Ool01000Oomoo`000Woo00D007oo
Oomoo`00009oo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`06
Ool00`00Oomoo`09Ool00`00Oomoo`0AOol00`00Oomoo`0[Ool00`00Oomoo`3oOol2Ool00`00Oomo
o`07Ool003Yoo`03001oogoo0;Eoo`03001oogoo01Qoo`03001oogoo02]oo`03001oogoo015oo`03
001oogoo00Uoo`03001oogoo00Ioo`03001oogoo009oo`@000=oo`03001oogoo009oo`05001oogoo
Ool00003Ool200001Goo001oogoo00000goo00<007ooOol01goo0`004Woo00<007ooOol04Goo00<0
07ooOol047oo0P002Woo00D007ooOomoo`00009oo`@000=oo`05001oogooOol00002Ool60002Ool0
0`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`0GOol00`00Oomoo`0DOol0
0`00Oomoo`0lOol00`00Oomoo`0FOol00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00@007ooOol000=oo`04001oogoo
000:Ool2000jOol20009Ool01@00Oomoogoo00000Woo00D007ooOomoo`00009oo`05001oogooOol0
0004Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomo
o`0AOol00`00Oomoo`0/Ool00`00Oomoo`3oOol1Ool00`00Oomoo`07Ool003Yoo`03001oogoo0;Eo
o`8001Qoo`03001oogoo02aoo`03001oogoo015oo`03001oogoo00Uoo`03001oogoo00Ioo`03001o
ogoo00=oo`D00003Ool007oo00=oo`06001oogooOol007oo0`000Woo00D007ooOomoo`0000=oo`03
001oogoo00Qoo`80015oo`03001oogoo015oo`03001oogoo00moo`8000Yoo`03001oogoo009oo`04
001oogoo0002Ool300000goo001oo`02Ool70004Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00
Oomoo`0;Ool00`00Oomoo`0GOol00`00Oomoo`0COol00`00Oomoo`0kOol00`00Oomoo`0FOol00`00
Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00
Oomoogoo00000goo00D007ooOomoo`00009oo`05001oogooOol0000;Ool2000fOol2000:Ool01@00
Oomoogoo00000goo00D007ooOomoo`00009oo`05001oogooOol00004Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0@Ool00`00Oomoo`0]Ool00`00
Oomoo`3oOol00`00Oomoo`07Ool003Yoo`03001oogoo0;Ioo`03001oogoo01Eoo`03001oogoo02ao
o`03001oogoo015oo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00=oo`P000=oo`03001o
o`0000@00005Ool007ooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`04000=
Ool00`00Oomoo`0AOol00`00Oomoo`0<Ool300000goo00000008Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000Woo00<007ooOol02`001Goo00<007ooOol017oo00<007ooOol01goo00<007ooOol02goo
00<007ooOol05goo00<007ooOol04Woo00<007ooOol0>Woo00<007ooOol05goo00<007ooOol02goo
00<007ooOol01Woo00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`00
00=oo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool3000`Ool3000;Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo015oo`8002ioo`03001o
ogoo0?ioo`03001oogoo00Moo`00>Woo00<007ooOol0]Woo00<007ooOol057oo00<007ooOol0;Goo
00<007ooOol04Goo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol040000Woo00D007ooOomo
o`00009oo`05001oogooOol00005Ool00`00Oomoo`05Ool00`00Oomoo`04Ool3000:Ool00`00Oomo
o`0AOol00`00Oomoo`08Ool40005Ool00`00Oomoo`05Ool00`00Oomoo`03Ool01@00Oomoogoo0000
0Woo00D007ooOomoo`0000=oo`P000=oo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00]o
o`03001oogoo01Qoo`03001oogoo015oo`03001oogoo03Uoo`03001oogoo01Qoo`03001oogoo00]o
o`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000Woo00<007ooOol00goo00<007ooOol037oo1000:7oo10003Woo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`0/
Ool00`00Oomoo`3nOol00`00Oomoo`07Ool003Yoo`03001oogoo0;Ioo`03001oogoo01=oo`03001o
ogoo02eoo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo00Moo`P000Aoo`03001oogoo009o
o`05001oogooOol00003Ool01000Oomoo`0017oo00<007ooOol00goo00<007ooOol017oo00<007oo
Ool01goo10001Woo00<007ooOol04Goo00<007ooOol017oo10002Goo00<007ooOol017oo00<007oo
Ool00goo00<007ooOol00Woo00@007ooOol000=oo`05001oogooOol00004Ool500000goo001oo`05
Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`0@Ool00`00Oomoo`0h
Ool00`00Oomoo`0HOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo00=oo`03
001oogoo00moo`<0029oo`<0015oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00002
Ool01@00Oomoogoo000017oo00<007ooOol00goo00<007ooOol017oo00<007ooOol01Woo00<007oo
Ool02Woo00<007ooOol04Woo00<007ooOol0;7oo00<007ooOol0oGoo00<007ooOol01goo000jOol0
0`00Oomoo`2fOol01000Oomoo`004Goo00<007ooOol0;Woo00<007ooOol04Goo00<007ooOol02Woo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool40002
Ool00`00Oomoo`0AOol00`00Oomoo`04000=Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`04001oogooOol30007Ool00`00Oomo
o`07Ool00`00Oomoo`0;Ool00`00Oomoo`0IOol00`00Oomoo`0?Ool00`00Oomoo`0gOol00`00Oomo
o`0HOol00`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00<007ooOol00Woo00@007ooOol000Ioo`03001oogoo015oo`@0
01Yoo`@001=oo`03001oogoo00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol01goo00<007ooOol02Woo00<007oo
Ool04Goo00<007ooOol0;Goo00<007ooOol0o7oo00<007ooOol01goo000jOol00`00Oomoo`2cOol0
1`00Oomoogoo001oo`00015oo`03001oogoo02eoo`03001oogoo019oo`03001oogoo00Yoo`03001o
ogoo00Ioo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool0
1@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol03goo1`003goo0`00
4Goo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`0<Ool0
0`00Oomoo`0HOol00`00Oomoo`0>Ool00`00Oomoo`0gOol00`00Oomoo`0HOol00`00Oomoo`0<Ool0
0`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00<007ooOol00Woo00@007ooOol000Moo`03001oogoo01Aoo`@000ioo`P001Ioo`03001oogoo
00=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00<007ooOol00goo
00<007ooOol017oo00<007ooOol01goo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol0;Woo
00<007ooOol0ngoo00<007ooOol01goo000jOol00`00Oomoo`2cOol20002Ool00`00Ool0000@Ool0
0`00Oomoo`0^Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00<007ooOol0
0Woo00<007ooOol01Goo00D007ooOomoo`00019oo`03001oogoo00=ooa0001=oo`05001oogooOol0
0007Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool00goo00<007ooOol017oo00<007ooOol01goo00<007ooOol037oo00<007ooOol06Goo00<007oo
Ool03Goo00<007ooOol0=Woo00<007ooOol06Goo00<007ooOol037oo00<007ooOol01goo00<007oo
Ool017oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`05
001oogooOol00007Ool2000HOol>000LOol20006Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000Eoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo
00Yoo`03001oogoo019oo`03001oogoo02ioo`03001oogoo0?Yoo`03001oogoo00Moo`00>Woo00<0
07ooOol0]7oo0P0000Aoo`00Ool000moo`03001oogoo02ioo`03001oogoo019oo`03001oogoo00Yo
o`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009o
o`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`05Ool01000Oomoo`004Woo00<007oo
Ool04Woo00<007ooOol04Goo00@007ooOol000Qoo`05001oogooOol00003Ool01@00Oomoogoo0000
17oo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol027oo00<007ooOol0
37oo00<007ooOol06Goo00<007ooOol037oo00<007ooOol0=Goo00<007ooOol06Woo00<007ooOol0
37oo00<007ooOol01goo00<007ooOol017oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0
0Woo00D007ooOomoo`0000Aoo`04001oogoo0009Ool00`00Oomoo`0nOol00`00Oomoo`05Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol00goo00<007ooOol00goo
00<007ooOol017oo00<007ooOol01Woo00<007ooOol02goo00<007ooOol04Goo00<007ooOol0;goo
00<007ooOol0nGoo00<007ooOol01goo000jOol00`00Oomoo`2dOol6000>Ool00`00Oomoo`0_Ool0
0`00Oomoo`0BOol00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol0
1Woo00<007oo00004Woo00<007ooOol04goo00<007ooOol047oo00<007oo000027oo00<007ooOol0
0Woo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`03001o
ogoo00Eoo`03001oogoo00Moo`03001oogoo00aoo`03001oogoo01Yoo`8000aoo`03001oogoo03=o
o`8001aoo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001o
ogoo009oo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo00002Goo00<007ooOol0
?7oo00<007ooOol01Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00005Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol0
0`00Oomoo`0`Ool00`00Oomoo`3hOol00`00Oomoo`07Ool003Yoo`03001oogoo0;Eoo`D000eoo`03
001oogoo02moo`03001oogoo019oo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Eoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool2000BOol00`00Oomoo`0COol00`00Oomoo`0@Ool20008Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol00goo00<007ooOol00goo00<007oo
Ool01Goo00<007ooOol01goo00<007ooOol03Goo00<007ooOol06goo00<007ooOol02Goo00<007oo
Ool0<Woo00<007ooOol077oo00<007ooOol037oo00<007ooOol01goo00<007ooOol01Goo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`03
001oogoo00Moo`8003Yoo`8000Qoo`03001oogoo00=oo`05001oogooOol00004Ool01@00Oomoogoo
00001Goo00<007ooOol00goo00<007ooOol017oo00<007ooOol01goo00<007ooOol02Woo00<007oo
Ool04Woo0P00<Goo00<007ooOol0mgoo00<007ooOol01goo000jOol00`00Oomoo`2eOol5000=Ool0
0`00Oomoo`0_Ool00`00Oomoo`0BOol00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`05Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0
0Woo00<007ooOol01Woo00<007oo00004Goo00<007ooOol04goo00<007ooOol03goo00<007oo0000
27oo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo01aoo`03001o
ogoo00Qoo`03001oogoo035oo`03001oogoo01eoo`03001oogoo00aoo`03001oogoo00Moo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00004Ool0
0`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`0fOol00`00Oomoo`08Ool00`00Oomoo`03Ool0
1@00Oomoogoo000017oo00D007ooOomoo`0000Eoo`03001oogoo00=oo`03001oogoo00Aoo`03001o
ogoo00Moo`03001oogoo00Yoo`03001oogoo01=oo`03001oogoo02moo`03001oogoo0?Moo`03001o
ogoo00Moo`00>Woo00<007ooOol0]Woo100037oo00<007ooOol0;goo00<007ooOol04goo00<007oo
Ool02Woo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool00Woo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00Eoo`04001oogoo000@Ool0
0`00Oomoo`0COol00`00Oomoo`0>Ool01000Oomoo`001goo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol01Goo
00<007ooOol01goo00<007ooOol03Woo00<007ooOol077oo00<007ooOol01goo00<007ooOol0<7oo
00<007ooOol07Goo00<007ooOol03Goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol02Goo00<007ooOol0=7oo00<007ooOol027oo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol00Woo00D007ooOomoo`0000Eoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo
00Moo`03001oogoo00Yoo`03001oogoo01Aoo`03001oogoo02moo`03001oogoo0?Ioo`03001oogoo
00Moo`00>Woo00<007ooOol0]goo0`002goo00<007ooOol0<7oo00<007ooOol04Woo00<007ooOol0
2goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
0Woo00D007ooOomoo`0000Eoo`03001oogoo00=oo`03001oogoo00Aoo`04001oogooOol2000>Ool0
0`00Oomoo`0COol00`00Oomoo`0<Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`06Ool00`00Oomoo`07Ool00`00Oomoo`0=Ool00`00Oomoo`0MOol00`00Oomoo`06Ool00`00Oomo
o`0_Ool00`00Oomoo`0NOol00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`09Ool2000bOol2000;Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool01@00Oomoogoo00001Goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01Woo00<0
07ooOol02goo00<007ooOol04goo00<007ooOol0<7oo00<007ooOol0mGoo00<007ooOol01goo000j
Ool00`00Oomoo`2gOol3000;Ool00`00Oomoo`0_Ool00`00Oomoo`0COol00`00Oomoo`0;Ool00`00
Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00
Oomoogoo000017oo00<007ooOol00goo00<007ooOol017oo00<007ooOol00goo0P0037oo00<007oo
Ool04goo00<007ooOol02Woo0P001Goo00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol01Woo
00<007ooOol01goo00<007ooOol03Goo00<007ooOol07Woo00<007ooOol00Woo00<007oo0000<Goo
00<007ooOol07goo00<007ooOol037oo00<007ooOol01goo00<007ooOol01Woo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol02goo0P00;Woo0P003Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01goo
00<007ooOol02Woo00<007ooOol04goo00<007ooOol0<Goo00<007ooOol0m7oo00<007ooOol01goo
000jOol00`00Oomoo`2hOol2000:Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00Oomoo`0;Ool0
0`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
1@00Oomoogoo00001Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol01Woo0P002Woo00<0
07ooOol04goo00<007ooOol027oo0P001goo00<007ooOol00goo00<007ooOol00goo00<007ooOol0
0goo00D007ooOomoo`0000Eoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo00Moo`03001oogoo00ioo`03001oogoo01ioo`07001oogooOol007oo00000goo00<007ooOol0
:Woo00<007ooOol07goo00<007ooOol03Goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000Eoo`03001oogoo00=oo`03001o
ogoo00aoo`8002Yoo`8000ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`03001o
ogoo00Yoo`03001oogoo01Aoo`03001oogoo031oo`03001oogoo0?Aoo`03001oogoo00Moo`00>Woo
00<007ooOol0^7oo0P002Woo00<007ooOol0;goo00<007ooOol04goo00<007ooOol02goo00<007oo
Ool01goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo00D007oo
Oomoo`0000Eoo`03001oogoo00Aoo`05001oogooOol0000:Ool20008Ool00`00Oomoo`0COol00`00
Oomoo`06Ool2000:Ool01@00Oomoogoo00001Woo00<007ooOol00goo00D007ooOomoo`0000Eoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo00eoo`03
001oogoo01moo`800004Ool000000003Ool00`00Oomoo`0YOol00`00Oomoo`0POol00`00Oomoo`0<
Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool01@00Oomoogoo00001Goo00<007ooOol017oo00<007ooOol03Goo00<007ooOol09Goo0P003goo
00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol00goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol02goo00<007ooOol04goo
00<007ooOol0<Goo00<007ooOol0lgoo00<007ooOol01goo000jOol00`00Oomoo`2iOol00`00Oomo
o`07Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo00<0
07ooOol01Goo00@007ooOol000aoo`<000Eoo`03001oogoo01=oo`03001oogoo00=oo`<000aoo`04
001oogoo0007Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`0>Ool00`00Oomoo`0POol4
0002Ool00`00Oomoo`0YOol00`00Oomoo`0POol00`00Oomoo`0=Ool00`00Oomoo`08Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool2000SOol2000@Ool00`00Oomoo`04Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`05Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`0COol00`00Oomoo`0bOol00`00Oomo
o`3bOol00`00Oomoo`07Ool003Yoo`03001oogoo0;Yoo`03001oogoo00Eoo`03001oogoo031oo`03
001oogoo01Aoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03
001oo`0000moo`8000=oo`03001oogoo01=oo`04001oogooOol2000?Ool00`00Ool00007Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00
Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0>Ool00`00Oomoo`0QOol300000goo0000000ZOol0
0`00Oomoo`0QOol00`00Oomoo`0=Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`05Ool0
0`00Oomoo`0>Ool2000NOol3000AOol00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`0:Ool00`00Oomoo`0DOol00`00Oomoo`0aOol00`00Oomoo`3bOol00`00Oomoo`07Ool0
03Yoo`03001oogoo0;Yoo`03001oogoo00Aoo`03001oogoo035oo`03001oogoo01=oo`03001oogoo
00aoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oo`00015oo`D001Aoo`03
001oo`000080011oo`03001oo`0000Moo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00io
o`03001oogoo021oo`D002Uoo`8002=oo`03001oogoo00ioo`03001oogoo00Qoo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo00Eoo`03001oogoo011oo`@001Eoo`D001=oo`03001oogoo00Eoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo00]oo`03001oogoo01Aoo`03001oogoo035oo`800?9oo`03001o
ogoo00Moo`00>Woo00<007ooOol0^Woo00<007ooOol00goo00<007ooOol0<Woo00<007ooOol04goo
00<007ooOol037oo00<007ooOol01goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00goo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol04goo
00<007oo00000`002goo1`004goo0P0027oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol00goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol0
3Woo00<007ooOol087oo1@009goo0P009Goo00<007ooOol03Woo00<007ooOol027oo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol01Woo00<007ooOol04goo1`002Woo10005goo00<007ooOol01Woo00<007ooOol0
0goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol0
1Woo00<007ooOol01goo00<007ooOol02goo00<007ooOol057oo00<007ooOol0<Woo00<007ooOol0
l7oo00<007ooOol01goo000jOol00`00Oomoo`2kOol00`00Oomoo`02Ool00`00Oomoo`0aOol00`00
Oomoo`0DOol00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`05Ool2000D
Ool00`00Oomoo`03Ool;0005Ool00`00Oomoo`0BOol20007Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`08
Ool00`00Oomoo`0>Ool00`00Oomoo`0QOol300000goo0000000SOol2000VOol00`00Oomoo`0>Ool0
0`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
0`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`0IOol:000JOol00`00Oomo
o`06Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`0EOol00`00Oomo
o`0bOol00`00Oomoo`3_Ool00`00Oomoo`07Ool003Yoo`03001oogoo0;]oo`05001oogooOol0000d
Ool00`00Oomoo`0COol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`05
Ool01000Ool000004Woo00<007ooOol04goo00<007ooOol04Goo00<007oo00001goo00<007ooOol0
0goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0
1Woo00<007ooOol02Goo00<007ooOol03Woo00<007ooOol087oo0`000goo00<007ooOol07Woo0P00
:7oo00<007ooOol03Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol0
0goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol01goo00<007ooOol0
>Woo0P002Goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol037oo00<007ooOol057oo00<0
07ooOol0<goo00<007ooOol0kWoo00<007ooOol01goo000jOol00`00Oomoo`2kOol01000Oomoo`00
=7oo00<007ooOol057oo00<007ooOol037oo00<007ooOol027oo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0
17oo00D007ooOomoo`00015oo`03001oogoo01=oo`03001oogoo011oo`04001oogoo0006Ool00`00
Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00
Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0>Ool00`00Oomoo`0POol30004Ool2000LOol2000Y
Ool00`00Oomoo`0?Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`07Ool2000iOol00`00
Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0<Ool00`00Oomoo`0EOol00`00
Oomoo`0bOol00`00Oomoo`3^Ool00`00Oomoo`07Ool003Yoo`03001oogoo0;]oo`04001oogoo000d
Ool00`00Oomoo`0DOol00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`04
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0COol00`00Oomoo`0?Ool01@00Oomoogoo
00001Goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol017oo00<007oo
Ool017oo00<007ooOol01goo00<007ooOol027oo00<007ooOol03Woo00<007ooOol087oo0P001goo
0P0067oo0P00:goo00<007ooOol03Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol017oo
00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol027oo
00<007ooOol0=Goo00<007ooOol02Goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo
00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol027oo00<007ooOol02goo
00<007ooOol05Goo00<007ooOol0<goo00<007ooOol0kGoo00<007ooOol01goo000jOol00`00Oomo
o`2lOol2000dOol00`00Oomoo`0EOol00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`06Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`0COol00`00Oomoo`0>Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool0
0`00Oomoo`0OOol20009Ool3000BOol3000/Ool00`00Oomoo`0?Ool00`00Oomoo`09Ool00`00Oomo
o`06Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`04Ool00`00Oomoo`09Ool00`00Oomoo`0cOol00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`08Ool00`00Oomoo`0;Ool00`00Oomoo`0EOol00`00Oomoo`0cOol00`00Oomoo`3]Ool00`00Oomo
o`07Ool003Yoo`03001oogoo0;aoo`03001oogoo03=oo`03001oogoo01Aoo`03001oogoo00aoo`03
001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo009oo`03001oogoo00Eoo`05001oogooOol00007Ool00`00Oomoo`0<Ool00`00Oomoo`0C
Ool00`00Oomoo`0<Ool20006Ool01@00Oomoogoo00001goo00<007ooOol00goo00<007ooOol00goo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol03Woo
00<007ooOol07goo00<007ooOol02goo10002goo0`00;goo00<007ooOol03goo00<007ooOol027oo
00<007ooOol01goo00<007ooOol017oo00<007ooOol017oo00<007ooOol00goo00<007ooOol017oo
00<007ooOol017oo00<007ooOol02Goo00<007ooOol0<Goo00<007ooOol02Woo00<007ooOol017oo
00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol027oo00<007ooOol037oo00<007ooOol05Goo00<007ooOol0<goo00<007ooOol0k7oo
00<007ooOol01goo000jOol00`00Oomoo`2kOol2000dOol00`00Oomoo`0EOol00`00Oomoo`0<Ool0
0`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomoo`0027oo0P0037oo00<007ooOol04goo00<007oo
Ool02goo00<007ooOol01Woo00D007ooOomoo`0000Ioo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00moo`03
001oogoo01ioo`03001oogoo00moo`/0035oo`03001oogoo00moo`03001oogoo00Uoo`03001oogoo
00Moo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Uoo`8002moo`8000aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo
00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`8000Uoo`03001oogoo00aoo`03
001oogoo01Eoo`03001oogoo03Aoo`03001oogoo0>]oo`03001oogoo00Moo`002Woo30002goo1000
5Goo00<007ooOol0^goo00<007oo0000<goo00<007ooOol05Goo00<007ooOol037oo00<007ooOol0
27oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00goo00<007ooOol017oo00<007ooOol0
0goo00<007ooOol01Goo00@007oo000000Yoo`8000Yoo`03001oogoo01=oo`03001oogoo00Yoo`03
001oogoo00Moo`80009oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00moo`03001oogoo
01eoo`03001oogoo04aoo`03001oogoo00moo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo
00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00]oo`03001oogoo02Yoo`8000ioo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00aoo`03
001oogoo01Eoo`03001oogoo03Aoo`03001oogoo0>]oo`03001oogoo00Moo`002Woo30002Goo2000
4goo00<007ooOol0^Woo00@007ooOol0039oo`03001oogoo01Eoo`03001oogoo00aoo`03001oogoo
00Uoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo
00Aoo`03001oogoo00Eoo`8000eoo`8000Qoo`03001oogoo01=oo`03001oogoo00Qoo`8000]oo`03
001oo`0000Ioo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oogoo00Ioo`03001oogoo00Uoo`03001oogoo011oo`03001oogoo01aoo`03001oogoo04]oo`03
001oogoo011oo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00]oo`8002Uoo`03001oogoo
00eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo
00Aoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00aoo`03001oogoo01Eoo`03001oogoo
03Aoo`03001oogoo0>Yoo`03001oogoo00Moo`002goo0`001Woo0P002Goo0P0017oo0P004goo00<0
07ooOol0^Goo00D007ooOomoo`00039oo`03001oogoo01Eoo`03001oogoo00aoo`03001oogoo00Uo
o`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Ao
o`03001oogoo00Ioo`03001oogoo00eoo`8000Ioo`03001oogoo01=oo`03001oogoo00Ioo`8000eo
o`8000Moo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo00Ioo`03001oogoo00Yoo`03001oogoo00moo`03001oogoo01aoo`03001oogoo04]oo`03001o
ogoo00moo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00aoo`03001oogoo02Eoo`03001o
ogoo00eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00aoo`03001oogoo01Eoo`03001o
ogoo03Eoo`03001oogoo0>Uoo`03001oogoo00Moo`0037oo0`003goo0P001Woo0P004Woo00<007oo
Ool0^Goo00<007ooOol00Woo00<007ooOol0;goo00<007ooOol05Goo00<007ooOol037oo00<007oo
Ool02Goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007oo
Ool017oo00<007ooOol017oo00<007oo000047oo0P000goo00<007ooOol057oo00<007ooOol017oo
0P003goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007oo
Ool01Goo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol03goo00<007ooOol077oo00<007oo
Ool0Bgoo00<007ooOol03goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol01Goo00<007oo
Ool00goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Woo00<007ooOol03Goo0P008goo
0P003goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007oo
Ool017oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol037oo00<007ooOol05Woo00<007oo
Ool0=7oo00<007ooOol0jGoo00<007ooOol01goo000=Ool3000>Ool20006Ool2000BOol00`00Oomo
o`2hOol00`00Oomoo`03Ool00`00Oomoo`0^Ool00`00Oomoo`0FOol00`00Oomoo`0<Ool00`00Oomo
o`08Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool00`00Ool0000BOol200000goo001oo`0EOol00`00Oomoo`02Ool2000@
Ool00`00Ool00006Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`0@Ool00`00Oomoo`0KOol00`00Oomoo`1:
Ool00`00Oomoo`0@Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`04
Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`0>Ool2000NOol3000A
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`05
Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00Oomoo`0EOol00`00Oomoo`0e
Ool00`00Oomoo`3XOol00`00Oomoo`07Ool000ioo`<000aoo`8000Qoo`80015oo`03001oogoo0;Qo
o`03001oogoo00=oo`8002moo`03001oogoo01Eoo`03001oogoo00eoo`03001oogoo00Qoo`03001o
ogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00Aoo`03001o
ogoo00Aoo`04001oogoo000COol2000GOol4000BOol00`00Ool00006Ool00`00Oomoo`05Ool00`00
Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00
Oomoo`0@Ool00`00Oomoo`0JOol00`00Oomoo`1;Ool00`00Oomoo`0@Ool00`00Oomoo`09Ool00`00
Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00
Oomoo`07Ool00`00Oomoo`0?Ool3000IOol2000COol00`00Oomoo`06Ool00`00Oomoo`04Ool00`00
Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00
Oomoo`0<Ool00`00Oomoo`0FOol00`00Oomoo`0eOol00`00Oomoo`3WOol00`00Oomoo`07Ool000mo
o`<000]oo`8000Qoo`80015oo`03001oogoo0;Moo`03001oogoo00Eoo`03001oogoo02eoo`03001o
ogoo01Eoo`03001oogoo00eoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00=oo`05001oogooOol0000COol3
000COol3000DOol01000Oomoo`001Woo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol01goo00<007ooOol02Woo00<007ooOol047oo00<007ooOol06Goo
00<007ooOol0BWoo00<007ooOol047oo00<007ooOol02Woo00<007ooOol01goo00<007ooOol01Woo
00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol027oo00<007ooOol04Goo
10004Woo0`0057oo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol037oo00<007ooOol05Woo
00<007ooOol0=Goo00<007ooOol0igoo00<007ooOol01goo000@Ool3000:Ool20008Ool2000AOol8
002aOol00`00Oomoo`06Ool00`00Oomoo`0/Ool00`00Oomoo`0FOol00`00Oomoo`0=Ool00`00Oomo
o`08Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool01@00Oomoogoo00001Goo00<007ooOol047oo00<007ooOol020001Woo1@000Woo00<007oo
Ool04Goo00@007ooOomoo`8000Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo01Qoo`03
001oogoo04Uoo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Ioo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo01Aoo`D0
00Eoo`P001Ioo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00eoo`03001oogoo01Ioo`03
001oogoo03Eoo`03001oogoo0=moo`P000Uoo`004Goo0`002Goo0P0027oo0P004Goo00<007ooOol0
]Woo00<007ooOol01Woo00<007ooOol0;7oo00<007ooOol05Woo00<007ooOol03Goo00<007ooOol0
27oo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00D007ooOomoo`0000Eoo`03001oogoo011oo`03001oogoo00Qoo`H000Moo`03001oogoo011o
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo01Qo
o`03001oogoo04Uoo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo01Uo
o`D001eoo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo00Eoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00eoo`03001oogoo01Ioo`03001o
ogoo03Ioo`03001oogoo0>Eoo`03001oogoo00Moo`004Woo0`0027oo0P0027oo0P004Goo00<007oo
Ool0]Goo00<007ooOol027oo00<007ooOol0:Woo00<007ooOol05goo00<007ooOol03Goo00<007oo
Ool027oo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007oo
Ool01Woo00@007oo000000Ioo`03001oogoo00moo`03001oogoo01Eoo`03001oogoo00moo`03001o
ogoo00Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo019oo`03001oogoo01Moo`03001o
ogoo04Qoo`03001oogoo019oo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Ioo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo03Uoo`03001o
ogoo00Qoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo00Ioo`03001oogoo00Uoo`03001oogoo00eoo`03001oogoo01Ioo`03001oogoo03Ioo`03001o
ogoo0>Eoo`03001oogoo00Moo`004goo0P0027oo0P0027oo0P004Goo00<007ooOol0]7oo00<007oo
Ool02Goo00<007ooOol0:Woo00<007ooOol05Woo00<007ooOol03Goo00<007ooOol02Goo00<007oo
Ool01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007oo
000027oo00<007ooOol03Woo00<007ooOol05Goo00<007ooOol03goo00<007ooOol01Goo00@007oo
Ool000Moo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Moo`03001o
ogoo00]oo`03001oogoo015oo`03001oogoo01Ioo`03001oogoo04Uoo`03001oogoo015oo`03001o
ogoo00]oo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Aoo`03001o
ogoo00Eoo`03001oogoo00Uoo`03001oogoo03Moo`03001oogoo00Uoo`03001oogoo00Eoo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Uoo`03001o
ogoo00ioo`03001oogoo01Ioo`03001oogoo03Ioo`03001oogoo0>Aoo`03001oogoo00Moo`0057oo
0P001goo0P0027oo0P004Goo00<007ooOol0]7oo00<007ooOol02Woo00<007ooOol0:Goo00<007oo
Ool05Woo00<007ooOol03Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol01Woo0P002Goo00<007ooOol03Goo00<007ooOol05Goo
00<007ooOol03Woo00<007ooOol01Woo00@007ooOol000Moo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00]oo`03001oogoo015oo`03001oogoo01Io
o`03001oogoo04Uoo`03001oogoo015oo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo03Eo
o`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00ioo`03001oogoo01Ioo`03001oogoo03Io
o`03001oogoo0>Aoo`03001oogoo00Moo`0057oo0P001goo0P0027oo0P004Goo00<007ooOol0/goo
00<007ooOol02goo00<007ooOol0:7oo00<007ooOol05goo00<007ooOol03Goo00<007ooOol02Goo
00<007ooOol01goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Woo
0P002Woo0P003Goo00<007ooOol05Goo00<007ooOol03Goo00<007ooOol01goo00<007oo00001goo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol02Woo
00<007ooOol04Woo00<007ooOol05Goo00<007ooOol0B7oo00<007ooOol04Woo00<007ooOol02goo
00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol02Woo00<007ooOol0<Woo0P0037oo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool017oo00<007ooOol01Woo00<007ooOol01goo00<007ooOol02Goo00<007ooOol03Goo00<007oo
Ool05Woo00<007ooOol0=goo00<007ooOol0hgoo00<007ooOol01goo000;Ool20007Ool20008Ool2
0006Ool2000BOol00`00Oomoo`2cOol00`00Oomoo`0;Ool00`00Oomoo`0XOol00`00Oomoo`0GOol0
0`00Oomoo`0=Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0EOol0
0`00Oomoo`0;Ool2000:Ool20008Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool0
0`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomoo`0BOol00`00Oomoo`0EOol00`00Oomoo`18Ool0
0`00Oomoo`0BOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0`Ool00`00Oomoo`0<Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`09Ool00`00Oomoo`0=Ool00`00Oomoo`0GOol00`00Oomoo`0gOol00`00Oomoo`3ROol0
0`00Oomoo`07Ool000]oo`<000Ioo`8000Qoo`8000Ioo`80019oo`03001oogoo0;9oo`03001oogoo
00eoo`03001oogoo02Moo`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Uoo`03001oogoo
00Moo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`8000eoo`03
001oogoo00Uoo`03001oogoo01Eoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Ioo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Yoo`03
001oogoo019oo`03001oogoo01Eoo`03001oogoo04Qoo`03001oogoo019oo`03001oogoo00]oo`03
001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03
001oogoo00]oo`03001oogoo02ioo`03001oogoo00aoo`03001oogoo00Ioo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00eoo`03
001oogoo01Moo`03001oogoo03Moo`03001oogoo0>9oo`03001oogoo00Moo`002goo100017oo0P00
2Woo0P0017oo0P004goo00<007ooOol0/Woo00<007ooOol03Goo00<007ooOol09Woo00<007ooOol0
5goo00<007ooOol03Goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007oo00003Woo00<007ooOol01goo00<007ooOol0
5Woo00<007ooOol02Goo00<007ooOol02goo0P001goo00<007ooOol01Woo00<007ooOol01Goo00<0
07ooOol01Woo00<007ooOol027oo00<007ooOol02goo00<007ooOol04Woo00<007ooOol04goo00<0
07ooOol0B7oo00<007ooOol04Woo00<007ooOol037oo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol0;7oo00<0
07ooOol037oo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol02Goo00<007ooOol03Woo00<007ooOol05Woo00<007ooOol0>7oo00<0
07ooOol0hGoo00<007ooOol01goo000<Ool8000;Ool8000COol00`00Oomoo`2aOol00`00Oomoo`0?
Ool00`00Ool0000UOol00`00Oomoo`0GOol00`00Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`00
3Woo0P001goo00<007ooOol05Woo00<007ooOol01goo0P003Woo00<007oo00001Woo00<007ooOol0
1Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol02goo00<007ooOol0
4Woo00<007ooOol04goo00<007ooOol0B7oo00<007ooOol04Woo00<007ooOol02goo00<007ooOol0
27oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01goo00<007ooOol0
2goo0`00:Woo0P003Goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
1Woo00<007ooOol01goo00<007ooOol02Goo00<007ooOol03Woo00<007ooOol05goo00<007ooOol0
=goo00<007ooOol0hGoo00<007ooOol01goo000>Ool5000>Ool4000EOol00`00Oomoo`2`Ool00`00
Oomoo`0@Ool00`00Ool0000UOol00`00Oomoo`0GOol00`00Oomoo`0=Ool00`00Oomoo`0:Ool00`00
Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000
Oomoo`0047oo00<007ooOol017oo00<007ooOol05Woo00<007ooOol01Goo0P0047oo00<007oo0000
1Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol0
2goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol0B7oo00<007ooOol04Woo00<007ooOol0
2goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol0
1goo00<007ooOol03Woo00<007ooOol09Goo0P003goo00<007ooOol01goo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol02Goo00<007ooOol03Woo00<0
07ooOol05goo00<007ooOol0=goo00<007ooOol0hGoo00<007ooOol01goo000jOol00`00Oomoo`2`
Ool00`00Oomoo`0AOol3000TOol00`00Oomoo`0FOol00`00Oomoo`0>Ool00`00Oomoo`0:Ool00`00
Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`0>Ool20004Ool00`00Oomoo`0GOol00`00Oomoo`02Ool2000AOol00`00
Oomoo`020005Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`08Ool0
0`00Oomoo`0;Ool00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`17Ool00`00Oomoo`0COol0
0`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`07Ool00`00Oomoo`0>Ool2000SOol2000@Ool00`00Oomoo`07Ool00`00Oomoo`06Ool0
0`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`0>Ool0
0`00Oomoo`0HOol00`00Oomoo`0gOol00`00Oomoo`3POol00`00Oomoo`07Ool003Yoo`03001oogoo
0:moo`03001oogoo00ioo`80009oo`<002=oo`03001oogoo01Moo`03001oogoo00ioo`03001oogoo
00Yoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo00moo`80009oo`03001oogoo01Moo`03001oogoo0080019o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Io
o`03001oogoo00Qoo`03001oogoo00aoo`03001oogoo01=oo`03001oogoo011oo`03001oogoo04Mo
o`03001oogoo01=oo`03001oogoo00aoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Mo
o`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo00moo`03001oogoo01moo`03001oogoo011o
o`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Mo
o`03001oogoo00Uoo`03001oogoo00ioo`03001oogoo01Qoo`03001oogoo03Qoo`03001oogoo0=mo
o`03001oogoo00Moo`00>Woo00<007ooOol0[goo00<007ooOol03goo0P0000Aoo`00000002=oo`03
001oogoo01Moo`03001oogoo00ioo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Eoo`03
001oogoo00Ioo`03001oogoo00Ioo`04001oogoo0007Ool00`00Oomoo`0@Ool3000IOol3000COol0
0`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`0COol00`00Oomoo`0@Ool00`00Oomoo`17Ool0
0`00Oomoo`0COol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`0LOol2000BOol00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`09Ool00`00Oomoo`0>Ool00`00Oomoo`0HOol00`00Oomoo`0hOol00`00Oomoo`3OOol00`00Oomo
o`07Ool003Yoo`03001oogoo0:ioo`03001oogoo015oo`800004Ool00000000ROol00`00Oomoo`0G
Ool00`00Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`06
Ool00`00Oomoo`05Ool01000Oomoo`001goo00<007ooOol04Woo00<007ooOol05Woo0P0057oo00<0
07ooOol01Goo00D007ooOomoo`0000Qoo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Uo
o`03001oogoo00]oo`03001oogoo01Aoo`03001oogoo00moo`03001oogoo04Ioo`03001oogoo01Ao
o`03001oogoo00aoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Io
o`03001oogoo00Qoo`03001oogoo011oo`<001Uoo`8001Aoo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Yoo`03001oogoo00io
o`03001oogoo01Moo`03001oogoo03Uoo`03001oogoo0=ioo`03001oogoo00Moo`00>Woo00<007oo
Ool0[Woo00<007ooOol04Woo1@008Goo00<007ooOol05goo00<007ooOol03Woo00<007ooOol02Woo
00<007ooOol027oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo0`0027oo00<007oo
Ool04Goo10004goo0P0000=oo`00Ool04goo00<007ooOol01Goo00@007ooOol000Uoo`03001oogoo
00Eoo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo01Aoo`03001oogoo
00ioo`8004Qoo`03001oogoo01Aoo`03001oogoo00aoo`03001oogoo00Qoo`03001oogoo00Moo`03
001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo01=oo`@0019oo`<001Eoo`03
001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Qoo`03
001oogoo00Yoo`03001oogoo00ioo`03001oogoo01Qoo`03001oogoo03Uoo`03001oogoo0=eoo`03
001oogoo00Moo`00>Woo00<007ooOol0[Woo00<007ooOol04goo10008Goo00<007ooOol05goo00<0
07ooOol03Woo00<007ooOol02Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol01Woo00<0
07ooOol01Woo0P002Woo00<007ooOol047oo00@007ooOomoo`@000]oo`@000=oo`03001oogoo015o
o`03001oogoo00Moo`03001oo`0000Qoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Uo
o`03001oogoo00aoo`03001oogoo01Aoo`03001oogoo00eoo`03001oogoo04Ioo`03001oogoo01Eo
o`03001oogoo00aoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo00Qoo`03001oogoo01Ioo`@000Yoo`@001Moo`03001oogoo00Qoo`03001oogoo00Io
o`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Yoo`03001oogoo00io
o`03001oogoo01Qoo`03001oogoo03Uoo`03001oogoo0=eoo`03001oogoo00Moo`00>Woo00<007oo
Ool0[Goo00<007ooOol05Goo10007goo00<007ooOol067oo00<007ooOol03Woo00<007ooOol02Woo
00<007ooOol027oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo0P002goo00<007oo
Ool03goo00<007ooOol01Goo2`001goo00<007ooOol047oo00<007ooOol027oo0P002Goo00<007oo
Ool01Woo00<007ooOol01goo00<007ooOol02Goo00<007ooOol037oo00<007ooOol057oo00<007oo
Ool03Goo00<007ooOol0AWoo00<007ooOol05Goo00<007ooOol037oo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol06Goo2P006Woo
00<007ooOol02Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol027oo
00<007ooOol02Woo00<007ooOol03Woo00<007ooOol067oo00<007ooOol0>Woo00<007ooOol0g7oo
00<007ooOol01goo000jOol00`00Oomoo`2]Ool00`00Oomoo`0FOol3000OOol00`00Oomoo`0HOol0
0`00Oomoo`0>Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool2000;Ool00`00Oomoo`0?Ool00`00Oomoo`0GOol00`00Oomoo`0?Ool00`00Oomo
o`0:Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomo
o`0<Ool00`00Oomoo`0DOol00`00Oomoo`0=Ool00`00Oomoo`16Ool00`00Oomoo`0EOol00`00Oomo
o`0<Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomo
o`0:Ool00`00Oomoo`0kOol00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomoo`0>Ool00`00Oomoo`0HOol00`00Oomo
o`0jOol00`00Oomoo`3LOol00`00Oomoo`07Ool003Yoo`03001oogoo0:eoo`03001oogoo01Moo`80
01moo`03001oogoo01Qoo`03001oogoo00ioo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo
00Moo`03001oogoo00Ioo`03001oogoo00Aoo`800003Ool007oo00Yoo`03001oogoo00eoo`03001o
ogoo01Qoo`03001oogoo00ioo`03001oogoo00Yoo`8000Qoo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Uoo`03001oogoo00aoo`03001oogoo01Eoo`03001oogoo00]oo`03001oogoo04Io
o`03001oogoo01Ioo`03001oogoo00aoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo03Uoo`03001oogoo00Uoo`03001oogoo00Mo
o`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Yoo`03001oogoo00io
o`03001oogoo01Qoo`03001oogoo03]oo`03001oogoo0=]oo`03001oogoo00Moo`00>Woo00<007oo
Ool0[7oo00<007ooOol06Goo0P007Goo00<007ooOol06Goo00<007ooOol03Woo00<007ooOol02Woo
00<007ooOol027oo00<007ooOol01goo00<007ooOol01Woo00<007ooOol017oo00@007ooOol000ao
o`03001oogoo00aoo`03001oogoo01Qoo`03001oogoo00ioo`03001oogoo00Yoo`<000Moo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00aoo`03001oogoo01Eoo`03001o
ogoo00]oo`03001oogoo04Ioo`03001oogoo01Eoo`03001oogoo00eoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00]oo`03001oogoo03Moo`03001o
ogoo00Yoo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Qoo`03001o
ogoo00Yoo`03001oogoo00moo`03001oogoo01Qoo`03001oogoo03Yoo`03001oogoo0=]oo`03001o
ogoo00Moo`00>Woo00<007ooOol0[7oo00<007ooOol06Goo0P007Goo00<007ooOol06Goo00<007oo
Ool03Woo00<007ooOol02Woo00<007ooOol027oo00<007ooOol01goo00<007ooOol01Woo00<007oo
Ool00goo0P000goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol067oo00<007ooOol03Goo
00<007ooOol02goo00<007oo00001Woo00<007ooOol027oo00<007ooOol01goo00<007ooOol02Goo
00<007ooOol037oo00<007ooOol05Woo00<007ooOol02Woo00<007ooOol0AWoo00<007ooOol05Goo
00<007ooOol03Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol01Woo
00<007ooOol037oo00<007ooOol0=Goo00<007ooOol02Woo00<007ooOol027oo00<007ooOol01Woo
00<007ooOol01goo00<007ooOol027oo00<007ooOol02Woo00<007ooOol03goo00<007ooOol067oo
00<007ooOol0>Woo00<007ooOol0fgoo00<007ooOol01goo000jOol00`00Oomoo`2[Ool00`00Oomo
o`0KOol00`00Oomoo`0KOol00`00Oomoo`0HOol00`00Oomoo`0?Ool00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`0;Ool2000;Ool00`00Oomoo`0HOol00`00Oomoo`0<Ool00`00Oomoo`0;Ool01@00Oomoogoo0000
1Goo00<007ooOol01goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol03Goo00<007ooOol0
5Goo00<007ooOol02Goo0P00Agoo00<007ooOol05Woo00<007ooOol037oo00<007ooOol02Woo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol037oo00<007ooOol0<Woo0P00
3Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol0
2goo00<007ooOol03Woo00<007ooOol067oo00<007ooOol0>goo00<007ooOol0fWoo00<007ooOol0
1goo000jOol00`00Oomoo`2ZOol00`00Oomoo`0LOol2000LOol00`00Oomoo`0HOol00`00Oomoo`0?
Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`06Ool01000Oomoogoo
0P001Goo00<007ooOol037oo00<007ooOol027oo00<007ooOol06Goo00<007ooOol02Goo0P003Woo
00D007ooOomoo`0000Eoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo
00eoo`03001oogoo01Ioo`03001oogoo00Moo`8004Qoo`03001oogoo01Ioo`03001oogoo00aoo`03
001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00eoo`03
001oogoo031oo`03001oogoo00aoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00]oo`03001oogoo00ioo`03001oogoo01Uoo`03001oogoo03Yoo`03
001oogoo0=Yoo`03001oogoo00Moo`00>Woo00<007ooOol0ZWoo00<007ooOol07Goo00<007ooOol0
6Goo00<007ooOol06Goo00<007ooOol03goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
1goo00<007ooOol01Woo00D007ooOomoo`0000Ioo`03001oogoo00eoo`03001oogoo00Moo`03001o
ogoo01Uoo`03001oogoo00Qoo`03001oogoo00eoo`03001oogoo00=oo`05001oogooOol0000:Ool0
0`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`0=Ool00`00Oomoo`0FOol00`00Oomoo`07Ool2
0018Ool00`00Oomoo`0EOol00`00Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`0=Ool00`00Oomoo`0^Ool00`00Oomoo`0=Ool00`00Oomo
o`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomo
o`0?Ool00`00Oomoo`0HOol00`00Oomoo`0kOol00`00Oomoo`3IOol00`00Oomoo`07Ool003Yoo`03
001oogoo0:Uoo`03001oogoo01moo`03001oogoo01Qoo`03001oogoo01Uoo`03001oogoo00moo`03
001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Moo`03001oo`0000Qoo`03
001oogoo00eoo`8000Moo`03001oogoo01Uoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo
00Aoo`05001oogooOol0000:Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`0=Ool00`00
Oomoo`0GOol00`00Oomoo`06Ool20017Ool00`00Oomoo`0FOol00`00Oomoo`0=Ool00`00Oomoo`0:
Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool2000/Ool2000?
Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0;
Ool00`00Oomoo`0?Ool00`00Oomoo`0IOol00`00Oomoo`0kOol00`00Oomoo`3HOol00`00Oomoo`07
Ool003Yoo`03001oogoo0:Uoo`03001oogoo01moo`03001oogoo01Qoo`03001oogoo01Uoo`03001o
ogoo00moo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Moo`03001o
o`0000Qoo`03001oogoo00moo`03001oogoo00Aoo`03001oogoo01Uoo`03001oogoo00Eoo`80011o
o`03001oogoo00Aoo`80009oo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Uoo`03001o
ogoo00eoo`03001oogoo01Moo`03001oogoo00Eoo`8000=oo`8004=oo`03001oogoo01Ioo`03001o
ogoo00eoo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001o
ogoo00moo`03001oogoo02Qoo`03001oogoo00moo`03001oogoo00Qoo`03001oogoo00Moo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00]oo`03001oogoo00moo`03001oogoo01Uoo`03001o
ogoo03]oo`03001oogoo0=Qoo`03001oogoo00Moo`00>Woo00<007ooOol0ZGoo00<007ooOol087oo
00<007ooOol05goo00<007ooOol06Goo00<007ooOol03goo00<007ooOol02Woo00<007ooOol02Goo
00<007ooOol01goo00<007ooOol01goo0`002Goo00<007ooOol03goo00<007ooOol00goo00<007oo
Ool06Goo00<007ooOol017oo00<007ooOol03goo00<007ooOol01Goo10002goo00<007ooOol01goo
00<007ooOol02Woo00<007ooOol03Goo00<007ooOol067oo00<007ooOol017oo0P000Woo0`00@Woo
00<007ooOol05goo00<007ooOol03Goo00<007ooOol02Woo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol03goo00<007ooOol09Woo00<007ooOol047oo00<007ooOol027oo
00<007ooOol01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol02goo00<007ooOol03goo
00<007ooOol06Goo00<007ooOol0?7oo00<007ooOol0egoo00<007ooOol01goo000jOol00`00Oomo
o`2XOol00`00Oomoo`0QOol2000GOol00`00Oomoo`0JOol00`00Oomoo`0?Ool00`00Oomoo`0:Ool0
0`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`06Ool2000:Ool00`00Oomoo`0@Ool20003Ool0
0`00Oomoo`0IOol00`00Oomoo`03Ool00`00Oomoo`0@Ool00`00Oomoo`06Ool3000:Ool00`00Oomo
o`08Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool00`00Oomoo`0HOol00`00Oomoo`04Ool60013Ool0
0`00Oomoo`0GOol00`00Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`0@Ool00`00Oomoo`0TOol00`00Oomoo`0AOol00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomoo`0?Ool0
0`00Oomoo`0JOol00`00Oomoo`0kOol00`00Oomoo`3GOol00`00Oomoo`07Ool003Yoo`03001oogoo
0:Qoo`03001oogoo029oo`03001oogoo01Eoo`03001oogoo01Uoo`03001oogoo011oo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Ioo`8000]oo`03001oogoo015oo`03
001oo`0001aoo`04001oogooOol2000BOol00`00Oomoo`07Ool3000:Ool00`00Oomoo`08Ool00`00
Oomoo`0:Ool00`00Oomoo`0=Ool00`00Oomoo`0IOol00`00Oomoo`03Ool50013Ool00`00Oomoo`0H
Ool00`00Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`0@Ool2000SOol00`00Oomoo`0AOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`0IOol00`00
Oomoo`0kOol00`00Oomoo`3GOol00`00Oomoo`07Ool003Yoo`03001oogoo0:Qoo`03001oogoo02=o
o`03001oogoo01Aoo`03001oogoo01Uoo`03001oogoo011oo`03001oogoo00]oo`03001oogoo00Uo
o`03001oogoo00Moo`03001oogoo00Eoo`<000aoo`03001oogoo015oo`8001aoo`04001oo`00000D
Ool00`00Oomoo`07Ool40009Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomoo`0>Ool00`00
Oomoo`0HOol00`00Oomoo`02Ool50014Ool00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`0:
Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`0BOol2000POol00`00
Oomoo`0AOol00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`0IOol00`00Oomoo`0lOol00`00Oomoo`3FOol00`00
Oomoo`07Ool003Yoo`03001oogoo0:Moo`03001oogoo02Aoo`8001Eoo`03001oogoo01Uoo`03001o
ogoo00moo`03001oogoo00aoo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Eoo`04001o
ogoo000;Ool00`00Oomoo`0BOol3000JOol2000EOol00`00Oomoo`08Ool50008Ool00`00Oomoo`08
Ool00`00Oomoo`0:Ool00`00Oomoo`0>Ool00`00Oomoo`0HOol00`00Oomoo`02Ool40015Ool00`00
Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`0COol2000KOol3000DOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`0IOol00`00
Oomoo`0lOol00`00Oomoo`3FOol00`00Oomoo`07Ool003Yoo`03001oogoo0:Moo`03001oogoo02Eo
o`03001oogoo01=oo`03001oogoo01Uoo`03001oogoo00moo`03001oogoo00aoo`03001oogoo00Uo
o`03001oogoo00Moo`03001oogoo00Aoo`80009oo`03001oogoo00Yoo`03001oogoo015oo`03001o
ogoo008001Ioo`<001Eoo`03001oogoo00Yoo`D000Moo`03001oogoo00Qoo`03001oogoo00Yoo`03
001oogoo00ioo`03001oogoo01Uoo`04001oogooOol30015Ool00`00Oomoo`0HOol00`00Oomoo`0>
Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0D
Ool2000FOol3000FOol00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`0IOol00`00Oomoo`0mOol00`00Oomoo`3E
Ool00`00Oomoo`07Ool003Yoo`03001oogoo0:Moo`03001oogoo02Eoo`8001=oo`03001oogoo01Yo
o`03001oogoo00moo`03001oogoo00aoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00=o
o`05001oogooOol0000=Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool2000BOol20002Ool00`00Oomo
o`0COol00`00Oomoo`0:Ool2000017oo001oo`001Goo00<007ooOol02Goo00<007ooOol02Woo00<0
07ooOol03Woo00<007ooOol06Goo00<007ooOol00`00AWoo00<007ooOol067oo00<007ooOol03Woo
00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol05Woo
0P004Woo0P0067oo00<007ooOol02Woo00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo
00<007ooOol02goo00<007ooOol047oo00<007ooOol06Woo00<007ooOol0?7oo00<007ooOol0eGoo
00<007ooOol01goo000jOol00`00Oomoo`2VOol00`00Oomoo`0WOol00`00Oomoo`0AOol00`00Oomo
o`0IOol00`00Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool70007Ool4
0005Ool00`00Oomoo`0AOol00`00Oomoo`0;Ool200001Goo000007oo000017oo00<007ooOol02Goo
00<007ooOol02Woo00<007ooOol03Woo00<007ooOol06Goo00<007ooOol00P00AWoo00<007ooOol0
6Goo00<007ooOol03Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
2Woo00<007ooOol05goo1@002Woo0`006Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
27oo00<007ooOol02Goo00<007ooOol02goo00<007ooOol047oo00<007ooOol06Woo00<007ooOol0
?Goo00<007ooOol0e7oo00<007ooOol01goo000jOol00`00Oomoo`2UOol00`00Oomoo`0YOol00`00
Oomoo`0@Ool00`00Oomoo`0IOol00`00Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool01@00Oomoogoo00001Woo00<007ooOol02Woo00<007ooOol047oo00<007ooOol02goo
1`002Goo00<007ooOol047oo00<007ooOol037oo0P000Woo00<007ooOol017oo00<007ooOol02Goo
00<007ooOol02Woo00<007ooOol03Woo00<007ooOol06Goo00@007ooOol004Moo`03001oogoo01Uo
o`03001oogoo00ioo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00]o
o`03001oogoo01]oo`X001aoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Qoo`03001o
ogoo00Uoo`03001oogoo00]oo`03001oogoo011oo`03001oogoo01Yoo`03001oogoo03eoo`03001o
ogoo0=Aoo`03001oogoo00Moo`00>Woo00<007ooOol0YGoo00<007ooOol0:Goo0P0047oo00<007oo
Ool06Woo00<007ooOol047oo00<007ooOol037oo00<007ooOol02Goo00<007ooOol027oo00<007oo
Ool00P001goo00<007ooOol02Woo00<007ooOol03goo00<007ooOol06goo00<007ooOol047oo00<0
07ooOol02goo00<007oo00000goo00<007ooOol00goo00<007ooOol02Goo00<007ooOol02Woo00<0
07ooOol03goo00<007ooOol06Goo0P00Agoo00<007ooOol06Goo00<007ooOol03goo00<007ooOol0
2Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol0@7oo00<007ooOol0
2Woo00<007ooOol02Woo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02goo00<007ooOol0
47oo00<007ooOol06Woo00<007ooOol0?Woo00<007ooOol0dgoo00<007ooOol01goo000jOol00`00
Oomoo`2TOol00`00Oomoo`0[Ool2000?Ool00`00Oomoo`0JOol00`00Oomoo`0@Ool00`00Oomoo`0<
Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Ool00008Ool00`00Oomoo`0;Ool00`00Oomoo`0>
Ool00`00Oomoo`0KOol00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Ool00004Ool01@00Oomoogoo
000037oo00<007ooOol02Woo00<007ooOol03goo00<007ooOol06Goo0P00Agoo00<007ooOol06Goo
00<007ooOol03goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02goo
00<007ooOol0?Woo00<007ooOol02goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Woo
00<007ooOol02goo00<007ooOol047oo00<007ooOol06goo00<007ooOol0?Goo00<007ooOol0dgoo
00<007ooOol01goo000jOol00`00Oomoo`2TOol00`00Oomoo`0/Ool01000Oomoo`0037oo00<007oo
Ool06Woo00<007ooOol047oo00<007ooOol037oo00<007ooOol02Goo00<007ooOol02Goo0P002Goo
00<007ooOol037oo00<007ooOol03Goo00<007ooOol06goo00<007ooOol03Woo00<007ooOol037oo
00<007ooOol01Goo0P000Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol03goo00<007oo
Ool06Goo0P00AWoo00<007ooOol06Woo00<007ooOol03goo00<007ooOol02Woo00<007ooOol02Woo
00<007ooOol02Woo00<007ooOol02goo00<007ooOol0?7oo00<007ooOol037oo00<007ooOol02Goo
00<007ooOol027oo00<007ooOol02Woo00<007ooOol02goo00<007ooOol047oo00<007ooOol06goo
00<007ooOol0?Goo00<007ooOol0dgoo00<007ooOol01goo000jOol00`00Oomoo`2SOol00`00Oomo
o`0^Ool00`00Ool0000;Ool00`00Oomoo`0JOol00`00Oomoo`0AOol00`00Oomoo`0<Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool2000:Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0KOol0
0`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`06Ool01000Oomoo`002goo00<007ooOol02goo
00<007ooOol03goo00<007ooOol06Goo0P00AWoo00<007ooOol06Woo00<007ooOol03goo00<007oo
Ool02goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol037oo00<007ooOol0>Woo00<007oo
Ool037oo00<007ooOol02Woo00<007ooOol027oo00<007ooOol02Goo00<007ooOol03Goo00<007oo
Ool047oo00<007ooOol06Woo00<007ooOol0?Woo00<007ooOol0dWoo00<007ooOol01goo000jOol0
0`00Oomoo`2SOol00`00Oomoo`0^Ool4000:Ool00`00Oomoo`0JOol00`00Oomoo`0AOol00`00Oomo
o`0<Ool00`00Oomoo`09Ool00`00Oomoo`08Ool2000<Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool0
0`00Oomoo`0LOol00`00Oomoo`0<Ool00`00Oomoo`0>Ool00`00Oomoo`07Ool00`00Ool0000;Ool0
0`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`0GOol00`00Ool00016Ool00`00Oomoo`0JOol0
0`00Oomoo`0?Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool0
0`00Oomoo`0hOol00`00Oomoo`0=Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`0=Ool00`00Oomoo`0@Ool00`00Oomoo`0JOol00`00Oomoo`0nOol00`00Oomoo`3BOol0
0`00Oomoo`07Ool003Yoo`03001oogoo0:=oo`03001oogoo02moo`<000Yoo`03001oogoo01Yoo`03
001oogoo015oo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo00Moo`03001oo`0000]oo`03
001oogoo00eoo`03001oogoo00Uoo`03001oogoo01aoo`03001oogoo00]oo`03001oogoo00ioo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo011oo`03001oogoo01Ioo`80
009oo`03001oogoo049oo`03001oogoo01]oo`03001oogoo00moo`03001oogoo00]oo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00eoo`03001oogoo03Ioo`03001oogoo00ioo`03001oogoo
00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00eoo`03001oogoo011oo`03001oogoo
01]oo`03001oogoo03ioo`03001oogoo0=5oo`03001oogoo00Moo`00>Woo1@00X7oo00<007ooOol0
;7oo0P000goo0`002Goo00<007ooOol06Woo00<007ooOol04Goo00<007ooOol037oo00<007ooOol0
2Woo00<007ooOol01Woo00@007ooOol000aoo`03001oogoo00eoo`03001oogoo00Qoo`03001oogoo
01aoo`03001oogoo00Yoo`03001oogoo00ioo`03001oogoo00Yoo`8000]oo`03001oogoo00]oo`03
001oogoo011oo`03001oogoo01Ioo`03001oogoo009oo`03001oogoo041oo`03001oogoo01aoo`03
001oogoo00moo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00ioo`03
001oogoo03Aoo`03001oogoo00ioo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03
001oogoo00eoo`03001oogoo011oo`03001oogoo01]oo`03001oogoo03ioo`03001oogoo0<aoo`H0
00Uoo`00>Woo00<007ooOol0XWoo00<007ooOol0;Woo0`0000=oo`0000002Goo00<007ooOol06Woo
00<007ooOol04Goo00<007ooOol037oo00<007ooOol02Woo00<007ooOol01Goo00D007ooOomoo`00
00aoo`03001oogoo00ioo`03001oogoo00Moo`03001oogoo01aoo`03001oogoo00Yoo`03001oogoo
00ioo`03001oogoo00Yoo`<000Yoo`03001oogoo00]oo`03001oogoo011oo`03001oogoo01Eoo`80
00Aoo`03001oogoo041oo`03001oogoo01aoo`03001oogoo00moo`03001oogoo00]oo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00moo`03001oogoo039oo`03001oogoo00moo`03001oogoo
00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00eoo`03001oogoo011oo`03001oogoo
01]oo`03001oogoo03ioo`03001oogoo0=5oo`03001oogoo00Moo`00>Woo00<007ooOol0XGoo00<0
07ooOol0<7oo1P0027oo00<007ooOol06Woo00<007ooOol04Goo00<007ooOol037oo00<007ooOol0
2Woo00<007ooOol017oo0P0017oo00<007ooOol02Woo00<007ooOol03Woo00<007ooOol01Woo00<0
07ooOol077oo00<007ooOol027oo0P0047oo00<007ooOol02goo00@007oo000000Uoo`03001oogoo
00]oo`03001oogoo011oo`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo03ioo`03001oogoo
01eoo`03001oogoo00moo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo
00moo`80035oo`03001oogoo00moo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03
001oogoo00eoo`03001oogoo011oo`03001oogoo01]oo`03001oogoo03moo`03001oogoo0=1oo`03
001oogoo00Moo`00>Woo00<007ooOol0XGoo00<007ooOol0<Woo1@001Woo00<007ooOol06goo00<0
07ooOol04Goo00<007ooOol037oo00<007ooOol02Woo00<007ooOol00goo0P001Goo00<007ooOol0
2Woo00<007ooOol03goo00<007ooOol01Goo00<007ooOol07Goo00<007ooOol01Woo00<007ooOol0
47oo00<007ooOol02Woo00D007ooOomoo`0000Uoo`03001oogoo00]oo`03001oogoo011oo`03001o
ogoo01Aoo`03001oogoo00Eoo`03001oogoo03ioo`03001oogoo01eoo`03001oogoo00moo`03001o
ogoo00aoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo02eoo`03001o
ogoo00moo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00eoo`03001o
ogoo011oo`03001oogoo01aoo`03001oogoo03ioo`03001oogoo0=1oo`03001oogoo00Moo`00>Woo
00<007ooOol0XGoo00<007ooOol0=7oo0`001Woo00<007ooOol06goo00<007ooOol04Goo00<007oo
Ool037oo00<007ooOol02Woo00<007ooOol00Woo0P001Woo00<007ooOol02Woo00<007ooOol047oo
0P001Goo00<007ooOol07Goo00<007ooOol01Goo00<007ooOol047oo00<007ooOol02goo00<007oo
Ool00Woo00<007ooOol01Woo00<007ooOol02goo00<007ooOol047oo00<007ooOol04goo0P0027oo
00<007ooOol0?7oo00<007ooOol07Woo00<007ooOol03goo00<007ooOol037oo00<007ooOol02Woo
00<007ooOol02goo00<007ooOol04Goo00<007ooOol0:Woo0P004Woo00<007ooOol02Woo00<007oo
Ool02Woo00<007ooOol02Woo00<007ooOol03Goo00<007ooOol047oo00<007ooOol077oo00<007oo
Ool0?goo00<007ooOol0cgoo00<007ooOol01goo000jOol00`00Oomoo`2POol00`00Oomoo`0fOol3
0005Ool00`00Oomoo`0JOol00`00Oomoo`0BOol00`00Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomo
o`020008Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol01@00Oomoogoo000087oo00<007ooOol00goo
0P004goo00<007ooOol02goo00<007ooOol00goo00<007ooOol017oo00<007ooOol037oo00<007oo
Ool04Goo00<007ooOol04Woo00<007ooOol01goo00<007ooOol0?7oo00<007ooOol07Goo00<007oo
Ool047oo00<007ooOol037oo00<007ooOol02Woo00<007ooOol02goo00<007ooOol04Woo00<007oo
Ool0:7oo00<007ooOol04Goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02Woo00<007oo
Ool03Goo00<007ooOol04Goo00<007ooOol06goo00<007ooOol0?goo00<007ooOol0cgoo00<007oo
Ool01goo000jOol00`00Oomoo`2POol00`00Oomoo`0hOol20004Ool00`00Oomoo`0JOol00`00Oomo
o`0BOol00`00Oomoo`0=Ool00`00Oomoo`0:Ool01000Ool000002Goo00<007ooOol02goo00<007oo
Ool04Goo00@007ooOol0021oo`03001oogoo009oo`03001oogoo019oo`03001oogoo00aoo`03001o
ogoo00Aoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo015oo`03001oogoo015oo`03001o
ogoo00Qoo`03001oogoo03aoo`03001oogoo01eoo`03001oogoo011oo`03001oogoo00aoo`03001o
ogoo00]oo`03001oogoo00]oo`03001oogoo019oo`03001oogoo02Ioo`03001oogoo015oo`03001o
ogoo00aoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00eoo`03001oogoo015oo`03001o
ogoo01]oo`03001oogoo03moo`03001oogoo0<moo`03001oogoo00Moo`00>Woo00<007ooOol0X7oo
00<007ooOol0>Goo0P000Woo00<007ooOol06goo00<007ooOol04Woo00<007ooOol03Goo00<007oo
Ool02Woo0`002Woo00<007ooOol02goo00<007ooOol04Woo0`0087oo00D007ooOomoo`0001Eoo`03
001oogoo00]oo`03001oogoo00Eoo`8000Aoo`03001oogoo00aoo`03001oogoo015oo`03001oogoo
015oo`03001oogoo00Uoo`03001oogoo03Yoo`03001oogoo01ioo`03001oogoo011oo`03001oogoo
00eoo`03001oogoo00Yoo`03001oogoo00aoo`03001oogoo019oo`03001oogoo02=oo`8001Aoo`03
001oogoo00]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00eoo`03001oogoo015oo`03
001oogoo01aoo`03001oogoo03moo`03001oogoo0<ioo`03001oogoo00Moo`00>Woo00<007ooOol0
Wgoo00<007ooOol0>goo00@007ooOol001eoo`03001oogoo019oo`03001oogoo00eoo`03001oogoo
00Yoo`8000aoo`03001oogoo00]oo`03001oogoo01=oo`8001moo`@001Eoo`03001oogoo00aoo`03
001oogoo00Ioo`8000=oo`03001oogoo00aoo`03001oogoo015oo`03001oogoo011oo`03001oogoo
00]oo`03001oogoo03Qoo`03001oogoo01moo`03001oogoo011oo`03001oogoo00eoo`03001oogoo
00]oo`03001oogoo00aoo`03001oogoo019oo`<0025oo`03001oogoo01=oo`03001oogoo00aoo`03
001oogoo00Yoo`03001oogoo00]oo`03001oogoo00eoo`03001oogoo015oo`03001oogoo01aoo`03
001oogoo03moo`03001oogoo0<ioo`03001oogoo00Moo`00>Woo00<007ooOol0Wgoo00<007ooOol0
?7oo0`007Goo00<007ooOol04Woo00<007ooOol03Goo00<007ooOol02Woo00<007ooOol02goo00<0
07ooOol037oo00<007ooOol04Woo00@007oo000001eoo`03001oogoo01Ioo`03001oogoo00aoo`03
001oogoo00Moo`<00003Ool007oo00eoo`03001oogoo015oo`03001oogoo00moo`03001oogoo00ao
o`03001oogoo03Qoo`03001oogoo01moo`03001oogoo011oo`03001oogoo00eoo`03001oogoo00]o
o`03001oogoo00aoo`03001oogoo01Eoo`03001oogoo01aoo`8001Ioo`03001oogoo00aoo`03001o
ogoo00Yoo`03001oogoo00]oo`03001oogoo00eoo`03001oogoo015oo`03001oogoo01aoo`03001o
ogoo03moo`03001oogoo0<ioo`03001oogoo00Moo`00>Woo00<007ooOol0Wgoo00<007ooOol0?Goo
0P007Goo00<007ooOol04Woo00<007ooOol03Goo00<007ooOol02Goo0P003Woo00<007ooOol02goo
00<007ooOol04Woo00D007ooOomoo`0001Yoo`<001Moo`03001oogoo00aoo`03001oogoo00Uoo`@0
00ioo`03001oogoo015oo`03001oogoo00eoo`<000moo`03001oogoo03Ioo`03001oogoo021oo`03
001oogoo011oo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo00eoo`03001oogoo01Eoo`80
01Yoo`8001Qoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00ioo`03
001oogoo015oo`03001oogoo01aoo`03001oogoo041oo`03001oogoo0<eoo`03001oogoo00Moo`00
>Woo00<007ooOol0WWoo00<007ooOol0?Woo0`0077oo00<007ooOol04Woo00<007ooOol03Goo00<0
07ooOol01goo0P000Woo00<007ooOol02goo00<007ooOol037oo00<007ooOol04Goo00<007ooOol0
0Woo0`005Goo0P000Woo00<007ooOol057oo00<007ooOol03Goo00<007ooOol02Woo10003Goo00<0
07ooOol04Goo00<007ooOol037oo0`0047oo00<007ooOol0=Woo00<007ooOol087oo00<007ooOol0
47oo00<007ooOol03Goo00<007ooOol037oo00<007ooOol037oo00<007ooOol05goo0P005Goo0`00
6Goo00<007ooOol037oo00<007ooOol02Woo00<007ooOol02goo00<007ooOol03Woo00<007ooOol0
4Goo00<007ooOol077oo00<007ooOol0@7oo00<007ooOol0cGoo00<007ooOol01goo000jOol00`00
Oomoo`2NOol00`00Oomoo`0nOol01000Ool000006goo00<007ooOol04Woo00<007ooOol03Goo00<0
07ooOol01Woo0P000goo00<007ooOol02goo00<007ooOol03Goo00<007ooOol047oo00<007ooOol0
1Goo10003goo0P001Goo00<007ooOol04goo00<007ooOol03Goo00<007ooOol02Woo1P002goo00<0
07ooOol04Goo00<007ooOol02goo0`004Woo00<007ooOol0=7oo00<007ooOol08Goo00<007ooOol0
47oo00<007ooOol03Woo00<007ooOol02goo00<007ooOol037oo00<007ooOol06Goo0`003Woo1000
6goo00<007ooOol03Goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol03Woo00<007ooOol0
4Goo00<007ooOol07Goo00<007ooOol0?goo00<007ooOol0cGoo00<007ooOol01goo000jOol00`00
Oomoo`2NOol00`00Oomoo`0nOol00`00Oomoo`02000JOol00`00Oomoo`0BOol00`00Oomoo`0=Ool0
0`00Oomoo`05Ool20004Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomo
o`0:Ool?0007Ool00`00Oomoo`0BOol00`00Oomoo`0=Ool00`00Oomoo`0<Ool70009Ool00`00Oomo
o`0AOol00`00Oomoo`0:Ool3000COol00`00Oomoo`0dOol00`00Oomoo`0POol00`00Oomoo`0BOol0
0`00Oomoo`0=Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00Oomoo`0KOol>000OOol00`00Oomo
o`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0>Ool00`00Oomoo`0BOol00`00Oomo
o`0LOol00`00Oomoo`10Ool00`00Oomoo`3<Ool00`00Oomoo`07Ool003Yoo`03001oogoo09eoo`03
001oogoo03moo`03001oogoo009oo`03001oogoo01Moo`03001oogoo019oo`03001oogoo00ioo`03
001oogoo00=oo`8000Eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo
021oo`03001oogoo019oo`03001oogoo00eoo`03001oogoo00aoo`<00003Ool00000008000Qoo`03
001oogoo015oo`03001oogoo00Uoo`@001=oo`03001oogoo03Aoo`03001oogoo021oo`03001oogoo
019oo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo00eoo`03001oogoo04Moo`03001oogoo
00eoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00ioo`03001oogoo019oo`03001oogoo
01aoo`03001oogoo041oo`03001oogoo0<aoo`03001oogoo00Moo`00>Woo00<007ooOol0WGoo00<0
07ooOol0?Woo00<007ooOol017oo00<007ooOol05Woo00<007ooOol04Woo00<007ooOol03Woo00@0
07ooOomoo`8000Qoo`03001oogoo00]oo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo021o
o`03001oogoo015oo`03001oogoo00ioo`03001oogoo00aoo`<0009oo`800003Ool007oo00Ioo`03
001oogoo015oo`03001oogoo00Qoo`@001Eoo`03001oogoo039oo`03001oogoo025oo`03001oogoo
019oo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo04Eoo`03001oogoo
00ioo`03001oogoo00Yoo`03001oogoo00aoo`03001oogoo00ioo`03001oogoo019oo`03001oogoo
01aoo`03001oogoo041oo`03001oogoo0<aoo`03001oogoo00Moo`00>Woo00<007ooOol0WGoo00<0
07ooOol0?Woo00<007ooOol01Goo100057oo00<007ooOol04Woo00<007ooOol03Woo00<007ooOol0
0P002Goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol087oo00<007oo
Ool047oo00<007ooOol03Woo00<007ooOol03Goo00@007oo0000009oo`<000Moo`03001oogoo015o
o`03001oogoo00Moo`/000moo`03001oogoo039oo`03001oogoo025oo`03001oogoo019oo`03001o
ogoo00eoo`03001oogoo00aoo`03001oogoo00ioo`03001oogoo04Aoo`03001oogoo00eoo`03001o
ogoo00]oo`03001oogoo00aoo`03001oogoo00ioo`03001oogoo019oo`03001oogoo01eoo`03001o
ogoo041oo`03001oogoo0<]oo`03001oogoo00Moo`00>Woo00<007ooOol0WGoo00<007ooOol0?Woo
00<007ooOol01Woo10004goo00<007ooOol04Woo00<007ooOol03Woo0`002goo00<007ooOol037oo
00<007ooOol03Woo00<007ooOol037oo00<007ooOol087oo00<007ooOol03goo00<007ooOol03goo
00<007ooOol037oo00<007ooOol00P0017oo0P001Woo00<007ooOol04Goo00<007ooOol01Woo2000
57oo00<007ooOol0<7oo00<007ooOol08Woo00<007ooOol04Woo00<007ooOol03Goo00<007ooOol0
37oo00<007ooOol03goo00<007ooOol0@Woo00<007ooOol03Woo00<007ooOol02goo00<007ooOol0
37oo00<007ooOol03Woo00<007ooOol04Woo00<007ooOol07Goo00<007ooOol0@7oo00<007ooOol0
bgoo00<007ooOol01goo000jOol00`00Oomoo`2MOol00`00Oomoo`0nOol00`00Oomoo`08Ool4000A
Ool00`00Oomoo`0BOol00`00Oomoo`0>Ool2000<Ool00`00Oomoo`0<Ool00`00Oomoo`0>Ool00`00
Oomoo`0<Ool00`00Oomoo`0POol00`00Oomoo`0>Ool00`00Oomoo`0@Ool00`00Oomoo`0<Ool01@00
Oomoogoo00001Woo0P0017oo00<007ooOol04Goo00<007ooOol017oo10006Woo00<007ooOol0<7oo
00<007ooOol08Woo00<007ooOol04Woo00<007ooOol03Goo00<007ooOol037oo00<007ooOol047oo
00<007ooOol0@7oo00<007ooOol03Woo00<007ooOol037oo00<007ooOol037oo00<007ooOol03Woo
00<007ooOol04Woo00<007ooOol07Goo00<007ooOol0@Goo00<007ooOol0bWoo00<007ooOol01goo
000jOol00`00Oomoo`2LOol00`00Oomoo`0oOol00`00Oomoo`09Ool4000@Ool00`00Oomoo`0BOol0
0`00Oomoo`0<Ool3000=Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool00`00Oomo
o`0POol00`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`0=Ool01000Oomoogoo0P001goo0P00
0Woo00<007ooOol04Goo00<007ooOol00Woo0`007Woo00<007ooOol0;Woo00<007ooOol08goo00<0
07ooOol04Woo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol03goo00<007ooOol0?goo00<0
07ooOol03goo00<007ooOol037oo00<007ooOol037oo00<007ooOol03Woo00<007ooOol04Woo00<0
07ooOol07Goo00<007ooOol0@Goo00<007ooOol0bWoo00<007ooOol01goo000jOol00`00Oomoo`2L
Ool00`00Oomoo`0oOol00`00Oomoo`0:Ool4000?Ool00`00Oomoo`0BOol00`00Oomoo`08Ool50000
0goo001oo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`09Ool00`00Oomoo`0QOol0
0`00Oomoo`0=Ool00`00Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`06Ool4
000COol00`00Oomoo`03000QOol00`00Oomoo`0]Ool00`00Oomoo`0SOol00`00Oomoo`0BOol00`00
Oomoo`0>Ool00`00Oomoo`0<Ool00`00Oomoo`0@Ool00`00Oomoo`0mOol00`00Oomoo`0?Ool00`00
Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`0BOol00`00Oomoo`0MOol00`00
Oomoo`11Ool00`00Oomoo`3:Ool00`00Oomoo`07Ool003Yoo`03001oogoo09aoo`03001oogoo03mo
o`03001oogoo00Qoo`P000eoo`03001oogoo019oo`03001oogoo00Aoo`L000=oo`03001oogoo00ao
o`03001oogoo00aoo`03001oogoo011oo`03001oogoo00Qoo`03001oogoo029oo`03001oogoo00]o
o`03001oogoo011oo`03001oogoo00eoo`03001oogoo00moo`<0015oo`@002=oo`03001oogoo02eo
o`03001oogoo02=oo`03001oogoo019oo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo011o
o`03001oogoo03]oo`03001oogoo011oo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00io
o`03001oogoo019oo`03001oogoo01eoo`03001oogoo049oo`03001oogoo0<Uoo`03001oogoo00Mo
o`00>Woo00<007ooOol0Vgoo00<007ooOol0?goo00<007ooOol01Woo30002goo00<007ooOol04goo
00<007ooOol02@001Woo00<007ooOol02goo00<007ooOol03Goo00<007ooOol047oo00<007ooOol0
1goo00<007ooOol08Woo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol03Goo00<007ooOol0
3Woo00@007ooOomoo`T000Aoo`H002Ioo`03001oogoo02]oo`03001oogoo02=oo`03001oogoo01=o
o`03001oogoo00ioo`03001oogoo00eoo`03001oogoo015oo`03001oogoo03Uoo`03001oogoo011o
o`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00ioo`03001oogoo01=oo`03001oogoo01io
o`03001oogoo045oo`03001oogoo0<Uoo`03001oogoo00Moo`00>Woo00<007ooOol0Vgoo00<007oo
Ool0?goo00<007ooOol03Goo1`002Goo00<007ooOol04goo2P0027oo00<007ooOol02goo00<007oo
Ool03Goo00<007ooOol04Goo00<007ooOol01Woo00<007ooOol08Woo00<007ooOol02Goo00<007oo
Ool04Goo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol017oo30000goo00<007ooOol097oo
00<007ooOol0:goo00<007ooOol08goo00<007ooOol04goo00<007ooOol03Woo00<007ooOol03Woo
00<007ooOol04Goo00<007ooOol0=goo00<007ooOol04Goo00<007ooOol03Goo00<007ooOol037oo
00<007ooOol03Woo00<007ooOol04goo00<007ooOol07Woo00<007ooOol0@Goo00<007ooOol0bGoo
00<007ooOol01goo000jOol00`00Oomoo`2KOol00`00Oomoo`0oOol00`00Oomoo`0DOol30006Ool0
0`00Oomoo`0COol01000Oomoogoo0`0000=oo`00Ool027oo00<007ooOol037oo00<007ooOol037oo
00<007ooOol04Woo00<007ooOol01Goo00<007ooOol08Woo00<007ooOol027oo00<007ooOol04Woo
00<007ooOol03Goo00<007ooOol03goo00<007ooOol01Goo1`001goo00<007ooOol09Goo00<007oo
Ool0:Goo00<007ooOol097oo00<007ooOol04goo00<007ooOol03goo00<007ooOol03Goo00<007oo
Ool04Woo00<007ooOol0=Goo00<007ooOol04Woo00<007ooOol037oo00<007ooOol03Goo00<007oo
Ool03Woo00<007ooOol04goo00<007ooOol07Woo00<007ooOol0@Woo00<007ooOol0b7oo00<007oo
Ool01goo000jOol00`00Oomoo`2JOol00`00Oomoo`10Ool00`00Oomoo`0FOol40003Ool00`00Oomo
o`0COol40003Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0BOol2
0005Ool00`00Oomoo`0ROol00`00Oomoo`07Ool00`00Oomoo`0BOol00`00Oomoo`0>Ool00`00Oomo
o`0?Ool00`00Oomoo`07Ool30009Ool00`00Oomoo`0UOol00`00Oomoo`0XOol00`00Oomoo`0UOol0
0`00Oomoo`0COol00`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`0BOol2000dOol00`00Oomo
o`0BOol00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`0COol00`00Oomo
o`0NOol00`00Oomoo`12Ool00`00Oomoo`38Ool00`00Oomoo`07Ool003Yoo`03001oogoo09Yoo`03
001oogoo041oo`03001oogoo01Uoo`/000Yoo`H000Eoo`03001oogoo00Uoo`03001oogoo00aoo`03
001oogoo00ioo`03001oogoo01=oo`03001oogoo009oo`03001oogoo029oo`03001oogoo00Ioo`03
001oogoo01=oo`03001oogoo00ioo`03001oogoo00moo`03001oogoo00Uoo`8000Qoo`03001oogoo
02Eoo`03001oogoo02Qoo`03001oogoo02Eoo`03001oogoo01=oo`03001oogoo00moo`03001oogoo
00ioo`03001oogoo01Aoo`03001oogoo031oo`03001oogoo019oo`03001oogoo00ioo`03001oogoo
00eoo`03001oogoo00ioo`03001oogoo01=oo`03001oogoo01ioo`03001oogoo049oo`03001oogoo
0<Qoo`03001oogoo00Moo`00>Woo00<007ooOol0VWoo00<007ooOol0@7oo00<007ooOol07Goo4P00
17oo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol0
57oo0P0000=oo`00000097oo00<007ooOol01Goo00<007ooOol04goo00<007ooOol03goo00<007oo
Ool03goo00<007ooOol02Woo0P001goo00<007ooOol09Woo00<007ooOol09Woo00<007ooOol09Woo
00<007ooOol057oo00<007ooOol03goo00<007ooOol03Woo00<007ooOol057oo00<007ooOol0;Woo
00<007ooOol04goo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol04goo
00<007ooOol07Woo00<007ooOol0@goo00<007ooOol0agoo00<007ooOol01goo000jOol00`00Oomo
o`2JOol00`00Oomoo`10Ool00`00Oomoo`0MOol00`00Oomoo`03Ool5000;Ool01@00Oomoogoo0000
3Goo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol05Goo0P009Goo00<007ooOol017oo00<0
07ooOol057oo00<007ooOol03goo00<007ooOol03goo00<007ooOol037oo00<007ooOol017oo00<0
07ooOol09goo00<007ooOol09Goo00<007ooOol09Woo00<007ooOol057oo00<007ooOol03goo00<0
07ooOol03Woo00<007ooOol05Goo00<007ooOol0:goo0P005Goo00<007ooOol03Woo00<007ooOol0
3Goo00<007ooOol03goo00<007ooOol057oo00<007ooOol07Goo00<007ooOol0@goo00<007ooOol0
agoo00<007ooOol01goo000jOol00`00Oomoo`2JOol00`00Oomoo`10Ool00`00Oomoo`0MOol00`00
Oomoo`02Ool4000>Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`0F
Ool00`00Oomoo`0TOol00`00Oomoo`02Ool00`00Oomoo`0DOol00`00Oomoo`0?Ool00`00Oomoo`0@
Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`0XOol00`00Oomoo`0SOol00`00Oomoo`0W
Ool00`00Oomoo`0DOol00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0EOol00`00Oomoo`0X
Ool2000GOol00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool00`00Oomoo`0DOol00`00
Oomoo`0MOol00`00Oomoo`13Ool00`00Oomoo`37Ool00`00Oomoo`07Ool003Yoo`03001oogoo09Uo
o`03001oogoo041oo`03001oogoo01ioo`03001oogoo00<0015oo`03001oogoo00moo`03001oogoo
00eoo`03001oogoo00ioo`03001oogoo01Eoo`<002Aoo`03001oogoo008001Moo`03001oogoo00mo
o`03001oogoo011oo`03001oogoo01=oo`03001oogoo02Qoo`03001oogoo02=oo`03001oogoo02Mo
o`03001oogoo01Aoo`03001oogoo011oo`03001oogoo00moo`03001oogoo01Eoo`8002Moo`03001o
ogoo01Ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00moo`03001oogoo01Aoo`03001o
ogoo01ioo`03001oogoo04=oo`03001oogoo0<Ioo`03001oogoo00Moo`00>Woo00<007ooOol0VGoo
00<007ooOol0@7oo00<007ooOol07Woo00@007oo000001=oo`03001oogoo00moo`03001oogoo00eo
o`03001oogoo00moo`03001oogoo01Aoo`04001oogoo000SOol3000IOol00`00Oomoo`0?Ool00`00
Oomoo`0?Ool00`00Oomoo`0DOol00`00Oomoo`0YOol00`00Oomoo`0QOol00`00Oomoo`0XOol00`00
Oomoo`0DOol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0GOol00`00Oomoo`0SOol00`00
Oomoo`0FOol00`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`0DOol00`00
Oomoo`0NOol00`00Oomoo`13Ool00`00Oomoo`36Ool00`00Oomoo`07Ool003Yoo`03001oogoo09Uo
o`03001oogoo041oo`03001oogoo01ioo`8001Eoo`03001oogoo00moo`03001oogoo00ioo`03001o
ogoo00ioo`03001oogoo01Aoo`05001oogooOol0000QOol2000JOol00`00Oomoo`0@Ool00`00Oomo
o`0?Ool00`00Oomoo`0DOol00`00Oomoo`0ZOol00`00Oomoo`0OOol00`00Oomoo`0YOol00`00Oomo
o`0DOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0GOol2000ROol00`00Oomoo`0GOol0
0`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0@Ool00`00Oomoo`0DOol00`00Oomoo`0NOol0
0`00Oomoo`13Ool00`00Oomoo`36Ool00`00Oomoo`07Ool003Yoo`03001oogoo09Qoo`03001oogoo
045oo`03001oogoo01ioo`03001oogoo01Aoo`03001oogoo00moo`03001oogoo00ioo`03001oogoo
00moo`03001oogoo01=oo`03001oogoo009oo`<001aoo`800003Ool007oo01Qoo`03001oogoo011o
o`03001oogoo011oo`03001oogoo01Aoo`03001oogoo02]oo`03001oogoo01eoo`03001oogoo02Yo
o`03001oogoo01Aoo`03001oogoo011oo`03001oogoo011oo`03001oogoo01Uoo`8001eoo`<001Uo
o`03001oogoo00moo`03001oogoo00ioo`03001oogoo011oo`03001oogoo01Aoo`03001oogoo01io
o`03001oogoo04=oo`03001oogoo0<Ioo`03001oogoo00Moo`00>Woo00<007ooOol0V7oo00<007oo
Ool0@Goo00<007ooOol07Woo00<007ooOol057oo00<007ooOol03goo00<007ooOol03Woo00<007oo
Ool03goo00<007ooOol04Woo00<007ooOol01Woo0P0067oo0P000goo00<007ooOol05goo00<007oo
Ool047oo00<007ooOol047oo00<007ooOol057oo00<007ooOol0:goo00<007ooOol07Goo00<007oo
Ool0:Woo00<007ooOol057oo00<007ooOol047oo00<007ooOol047oo00<007ooOol06goo0P006Woo
00<007ooOol06Woo00<007ooOol03goo00<007ooOol03Woo00<007ooOol047oo00<007ooOol057oo
00<007ooOol07Woo00<007ooOol0@goo00<007ooOol0aWoo00<007ooOol01goo000jOol00`00Oomo
o`2HOol00`00Oomoo`11Ool00`00Oomoo`0NOol00`00Oomoo`0DOol00`00Oomoo`0@Ool00`00Oomo
o`0>Ool00`00Oomoo`0?Ool00`00Oomoo`0AOol00`00Oomoo`08Ool2000DOol20005Ool00`00Oomo
o`0FOol00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0DOol00`00Oomoo`0[Ool00`00Oomo
o`0LOol00`00Oomoo`0[Ool00`00Oomoo`0DOol00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomo
o`0LOol2000EOol3000LOol00`00Oomoo`0@Ool00`00Oomoo`0>Ool00`00Oomoo`0@Ool00`00Oomo
o`0DOol00`00Oomoo`0NOol00`00Oomoo`13Ool00`00Oomoo`36Ool00`00Oomoo`07Ool003Yoo`03
001oogoo09Moo`03001oogoo049oo`03001oogoo01ioo`03001oogoo01Aoo`03001oogoo011oo`03
001oogoo00ioo`03001oogoo011oo`03001oogoo011oo`03001oogoo00Yoo`<000moo`8000Moo`03
001oogoo01Ioo`03001oogoo011oo`03001oogoo015oo`03001oogoo01Aoo`03001oogoo02aoo`03
001oogoo01Yoo`03001oogoo02aoo`03001oogoo01Eoo`03001oogoo011oo`03001oogoo011oo`03
001oogoo01ioo`<000ioo`@001moo`03001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03
001oogoo01Aoo`03001oogoo01moo`03001oogoo04=oo`03001oogoo0<Eoo`03001oogoo00Moo`00
>Woo00<007ooOol0Ugoo00<007ooOol0@Woo00<007ooOol07Woo00<007ooOol057oo00<007ooOol0
47oo00<007ooOol03Woo00<007ooOol047oo00<007ooOol047oo00<007ooOol03Goo3`002Goo00<0
07ooOol05Goo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol057oo00<007ooOol0;Goo00<0
07ooOol067oo00<007ooOol0;Goo00<007ooOol05Goo00<007ooOol047oo00<007ooOol04Goo00<0
07ooOol087oo3P008Woo00<007ooOol047oo00<007ooOol03goo00<007ooOol047oo00<007ooOol0
57oo00<007ooOol07goo00<007ooOol0@goo00<007ooOol0aGoo00<007ooOol01goo000jOol00`00
Oomoo`2GOol00`00Oomoo`11Ool00`00Oomoo`0OOol00`00Oomoo`0DOol00`00Oomoo`0@Ool00`00
Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0VOol00`00Oomoo`0DOol00`00
Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0EOol00`00Oomoo`0^Ool00`00Oomoo`0FOol00`00
Oomoo`0^Ool00`00Oomoo`0EOol00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`1@Ool00`00
Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0DOol00`00Oomoo`0OOol00`00
Oomoo`13Ool00`00Oomoo`35Ool00`00Oomoo`07Ool003Yoo`03001oogoo09Moo`03001oogoo045o
o`03001oogoo01moo`03001oogoo01Aoo`03001oogoo011oo`03001oogoo00moo`03001oogoo015o
o`03001oogoo00ioo`03001oogoo02Ioo`03001oogoo01=oo`03001oogoo015oo`03001oogoo015o
o`03001oogoo01Eoo`03001oogoo02moo`03001oogoo01Aoo`03001oogoo02moo`03001oogoo01Eo
o`03001oogoo015oo`03001oogoo015oo`03001oogoo04ioo`03001oogoo015oo`03001oogoo00mo
o`03001oogoo00moo`03001oogoo01Eoo`03001oogoo01moo`03001oogoo04=oo`03001oogoo0<Eo
o`03001oogoo00Moo`00>Woo00<007ooOol0Ugoo00<007ooOol0@Goo00<007ooOol07goo00<007oo
Ool057oo00<007ooOol04Goo00<007ooOol03Woo00<007ooOol04Goo00<007ooOol03Goo00<007oo
Ool09goo00<007ooOol04goo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol05Goo00<007oo
Ool0;goo00<007ooOol057oo00<007ooOol0;goo00<007ooOol05Goo00<007ooOol04Goo00<007oo
Ool04Goo00<007ooOol0CWoo00<007ooOol047oo00<007ooOol03goo00<007ooOol047oo00<007oo
Ool05Goo00<007ooOol07goo00<007ooOol0@goo00<007ooOol0aGoo00<007ooOol01goo000jOol0
0`00Oomoo`2FOol00`00Oomoo`12Ool00`00Oomoo`0OOol00`00Oomoo`0DOol00`00Oomoo`0AOol0
0`00Oomoo`0?Ool00`00Oomoo`0AOol00`00Oomoo`0<Ool00`00Oomoo`0WOol00`00Oomoo`0BOol0
0`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0EOol00`00Oomoo`0`Ool00`00Oomoo`0BOol0
0`00Oomoo`0`Ool00`00Oomoo`0FOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`1<Ool0
0`00Oomoo`0AOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0EOol00`00Oomoo`0OOol0
0`00Oomoo`14Ool00`00Oomoo`34Ool00`00Oomoo`07Ool003Yoo`D009Aoo`03001oogoo049oo`03
001oogoo01moo`03001oogoo01Aoo`03001oogoo015oo`03001oogoo00moo`03001oogoo015oo`03
001oogoo00aoo`03001oogoo02Moo`03001oogoo015oo`03001oogoo019oo`03001oogoo019oo`03
001oogoo01Eoo`03001oogoo035oo`80011oo`8003=oo`03001oogoo01Ioo`03001oogoo015oo`03
001oogoo019oo`03001oogoo04Yoo`03001oogoo015oo`03001oogoo011oo`03001oogoo011oo`03
001oogoo01Eoo`03001oogoo01moo`03001oogoo04Aoo`03001oogoo0;moo`H000Uoo`00>Woo00<0
07ooOol0UWoo00<007ooOol0@Goo00<007ooOol087oo00<007ooOol057oo00<007ooOol04Goo00<0
07ooOol03goo00<007ooOol04Woo00<007ooOol02goo00<007ooOol09goo00<007ooOol047oo00<0
07ooOol04goo00<007ooOol04Woo00<007ooOol05Goo00<007ooOol0<goo0P0037oo0P00=Goo00<0
07ooOol05Woo00<007ooOol04Goo00<007ooOol04goo00<007ooOol0BGoo00<007ooOol04Goo00<0
07ooOol047oo00<007ooOol047oo00<007ooOol05Goo00<007ooOol07goo00<007ooOol0A7oo00<0
07ooOol0a7oo00<007ooOol01goo000jOol00`00Oomoo`2FOol00`00Oomoo`11Ool00`00Oomoo`0P
Ool00`00Oomoo`0DOol00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`0BOol00`00Oomoo`0:
Ool00`00Oomoo`0WOol00`00Oomoo`0?Ool00`00Oomoo`0DOol00`00Oomoo`0BOol00`00Oomoo`0E
Ool00`00Oomoo`0eOol20008Ool2000gOol00`00Oomoo`0FOol00`00Oomoo`0AOol00`00Oomoo`0D
Ool00`00Oomoo`17Ool00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`0E
Ool00`00Oomoo`0OOol00`00Oomoo`14Ool00`00Oomoo`34Ool00`00Oomoo`07Ool003Yoo`03001o
ogoo09Ioo`03001oogoo045oo`03001oogoo021oo`03001oogoo01Aoo`03001oogoo019oo`03001o
ogoo00moo`03001oogoo01=oo`03001oogoo00Uoo`03001oogoo02Qoo`03001oogoo00ioo`03001o
ogoo01=oo`03001oogoo019oo`03001oogoo01Ioo`03001oogoo03Moo`<000=oo`8003Uoo`03001o
ogoo01Ioo`03001oogoo019oo`03001oogoo01=oo`03001oogoo04Ioo`03001oogoo019oo`03001o
ogoo011oo`03001oogoo015oo`03001oogoo01Eoo`03001oogoo01moo`03001oogoo04Eoo`03001o
ogoo0<=oo`03001oogoo00Moo`00>Woo00<007ooOol0UWoo00<007ooOol0@Goo00<007ooOol087oo
00<007ooOol057oo00<007ooOol04Woo00<007ooOol03goo00<007ooOol04goo00<007ooOol02Goo
00<007ooOol0:7oo00<007ooOol03Goo00<007ooOol057oo00<007ooOol04Woo00<007ooOol05Woo
00<007ooOol0>Woo0`00>goo00<007ooOol05Woo00<007ooOol04Woo00<007ooOol057oo00<007oo
Ool0A7oo00<007ooOol04goo00<007ooOol047oo00<007ooOol04Goo00<007ooOol05Goo00<007oo
Ool07goo00<007ooOol0AGoo00<007ooOol0`goo00<007ooOol01goo000jOol00`00Oomoo`2FOol0
0`00Oomoo`11Ool00`00Oomoo`0POol00`00Oomoo`0EOol00`00Oomoo`0AOol00`00Oomoo`0@Ool0
0`00Oomoo`0COol00`00Oomoo`07Ool00`00Oomoo`0YOol00`00Oomoo`0<Ool00`00Oomoo`0DOol0
0`00Oomoo`0COol00`00Oomoo`0FOol00`00Oomoo`1hOol00`00Oomoo`0GOol00`00Oomoo`0BOol0
0`00Oomoo`0DOol00`00Oomoo`12Ool00`00Oomoo`0COol00`00Oomoo`0AOol00`00Oomoo`0@Ool0
0`00Oomoo`0FOol00`00Oomoo`0POol00`00Oomoo`14Ool00`00Oomoo`33Ool00`00Oomoo`07Ool0
03Yoo`03001oogoo09Eoo`03001oogoo049oo`03001oogoo021oo`03001oogoo01Eoo`03001oogoo
015oo`03001oogoo011oo`03001oogoo01Aoo`03001oogoo00Ioo`03001oogoo02Uoo`03001oogoo
00]oo`03001oogoo01Eoo`03001oogoo01=oo`03001oogoo01Ioo`03001oogoo07Qoo`03001oogoo
01Moo`03001oogoo019oo`03001oogoo01Eoo`03001oogoo041oo`03001oogoo01Aoo`03001oogoo
015oo`03001oogoo011oo`03001oogoo01Ioo`03001oogoo021oo`03001oogoo04Aoo`03001oogoo
0<=oo`03001oogoo00Moo`00>Woo00<007ooOol0UGoo00<007ooOol0@Woo00<007ooOol087oo00<0
07ooOol05Goo00<007ooOol04Woo00<007ooOol03goo00<007ooOol05Goo00<007ooOol01Goo00<0
07ooOol0:Goo00<007ooOol02Woo00<007ooOol05Woo00<007ooOol04Woo00<007ooOol05goo00<0
07ooOol0N7oo00<007ooOol05goo00<007ooOol04Woo00<007ooOol05Woo00<007ooOol0?Woo00<0
07ooOol05Goo00<007ooOol047oo00<007ooOol04Goo00<007ooOol05Woo00<007ooOol087oo00<0
07ooOol0AGoo00<007ooOol0`Woo00<007ooOol01goo000jOol00`00Oomoo`2EOol00`00Oomoo`12
Ool00`00Oomoo`0POol00`00Oomoo`0EOol00`00Oomoo`0BOol00`00Oomoo`0@Ool2000FOol00`00
Oomoo`04Ool00`00Oomoo`0YOol00`00Oomoo`09Ool00`00Oomoo`0FOol00`00Oomoo`0COol00`00
Oomoo`0GOol00`00Oomoo`1hOol00`00Oomoo`0GOol00`00Oomoo`0COol00`00Oomoo`0FOol00`00
Oomoo`0lOol00`00Oomoo`0EOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0FOol00`00
Oomoo`0POol00`00Oomoo`15Ool00`00Oomoo`32Ool00`00Oomoo`07Ool003Yoo`03001oogoo09Eo
o`03001oogoo049oo`03001oogoo021oo`03001oogoo01Eoo`03001oogoo019oo`03001oogoo015o
o`03001oogoo01Eoo`03001oogoo00=oo`03001oogoo02Uoo`03001oogoo00Qoo`03001oogoo01Mo
o`03001oogoo01=oo`03001oogoo01Moo`03001oogoo07Qoo`03001oogoo01Moo`03001oogoo01=o
o`03001oogoo01Moo`03001oogoo03Yoo`03001oogoo01Ioo`03001oogoo015oo`03001oogoo015o
o`03001oogoo01Ioo`03001oogoo021oo`03001oogoo04Eoo`03001oogoo0<9oo`03001oogoo00Mo
o`00>Woo00<007ooOol0UGoo00<007ooOol0@Woo00<007ooOol087oo00<007ooOol05Goo00<007oo
Ool04Woo00<007ooOol04Woo00<007ooOol05Goo00<007ooOol00Woo00<007ooOol0:Goo00<007oo
Ool01goo00<007ooOol05goo00<007ooOol057oo00<007ooOol05goo00<007ooOol0N7oo00<007oo
Ool05goo00<007ooOol057oo00<007ooOol05goo00<007ooOol0>7oo00<007ooOol05Woo00<007oo
Ool04Goo00<007ooOol04Woo00<007ooOol05Woo00<007ooOol087oo00<007ooOol0AGoo00<007oo
Ool0`Woo00<007ooOol01goo000jOol00`00Oomoo`2DOol00`00Oomoo`13Ool00`00Oomoo`0POol0
0`00Oomoo`0FOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0FOol200000goo001oo`0/
Ool00`00Oomoo`05Ool00`00Oomoo`0HOol00`00Oomoo`0DOol00`00Oomoo`0GOol00`00Oomoo`1h
Ool00`00Oomoo`0GOol00`00Oomoo`0DOol00`00Oomoo`0HOol2000fOol2000IOol00`00Oomoo`0A
Ool00`00Oomoo`0BOol00`00Oomoo`0FOol00`00Oomoo`0POol00`00Oomoo`16Ool00`00Oomoo`31
Ool00`00Oomoo`07Ool003Yoo`03001oogoo09Aoo`03001oogoo04=oo`03001oogoo021oo`03001o
ogoo01Ioo`03001oogoo015oo`03001oogoo019oo`03001oogoo01Qoo`8002eoo`03001oogoo00Ao
o`03001oogoo01Uoo`03001oogoo01=oo`03001oogoo01Qoo`03001oogoo07Qoo`03001oogoo01Qo
o`03001oogoo01=oo`03001oogoo01Yoo`03001oogoo039oo`03001oogoo01Qoo`03001oogoo019o
o`03001oogoo019oo`03001oogoo01Ioo`03001oogoo021oo`03001oogoo04Ioo`03001oogoo0<5o
o`03001oogoo00Moo`00>Woo00<007ooOol0U7oo00<007ooOol0@Woo00<007ooOol08Goo00<007oo
Ool05Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol067oo00<007ooOol0:goo00<007oo
Ool00goo00<007ooOol06Goo00<007ooOol057oo00<007ooOol067oo00<007ooOol0NGoo00<007oo
Ool05goo00<007ooOol057oo00<007ooOol06Woo00<007ooOol0<7oo00<007ooOol06Goo00<007oo
Ool04Goo00<007ooOol04Woo00<007ooOol05goo00<007ooOol08Goo00<007ooOol0AGoo00<007oo
Ool0`Goo00<007ooOol01goo000jOol00`00Oomoo`2DOol00`00Oomoo`12Ool00`00Oomoo`0QOol0
0`00Oomoo`0FOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0HOol3000[Ool01000Oomo
ogoo0P0077oo00<007ooOol057oo00<007ooOol067oo00<007ooOol0NGoo00<007ooOol05goo00<0
07ooOol05Goo00<007ooOol06Woo0P00;Woo0P006goo00<007ooOol04Woo00<007ooOol04Woo00<0
07ooOol05goo00<007ooOol08Goo00<007ooOol0AGoo00<007ooOol0`Goo00<007ooOol01goo000j
Ool00`00Oomoo`2COol00`00Oomoo`13Ool00`00Oomoo`0QOol00`00Oomoo`0GOol00`00Oomoo`0A
Ool00`00Oomoo`0BOol00`00Oomoo`0HOol01000Oomoo`00:Woo0P0000=oo`00Ool07Goo00<007oo
Ool04goo00<007ooOol06Goo00<007ooOol0NGoo00<007ooOol067oo00<007ooOol057oo00<007oo
Ool077oo00<007ooOol0:Woo00<007ooOol06goo00<007ooOol04Woo00<007ooOol04Woo00<007oo
Ool05goo00<007ooOol08Goo00<007ooOol0AWoo00<007ooOol0`7oo00<007ooOol01goo000jOol0
0`00Oomoo`2COol00`00Oomoo`13Ool00`00Oomoo`0QOol00`00Oomoo`0GOol00`00Oomoo`0BOol0
0`00Oomoo`0BOol00`00Oomoo`0GOol01@00Oomoogoo0000:Goo0`007Woo00<007ooOol057oo00<0
07ooOol06Goo00<007ooOol0NGoo00<007ooOol067oo00<007ooOol05Goo00<007ooOol077oo00<0
07ooOol0:7oo00<007ooOol06goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol05goo00<0
07ooOol08Goo00<007ooOol0AWoo00<007ooOol0`7oo00<007ooOol01goo000jOol00`00Oomoo`2C
Ool00`00Oomoo`13Ool00`00Oomoo`0QOol00`00Oomoo`0GOol00`00Oomoo`0BOol00`00Oomoo`0B
Ool00`00Oomoo`0FOol00`00Oomoo`03Ool2000WOol2000OOol00`00Oomoo`0DOol00`00Oomoo`0I
Ool00`00Oomoo`1iOol00`00Oomoo`0HOol00`00Oomoo`0EOol00`00Oomoo`0MOol2000VOol2000N
Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0GOol00`00Oomoo`0QOol00`00Oomoo`16
Ool00`00Oomoo`30Ool00`00Oomoo`07Ool003Yoo`03001oogoo09=oo`03001oogoo04=oo`03001o
ogoo025oo`03001oogoo01Moo`03001oogoo019oo`03001oogoo01=oo`03001oogoo01Eoo`03001o
ogoo00Eoo`8002=oo`D001eoo`03001oogoo01Eoo`03001oogoo01Uoo`03001oogoo07Uoo`03001o
ogoo01Qoo`03001oogoo01Ioo`03001oogoo01ioo`03001oogoo029oo`03001oogoo01eoo`03001o
ogoo01=oo`03001oogoo01=oo`03001oogoo01Moo`03001oogoo025oo`03001oogoo04Ioo`03001o
ogoo0<1oo`03001oogoo00Moo`00>Woo00<007ooOol0Tgoo00<007ooOol0@goo00<007ooOol08Goo
00<007ooOol05goo00<007ooOol04goo00<007ooOol04Woo00<007ooOol05Goo00<007ooOol01goo
0P007goo0P000Woo0`0077oo00<007ooOol05Goo00<007ooOol06Woo00<007ooOol0NGoo00<007oo
Ool06Goo00<007ooOol05Goo00<007ooOol07goo0P0087oo0P0087oo00<007ooOol04Woo00<007oo
Ool057oo00<007ooOol05goo00<007ooOol08Goo00<007ooOol0AWoo00<007ooOol0`7oo00<007oo
Ool01goo000jOol00`00Oomoo`2BOol00`00Oomoo`14Ool00`00Oomoo`0QOol00`00Oomoo`0GOol0
0`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0DOol00`00Oomoo`09Ool00`00Oomoo`0JOol2
0003Ool5000KOol00`00Oomoo`0EOol00`00Oomoo`0JOol00`00Oomoo`1iOol00`00Oomoo`0IOol0
0`00Oomoo`0EOol00`00Oomoo`0QOol2000LOol2000QOol00`00Oomoo`0COol00`00Oomoo`0COol0
0`00Oomoo`0HOol00`00Oomoo`0QOol00`00Oomoo`17Ool00`00Oomoo`2oOol00`00Oomoo`07Ool0
03Yoo`03001oogoo099oo`03001oogoo04Aoo`03001oogoo025oo`03001oogoo01Moo`03001oogoo
01=oo`03001oogoo01Aoo`03001oogoo01=oo`03001oogoo00Yoo`<001Ioo`<000Eoo`D001Yoo`03
001oogoo01Ioo`03001oogoo01Uoo`03001oogoo07Yoo`03001oogoo01Uoo`03001oogoo01Ioo`03
001oogoo029oo`<001Ioo`<0029oo`03001oogoo01Aoo`03001oogoo01=oo`03001oogoo01Moo`03
001oogoo029oo`03001oogoo04Moo`03001oogoo0;moo`03001oogoo00Moo`00>Woo00<007ooOol0
TWoo00<007ooOol0A7oo00<007ooOol08Goo00<007ooOol05goo00<007ooOol04goo00<007ooOol0
57oo00<007ooOol04Woo00<007ooOol03Woo10003goo0`0027oo0`0000=oo`0000006Goo00<007oo
Ool05Woo00<007ooOol06Goo00<007ooOol0NWoo00<007ooOol06Goo00<007ooOol05Woo00<007oo
Ool09Goo10003Woo10009Goo00<007ooOol057oo00<007ooOol04goo00<007ooOol05goo00<007oo
Ool08Woo00<007ooOol0Agoo00<007ooOol0_goo00<007ooOol01goo000jOol00`00Oomoo`2BOol0
0`00Oomoo`14Ool00`00Oomoo`0QOol00`00Oomoo`0GOol00`00Oomoo`0DOol00`00Oomoo`0DOol0
0`00Oomoo`0AOol00`00Oomoo`0BOol?000;Ool300000goo0000000HOol00`00Oomoo`0GOol00`00
Oomoo`0IOol00`00Oomoo`1jOol00`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0XOol>000X
Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0GOol00`00Oomoo`0ROol00`00Oomoo`17
Ool00`00Oomoo`2oOol00`00Oomoo`07Ool003Yoo`03001oogoo099oo`03001oogoo04Aoo`03001o
ogoo025oo`03001oogoo01Qoo`03001oogoo01=oo`03001oogoo01Aoo`03001oogoo015oo`03001o
ogoo02aoo`<0009oo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Yoo`03001oogoo07Yo
o`03001oogoo01Yoo`03001oogoo01Ioo`03001oogoo05ioo`03001oogoo01Aoo`03001oogoo01Ao
o`03001oogoo01Moo`03001oogoo029oo`03001oogoo04Qoo`03001oogoo0;ioo`03001oogoo00Mo
o`00>Woo00<007ooOol0TWoo00<007ooOol0A7oo00<007ooOol08Goo00<007ooOol067oo00<007oo
Ool057oo00<007ooOol057oo00<007ooOol047oo00<007ooOol0;7oo00<007oo00000goo00<007oo
Ool04goo0P006Goo00<007ooOol06Woo00<007ooOol0NWoo00<007ooOol06Woo00<007ooOol05goo
00<007ooOol0G7oo00<007ooOol05Goo00<007ooOol057oo00<007ooOol05goo00<007ooOol08Woo
00<007ooOol0B7oo00<007ooOol0_Woo00<007ooOol01goo000jOol00`00Oomoo`2BOol00`00Oomo
o`14Ool00`00Oomoo`0QOol00`00Oomoo`0HOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomo
o`0@Ool00`00Oomoo`0/Ool01000Oomoo`0067oo00<007ooOol067oo00<007ooOol06Woo00<007oo
Ool0NWoo00<007ooOol06Woo00<007ooOol067oo00<007ooOol0Fgoo00<007ooOol05Goo00<007oo
Ool057oo00<007ooOol05goo00<007ooOol08Woo00<007ooOol0B7oo00<007ooOol0_Woo00<007oo
Ool01goo000jOol00`00Oomoo`2BOol00`00Oomoo`14Ool00`00Oomoo`0QOol00`00Oomoo`0HOol0
0`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0?Ool00`00Oomoo`0_Ool00`00Oomoo`0EOol0
0`00Oomoo`0HOol00`00Oomoo`0KOol00`00Oomoo`1jOol00`00Oomoo`0KOol00`00Oomoo`0GOol0
0`00Oomoo`1JOol00`00Oomoo`0EOol00`00Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0ROol0
0`00Oomoo`18Ool00`00Oomoo`2nOol00`00Oomoo`07Ool003Yoo`03001oogoo099oo`03001oogoo
04Aoo`03001oogoo025oo`03001oogoo01Uoo`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo
00eoo`03001oogoo031oo`03001oogoo01Eoo`03001oogoo01Qoo`03001oogoo01]oo`03001oogoo
07Yoo`03001oogoo01]oo`03001oogoo01Qoo`03001oogoo05Qoo`03001oogoo01Ioo`03001oogoo
01Aoo`03001oogoo01Qoo`03001oogoo029oo`03001oogoo04Qoo`03001oogoo0;ioo`03001oogoo
00Moo`00>Woo00<007ooOol0TWoo00<007ooOol0A7oo00<007ooOol08Goo00<007ooOol06Goo00<0
07ooOol057oo00<007ooOol05Woo00<007ooOol037oo00<007ooOol0<7oo00<007ooOol057oo00<0
07ooOol06Goo00<007ooOol06goo00<007ooOol0NWoo00<007ooOol06goo00<007ooOol06Goo00<0
07ooOol0EWoo00<007ooOol05goo00<007ooOol057oo00<007ooOol067oo00<007ooOol08Woo00<0
07ooOol0B7oo00<007ooOol0_Woo00<007ooOol01goo000jOol00`00Oomoo`2AOol00`00Oomoo`14
Ool00`00Oomoo`0SOol00`00Oomoo`0HOol00`00Oomoo`0EOol00`00Oomoo`0EOol00`00Oomoo`0;
Ool2000bOol00`00Oomoo`0DOol00`00Oomoo`0HOol00`00Oomoo`0KOol00`00Oomoo`1lOol00`00
Oomoo`0KOol00`00Oomoo`0IOol00`00Oomoo`1EOol00`00Oomoo`0FOol00`00Oomoo`0EOol00`00
Oomoo`0HOol00`00Oomoo`0SOol00`00Oomoo`18Ool00`00Oomoo`2mOol00`00Oomoo`07Ool003Yo
o`03001oogoo095oo`03001oogoo04Aoo`03001oogoo02=oo`03001oogoo01Qoo`03001oogoo01Eo
o`03001oogoo01Ioo`03001oogoo00Yoo`80039oo`03001oogoo01=oo`03001oogoo01Uoo`03001o
ogoo01]oo`03001oogoo07aoo`03001oogoo01]oo`03001oogoo01Yoo`03001oogoo05=oo`03001o
ogoo01Moo`03001oogoo01Eoo`03001oogoo01Qoo`03001oogoo02=oo`03001oogoo04Qoo`03001o
ogoo0;eoo`03001oogoo00Moo`00>Woo00<007ooOol0TGoo00<007ooOol0A7oo00<007ooOol08goo
00<007ooOol06Goo00<007ooOol057oo00<007ooOol05goo00<007ooOol02Goo0P00<Woo00<007oo
Ool04Woo00<007ooOol06Woo00<007ooOol06goo00<007ooOol0O7oo00<007ooOol06goo00<007oo
Ool06Woo00<007ooOol0DWoo00<007ooOol067oo00<007ooOol057oo00<007ooOol06Goo00<007oo
Ool08goo00<007ooOol0B7oo00<007ooOol0_Goo00<007ooOol01goo000jOol00`00Oomoo`2AOol0
0`00Oomoo`14Ool00`00Oomoo`0SOol00`00Oomoo`0IOol00`00Oomoo`0EOol00`00Oomoo`0GOol0
0`00Oomoo`07Ool3000cOol00`00Oomoo`0@Ool00`00Oomoo`0JOol00`00Oomoo`0LOol00`00Oomo
o`1lOol00`00Oomoo`0LOol00`00Oomoo`0JOol00`00Oomoo`1@Ool00`00Oomoo`0HOol00`00Oomo
o`0EOol00`00Oomoo`0IOol00`00Oomoo`0SOol00`00Oomoo`18Ool00`00Oomoo`2mOol00`00Oomo
o`07Ool003Yoo`03001oogoo095oo`03001oogoo04Aoo`03001oogoo02=oo`03001oogoo01Uoo`03
001oogoo01Eoo`03001oogoo01Qoo`03001oogoo00Ioo`<003=oo`03001oogoo011oo`03001oogoo
01Yoo`03001oogoo01aoo`03001oogoo07aoo`03001oogoo01aoo`03001oogoo01Yoo`03001oogoo
051oo`03001oogoo01Moo`03001oogoo01Ioo`03001oogoo01Uoo`03001oogoo02=oo`03001oogoo
04Qoo`03001oogoo0;eoo`03001oogoo00Moo`00>Woo00<007ooOol0TGoo00<007ooOol0A7oo00<0
07ooOol08goo00<007ooOol06Goo00<007ooOol05Goo00<007ooOol06Goo00<007ooOol017oo1@00
<Woo00<007ooOol03goo00<007ooOol06Woo00<007ooOol07Goo00<007ooOol0O7oo00<007ooOol0
7Goo00<007ooOol06Woo00<007ooOol0Cgoo00<007ooOol05goo00<007ooOol05Woo00<007ooOol0
6Goo00<007ooOol08goo00<007ooOol0B7oo00<007ooOol0_Goo00<007ooOol01goo000jOol00`00
Oomoo`2AOol00`00Oomoo`14Ool00`00Oomoo`0SOol00`00Oomoo`0IOol00`00Oomoo`0FOol00`00
Oomoo`0IOol00`00Oomoo`03Ool5000bOol00`00Oomoo`0>Ool00`00Oomoo`0KOol00`00Oomoo`0M
Ool00`00Oomoo`1lOol00`00Oomoo`0MOol00`00Oomoo`0KOol00`00Oomoo`1=Ool00`00Oomoo`0G
Ool00`00Oomoo`0FOol00`00Oomoo`0JOol00`00Oomoo`0SOol00`00Oomoo`18Ool00`00Oomoo`2m
Ool00`00Oomoo`07Ool003Yoo`03001oogoo095oo`03001oogoo04Aoo`03001oogoo02=oo`03001o
ogoo01Uoo`03001oogoo01Ioo`03001oogoo01Yoo`04001oogooOol2000017oo00000000<Woo00<0
07ooOol03Woo00<007ooOol06goo00<007ooOol077oo00<007ooOol0OWoo00<007ooOol077oo00<0
07ooOol06goo00<007ooOol0C7oo00<007ooOol067oo00<007ooOol05Woo00<007ooOol06Woo00<0
07ooOol08goo00<007ooOol0B7oo00<007ooOol0_Goo00<007ooOol01goo000jOol00`00Oomoo`2@
Ool00`00Oomoo`15Ool00`00Oomoo`0TOol00`00Oomoo`0IOol00`00Oomoo`0FOol00`00Oomoo`0J
Ool00`00Oomoo`06000bOol00`00Oomoo`0=Ool00`00Oomoo`0KOol00`00Oomoo`0MOol00`00Oomo
o`1nOol00`00Oomoo`0MOol00`00Oomoo`0KOol00`00Oomoo`1:Ool00`00Oomoo`0HOol00`00Oomo
o`0GOol00`00Oomoo`0IOol00`00Oomoo`0TOol00`00Oomoo`19Ool00`00Oomoo`2lOol00`00Oomo
o`07Ool003Yoo`03001oogoo091oo`03001oogoo04Eoo`03001oogoo02Aoo`03001oogoo01Uoo`03
001oogoo01Ioo`03001oogoo01Yoo`07001oogoo001oo`00Ool00P00<Woo00<007ooOol037oo00<0
07ooOol077oo00<007ooOol07Goo00<007ooOol0OWoo00<007ooOol07Goo00<007ooOol077oo00<0
07ooOol0Agoo0P006goo00<007ooOol05goo00<007ooOol06Goo00<007ooOol097oo00<007ooOol0
BGoo00<007ooOol0_7oo00<007ooOol01goo000jOol00`00Oomoo`2@Ool00`00Oomoo`15Ool00`00
Oomoo`0TOol00`00Oomoo`0IOol00`00Oomoo`0FOol00`00Oomoo`0KOol20002Ool01000Oomoo`00
<goo00<007ooOol02Woo00<007ooOol07Goo00<007ooOol07Goo00<007ooOol0OWoo00<007ooOol0
7Goo00<007ooOol07Goo00<007ooOol0AGoo00<007ooOol06goo00<007ooOol05Woo00<007ooOol0
6Woo00<007ooOol097oo00<007ooOol0BGoo00<007ooOol0_7oo00<007ooOol01goo000jOol5002>
Ool00`00Oomoo`15Ool00`00Oomoo`0TOol00`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0K
Ool01000Oomoo`000Woo00<007ooOol0<Goo00<007ooOol027oo0P007goo00<007ooOol07Woo00<0
07ooOol0Ogoo00<007ooOol07Goo00<007ooOol07Goo0P00A7oo00<007ooOol06goo00<007ooOol0
5goo00<007ooOol06Woo00<007ooOol097oo00<007ooOol0BGoo00<007ooOol0]goo1P002Goo000j
Ool00`00Oomoo`2@Ool00`00Oomoo`15Ool00`00Oomoo`0TOol00`00Oomoo`0IOol00`00Oomoo`0G
Ool00`00Oomoo`0LOol00`00Ool0000fOol00`00Oomoo`07Ool00`00Oomoo`0OOol00`00Oomoo`0N
Ool00`00Oomoo`1oOol00`00Oomoo`0MOol00`00Oomoo`0OOol00`00Oomoo`11Ool00`00Oomoo`0K
Ool00`00Oomoo`0GOol00`00Oomoo`0JOol00`00Oomoo`0TOol00`00Oomoo`19Ool00`00Oomoo`2l
Ool00`00Oomoo`07Ool003Yoo`03001oogoo091oo`03001oogoo04Eoo`03001oogoo02Aoo`03001o
ogoo01Yoo`03001oogoo01Moo`03001oogoo01aoo`8003Ioo`03001oogoo00Ioo`03001oogoo021o
o`03001oogoo01ioo`03001oogoo07moo`03001oogoo01ioo`03001oogoo01moo`03001oogoo03io
o`8001eoo`03001oogoo01Qoo`03001oogoo01Yoo`03001oogoo02Aoo`03001oogoo04Uoo`03001o
ogoo0;aoo`03001oogoo00Moo`00>Woo00<007ooOol0T7oo00<007ooOol0AGoo00<007ooOol097oo
00<007ooOol06Woo00<007ooOol05goo00<007ooOol077oo0P00=Woo00<007ooOol01Goo00<007oo
Ool087oo00<007ooOol07Woo00<007ooOol0P7oo00<007ooOol07Woo00<007ooOol087oo00<007oo
Ool0?7oo00<007ooOol07Goo00<007ooOol05goo00<007ooOol06goo00<007ooOol097oo00<007oo
Ool0BGoo00<007ooOol0_7oo00<007ooOol01goo000jOol00`00Oomoo`2@Ool00`00Oomoo`15Ool0
0`00Oomoo`0TOol00`00Oomoo`0JOol00`00Oomoo`0HOol00`00Oomoo`0KOol00`00Ool0000eOol0
0`00Oomoo`04Ool00`00Oomoo`0QOol00`00Oomoo`0NOol00`00Oomoo`20Ool00`00Oomoo`0NOol0
0`00Oomoo`0QOol00`00Oomoo`0jOol00`00Oomoo`0MOol00`00Oomoo`0HOol00`00Oomoo`0KOol0
0`00Oomoo`0TOol00`00Oomoo`1:Ool00`00Oomoo`2kOol00`00Oomoo`07Ool003Yoo`03001oogoo
08moo`03001oogoo04Ioo`03001oogoo02Eoo`03001oogoo01Yoo`03001oogoo01Moo`03001oogoo
01]oo`03001oogoo008003=oo`03001oogoo00=oo`03001oogoo029oo`03001oogoo01ioo`03001o
ogoo085oo`03001oogoo01ioo`03001oogoo025oo`03001oogoo03Moo`80021oo`03001oogoo01Qo
o`03001oogoo01Yoo`03001oogoo02Eoo`03001oogoo04Yoo`03001oogoo0;]oo`03001oogoo00Mo
o`00>Woo00<007ooOol0Sgoo00<007ooOol0AWoo00<007ooOol09Goo00<007ooOol06Woo00<007oo
Ool067oo00<007ooOol06Woo00<007ooOol00Woo00<007ooOol0<7oo0P000goo00<007ooOol08goo
00<007ooOol07Woo00<007ooOol0PGoo00<007ooOol07Woo00<007ooOol08Woo00<007ooOol0=Goo
00<007ooOol07goo00<007ooOol06Goo00<007ooOol06Woo00<007ooOol09Goo00<007ooOol0BWoo
00<007ooOol0^goo00<007ooOol01goo000jOol00`00Oomoo`2?Ool00`00Oomoo`16Ool00`00Oomo
o`0UOol00`00Oomoo`0JOol00`00Oomoo`0HOol00`00Oomoo`0JOol00`00Oomoo`03Ool00`00Oomo
o`0`Ool01000Oomoo`009Goo00<007ooOol07goo00<007ooOol0PGoo00<007ooOol07goo00<007oo
Ool08Woo0P00=7oo00<007ooOol087oo00<007ooOol06Goo00<007ooOol06Woo00<007ooOol09Goo
00<007ooOol0BWoo00<007ooOol0^goo00<007ooOol01goo000jOol00`00Oomoo`2?Ool00`00Oomo
o`16Ool00`00Oomoo`0UOol00`00Oomoo`0KOol00`00Oomoo`0GOol00`00Oomoo`0IOol00`00Oomo
o`05Ool00`00Oomoo`0_Ool00`00Ool0000VOol00`00Oomoo`0NOol00`00Oomoo`22Ool00`00Oomo
o`0OOol00`00Oomoo`0TOol00`00Oomoo`0`Ool00`00Oomoo`0QOol00`00Oomoo`0HOol00`00Oomo
o`0KOol00`00Oomoo`0UOol00`00Oomoo`1:Ool00`00Oomoo`2kOol00`00Oomoo`07Ool003Yoo`03
001oogoo08moo`03001oogoo04Ioo`03001oogoo02Eoo`03001oogoo01]oo`03001oogoo01Qoo`03
001oogoo01Qoo`03001oogoo00Ioo`<002eoo`<002Ioo`03001oogoo01moo`03001oogoo089oo`03
001oogoo021oo`03001oogoo02Aoo`<002eoo`8002=oo`03001oogoo01Uoo`03001oogoo01]oo`03
001oogoo02Eoo`03001oogoo04Yoo`03001oogoo0;]oo`03001oogoo00Moo`00>Woo00<007ooOol0
Sgoo00<007ooOol0AWoo00<007ooOol09Goo00<007ooOol06goo00<007ooOol06Goo00<007ooOol0
5goo00<007ooOol02Goo0P00:Woo00<007oo00009goo00<007ooOol07goo00<007ooOol0PWoo00<0
07ooOol087oo00<007ooOol09goo00<007ooOol09goo0`009Goo00<007ooOol06Goo00<007ooOol0
6goo00<007ooOol09Goo00<007ooOol0BWoo00<007ooOol0^goo00<007ooOol01goo000jOol00`00
Oomoo`2?Ool00`00Oomoo`16Ool00`00Oomoo`0UOol00`00Oomoo`0KOol00`00Oomoo`0IOol00`00
Oomoo`0GOol00`00Oomoo`0;Ool2000WOol01000Oomoo`009Woo00<007ooOol087oo00<007ooOol0
PWoo00<007ooOol08Goo00<007ooOol09goo00<007ooOol09Goo00<007ooOol09Woo00<007ooOol0
67oo00<007ooOol077oo00<007ooOol09Goo00<007ooOol0BWoo00<007ooOol0^goo00<007ooOol0
1goo000jOol00`00Oomoo`2?Ool00`00Oomoo`16Ool00`00Oomoo`0VOol00`00Oomoo`0KOol00`00
Oomoo`0IOol00`00Oomoo`0FOol00`00Oomoo`0=Ool2000ROol30003Ool00`00Oomoo`0TOol00`00
Oomoo`0OOol00`00Oomoo`24Ool00`00Oomoo`0POol00`00Oomoo`0XOol3000ROol2000XOol00`00
Oomoo`0IOol00`00Oomoo`0LOol00`00Oomoo`0UOol00`00Oomoo`1:Ool00`00Oomoo`2kOol00`00
Oomoo`07Ool003Yoo`03001oogoo08moo`03001oogoo04Ioo`03001oogoo02Ioo`03001oogoo01]o
o`03001oogoo01Uoo`03001oogoo01Eoo`03001oogoo011oo`03001oogoo01aoo`<000Ioo`03001o
ogoo02=oo`03001oogoo021oo`03001oogoo08Aoo`03001oogoo025oo`03001oogoo02Yoo`8001io
o`8002Yoo`03001oogoo01Uoo`03001oogoo01]oo`03001oogoo02Ioo`03001oogoo04Yoo`03001o
ogoo0;]oo`03001oogoo00Moo`00>Woo00<007ooOol0SWoo00<007ooOol0B7oo00<007ooOol09Goo
00<007ooOol06goo00<007ooOol06Woo00<007ooOol057oo00<007ooOol04Goo0`006Goo0P002Woo
00<007ooOol08Woo00<007ooOol087oo00<007ooOol0Q7oo00<007ooOol08Goo00<007ooOol0;7oo
0P006Goo0`00:goo00<007ooOol06Goo00<007ooOol077oo00<007ooOol09Woo00<007ooOol0Bgoo
00<007ooOol0^Woo00<007ooOol01goo000jOol00`00Oomoo`2>Ool00`00Oomoo`18Ool00`00Oomo
o`0UOol00`00Oomoo`0KOol00`00Oomoo`0KOol00`00Oomoo`0COol00`00Oomoo`0DOol4000BOol3
000<Ool00`00Oomoo`0QOol00`00Oomoo`0QOol00`00Oomoo`24Ool00`00Oomoo`0ROol00`00Oomo
o`0]Ool3000BOol4000]Ool00`00Oomoo`0JOol00`00Oomoo`0LOol00`00Oomoo`0VOol00`00Oomo
o`1;Ool00`00Oomoo`2jOol00`00Oomoo`07Ool003Yoo`03001oogoo08ioo`03001oogoo04Qoo`03
001oogoo02Eoo`03001oogoo01aoo`03001oogoo01Yoo`03001oogoo01=oo`03001oogoo01Qoo`@0
00Moo`L000moo`03001oogoo021oo`03001oogoo025oo`03001oogoo08Ioo`03001oogoo025oo`03
001oogoo031oo`@000Yoo`@0035oo`03001oogoo01Yoo`03001oogoo01aoo`03001oogoo02Ioo`03
001oogoo04]oo`03001oogoo0;Yoo`03001oogoo00Moo`00>Woo00<007ooOol0SWoo00<007ooOol0
B7oo00<007ooOol09Goo00<007ooOol077oo00<007ooOol06goo00<007ooOol04Woo00<007ooOol0
77oo1`005Woo00<007ooOol07goo00<007ooOol08Woo00<007ooOol0QWoo00<007ooOol08Woo00<0
07ooOol0<goo2P00=7oo00<007ooOol06goo00<007ooOol077oo00<007ooOol09Woo00<007ooOol0
Bgoo00<007ooOol0^Woo00<007ooOol01goo000jOol00`00Oomoo`2>Ool00`00Oomoo`18Ool00`00
Oomoo`0UOol00`00Oomoo`0LOol00`00Oomoo`0KOol00`00Oomoo`0AOol00`00Oomoo`0jOol00`00
Oomoo`0OOol00`00Oomoo`0ROol00`00Oomoo`26Ool00`00Oomoo`0ROol00`00Oomoo`1aOol00`00
Oomoo`0KOol00`00Oomoo`0LOol00`00Oomoo`0VOol00`00Oomoo`1;Ool00`00Oomoo`2jOol00`00
Oomoo`07Ool003Yoo`03001oogoo08ioo`03001oogoo04Qoo`03001oogoo02Eoo`03001oogoo01eo
o`03001oogoo01]oo`03001oogoo011oo`03001oogoo03Yoo`03001oogoo01ioo`03001oogoo029o
o`03001oogoo08Qoo`03001oogoo029oo`03001oogoo06moo`03001oogoo01]oo`03001oogoo01eo
o`03001oogoo02Ioo`03001oogoo04]oo`03001oogoo0;Yoo`03001oogoo00Moo`00>Woo00<007oo
Ool0SWoo00<007ooOol0B7oo00<007ooOol09Woo00<007ooOol077oo00<007ooOol06goo00<007oo
Ool047oo00<007ooOol0>Woo00<007ooOol07Woo00<007ooOol08Woo00<007ooOol0R7oo00<007oo
Ool08Woo00<007ooOol0KWoo00<007ooOol077oo00<007ooOol077oo00<007ooOol09goo00<007oo
Ool0Bgoo00<007ooOol0^Woo00<007ooOol01goo000jOol00`00Oomoo`2>Ool00`00Oomoo`18Ool0
0`00Oomoo`0VOol00`00Oomoo`0LOol00`00Oomoo`0LOol00`00Oomoo`0?Ool00`00Oomoo`0kOol0
0`00Oomoo`0LOol00`00Oomoo`0SOol00`00Oomoo`28Ool00`00Oomoo`0ROol00`00Oomoo`1^Ool0
0`00Oomoo`0LOol00`00Oomoo`0LOol00`00Oomoo`0WOol00`00Oomoo`1;Ool00`00Oomoo`2jOol0
0`00Oomoo`07Ool003Yoo`03001oogoo08ioo`03001oogoo04Qoo`03001oogoo02Ioo`03001oogoo
01eoo`03001oogoo01]oo`03001oogoo00moo`03001oogoo03]oo`03001oogoo01]oo`03001oogoo
02=oo`03001oogoo08Yoo`03001oogoo029oo`03001oogoo06aoo`03001oogoo01aoo`03001oogoo
01eoo`03001oogoo02Ioo`03001oogoo04eoo`03001oogoo0;Uoo`03001oogoo00Moo`00>Woo00<0
07ooOol0SWoo00<007ooOol0B7oo00<007ooOol09Woo00<007ooOol07Goo00<007ooOol077oo00<0
07ooOol03Goo00<007ooOol0?7oo00<007ooOol06goo00<007ooOol08goo00<007ooOol0RWoo00<0
07ooOol08goo00<007ooOol0JWoo00<007ooOol07Goo00<007ooOol07Goo00<007ooOol09Woo00<0
07ooOol0CGoo00<007ooOol0^Goo00<007ooOol01goo000jOol00`00Oomoo`2>Ool00`00Oomoo`18
Ool00`00Oomoo`0WOol00`00Oomoo`0LOol00`00Oomoo`0MOol00`00Oomoo`0<Ool00`00Oomoo`0l
Ool2000KOol00`00Oomoo`0TOol00`00Oomoo`2:Ool00`00Oomoo`0TOol00`00Oomoo`1YOol00`00
Oomoo`0MOol00`00Oomoo`0LOol00`00Oomoo`0WOol00`00Oomoo`1=Ool00`00Oomoo`2iOol00`00
Oomoo`07Ool003Yoo`03001oogoo08ioo`03001oogoo04Qoo`03001oogoo02Moo`03001oogoo01eo
o`03001oogoo01eoo`03001oogoo00]oo`03001oogoo03aoo`8001Yoo`03001oogoo02Aoo`03001o
ogoo08aoo`03001oogoo02Aoo`03001oogoo06Moo`03001oogoo01eoo`03001oogoo01eoo`03001o
ogoo02Moo`03001oogoo04eoo`03001oogoo0;Uoo`03001oogoo00Moo`00>Woo00<007ooOol0SWoo
00<007ooOol0B7oo00<007ooOol09goo00<007ooOol07Goo00<007ooOol07Goo00<007ooOol02goo
00<007ooOol0>goo0`006Woo00<007ooOol097oo00<007ooOol0S7oo00<007ooOol097oo00<007oo
Ool0Igoo00<007ooOol077oo00<007ooOol07Woo00<007ooOol09goo00<007ooOol0CGoo00<007oo
Ool0^Goo00<007ooOol01goo000jOol00`00Oomoo`2>Ool00`00Oomoo`18Ool00`00Oomoo`0WOol0
0`00Oomoo`0MOol00`00Oomoo`0NOol00`00Oomoo`0:Ool00`00Oomoo`0kOol4000HOol00`00Oomo
o`0UOol00`00Oomoo`2<Ool00`00Oomoo`0TOol00`00Oomoo`1VOol00`00Oomoo`0MOol00`00Oomo
o`0NOol00`00Oomoo`0WOol00`00Oomoo`1=Ool00`00Oomoo`2iOol00`00Oomoo`07Ool003Yoo`03
001oogoo08ioo`03001oogoo04Qoo`03001oogoo02Moo`03001oogoo01ioo`03001oogoo01ioo`03
001oogoo00Qoo`03001oogoo03aoo`@001Moo`03001oogoo02Eoo`03001oogoo08ioo`03001oogoo
02Aoo`03001oogoo06Aoo`03001oogoo01ioo`03001oogoo01ioo`03001oogoo02Moo`03001oogoo
04eoo`03001oogoo0;Uoo`03001oogoo00Moo`00>Woo00<007ooOol0SWoo00<007ooOol0B7oo00<0
07ooOol09goo00<007ooOol07Woo00<007ooOol07Woo00<007ooOol027oo00<007ooOol0?7oo1000
5goo00<007ooOol09Goo00<007ooOol0SWoo00<007ooOol09Goo00<007ooOol0HWoo00<007ooOol0
7Woo00<007ooOol07goo00<007ooOol09goo00<007ooOol0CGoo00<007ooOol0^Goo00<007ooOol0
1goo000jOol00`00Oomoo`2=Ool00`00Oomoo`1:Ool00`00Oomoo`0WOol00`00Oomoo`0MOol00`00
Oomoo`0OOol00`00Oomoo`07Ool00`00Oomoo`0lOol5000EOol00`00Oomoo`0VOol00`00Oomoo`2>
Ool00`00Oomoo`0VOol00`00Oomoo`1POol00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0X
Ool00`00Oomoo`1=Ool00`00Oomoo`2iOol00`00Oomoo`07Ool003Yoo`03001oogoo08eoo`03001o
ogoo04Yoo`03001oogoo02Moo`03001oogoo01ioo`03001oogoo01moo`03001oogoo00Ioo`03001o
ogoo03aoo`<00003Ool007oo01=oo`03001oogoo02Moo`03001oogoo08moo`03001oogoo02Ioo`03
001oogoo05ioo`03001oogoo021oo`03001oogoo01ioo`03001oogoo02Qoo`03001oogoo04eoo`03
001oogoo0;Uoo`03001oogoo00Moo`00>Woo00<007ooOol0SGoo00<007ooOol0BWoo00<007ooOol0
9goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol01Goo00<007ooOol0>goo0P0000Aoo`00
Ool001Aoo`03001oogoo02Ioo`03001oogoo091oo`03001oogoo02Ioo`03001oogoo05eoo`03001o
ogoo025oo`03001oogoo01ioo`03001oogoo02Qoo`03001oogoo04eoo`03001oogoo0;Uoo`03001o
ogoo00Moo`00>Woo00<007ooOol0SGoo00<007ooOol0BWoo00<007ooOol09goo00<007ooOol07Woo
00<007ooOol08Goo00<007ooOol00goo00<007ooOol0?7oo0P0000Eoo`00Oomoo`00019oo`03001o
ogoo02Moo`03001oogoo091oo`03001oogoo02Moo`03001oogoo05]oo`03001oogoo025oo`03001o
ogoo01moo`03001oogoo02Qoo`03001oogoo04eoo`03001oogoo0;Uoo`03001oogoo00Moo`00>Woo
00<007ooOol0SGoo00<007ooOol0BWoo00<007ooOol09goo00<007ooOol07goo00<007ooOol087oo
00<007ooOol00goo00<007ooOol0?7oo00@007ooOol001=oo`8002Yoo`03001oogoo095oo`03001o
ogoo02Moo`8005]oo`03001oogoo025oo`03001oogoo01moo`03001oogoo02Qoo`03001oogoo04eo
o`03001oogoo0;Uoo`03001oogoo00Moo`0047oo1`002Woo10005Goo00<007ooOol0SGoo00<007oo
Ool0BWoo00<007ooOol09goo00<007ooOol07goo00<007ooOol08Goo00<007ooOol00Woo00<007oo
Ool0?goo00<007ooOol047oo00<007ooOol0:Woo00<007ooOol0TGoo00<007ooOol0:Goo00<007oo
Ool0F7oo00<007ooOol08Goo00<007ooOol07goo00<007ooOol0:7oo00<007ooOol0CGoo00<007oo
Ool0^Goo00<007ooOol01goo000@Ool70008Ool8000COol00`00Oomoo`2=Ool00`00Oomoo`1:Ool0
0`00Oomoo`0WOol00`00Oomoo`0POol00`00Oomoo`0QOol01@00Oomoogoo0000@Woo00<007ooOol0
3goo00<007ooOol0:Goo00<007ooOol0Tgoo00<007ooOol0:7oo00<007ooOol0Egoo00<007ooOol0
8Goo00<007ooOol07goo00<007ooOol0:Goo00<007ooOol0CGoo00<007ooOol0^Goo00<007ooOol0
1goo000COol2000:Ool20004Ool2000COol00`00Oomoo`2=Ool00`00Oomoo`1:Ool00`00Oomoo`0X
Ool00`00Oomoo`0OOol00`00Oomoo`0ROol01000Ool00000@Woo00<007ooOol03Woo00<007ooOol0
:Goo00<007ooOol0U7oo00<007ooOol0:Goo00<007ooOol0EGoo00<007ooOol08Woo00<007ooOol0
7goo00<007ooOol0:Goo00<007ooOol0CGoo00<007ooOol0^Goo00<007ooOol01goo000COol20009
Ool20006Ool2000BOol00`00Oomoo`2=Ool00`00Oomoo`1:Ool00`00Oomoo`0XOol00`00Oomoo`0P
Ool00`00Oomoo`0ROol30012Ool00`00Oomoo`0=Ool00`00Oomoo`0ZOol00`00Oomoo`2DOol00`00
Oomoo`0ZOol00`00Oomoo`1COol00`00Oomoo`0ROol00`00Oomoo`0POol00`00Oomoo`0YOol00`00
Oomoo`1=Ool00`00Oomoo`2iOol00`00Oomoo`07Ool001=oo`8000Uoo`8000Ioo`80019oo`03001o
ogoo08eoo`03001oogoo04Yoo`03001oogoo02Qoo`03001oogoo021oo`03001oogoo029oo`<0049o
o`03001oogoo00aoo`03001oogoo02Yoo`03001oogoo09Ioo`03001oogoo02Yoo`03001oogoo055o
o`03001oogoo02=oo`03001oogoo021oo`03001oogoo02Qoo`03001oogoo04ioo`03001oogoo0;Uo
o`03001oogoo00Moo`002goo30001Woo0P0027oo0P004Goo00<007ooOol0SGoo00<007ooOol0BWoo
00<007ooOol0:7oo00<007ooOol087oo00<007ooOol08Woo1000@Goo00<007ooOol02goo00<007oo
Ool0:goo00<007ooOol0UWoo00<007ooOol0:goo00<007ooOol0Cgoo00<007ooOol08goo00<007oo
Ool087oo00<007ooOol0:Goo00<007ooOol0CWoo00<007ooOol0^Goo00<007ooOol01goo000;Ool<
0006Ool20008Ool2000AOol00`00Oomoo`2=Ool00`00Oomoo`1:Ool00`00Oomoo`0YOol00`00Oomo
o`0POol00`00Oomoo`0POol400000goo001oo`0oOol00`00Oomoo`0:Ool00`00Oomoo`0[Ool00`00
Oomoo`2HOol00`00Oomoo`0[Ool00`00Oomoo`1=Ool00`00Oomoo`0TOol00`00Oomoo`0POol00`00
Oomoo`0YOol00`00Oomoo`1>Ool00`00Oomoo`2iOol00`00Oomoo`07Ool000]oo`8000Ioo`800003
Ool007oo00Eoo`8000Qoo`80015oo`P008Qoo`03001oogoo04Yoo`03001oogoo02Uoo`03001oogoo
021oo`03001oogoo01moo`D00003Ool007oo03moo`03001oogoo00Uoo`03001oogoo02aoo`03001o
ogoo09Qoo`03001oogoo02aoo`03001oogoo04Yoo`8002Ioo`03001oogoo025oo`03001oogoo02Uo
o`03001oogoo04ioo`03001oogoo0;9oo`P000Uoo`0037oo0P001Goo0P0027oo0P0027oo0P004Goo
00<007ooOol0SGoo00<007ooOol0BWoo00<007ooOol0:Goo00<007ooOol087oo00<007ooOol07goo
1@000Woo00<007ooOol0?Woo00<007ooOol01Woo0P00;goo00<007ooOol0V7oo00<007ooOol0;Goo
0P00BGoo00<007ooOol09Woo00<007ooOol08Goo00<007ooOol0:Goo00<007ooOol0CWoo00<007oo
Ool0^Goo00<007ooOol01goo000<Ool30004Ool20008Ool20008Ool2000AOol00`00Oomoo`2=Ool0
0`00Oomoo`1:Ool00`00Oomoo`0YOol00`00Oomoo`0QOol00`00Oomoo`0MOol2000017oo00000000
0goo00<007ooOol0?Goo00<007ooOol01Goo00<007ooOol0;Woo00<007ooOol0VWoo00<007ooOol0
;Woo00<007ooOol0AGoo00<007ooOol09Woo00<007ooOol08Woo00<007ooOol0:Goo00<007ooOol0
CWoo00<007ooOol0^Goo00<007ooOol01goo000=Ool20004Ool20008Ool20008Ool2000AOol00`00
Oomoo`2=Ool00`00Oomoo`1:Ool00`00Oomoo`0ZOol00`00Oomoo`0POol00`00Oomoo`0MOol00`00
Oomoo`030004Ool2000mOol00`00Oomoo`04Ool00`00Oomoo`0_Ool00`00Oomoo`2JOol00`00Oomo
o`0_Ool00`00Oomoo`12Ool2000YOol00`00Oomoo`0QOol00`00Oomoo`0ZOol00`00Oomoo`1>Ool0
0`00Oomoo`2iOol00`00Oomoo`07Ool000ioo`8000=oo`8000Qoo`8000Qoo`80015oo`03001oogoo
08eoo`03001oogoo04Yoo`03001oogoo02Yoo`03001oogoo025oo`03001oogoo01]oo`07001oogoo
Ool007oo00001Woo00<007ooOol0>Woo00<007ooOol00Woo0P00<Woo00<007ooOol0Vgoo00<007oo
Ool0;goo0P00@Goo00<007ooOol0:Goo00<007ooOol08Goo00<007ooOol0:Woo00<007ooOol0CWoo
00<007ooOol0^Goo00<007ooOol01goo000>Ool30002Ool20008Ool20008Ool2000AOol00`00Oomo
o`2=Ool00`00Oomoo`1;Ool00`00Oomoo`0YOol00`00Oomoo`0QOol00`00Oomoo`0NOol01000Oomo
o`001goo00<007ooOol0>Goo00D007ooOomoo`0003=oo`03001oogoo09aoo`03001oogoo035oo`03
001oogoo03eoo`03001oogoo02Uoo`03001oogoo029oo`03001oogoo02Uoo`03001oogoo051oo`03
001oogoo0;Qoo`03001oogoo00Moo`003goo0P000Woo0P002Goo0P001Woo0P004Woo00<007ooOol0
SGoo00<007ooOol0Bgoo00<007ooOol0:Goo00<007ooOol08Woo00<007ooOol07Goo00<007ooOol0
2Goo0P00>Goo00@007ooOol003Aoo`03001oogoo09eoo`03001oogoo035oo`03001oogoo03Yoo`80
02]oo`03001oogoo02=oo`03001oogoo02Uoo`03001oogoo051oo`03001oogoo0;Qoo`03001oogoo
00Moo`0047oo0P0000=oo`0000002Goo0P001Woo0P004Woo00<007ooOol0SGoo00<007ooOol0Bgoo
00<007ooOol0:Woo00<007ooOol08Goo00<007ooOol07Goo00<007ooOol02goo0P00=goo0`00=7oo
00<007ooOol0WWoo00<007ooOol0<Woo0P00>Goo00<007ooOol0:goo00<007ooOol08Woo00<007oo
Ool0:Woo00<007ooOol0D7oo00<007ooOol0^7oo00<007ooOol01goo000AOol4000:Ool20004Ool2
000COol00`00Oomoo`2=Ool00`00Oomoo`1;Ool00`00Oomoo`0ZOol00`00Oomoo`0ROol00`00Oomo
o`0LOol00`00Oomoo`0=Ool2000dOol3000dOol00`00Oomoo`2POol00`00Oomoo`0cOol00`00Oomo
o`0cOol3000]Ool00`00Oomoo`0SOol00`00Oomoo`0ZOol00`00Oomoo`1@Ool00`00Oomoo`2hOol0
0`00Oomoo`07Ool0015oo`@000Yoo`P001=oo`03001oogoo08eoo`03001oogoo04]oo`03001oogoo
02Yoo`03001oogoo029oo`03001oogoo01]oo`80015oo`80031oo`80009oo`03001oogoo039oo`03
001oogoo0:1oo`03001oogoo03Aoo`03001oogoo035oo`03001oogoo02ioo`03001oogoo02=oo`03
001oogoo02Yoo`03001oogoo051oo`03001oogoo0;Qoo`03001oogoo00Moo`004Woo0`0037oo1000
5Goo00<007ooOol0SGoo00<007ooOol0Bgoo00<007ooOol0:goo00<007ooOol08Woo00<007ooOol0
6Woo00<007ooOol04Woo0P00;Goo00<007ooOol00Woo00<007ooOol0<Goo00<007ooOol0XWoo00<0
07ooOol0=7oo0P00<7oo00<007ooOol0;Woo00<007ooOol08goo00<007ooOol0:goo00<007ooOol0
D7oo00<007ooOol0^7oo00<007ooOol01goo000jOol00`00Oomoo`2=Ool00`00Oomoo`1;Ool00`00
Oomoo`0[Ool00`00Oomoo`0ROol00`00Oomoo`0JOol00`00Oomoo`0DOol2000YOol20005Ool00`00
Oomoo`0aOol00`00Oomoo`2SOol00`00Oomoo`0eOol2000/Ool2000aOol00`00Oomoo`0SOol00`00
Oomoo`0[Ool00`00Oomoo`1@Ool00`00Oomoo`2hOol00`00Oomoo`07Ool003Yoo`03001oogoo08eo
o`03001oogoo04]oo`03001oogoo02]oo`03001oogoo02=oo`03001oogoo01Uoo`03001oogoo01Io
o`8002Eoo`8000Moo`03001oogoo035oo`03001oogoo0:=oo`03001oogoo03Moo`<002Ioo`<003=o
o`03001oogoo02=oo`03001oogoo02]oo`03001oogoo051oo`03001oogoo0;Qoo`03001oogoo00Mo
o`00>Woo00<007ooOol0SGoo00<007ooOol0C7oo00<007ooOol0:goo00<007ooOol08Woo00<007oo
Ool06Goo00<007ooOol067oo00<007ooOol07goo0`002Goo00<007ooOol0<7oo00<007ooOol0YGoo
00<007ooOol0>Goo0`008Goo0P00=Goo00<007ooOol08goo00<007ooOol0;7oo00<007ooOol0D7oo
00<007ooOol0^7oo00<007ooOol01goo000jOol00`00Oomoo`2=Ool00`00Oomoo`1<Ool00`00Oomo
o`0[Ool00`00Oomoo`0SOol00`00Oomoo`0GOol00`00Oomoo`0JOol3000JOol4000<Ool00`00Oomo
o`0`Ool00`00Oomoo`2UOol00`00Oomoo`0lOol00`00Oomoo`0KOol3000gOol00`00Oomoo`0SOol0
0`00Oomoo`0[Ool00`00Oomoo`1AOol00`00Oomoo`2hOol00`00Oomoo`07Ool003Yoo`03001oogoo
08eoo`03001oogoo04aoo`03001oogoo02]oo`03001oogoo02Aoo`03001oogoo01Ioo`03001oogoo
01eoo`@0019oo`@0011oo`03001oogoo02moo`03001oogoo0:Moo`03001oogoo03aoo`<001Ioo`@0
03Uoo`03001oogoo02Aoo`03001oogoo02]oo`03001oogoo055oo`03001oogoo0;Qoo`03001oogoo
00Moo`00>Woo00<007ooOol0SGoo00<007ooOol0C7oo00<007ooOol0;7oo00<007ooOol08goo00<0
07ooOol05Woo00<007ooOol08Goo20000goo1`0057oo0P00<7oo00<007ooOol0Ygoo00<007ooOol0
?goo200027oo1P00?Goo00<007ooOol08goo00<007ooOol0;7oo00<007ooOol0DGoo00<007ooOol0
^7oo00<007ooOol01goo000jOol00`00Oomoo`2=Ool00`00Oomoo`1<Ool00`00Oomoo`0/Ool00`00
Oomoo`0TOol00`00Oomoo`0EOol00`00Oomoo`0YOol3000LOol00`00Oomoo`0]Ool00`00Oomoo`2Y
Ool00`00Oomoo`16Ool80011Ool2000VOol00`00Oomoo`0/Ool00`00Oomoo`1AOol00`00Oomoo`2h
Ool00`00Oomoo`07Ool003Yoo`03001oogoo08eoo`03001oogoo04aoo`03001oogoo02aoo`03001o
ogoo02Aoo`03001oogoo01Aoo`8004Yoo`03001oogoo02aoo`03001oogoo0:Yoo`03001oogoo08mo
o`03001oogoo02Eoo`03001oogoo02aoo`03001oogoo055oo`03001oogoo0;Qoo`03001oogoo00Mo
o`00>Woo00<007ooOol0SGoo00<007ooOol0C7oo00<007ooOol0;7oo00<007ooOol09Goo00<007oo
Ool04goo00<007ooOol0BGoo00<007ooOol0:goo00<007ooOol0[7oo00<007ooOol0SGoo00<007oo
Ool09Goo00<007ooOol0;Goo00<007ooOol0DGoo00<007ooOol0^7oo00<007ooOol01goo000jOol0
0`00Oomoo`2=Ool00`00Oomoo`1=Ool00`00Oomoo`0/Ool00`00Oomoo`0UOol00`00Oomoo`0BOol0
0`00Oomoo`19Ool00`00Oomoo`0[Ool00`00Oomoo`2/Ool00`00Oomoo`2=Ool00`00Oomoo`0UOol0
0`00Oomoo`0]Ool00`00Oomoo`1AOol00`00Oomoo`2hOol00`00Oomoo`07Ool003Yoo`03001oogoo
08eoo`03001oogoo04eoo`03001oogoo02aoo`03001oogoo02Eoo`03001oogoo019oo`03001oogoo
04Uoo`03001oogoo02Yoo`03001oogoo0:eoo`03001oogoo08aoo`03001oogoo02Ioo`03001oogoo
02eoo`03001oogoo055oo`03001oogoo0;Qoo`03001oogoo00Moo`00>Woo00<007ooOol0SWoo00<0
07ooOol0C7oo00<007ooOol0;7oo00<007ooOol09Woo00<007ooOol04Goo00<007ooOol0BGoo00<0
07ooOol0:Goo00<007ooOol0[goo00<007ooOol0RWoo00<007ooOol09Woo00<007ooOol0;Goo00<0
07ooOol0DGoo00<007ooOol0^Goo00<007ooOol01goo000jOol00`00Oomoo`2>Ool00`00Oomoo`1<
Ool00`00Oomoo`0/Ool00`00Oomoo`0WOol00`00Oomoo`0?Ool00`00Oomoo`1:Ool00`00Oomoo`0Y
Ool00`00Oomoo`2`Ool00`00Oomoo`29Ool00`00Oomoo`0VOol00`00Oomoo`0]Ool00`00Oomoo`1A
Ool00`00Oomoo`2iOol00`00Oomoo`07Ool003Yoo`03001oogoo08ioo`03001oogoo04eoo`03001o
ogoo02aoo`03001oogoo02Ioo`03001oogoo00moo`03001oogoo04Yoo`8002Uoo`03001oogoo0;9o
o`03001oogoo08Moo`03001oogoo02Moo`03001oogoo02eoo`03001oogoo055oo`03001oogoo0;Uo
o`03001oogoo00Moo`00>Woo00<007ooOol0SWoo00<007ooOol0CGoo00<007ooOol0;7oo00<007oo
Ool09goo00<007ooOol03Woo00<007ooOol0Bgoo00<007ooOol09Woo00<007ooOol0]7oo00<007oo
Ool0QWoo00<007ooOol09goo00<007ooOol0;Goo00<007ooOol0DGoo00<007ooOol0^Goo00<007oo
Ool01goo000jOol00`00Oomoo`2>Ool00`00Oomoo`1=Ool00`00Oomoo`0/Ool00`00Oomoo`0WOol0
0`00Oomoo`0>Ool00`00Oomoo`1;Ool00`00Oomoo`0VOol00`00Oomoo`1DOol:001FOol00`00Oomo
o`26Ool00`00Oomoo`0WOol00`00Oomoo`0]Ool00`00Oomoo`1AOol00`00Oomoo`2iOol00`00Oomo
o`07Ool003Yoo`03001oogoo08ioo`03001oogoo04eoo`03001oogoo02eoo`03001oogoo02Moo`03
001oogoo00aoo`8004eoo`03001oogoo02Eoo`03001oogoo05=oo`8000Yoo`8005Eoo`03001oogoo
08Aoo`03001oogoo02Moo`03001oogoo02ioo`03001oogoo055oo`03001oogoo0;Uoo`03001oogoo
00Moo`00>Woo00<007ooOol0SWoo00<007ooOol0CGoo00<007ooOol0;Goo00<007ooOol0:7oo00<0
07ooOol02goo00<007ooOol0C7oo00<007ooOol097oo00<007ooOol0DWoo0P003Woo0P00E7oo00<0
07ooOol0PWoo00<007ooOol0:7oo00<007ooOol0;Goo00<007ooOol0DWoo00<007ooOol0^Goo00<0
07ooOol01goo000jOol00`00Oomoo`2>Ool00`00Oomoo`1=Ool00`00Oomoo`0^Ool00`00Oomoo`0X
Ool00`00Oomoo`0:Ool00`00Oomoo`1<Ool00`00Oomoo`0TOol00`00Oomoo`1@Ool2000BOol2001B
Ool00`00Oomoo`21Ool00`00Oomoo`0YOol00`00Oomoo`0]Ool00`00Oomoo`1BOol00`00Oomoo`2i
Ool00`00Oomoo`07Ool003Yoo`03001oogoo08ioo`03001oogoo04eoo`03001oogoo02ioo`03001o
ogoo02Qoo`03001oogoo00Yoo`03001oogoo04aoo`03001oogoo02=oo`03001oogoo04moo`8001Io
o`80055oo`03001oogoo081oo`03001oogoo02Qoo`03001oogoo02ioo`03001oogoo059oo`03001o
ogoo0;Uoo`03001oogoo00Moo`00>Woo00<007ooOol0SWoo00<007ooOol0CWoo00<007ooOol0;Goo
00<007ooOol0:Goo00<007ooOol02Goo00<007ooOol0C7oo0P008goo00<007ooOol0Cgoo00<007oo
Ool067oo00<007ooOol0Cgoo00<007ooOol0OWoo00<007ooOol0:Goo00<007ooOol0;Woo00<007oo
Ool0DWoo00<007ooOol0^Goo00<007ooOol01goo000jOol00`00Oomoo`2>Ool00`00Oomoo`1>Ool0
0`00Oomoo`0^Ool00`00Oomoo`0YOol00`00Oomoo`07Ool00`00Oomoo`1=Ool2000ROol00`00Oomo
o`1?Ool00`00Oomoo`0JOol00`00Oomoo`1?Ool00`00Oomoo`1lOol00`00Oomoo`0ZOol00`00Oomo
o`0]Ool00`00Oomoo`1COol00`00Oomoo`2iOol00`00Oomoo`07Ool003Yoo`03001oogoo08ioo`03
001oogoo04ioo`03001oogoo02ioo`03001oogoo02Yoo`03001oogoo00Ioo`03001oogoo04aoo`<0
025oo`03001oogoo04moo`03001oogoo01aoo`03001oogoo04moo`03001oogoo07Yoo`03001oogoo
02Yoo`03001oogoo02ioo`03001oogoo05=oo`03001oogoo0;Uoo`03001oogoo00Moo`00>Woo00<0
07ooOol0SWoo00<007ooOol0CWoo00<007ooOol0;Woo00<007ooOol0:goo00<007ooOol01Goo00<0
07ooOol0C7oo100087oo00<007ooOol0CWoo00<007ooOol07Woo00<007ooOol0Cgoo00<007ooOol0
N7oo00<007ooOol0:goo00<007ooOol0;Woo00<007ooOol0Dgoo00<007ooOol0^Goo00<007ooOol0
1goo000jOol00`00Oomoo`2>Ool00`00Oomoo`1>Ool00`00Oomoo`0_Ool00`00Oomoo`0ZOol00`00
Oomoo`05Ool00`00Oomoo`1<Ool4000OOol00`00Oomoo`1>Ool00`00Oomoo`0POol00`00Oomoo`1?
Ool00`00Oomoo`1gOol00`00Oomoo`0ZOol00`00Oomoo`0_Ool00`00Oomoo`1COol00`00Oomoo`2i
Ool00`00Oomoo`07Ool003Yoo`03001oogoo08ioo`03001oogoo04moo`03001oogoo02ioo`03001o
ogoo02]oo`03001oogoo00=oo`8004ioo`@001moo`03001oogoo04eoo`03001oogoo029oo`03001o
ogoo04ioo`03001oogoo07Ioo`03001oogoo02]oo`03001oogoo02ioo`03001oogoo05Aoo`03001o
ogoo0;Uoo`03001oogoo00Moo`00>Woo00<007ooOol0SWoo00<007ooOol0Cgoo00<007ooOol0;Woo
00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol0CGoo1@007Goo00<007ooOol0CGoo00<007oo
Ool097oo0P00Cgoo00<007ooOol0M7oo00<007ooOol0:goo00<007ooOol0;goo00<007ooOol0E7oo
00<007ooOol0^Goo00<007ooOol01goo000jOol00`00Oomoo`2>Ool00`00Oomoo`1?Ool00`00Oomo
o`0_Ool00`00Oomoo`0[Ool00`00Oomoo`02Ool00`00Oomoo`1=Ool5000LOol00`00Oomoo`1=Ool0
0`00Oomoo`0WOol00`00Oomoo`1=Ool00`00Oomoo`1bOol00`00Oomoo`0/Ool00`00Oomoo`0_Ool0
0`00Oomoo`1COol00`00Oomoo`2jOol00`00Oomoo`07Ool003Yoo`03001oogoo08moo`03001oogoo
04ioo`03001oogoo02moo`03001oogoo02aoo`05001oogooOol0001?Ool01@00Ool007oo00006goo
00<007ooOol0CGoo00<007ooOol0:Goo00<007ooOol0CGoo00<007ooOol0L7oo00<007ooOol0;Goo
00<007ooOol0;goo00<007ooOol0Dgoo00<007ooOol0^Woo00<007ooOol01goo000jOol00`00Oomo
o`2?Ool00`00Oomoo`1>Ool00`00Oomoo`0_Ool00`00Oomoo`0]Ool01000Oomoo`00CWoo0P0000=o
o`00Ool00P006Goo00<007ooOol0CGoo00<007ooOol0:goo00<007ooOol0CGoo00<007ooOol0Kgoo
00<007ooOol0;7oo00<007ooOol0<7oo00<007ooOol0Dgoo00<007ooOol0^Woo00<007ooOol01goo
000jOol00`00Oomoo`2?Ool00`00Oomoo`1?Ool00`00Oomoo`0_Ool00`00Oomoo`0]Ool3001>Ool2
0002Ool00`00Ool0000HOol00`00Oomoo`1>Ool00`00Oomoo`0[Ool00`00Oomoo`1=Ool00`00Oomo
o`1^Ool00`00Oomoo`0]Ool00`00Oomoo`0_Ool00`00Oomoo`1DOol00`00Oomoo`2jOol00`00Oomo
o`07Ool003Yoo`D008eoo`03001oogoo04moo`03001oogoo02moo`8002moo`8004ioo`05001oogoo
Ool0000IOol00`00Oomoo`1>Ool00`00Oomoo`0]Ool00`00Oomoo`1=Ool00`00Oomoo`1[Ool2000_
Ool00`00Oomoo`0`Ool00`00Oomoo`1DOol00`00Oomoo`2eOol60009Ool003Yoo`03001oogoo08mo
o`03001oogoo04moo`03001oogoo031oo`03001oogoo02aoo`<0059oo`03001oogoo01Ioo`03001o
ogoo04ioo`03001oogoo02ioo`03001oogoo04ioo`03001oogoo06Uoo`03001oogoo02moo`03001o
ogoo031oo`03001oogoo05Aoo`03001oogoo0;Yoo`03001oogoo00Moo`00>Woo00<007ooOol0Sgoo
00<007ooOol0Cgoo00<007ooOol0<Goo00<007ooOol0:goo1000DGoo00<007ooOol057oo0P00D7oo
00<007ooOol0<7oo00<007ooOol0CWoo0P00J7oo00<007ooOol0<7oo00<007ooOol0<7oo00<007oo
Ool0E7oo00<007ooOol0^Woo00<007ooOol01goo000jOol00`00Oomoo`2?Ool00`00Oomoo`1@Ool0
0`00Oomoo`0`Ool00`00Oomoo`0ZOol400000goo001oo`1?Ool00`00Oomoo`0COol00`00Oomoo`1?
Ool00`00Oomoo`0bOol00`00Oomoo`1?Ool00`00Oomoo`1TOol00`00Oomoo`0`Ool00`00Oomoo`0a
Ool00`00Oomoo`1DOol00`00Oomoo`2jOol00`00Oomoo`07Ool003Yoo`03001oogoo08moo`03001o
ogoo051oo`03001oogoo031oo`03001oogoo02Uoo`D0009oo`03001oogoo04eoo`03001oogoo019o
o`03001oogoo04moo`03001oogoo03Aoo`03001oogoo04moo`03001oogoo069oo`03001oogoo035o
o`03001oogoo035oo`03001oogoo05Aoo`03001oogoo0;Yoo`03001oogoo00Moo`00>Woo00<007oo
Ool0Sgoo00<007ooOol0D7oo00<007ooOol0<Goo00<007ooOol0:7oo1@000goo0P00CGoo00<007oo
Ool04Goo00<007ooOol0Cgoo00<007ooOol0=Woo00<007ooOol0Cgoo00<007ooOol0H7oo00<007oo
Ool0<Goo00<007ooOol0<Goo00<007ooOol0EGoo00<007ooOol0^Woo00<007ooOol01goo000jOol0
0`00Oomoo`2?Ool00`00Oomoo`1@Ool00`00Oomoo`0aOol00`00Oomoo`0WOol2000017oo00000000
1Goo00<007ooOol0BWoo00<007ooOol047oo00<007ooOol0Cgoo00<007ooOol0>7oo00<007ooOol0
Cgoo00<007ooOol0GWoo00<007ooOol0<Woo00<007ooOol0<Goo00<007ooOol0EGoo00<007ooOol0
^Woo00<007ooOol01goo000jOol00`00Oomoo`2?Ool00`00Oomoo`1AOol00`00Oomoo`0`Ool00`00
Oomoo`0WOol00`00Oomoo`030006Ool00`00Oomoo`19Ool2000@Ool00`00Oomoo`1?Ool00`00Oomo
o`0jOol00`00Oomoo`1?Ool00`00Oomoo`1LOol00`00Oomoo`0cOol00`00Oomoo`0aOol00`00Oomo
o`1EOol00`00Oomoo`2jOol00`00Oomoo`07Ool003Yoo`03001oogoo08moo`03001oogoo055oo`03
001oogoo035oo`03001oogoo02Eoo`05001oogoo001oo`020007Ool2001:Ool00`00Oomoo`0;Ool3
001AOol00`00Oomoo`0lOol00`00Oomoo`1?Ool00`00Oomoo`1IOol2000eOol00`00Oomoo`0bOol0
0`00Oomoo`1EOol00`00Oomoo`2jOol00`00Oomoo`07Ool003Yoo`03001oogoo08moo`03001oogoo
055oo`03001oogoo035oo`03001oogoo02Qoo`04001oogoo0009Ool00`00Oomoo`17Ool00`00Oomo
o`0:Ool00`00Oomoo`1AOol00`00Oomoo`0nOol00`00Oomoo`1?Ool2001HOol00`00Oomoo`0eOol0
0`00Oomoo`0aOol00`00Oomoo`1FOol00`00Oomoo`2jOol00`00Oomoo`07Ool003Yoo`03001oogoo
08moo`03001oogoo055oo`03001oogoo035oo`03001oogoo02Qoo`04001oogoo000:Ool00`00Oomo
o`16Ool00`00Oomoo`09Ool00`00Oomoo`1AOol00`00Oomoo`10Ool00`00Oomoo`1@Ool2001EOol0
0`00Oomoo`0eOol00`00Oomoo`0bOol00`00Oomoo`1FOol00`00Oomoo`2jOol00`00Oomoo`07Ool0
03Yoo`03001oogoo08moo`03001oogoo059oo`03001oogoo035oo`03001oogoo02Moo`03001oogoo
00aoo`03001oogoo04Eoo`03001oogoo00Qoo`03001oogoo055oo`03001oogoo049oo`03001oogoo
055oo`80055oo`8003Qoo`03001oogoo039oo`03001oogoo05Ioo`03001oogoo0;Yoo`03001oogoo
00Moo`00>Woo00<007ooOol0Sgoo00<007ooOol0DWoo00<007ooOol0<Goo00<007ooOol09Woo0P00
3goo00<007ooOol0A7oo00<007ooOol01goo00<007ooOol0DWoo00<007ooOol0@Woo00<007ooOol0
Dgoo00<007ooOol0CGoo00<007ooOol0=goo00<007ooOol0<Woo00<007ooOol0EWoo00<007ooOol0
^goo00<007ooOol01goo000jOol00`00Oomoo`2@Ool00`00Oomoo`1AOol00`00Oomoo`0bOol00`00
Oomoo`0UOol00`00Oomoo`0?Ool00`00Oomoo`13Ool00`00Oomoo`06Ool00`00Oomoo`1BOol00`00
Oomoo`14Ool00`00Oomoo`1COol00`00Oomoo`1;Ool00`00Oomoo`0hOol00`00Oomoo`0bOol00`00
Oomoo`1FOol00`00Oomoo`2kOol00`00Oomoo`07Ool003Yoo`03001oogoo091oo`03001oogoo055o
o`03001oogoo03=oo`03001oogoo02Aoo`03001oogoo011oo`8004=oo`03001oogoo00Aoo`8005Ao
o`03001oogoo04Ioo`03001oogoo05=oo`8004Uoo`8003Yoo`03001oogoo03=oo`03001oogoo05Io
o`03001oogoo0;]oo`03001oogoo00Moo`00>Woo00<007ooOol0T7oo00<007ooOol0DWoo00<007oo
Ool0<Woo00<007ooOol097oo00<007ooOol04Woo0P00@Goo00<007ooOol00Woo0P00EWoo00<007oo
Ool0Agoo00<007ooOol0E7oo00<007ooOol0A7oo0P00?7oo00<007ooOol0<Woo00<007ooOol0Egoo
00<007ooOol0^goo00<007ooOol01goo000jOol00`00Oomoo`2@Ool00`00Oomoo`1BOol00`00Oomo
o`0cOol00`00Oomoo`0SOol00`00Oomoo`0DOol20010Ool01000Ool00000EWoo0P00Bgoo00<007oo
Ool0E7oo0P00@Woo0P00?Goo00<007ooOol0<goo00<007ooOol0Egoo00<007ooOol0^goo00<007oo
Ool01goo000jOol00`00Oomoo`2@Ool00`00Oomoo`1BOol00`00Oomoo`0cOol00`00Oomoo`0ROol0
0`00Oomoo`0GOol2000nOol2001HOol00`00Oomoo`1;Ool00`00Oomoo`1EOol2000oOol00`00Oomo
o`0lOol00`00Oomoo`0dOol00`00Oomoo`1GOol00`00Oomoo`2kOol00`00Oomoo`07Ool003Yoo`03
001oogoo091oo`03001oogoo05=oo`03001oogoo03=oo`03001oogoo025oo`03001oogoo01Uoo`80
03Yoo`<005Qoo`03001oogoo04eoo`03001oogoo05Ioo`8003aoo`03001oogoo03eoo`03001oogoo
03Aoo`03001oogoo05Moo`03001oogoo0;]oo`03001oogoo00Moo`00>Woo00<007ooOol0T7oo00<0
07ooOol0Dgoo00<007ooOol0<goo00<007ooOol08Goo00<007ooOol06goo0P00=Woo0P000Woo00<0
07ooOol0EGoo00<007ooOol0Cgoo00<007ooOol0Egoo0P00=goo0`00?goo00<007ooOol0=7oo00<0
07ooOol0F7oo00<007ooOol0^goo00<007ooOol01goo000jOol00`00Oomoo`2@Ool00`00Oomoo`1C
Ool00`00Oomoo`0dOol00`00Oomoo`0POol00`00Oomoo`0MOol2000bOol20004Ool00`00Oomoo`1D
Ool00`00Oomoo`1AOol00`00Oomoo`1HOol2000bOol30012Ool00`00Oomoo`0dOol00`00Oomoo`1H
Ool00`00Oomoo`2kOol00`00Oomoo`07Ool003Yoo`03001oogoo095oo`03001oogoo059oo`03001o
ogoo03Eoo`03001oogoo01ioo`80025oo`8002ioo`8000Ioo`03001oogoo05=oo`03001oogoo059o
o`03001oogoo05Yoo`8002moo`03001oogoo049oo`03001oogoo03Eoo`03001oogoo05Moo`03001o
ogoo0;aoo`03001oogoo00Moo`00>Woo00<007ooOol0TGoo00<007ooOol0DWoo00<007ooOol0=Goo
00<007ooOol07Woo00<007ooOol08Woo0`00:Goo0P0027oo00<007ooOol0DWoo00<007ooOol0E7oo
00<007ooOol0Fgoo0`00:Goo0`00A7oo00<007ooOol0=Goo00<007ooOol0F7oo00<007ooOol0_7oo
00<007ooOol01goo000jOol00`00Oomoo`2AOol00`00Oomoo`1COol00`00Oomoo`0eOol00`00Oomo
o`0MOol00`00Oomoo`0UOol3000ROol4000:Ool00`00Oomoo`1AOol00`00Oomoo`1FOol00`00Oomo
o`1MOol4000QOol40017Ool00`00Oomoo`0eOol00`00Oomoo`1HOol00`00Oomoo`2lOol00`00Oomo
o`07Ool003Yoo`03001oogoo095oo`03001oogoo05=oo`03001oogoo03Eoo`03001oogoo01eoo`03
001oogoo02Qoo`<001aoo`<000ioo`03001oogoo051oo`03001oogoo05Qoo`03001oogoo061oo`80
01eoo`8004Yoo`03001oogoo03Ioo`03001oogoo05Qoo`03001oogoo0;aoo`03001oogoo00Moo`00
>Woo00<007ooOol0TGoo00<007ooOol0Dgoo00<007ooOol0=Woo00<007ooOol077oo00<007ooOol0
:goo1@004Woo1@004Woo00<007ooOol0Cgoo00<007ooOol0FGoo00<007ooOol0HGoo1@004Woo1P00
C7oo00<007ooOol0=Woo00<007ooOol0F7oo00<007ooOol0_7oo00<007ooOol01goo000jOol00`00
Oomoo`2AOol00`00Oomoo`1COol00`00Oomoo`0fOol00`00Oomoo`0KOol00`00Oomoo`0aOolB000G
Ool00`00Oomoo`1>Ool00`00Oomoo`1JOol00`00Oomoo`1VOolB001BOol00`00Oomoo`0fOol00`00
Oomoo`1HOol00`00Oomoo`2lOol00`00Oomoo`07Ool003Yoo`03001oogoo099oo`03001oogoo05=o
o`03001oogoo03Ioo`03001oogoo01Yoo`03001oogoo05Yoo`03001oogoo04eoo`03001oogoo05ao
o`03001oogoo0<Qoo`03001oogoo03Ioo`03001oogoo05Uoo`03001oogoo0;aoo`03001oogoo00Mo
o`00>Woo00<007ooOol0TWoo00<007ooOol0Dgoo00<007ooOol0=goo00<007ooOol06Goo00<007oo
Ool0FWoo00<007ooOol0C7oo00<007ooOol0GWoo00<007ooOol0aWoo00<007ooOol0=goo00<007oo
Ool0F7oo00<007ooOol0_Goo00<007ooOol01goo000jOol00`00Oomoo`2BOol00`00Oomoo`1DOol0
0`00Oomoo`0fOol00`00Oomoo`0IOol00`00Oomoo`1JOol00`00Oomoo`1;Ool00`00Oomoo`1POol0
0`00Oomoo`34Ool00`00Oomoo`0hOol00`00Oomoo`1HOol00`00Oomoo`2mOol00`00Oomoo`07Ool0
03Yoo`03001oogoo099oo`03001oogoo05Aoo`03001oogoo03Moo`03001oogoo01Moo`8005aoo`03
001oogoo04Yoo`03001oogoo069oo`03001oogoo0<9oo`03001oogoo03Qoo`03001oogoo05Uoo`03
001oogoo0;eoo`03001oogoo00Moo`00>Woo00<007ooOol0Tgoo00<007ooOol0Dgoo00<007ooOol0
=goo00<007ooOol05goo00<007ooOol0Fgoo00<007ooOol0BGoo00<007ooOol0I7oo00<007ooOol0
`Goo00<007ooOol0>7oo00<007ooOol0FGoo00<007ooOol0_Goo00<007ooOol01goo000jOol00`00
Oomoo`2COol00`00Oomoo`1DOol00`00Oomoo`0gOol00`00Oomoo`0FOol00`00Oomoo`1KOol00`00
Oomoo`18Ool00`00Oomoo`1VOol00`00Oomoo`2oOol00`00Oomoo`0iOol00`00Oomoo`1HOol00`00
Oomoo`2nOol00`00Oomoo`07Ool003Yoo`03001oogoo09=oo`03001oogoo05Aoo`03001oogoo03Qo
o`03001oogoo01Eoo`03001oogoo05]oo`03001oogoo04Moo`03001oogoo06Qoo`03001oogoo0;io
o`03001oogoo03Qoo`03001oogoo05Uoo`03001oogoo0;ioo`03001oogoo00Moo`00>Woo00<007oo
Ool0Tgoo00<007ooOol0E7oo00<007ooOol0>7oo00<007ooOol05Goo00<007ooOol0Fgoo00<007oo
Ool0AWoo00<007ooOol0JWoo00<007ooOol0_Goo00<007ooOol0>7oo00<007ooOol0FGoo00<007oo
Ool0_Woo00<007ooOol01goo000jOol00`00Oomoo`2COol00`00Oomoo`1EOol00`00Oomoo`0hOol0
0`00Oomoo`0COol00`00Oomoo`1MOol00`00Oomoo`14Ool00`00Oomoo`1/Ool00`00Oomoo`2kOol0
0`00Oomoo`0iOol00`00Oomoo`1IOol00`00Oomoo`2nOol00`00Oomoo`07Ool003Yoo`03001oogoo
09=oo`03001oogoo05Eoo`03001oogoo03Uoo`03001oogoo019oo`03001oogoo05eoo`03001oogoo
04=oo`03001oogoo06ioo`03001oogoo0;Uoo`03001oogoo03Yoo`03001oogoo05Uoo`03001oogoo
0;ioo`03001oogoo00Moo`00>Woo00<007ooOol0Tgoo00<007ooOol0EGoo00<007ooOol0>Goo00<0
07ooOol04Woo00<007ooOol0GGoo00<007ooOol0@Woo00<007ooOol0L7oo00<007ooOol0^7oo00<0
07ooOol0>Goo00<007ooOol0FGoo00<007ooOol0_goo00<007ooOol01goo000jOol00`00Oomoo`2D
Ool00`00Oomoo`1EOol00`00Oomoo`0iOol00`00Oomoo`0AOol00`00Oomoo`1MOol00`00Oomoo`12
Ool00`00Oomoo`1aOol00`00Oomoo`2fOol00`00Oomoo`0jOol00`00Oomoo`1IOol00`00Oomoo`2o
Ool00`00Oomoo`07Ool003Yoo`03001oogoo09Aoo`03001oogoo05Eoo`03001oogoo03Yoo`03001o
ogoo00moo`8005moo`80049oo`03001oogoo07=oo`03001oogoo0;Aoo`03001oogoo03Yoo`03001o
ogoo05Yoo`03001oogoo0;moo`03001oogoo00Moo`00>Woo00<007ooOol0U7oo00<007ooOol0EGoo
00<007ooOol0>Woo00<007ooOol03goo00<007ooOol0GWoo0P00@Goo00<007ooOol0MGoo00<007oo
Ool0/Woo00<007ooOol0>goo00<007ooOol0FWoo00<007ooOol0_goo00<007ooOol01goo000jOol5
002BOol00`00Oomoo`1FOol00`00Oomoo`0jOol2000?Ool00`00Oomoo`1NOol2000oOol2001iOol0
0`00Oomoo`2`Ool00`00Oomoo`0kOol00`00Oomoo`1KOol00`00Oomoo`2jOol60009Ool003Yoo`03
001oogoo09Aoo`03001oogoo05Ioo`03001oogoo03]oo`03001oogoo00eoo`03001oogoo05ioo`<0
03eoo`03001oogoo07Yoo`03001oogoo0:moo`03001oogoo03]oo`03001oogoo05]oo`03001oogoo
0;moo`03001oogoo00Moo`00>Woo00<007ooOol0U7oo00<007ooOol0EWoo00<007ooOol0?7oo00<0
07ooOol037oo00<007ooOol0GWoo0`00?7oo00<007ooOol0O7oo00<007ooOol0[Goo00<007ooOol0
?7oo00<007ooOol0Fgoo00<007ooOol0_goo00<007ooOol01goo000jOol00`00Oomoo`2EOol00`00
Oomoo`1EOol00`00Oomoo`0mOol00`00Oomoo`0:Ool00`00Oomoo`1NOol5000jOol00`00Oomoo`1n
Ool00`00Oomoo`2[Ool00`00Oomoo`0lOol00`00Oomoo`1KOol00`00Oomoo`30Ool00`00Oomoo`07
Ool003Yoo`03001oogoo09Eoo`03001oogoo05Ioo`03001oogoo03aoo`03001oogoo00Yoo`03001o
ogoo05ioo`D003Uoo`03001oogoo081oo`03001oogoo0:Uoo`03001oogoo03eoo`03001oogoo05]o
o`03001oogoo0<1oo`03001oogoo00Moo`00>Woo00<007ooOol0UGoo00<007ooOol0EWoo00<007oo
Ool0?Goo00<007ooOol027oo0P00H7oo0`0000=oo`000000=goo00<007ooOol0PWoo00<007ooOol0
Ygoo00<007ooOol0?Woo00<007ooOol0Fgoo00<007ooOol0`7oo00<007ooOol01goo000jOol00`00
Oomoo`2EOol00`00Oomoo`1GOol00`00Oomoo`0lOol00`00Oomoo`08Ool2001POol300000goo0000
000fOol00`00Oomoo`24Ool00`00Oomoo`2VOol00`00Oomoo`0mOol00`00Oomoo`1LOol00`00Oomo
o`30Ool00`00Oomoo`07Ool003Yoo`03001oogoo09Eoo`03001oogoo05Moo`03001oogoo03eoo`03
001oogoo00Ioo`<0061oo`<0009oo`03001oogoo03=oo`03001oogoo08Ioo`03001oogoo0:Aoo`03
001oogoo03ioo`03001oogoo05aoo`03001oogoo0<1oo`03001oogoo00Moo`00>Woo00<007ooOol0
UWoo00<007ooOol0EWoo00<007ooOol0?Woo00<007ooOol01Goo0`00H7oo00<007oo00000goo00<0
07ooOol0<Goo00<007ooOol0R7oo00<007ooOol0XWoo00<007ooOol0?goo00<007ooOol0Fgoo00<0
07ooOol0`Goo00<007ooOol01goo000jOol00`00Oomoo`2FOol00`00Oomoo`1GOol00`00Oomoo`0n
Ool20004Ool4001POol00`00Ool0000eOol2002<Ool2002QOol00`00Oomoo`0oOol00`00Oomoo`1L
Ool00`00Oomoo`31Ool00`00Oomoo`07Ool003Yoo`03001oogoo09Ioo`03001oogoo05Moo`03001o
ogoo03moo`03001oogoo009oo`@0069oo`03001oogoo039oo`03001oogoo08ioo`03001oogoo09eo
o`03001oogoo041oo`03001oogoo05aoo`03001oogoo0<5oo`03001oogoo00Moo`00>Woo00<007oo
Ool0UWoo00<007ooOol0F7oo00<007ooOol0?goo00@007ooOomoo`@0069oo`03001oogoo035oo`03
001oogoo091oo`03001oogoo09]oo`03001oogoo041oo`03001oogoo05eoo`03001oogoo0<5oo`03
001oogoo00Moo`00>Woo00<007ooOol0UWoo00<007ooOol0F7oo00<007ooOol0@7oo00<007oo0000
1000HWoo00<007ooOol0<7oo00<007ooOol0TWoo00<007ooOol0VGoo00<007ooOol0@Goo00<007oo
Ool0G7oo00<007ooOol0`Woo00<007ooOol01goo000jOol00`00Oomoo`2FOol00`00Oomoo`1IOol0
0`00Oomoo`10Ool2000017oo001oo`00HWoo00<007ooOol0;goo00<007ooOol0U7oo00<007ooOol0
Ugoo00<007ooOol0@Goo00<007ooOol0GGoo00<007ooOol0`Woo00<007ooOol01goo000jOol00`00
Oomoo`2GOol00`00Oomoo`1HOol00`00Oomoo`10Ool2000017oo001oo`00HWoo00<007ooOol0;Woo
00<007ooOol0UWoo0P00UWoo00<007ooOol0@Woo00<007ooOol0GGoo00<007ooOol0`Woo00<007oo
Ool01goo000jOol00`00Oomoo`2GOol00`00Oomoo`1IOol00`00Oomoo`11Ool200000goo001oo`1R
Ool00`00Oomoo`0/Ool00`00Oomoo`2IOol00`00Oomoo`2COol00`00Oomoo`11Ool00`00Oomoo`1N
Ool00`00Oomoo`32Ool00`00Oomoo`07Ool003Yoo`03001oogoo09Moo`03001oogoo05Uoo`03001o
ogoo045oo`8006Eoo`03001oogoo02]oo`03001oogoo09]oo`03001oogoo095oo`03001oogoo049o
o`03001oogoo05eoo`03001oogoo0<=oo`03001oogoo00Moo`00>Woo00<007ooOol0Ugoo00<007oo
Ool0FWoo00<007ooOol0@7oo00@007oo000006=oo`03001oogoo02Uoo`8009moo`80091oo`03001o
ogoo049oo`03001oogoo05ioo`03001oogoo0<=oo`03001oogoo00Moo`00>Woo00<007ooOol0Ugoo
00<007ooOol0FWoo00<007ooOol0@7oo00D007ooOomoo`00069oo`03001oogoo02Qoo`03001oogoo
0:5oo`03001oogoo08]oo`8004Eoo`03001oogoo05ioo`03001oogoo0<=oo`03001oogoo00Moo`00
>Woo00<007ooOol0Ugoo00<007ooOol0Fgoo00<007ooOol0?goo00<007ooOol00Woo00<007ooOol0
Ggoo00<007ooOol09goo00<007ooOol0Xgoo00<007ooOol0RGoo00<007ooOol0A7oo00<007ooOol0
Ggoo00<007ooOol0`goo00<007ooOol01goo000jOol00`00Oomoo`2HOol00`00Oomoo`1JOol00`00
Oomoo`0oOol00`00Oomoo`03Ool00`00Oomoo`1NOol00`00Oomoo`0UOol2002WOol00`00Oomoo`27
Ool00`00Oomoo`15Ool00`00Oomoo`1NOol00`00Oomoo`34Ool00`00Oomoo`07Ool003Yoo`03001o
ogoo09Qoo`03001oogoo05Yoo`03001oogoo03moo`03001oogoo00Aoo`03001oogoo05eoo`03001o
ogoo02=oo`800:Yoo`03001oogoo08Eoo`03001oogoo04Ioo`03001oogoo05ioo`03001oogoo0<Ao
o`03001oogoo00Moo`00>Woo00<007ooOol0V7oo00<007ooOol0Fgoo00<007ooOol0?Goo00<007oo
Ool01Woo00<007ooOol0G7oo00<007ooOol08Goo0P00[Goo00<007ooOol0Pgoo00<007ooOol0AWoo
00<007ooOol0Ggoo00<007ooOol0a7oo00<007ooOol01goo000jOol00`00Oomoo`2HOol00`00Oomo
o`1LOol00`00Oomoo`0lOol00`00Oomoo`07Ool00`00Oomoo`1KOol00`00Oomoo`0POol00`00Oomo
o`2^Ool20022Ool00`00Oomoo`17Ool00`00Oomoo`1OOol00`00Oomoo`34Ool00`00Oomoo`07Ool0
03Yoo`03001oogoo09Uoo`03001oogoo05]oo`03001oogoo03aoo`03001oogoo00Qoo`03001oogoo
05Yoo`03001oogoo01moo`03001oogoo0;5oo`8007moo`03001oogoo04Moo`03001oogoo05moo`03
001oogoo0<Eoo`03001oogoo00Moo`00>Woo00<007ooOol0VGoo00<007ooOol0G7oo00<007ooOol0
>goo00<007ooOol02Goo0P00FWoo00<007ooOol07Goo0P00]Woo0P00Ngoo0P00BWoo00<007ooOol0
Ggoo00<007ooOol0aGoo00<007ooOol01goo000jOol00`00Oomoo`2JOol00`00Oomoo`1KOol00`00
Oomoo`0jOol2000=Ool00`00Oomoo`1GOol00`00Oomoo`0LOol00`00Oomoo`2hOol00`00Oomoo`1g
Ool00`00Oomoo`1:Ool00`00Oomoo`1OOol00`00Oomoo`35Ool00`00Oomoo`07Ool003Yoo`03001o
ogoo09Yoo`03001oogoo05aoo`03001oogoo03Uoo`03001oogoo00eoo`8005Qoo`03001oogoo01Yo
o`03001oogoo0;Yoo`03001oogoo07Eoo`03001oogoo04Yoo`03001oogoo061oo`03001oogoo0<Eo
o`03001oogoo00Moo`00>Woo00<007ooOol0VWoo00<007ooOol0G7oo00<007ooOol0>Goo00<007oo
Ool03goo00<007ooOol0EGoo00<007ooOol067oo0P00_Woo0P00Lgoo0P00C7oo00<007ooOol0HGoo
00<007ooOol0aGoo00<007ooOol01goo000jOol00`00Oomoo`2KOol00`00Oomoo`1KOol00`00Oomo
o`0iOol00`00Oomoo`0@Ool00`00Oomoo`1DOol00`00Oomoo`0GOol00`00Oomoo`30Ool2001_Ool2
001=Ool00`00Oomoo`1QOol00`00Oomoo`36Ool00`00Oomoo`07Ool003Yoo`03001oogoo09]oo`03
001oogoo05aoo`03001oogoo03Qoo`03001oogoo015oo`8005Aoo`03001oogoo01Eoo`800<Eoo`80
06aoo`03001oogoo04eoo`03001oogoo065oo`03001oogoo0<Ioo`03001oogoo00Moo`00>Woo00<0
07ooOol0Vgoo00<007ooOol0G7oo00<007ooOol0=goo00<007ooOol057oo00<007ooOol0DGoo00<0
07ooOol04goo0P00bGoo0P00JGoo00<007ooOol0CGoo00<007ooOol0HWoo00<007ooOol0aWoo00<0
07ooOol01goo000jOol00`00Oomoo`2KOol00`00Oomoo`1MOol00`00Oomoo`0fOol00`00Oomoo`0E
Ool00`00Oomoo`1@Ool00`00Oomoo`0AOol2003=Ool00`00Oomoo`1UOol00`00Oomoo`1>Ool00`00
Oomoo`1ROol00`00Oomoo`36Ool00`00Oomoo`07Ool003Yoo`03001oogoo09aoo`03001oogoo05ao
o`03001oogoo03Ioo`03001oogoo01Ioo`03001oogoo04moo`03001oogoo011oo`03001oogoo0<io
o`03001oogoo06=oo`03001oogoo04moo`03001oogoo065oo`03001oogoo0<Moo`03001oogoo00Mo
o`00>Woo00<007ooOol0W7oo00<007ooOol0GGoo00<007ooOol0=Goo00<007ooOol05goo0`00CWoo
00<007ooOol03Goo0`00dWoo0`00H7oo0P00DGoo00<007ooOol0HWoo00<007ooOol0agoo00<007oo
Ool01goo000jOol00`00Oomoo`2LOol00`00Oomoo`1NOol00`00Oomoo`0dOol00`00Oomoo`0JOol2
001<Ool00`00Oomoo`0;Ool2003HOol2001KOol3001COol00`00Oomoo`1ROol00`00Oomoo`37Ool0
0`00Oomoo`07Ool003Yoo`03001oogoo09aoo`03001oogoo05ioo`03001oogoo03=oo`03001oogoo
01eoo`03001oogoo04Uoo`03001oogoo00Uoo`800=aoo`8005Moo`8005Eoo`03001oogoo069oo`03
001oogoo0<Qoo`03001oogoo00Moo`00>Woo00<007ooOol0W7oo00<007ooOol0Ggoo00<007ooOol0
<Woo00<007ooOol07Woo0P00BGoo00<007ooOol01goo0P00h7oo0P00Dgoo0P00Egoo00<007ooOol0
HWoo00<007ooOol0b7oo00<007ooOol01goo000jOol00`00Oomoo`2MOol00`00Oomoo`1OOol00`00
Oomoo`0aOol00`00Oomoo`0POol20017Ool00`00Oomoo`04Ool3003TOol2001?Ool2001HOol00`00
Oomoo`1SOol00`00Oomoo`38Ool00`00Oomoo`07Ool003Yoo`03001oogoo09eoo`03001oogoo05mo
o`03001oogoo035oo`03001oogoo029oo`<004Aoo`04001oogooOol3003YOol2001;Ool2001IOol0
0`00Oomoo`1SOol00`00Oomoo`39Ool00`00Oomoo`07Ool003Yoo`03001oogoo09eoo`03001oogoo
061oo`03001oogoo031oo`03001oogoo02Eoo`<0049oo`03001oo`000>ioo`<004Ioo`8005]oo`03
001oogoo06=oo`03001oogoo0<Uoo`03001oogoo00Moo`00>Woo00<007ooOol0WGoo00<007ooOol0
HGoo00<007ooOol0;Woo00<007ooOol0:Goo0P00@7oo0P00lWoo0`00@Goo0P00G7oo00<007ooOol0
I7oo00<007ooOol0bGoo00<007ooOol01goo000jOol5002LOol00`00Oomoo`1POol00`00Oomoo`0^
Ool00`00Oomoo`0[Ool3000hOol6003fOol4000iOol4001MOol00`00Oomoo`1TOol00`00Oomoo`35
Ool60009Ool003Yoo`03001oogoo09ioo`03001oogoo061oo`03001oogoo02ioo`03001oogoo02io
o`@0031oo`@000Eoo`03001oogoo0?Qoo`@0035oo`@0065oo`03001oogoo06Aoo`03001oogoo0<Yo
o`03001oogoo00Moo`00>Woo00<007ooOol0Wgoo00<007ooOol0H7oo00<007ooOol0;Goo00<007oo
Ool0<Woo0`00:Goo10002Goo00<007ooOol0o7oo1000:Goo1000IGoo00<007ooOol0I7oo00<007oo
Ool0bWoo00<007ooOol01goo000jOol00`00Oomoo`2OOol00`00Oomoo`1POol00`00Oomoo`0]Ool0
0`00Oomoo`0eOol4000ROol3000=Ool00`00Oomoo`3oOol1Ool4000QOol4001XOol00`00Oomoo`1T
Ool00`00Oomoo`3;Ool00`00Oomoo`07Ool003Yoo`03001oogoo09moo`03001oogoo065oo`03001o
ogoo02]oo`03001oogoo03Yoo`P0019oo`P0011oo`03001oogoo0?moo`Eoo`@001Uoo`@006]oo`03
001oogoo06Eoo`03001oogoo0<]oo`03001oogoo00Moo`00>Woo00<007ooOol0X7oo00<007ooOol0
H7oo00<007ooOol0:goo00<007ooOol0@Woo4P0067oo00<007ooOol0ogoo2Goo6@00Kgoo00<007oo
Ool0I7oo00<007ooOol0c7oo00<007ooOol01goo000jOol00`00Oomoo`2POol00`00Oomoo`1QOol0
0`00Oomoo`0ZOol00`00Oomoo`1/Ool2003oOonAOol00`00Oomoo`1UOol00`00Oomoo`3<Ool00`00
Oomoo`07Ool003Yoo`03001oogoo0:1oo`03001oogoo069oo`03001oogoo02Uoo`03001oogoo06ao
o`800?mooi1oo`03001oogoo06Ioo`03001oogoo0<aoo`03001oogoo00Moo`00>Woo00<007ooOol0
XGoo00<007ooOol0HWoo00<007ooOol0:7oo00<007ooOol0Jgoo0`00ogooSgoo00<007ooOol0IWoo
00<007ooOol0cGoo00<007ooOol01goo000jOol00`00Oomoo`2QOol00`00Oomoo`1ROol00`00Oomo
o`0WOol2001]Ool4003oOon>Ool00`00Oomoo`1VOol00`00Oomoo`3=Ool00`00Oomoo`07Ool003Yo
o`03001oogoo0:5oo`03001oogoo06=oo`03001oogoo02Ioo`8006eoo`@00?mooheoo`03001oogoo
06Moo`03001oogoo0<eoo`03001oogoo00Moo`00>Woo00<007ooOol0XGoo00<007ooOol0I7oo00<0
07ooOol09Goo0P00KGoo1000ogooS7oo00<007ooOol0Igoo00<007ooOol0cWoo00<007ooOol01goo
000jOol00`00Oomoo`2ROol00`00Oomoo`1SOol00`00Oomoo`0TOol3001]Ool5003oOon:Ool00`00
Oomoo`1XOol00`00Oomoo`3>Ool00`00Oomoo`07Ool003Yoo`03001oogoo0:9oo`03001oogoo06Ao
o`03001oogoo02=oo`<006eoo`03001oo`0000800?moohYoo`03001oogoo06Qoo`03001oogoo0<io
o`03001oogoo00Moo`00>Woo00<007ooOol0Xgoo00<007ooOol0I7oo00<007ooOol08Goo1000KGoo
00<007oo00000P00ogooRGoo00<007ooOol0J7oo00<007ooOol0cgoo00<007ooOol01goo000jOol0
0`00Oomoo`2SOol00`00Oomoo`1UOol00`00Oomoo`0POol5001[Ool200000goo001oo`02003oOon7
Ool00`00Oomoo`1YOol00`00Oomoo`3?Ool00`00Oomoo`07Ool003Yoo`03001oogoo0:=oo`03001o
ogoo06Ioo`03001oogoo01moo`800003Ool0000006]oo`04001oogoo0002Ool00`00Oomoo`3oOon5
Ool00`00Oomoo`1YOol00`00Oomoo`3?Ool00`00Oomoo`07Ool003Yoo`03001oogoo0:Aoo`03001o
ogoo06Eoo`03001oogoo01ioo`<00003Ool0000006]oo`04001oogoo003oOon8Ool2001[Ool00`00
Oomoo`3@Ool00`00Oomoo`07Ool003Yoo`03001oogoo0:Aoo`03001oogoo06Ioo`03001oogoo01eo
o`04001oo`00Ool2001^Ool00`00Oomoo`3oOon6Ool00`00Oomoo`1ZOol00`00Oomoo`3@Ool00`00
Oomoo`07Ool003Yoo`03001oogoo0:Eoo`03001oogoo06Ioo`03001oogoo01]oo`04001oo`000002
Ool00`00Oomoo`1/Ool00`00Oomoo`3oOon5Ool00`00Oomoo`1ZOol00`00Oomoo`3AOol00`00Oomo
o`07Ool003Yoo`03001oogoo0:Eoo`03001oogoo06Moo`03001oogoo01aoo`05001oogooOol0001^
Ool00`00Oomoo`3oOon4Ool00`00Oomoo`1[Ool00`00Oomoo`3AOol00`00Oomoo`07Ool003Yoo`03
001oogoo0:Eoo`03001oogoo06Qoo`03001oogoo01]oo`03001oogoo071oo`03001oogoo0?moohAo
o`03001oogoo06]oo`03001oogoo0=5oo`03001oogoo00Moo`00>Woo00<007ooOol0YWoo00<007oo
Ool0Igoo00<007ooOol06goo00<007ooOol0L7oo00<007ooOol0ogooPgoo00<007ooOol0Jgoo00<0
07ooOol0dWoo00<007ooOol01goo000jOol00`00Oomoo`2VOol00`00Oomoo`1XOol00`00Oomoo`0J
Ool00`00Oomoo`1`Ool00`00Oomoo`3oOon2Ool00`00Oomoo`1/Ool00`00Oomoo`3BOol00`00Oomo
o`07Ool003Yoo`03001oogoo0:Ioo`03001oogoo06Uoo`03001oogoo01Uoo`03001oogoo071oo`03
001oogoo0?mooh5oo`03001oogoo06aoo`03001oogoo0==oo`03001oogoo00Moo`00>Woo00<007oo
Ool0Ygoo00<007ooOol0JGoo00<007ooOol05goo00<007ooOol0LGoo00<007ooOol0ogooP7oo00<0
07ooOol0KGoo00<007ooOol0dgoo00<007ooOol01goo000jOol00`00Oomoo`2WOol00`00Oomoo`1Z
Ool00`00Oomoo`0FOol00`00Oomoo`1aOol00`00Oomoo`3oOon0Ool00`00Oomoo`1]Ool00`00Oomo
o`3COol00`00Oomoo`07Ool003Yoo`03001oogoo0:Qoo`03001oogoo06Uoo`03001oogoo01Ioo`03
001oogoo075oo`800?mooh1oo`03001oogoo06eoo`03001oogoo0=Aoo`03001oogoo00Moo`00>Woo
00<007ooOol0Z7oo00<007ooOol0JWoo00<007ooOol05Goo00<007ooOol0LWoo00<007ooOol0ogoo
OGoo00<007ooOol0KGoo00<007ooOol0eGoo00<007ooOol01goo000jOol00`00Oomoo`2XOol00`00
Oomoo`1[Ool00`00Oomoo`0DOol00`00Oomoo`1bOol00`00Oomoo`3oOomlOol00`00Oomoo`1^Ool0
0`00Oomoo`3EOol00`00Oomoo`07Ool003Yoo`03001oogoo0:Uoo`03001oogoo06]oo`03001oogoo
019oo`03001oogoo07=oo`03001oogoo0?moog]oo`03001oogoo06ioo`03001oogoo0=Ioo`03001o
ogoo00Moo`00>Woo00<007ooOol0ZGoo00<007ooOol0K7oo00<007ooOol04Goo00<007ooOol0Lgoo
00<007ooOol0ogooNWoo00<007ooOol0Kgoo00<007ooOol0eWoo00<007ooOol01goo000jOol00`00
Oomoo`2ZOol00`00Oomoo`1/Ool00`00Oomoo`0@Ool00`00Oomoo`1cOol00`00Oomoo`3oOomiOol0
0`00Oomoo`1_Ool00`00Oomoo`3GOol00`00Oomoo`07Ool003Yoo`03001oogoo0:Yoo`03001oogoo
06eoo`03001oogoo00moo`03001oogoo07=oo`03001oogoo0?moogQoo`03001oogoo071oo`03001o
ogoo0=Moo`03001oogoo00Moo`00>Woo00<007ooOol0ZWoo00<007ooOol0KWoo00<007ooOol03Woo
00<007ooOol0Lgoo00<007ooOol0ogooMgoo00<007ooOol0LGoo00<007ooOol0egoo00<007ooOol0
1goo000?Ool5000=Ool4000EOol00`00Oomoo`2[Ool00`00Oomoo`1^Ool00`00Oomoo`0=Ool00`00
Oomoo`1cOol00`00Oomoo`3oOomfOol00`00Oomoo`1aOol00`00Oomoo`3HOol00`00Oomoo`07Ool0
00eoo`P000Yoo`P001=oo`03001oogoo0:aoo`03001oogoo06ioo`03001oogoo00]oo`8007Eoo`03
001oogoo0?moogEoo`03001oogoo075oo`03001oogoo0=Uoo`03001oogoo00Moo`003Goo0P0017oo
0`002Goo0P0017oo0P004goo00<007ooOol0[7oo00<007ooOol0Kgoo00<007ooOol02Woo00<007oo
Ool0M7oo00<007ooOol0ogooM7oo00<007ooOol0LWoo00<007ooOol0fGoo00<007ooOol01goo000<
Ool20006Ool30007Ool20006Ool2000BOol00`00Oomoo`2]Ool00`00Oomoo`1_Ool2000:Ool00`00
Oomoo`1dOol00`00Oomoo`3oOomcOol00`00Oomoo`1bOol00`00Oomoo`3JOol00`00Oomoo`07Ool0
00]oo`8000Qoo`8000Moo`8000Ioo`80019oo`03001oogoo0:eoo`03001oogoo075oo`03001oogoo
00Moo`03001oogoo07Aoo`03001oogoo0?moog9oo`03001oogoo07=oo`03001oogoo0=Yoo`03001o
ogoo00Moo`002goo0P0027oo0P001Woo0P0027oo0P004Goo00<007ooOol0[Goo00<007ooOol0LWoo
00<007ooOol01Woo00<007ooOol0M7oo00<007ooOol0ogooLGoo00<007ooOol0M7oo00<007ooOol0
fWoo00<007ooOol01goo000;Ool20008Ool20006Ool20008Ool2000AOol00`00Oomoo`2^Ool00`00
Oomoo`1bOol00`00Oomoo`05Ool00`00Oomoo`1dOol00`00Oomoo`3oOom`Ool00`00Oomoo`1dOol0
0`00Oomoo`3KOol00`00Oomoo`07Ool000]oo`8000Qoo`8000Ioo`8000Qoo`80015oo`P00:Uoo`03
001oogoo079oo`8000Eoo`03001oogoo07Eoo`03001oogoo0?moofioo`8007Moo`03001oogoo0=Ao
o`P000Uoo`002goo0`001Woo0`001Woo0P0027oo0P004Goo00<007ooOol0[Woo00<007ooOol0M7oo
00<007ooOol00Woo00<007ooOol0MGoo00<007ooOol0ogooKGoo00<007ooOol0Mgoo00<007ooOol0
fgoo00<007ooOol01goo000;Ool40004Ool30007Ool20008Ool2000AOol00`00Oomoo`2_Ool00`00
Oomoo`1dOol01@00Oomoogoo0000Mgoo00<007ooOol0ogooK7oo00<007ooOol0Mgoo00<007ooOol0
g7oo00<007ooOol01goo000;Ool200000goo000000050008Ool20008Ool2000AOol00`00Oomoo`2_
Ool00`00Oomoo`1eOol01000Oomoo`00Mgoo00<007ooOol0J7oo7000iGoo0P00NWoo00<007ooOol0
g7oo00<007ooOol01goo000<Ool00`00Oomoo`050009Ool20008Ool2000AOol00`00Oomoo`2`Ool0
0`00Oomoo`1eOol00`00Ool0001hOol00`00Oomoo`1POol7000LOol8003LOol00`00Oomoo`1iOol0
0`00Oomoo`3MOol00`00Oomoo`07Ool000aoo`8000moo`8000Qoo`80015oo`03001oogoo0;1oo`03
001oogoo07Ioo`8007Qoo`03001oogoo05aoo`@002]oo`@00=Moo`03001oogoo07Yoo`03001oogoo
0=eoo`03001oogoo00Moo`0037oo0`003goo0P001Woo0P004Woo00<007ooOol0/Goo00<007ooOol0
MGoo0`00Mgoo00<007ooOol0F7oo1000<goo0`00dgoo00<007ooOol0NWoo00<007ooOol0gWoo00<0
07ooOol01goo000=Ool3000>Ool20006Ool2000BOol00`00Oomoo`2bOol00`00Oomoo`1dOol01000
Oomoo`00MWoo00<007ooOol0E7oo1000>Woo1000cWoo00<007ooOol0NWoo00<007ooOol0ggoo00<0
07ooOol01goo000>Ool3000>Ool20004Ool2000COol00`00Oomoo`2cOol00`00Oomoo`1cOol01@00
Oomoogoo0000MGoo00<007ooOol0D7oo1000@Woo1@00agoo0P00O7oo00<007ooOol0h7oo00<007oo
Ool01goo000?Ool80008Ool8000COol00`00Oomoo`2cOol00`00Oomoo`1cOol00`00Oomoo`02Ool2
001cOol00`00Oomoo`1=Ool3001;Ool30032Ool2001nOol00`00Oomoo`3POol00`00Oomoo`07Ool0
015oo`H000Yoo`@001Eoo`03001oogoo0;Aoo`03001oogoo079oo`03001oogoo00Aoo`80075oo`03
001oogoo04Uoo`@0055oo`@00;eoo`03001oogoo07eoo`03001oogoo0>5oo`03001oogoo00Moo`00
>Woo00<007ooOol0]7oo00<007ooOol0LWoo00<007ooOol01Woo0P00Kgoo00<007ooOol0AGoo1000
FGoo0`00^Goo00<007ooOol0OWoo00<007ooOol0hGoo00<007ooOol01goo000jOol00`00Oomoo`2d
Ool00`00Oomoo`1aOol2000:Ool00`00Oomoo`1/Ool00`00Oomoo`11Ool4001POol4002cOol20020
Ool00`00Oomoo`3ROol00`00Oomoo`07Ool003Yoo`03001oogoo0;Eoo`03001oogoo071oo`03001o
ogoo00Yoo`03001oogoo06]oo`03001oogoo03ioo`<006Qoo`<00:ioo`80085oo`03001oogoo0>=o
o`03001oogoo00Moo`00>Woo00<007ooOol0]Woo00<007ooOol0Kgoo00<007ooOol02goo0P00Jgoo
00<007ooOol0?7oo0P00KWoo0P00ZWoo0P00Pgoo00<007ooOol0hgoo00<007ooOol01goo000jOol0
0`00Oomoo`2fOol00`00Oomoo`1_Ool00`00Oomoo`0=Ool2001YOol00`00Oomoo`0jOol2001bOol3
002VOol00`00Oomoo`22Ool00`00Oomoo`3TOol00`00Oomoo`07Ool003Yoo`03001oogoo0;Moo`03
001oogoo06eoo`80015oo`8006Ioo`<003Moo`@007Moo`@00:1oo`8008Aoo`03001oogoo0>Eoo`03
001oogoo00Moo`00>Woo00<007ooOol0^7oo00<007ooOol0K7oo0P004goo0P00I7oo0`00=7oo0`00
Ogoo0P00WGoo00<007ooOol0Q7oo00<007ooOol0iGoo00<007ooOol01goo000jOol00`00Oomoo`2h
Ool00`00Oomoo`1[Ool3000EOol2001ROol3000bOol20024Ool2002JOol00`00Oomoo`25Ool00`00
Oomoo`3UOol00`00Oomoo`07Ool003Yoo`03001oogoo0;Uoo`03001oogoo06Yoo`<001Moo`03001o
ogoo05moo`<002moo`<008Qoo`<009Eoo`8008Moo`03001oogoo0>Ioo`03001oogoo00Moo`00>Woo
00<007ooOol0^Woo00<007ooOol0J7oo100067oo0P00GWoo1@00:Woo1000SWoo1000Sgoo0P00R7oo
00<007ooOol0igoo00<007ooOol01goo000jOol00`00Oomoo`2jOol00`00Oomoo`1XOol5000IOol2
001LOol5000WOol3002FOol40028Ool30029Ool00`00Oomoo`3XOol00`00Oomoo`07Ool003Yoo`03
001oogoo0;]oo`03001oogoo06Moo`D001]oo`8005Yoo`D002Aoo`<009eoo`<0089oo`<008]oo`03
001oogoo0>Uoo`03001oogoo00Moo`00>Woo00<007ooOol0_7oo00<007ooOol0IGoo0P0000Aoo`00
000001eoo`8005Qoo`05001oo`00Ool0000ROol2002SOol2001nOol2002>Ool00`00Oomoo`3YOol0
0`00Oomoo`07Ool003Yoo`03001oogoo0;aoo`03001oogoo06Eoo`03001oogoo00<001moo`8005Eo
o`800003Ool007oo008001moo`800:Moo`8007]oo`03001oogoo08eoo`03001oogoo0>Yoo`03001o
ogoo00Moo`00>Woo00<007ooOol0_Goo00<007ooOol0Hgoo00@007ooOol0009oo`03001oogoo01mo
o`@0055oo`04001oogoo0002Ool00`00Oomoo`0HOol5002[Ool4001eOol2002@Ool00`00Oomoo`3Z
Ool00`00Oomoo`07Ool003Yoo`03001oogoo0;eoo`03001oogoo06Ioo`04001oogoo000UOol2001C
Ool00`00Oomoo`0FOol4002dOol4001^Ool3002AOol00`00Oomoo`3[Ool00`00Oomoo`07Ool003Yo
o`03001oogoo0;ioo`03001oogoo06Eoo`03001oogoo02Qoo`<0051oo`03001oogoo01=oo`<00;ao
o`@006Ioo`@009=oo`03001oogoo0>aoo`03001oogoo00Moo`00>Woo00<007ooOol0_goo00<007oo
Ool0I7oo00<007ooOol0:goo0`00CGoo00<007ooOol03goo1000`goo1000Ggoo0`00UWoo00<007oo
Ool0kGoo00<007ooOol01goo000jOol00`00Oomoo`30Ool00`00Oomoo`1SOol00`00Oomoo`0^Ool4
0019Ool00`00Oomoo`0;Ool4003;Ool4001IOol2002IOol00`00Oomoo`3]Ool00`00Oomoo`07Ool0
03Yoo`03001oogoo0<1oo`03001oogoo06=oo`03001oogoo039oo`@004Eoo`03001oogoo00Moo`@0
0==oo`<005=oo`<009Yoo`03001oogoo0>ioo`03001oogoo00Moo`00>Woo00<007ooOol0`Goo00<0
07ooOol0HWoo00<007ooOol0=Woo1000@Goo00<007ooOol00goo1000fWoo1000Bgoo1000W7oo00<0
07ooOol0kgoo00<007ooOol01goo000jOol00`00Oomoo`31Ool00`00Oomoo`1QOol00`00Oomoo`0k
Ool3000mOol7003ROol7000nOol6002POol00`00Oomoo`3_Ool00`00Oomoo`07Ool003Yoo`03001o
ogoo0<9oo`80065oo`03001oogoo03ioo`@003Eoo`@00003Ool007oo0>eoo`D003Aoo`D00:Eoo`03
001oogoo0?1oo`03001oogoo00Moo`00>Woo00<007ooOol0a7oo00<007ooOol0GWoo00<007ooOol0
@Woo20009Goo20001Goo00<007ooOol0lGoo1`009Goo2000ZWoo00<007ooOol0l7oo00<007ooOol0
1goo000jOol00`00Oomoo`34Ool00`00Oomoo`1NOol00`00Oomoo`1:OolU000=Ool00`00Oomoo`3h
Ool@000:Ool;002aOol00`00Oomoo`3aOol00`00Oomoo`07Ool003Yoo`03001oogoo0<Eoo`03001o
ogoo05eoo`03001oogoo07aoo`03001oogoo0?moo`Uoo`X00;]oo`03001oogoo0?9oo`03001oogoo
00Moo`00>Woo00<007ooOol0aWoo00<007ooOol0G7oo00<007ooOol0O7oo00<007ooOol0ogoocGoo
00<007ooOol0lgoo00<007ooOol01goo000jOol00`00Oomoo`36Ool00`00Oomoo`1LOol00`00Oomo
o`1lOol00`00Oomoo`3oOoo<Ool00`00Oomoo`3dOol00`00Oomoo`07Ool003Yoo`03001oogoo0<Mo
o`03001oogoo05Yoo`8007ioo`03001oogoo0?mool]oo`03001oogoo0?Eoo`03001oogoo00Moo`00
>Woo00<007ooOol0b7oo00<007ooOol0FGoo00<007ooOol0OGoo00<007ooOol0ogoobWoo00<007oo
Ool0mWoo00<007ooOol01goo000jOol50037Ool00`00Oomoo`1HOol00`00Oomoo`1mOol00`00Oomo
o`3oOoo9Ool00`00Oomoo`3bOol60009Ool003Yoo`03001oogoo0<Uoo`03001oogoo05Qoo`03001o
ogoo07eoo`03001oogoo0?moolQoo`03001oogoo0?Qoo`03001oogoo00Moo`00>Woo00<007ooOol0
bWoo00<007ooOol0Egoo00<007ooOol0OGoo00<007ooOol0ogoob7oo00<007ooOol0n7oo00<007oo
Ool01goo000jOol00`00Oomoo`3;Ool00`00Oomoo`1FOol00`00Oomoo`1mOol00`00Oomoo`3oOoo7
Ool00`00Oomoo`3iOol00`00Oomoo`07Ool003Yoo`03001oogoo0<aoo`03001oogoo05Eoo`03001o
ogoo07eoo`03001oogoo0?moolIoo`03001oogoo0?Yoo`03001oogoo00Moo`00>Woo00<007ooOol0
cGoo00<007ooOol0E7oo00<007ooOol0OGoo00<007ooOol0ogooaGoo00<007ooOol0ngoo00<007oo
Ool01goo000jOol00`00Oomoo`3>Ool00`00Oomoo`1BOol00`00Oomoo`1nOol00`00Oomoo`3oOoo4
Ool00`00Oomoo`3lOol00`00Oomoo`07Ool003Yoo`03001oogoo0<moo`03001oogoo055oo`03001o
ogoo07ioo`03001oogoo0?mool=oo`03001oogoo0?eoo`03001oogoo00Moo`00>Woo00<007ooOol0
d7oo00<007ooOol0D7oo00<007ooOol0OWoo00<007ooOol0ogoo`Woo00<007ooOol0oWoo00<007oo
Ool01goo000jOol00`00Oomoo`3AOol00`00Oomoo`1?Ool00`00Oomoo`1nOol00`00Oomoo`3oOoo1
Ool00`00Oomoo`3oOol00`00Oomoo`07Ool003Yoo`03001oogoo0=9oo`03001oogoo04ioo`03001o
ogoo07ioo`03001oogoo0?mool1oo`03001oogoo0?moo`5oo`03001oogoo00Moo`00>Woo00<007oo
Ool0dgoo00<007ooOol0CGoo00<007ooOol0OWoo00<007ooOol0ogoo_goo00<007ooOol0ogoo0Woo
00<007ooOol01goo000jOol00`00Oomoo`3DOol00`00Oomoo`1<Ool00`00Oomoo`1nOol00`00Oomo
o`3oOonnOol00`00Oomoo`3oOol3Ool00`00Oomoo`07Ool003Yoo`03001oogoo0=Eoo`03001oogoo
04]oo`03001oogoo07ioo`03001oogoo0?mookeoo`03001oogoo0?moo`Aoo`03001oogoo00Moo`00
>Woo00<007ooOol0eWoo00<007ooOol0BGoo00<007ooOol0Ogoo00<007ooOol0ogoo_7oo00<007oo
Ool0ogoo1Goo00<007ooOol01goo000jOol00`00Oomoo`3GOol00`00Oomoo`18Ool00`00Oomoo`20
Ool00`00Oomoo`3oOonjOol00`00Oomoo`3oOol6Ool00`00Oomoo`07Ool003Yoo`03001oogoo0=Mo
o`03001oogoo04Qoo`03001oogoo081oo`03001oogoo0?mookUoo`03001oogoo0?moo`Moo`03001o
ogoo00Moo`00>Woo00<007ooOol0f7oo00<007ooOol0Agoo00<007ooOol0P7oo00<007ooOol0ogoo
^7oo00<007ooOol0ogoo27oo00<007ooOol01goo000jOol00`00Oomoo`3IOol00`00Oomoo`16Ool0
0`00Oomoo`20Ool00`00Oomoo`3oOongOol00`00Oomoo`3oOol9Ool00`00Oomoo`07Ool003Yoo`03
001oogoo0=Yoo`8004Ioo`03001oogoo081oo`03001oogoo0?mookIoo`03001oogoo0?moo`Yoo`03
001oogoo00Moo`00>Woo00<007ooOol0g7oo00<007ooOol0@goo00<007ooOol0P7oo00<007ooOol0
ogoo]Goo00<007ooOol0ogoo2goo00<007ooOol01goo000jOol00`00Oomoo`3MOol00`00Oomoo`12
Ool00`00Oomoo`20Ool00`00Oomoo`3oOoncOol2003oOol>Ool00`00Oomoo`07Ool003Yoo`03001o
ogoo0=ioo`80049oo`03001oogoo081oo`03001oogoo0?mook9oo`03001oogoo0?moo`ioo`03001o
ogoo00Moo`00>Woo00<007ooOol0h7oo00<007ooOol0?Woo00<007ooOol0PGoo00<007ooOol0ogoo
/Goo00<007ooOol0ogoo3goo00<007ooOol01goo000jOol00`00Oomoo`3QOol00`00Oomoo`0mOol0
0`00Oomoo`21Ool2003oOon`Ool2003oOolBOol00`00Oomoo`07Ool003Yoo`03001oogoo0>9oo`80
03aoo`8008=oo`800?moojmoo`03001oogoo0?mooa9oo`03001oogoo00Moo`00>Woo00<007ooOol0
i7oo00<007ooOol0>Goo0P00PWoo0`00ogoo[Woo00<007ooOol0ogoo4goo00<007ooOol01goo000j
Ool00`00Oomoo`3UOol00`00Oomoo`0hOol30021Ool4003oOon[Ool2003oOolFOol00`00Oomoo`07
Ool003Yoo`03001oogoo0>Ioo`8003Moo`@0085oo`@00?moojYoo`03001oogoo0?mooaIoo`03001o
ogoo00Moo`00>Woo00<007ooOol0j7oo00<007ooOol0=7oo1000PGoo1000ogooZGoo00<007ooOol0
ogoo5goo00<007ooOol01goo000jOol00`00Oomoo`3YOol00`00Oomoo`0cOol40021Ool5003oOonV
Ool2003oOolJOol00`00Oomoo`07Ool003Yoo`03001oogoo0>Yoo`80039oo`D0085oo`800003Ool0
00000?moojEoo`03001oogoo0?mooaYoo`03001oogoo00Moo`00>Woo00<007ooOol0k7oo00<007oo
Ool0;goo0`0000=oo`00Ool0P7oo0P0000=oo`000000ogooXgoo0P00ogoo7Goo00<007ooOol01goo
000jOol00`00Oomoo`3]Ool00`00Oomoo`0^Ool01000Ool007oo0P00Ogoo0`000Woo0P00ogooXGoo
00<007ooOol0ogoo7Goo00<007ooOol01goo000jOol00`00Oomoo`3]Ool2000^Ool01000Oomoo`00
0Woo00<007ooOol0OGoo00<007oo00000goo00<007ooOol0ogooWWoo00<007ooOol0ogoo7Woo00<0
07ooOol01goo000jOol00`00Oomoo`3_Ool00`00Oomoo`0^Ool01000Oomoo`00Ogoo00<007oo0000
ogooXWoo0P00ogoo8Goo00<007ooOol01goo000jOol00`00Oomoo`3`Ool00`00Oomoo`0]Ool00`00
Oomoo`22Ool00`00Oomoo`3oOonOOol00`00Oomoo`3oOolQOol00`00Oomoo`07Ool003Yoo`03001o
ogoo0?5oo`8002eoo`03001oogoo089oo`03001oogoo0?mooiioo`03001oogoo0?moob9oo`03001o
ogoo00Moo`00>Woo00<007ooOol0lgoo0P00:goo00<007ooOol0PWoo00<007ooOol0ogooW7oo0P00
ogoo9Goo00<007ooOol01goo000jOol00`00Oomoo`3eOol2000YOol00`00Oomoo`22Ool00`00Oomo
o`3oOonJOol2003oOolWOol00`00Oomoo`07Ool003Yoo`03001oogoo0?Moo`8002Moo`03001oogoo
089oo`03001oogoo0?mooiQoo`800?moobUoo`03001oogoo00Moo`00>Woo00<007ooOol0nGoo00<0
07ooOol097oo00<007ooOol0PWoo00<007ooOol0ogooUgoo00<007ooOol0ogoo:Goo00<007ooOol0
1goo000jOol5003hOol2000TOol00`00Oomoo`22Ool00`00Oomoo`3oOonDOol3003oOolWOol60009
Ool003Yoo`03001oogoo0?aoo`03001oogoo021oo`03001oogoo08=oo`03001oogoo0?mooi=oo`03
001oogoo0?moobeoo`03001oogoo00Moo`00>Woo00<007ooOol0oGoo0P0087oo00<007ooOol0Pgoo
00<007ooOol0ogooTGoo0P00ogoo<7oo00<007ooOol01goo000jOol00`00Oomoo`3oOol2000NOol0
0`00Oomoo`23Ool00`00Oomoo`3oOon?Ool2003oOolbOol00`00Oomoo`07Ool003Yoo`03001oogoo
0?moo`9oo`8001aoo`03001oogoo08=oo`03001oogoo0?mooheoo`800?moocAoo`03001oogoo00Mo
o`00>Woo00<007ooOol0ogoo17oo00<007ooOol06Goo00<007ooOol0Pgoo00<007ooOol0ogooRgoo
0P00ogoo=Woo00<007ooOol01goo000jOol00`00Oomoo`3oOol5Ool2000IOol00`00Oomoo`23Ool0
0`00Oomoo`3oOon9Ool2003oOolhOol00`00Oomoo`07Ool003Yoo`03001oogoo0?moo`Moo`8001Mo
o`03001oogoo08=oo`03001oogoo0?moohMoo`800?moocYoo`03001oogoo00Moo`00>Woo00<007oo
Ool0ogoo2Goo10004goo00<007ooOol0Pgoo00<007ooOol0ogooQGoo0P00ogoo?7oo00<007ooOol0
1goo000jOol00`00Oomoo`3oOol=Ool2000AOol00`00Oomoo`23Ool00`00Oomoo`3oOon3Ool2003o
OolnOol00`00Oomoo`07Ool003Yoo`03001oogoo0?moo`moo`8000moo`03001oogoo08=oo`03001o
ogoo0?mooh5oo`800?mood1oo`03001oogoo00Moo`00>Woo00<007ooOol0ogoo4Goo0P003Goo00<0
07ooOol0Pgoo00<007ooOol0ogooOWoo0`00ogoo@Woo00<007ooOol01goo000jOol00`00Oomoo`3o
OolCOol2000:Ool20025Ool00`00Oomoo`3oOomlOol2003oOom5Ool00`00Oomoo`07Ool003Yoo`03
001oogoo0?mooaEoo`<000Moo`03001oogoo08Aoo`03001oogoo0?moogUoo`<00?moodMoo`03001o
ogoo00Moo`00>Woo00<007ooOol0ogoo67oo0P001Goo00<007ooOol0Q7oo00<007ooOol0ogooMWoo
0`00ogooBWoo00<007ooOol01goo000jOol00`00Oomoo`3oOolJOol20003Ool00`00Oomoo`24Ool0
0`00Oomoo`3oOomdOol2003oOom=Ool00`00Oomoo`07Ool003Yoo`03001oogoo0?mooaaoo`@008Mo
o`03001oogoo0?moofmoo`@00?moodmoo`03001oogoo00Moo`00>Woo00<007ooOol0ogoo7goo1000
Q7oo00<007ooOol0ogooK7oo0`00ogooDgoo00<007ooOol01goo000jOol00`00Oomoo`3oOolOOol0
1000Oomoogoo1000P7oo00<007ooOol0ogooJGoo0`00ogooEWoo00<007ooOol01goo000jOol00`00
Oomoo`3oOolOOol00`00Oomoo`05Ool4001lOol00`00Oomoo`3oOomXOol00`00Oomoo`3oOomGOol0
0`00Oomoo`07Ool003Yoo`03001oogoo0?mooamoo`03001oogoo00Uoo`8007Yoo`03001oogoo0?mo
ofEoo`<00?mooeYoo`03001oogoo00Moo`00>Woo00<007ooOol0ogoo7goo00<007ooOol02goo0P00
N7oo00<007ooOol0ogooHGoo1000ogooGGoo00<007ooOol01goo000jOol00`00Oomoo`3oOolOOol0
0`00Oomoo`0=Ool3001eOol00`00Oomoo`3oOomMOol4003oOomQOol00`00Oomoo`07Ool003Yoo`03
001oogoo0?mooamoo`03001oogoo011oo`P006eoo`03001oogoo05Uooc<00<aoo`@00?moofEoo`03
001oogoo00Moo`00>Woo00<007ooOol0ogoo7goo00<007ooOol067oo0`00JWoo00<007ooOol0BWoo
3`00<goo3`00^Woo0`00ogooJGoo00<007ooOol01goo000jOol00`00Oomoo`3oOolOOol00`00Oomo
o`0KOol5001UOol00`00Oomoo`0nOol<001AOol;002WOol8003oOom/Ool00`00Oomoo`07Ool003Yo
o`03001oogoo0?mooaioo`80029oo`<0069oo`03001oogoo03=oo`/006Qoo``009Moo`@00?moogAo
o`03001oogoo00Moo`00>Woo00<007ooOol0ogoo7Woo00<007ooOol097oo2000FWoo00<007ooOol0
9goo3000Ogoo2`00QGoo1`00ogooN7oo00<007ooOol01goo000jOol00`00Oomoo`3oOolNOol00`00
Oomoo`0/Ool8001BOol00`00Oomoo`0POol7002FOol8001iOol4003oOomoOol00`00Oomoo`07Ool0
03Yoo`03001oogoo0?mooaioo`03001oogoo03Aoo`L004]oo`03001oogoo01Aoo``00:Eoo`/006Io
o`P00?mooh=oo`03001oogoo00Moo`00>Woo00<007ooOol0ogoo7Woo00<007ooOol0>goo2000@goo
00<007ooOol01Goo3`00_7oo3`00C7oo2`00ogooRgoo00<007ooOol01goo000jOol00`00Oomoo`3o
OolNOol00`00Oomoo`13Ool?000]Ool?003JOol@000`Ool<003oOonFOol00`00Oomoo`07Ool003Yo
o`03001oogoo0?mooaioo`03001oogoo059oobd000Moo`03001oogoo0>mooc000?mooj9oo`03001o
ogoo00Moo`00>Woo00<007ooOol0ogoo7Woo00<007ooOol0QWoo00<007ooOol0ogooogoo`Woo00<0
07ooOol01goo000jOol00`00Oomoo`3oOolMOol30026Ool3003oOoooOoo3Ool00`00Oomoo`07Ool0
03Yoo`03001oogoo0?mooaeoo`<008Ioo`<00?mooomool=oo`03001oogoo00Moo`00>Woo00<007oo
Ool0ogoo7Goo0`00QWoo0`00ogooogoo`goo00<007ooOol01goo000jOol00`00Oomoo`3oOolMOol3
0026Ool3003oOoooOoo3Ool00`00Oomoo`07Ool003Yoo`03001oogoo0?mooaaoo`D008Aoo`D00?mo
oomool9oo`03001oogoo00Moo`00>Woo00<007ooOol0ogoo77oo1@00Q7oo1@00ogooogoo`Woo00<0
07ooOol01goo000jOol00`00Oomoo`3oOolLOol50024Ool5003oOoooOoo2Ool00`00Oomoo`07Ool0
03Yoo`D00?mooaYoo`05001oo`00Ool00024Ool01@00Ool007oo0000ogooogoo_Goo1P002Goo000j
Ool00`00Oomoo`3oOolKOol200000goo001oo`020022Ool200000goo001oo`02003oOoooOoo1Ool0
0`00Oomoo`07Ool003Yoo`03001oogoo0?mooa]oo`04001oogoo0002Ool00`00Oomoo`20Ool01000
Oomoo`000Woo00<007ooOol0ogooogoo_goo00<007ooOol01goo000jOol00`00Oomoo`3oOolNOol0
0`00Oomoo`26Ool00`00Oomoo`3oOoooOoo2Ool00`00Oomoo`07Ool003Yoo`03001oogoo0?mooaeo
o`8008Qoo`03001oogoo0?mooomool9oo`03001oogoo00Moo`00>Woo00<007ooOol0ogoo7Goo00<0
07ooOol0Qgoo00<007ooOol0ogooogoo`Woo00<007ooOol01goo000jOol00`00Oomoo`3oOolMOol0
0`00Oomoo`27Ool00`00Oomoo`3oOoooOoo2Ool00`00Oomoo`07Ool003Yoo`03001oogoo0?mooaeo
o`03001oogoo08Moo`03001oogoo0?mooomool9oo`03001oogoo00Moo`00>Woo00<007ooOol0ogoo
7Goo00<007ooOol0Qgoo00<007ooOol0ogooogoo`Woo00<007ooOol01goo000jOol00`00Oomoo`3o
OolMOol00`00Oomoo`27Ool00`00Oomoo`3oOoooOoo2Ool00`00Oomoo`07Ool003Yoo`03001oogoo
0?mooaeoo`03001oogoo08Moo`03001oogoo0?mooomool9oo`03001oogoo00Moo`00>Woo00<007oo
Ool0ogoo7Goo00<007ooOol0Qgoo00<007ooOol0ogooogoo`Woo00<007ooOol01goo000jOol00`00
Oomoo`3oOolMOol00`00Oomoo`27Ool00`00Oomoo`3oOoooOoo2Ool00`00Oomoo`07Ool003Yoo`03
001oogoo0?mooaeoo`03001oogoo08Moo`03001oogoo0?mooomool9oo`03001oogoo00Moo`00>Woo
00<007ooOol0ogoo7Goo00<007ooOol0Qgoo00<007ooOol0ogooogoo`Woo00<007ooOol01goo000j
Ool00`00Oomoo`3oOolMOol00`00Oomoo`27Ool00`00Oomoo`3oOoooOoo2Ool00`00Oomoo`07Ool0
03Yoo`03001oogoo0?mooaeoo`03001oogoo08Moo`03001oogoo0?mooomool9oo`03001oogoo00Mo
o`00>Woo00<007ooOol0ogoo7Goo00<007ooOol0Qgoo00<007ooOol0ogooogoo`Woo00<007ooOol0
1goo000jOol00`00Oomoo`3oOolMOol00`00Oomoo`27Ool00`00Oomoo`3oOoooOoo2Ool00`00Oomo
o`07Ool003Yoo`03001oogoo0?mooaeoo`03001oogoo08Moo`03001oogoo0?mooomool9oo`03001o
ogoo00Moo`00>Woo00<007ooOol0ogoo7Goo00<007ooOol0Qgoo00<007ooOol0ogooogoo`Woo00<0
07ooOol01goo000jOol00`00Oomoo`3oOolMOol00`00Oomoo`27Ool00`00Oomoo`3oOoooOoo2Ool0
0`00Oomoo`07Ool003Yoo`03001oogoo0?mooaeoo`03001oogoo08Moo`03001oogoo0?mooomool9o
o`03001oogoo00Moo`00>Woo00<007ooOol0ogoo7Goo00<007ooOol0Qgoo00<007ooOol0ogooogoo
`Woo00<007ooOol01goo000jOol00`00Oomoo`3oOolMOol00`00Oomoo`27Ool00`00Oomoo`3oOooo
Ooo2Ool00`00Oomoo`07Ool003Yoo`03001oogoo0?mooaeoo`03001oogoo08Moo`03001oogoo0?mo
oomool9oo`03001oogoo00Moo`00>Woo00<007ooOol0ogoo7Goo00<007ooOol0Qgoo00<007ooOol0
ogooogoo`Woo00<007ooOol01goo000jOol00`00Oomoo`3oOolMOol00`00Oomoo`27Ool00`00Oomo
o`3oOoooOoo2Ool00`00Oomoo`07Ool003Yoo`03001oogoo0?mooaeoo`03001oogoo08Moo`03001o
ogoo0?mooomool9oo`03001oogoo00Moo`00>Woo00<007ooOol0ogoo7Goo00<007ooOol0Qgoo00<0
07ooOol0ogooogoo`Woo00<007ooOol01goo000jOol00`00Oomoo`3oOolMOol00`00Oomoo`27Ool0
0`00Oomoo`3oOoooOoo2Ool00`00Oomoo`07Ool003Yoo`03001oogoo0?mooaeoo`03001oogoo08Mo
o`03001oogoo0?mooomool9oo`03001oogoo00Moo`00>Woo00<007ooOol0ogoo7Goo00<007ooOol0
Qgoo00<007ooOol0ogooogoo`Woo00<007ooOol01goo000jOol00`00Oomoo`3oOolMOol00`00Oomo
o`27Ool00`00Oomoo`3oOoooOoo2Ool00`00Oomoo`07Ool003Yoo`03001oogoo0?mooaeoo`03001o
ogoo08Moo`03001oogoo0?mooomool9oo`03001oogoo00Moo`003Woo1P003Goo10005Goo00<007oo
Ool0ogoo7Goo00<007ooOol0Qgoo00<007ooOol0ogooogoo`Woo00<007ooOol01goo000=Ool8000:
Ool8000COol00`00Oomoo`3oOolMOol00`00Oomoo`27Ool00`00Oomoo`3oOoooOoo2Ool00`00Oomo
o`07Ool000aoo`<000Aoo`<000Uoo`8000Aoo`8001=oo`03001oogoo0?mooaeoo`03001oogoo08Mo
o`03001oogoo0?mooomool9oo`03001oogoo00Moo`002goo0`001Woo0`001goo0P001Woo0P004Woo
00<007ooOol0ogoo7Goo00<007ooOol0Qgoo00<007ooOol0ogooogoo`Woo00<007ooOol01goo000;
Ool20008Ool20007Ool20006Ool2000BOol00`00Oomoo`3oOolMOol00`00Oomoo`27Ool00`00Oomo
o`3oOoooOoo2Ool00`00Oomoo`07Ool000]oo`8000Qoo`8000Ioo`8000Qoo`80015oo`03001oogoo
0?mooaeoo`03001oogoo08Moo`03001oogoo0?mooomool9oo`03001oogoo00Moo`002goo0P0027oo
0P001Woo0P0027oo0P004Goo00<007ooOol0ogoo7Goo00<007ooOol0Qgoo00<007ooOol0ogooogoo
`Woo00<007ooOol01goo000;Ool30006Ool30006Ool20008Ool2000AOol8003oOolHOol00`00Oomo
o`27Ool00`00Oomoo`3oOoooOonkOol80009Ool000aoo`<000Aoo`<000Moo`8000Qoo`80015oo`03
001oogoo0?mooomooomooomoofeoo`03001oogoo00Moo`003Goo200027oo0P0027oo0P004Goo00<0
07ooOol0ogooogooogooogooKGoo00<007ooOol01goo000=Ool80008Ool20008Ool2000AOol00`00
Oomoo`3oOoooOoooOoooOom]Ool00`00Oomoo`07Ool000aoo`<000Aoo`<000Moo`8000Qoo`80015o
o`03001oogoo0?mooomooomooomoofeoo`03001oogoo00Moo`002goo0P0027oo0P001Woo0P0027oo
0P004Goo00<007ooOol0ogooogooogooogooKGoo00<007ooOol01goo000;Ool20008Ool20007Ool2
0006Ool2000BOol00`00Oomoo`3oOoooOoooOoooOom]Ool00`00Oomoo`07Ool000]oo`8000Qoo`80
00Moo`8000Ioo`80019oo`03001oogoo0?mooomooomooomoofeoo`03001oogoo00Moo`0037oo0`00
17oo100027oo0P0017oo0P004goo00<007ooOol0ogooogooogooogooKGoo00<007ooOol01goo000<
Ool:0009Ool8000COol00`00Oomoo`0HOol00`00Oomoo`2lOol00`00Oomoo`2kOol00`00Oomoo`2l
Ool00`00Oomoo`2kOol00`00Oomoo`2lOol00`00Oomoo`2EOol00`00Oomoo`07Ool000ioo`H000eo
o`@001Eoo`03001oogoo01Qoo`03001oogoo0;aoo`03001oogoo0;]oo`03001oogoo0;aoo`03001o
ogoo0;]oo`03001oogoo0;aoo`03001oogoo09Eoo`03001oogoo00Moo`00>Woo00<007ooOol067oo
00<007ooOol0_7oo00<007ooOol0^goo00<007ooOol0_7oo00<007ooOol0^goo00<007ooOol0_7oo
00<007ooOol0UGoo00<007ooOol01goo000jOol00`00Oomoo`0HOol00`00Oomoo`0SOol00`00Oomo
o`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`0SOol00`00Oomo
o`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomo
o`0SOol00`00Oomoo`0TOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomo
o`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0TOol00`00Oomo
o`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomo
o`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`07Ool003Yoo`03001oogoo01Qoo`03
001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02Aoo`03
001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03
001oogoo02=oo`03001oogoo02=oo`03001oogoo02Aoo`03001oogoo02=oo`03001oogoo02=oo`03
001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03
001oogoo02Aoo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03
001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo00Moo`00
>Woo00<007ooOol067oo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol0
8goo00<007ooOol097oo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol0
8goo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol097oo00<007ooOol0
8goo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol0
8goo00<007ooOol08goo00<007ooOol097oo00<007ooOol08goo00<007ooOol08goo00<007ooOol0
8goo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol0
8goo00<007ooOol01goo000jOol00`00Oomoo`0HOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00
Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00
Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00
Oomoo`0TOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00
Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`0SOol00`00
Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00
Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`07Ool003Yoool00?l00?l00?l0074000Uoo`00\
\>"], "Graphics",
  CellLabel->"From In[47]:=",
  Evaluatable->False,
  ImageSize->{400, 247.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[65]="]
}, Open  ]],

Cell["\<\
Field lines and equipotential lines of the pigtail, the two \
conductors to the left on potential 1, the others on 0.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g = 
        Table[{u[\([i, j + 1]\)] - u[\([i, j]\)], 
            u[\([i + 1, j]\)] - u[\([i, j]\)]}, {i, 1, nz - 1}, {j, 1, 
            ns - 1}];\)\), "\n", 
    \(\(lrow = 
        Table[{u[\([nz, j + 1]\)] - u[\([nz, j]\)], 
            u[\([nz, j]\)] - u[\([nz - 1, j]\)]}, {j, 1, 
            ns - 1}];\)\ \), "\[IndentingNewLine]", 
    \(\(g = Append[g, lrow];\)\), "\[IndentingNewLine]", 
    \(\(lcol = 
        Append[Table[{u[\([i, ns]\)] - u[\([i, ns - 1]\)], 
              u[\([i + 1, ns]\)] - u[\([i, ns]\)]}, {i, 1, 
              nz - 1}], {u[\([nz, ns]\)] - u[\([nz, ns - 1]\)], 
            u[\([nz, ns]\)] - 
              u[\([nz - 1, ns]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(g = Transpose[Append[Transpose[g], lcol]];\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(2.5857195763396635`*^-10\)], "Output",
  CellLabel->"Out[80]="]
}, Open  ]],

Cell[TextData[{
  "The following results were obtained in runs with the parameters vi as \
specified :\n\n",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_11\)]],
  "   =  129.529 [pF/m]      (v1 = 1, v2 = 0, v3 = 0, v4 = 0)\n",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_22\)]],
  "   =  129.527 [pF/m]      (v1 = 0, v2 = 1, v3 = 0, v4 = 0)\n",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_\(\(33\)\(\ \)\)\)]],
  "  =  129.527 [pF/m]      (v1 = 0, v2 = 0, v3 = 1, v4 = 0)\n",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_44\)]],
  "   =  129.529 [pF/m]      (v1 = 0, v2 = 0, v3 = 0, v4 = 1)\n",
  Cell[BoxData[
      \(TraditionalForm\`CC\&~\_12\)]],
  "=  258.572 [pF/m]      (v1 = 1, v2 = 1, v3 = 0, v4 = 0)  ",
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&\((28)\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_\(\(12\)\(\ \ \ \ \)\)\)]],
  "= - 0.242     [pF/m] \n",
  Cell[BoxData[
      \(TraditionalForm\`CC\&~\_23\)]],
  "=  258.569 [pF/m]      (v1 = 0, v2 = 1, v3 = 1, v4 = 0)   ",
  Cell[BoxData[
      \(TraditionalForm\` \[Rule] \)]],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_\(\(23\)\(\ \ \ \ \)\)\)]],
  "= - 0.242     [pF/m] \n",
  Cell[BoxData[
      \(TraditionalForm\`CC\&~\_34\)]],
  "=  258.572 [pF/m]      (v1 = 0, v2 = 0, v3 = 1, v4 = 1)   ",
  Cell[BoxData[
      \(TraditionalForm\` \[Rule] \)]],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_\(\(34\)\(\ \ \ \ \)\)\)]],
  "= - 0.242     [pF/m] \n",
  Cell[BoxData[
      \(TraditionalForm\`CC\&~\_13\)]],
  "=  259.049 [pF/m]      (v1 = 1, v2 = 0, v3 = 1, v4 = 0)   ",
  Cell[BoxData[
      \(TraditionalForm\` \[Rule] \)]],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_\(\(13\)\(\ \ \ \ \)\)\)]],
  "= - 0.0035   [pF/m] \n",
  Cell[BoxData[
      \(TraditionalForm\`CC\&~\_24\)]],
  "=  259.049 [pF/m]      (v1 = 0, v2 = 1, v3 = 0, v4 = 1)   ",
  Cell[BoxData[
      \(TraditionalForm\` \[Rule] \)]],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_\(\(24\)\(\ \ \ \ \)\)\)]],
  "= - 0.0035   [pF/m] \n",
  Cell[BoxData[
      \(TraditionalForm\`CC\&~\_14\)]],
  "=  259.059 [pF/m]      (v1 = 1, v2 = 0, v3 = 0, v4 = 1)   ",
  Cell[BoxData[
      \(TraditionalForm\` \[Rule] \)]],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`C\&~\_\(\(14\)\(\ \ \ \ \)\)\)]],
  "=   0             [pF/m] \n\nUsing (24) the coefficients of capacity come \
out to be\n\n",
  Cell[BoxData[
      \(TraditionalForm\`C\_10\)]],
  " = 129.28 [pF/m] , ",
  Cell[BoxData[
      \(TraditionalForm\`C\_20\)]],
  " = 129.04 [pF/m] , ",
  Cell[BoxData[
      \(TraditionalForm\`C\_30\)]],
  " = 129.04 [pF/m] , ",
  Cell[BoxData[
      \(TraditionalForm\`C\_40\)]],
  " = 129.28 [pF/m] ,\n",
  Cell[BoxData[
      \(TraditionalForm\`C\_12\)]],
  " = 0.242   [pF/m] , ",
  Cell[BoxData[
      \(TraditionalForm\`C\_23\)]],
  " = 0.242   [pF/m] , ",
  Cell[BoxData[
      \(TraditionalForm\`C\_34\)]],
  " = 0.242   [pF/m] ,\n",
  Cell[BoxData[
      \(TraditionalForm\`C\_13\)]],
  " = 0.0035 [pF/m] , ",
  Cell[BoxData[
      \(TraditionalForm\`C\_24\)]],
  " = 0.0035 [pF/m] ,\n",
  Cell[BoxData[
      \(TraditionalForm\`C\_14\)]],
  " = 0          [pF/m] \n\nAll ten coefficients of capacity form a five node \
network (Fig. 8). To describe two differential pairs we need to combine the \
ten into six effective capacities ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_ij\)\&^\)]],
  " between the nodes 1 to 4, to each of which all ten coefficients will \
contribute. ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_12\)\&^\)]],
  " of the first differential line (",
  Cell[BoxData[
      \(TraditionalForm\`C\_1'\)]],
  " in Fig. 1) is the whole capacity from node 1 to 2. ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_34\)\&^\)]],
  " of the second differential line (",
  Cell[BoxData[
      \(TraditionalForm\`C\_2'\)]],
  " in Fig. 1) is the total capacity from node 3 to 4. For the coupling \
capacity (",
  Cell[BoxData[
      \(TraditionalForm\`C\_12'\)]],
  " in Fig. 1)  there is a special twist: Any change of the potential on node \
1 will  couple via ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_13\)\&^\)]],
  " to node 3 and via ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_14\)\&^\)]],
  " to node 4 and is (because of the dominating ",
  Cell[BoxData[
      \(TraditionalForm\`C\_i0\)]],
  "'s) hardly seen as a voltage on the second pair (common mode rejection of \
the differential line), the same can be said for changes of potential on node \
2; therefore the coupling is given by "
}], "Text",
  PageBreakAbove->Automatic],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`C\_12\)]],
  "' = ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_23\)\&^\)]],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_24\)\&^\)]],
  " - (",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_13\)\&^\)]],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_14\)\&^\)]],
  ")."
}], "NumberedEquation"],

Cell[TextData[{
  "This completes the expression of all three capacities found in Fig. 1 \
through the ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_ij\)\&^\)]],
  " of the pigtail. Their values will be used in the code example below.\n\t\
Now in order to find the effective capacity ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_ij\)\&^\)]],
  " between two nodes i and j we reduce the network node by node through \
replacing successively star-type nodes with box-type nets, which are then \
parallel to the rest of the network, until there are only two nodes left (",
  StyleBox["Ref. 7",
    FontWeight->"Bold"],
  ", p.31f). As you will see, every reduction blows up the resulting \
expression quite a bit, so the symbolic capability of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " comes to good use here."
}], "Text"],

Cell[GraphicsData["PICT", "\<\
X0@000000N023@0A0_l<0?on0001;0000B`000000007d0R>0000002Q09H02P40
000000000000X02H0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G
0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40000000000000X02H
0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G0:40UP0:0@000000
0000002P09P0X02I0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F
00X10000000000000:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I
0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F00X1000000000000
0:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40
000000000000X02H0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G
0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40000000000000X02H
0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G0:40UP0:0@000000
0000002P09P0X02I0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F
00X10000000000000:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I
0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F00X1000000000000
0:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40
000000000000X02H0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G
0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40000000000000X02H
0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G0:40UP0:0@000000
0000002P09P0X02I0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F
00X10000000000000:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I
0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F00X1000000000000
0:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40
000000000000X02H0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G
0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40000000000000X02H
0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G0:40UP0:0@000000
0000002P09P0X02I0:00U`2Q09H02P40000000000000X02H0:00V@2P09L07P01
00X000001m08SP0/00`05@U8IFafIGAYHf400`0E00@1000=00`0;P04003o000[
0`<180040000:@018000104002T00B0000@0000Y004P00070000000S0000X02n
0:40`00=HgEbLVE^M71_JFid3@00X02o0281h0880000X02n0:40`03=HgEbLVE^
M71_JFid838PJFiTIGPPLgER86EhHfPP<b1YKVAUN21cMF8=83Db<20PI6Uf86Eh
HfPP3B0d>30P86AYMR0c86U^I6Eh80dP<20PLgER83<PJFiTIGPP3B0`821cMF8P
=20b879_K6`P=B1YKVAUN20e86U^I6Eh87AbHFicK65dI@e^IFLPLf=QK6D==20b
879_K6`PKVEW86EhHfPPKVEW86EhHfPPM79QKW=/HGAU80dP=3P`821cMF8PM79Q
KW=/HGAU3@00X@300D@U8E1C;D5TKf9U;C<^<215D5=6;C<^<0dU9D9_MFiTJFiW
@Vmh>R0P<20`83Db<20d>30P3BDUE6UdK6Dj82Q3LVmcLgAQK6/^@diF:B0=9BE3
LVEQM6mb>R13HFifHG<P:3L^<2hb:B0=9BE3LVEQM6U_KTAQM6Dj82P`<bl`<Rl`
<B10830c>S4`851=:B0=9BE4Kf=eKFE^M51bKf=CIGAc>R14IFiUHV5O@f5^MV5c
@gEcM6m]@fm/Kg9c3BDU:b13ETAYHg@=9BE4Kf=eKFE^M4I_KWAc>R0=9BE4Kf=e
KFE^M4iUIFAUI4I_KWAc>R0=9BE4Kf=eKFE^M51bKf=ULg=3Kfa_LW<j84=iHFhP
CF5WIFidHB1IIFa/KgLP@VaQHf/=9BE5KVA3Kfe]IFidL`dU9D9UIfU^D79_K6mW
80d0X@30@00U9D9UIfU^DVEcKgEbHfDj871bKf=cIG@P@eI4JF=d3BDUE6UdK6Dj
84AUKVERHB1cM65^I65bI21WLV5`J6USL`dU9EIULW=YKfhj834^<38=9BE3LVEQ
M6U_KTAQM6Dj834`;c4d;cTi3BDU@fm`NG9YIfQd>R0X@bTP<CTi=2`P<CTi>B14
IFiUHV4PDgUcM6E]LbhP@Fa/859YIfQdLb1BIG=ULWIUI0eeLfEbI6USM20_@eI4
JF=d838`<21TJF=d871eM0e3ETAYHg@PHVEWJFh=;fU^MV5/JFASKfa_LWAQHVaU
?b1dLWEU86AUIR0P80d_K6EfIF`b82m/HFiWMF5WIFaUMVE/87MXIG9U87]`Kg0P
K65^IgEQIfE/IGIUK20b86MUOG]VHFacIGdPJFIUK7=U86AUIPe/IGIUK38PKVmd
87/P;gQcJ6mg87/=<21SMG9bIFidL6mYKW@P=B0]<B1bKfa/87]`Kg0PL6m`86e_
MVEdKb1TMG0P<B1QI6@P<b0a879_K6`PIGQSJ21TMG0P=20a879_K6`PIGQSJ21W
IG@P<21bKFmfIGA_86=eLW9UKWA`KfU^M7dPIGQSJ21[LfQ_M`e`Kg0PL6m`871_
L21`Kg1m86AUIR1m86UV3BmYKVUdJF5/JGYU3G]3ETAYHg@=NfAeL21hHfQUHf]k
HVU^I7eYIR1`Kg0PL6m`OFI_LV5/K0eSMG9bIFidLf=bIFE^82mOLg0PIGQSJ21T
IFHP;emcHB1UN6=X86AUIR0_Gg=V86EhHfPPI6EV3Bm4IFIQMFadDf=bIFE^Nemc
IR1OLf4P;emcL21/Kf5TOFAUIPd_A6EVHGE/M5=SLVEUKU1bKf=k82mOLg0PK6mQ
I7eTIFH=;g=UM7=dLVm[IF5TJWEcM21gJ6EbIG]`Kg0PM79eIGekIV5/LfEmJFIU
K7=U3G/_Lf4P;g=UM7=dLVm[IF5TJWEcM21/Kf5T86AUIPd_K6TP;faYKVEdKb1/
Kf5T86AUIPd_KG@P;fe_MVEdKb1/Kf5T86AUIPd_Hg@P;f=eLWIUM6lPK6mQI21T
IFH=;faX87/PHgEbLVE^M71_JFid86EhHfPPL6m`86aYKVEdKgeRJFiT86AUIPd_
K7HPNb1SMG9bIFidL6mYKW@PL6m`86EhHfPPK6U^IGA_OF9YKV@PI6EVO@ek;g=Q
Ng]SMG9bIFidI6USM21CM79_JfE1I6YeLgA4JF=d86iUNe=dLVm[ID5TJWEcM4AY
Hg@PHVEWJFimJFImNb1SMG9bIFidI6USM21CM79_JfE1I6YeLgA4JF=d86EaNfE^
I7eYIWeYIVE/LfEm869YKV@PI6EV3GEcIG9TJF=d82mCM79_JfE1I6YeLgA4JF=d
834`<21TJF=d871eM0eCM79_JfE1I6YeLgA4JF=d869UIfU^3BmON6`=NgAbHFic
IVmbK@d^<SDPLgER879_MFiT82hb=B1QI6@PIGQSJ0d^<SDPLgER879_MFiT82hb
=B1QI6@PIGQSJ0eYM79QKW=VKg9]3GeRJFiT86AUIPd_K6Uk85mhK21/JFiUM6mm
HVU^I21TIFH=;fedNb1ON6`PKFmfIGA_OF9YKV@PI6EV3BmSM7/PGgQ/86=eLWIU
M6mmHVU^I21TIFH=;faX87/PI7E`85mhK21`Kg0PHgEbLVE^M71_JFid86EhHfPP
L6m`86aYKVEdKgeRJFiT86AUIPd_K7HPNb1TMG0PGgQ/871_L21SMG9bIFidL6mY
KW@PL6m`86EhHfPPK6U^IGA_OF9YKV@PI6EV3BmbL7]ON6`_HgIOHR1hI6H_HgIO
LR1hI6H=GgQ/;f=fGg@PN6AV;f=fGf`PN6AV3F=fGf`PHgIOM21]KgIUM6l=HgIO
LR1SMUmd86aYKVEdK`eSMUmb86=fGf8PK6U^IGA_3F=fGf`PHgIOHR1/JFiUM6l=
Hfa_LfE`HGAX3GeRJFiT86AUIPeUKVAmJFIUK7=UOFAUIPd_M6EbKFU^HGAU3G]e
LfEbI6USM20_DgAbKf]U@FAZMG=dA6USM21[KVmgKR1kHgEbLVE^M6AYHg@PDgAb
Kf]U@FAZMG=dA6USM21ULG]UKVAmJFImJFH=HgEbLVE^M6AYHg@P@eI4JF=d86Ea
NfE^I7eYIWeTIFH=;fehCF5h83Hd86AUIPd_KGQCM6/PFfehCF5h87]]HGAbJGQm
879UL6EQM5eTIFH=;fehBFAh830PI6EV3BmcM6ekKGQCM6/PKGQ9I7PP<21/M21k
;fehBFAh830PLgA_LVEmJFHPKGQ9I7PPIfEd86=eLW9UKWA]HGAbJGPPL6m`82m]
N4UTN21]N4UTN20a865TI21cM6mbIGeTIFH=;g9dKG]]N4UTN20a86MU87/_KGQ9
I7PPKGQ9I7PP<B1cMF8PLgA_LVDPKGQCM6/PKGQ9I7PPIfEd87=UM6eQM79YN7eY
IR1mI6EV3BmcHf`PNb0g<R1TJGHPIGQSJ20g<R1TJGHPIGQSJ21cHf5/IB1m86AU
IPd_Lf=/JB1k83Lb86EhHfPPI6Uf86EhHfPP=c8PIGQSJ21TJGHPIGQSJ21cHf5/
IB1m86AUIPd_Gf=fKGAh86eQM79YN21TIFH=;emdN7A]M7PPKF5dLVUh86AUIPd_
GfU^JGA]M7PPKF5dLVUh86AUIPd_N6AVNfEhHfPPI6EVOFAUIPd_KFU^Nc8PHfm`
NB1WM7]UN6=XOFUV871_L7eTIFH=;feQN7/b86=_L7TPK7AkIGQSJ7eYIR1`Kg1m
I6EV3Bm3EWIUHb0b=CHPHG9bHGTPI6EV3BmD87AbMFDPI6EV3Bm686IQK7=U86AU
IPd_GfUT830PI6EV3BmOIFiSKfAYKVAUN20`86AUIPd_GfE^HfmT@G9b83<PHG9b
HGTPI6EV3BmOIV@P<21TIFH=;emdIGQdDf5fIB1^MFa/86AUIPd_GfaUM7AULU=`
HF=U830PI6EV3BmOLg1QHfEHM79Q830PI6EV3BmOD65WIE=QMVDPKWE/K21TIFH=
;em`IFiX834^<21TIFH=;em`IFif834^<21TIFH=;g=QMVD`86ieK6`PI6EV3BmO
Mb0`86AUIPd_GfPP<21TIFH=;emTLb0`86AUIPd_J6=d86IQK7=U86AUIPd_L7LP
<21TIFH=;gMTJFHP<21TIFH=;gAUKG0P<21TIFH=;f=eLW9_M20`86AUIPd_Lf5f
IFQQKVA/IG8PKWE/K21TIFH=;fUQ830PI6EV3BmYN20`86AUIPd_JGQ^834PI6EV
3Bm=MFadJG1/IDAQM65CKgEbHfEc86IQK7=U86AUIR0=;fAUHWEW3G]TMG0P;bAU
L7<PIGQSJ21^Kg@PI6EVNbmcHGIUJ65^I6aULR1ULW9_LVAYHg@P;fQQKVA/IFEb
LVmb86MUM21TIFH=IG9bKg9TJF=d3BmXHFiTK6EULW9_LW/TIG9bKg8PHVEWJFh=
KVEgIG9bKg9k;fiUMfEbLVmb86IQK7=U86AUIPecJ6mgL65WI@dg<R0g<R1cHf5/
I@d_B6E/MVEdJF=Q86IYKVAVKfid82hb87=SHFaUIVm^M21cIGAVKfid3Bhb=B0i
;SHPKFmfIGA_3BQ5LW9_LSXP:G=XKgL=IG9bKg9^HFeU3G]TMG0PM7U`IBmcM79Y
KVMdNG1U86iU3G/XHfm^MVEbM6ET86EbLVmb86iQKFDPMfU/K21UKV@PMG0PJFhP
M6QYLb1cM79YKVLYHgIcOFUV3G=XKgMmIGQUH`d^<SDP>Bhd86e_MVEdK`dXCfIV
IFiTJFiW84=_KFeQKV@j82UcJ6mg3BmSKfe]HFiT86a_HF@=NfAeL21dNG1U;g=d
LVU^IgAiL6DPKVD=NbQSKfifIG9dIF@PHfm]KF5^I21^HFeU87MYK6`PIFiT87E`
86U^87AXJG<PLgAbJFiW:F=fLgeYIPecJ6mgOFEhIF<=;S8e83T^<R1]KgIUM6l=
:5=dHF=[>R0YLfQ_M`e_LgAQHf/=Nbhb=B1SMG9bIFidL6mYKW@P;S8PLgER86Eh
HfPPL6m`86e_MVEdK`eTMG0PM7U`IBmcM79YKVMdNG1U86iUNfAeL21dNG1U;fU^
M6EWIG9dNG1U86Ea3C4PJFiTIGPPM7U`IBmbIF5/M7U`IB1ULB1_LPda86U^I6Eh
87AiL6D_KV5]IGAiL6DPIG4PKg8=KVmd87]dNG1UOFUV3BQSKfifIG9dIF@PLgAQ
Hf/PMfU/K21UKV@PMG0PJFhPM6QYLb1cM79YKVLYHgIcOFUV3G=XKgMmIVmbHFa/
3G=XKgM`HFMU3D=FA6USM20_Lf5fIFQQKVA/IG8PIfEd86EhIF=mJFH=IFiTOG1e
M7eYIWeTIFH=;faSNg=UM6aYKVESHG1mI6EV3Bm/JW]cIGA/JFiUJVmYKWeTIFH=
;fa]Ng=UM6eYM6EbK6U]JGAmI6EV3Bm/IW]cIGAVK65dOFAUIPd_Hg1kHfa_LfE`
HGAXOFAUIPd_KW1kKVEgL65dJ7eTIFH=;bA`LgXP<c0PHG9bHGTPI6EV3BlTL6Uh
830PI6EV3BmWLg]WLf5fIB0TL7=j86AeL20TL6Uh85m`IFiX871eM20TL6Uh834P
HFAT85m`IFif871eM20_971YN20TL6Uh838PHFAT86AUIWeTIFH=;fMbNfMbIG=d
Kg9U;bA`JGPP971YN20b87=eHR1TIFHP971cNR1TMG0P971YN21WIG@P;em`IFiX
86EhHfPPI6EV82A`JGPP<B1QI6@PIfEd82mOL6E^MR1UN6=X86AUIWeTIFH=;faY
NfaYKVEdKgdPI6EV3Bm/J7]SMG9bIFidL6mYKW@PIGQSJ21`Kg0PK6U^IGA_OFAU
IPd_K7IkHgEbLVE^M71_JFid871_L21UN6=X86aYKVEdKgeTIFH=;fedNfe_MVEd
KgdPI6EV3BmOHgIOKFQkHgEbLVE^M71_JFid86EhHfPPL6m`86e_MVEdKgeTIFH=
;emSMUm]MW]SMG9bIFidL6mYKW@PL6m`86EhHfPPKFmfIGA_OFAUIPd_HgAkHgEb
MVEdKgdPI6EV3BmbM7/d82db879_K6`PKFmfIGA_3FAeL20`86EhHfPPLVaYKVEd
K`eUN6=X830PLVaYKVEdK`e^IFLP<21UN6=X879/JFiUM6l=Hfa_LfE`HGAXOFAU
IPd_GfQb3G/=Nbm0IG9b86IQK7=U86AUIR1SMG9bIFidIVaQM21TMG1kIg=QMVEk
IFmSK6U`OG=dKg1`IFAkIg9ULgA_LVDP<R1]MF`PI7E`87=UM6I/HG@PI7E`838`
<21WIG/X9BDP@f5^MV5c>T=/JG0PIV5YK6ETG78YL79YKW@P;d1ULW8PM79eIB1T
IFHPL6m`86EhJGAmJFImNfMbIG=dKg9U87=UM6I/HG@PIGQYM7eYIVE/LfEmK6m_
L210IG9b86i_M21kIFmSK6U`OFUV87=UM6I/HGAm3G/_@6EbLR1VHFacIB1TIFHP
HgEbLVE^M6I/HG@PI7E`NfMcHGIUNf=/JG1mLgA_L71UI7]WLVEcM6mbIB0b86ee
K21TMG0PLfEdIVaQM21TMG0P<S0`86MUNbPU9B13HFifHG<j@faYL21VHFU/IFAL
LRU`LVU^M20_@6EbLR1dLWEU86AUIR1`Kg0PIGQYM7eYIWekIg9ULgA_LVDPLfEd
IVaQM21UN6UdOFUVIFacIGe/Kfm`841ULW8PKVmd87]SK6U`OFUV87=UM6I/HGAm
3GeTIFH=;emSLb1^MFa/86AUIPd_IVMkLfEdIg9QNGeTIFH=;g=UM6=]NF]SKfa_
LR1gJ6EbIB1kL6m`87AbMFEmNfIQK7=UOFUVIFacI@ek;fHdNb1cIGASKGU[Hfm/
Kg9mI6EVOG/_ISAk<B1cMF8P=20a879_K6`P<g/c86U^I6Eh865TI21^IFLPI7E`
830PK7AkL6m`831mJFHP<b0a879_K6amLVE`IF5d87=UM79WHV=_K6mb871_L7eT
IFImJFIUK7=U3BmcIGASKfa_LW=`HF=U87MXIG9U87]`Kg0PM79eIGekIV5/LfEm
JFIUK7=U3G/_Lf=cNb1TMG0PLfEdHfm/Kg9cL65SIB0_Gf=c86EhHfPPI6EVOFAU
IRmV<g/PGf=c87=UM6=_K6mbLg1QHfDPLfEdHfm/Kg9mI6EV3Gek;fHcNb1cIGAb
If9SKfa_LWeTIFH_Lf=cNb1`Kg1mI6EVOFUVIFacI@d_96=S83DPHG9bHGTPI6EV
3BmVJFiTHfeiJf=eLgA_KF=_K6mb87MXIG9U87]`Kg0PM79eIGekIV5/LfEmJFIU
K7=U3Fi_M21k;fIYKVASKGU[HgEcM6m]Hfm/Kg9k96=S865cM6mbIGeTIFImJFH=
;g=UM6=eLgA_KF=_K6mb87MXIG9U87]`Kg0PM79eIGekIV5/LfEmJFIUK7=U3Fi_
M7/_LfEdHgEcM6m]Hfm/Kg9kIGQSJ21QK6mQI21`Kg0PL6m`83Ak=21YKVAUN21]
MF`P=20a879_K6amLVE`IF5d87=UM6=]NF]SKfa_LR1`Kg1mI6EVOFUV3BmVHg/f
834PLVm/K21VJFiTHfeiJf=eLgA_KF=_K6mb86EhHfPPLfEdHgEcM6m]Hfm/Kg9m
I6EV3BmcIGAcIG1QLV5dJFm^Ig9QNB1gJ6EbIB1kL6m`87AbMFEmNfIQK7=UOFUV
IFacI@e^KgAk;g=UM7=UL65bHGAYKfiWLV5i87]cNG=dIFeTJF=d82mcIGAWLV5i
86MUM21UN6ESOB1TIFImJFH=;g=WNb1cIGAcIG1QLV5dJFm^Ig9QNGeTIFH=;g=`
NbmOL6E^MR1hI6H_Gg1UKVPPN6AVOFAUIPd_LW0=NbmSMUmR87QTIRmSMUmb87QT
IPd_HgIOM21hI6H_HgIOK21hI6H=HgIOK21SMUmd86e_MVEdK`eSMUmb86=fGg@P
K6U^IGA_3F=fGg8PHgIOHR1/JFiUM6l=HgIOK21SMUmR86aYKVEdK`eSK6mcIG1Q
M6QmI6EV3BmbLW/_NG9QI6UeLb1hI6H=;gQbHFAYMG<PN6AV3BmSMUmR87QTIPd_
HgIOLR1hI6H=;f=fGg@PN6AV3BmSMUm/87QTIPeSMUm/87QbHFAYMG<PHFAT86=f
Gg@PKFmfIGA_3F=fGg8PN79QI6UeLb1cMF8PHgIOM21/JFiUM6l=Gf=fKGAh86=e
LW9UKWA]HGAbJGPPL6m`3F=eLW9UKWA`KfU^M21dLV5^LfaQM6D=N79QI6UeLb1i
LV5TJGEc87=SHFaU3C4P<20a834P<B1QLV=dKb0dNg1_L7ebIG1UHG@=Gf=fKGAh
87=UM6eQM79YN0eSMUmb86=fGf8PNG9QI6UeLb1cMF8PK6U^IGA_3EmSMVedN21S
MG9bIFidKF5dLVUh871_L0eSMG9bIFidL6mYKW@PM79QKW=/HGAU3GQbHFAYMG<P
NG9QI6UeLb1cHf5/I@d`834P;C4P<B0a865bHgA_83AkL6m`OG9UL6EQM0eOHgI]
M7PPLfEdKF5dLVUh3F=fGf`PN79QI6UeLb1QI6@PHgIOHR1/JFiUM6l=Gf=fKGAh
86=eLW9UKWA]HGAbJGPPL6m`3F=eLW9UKWA`KfU^M21dLV5^LfaQM6D=N79QI6Ue
Lb1iLV5TJGEc87=SHFaU3Bda830P;C4P;C4P<B1QLV=dKb0dNg1_L7ebIG1UHG@=
Gf=fKGAh87=UM6eQM79YN0eSMUm/86=fGg@PNG9QI6UeLb1QI6@PK6U^IGA_3EmS
MVedN21SMG9bIFidKF5dLVUh871_L0eSMG9bIFidL6mYKW@PM79QKW=/HGAU3GQb
HFAYMG<PNG9QI6UeLb1cHf5/I@d`82da834P;C4P<B1QLV=dKb0dNg1_L7ebIG1U
HG@=Gf=fKGAh87=UM6eQM79YN0eSK6mcIG1QM6QmI6EV3BmUL7]OHgI]M7PPHgEb
LVE^M6eQM79YN21`Kg0=M79QKW=/HGAU3G=SHFaU3C4P<21]KgIUM6l=<20`834P
<20c=S0PHG9S3F=/Kg=UL65dJ0eOHgI]M7PPLfEdKF5dLVUhOFAUIPd_MfAkGf=f
KGAh86=eLW9UKWA]HGAbJGPPL6m`3GAbHFicK65dI@ecHf5/I@d`830PKFmfIGA_
3C0P<20a83DP;C8PLVm/K21QLV=^3F=/Kg=UL65dJ0eOHgI]M7PPLfEdKF5dLVUh
OFAUIPd_HG=kGf=fKGAh86=eLW9UKWA]HGAbJGPPL6m`3GAbHFicK65dI@ecHf5/
I@d`830P<B0e82db879_K6`PHG9SKPeOHgI]M7PPLfEdKF5dLVUhOFAUIPd_I7<=
Nem`IFif85m`IFiX86iU86AeL7]cM6dPGg1UKVPPI7E`830PK6EkL6m`835mJFHP
Gg1UKWHPI7E`830PK6EkL6m`835mJFHPLf=QK6EmNem`IFiX87=UM6aYKVEgJFAd
J7eYIVE/LfDPLgAbKf]U87]bM6emJFImI6EV3BmTIW]VJFa/OFAUIPd_I6EkIFmV
JFa/OFAUIPd_GfMcM6/P=B1QLW9QNB1TIFH=;emWLgA[Hb0`86AUIPd_GfMcM7/P
>B1TJF=d869UIfU^86aUMVE/<W/_Gf=SLb1SMG9bIFidHfm/Kg9cL65SIB1TIFHP
;emSHb1KHgEbLVE^M6=_K6mbGB1TIFImNbmOHf<PFf=eLW9UKWAbIf9SKfa_LUeT
IFImJFIUK7=U87]SMG9bIFidL6mYKWAmLgA_L71UI21k;emSL21^MFa/86AUIWek
838PHG9bHGTPHG=dKg9U82mOHg0PIGQSJ21TIFImJFIUK7=U82mOHfHPHgEbLVE^
M6I_KW@PI6EV3BmOHfag86=eLW9UKWA/JFiUMfUTM6PPI6EV82mOHfaS86=eLW9U
KWA/JFiUHf5`86AUIR0_Gf=/JR1SMG9bIFidK6U^IFY_JFhPI6EV82mOHfe/86=e
LW9UKWA]JGAULVaYKFUd86AUIR1SMG9bIFidI6USM21UKVAmI6EV3BmXLg]^IGM`
HGAX86McHGIU87=dKGeTIFH=;fQSNbmOJ78PK6mQI21UN6=X86MUM21UN6ES86iU
Mg1QM6QmI6EV3BmXIG]OIg=dJb1OIg=dJf<PGfMcM21`MG@P;emWLgA[Hb1OIg=d
Jf<P<B1QI6@PLgA_LVDP3FMbIG=dKg9U879dKB0_GfMcM6]S85mWLgA[Hb0a87=e
HR1cM6mbIB1OIg=dJb1OIg=dJf<PIfEd86aUMVE/<W]TMG0P;emSHg<PIfEd87=U
M6=_K6mbLg1QHfDPI7E`82mOHf<PIfEd865/Kf5T871_L21cIGASKfa_LWekI7E`
82mOHf<PIfEd865/Kf5T871_L21cIGAbIf9SKfa_LWeYIVE/LfDPI7E`82mOHg0P
IfEd86AeL21^MFa/86Ea80e^KgAkHFa_HF@PL6m`86e_MVEdKgekL6m`OFUVIFac
IB1TMG0P;emSIR1WIG@PLfEdIVm^M0eTMG0_Gf=/Mb1WIG@PLfEdK6U^IGMYI7AX
86AeL2mOHfaS86MUM21cIGA/JFiUHf5`86AeL2mOHfaZ86MUM21cIGA/JFiUJVmY
KR1TMG0_Gf=]K21WIG@PLfEdKFUdIG9/JFeYM21`Kg1mI6EV3BmYI7/P;emYI21h
I6ImI6EV3BmOJFeQM79YN7]OMb0`830PGfPPGfUT830PKVEkKVEW830PGfQmNc0P
<7eYIVE/LfDPGf=fKGAh865cM6mbIGeTIFH=9B13Kg1iLVUWJ7@P:4<Y834i>C0/
834i>C4PHWTP@FA_HVDPDgUcM6E]Lb19KV=_LW1_LV5dIF@^3BDP@Fa/879YIfQd
Lb1bIG=ULWIUI2h=K6EfIF`b87/PLf5fIB0_I6m^M6a_HFA/IGIUK34PN6AV87eY
IPd_LgAQLWA^Kfa_HFAkNbm^Kfa_HF@PLf5fIB1TIFIm86UVOFAUIPd_IFiTKVm/
Kf5TNg]^Kfa_HF@PLVEcM6mbIGeYIR1mI6EV3BmdIG=dLgUcM6E]I6USM7]gJ6Eb
IG]cNG=dIFeTJF=d86EaNgAbMFEmNfIQK7=UOFUVIFacIGekIV5/LfEmJFIUK7=U
OFAUIPd_KV=_K6mbLb0a86AUIPd_Hfm/Kg9YKF5WIB1gJ6EbIG]`Kg0PM79eIGek
IV5/LfEmJFIUK7=UNbm^Hfm/Kg9c830=LgAQM7EcI6USM21RIFMYKR0=;g1bKf=U
Lg=SKfa_LW<PMfQULVEkL6m`871_L21`LVmSIG=cHfm/Kg9cOG/_I6EfJF=UJFiV
Kb1gJ6EbIG]`Kg0PI6EfJF=UJFiVKb0_@fm/Kg9c86]^KgM^3G]`Kg0PNfAUMVUS
IFU^IVlP;d=_K6mbLb1WIGAmOFUVOFUVOFUVIFacIB1UKV@PI6EV3FiSKfa_LW<P
<21^IG/_Hfm/Kg9YKF5WIB1dIG=dLgUcM6E]I6USM0d_LfEdHfm/Kg9dLV5^LfIU
LR1dIG=dLgUcM6E]I6USM0d_HgEbLVE^M6=_K6mbM79QKW=VIG8PM6EcM7=iLgAU
KFAYHg@=;f=eLW9UKWASKGU[Hfm/Kg8PM6EcM7=iLgAUKFAYHg@=HFiT865^I21Q
KV@PKVmdNbm^Hfm/Kg9c830PI6EVOFUVOFUVOFUV3FiSKfa_LW<PI7E`834PKVDP
IGQSJ21TMG0P<b1^IB1UN6=X83@PKVDPHFiT865^I21k;fiSKfa_LW<P<21TIFIm
JFH=KV=_K6mbLb0a86Ea86AeL21TMG0PKVmd87=dHG9dKVm/Kf5T3G/_I6mSK7Ed
JFeQIfEkFg/b=CDPKGE/879_MFiT86=fJB1RMf=/MG@PIGQSJ21WIG@P<SDe86AY
MWdP;fEhIF<PK6mQI21TMG0PHgEbLVE^M7AbHFicIVEb86EhHfQM80eSMWPPHVU^
I21cIGAdLV5^LfIULR1OMb1OJ20h85mYKF5dLVUh85mTLb1YKF5WIGeTIFImJFH=
KVmd86E^I6i_K6mQI0e^Hfm/Kg9c86AeL20c86Ea86EhHfPP=21ULB1_LPeTMG0P
I7E`86i_M21cM65bM6i_K6mQI0ek;fieK6a`LVmSNg]mOFAUIRmSKfiSHGAeM6U/
NbmUN6ES86a_HF@==b0]<B1bKfa/82mUN6ES86a_HFAmI6EV3BmTIFIcMF9SK7Ed
3G/a865TI21WIGAYKWAULWIQK21TIFImI6EV3BmcL6=_KV=QM7AbHFicIVEb820P
3G/_A6=/MG@PIGQSJ21TIFH_@f=/MG@PIGQSJ21TIFH_@V=/MG@PIGQSJ21TIFH_
@F=/MG@PIGQSJ21TIFH_KV=_KG1eM6DPIGQSJ21/I0eSMG9bIFidHfm/Kg9dLV5^
LfIULPeKNd5SK7Ed86iSKfe`MGAUOF=_KV=QM7EdJFaM86=fN0eKNd9SK7Ed86iS
Kfe`MGAUOF=_KV=QM7EdJFaM86=fN0eKNd=SK7Ed86iSKfe`MGAUOF=_KV=QM7Ed
JFaM86=fN0eKNdASK7Ed86iSKfe`MGAUOF=_KV=QM7EdJFaM86=fN0ecIGASKfa_
LWAbHFicIVEbOFAUIPd_LfEdMG1bIf9SK7EdL`ek;f9YM3=h879WHV=/MG@PK6E^
IgAX83<PLgER86AUIPd_HVUd<GPPHVUd<gPP<b1YI6Uf86AUIRmbHfaeM21bIf9S
K7Ed86AUIPd_If=/MG@PLV=/MG@P<B1RJG@cN21TIFIcMF9SK7Ed;f9SK7Ed879S
K7Ed838PHVUd<gPPI6EVLgERHfaeM7eTIFImJFHPKVmd820=IFiTKVm/Kf5T86iS
Kfa_LW<P<b1ULB1TMG0PI7E`86i_M21cM65bM6i_K6mQI0ek;c=SKfe`MGAUNfEh
HfPPHVUd<gPPKGE/3G9_MFiT86=fJB1WIG@P<SDe86AYMWeTIFH=;fA_HfaeM6U]
HFMUNbD_LVMRHfaeM21hI6HPL6m`80ecIGAeL79WHV=/MGAc;c=SKfe`MGAU879S
K7Ed86MSK7Ed869SK7Ed86AeL0ecL6=_KV=QM7AbHFicIVEb85mg85mX83PPGfU]
HGAbJGP=FbmOI7<PK6mQI20_IGQUHb1/Kf5T82mTMG0PK6mQI21TMG1MHgIh3Fie
K6a`LVmS86ieK6a`LVmS87AbMFDP<b1SKfa_LVU]HFMUOFAUIWeYIR1^Kg@PIFiT
KVm/Kf5T86iSKfa_LW<P=21ULB1TMG0PI7E`86i_M21cM65bM6i_K6mQI0ek;g=d
MFIVHfaeM7]SKGU[JFiTIGPP<b0]<B1bKfa/871eM7eTIFH=;fIdKfU^M7/a86Eh
HfPPLgER838e=B1]MF`PLVmeKV@PHgIYOFAUIPd_=6=_KG1eM6DPNb1UN6=X869Y
M3Ah86eeK21bKgE^I21SMVTPIfEd838e=B1TJGHPOB1TIFH=;f=_KG1eM6ESKGU[
HfaeM7]cIGAeL79WHV=/MGAc;f9YM3Ah879WHV=/MG@PK6E^IgAX83<PJFAYMR0d
86eeK20d87=eHR1TIFH=;f=]NF]SK7Ed869YM3Ah83@PHFAT87=dLVU^Ib1TIFH=
;f=SK7Ed86=]NF]SK7Ed86AUIPd_KF=/MG@PHf=/MG@P<B1RJG@dN21TIFIcMF9S
K7Ed3BmiHfaeM21SHfaeM20b869YM3Ah86AUIW=eHV=/MG@=;f]SK7Ed86=SK7Ed
83<PHVUd=7PPI6EVLgERHfaeM0d_HfeiJfU^I6Eh830PI6EV3C0P<B1RJG@aN0ek
I7E`82mSKGU[JFiTIGPPIGQSJ21RJG@aN21UN6=X87=eHR0d86eeK21TIFH=<b1]
MF`PI7E`879SK7Ed86EhHfPPIfEd838e=B1TJGHPIGQSJ21TMG0PIf=/MG@PIGQS
J21WIG@P<SDe86AYMPeUN6=X869SK7Ed86EhHfPPIfEd838e=B1TJGH=LfEdLVMR
Hfm/Kg8PHgEbLVE^M6=]NF]SKfa_LPeVM6mYKW@PJf=/MG@PLgAeIVISK7Ed3FId
KfU^M21iHfaeM21cM7EVIV=/MG@=IWA_JFid86eSK7Ed87=dMFIVHfaeM0eVM6mY
KW@PHf=/MG@PLgAeIVISK7Ed3GeVKg9mI6EV3BmTKf=/MGAYKF5WIG]YKWIQK6UT
Hfm/Kg9dHF9/ICmkHfm]L7EdIF=]NF]SK7EdOFUV3BldHfm]L7EdIB1SHfaeM21]
HfaeM21iHfaeM21[HfaeM21cL6=_KV=QM7AbHFicIVEb3Emg85mX83PPGfU]HGAb
JGQK;emTLb1/Kf5T82mUN6ES86a_HF@_I7E`86a_HF@PI7E`86AeL5dPHgIh80e^
MFa/L79_Hb1^MFa/L79_Hb1^MFa/L79_Hb1dLWEU83@PHfm/Kg9YKF5WIGeTIFIm
JFH=KVmd86E^I6i_K6mQI0e^Hfm/Kg9c830PIG4=I7E`86AeL21^Kg@PLgAQLWA^
Kfa_HF@=NbmSKfa_LVEhL65^I7]]NG=dLVU^IfEhL20`879WHV=/MG@=<b1SKg1i
3CLP;C4PLVm/K0ek<b1]MF`P<b1WIGAYKWAULWIQK21`MGAYKWAULWIQK21UN6=X
83<PHFAT86EhHfPP<b1SKg1iOFI_LV5/K0e`Kg0PL6m`871_L21`Kg0PL6m`OFAU
IPd_Hg9UHGAUIGQ`HFiTLgAbNbm]NG=dLVU^IfEhL21UN6=X87=d<21/IFiWM6PP
KGE/87=dLVU^Ib1TIFImI6EV3BmTKf=/MGAYKF5WIG/_LVMRHfaeM21hI6HPL6m`
83<PHg9UHGAUIGQ`HFiTLgAb85mg85mX83PPGfU]HGAbJGP=FbmOI7<PK6mQI20_
IGQUHb1/Kf5T82mSKfa_LVEhL65^I21/Kf5T82mUN6ES86a_HFAM86=fN0eVHFac
IB0c86=_K6mbJFeQIfEmI6EVOFUV86i_M21UKVA^Kfa_HF@=K6EfIF`b87/PI6m^
M6a_HFA/IGIUK34PLVEcM6mbIB1mJFH=K6EfIF`b86i_M7/PLf5fIB0_I6m^M6a_
HFA/IGIUK38PN6AV87eYIPd_LVMRHfaeM20`86AUIPd_I6mSK7EdJFeQIfEk;fQY
MV5/838e=B1TIFHP3E/_BFiTIGQUI20_A6EfJF=UDTM286QYMV5/879WHV=/MGAM
87=UM6=_K6mbLg1QHfD=GfU]HFMUI6USM21TMG0PHVEWJFhP3BmGJFAdJ21OMb1T
IFHP3Bm8IFUWJ7@PGfPPI6EV820=;dAUHfmTIB1K<21XJGIQK5dPI6EV820=;dU]
HFMUCF5dLVUh85mYKF5dLVUh86AUIPd_@VUdLe1ULT=_KG1_KVE^M20h86AUIR0=
;dU^M6EbL6m/HGAU86IQK7=U86AUIPeUKV@PJFeQIfEmI6EV3FaUMVE/<R1^KgAk
86A_KWA/Kf5TK6EfIF`b879ULgA_LVDPOFUV3BDUAFiTD79_He=UM0d_GfU]HFMU
I6USM20a=B1TJF=d869UIfU^82m9KF5WIEAiL6DP<B1TIFH_@VUdLe1ULT=_KG1_
KVE^M20h86AUIRm9KWAULW1_K65dIB1VHFacIB1TIFHPHgEbLVE^M6AYHg@PIFiT
86AUIPd_J65cHfm/Kg8PM79eIB1TIFH=;faUMVE/<R1cNG=dIFeTJF=d82m/HFiW
MF5WIFaUMVE/86]^KgM^3G]/HFiWMF5WIFaUMVE/838PIfEmNfIQK7=UOFUVIFac
IB1TIFH=;fI_MG9ULB1k=21YKVAUN21ULB0h834PLVm/K0dd86U^I6Eh86Ea83PP
<B1bKfa/3C@PJFiTIGPPIG4P>20a879_K6`==21YKVAUN21ULB0h834PLVm/K0e`
Kg0PL6m`871_L21`Kg0PHFiT865^I21QKVAm86AUIPd_LfEdMG1RHFiTLg]WLf5f
I@d_Gg=UM7AbHFicIVEb87=iLgAUKFAYHg@P;g=UM7AbHFicIVEb86MUM21TIFH=
;emSMG9bIFidM79QKW=VIG8PLgUcM6E]I6USM20_HgEbLVE^M7AbHFicIVEb86MU
M21TIFH=;emYKF5WIB1cNG=dIFeTJF=d82mYKF5WIB1WIG@PI6EV3BmRK65^Jb0`
85mSMG9bIFidM79QKW=VIG8PIGQUH`da85mSMG9bIFidM79QKW=VIG8PIGQUHb1U
LB1TIFH=;fiUIf5dJGIU869/HFi[Nc0PGf=eLW9UKWAdLV5^LfIULR1UN6ES830^
=B1/M7d=Nc0PGf=eLW9UKWAdLV5^LfIULR1UN6ES834PGf=eLW9UKWAdLV5^LfIU
LR1UN6ES86MdOFUVIFacIB1TIFH=;fU^MVEbM6ET?b1^IFMQM6UfIB1TIFH=;emS
MG9bIFidIg9QNB1cNG=dIFeTJF=d82mSMG9bIFidIg9QNB1WIG@PI6EV3FQQLf=_
K6mbNblTHR0`86AUIWdPNblTHR0e86AUIWdPJFIUK7=U3BmcIGASKGU[Hfm/Kg8P
MfQULVEkL6m`834P<20`830PLfEdHfeiJf=_K6mb85mSMG9bIFidIg9QNB0a86Eh
HfPPLgER3C0P<B0`830PLfEdHfeiJf=_K6mb85mSMG9bIFidIg9QNB0a86EhHfPP
LgER3C0P<20a830PLfEdHfeiJf=_K6mb85mSMG9bIFidIg9QNB0a86EhHfPPLgER
3C0P<20`834PLfEdHfeiJf=_K6mb85mSMG9bIFidIg9QNB0a86EhHfPPLgER3C@P
Nc@PHfm`NGdPLVE`IF5d3C4P<20`830PIVmeLVEaNblTHR0a87=dKg9UOFUV3C0P
<B0`830PIVmeLVEaNblTHR0b87=dKg9UOFUV3C0P<20a830PIVmeLVEaNblTHR0c
87=dKg9UOFUV3C0P<20`834PIVmeLVEaNblTHR0d87=dKg9UOFUV3C0P<20`830P
IVmeLVEaNblTHR0f87=dKg9UOFUVOFUV3F9/HFi[NblTHR0f87=dKg9UOFUV3BAR
830PIG4P968P=B1ULB1_LW/_96Ad830PI6EVOFUV;bATM20]<B1TIFHPIg9ULgA_
LVEmI6EV3BmTKfU]HFMUN`e/IGIUK39kJFeQIfEmNf9UIfU^3EMYI7AX84QUJFMX
M212JGAcD6Eb@fm]L6m^IFid84U]HFMUCF5dLVUh3DAUHfmTIB1/IFiWM6PP<R1U
L@ek;dAQM65CKgEbHfDPK6mQI21UKV@PJFeQIfEmN`e4IF=_I6DPK6E^IgAX83HP
IG4=NdeeK7AYL6aUA65dHE=_MG9SIG=kA65dHE=_MG9SIB0`86MUM214HGAQDfme
LV=U834PIfEd84AQM65CKgEbHfDP<R1WIGAmNbm4HGAQDfmeLV=U86a_HFAmJFIU
K7=U3DeeK7AYL6aUA65dHE=_MG9SIG<P<b1UKV@PA5=9@fm/Kg99KF5WIGek3DAU
HfmTIB1/IFiWM6PP>21ULG]=MFadJG1/IDAQM65CKgEbHfEcNdAQM65CKgEbHfDP
<21WIG@PA65dHE=_MG9SIB0a86MUM0e4HGAQDfmeLV=U838PIfEd84AQM65CKgEb
HfDP<b1WIGAmNbm4HGAQDfmeLV=U86a_HFAmJFIUK7=U3DeeK7AYL6aUA65dHE=_
MG9SIG<P=21UKV@PA5=9@fm/Kg99KF5WIGeYIWeYIVE/LfD=OFUVIFacI@emJFIU
K7=UOFAUIPd_I7Ak;g9WHV=/MG@PN6AV82mRMf=/MG@PN6AVOFAUIPd_Hfak96TP
LfEdKF5dLVUh87AbHFicK65dIB1cHf5/I@d_GgLPGfU]HFMUI6USM20_EfUTM6PP
IfEd86AUIPd_GfPPGfU]HFMUI6USM20_B6EYIfQd86MUM21TIFH=;emTLb1OJFeQ
IfETJF=d82m4HGAQDfmeLV=U86MUM21TIFH=I6mSK7EdJFeQIfEm86AUIPd_HfAk
96TPLfEdKF5dLVUh87AbHFicK65dIB1cHf5/I@e/IGIUK39kGfU]HFMUI6USM20_
@fm/Kg9CL65SIB1WIG@PLfEdHfm/Kg9cL65SIGeYIPd_GgLPGfU]HFMUI6USM20_
EfUTM6PPIfEd86AUIPd_GfPPGfU]HFMUI6USM20_B6EYIfQd86MUM21TIFH=;emT
Lb1OJFeQIfETJF=d82m4HGAQDfmeLV=U86MUM21TIFH=GfU]HFMUI6USM21RIFMY
KPd_BFeQIfE=HGAbJGPPGfU]HGAbJGPPI6EV3F=eLW9UKWATJF=d86E^I0eTKfU]
HFMUOB1TIFH=;fU]NbAY87=UM6eQM79YN21dLV5^LfaQM6DPLf=QK6DP3FaUMVE/
<W/_A6EfJF=UAg9QNB1cIGASKfa_LW=`HF=U830PLfEdIg9QNGeYIPd_GgLPGfU]
HFMUI6USM20_EfUTM6PPIfEd86AUIPd_GfPPGfU]HFMUI6USM20_B6EYIfQd86MU
M21TIFH=;emTLb1OJFeQIfETJF=d82m4HGAQDfmeLV=U86MUM21TIFH=GfU]HFMU
I6USM21RIFMYKPdU;dAUHfmTIB1K<20aGB1TIFHP80dU;eMYI7AX85mg86AUIPdU
;dQUJFMXM21OJ21TIFH=;dU]HFMUCF5dLVUh85mYKF5dLVUh86AUIPeSMG9bIFid
I6USM21UKV@P3FA_JFeQIfDPOFAUIPd_Hfm/Kg9YKF5WIB1gJ6EbIG]`Kg0_A5=9
@fm/Kg99KF5WIB1kHfm/Kg9YKF5WIGdPI6EVOG/_A5=9@fm/Kg99KF5WIG/=;bA^
Hb1hI6HPL6m`82m`LVmS<21hI6HP<b1YKVAUN20b86U^I6Eh86eeK20g865TI20h
86AYMR1SMVTPLgAbJFiW82mcM34PN6AV3BA^Hb0c86EaNg]`LVmS<21TMG0_Lg@`
87QTIR0`86EhHfPP<b1UN6=X86aUKVMdJ20c87=eHPekI7E`87=d<21UN6=X86MU
M20^<b1]MF`P<B1YKVAUN20a865TI21cM30PIGQSJ21WIG@P;SDi86eeK21QI6@P
<B1YKVAUN20b865TI21cM30PIGQSJ21WIG@P;S4a86eeK21QI6@=HgIY86EhHfPP
<b1TJGHPHgIY86EhHfPPLg@a83<P<B1bKfa/871eM7eVKg8PLg@aOGekNg1bKf<`
86AeL2mcM30PN6AV830PIGQSJ20d86EhHfPPK6E^IgAX83@PLgERNfAeL0ecM30P
IGQSJ21WIG@P;S<PKGE/3C4PJFiTIGPP<B1QI6@PLg@`86EhHfPPIfEd82he>B1]
MF`PHFAT3C4PJFiTIGPP<R1QI6@PLg@`86EhHfPPIfEd82ha<B1]MF`PHFAT3C4P
JFiTIGPP<b1QI6@PLg@`86EhHfPPIfEd865TI21TMG0P<SDe;S0PIgAkL6m`838e
=Bh`OFUV3C8e=Bh`86EhHfPPLgER86=fJ@eUN6=X83@PI6Uf86=fJB1UN6=X3G=d
<B0c834PLVm/K21`MGAmIVmb87=d<GemJFIUK7=U3FU]HFMUOFAUIWeYIVE/LfD=
;dm@BFU]HFMUNfU]HFMUOFAUIPd_96TPKF5dLVUh86AUIPd_HVUkLf=QK6DPM79Q
KW=/HGAU82AY86=eLW9UKWA]HGAbJGPPL6m`87AbHFicK65dIB1cHf5/IB1cIGAe
L69QKVAcOFAUIPd_IFUk96TPLfEdKF5dLVUhOFAUIPd_JF]k96TPLfEdKF5dLVUh
87AbHFicK65dIB1cHf5/IB0=;emg85mYKF5WIFAYHg@P;eMYI7AX86MUM21TIFH=
;emX85mYKF5WIFAYHg@P;dQUJFMXM21WIG@PI6EV3BmOI7<PGfU]HFMUI6USM20_
A65dHE=_MG9SIB1WIG@PI6EV3Emg85mX86IQK7=U85mYKF5dLVUh83DP;C4PLVm/
K21OI7<PJFeQIfE]HG=[OFAUIPd_LW=k<R1SKg1i87AbHFicK65dI@dc82da879_
K6`PKVEW879_M65dI@e^IFLPIGQSJ21^IFLPIGQSJ21dLV5^LfaQM6D=OFAUIPd_
Hg=kGf=fKGAh865cM6mbIB1SKfiSHGAm86AUIPd_IVAk;emVI21hI6ImI6EV3BmO
IVm^M4eQM79YN7/a830P<21OIV@P<21^IG/]<B0`831mNc4P<20`OFUVIFacIB1O
HgI]M7PPHG=dKg9UOFAUIPd_LVIk;emUKV=_I6U^I6Eh87QTIPe6KfidA6UbIF=d
Kg9i86EhHfPPJfi_MfhPN`eVJFiTIVm^M21TMG0PK6E^IgAX834PHFAT86AYHg@P
HVEWJFik<B1YKVAUN2m6BD@PKVEkI6EVOG]`Kg0PL6m`OFUVIFacIGeVKg9QK6`=
I7E`82m6KfidCV5]IB1UN6=X86AUIR16KfidE7U`IB0`86iUNbm5KV=_I6U^Ib15
KV=_I6U^Ib0b=CHPHG9bHGTPHfm`NB1TIFH=GfE^HfmTJFiTIGPP<21WIG/`85mU
KV=_I45bLR1OIFiSKfAYKVAUN21WIGAkI7E`87AiL6D_KV5]IGAiL6DPIG5kAFiS
KfAYKVLP<R1YKVAUN20b86U^I6Eh871eM21`Kg0P<B1QI6Am3G]UN6=X871_L7eY
IVE/LfEmIVmbHFa/871_L7eYIWeYIPeSMG9bIFidI6USM21UKV@=I6EVJFiUIVm^
M21`Kg0POG]`Kg0PL6m`OFUVIFacIGdPI6EV3BmSMW=VNb1VJFiTIVm^M21VM5=Y
NVDP<20`86IdDfUjIB1OIV@P<21^IG/]<B1]MFamJFHP<20`85mSMVedN21QLgA_
LVDP3FeQJfEVKfid87=UM6I_KWAmI6EV3Bm]IW/c82da879_K6`PIVU^I6I_KW@P
<b0a879_K6`PIGQSJ21VM5=YNVDPKGE/86EhHfPPIWACJGYU86eeK20`86EhHfPP
<21UN6=X80eOIV@P<21^IG/]<B1]MFamJFHP<20`85mSMVedN21QLgA_LVDPKF5[
IFI_KW@PLfEdIVm^M7eTIFH=;gMbJc4P:20Y86AUIPd_MfAYHg@P<CHPI6USM21T
IFH=;eM_LV/g=B0g=B1cM79YKVLPI6EV3Bm>KF]kEfmbJcLe86=fLb1TMG1mI6EV
3Bm>L7AkL7Ed86=fKWeTIFH=;fAXCfAXNdi]Jb0b83Li84i`M7eTIFH=;fAX@VAX
Ndi]Jb0b834a<B1>L7AmI6EV3BmTJ5=TJ7]>KF/P<R0h<b1>L7AmI6EV3BmcIUMY
I7AXNfMcHGIU830P<21]KgIUM6lP<20`86aYKVEdKb0`830PK6U^IGA_830P<21/
JFiUM6lPHfa_LfE`HGAX86=/JG0PLgAbJFiWMfUTM6PPIg9ULgA_LVEmI6EV3BmV
M7=k;fIdDfUjIB1UN6=X86AUIWeTIFH=;fe[AUAkI7E`;dI_KWADNG1U86MUM20`
86EaNfAeL21]HGQ/IFiWM6PPI6USM21RIFMYKPek<B1YKVAUN2m6BD@PKVDP<R1Y
KVAUN20_EFiYLGEUBD@PKVDPHFiTNfAUIWekL6m`871_L7eYIVE/LfEmIVmbHFa/
3F=eLW9UKWATJF=d86E^I0eTMG0_ATAUL5IUHgA_LR0b86=_L7TPIfEd3E]UN6=X
83HPJFiTIGPPIGQSJ20f86U^I6Eh86EhHfQkKF]6E20c834PLVm/K7eVKg9QK6`P
L6m`871_L5dPL7Ed86AeL7ek;gAUKG16E20a<R1TJF=d86AUIPedIFe`AU@PHVEW
JFh=;dI_KWA=HGAbJGPPFc4P<20`834P<20`GB1TIFH=;dI_KWADNG1U83<PI6EV
3FAeL2m5KV=_I6U^Ib1WIG@_AFiSKfAYKVLPIGQSJ21TIFH=;g1bKf<b838PJFiT
IGPPI6EV3FAeL2mVM34PIGQSJ21TIFH=;fId<R0a865bLV5i86AUIPd_AVm^M492
KgPPFc0P<20a835M86AUIPd_@WEYK6A3J65bNd=FA6USM21RIFMYKPeUN6=X86Ae
L2mVM6Ad87QTIR1RIFMYKPegI6USM21RIFMYKPd_HfQb87QTIRmSJ79cM21gLV/a
86AeL20`86=XLR1`MG@PI6EV3FId<R0`86MUM21^MFa/86EaNfId<B1TMG0PK6E^
IgAX838PHFAT86AYHg@PHVEWJFh=Nc4PJFiTIGP_ATU486iU838PJFiTIGPP;eE^
JG5eIDU486iU865^I7]TIFImNg1_L21`Kg1mJFIUK7=UOFI_LV5/K0d_D65YKWAD
NG1U838PI6EV;e=dLVm[IEMYI7AX82h`<S@P<216KfidCF5dLVUh86UTM79QKW=V
Kg9]871_L21TIFH=HgEbLVE^M6AYHg@PIFiT3Bma86EhHfPPI6EVJFiUIVm^M0eV
M38PIGQSJ20`86EhHfPPL7EdOFUV3FIdI7@_L79_Hc8PIfEd86EhIF<PIFiT86E^
I21UKVAmI6EV86E^I21dIFe`AUAmJFIUK7=U3C<PJFiTIGPPIGQSJ0eTIFIYKVEV
Kfid86EhHfPPL6m`OFAUIPd_KF9kI7E`86AX@VAX84I_KWA4JG9UHgA_LWTP<B1Y
KVAUN21[KVmgKPekIGQSJ21`Kg1mNfAe02<0002Q0<0Gf70P<R1YKVAUN0eVJFiT
IVm^M7]RKfaTL79_HgdPIGQSJ0e]JdID871_L21`Kg0PL6m`86EhHfPPL6m`3GeY
IVE/LfDPOFAUIPd_KFmkI7E`86AXCfAX84I_KWA4JG9UHgA_LWTP<B1YKVAUN21[
KVmgKPekIGQSJ21`Kg1mNfAeL20b86U^I6Eh3FIYKVAVKfidNfmeM71bKf=m86Eh
HfP=KF]6E21`Kg0PL6m`871_L21UN6=X871_L0emJFIUK7=U87eTIFH=;fecNfAe
L21TJ5=TJ216KfidA6UbIF=dKg9i834PJFiTIGPPJfi_Mfh=NfEhHfPPL6m`OG]T
MG0P<R1YKVAUN0eVJFiTIVm^M7]CJ65T@fQQLWdPIGQSJ0e]JdID821`Kg0PL6m`
871_L21UN6=X871_L0emJFIUK7=U87eTIFH=;fmeM71bKf=kIW@a87=UM6I_KW@=
Ig=QMVDPHfQbLg@PLfIGJFAdJ21WLVEcM6mbI@ecIGASJ65bMfUTM6PPI69/LfQm
I6EV3BmRKfaTL79_Hg]VM34PLfEdIVm^M0eWLf5fI@eSJ79cM21cIUMYI7AX834P
JFiTIGPP<21^IG]UN6=X82h`=B1QI6@PIGQSJ7eYIPeWLVEcM6mbI@ecIGASJ65b
MfUTM6P=IW@a82m@HFU^M5AiL6DPIfEd838PKVD=Nc0P<21]KgIUM6lPIg=QMVDP
IW@b830PIfEd87=UM6I_KW@PHfQbLg@PLfQ_Mb1WLVEcM6mbIB1SJ79cM21cJ6mg
O@ek<20`86e_MVEdKb1WLf5fIB1SJ79cM21cJ6mg86MbIG=dKg9U82h`=B0`86e_
MVEdKb1SJ79cM21cJ6mgOFUVIFacIGeTIFH=;fARK7=XNf=eLW9UKWASKfa_LR1S
MG9bIFidHfm/Kg9cL65SIB0a;S0PLfEdIg9QN@eSJ79cM20`830PKFmfIGA_87=X
KgLPLfEdHfm/Kg9cL65SIB1cIGASKfa_LPeVM38P<21WIG@PLfEdIVm^M21SJ79c
M20`830PKFmfIGA_87=XKgMmI6EV3BmCJ65T@fQQLW/=IW@a87=UM6I_KW@=Ig=Q
MVD=HfQbLg@PLfIGJFAdJ20a86U^I6Eh830PKVEkIGQSJ20^<3DPHFAT86EhHfQm
JFH=Ig9ULgA_LVD=LfEdHfQQLWMYI7AX3F=XLW=d82h`=R0`86e_MVEdKb1cJ6mg
3C0P;S0e87AbHFicK65dIB1THVacJ7eTIFH=;gAcNg=XKgMmI6EV3BmdHG/_GfaU
M7AULU=`HF=U87QTIRmOLg1QHfEHM79Q87QTIWeTIFH=;gAVNbmOM6EhM5MYI7AX
87QTIPd_GfieKE=`HF=ULb1hI6H=;emcM79YKVM<IFiWM6PPN6AV3FAeL0UcM79Y
KVMgJFAdJ21`Kg0=GfaUM7AULU=`HF=U85mcM79YKVM<IFiWM6PP<B1cMF8PKGE/
865TI0eOLg1QHfEHM79Q85m^MFeCL65SIG<PKGE/865TI0eOM6EhM5MYI7AX86Eh
HfPPLgER82mgI6UV87QTIPeOLg1QHfEHM79Q830P<c8=MfAYIR1OLgAbJFiWC6E^
IgAX86AYMPeOK6EdM6EbDg1QHfDPHFAT3C0P=R0]<B1bKfa/865gJFAdJ7=XKgMm
I6EV3Bm`HW/_Ge1QIfECHGIU87=QMVDPI6EV;g=XKgM`HFMUNgeTIFImI6EV3Bm`
IG]OD65WIE=QMVDPLVEcM6mbIGeTIFH=;g1]Nem`KB1SMG9bIFidKF5dLVUh871_
L7eTIFH=;em`KB1]HGAbJGPPI6EV3Bm`Lg]cJ6mgL65WIB1OL6dPLfEdKF5dLVUh
OFAUIPe/IGIUK39k;fEV87]WLf5fIB0f865bLV5i865cM6mbIB1SKfiSHG@PI7E`
86EhIF=VKg9]86MbIG=dKg9UOFAUIWd=NbmUIW]WLf5fIB0f865bLV5i865cM6mb
IB1SKfiSHG@PKVEgL65dJ21TMG0PHVEWJFhPCF5dLVUh86=_KV=QM0e2@Vmh86Ae
L21TMG0P<21WIG@PIGQSJ20a86MUM21]KgIUM6l=I7E`86AeL20`86MUM21UN6=X
83<PIfEd86aYKVEdK`eTMG0PI7E`838PIfEd86EhHfPP<b1WIG@PK6U^IGA_3FAe
L20b86MUM21UN6=X834PIfEd86aYKVEdKb1SK6mcIG1QM6P=HfaYL21^IGM`HGAX
851QJFidD79_Hb1UKV@PIg9ULgA_LVEmI6EVOFUVIFacI@d_HV=kLf5fIB0a<B0a
879_K6`P<C0PI6USM21RIFMYKR0_@T9_N20e834PLVm/K20d865bLV5i865cM6mb
IB1TIFH=;deQM79YN20g834PLVm/K20f865bLV5i865cM6mbIB1TIFHP;dI_LVeD
NG1U834PI6EV;e1QJFidD79_Hg/_L70PIfEd86EhIF=mI6EVOFAUIPd_IF=kL6m`
879ULgA_LVEmI6EV3Bm`LVU^M7I]Nc4PMVebIF=/HFU]87I]LgAQM7Ec871_L21U
N6=X871_L20X820P820P820P820P820P820P820P820P82USMW<PL79YKW@P:5a^
:G1bJFid86I/MG=XOFAUIPd_LfEdKgIULW1bJFid87MXIG9U87]`Kg1mNbmcIGA_
MVEbL79YKWAkL6m`OFAUIWeYIVE/LfD=;g=cM78PNb0_97=cM79c86EhHfPPI6EV
82lTLg=dLR1UN6=X86AUIR0_97=cM79i86EhHfPPI6EV82lTLg=dLWPPIGQSJ21T
IFHP;d=_MG9YIG8PIVU^I6I_KW@P97=cM79c80ecHf5/IFI_KW@PLfEdIVm^M20T
Lg=dLWPP97=cM79i86ed87=dKB0a82da87=SHFaU82AcLgAb87=XKgLPLWA]87dP
I6EV3Bm4DdU2IFMYKU1QJFidD79_Hg/_L70PKF5bJg]SMG9bIFidIVU/IB1dKf]U
KR1^KgAkOFUV86AeL2m4DdU5KVA@HFU^M51bKf<=2FEaNg1_L21SKgE^M7A_KF5b
Jb1QLW9QNB1QLgA_LVDPHgIh869YKV@P;fEhIF<PK6mQI5eSMWPPI6EV84ACBDE^
I51QJFidD79_Hb1UN6UdO@d9Nf=_MFidM6m]HG9[83<`<21WM7]SKgE^M7A_KF5b
Jb1QLW9QNB1QLgA_LVDPHgIh869YKV@P;fEhIF<PK6mQI7eYIWeYIVE/LfEmK6m_
L7eTIFH=;dACBDE^I51QJFidD79_Hg]SMG9bIFidI6USM21UKVAmI6EV3Bm4DdU2
IFMYKU1QJFidDgERD79_Hb1kLf5fIB0a<B0a879_K6`P<C0PI6USM21TMG0P;g14
86EhHfPPI6EV869UIfU^80d9;d92KgPP=B0a879_K6`P=21QLW9QNB1QLgA_LVDP
I6EV82m=HGAbJGPP=b0a879_K6`P=R1QLW9QNB1QLgA_LVDPI6EV80d9;dI_LVeD
NG1U834PI6EV82m@HFU^M51bKf<PNb0_L70PIfEd86EhIF<POB1TIFHP;g1`OB1T
IFH=;dACBDE^I51QJFidDgERD79_Hb1kHVU^I21TIFHPIFiT8714OB1TIFH=;fUQ
HB1k;fUh86Uh86UhKR1QI6@PI6EVOB1TIFH=;fUQLc8PNbmYIf5`86EhHfPPI6EV
82mOLg@`86UQ86Uh86UWHG0PHFAT86MUM21TIFHPGg=d<7dPI6EV3BmYHG<PNbmc
M30PJF4PJGPPIfEd86AUIR1YHF4PLg@`OB1TIFH=;fTh=G<PNc0PJF5c<R0_@E=3
BDTh=DAUHfmTIB1VJFadIG8PLg@`879UHFAcM79YKVLPL6m`86UQHGdPI6EV3BmY
LVaULb1k<21YHG<b82m1Dd=9BCPeA6ESKfAU86IYK7AULR0_DWE^C6E^IgAXA6ES
KfAU86IYK7AULR1cM30PLVEQI7=dLVU^Ib1`Kg0PJF5QOB1TIFH=JFiYM6UQK6Uj
I@eUKV@=9BE5KVABIG=_MG9SI@e3ETAYHg@PHVEWJFhP<21YI20a86IT3EmUKV=_
I45bLR0`3E/=<cT_LGE_M6EcJFiWK6DP>CH_Ig9QMVD=<C8h;f9eK6aUM2mRMFa/
IG@_LGE_M6EcJFiWK69QLfD_IVa_LVU^;g5eKgAUI69/HV5cIBmUK6aYL7=YLbmT
HFMWIG8_I65WIfEbI69/;f=YLV=eKFI/IGP_L6EbM6Q_MG=QKV@_Df=QLVm^;fMe
JFacJFiWK6aUIW@_CdD_HWE/K6Ed;f9eK6aUM2mRMFa/IG@=;f9eK6aUM2maMFmd
IFaUIW@_LGE_M6EbJFMXM2maMFmdIFARK6aUIW@_LGE_M6ETHVabJFMXM2mRMFa/
IG@_IFiTHG=X;fE]I65cJ2mdJFaTIBmdLV5TIFeQLV/=;g=SHG9_KPd_IgEYK7=Y
KVM/LVUWJ7@_KfD_HWE/K6Ed;f9eK6aUM2mII6UULVEcJG<=;f9eK6aUM2mUN6=/
HFeTKgM^;f=UKW@_LgAULVaYKVL_HgEbLVE^HgT_NFE^;f9bKf]UKV9QLRmcIF=d
JFm^;fAYIG9ULfUc;f=_L7UbJFMXM2m_LVAVIFeYKVU^IBmWMFU/K6E]KgA/IFId
;fa_IfUSHFa^Kg@_J7U`J6E^;g9UIfUcM6EbIF@_KF5SLVm^3BmTIFMbIFD_L6ae
LfeYKWEc;gAgKg=eL6EbJFmb;gAXLVEULgE`IG9YKg8_HF=eM6D_KGD_L65bHFMb
HG1X;g1ULVU_I6=UKWAULVET;f=UI6U/K64_KfiULgE`IG9YKg8_Kg9TKF5cHgE/
JFiU;fMeJFa/IFe_M79YIfQd;fm^IG5eHG9dIG8_KfiUJ65/IRmdJ79UIG5eHG9d
IG9c;g5eIG=dJFm^I6mgKPd_@FMbHGIU;d5QHgEdIBm1HfUbHgE]IVaUN2m1M6U/
I6D_@FAYIG9ULfUc3Bm1LVU^I`d_@DD_@f=UI6U/K64_AFMbHGIU;dEQHgEdIBm5
Ig9QMVD_AFAYIG9ULfUc;dUWLV5fIBm9HF=eM6D_BF=YLV=eKFI/IGP_BFAYIG9U
LfUc3Bm5M6P_CWAYK6AU;dmWLV5fIBm?HF=eM6D_Cf=YLV=eKFI/IGP_CgAYK6AU
;dmTJFEbIG=YLbm]MFadJG1/NBm?LfaQLfP_EFMbHGIU;eEQHgEdIBmEHfUbHgE]
IVaUN2mEI6UULVEcJG<_FF5SMGAU;eAXKg9^;fMULVeQKVARK7<=;f5WLV5fIBmQ
HF=eM6D_HF=YLV=eKFI/IGP_HGAYK6AU;f5TJFEbIG=YL`d_HG9YKVL=;f5U;f=S
IFAYK6aQ;fEWLV5fIBmUHF=eM6D_IF=YLV=eKFI/IGP_IFAYIG9ULfUc3BmYIg9Q
MVD=;fUQHgEdI@d_JF=YLV=eKFI/IGP=;fUTJFEbIG=YL`d_IGAX;fidJFaTIBm_
Ig9QMVD_Kf5SMGAU;fmSJG9SMFeVK6Eh;fmdJFaTIBm_I6UULVEcJG<_I6UfJFAU
;fmcK65cJ2meIg9QMVD_MF5SMGAU;gESJG9SMFeVK6Eh;gETJFEbIG=YLbmiHF=e
M6D_M6Q_LVh_NFAYIG9ULfUc3EdPL7Ed3EmUKV=_I45bLR0a3E/=<cT_LGE_M6Ec
JFiWK6DP>CH_Ig9QMVD=<C8h;d5TJFEbIG=YLbm1LVU^Ibm3HfETJFa/HBm5HF=e
M6D_CWAYK6AU;dmTJFEbIG=YLbmEI6UULVEcJG<_HF5SMGAU3BmQIg9QMVD_HF=Y
LV=eKFI/IGP_HFAYIG9ULfUc;f5dJFaTIBmQLVU^IbmSHfETJFa/HBmUHF=eM6D_
IFMbHGIU3BmUHfUbHgE]IVaUN2mUI6UULVEcJG<_JF5SMGAU;fUWLV5fIBmYHfUb
HgE]IVaUN2mYI6UULVEcJG<_KWAYK6AU;fmQHgEdI@d_KfMbHGIU;fmSJG9SMFeV
K6Eh;fmTJFEbIG=YLbm_M6U/I6D_MF5SMGAU;gEWLV5fIBmeHfUbHgE]IVaUN2me
I6UULVEcJG<=;fAQIfMULRmTIFMbIFD_HfE^M2mcM6EbK6U^IbmcIF=dJFm^;f9e
K6aUM2m`HG9QIg9QL6P_IfEbKF5^I69/L`d_LVEWJG=dIG9UI2mSKg1iLVUWJ7@_
M79QI6E]HG9[;f5SMGAU;fAYIG9ULfUc;fi_M6EaMF5/;d55;dmcK65cJ0d_JFiV
JFiYM7T_L6aeLfeYKWEc;faULg=ULGEQK2mWLVEQM6EbIG5eHF`_NFE^;fee;g1Q
LWAYHFaTJFIV;g=eKFeQM6U_KPd_L79_I7ESM2m`JBmYKWAUIg9QK2m_LVAVIFeY
KVU^IBm_LVA]HG=SMFaYKVD_CfeUIf4_HFD_Kg=/HG=X3BmaMFEcM6U_KVA_Mfh_
IGQSK65]I6mgKRm/KfMYHf5/KVmd;g9QI6USHF`_IVa_LVU^;f5`L79_N6EaMF5/
;dAUK7AQ;fMeJFa/IFe_M6aUIW@=;fMeJFa/IFe_M79YIfQd;fE/K6U`LfUc;f9/
HFi[;d5WLV5fIBm1M6U/I6D_CgAYK6AU;dm5;fmU3BmUKVAQLfP_IFeTHG=X;g5e
KgAUI69/K6EVM2maMFmdIFARK79YIfQd;g5eKgAUK6EVM2maMFmdIG9YIfQd;fAY
MVUTIBm/KgYUKVMU3BmiI6UULVEcJG<_FFAYIG9ULfUc;fIbHF=dJFm^;f=eLW9U
KV=i;fMeJFacJFiWK6aUIW@_IgEYK7=YKVM/LVUWJ7@_IVT_IV`=;fAQIfMULVAR
K2m`IG9YKfASIFidIG9UI2maMFmdIG=YKVM/HV5cIBmaMFmdIFARK69QLfD_L6Eb
M6Q_MG=QKV@_@F=YLV=eKFI/IGP_AF=YLV=eKFI/IGP_@F5SMGAU3Bm5I6UULVEc
JG<_AFMbHGIU;dUQHgEdIBm9HfUbHgE]IVaUN2m9I6UULVEcJG<_BFMbHGIU;dmQ
HgEdIBm?HfUbHgE]IVaUN0d_HG1`K6D_CfMbHGIU;eEQHgEdIBmEHfUbHgE]IVaU
N2mEIg9QMVD_I6mdK6EcLfT_HfUbHgE]IVaUN2mdJFaTI@d_KF5SLVm^;f9bIGIU
;fA_M65SHfE^M2mbJFiW;f=UI6U/K64_J7E^If5bMFe/HGEd;fmWKfiUJbmSHG9_
KPeM871eM0eUKV@=9BE5KVA@LVm/KfLP3BDU@VEWJFiCIGAeL20=@eI4JF=d869U
IfU^3@d_GemOAThc;C4P;dQUK7IUM6USHBe2KfaT86AeL20PI7E`86IYKVAVKfid
86AeL20_@fQQLU=dLVU^Ig<PJfi_MfhPNf9UIfU^84=XHG9CM79YKVMc82m1I6UU
LVEcJG<PJfi_MfhPNc4POG/]<GdPJFIUK7=U86E^I7dPNg1_L20]<GdPJFIUK7=U
879V3BmOGem6CS<P;dQUK7IUM6USHB1TMG0P86AeL21VJFiTIVm^M21TMG0P;d=X
HG9CM79YKVMc86]^KgM^87]RIFMYKR13J65bDgAbJFiWLb0_@FAYIG9ULfUc86]^
KgM^87/a87ek;C5m86UVIFacIB1UKVAm87]`Kg0P;C5m86UVIFacIB1bIPd`86UT
3C4PIV@=<20d>30PM79QKW=/HGAU3C<`<20]<c0`87=SK6T=9BE5KVACIGAeL20=
9BE2IFMYKU1QIfECIGAeL20=L6d=9BE5KVA@HFMUDfEdMG0=;dAUMVUSIE97@R1c
Hg<=<20`830PIS<=<2ha<SD`830^<C8e<21cL0dP<21/H`dP<R1/JPeD87=Q3BE`
HFMU879UHg@j834`838i=b0e<STP=cLe80ecM6d=<BhP<BhP<BhPIS<=KW0=<c4d
<Bhb=S0a83L`<CT^>3Hf=b0c<cLi;STg=38P=c8e>2he>30h879`3FAU3C0P<20`
86Hc3C4g;S<f<C0P<CL^<cHa<21cL0da<Bhe86a]3B0`86aZ3Fi`3C<a=34^<SH`
<B0g<34i;SPf=SLP<c<g>Bhi=c@b83Lb=CP^=CP`>21bL0eTL`ebM6d=0:40`01V
LgA]3C0P<20`86Hc3CDb;S0h<c4P=C8^<3Pc<B1cL0de<2h`86a]3B0`86aZ3Fi`
3C<d<CD^=38i<R0c<CPe;SLd=cLPKG@=<STa<Bhi=CTe83<a>3D^=c@g=b1/J@eT
L`ebM6d=0:40`015LgA]3C0P<20`86Hc3Fi`3C<d<CD^=38i<R0c<SPa;S8c<c<P
KG@=<STa<Bhi=CTe83<b>34^<S<c<b1/J@eTL`ebM6d=002Q0<00F7=dK@d`830P
<21V<`da=bhc=S4`834g;S<f<C0PLg0=KW0=<c4f<bhf>C@d838g=S0^=30b=R1]
M0dc<CHc;SHi=3@P<c4i=2hd<SPb86aY3FAc3G9dK@d0X@3004EcM6d=<20`830P
IS<=KW0=<c4f<bhf>C@d83<b>C@^<SDd<B1]M0dc<CHc;SHi=3@P<cLb>2hb=cTg
86aY3FAc3G9dK@d00:40`01dLgA]3C0P<20`86Hc3Fi`3C@c;S@`<SHP=3<^=30b
=R0c<CHc;SHi=3@P<SLd=bhc>34i86E`3FAU3C0P<20`86Hc3Fi`3C@c;S@`<SHP
=3<^=30b=R0c<CHc;SHi=3@P<SLd=bhc>34i86E`3FAc3G9dK@d0X@3007AcM6d=
<20`830PIS<=KW0=<SH^<3@a=B0b=Rh`=34e83<a=S<^=STd=20c=c8c;STc>C@P
IG0=I6D=<20`830PIS<=KW0=<SH^<3@a=B0b=Rh`=34e83<a=S<^=STd=20c=c8c
;STc>C@PIG0=I7<=LWA]3@2Q0<00F7=dK@d`830P<21V<`de<Rh`>3<a83Db;S0h
<c4PLg0=KW0==3<h=bhf=3He83<a>3D^=c@g=b1]M0dc>3Pd;S4g=SPP<c4h=Bhg
=3Lg86aY3FAc3G9dK@d0X@3004EcM6d=<20`830PIS<=KW0==3<h=bhf=3He83<b
>34^<S<c<b1]M0dc>3Pd;S4g=SPP<c8h<Bhb<c<c86aY3FAc3G9dK@d00:40`01H
LgA]3C0P<20`86Hc3C4g;S<f<C0P<CL^<cHa<21cL0e^L0dd<CDc;S8g<SLP<SLf
<2hd<38f86ed3C@a=C<^<SLb=b0c<CTd;S@b>38PK6T=I7<=LWA]3@2Q0<00AG=d
K@d`830P<21V<`e^L0dd<CDc;S8g<SLP<c8h>Bhi<C<h86ed3C@a=C<^<SLb=b0c
=c8c;STc>C@PK6T=I7<=LWA]3@00X@3005QcM6d=<20`830PIS<==C8^<3Pc<B0e
<Rh`>3<a87=`3Fi`3CDc=cL^<S8d>20c<CPe;SLd=cLPKG@==3Pg<bhg=CDa83<a
>3D^=c@g=b1/J@eTL`ebM6d=0:40`015LgA]3C0P<20`86Hc3Fi`3CDc=cL^<S8d
>20c<SPa;S8c<c<PKG@==3Pg<bhg=CDa83<b>34^<S<c<b1/J@eTL`ebM6d=002Q
0<00EW=dK@d`830P<21V<`da=bhc=S4`834g;S<f<C0PLg0=KW0==C4d<Rhh=C4P
<SLf<2hd<38f86ed3CDa=38^>3Da83<a>C@^=38h<R1/J@eTL`ebM6d=0:40`013
LgA]3C0P<20`86Hc3Fi`3CDa=38^>3Da83<b>3T^>C4c>21]M0de<C@b;SPe<B0c
=c8c;STc>C@PK6T=I7<=LWA]3@00X@30079cM6d=<20`830PIS<=KW0==3<^=30b
=R0d<bhd<38f83Da=38^>3Da838g=C4^=c8b<B1UL0eTI@d`830P<21V<`e^L0dd
<bhd<38f83@c;S@`<SHP=C4d<Rhh=C4P<SLe<Bhg<S8a86E`3FAc3G9dK@d0X@30
05QcM6d=<20`830PIS<==C8^<3Pc<B0e<Rh`>3<a87=`3Fi`3CHc=3T^=3@b<B0c
<CPe;SLd=cLPKG@==CPd=Bhi=c8d83<a>3D^=c@g=b1/J@eTL`ebM6d=0:40`015
LgA]3C0P<20`86Hc3Fi`3CHc=3T^=3@b<B0c<SPa;S8c<c<PKG@==CPd=Bhi=c8d
83<b>34^<S<c<b1/J@eTL`ebM6d=002Q0<00Eg=dK@d`830P<21V<`da=bhc=S4`
834g;S<f<C0PLg0=KW0==S4a=Bh`=SPc838g=CH^<3Hb=21]M0df<C4e;S0f>3<P
<c4i<2h`>3PPK6T=I7<=LWA]3@00X@3004EcM6d=<20`830PIS<=KW0==S4a=Bh`
=SPc83<c<3L^<SLd>B1]M0df<C4e;S0f>3<P<cLd<Bhc<30d86aY3FAc3G9dK@d0
0:40`01dLgA]3C0P<20`86Hc3Fi`3C@c;S@`<SHP=3<^=30b=R0f<C4e;S0f>3<P
<SLe<Bhg<S8a86E`3FAU3C0P<20`86Hc3Fi`3C@c;S@`<SHP=3<^=30b=R0f<C4e
;S0f>3<P<SLe<Bhg<S8a86E`3FAc3G9dK@d0X@3005QcM6d=<20`830PIS<==C8^
<3Pc<B0e<Rh`>3<a87=`3Fi`3C<e>30^<cDh>B0b=3Pb;SHb=S<PKG@=<cDh<2hc
=CPi838i>3H^<3Te>B1/J@eTL`ebM6d=0:40`013LgA]3C0P<20`86Hc3Fi`3C<f
=SL^<CHd838d>38^=S8f<b1]M0dc=SHg;S4f=20b>CPf;S0i=CTPK6T=I7<=LWA]
3@00X@3005QcM6d=<20`830PIS<=<CL^<cHa<20a=bhc=S4`87=`3Fi`3C<e>CL^
=c4i>B0b=c@g;S<h<CTPKG@=<c4f<bhf>C@d838g=3L^<cPa>B1/J@eTL`ebM6d=
0:40`015LgA]3C0P<20`86Hc3Fi`3C@a<3T^>3L`<B0b=c@g;S<h<CTPKG@=<cHg
=Bhh=3@e838g=3L^<cPa>B1/J@eTL`ebM6d=002Q0<00EW=dK@d`830P<21V<`de
<Rh`>3<a83Db;S0h<c4PLg0=KW0==3H`<2hc<CTP<S@h<Rhf<SHc86ed3C@f<30^
<c4i838i>3H^<3Te>B1/J@eTL`ebM6d=0:40`015LgA]3C0P<20`86Hc3Fi`3C@f
>C4^=3Hd=20b=3Pb;SHb=S<PKG@==3Hi<Bhd=S@d838i>3H^<3Te>B1/J@eTL`eb
M6d=002Q0<00F7=dK@d`830P<21V<`da=bhc=S4`834g;S<f<C0PLg0=KW0==3H`
=2hf=CTc838g=3L^<cPa>B1]M0dd<CL`;SHc<cLP<SLd=bhc>34i86aY3FAc3G9d
K@d0X@3004=cM6d=<20`830PIS<=KW0==C4b=Bhd>B0b=c@g;S<h<CTPKG@==3Hi
<Bhd=S@d838g=3L^<cPa>B1/J@eTL`ebM6d=002Q0<00F7=dK@d`830P<21V<`de
<Rh`>3<a83Db;S0h<c4PLg0=KW0==CDg=Rhh=cHf838d>38^=S8f<b1]M0de=CLf
;SPg=SHP<STh=Rh`>CDi86aY3FAc3G9dK@d0X@3004EcM6d=<20`830PIS<=KW0=
=CHf<bhf>34g838d>38^=S8f<b1]M0de=SHc;SHh<CLP<STh=Rh`>CDi86aY3FAc
3G9dK@d00:40`01HLgA]3C0P<20`86Hc3C4g;S<f<C0P<CL^<cHa<21cL0e^L0de
=CPe;SDe=c4P<SLd=bhc>34i86ed3CDa=C4^=C<a=B0b=c@g;S<h<CTPK6T=I7<=
LWA]3@2Q0<00AG=dK@d`830P<21V<`e^L0df<C0f;S<h=cPP<SLd=bhc>34i86ed
3CDf=c8^<cHb<R0b=c@g;S<h<CTPK6T=I7<=LWA]3@00X@3002McM6d=<20`830P
IS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`01FLgA]3C8`>2hc<c8c
86IdL`d_GemOAThc86=fLfH=<20`830PIS<=AR1cH@dc<CT`;SLc=CTP<STb<2hh
<CHb86ed3BPa:B0PLfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=0:40`00WLgA]3C0P
<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00?7=dK@d`830P
<21V<`e687=Q3C@a>CL^=SLe<R0b>C8`;SPa=S8PKG@=:38Y821cJ6mg3E@PLf4=
LWA]3@2Q0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21c
L0d`830P<21V<`d00:40`00lLgA]3C0P<20`86Hc3DHPLf4==C4f>Bhh>C8e838i
<S0^>34f<R1]M0dX<bTP87=XKgL=E21cH@ebM6d=0:40`004LWA]3@2Q0<009g=d
K@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@3003acM6d=
<20`830PIS<=AR1cH@df<C@b;S4`>CPP<STb<2hh<CHb86ed3BPd:B0PLfQ_M`eD
87=Q3G9dK@d0X@3000AbM6d=0:40`01HLgA]3C0P<20`86Hc3C4g;S<f<C0P<CL^
<cHa<21cL0e^L0df<C@a;S4`>CPP<cLb<bhi<cTd86ed3C<a<cL^=SDb>20c=c8c
;STc>C@PK6T=I7<=LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`
87=`3C0P<20`86Hc3@00X@3005IcM6d=<c4b;S@i>3@PIWAc3BmOGem6CS<PHgIc
IPd`830P<21V<`e687=Q3C8f<30^=3Ha<B0c=C8a;SPe<cLPKG@=:4<Y821cJ6mg
3E@PLf4=LWA]3@2Q0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^
<C8e<21cL0d`830P<21V<`d00:40`01SLgA]3C8`>2hc<c8c86IdL`d_GemOAThc
86=fLfH=<20`830PIS<=AR1cH@db>30g;SLi<c@P<cDh<2he<cDa86ed3BPa<2TP
Fc4a=Bhh=R0`85dPN7=XKgL=E21cH@ebM6d=002Q0<00179dK@d0X@3002McM6d=
<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`01FLgA]3C<a
<Rhd>CPd86IdL`d_GemOAThc86=fLfH=<20`830PIS<=AR1cH@dc=S0g;S@`<3DP
<cDb<Bhh=C<g86ed3BQ3:B0PLfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=0:40`00W
LgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00Hg=d
K@db<3P^<c<b<b1VM7<=;emOGdI><b1SMW=V3C0P<20`86Hc3DHPLf4=<cPb<bhd
<C<b83<e>30^=C<e<B1]M0dX<S0Y85/a<CD^>3HP<21M87QcJ6mg3E@PLf4=LWA]
3@00X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=
<20`830PIS<=002Q0<00EW=dK@dc<C8^=3Th=21VM7<=;emOGdI><b1SMW=V3C0P
<20`86Hc3DHPLf4==3Ha=2hc<cTh83<e<cT^<S4d=b1]M0dX@bTP87=XKgL=E21c
H@ebM6d=0:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`
87=`3C0P<20`86Hc3@00X@3006=cM6d=<S0h;S<c<S<PIWAc3BmOGem6CS<PHgIc
IPd`830P<21V<`e687=Q3C@h<c0^<cDb=R0c=CTg;SPi=S4PKG@=:3<`:B1K<C4e
;SPf830PGB1hLfQ_M`eD87=Q3G9dK@d00:40`004LWA]3@2Q0<009g=dK@d`830P
<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@3005EcM6d=<c4b;S@i
>3@PIWAc3BmOGem6CS<PHgIcIPd`830P<21V<`e687=Q3CDe=ST^<CTf83<e<cT^
<S4d=b1]M0dX@bTP87=XKgL=E21cH@ebM6d=002Q0<00179dK@d0X@3002McM6d=
<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`01SLgA]3C8`
>2hc<c8c86IdL`d_GemOAThc86=fLfH=<20`830PIS<=AR1cH@de=cPe;S8`>3PP
<cDi=bhh>CHa86ed3BPd<2TPFc4a=Bhh=R0`85dPN7=XKgL=E21cH@ebM6d=002Q
0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P
<21V<`d00:40`01FLgA]3C<a<Rhd>CPd86IdL`d_GemOAThc86=fLfH=<20`830P
IS<=AR1cH@dc=C<g;STe=S@P<S@d=Bhd=c0c86ed3BQ3:B0PLfQ_M`eD87=Q3G9d
K@d0X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=
<20`830PIS<=002Q0<00Hg=dK@db<3P^<c<b<b1VM7<=;emOGdI><b1SMW=V3C0P
<20`86Hc3DHPLf4=<cLd=Bhb>3Pf838e<3@^<CDa=b1]M0dX<C8Y85/a<CD^>3HP
<21M87QcJ6mg3E@PLf4=LWA]3@00X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc
3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00EW=dK@dc<C8^=3Th=21V
M7<=;emOGdI><b1SMW=V3C0P<20`86Hc3DHPLf4==3Dd=2hh>CDg838d=3D^=3L`
<b1]M0dX@bTP87=XKgL=E21cH@ebM6d=0:40`004LWA]3@2Q0<009g=dK@d`830P
<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@30069cM6d=<S0h;S<c
<S<PIWAc3BmOGem6CS<PHgIcIPd`830P<21V<`e687=Q3C@g=C8^<S8h838e<3@^
<CDa=b1]M0dX<S<Y85/a<CD^>3HP<21M87QcJ6mg3E@PLf4=LWA]3@2Q0<00179d
K@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d0
0:40`01ELgA]3C<a<Rhd>CPd86IdL`d_GemOAThc86=fLfH=<20`830PIS<=AR1c
H@de=C<d;S@g=20b=3@e;S@g<3<PKG@=:4<Y821cJ6mg3E@PLf4=LWA]3@00X@30
00AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830P
IS<=002Q0<00Hg=dK@db<3P^<c<b<b1VM7<=;emOGdI><b1SMW=V3C0P<20`86Hc
3DHPLf4==CLd<Bhh<3Hc838e<3@^<CDa=b1]M0dX<c@Y85/a<CD^>3HP<21M87Qc
J6mg3E@PLf4=LWA]3@00X@3000AbM6d=0:40`01HLgA]3C0P<20`86Hc3C4g;S<f
<C0P<CL^<cHa<21cL0e^L0dd<CDc;S8g<SLP<cLc<Rhf<CTi86ed3C@a=C<^<SLb
=b0d<3@e;S4a>3<PK6T=I7<=LWA]3@2Q0<00F7=dK@d`830P<21V<`dc=2hg<S8`
83<d;SLb<S0PLg0=KW0==3<e<Rhi<S@d83@`<SL^=cDg<b1]M0dc>C4h;SPi>3TP
=30b=bhg=CLc86aY3FAc3G9dK@d0X@3004AcM6d=<20`830PIS<=KW0==38f=Rha
<CTc83@`>CL^<S0a=21]M0dd<38c;S0f=B0d<3Tg;S8`<C@PK6T=I7<=LWA]3@2Q
0<00Pg=dK@d`830P<21V<`e^L0da=bhc=S4P<CL^<cHa83Ha<S<^=c@h>20c=c<b
;SHa>CTPIG0=I6D=<20`830PIS<=<CL^<cHa<20a=bhc=S4`87=`3Fi`3C4g;S<f
<B0a=bhc=S4P=S4b<bhg=3Ph83<g<c8^=S4i>B1UL0eTL`ebM6d=002Q0<00F7=d
K@d`830P<21V<`de<Rh`>3<a83Db;S0h<c4PLg0=KW0=<cPh=2ha=cHh834f<cH^
<SLf=21]M0dc>3Pd;S4g=SPP<S4c>Bhg=3Ha86aY3FAc3G9dK@d0X@3004EcM6d=
<20`830PIS<=KW0=<cTg<2hi>34i834f<c4^>C<f<R1]M0dc>CL`;STh<CTP<S4c
=Bhd<3Dh86aY3FAc3G9dK@d00:40`01FLgA]3C0P<20`86Hc3C4g;S<f<C0P<CL^
<cHa<21cL0e^L0dc<CDe;S0a<cTP<CT`<Bh`<c8PKG@=<cT`<Bhe<cLh834i<34^
<3<b86aY3FAc3G9dK@d0X@3004AcM6d=<20`830PIS<=KW0==C4e<Bhe<c4e834h
>CH^=STa>21]M0dc>CPh;S<d<b0a>3Tf;SHi<CPPK6T=I7<=LWA]3@2Q0<009g=d
K@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@3005IcM6d=
<c4b;S@i>3@PIWAc3BmOGem6CS<PHgIcIPd`830P<21V<`e687=Q3C<c=S@^<c@f
<B0a=cHh;S<i<3@PKG@=:4<Y821cJ6mg3E@PLf4=LWA]3@2Q0<00179dK@d0X@30
02McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`01S
LgA]3C8`>2hc<c8c86IdL`d_GemOAThc86=fLfH=<20`830PIS<=AR1cH@dc=CLa
;SHg>3@P<CPb=bh`=c4h86ed3BPa<bTPFc4a=Bhh=R0`85dPN7=XKgL=E21cH@eb
M6d=002Q0<00179dK@d0X@3005McM6d=<20`830PIS<==C8^<3Pc<B0e<Rh`>3<a
87=`3Fi`3CDd<C4^>C@f>20a=3Le;SHh=b1]M0de=34a;STd=SPP<CTg>Bha=CHf
86aY3FAc3G9dK@d00:40`012LgA]3C0P<20`86Hc3Fi`3CDd>CP^=cDb834d=cD^
=SPg86ed3CDd>CP^=cDb834i=cT^<CDf=R1/J@eTL`ebM6d=0:40`01HLgA]3C0P
<20`86Hc3C4g;S<f<C0P<CL^<cHa<21cL0e^L0dd<C@h;STc<S@P<CLd=2hg>38h
86ed3CDd<c<^=S@h<B0a=c@d;SLh<SPPK6T=I7<=LWA]3@2Q0<00AG=dK@d`830P
<21V<`e^L0df<C0b;S0d=cDP<CLd<2hd=38f86ed3CDe<C4^=cLb=b0a=c@`;S@d
<SHPK6T=I7<=LWA]3@00X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21c
L0d`830P<21V<`d00:40`01FLgA]3C<a<Rhd>CPd86IdL`d_GemOAThc86=fLfH=
<20`830PIS<=AR1cH@de=S0c;STa>34P<CDi=2hg>30a86ed3BQ3:B0PLfQ_M`eD
87=Q3G9dK@d0X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b
=C0PLg0=<20`830PIS<=002Q0<00Hg=dK@db<3P^<c<b<b1VM7<=;emOGdI><b1S
MW=V3C0P<20`86Hc3DHPLf4==CPa<Bhb=C0d834f=C<^=3Ha=B1]M0dX<S@Y85/a
<CD^>3HP<21M87QcJ6mg3E@PLf4=LWA]3@00X@3000AbM6d=0:40`01DLgA]3C0P
<20`86Hc3CDb;S0h<c4P=C8^<3Pc<B1cL0e^L0dd=CTe;STg>3PP>3De;S0c<3@P
KG@==3Di=Bhi=cPh834c=CP^=B1/J@eTL`ebM6d=0:40`011LgA]3C0P<20`86Hc
3Fi`3C@f>C4^=3Hd=20h=CD^<3<`=21]M0dd=STa;S@f=3@P<C<e>2he86aY3FAc
3G9dK@d00:40`01FLgA]3C0P<20`86Hc3C4g;S<f<C0P<CL^<cHa<21cL0e^L0dc
<CDi;S<e=34P<C4b=2ha<SHb86ed3C@f<CL^=SPP<C4b=2ha<SHb86aY3FAc3G9d
K@d0X@3004=cM6d=<20`830PIS<=KW0==S4b<bhg=3Ph834a<CT^=cPf86ed3C@g
<CL^=C0e>B0a<C4i;SLh=R1/J@eTL`ebM6d=002Q0<009g=dK@d`830P<21V<`d`
;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@3005EcM6d=<c4b;S@i>3@PIWAc
3BmOGem6CS<PHgIcIPd`830P<21V<`e687=Q3C@e=3@^>3Te=b0g>CH^<CLc<B1]
M0dX@bTP87=XKgL=E21cH@ebM6d=002Q0<00179dK@d0X@3002McM6d=<20`830P
IS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`01QLgA]3C8`>2hc<c8c
86IdL`d_GemOAThc86=fLfH=<20`830PIS<=AR1cH@dd=cDb;S8b>20h=C@^>3Dd
=B1]M0dX<C@Y85/a<CD^>3HP<21M87QcJ6mg3E@PLf4=LWA]3@00X@3000AbM6d=
0:40`01HLgA]3C0P<20`86Hc3C4g;S<f<C0P<CL^<cHa<21cL0e^L0dc<CHc;SHi
=3@P<CPi<Rhc=C4e86ed3C<a=S<^=STd=20b=c@c;S0d<CHPK6T=I7<=LWA]3@2Q
0<00@g=dK@d`830P<21V<`e^L0de<C@b;SPe<B0a>3Tb;S<e<CDPKG@==C4d<Rhh
=C4P<SLd<bh`=34f86aY3FAc3G9dK@d00:40`015LgA]3C0P<20`86Hc3Fi`3C@a
=C<^<SLb=b0a=c@`;S@d<SHPKG@==34e<bhb=c8g838g=3L^<cPa>B1/J@eTL`eb
M6d=002Q0<00AG=dK@d`830P<21V<`e^L0df<C4e;S0f>3<P<CLc=Rha<38c86ed
3CHa<CD^<3Hh<b0b=cH`;S@`<SHPK6T=I7<=LWA]3@00X@3004EcM6d=<20`830P
IS<=KW0=<c4f<bhf>C@d834a<C4^<C0e=B1]M0dc<CHc;SHi=3@P<CPi<Rhc=C4e
86aY3FAc3G9dK@d00:40`015LgA]3C0P<20`86Hc3Fi`3CHa<CD^<3Hh<b0a<C4a
;S4`=CDPKG@==S4a=Bh`=SPc834g<cH^<C0b<b1/J@eTL`ebM6d=002Q0<00Eg=d
K@d`830P<21V<`dc=2hg<S8`83<d;SLb<S0PLg0=KW0=<S4i;S<c=cLP=S4c=Rh`
<c@d86ed3C4e=c<^=3Tg=B0f=cLh;S<i<S<PK6T=I7<=LWA]3@00X@3002McM6d=
<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`00iLgA]3C0P
<20`86Hc3DHPLf4=<Rh`>3Da83Hb>CP^<C8c<b1]M0dX<BTP87=XKgL=E21cH@eb
M6d=002Q0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21c
L0d`830P<21V<`d00:40`00lLgA]3C0P<20`86Hc3DHPLf4=<CDh<Bhi<cPb83L`
=cT^<cHi<b1]M0dX<RTP87=XKgL=E21cH@ebM6d=0:40`004LWA]3@2Q0<00EW=d
K@d`830P<21V<`dc=2hg<S8`83<d;SLb<S0PLg0=KW0=<SHa;SD`<3@P=C4a<bhd
<3Td86ed3C8f<Bhe<30d83Ha<S0^<c@h=b1/J@eTL`ebM6d=0:40`013LgA]3C0P
<20`86Hc3Fi`3C4g<c8^<3Dd<R0e<CHc;STf=3LPKG@=<S<i;S0`=S8P=S4c=Rha
>38PK6T=I7<=LWA]3@00X@3004AcM6d=<20`830PIS<=KW0=<S8e=bha<SPi83H`
<c<^=CHf=21]M0db<SD^>3Pi<R0f<C<g;SLc<SDPK6T=I7<=LWA]3@2Q0<00MW=d
K@d`830P<21V<`e^L0da<c0^<S0g=b0a<S4^=C8g<R0b=C8^>34i>B0e<C<`;SLg
<3@PIG0=I6D=<20`830PIS<=KW0=<C<`;S8`=cLP<C8a;SDb=c8P<SDb;SPa>CTP
=C4c<2hg=c0d86E`3FAc3G9dK@d0X@3004AcM6d=<20`830PIS<=KW0=<S8f;S<g
=3LP=C4c<2hg=SDg86ed3C4g<CT^=38b=b0e<CHe;S@h=cLPK6T=I7<=LWA]3@2Q
0<00AG=dK@d`830P<21V<`e^L0da=c0e;S0g<C8P=C4e=bhb=cTf86ed3C8b=3<^
<SHb>B0f<38e;S<c<3PPK6T=I7<=LWA]3@00X@3007AcM6d=<20`830PIS<=KW0=
=C8^<3Pc<B0e<Rh`>3<a834g<CT^>38f<b0e<CHe;S@i<S@PIG0=I6D=<20`830P
IS<=KW0==C8^<3Pc<B0e<Rh`>3<a834g<CT^>38f<b0e<CHe;S@i<S@PIG0=I7<=
LWA]3@2Q0<00LW=dK@d`830P<21V<`e^L0de<Rh`>3<a83Db;S0h<c4P<S8e>2h`
<CPP=S0c<bhe=3<f86E`3FAU3C0P<20`86Hc3Fi`3CDb;S0h<c4P=C8^<3Pc<B0b
<SDh;S0a>20f<3<c;SDd<cHPIG0=I7<=LWA]3@2Q0<00@7=dK@d`830P<21V<`e^
L0db<S@d;SPg>3PP=S0`=2hh<cDPKG@=<CDh=Bha=R0f=cHh;SLb86aY3FAc3G9d
K@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d0
0:40`00kLgA]3C0P<20`86Hc3DHPLf4=<S<i=bhi<3Hb83Ha<S@^=C4c86ed3BPc
:B0PLfQ_M`eD87=Q3G9dK@d00:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`
;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@3003acM6d=<20`830PIS<=AR1c
H@da=cDe;SDd>3@P=C0c<2hg=SPf86ed3BPd:B0PLfQ_M`eD87=Q3G9dK@d0X@30
00AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830P
IS<=002Q0<00>W=dK@d`830P<21V<`e687=Q3CLa;SDb>C8P=3Tg>2hf>3De86ed
3BP`:B0PLfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=0:40`01TLgA]3C0P<20`86Hc
3C<d;SLb<S0P<c@^=c8b<21cL0da=2hc86a]3B0`86aZ3Fi`3C8b<Rhd<cPa83Da
<C<^=30i=21]M0da=S8h;SHh<B0f=cHb;SL`=SDPK6T=I7<=LWA]3@2Q0<00Dg=d
K@d`830P<21V<`de<2h`86a]3B0`86aZ3Fi`3C4f>3D^<C@`<b0e<C@g;S0a<cLP
KG@=<CDh<2hi=c@b83Hg=S4^=CPh>21/J@eTL`ebM6d=002Q0<00A7=dK@d`830P
<21V<`e^L0db<CT^=c8g=20e<C8i;S8g=34PKG@=<S8e<2hi=SLa83H`<c8^<3@g
<b1/J@eTL`ebM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=
<20`830PIS<=002Q0<00Y7=dK@d`830P<21V<`e687=Q3C8a<cH^=3T`>B0f>3Ph
;S<i>21]M0dXLVE`K65SIB1^KfAU83@Y85/f>Bhc>20a<CD^>3HP<C4e;SPf83@f
;S8h834a=Bhh=R0a<3@^<CLP<C4e;SPf83Dg;SPh834a=Bhh=R0a<CD^>3HP<C4e
;SPf834a=Bhh=R0e=bhh>20`85dPN7=XKgL=E21cH@ebM6d=0:40`004LWA]3@2Q
0<00MW=dK@d`830P<21V<`e^L0dc<C8f;S0f>C8P=SD`<Rhb>C4b86ed3C8i<cD^
<3Tg>B0f=CLa;SLc=C<PK6T=<STc=Bh`>CLi83Hd<c8^>3@g<B1/J@dc<C8f;S0f
>C8P=SD`<Rhb>C4b86aY3F=`3FAU3G9dK@d0X@3005QcM6d=<20`830PIS<=<CL^
<cHa<20a=bhc=S4`87=`3Fi`3C<`=c<^>CPf<B0f=3Tc;SHa<3LPKG@=<S<i=Rhi
<3Hb83Hd>C<^=S4`=b1/J@eTL`ebM6d=0:40`01VLgA]3C0P<20`86Hc3C<d;SLb
<S0P<c@^=c8b<21cL0da=2hc86a]3B0`86aZ3Fi`3C<b>38^<c4h=20f<3Hh;S8f
=CHPKG@==3Hc=Rhd=cPb83Hg<C0^=S8c=B1/J@eTL`ebM6d=0:40`00WLgA]3C0P
<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00?7=dK@d`830P
<21V<`e687=Q3C<`=30^<SHd<B0f<SP`;SLf<S8PKG@=:34Y821cJ6mg3E@PLf4=
LWA]3@2Q0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21c
L0d`830P<21V<`d00:40`00lLgA]3C0P<20`86Hc3DHPLf4==3Dh=Bhc>CDa83L`
<SL^<SPf<R1]M0dX<RTP87=XKgL=E21cH@ebM6d=0:40`004LWA]3@2Q0<00IW=d
K@d`830P<21V<`dc=2hg<S8`83<d;SLb<S0PLg0==C0^<21/K@dP<21/JPe^L0dc
<c<`;S0f<C8P=C0i=Rh`=3Pc86ed3C<c<c0^<3Ha<R0f<C0b;STh=cLPK6T=I7<=
LWA]3@2Q0<00IG=dK@d`830P<21V<`da=bhc=S4`834g;S<f<C0PLg0=<C@^<b1/
K@dP<21/JPe^L0de<c<`;STa>C4P=CTe=Bhd<CTPKG@=<c8i>Bhf=cTd83H`=cH^
>C@f<B1/J@eTL`ebM6d=002Q0<00F7=dK@d`830P<21V<`dc=2hg<S8`83<d;SLb
<S0PLg0=KW0==C8i=Rha>CLa83Di>34^=3H`=B1]M0dd=SDc;SPc>C8P=SLb=bhi
>3@e86aY3FAc3G9dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21c
L0d`830P<21V<`d00:40`00kLgA]3C0P<20`86Hc3DHPLf4==C@e<bhd=3Hc83Ha
<3L^<CDb86ed3BPc:B0PLfQ_M`eD87=Q3G9dK@d00:40`004LWA]3@2Q0<009g=d
K@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@3003acM6d=
<20`830PIS<=AR1cH@dc<CLi;S4e<S<P=3Tf<Bhc<S@e86ed3BP`:B0PLfQ_M`eD
87=Q3G9dK@d0X@3000AbM6d=0:40`01HLgA]3C0P<20`86Hc3C<d;SLb<S0P<c@^
=c8b<21cL0e^L0dc<SHd;STe=c@P=C4a<bhd<3Td86ed3C@f=C<^>3<i<R0f=cHb
;SL`=SDPK6T=I7<=LWA]3@2Q0<00AG=dK@d`830P<21V<`e^L0dc<SPb;S<a>3@P
=C4a<bhd<3Td86ed3CDc<C<^=CDh<B0f<34f;S4h<SDPK6T=I7<=LWA]3@00X@30
05QcM6d=<20`830PIS<=<CL^<cHa<20a=bhc=S4`87=`3Fi`3C<b=S@^>CDg=20e
<C<`;SLg<3@PKG@=<c8f=2hi=CLd83Ha<S0^<c@h=b1/J@eTL`ebM6d=0:40`013
LgA]3C0P<20`86Hc3Fi`3CDc<SH^=CLh>B0f<3@f;SDf=3<PKG@==3Hf=Rhh=R0f
>34`;S@d>C<PK6T=I7<=LWA]3@00X@3004EcM6d=<20`830PIS<=KW0=<c8i>Bhf
=cTd83Ha=CD^<3L`=b1]M0dd=SLa;S8`<38P=SLi=bhd<SPf86aY3FAc3G9dK@d0
0:40`01HLgA]3C0P<20`86Hc3C<d;SLb<S0P<c@^=c8b<21cL0e^L0de<c4c;SDe
>34P=S0a=Rha>38e86ed3C<b>CT^=SLi=20f<C<g;SL`>CLPK6T=I7<=LWA]3@2Q
0<00F7=dK@d`830P<21V<`da=bhc=S4`834g;S<f<C0PLg0=KW0=<c<c=2hd<34e
83D`>CH^<3@h<b1]M0dd=c8c;S8h<c<P=SLd=Bhc=3De86aY3FAc3G9dK@d0X@30
05AcM6d=<20`830PIS<=>2hf>30e83P^=SP`=B1cL0e^L0df=cDh;SPf<c8P=S0e
>Bhe>3Da86ed3CPa<C<^<38c83Hg<34^>C@c86aY3FAc3G9dK@d0X@3002McM6d=
<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`00lLgA]3C0P
<20`86Hc3DHPLf4==S@i=Bha<3Lg83Hb<C4^<c4h<B1]M0dX<BTP87=XKgL=E21c
H@ebM6d=0:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P<2ha<SD`
87=`3C0P<20`86Hc3@00X@3003acM6d=<20`830PIS<=AR1cH@dh<3Ld;STf<3LP
=c0d=2hf=3Lb86ed3BPb:B0PLfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=0:40`01G
LgA]3C0P<20`86Hc3C4g;S<f<C0P<CL^<cHa<21cL0e^L0dh=cHb;STg=S<P=CTe
>Bhg=CTb86ed3CHg<cL^<CHb83H`=c8^=S0e>B1/J@eTL`ebM6d=002Q0<00EW=d
K@d`830P<21V<`dh;SHh<3DP>2hf>30e87=`3Fi`3CPg<3L^=S<h<B0e>CPa;S@f
<3DPKG@=>30f=Bhb>30b83Hg<SL^>CPd=B1/J@eTL`ebM6d=0:40`00WLgA]3C0P
<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00>g=dK@d`830P
<21V<`e687=Q3CPh>C0^>C8h>20f<3Pi;SLi<B1]M0dX<bTP87=XKgL=E21cH@eb
M6d=002Q0<00179dK@d0X@3005QcM6d=<20`830PIS<=<CL^<cHa<20a=bhc=S4`
87=`3Fi`3CPg=CT^=c8a<B0e>CPe;SP`<3PPKG@=>34`<2h`<38c83Hg=3T^=SPe
>21/J@eTL`ebM6d=0:40`014LgA]3C0P<20`86Hc3Fi`3CHg<cL^<CHb83Ha<38^
>CPg=b1]M0dh<C0h;SHh<SPP=SLd=Bhc=3De86aY3FAc3G9dK@d0X@3005EcM6d=
<20`830PIS<=>2hf>30e83P^=SP`=B1cL0e^L0dh=cPe;SLf<SLP=CTi>2hh<S4e
86ed3CHg=C@^=C8c83Ha<S0^<c@h=b1/J@eTL`ebM6d=002Q0<00F7=dK@d`830P
<21V<`dc=2hg<S8`83<d;SLb<S0PLg0=KW0=>3Lc<bhf=cTf83Dh>CP^>CTe=R1]
M0df=c4i;SP`<3TP=S0b<2he<S8h86aY3FAc3G9dK@d0X@3004EcM6d=<20`830P
IS<=KW0=>3Lh=Bhg=S8g83H`<c<^=C@c=R1]M0dh<C@c;S@`=3PP=SLh<2h`=SLf
86aY3FAc3G9dK@d00:40`013LgA]3C0P<20`86Hc3Fi`3CHg<3H^=cP`<R0f<C@f
;S<i<38PKG@=>30f<2hi=20f=cPh;SLd>34PK6T=I7<=LWA]3@00X@30095cM6d=
<20`830PIS<=KW0=<c@^=c8b83<d;SLb<R0e<c4c;SDe>34P=S0a=Rha>38e86E`
3FAU3C0P<20`86Hc3C4g;S<f<C0P<CL^<cHa<21cL0de<2h`86a]3B0`86aZ3Fi`
3C<d;SLb<R0c=2hg<S8P=C<a<bhe=CPa83H`<CH^<CPb=B1UL0eTL`ebM6d=002Q
0<00L7=dK@d`830P<21V<`e^L0dc=2hg<S8P<c@^=c8b83<b>CT^=SLi=20e<C4c
;S@`>C@PIG0=I6D=<20`830PIS<=KW0=<c@^=c8b83<d;SLb<R0c<STi;SHg>C@P
=C4a<bhd<3Td86E`3FAc3G9dK@d0X@30071cM6d=<20`830PIS<=KW0=<c@^=c8b
83<d;SLb<R0c<STi;SHg>C@P=S4b<2hc=3Pg86E`3FAU3C0P<20`86Hc3Fi`3C<d
;SLb<R0c=2hg<S8P<c8i>Bhf=cTd83Ha<S0^<c@h=b1UL0eTL`ebM6d=0:40`01`
LgA]3C0P<20`86Hc3Fi`3C<d;SLb<R0c=2hg<S8P=3Hg<Bhb<30b83Hg=S8^=c0f
=B1UL0eTI@d`830P<21V<`e^L0dc=2hg<S8P<c@^=c8b83@f=c4^<S0`<R0f=cHb
;SL`=SDPIG0=I7<=LWA]3@2Q0<00LW=dK@d`830P<21V<`e^L0db=Rh`=34e83<d
;SLb<R0h<C4g;S<f<c<P=SLd=Bhc=3De86E`3FAU3C0P<20`86Hc3Fi`3C8f;S0d
<CDP<c@^=c8b83Pa<CL^<cHc<b0f=c@e;S<d=CDPIG0=I7<=LWA]3@2Q0<00L7=d
K@d`830P<21V<`e^L0dc=2hg<S8P<c@^=c8b83Pg=C4^<3@`=R0e>CTh;SPb<CDP
IG0=I6D=<20`830PIS<=KW0=<c@^=c8b83<d;SLb<R0h=cDa;S0d<3HP=CTi>2hh
<S4e86E`3FAc3G9dK@d0X@30079cM6d=<20`830PIS<=KW0=<SH^<3@a=B0c=2hg
<S8P=SLd=Bhh=38e83Ha<38^>CPg=b1UL0eTI@d`830P<21V<`e^L0db=Rh`=34e
83<d;SLb<R0f=c@e;SPd<SDP=S4`<Rhi>3Lg86E`3FAc3G9dK@d0X@3002McM6d=
<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`02TLgA]3C0P
<20`86Hc3DHPLf4==C@`<2hc=S<b83Dc=cL^>CPi86ed3BQbIG1/HF=U86i_I6DP
<2TPFcHi;S<h834a=Bhh=R0a<CD^>3HP=3H^<SPP<C4e;SPf834`=2ha=b0a<CD^
>3HP=CL^>3PP<C4e;SPf834a=Bhh=R0a<CD^>3HP<C4e;SPf83Dg;SPh830PGB1h
LfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=0:40`01fLgA]3C0P<20`86Hc3Fi`3CHd
=38^<38d=R0f=C4`;STg<CLPKG@==S8e<Bh`=C<c83He>30^=34e>21/J@df<SDa
;S0e<c<P=S@d<Bhe<SLf86aY3CHd=38^<38d=R0f=C4`;STg<CLPK6T=Hg0=I6D=
LWA]3@2Q0<00F7=dK@d`830P<21V<`da=bhc=S4`834g;S<f<C0PLg0=KW0==S<h
>Bhi=34e83He<C0^>CLa=b1]M0de=CDf;SHa<S@P=SDa<2hi=c4g86aY3FAc3G9d
K@d0X@3004EcM6d=<20`830PIS<=KW0=<SHc<bhh<S8e83L`<c@^<c@d>B1]M0db
=38e;S@i<38P=c8d<Rhf=cLa86aY3FAc3G9dK@d00:40`014LgA]3C0P<20`86Hc
3Fi`3C8d<SD^=3T`<R0g<3@f;SHb<B1]M0db=S<c;SPb<SDP=c8e=2hi=C<b86aY
3FAc3G9dK@d0X@3004EcM6d=<20`830PIS<=KW0=<c<g=Rh`<3Hb83L`<S<^=3Td
<R1]M0dc<C@c;SP`<SHP=c8e=Bhf>CLi86aY3FAc3G9dK@d00:40`01fLgA]3C0P
<20`86Hc3Fi`3C<`>C4^<c@g<B0g<C@`;S<`>3PPKG@=<ST`<2hc=cDi83Lb<3T^
=cDb>B1/J@db>C0`;S<g=CTP=c0g<2hh=S@g86aY3C<`>C4^<c@g<B0g<C@`;S<`
>3PPK6T=Hg0=I6D=LWA]3@2Q0<00AG=dK@d`830P<21V<`e^L0dc<3<i;S8f=34P
=c4d<Rhd=cPi86ed3C8f>C8^<3@c=R0g<C@b;S@g>3TPK6T=I7<=LWA]3@00X@30
04EcM6d=<20`830PIS<=KW0==CHc=Rhc=S@f83De=c0^<cDc<B1]M0de=c8c;S4f
>CLP=CHg=2he<CTb86aY3FAc3G9dK@d00:40`015LgA]3C0P<20`86Hc3Fi`3CDh
<S4^>C4`=20e=CPb;SDb>C<PKG@==CLc=Bha<3Dc83Df=ST^<c<d=21/J@eTL`eb
M6d=002Q0<00AG=dK@d`830P<21V<`e^L0de=c<`;S8b<SHP=CHg=bhf=38f86ed
3CDg<c0^<S8b=R0e=cHd;S@d=cLPK6T=I7<=LWA]3@00X@3004EcM6d=<20`830P
IS<=KW0==S@b<Bhf<SDd83De=c8^=c8h<R1]M0df=C0h;S@c<3DP=CLf<bhf>CTe
86aY3FAc3G9dK@d00:40`015LgA]3C0P<20`86Hc3Fi`3CHe>3<^=C4f>20e=CHi
;S4c=S8PKG@==S<i<Rhe=3Df83De=ST^<C<f<R1/J@eTL`ebM6d=002Q0<00A7=d
K@d`830P<21V<`e^L0df=CTi;S4d<CLP=CDf>Bhc<CTh86ed3CHd>C@^>CLe=B0e
=cH`;S8i<B1/J@eTL`ebM6d=0:40`01fLgA]3C0P<20`86Hc3Fi`3CHc<3<^<C<f
=20e=SH`;S8h<CHPKG@==S4a<Rha=SDa83Dg<ST^=c8e=b1/J@df<C4b;S4f=C4P
=CDi<2hh<cLe86aY3CHc<3<^<C<f=20e=SH`;S8h<CHPK6T=Hg0=I6D=LWA]3@2Q
0<00AG=dK@d`830P<21V<`e^L0df<SDa;S0e<c<P=CHf<2hb>34f86ed3CDi<S4^
<CTc>B0e=SH`;S8h<CHPK6T=I7<=LWA]3@00X@3006=cM6d=<20`830PIS<==2hc
=30c83@^<c@`<b1cL0da<Bhe86a]3B0`86aZ3Fi`3CDd<cD^<3Pe<R0g<SHa;SPc
=CTPKG@==SLh>Bhb=3DP=cT`=2ha>C<h86aY3FAc3G9dK@d00:40`00WLgA]3C0P
<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00?7=dK@d`830P
<21V<`e687=Q3CDa=CP^<c0h>B0g=C4c;S<i=3TPKG@=:34Y821cJ6mg3E@PLf4=
LWA]3@2Q0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21c
L0d`830P<21V<`d00:40`00lLgA]3C0P<20`86Hc3DHPLf4==SPb=2hi=SLa83Pb
=CT^>C4h>B1]M0dX<RTP87=XKgL=E21cH@ebM6d=0:40`004LWA]3@2Q0<00IG=d
K@d`830P<21V<`da=bhc=S4`834g;S<f<C0PLg0=<C@^<b1/K@dP<21/JPe^L0de
=30`;S<f<c8P=c<e=bhc<S4f86ed3CHg=C@^=C8c83Li>CT^=SLi=21/J@eTL`eb
M6d=002Q0<00Eg=dK@d`830P<21V<`dc=2hg<S8`83<d;SLb<S0PLg0=KW0==C<h
<bh`<38b83Ld<C<^=c@d>B1]M0df=c<g;S4f<R0h<3Df;S4`<SLPK6T=I7<=LWA]
3@00X@3007IcM6d=<20`830PIS<=KW0==S<b<2hd>CLd83Le<3T^<S<`=B1]M0df
=30g;S<`<SDP=c<c=Bhf<S0c86aY3CHe<C4^=3Hh=b0g=3Dg;S4d=cDPK6T==S<b
<2hd>CLd83Le<3T^<S<`=B1/J@eSL0eTI@ebM6d=0:40`01VLgA]3C0P<20`86Hc
3C4g;S<f<C0P<CL^<cHa<21cL0de<2h`86a]3B0`86aZ3Fi`3CLb<cD^<CTb>20f
=cLg;SHd<S@PKG@==S<d>Bhg>30f83Ld>3T^=3@d=21/J@eTL`ebM6d=0:40`01S
LgA]3C0P<20`86Hc3CP^=SP`=B0h;SHh<3DPLg0=<C@^<b1/K@dP<21/JPe^L0de
=3<e;S0h=C8P=c<a>2hb=CTc86ed3CHg>3T^<S@e83Li=S0^=S4g<B1/J@eTL`eb
M6d=002Q0<00UG=dK@d`830P<21V<`e^L0db=Rh`=34e838f;S0d<CDP=SLh<2he
=S@e83Li>3H^=SDh=b1UL0eTI@d`830P<21V<`da=bhc=S4`834g;S<f<C0PLg0=
=C0^<21/K@dP<21/JPe^L0db=Rh`=34e838f;S0d<CDP=SLh<2he=S@e83Li>3H^
=SDh=b1UL0eTL`ebM6d=002Q0<00LW=dK@d`830P<21V<`e^L0db=Rh`=34e83<d
;SLb<R0e=30i;S0d<cLP=c<e<Rhi>34c86E`3FAU3C0P<20`86Hc3Fi`3C8f;S0d
<CDP<c@^=c8b83Dd<3T^<3@c=b0g<cDb;STh<C<PIG0=I7<=LWA]3@2Q0<009g=d
K@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@300:EcM6d=
<20`830PIS<=AR1cH@df>CHb;SPe=C<P=c<c>Bhg>3@f86ed3BQbIG1/HF=U86i_
I6DP<bTPFcHi;S<h834a=Bhh=R0a<CD^>3HP=3H^<SPP<C4e;SPf834`=2ha=b0a
<CD^>3HP=CL^>3PP<C4e;SPf834a=Bhh=R0a<CD^>3HP<C4e;SPf83Dg;SPh830P
GB1hLfQ_M`eD87=Q3G9dK@d00:40`004LWA]3@2Q0<00F7=dK@d`830P<21V<`da
=bhc=S4`834g;S<f<C0PLg0=KW0==c<a<2h`=cDg83Le<SH^=CTa=B1]M0dg<c4`
;S0g=CLP=cHa<bhc>CHg86aY3FAc3G9dK@d0X@3004EcM6d=<20`830PIS<=KW0=
=c<a<2h`=cDg83Lf<c0^=cDg=b1]M0dg<c4`;S0g=CLP=cLa=bhe=S8h86aY3FAc
3G9dK@d00:40`01fLgA]3C0P<20`86Hc3Fi`3CLh=3P^<SHg=20g=S4a;S8b=SDP
KG@==cHe=bhb>CHb83Lf>30^=SL`=R1/J@dg=SDg;S8i=S8P=cDd<Bhg>38d86aY
3CLh=3P^<SHg=20g=S4a;S8b=SDPK6T=Hg0=I6D=LWA]3@2Q0<00AG=dK@d`830P
<21V<`e^L0dg=3Hf;S<b=3TP=cHa<bhc>CHg86ed3CLg>CH^<CPd=20g=S4c;S<i
=SLPK6T=I7<=LWA]3@00X@3004EcM6d=<20`830PIS<=KW0==cTh=bha=CDf83Le
<3T^<S<`=B1]M0dg>CPg;S4e=CHP=cHa<bhc>CHg86aY3FAc3G9dK@d00:40`015
LgA]3C0P<20`86Hc3Fi`3CLi>3L^<CDe=R0g=S4c;S<i=SLPKG@==cTh=bha=CDf
83Lg<30^<S0a>21/J@eTL`ebM6d=002Q0<009g=dK@d`830P<21V<`d`;S4b=C0P
<2ha<SD`87=`3C0P<20`86Hc3@00X@300OYcM6d=<S0h;S<c<S<PIWAc3BmOGem6
CS<]<B1SMW=V3C0P<20`86Hc3DHPLf4=<CPe<Rhi<cLa834f<2hd<C<f86ed3BQB
IFAeHgAYKfhPKfHPHB1>IGAgKg9[86mV84=QL65SJGAYIG<PMfUdJ20e84i_I6Ec
85`X<2ddG2TY85/a=C0^=3DP<C4e;SPf834b=bhb=R0a<SL^<SHP<C4e;SPf83Hi
;S<h83Dg;SPh834b=bhb=R0a<SL^<SHP=CL^>3PP<C8g;S8f83Hi;S<h83Dg;SPh
834a=Bhh=R0e=bhh>20a=C0^=3DP<C4e;SPf83Hi;S<h834f<Rh`=B0=<C8g;S8f
83Pa;S0g834a=Bhh=R0e=bhh>20a<SL^<SHP=ST^<cPP=CL^>3PP<CD`;S@e834a
=Bhh=R0a<SL^<SHP<C4e;SPf834a=Bhh=R0e=bhh>20f>Bhc>20e=bhh>20a<CD^
>3HP<C4e;SPf83Dg;SPh834f<Rh`=B0e=bhh>20f>Bhc>20a<SL^<SHP=CL^>3PP
<C4e;SPf83Dg;SPh80da=C0^=3DP<C8g;S8f834b=bhb=R0a<CD^>3HP<C4e;SPf
83Dg;SPh83Hi;S<h834a=Bhh=R0f>Bhc>20a<CD^>3HP<21M87QcJ6mg3E@PLf4=
LWA]3@2Q0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21c
L0d`830P<21V<`d00:40`01FLgA]3C8`>2hc<c8c86IdL`d_GemOAThc86=fLfH=
<20`830PIS<=AR1cH@dd<S4e;S0c=S<P<cTb=bhg=CDe86ed3BP`:B0PLfQ_M`eD
87=Q3G9dK@d0X@3000AbM6d=0:40`023LgA]3C0P<20`86Hc3Fi`3C<d;SLb<R0c
=2hg<S8P<S@a>2hf<3Le83L`<cP^<c4b>21UL0eTI@d`830P<21V<`da=bhc=S4`
834g;S<f<C0PLg0=KW0=<c@^=c8b83<d;SLb<R0b=34h;SH`=cDP=c0c>2hc<C8h
86E`3FAc3G9dK@d00:40`01^LgA]3C0P<20`86Hc3Fi`3C<d;SLb<R0c=2hg<S8P
<SDb<Rhg=c<f83La=3@^=S@i86E`3FAU3C0P<20`86Hc3Fi`3C<d;SLb<R0c=2hg
<S8P<SDb<Rhg=c<f83La=3@^=S@i86E`3FAc3G9dK@d0X@3006icM6d=<20`830P
IS<=KW0=<c@^=c8b83<d;SLb<R0e=S<`;S<i=SPP=CDf=2hg>CHPIG0=I6D=<20`
830PIS<=KW0=<c@^=c8b83<d;SLb<R0e=S<`;S<i=SPP=CDf=2hg>CHPIG0=I7<=
LWA]3@2Q0<00KW=dK@d`830P<21V<`e^L0dc=2hg<S8P<c@^=c8b83Dh<SL^>3Lh
=20e=CHd;SLi=R1UL0eTI@d`830P<21V<`e^L0dc=2hg<S8P<c@^=c8b83Dh<SL^
>3Lh=20e=CHd;SLi=R1UL0eTL`ebM6d=0:40`01`LgA]3C0P<20`86Hc3Fi`3C<d
;SLb<R0c=2hg<S8P=c<a<2h`=cDg83Le<3T^<S<`=B1UL0eTI@d`830P<21V<`e^
L0dc=2hg<S8P<c@^=c8b83Lc<C0^<3Le=b0g=C0i;S8c<3DPIG0=I7<=LWA]3@2Q
0<00L7=dK@d`830P<21V<`e^L0dc=2hg<S8P<c@^=c8b83Lc<C0^<3Le=b0g=S4c
;S<i=SLPIG0=I6D=<20`830PIS<=KW0=<c@^=c8b83<d;SLb<R0g<c4`;S0g=CLP
=cHa<bhc>CHg86E`3FAc3G9dK@d0X@30071cM6d=<20`830PIS<=KW0=<c@^=c8b
83<d;SLb<R0g<c4`;S0g=CLP=cLa=bhe=S8h86E`3FAU3C0P<20`86Hc3Fi`3C<d
;SLb<R0c=2hg<S8P=c<a<2h`=cDg83Lg<CL^=CHb>21UL0eTL`ebM6d=0:40`01`
LgA]3C0P<20`86Hc3Fi`3C<d;SLb<R0c=2hg<S8P=cTh=bha=CDf83Le<3T^<S<`
=B1UL0eTI@d`830P<21V<`e^L0dc=2hg<S8P<c@^=c8b83Li>3L^<CDe=R0g=C0i
;S8c<3DPIG0=I7<=LWA]3@2Q0<00DG=dK@d`830P<21V<`da=2hc86a]3B0`86aZ
3Fi`3C<c<CL^<3@`=20e<3He;SHf=SDPKG@==C<f<2hb<CDh83Di=c8^=cPPK6T=
I7<=LWA]3@00X@3009UcM6d=<20`830PIS<=KW0=<C<`;S8`=cLP<C8a;SDb=c8P
<CLb>2he<3Hh83Da=SD^=3Tb=21UL0eTI@d`830P<21V<`dc=2hg<S8`83<d;SLb
<S0PLg0==C0^<21/K@dP<21/JPe^L0da<c0^<S0g=b0a<S4^=C8g<R0a=c8h;SD`
=SPP=C4f=Bhd>C8d86E`3FAc3G9dK@d00:40`01hLgA]3C0P<20`86Hc3Fi`3C4c
<2hb<3Lg834b<Bhe<SLb838b<c4^>CLf=B0f<3<c;SDd<cHPIG0=I6D=<20`830P
IS<=KW0=<C<`;S8`=cLP<C8a;SDb=c8P<S8c<Bhi=cHe83H`<c<^=C@c=R1UL0eT
L`ebM6d=0:40`01hLgA]3C0P<20`86Hc3Fi`3C4c<2hb<3Lg834b<Bhe<SLb834f
<3H^>CLi=b0f=cHb;SL`=SDPIG0=I6D=<20`830PIS<=KW0=<C<`;S8`=cLP<C8a
;SDb=c8P<CH`=Rhi=cTg83Hg=S8^=c0f=B1UL0eTL`ebM6d=0:40`01fLgA]3C0P
<20`86Hc3Fi`3C4c<2hb<3Lg834b<Bhe<SLb838h=bhe=34i83Ha<cL^=c0i=b1U
L0eTI@d`830P<21V<`e^L0da<c0^<S0g=b0a<S4^=C8g<R0b>3L^=C@a>B0f<C<g
;SL`>CLPIG0=I7<=LWA]3@2Q0<00N7=dK@d`830P<21V<`e^L0da<c0^<S0g=b0a
<S4^=C8g<R0c<c0h;S<e>CTP=C4c<2hg=c0d86E`3FAU3C0P<20`86Hc3Fi`3C4c
<2hb<3Lg834b<Bhe<SLb83<c<3P^<cDi>B0e<C<`;SLg<3@PIG0=I7<=LWA]3@2Q
0<00N7=dK@d`830P<21V<`e^L0da<c0^<S0g=b0a<S4^=C8g<R0e<SPg;SDa=SHP
=CTi>2hh<S4e86E`3FAU3C0P<20`86Hc3Fi`3C4c<2hb<3Lg834b<Bhe<SLb83Db
>3L^=C4f=R0e>CTh;SPb<CDPIG0=I7<=LWA]3@2Q0<00N7=dK@d`830P<21V<`e^
L0da<c0^<S0g=b0a<S4^=C8g<R0d=SHb;SDa>CLP=SLb=bhi>3@e86E`3FAU3C0P
<20`86Hc3Fi`3C4c<2hb<3Lg834b<Bhe<SLb83@f=S8^=C4i=b0f=c8g;STh=3DP
IG0=I7<=LWA]3@2Q0<00N7=dK@d`830P<21V<`e^L0da<c0^<S0g=b0a<S4^=C8g
<R0c<c0h;S<e>CTP=S4`<Rhi>3Lg86E`3FAU3C0P<20`86Hc3Fi`3C4c<2hb<3Lg
834b<Bhe<SLb83<c<3P^<cDi>B0f<C0b;STh=cLPIG0=I7<=LWA]3@2Q0<00N7=d
K@d`830P<21V<`e^L0da<c0^<S0g=b0a<S4^=C8g<R0f=c@e;SPd<SDP=S0h=Bhf
<SHf86E`3FAU3C0P<20`86Hc3Fi`3C4c<2hb<3Lg834b<Bhe<SLb83Hg=3D^>3@b
=B0f<3Pe;SHb=SHPIG0=I7<=LWA]3@2Q0<00N7=dK@d`830P<21V<`e^L0da<c0^
<S0g=b0a<S4^=C8g<R0h=c8d;STi>C4P=CTi>2hh<S4e86E`3FAU3C0P<20`86Hc
3Fi`3C4c<2hb<3Lg834b<Bhe<SLb83Pg<S@^>CTi<B0e>CTh;SPb<CDPIG0=I7<=
LWA]3@2Q0<00N7=dK@d`830P<21V<`e^L0da<c0^<S0g=b0a<S4^=C8g<R0h<C4g
;S<f<c<P=SLb=bhi>3@e86E`3FAU3C0P<20`86Hc3Fi`3C4c<2hb<3Lg834b<Bhe
<SLb83Pa<CL^<cHc<b0f=c8g;STh=3DPIG0=I7<=LWA]3@2Q0<00N7=dK@d`830P
<21V<`e^L0da<c0^<S0g=b0a<S4^=C8g<R0e=3@c;SLf=CPP=c<e<Rhi>34c86E`
3FAU3C0P<20`86Hc3Fi`3C4c<2hb<3Lg834b<Bhe<SLb83Dd=3<^=cHe>20g<cDb
;STh<C<PIG0=I7<=LWA]3@2Q0<00N7=dK@d`830P<21V<`e^L0da<c0^<S0g=b0a
<S4^=C8g<R0f=c@e;SPd<SDP=cTg=bhi=cPa86E`3FAU3C0P<20`86Hc3Fi`3C4c
<2hb<3Lg834b<Bhe<SLb83Hg=3D^>3@b=B0g>CLg;STg>34PIG0=I7<=LWA]3@2Q
0<00Qg=dK@d`830P<21V<`e^L0dd<bhd<38f83@c;S@`<SHP=34e<bhb=c8g83<g
<CT^=CTi<R1UL0eTI@d`830P<21V<`da=bhc=S4`834g;S<f<C0PLg0=KW0==3<^
=30b=R0d<bhd<38f83@a=C<^<SLb=b0c=c4i;SDi>C8PIG0=I7<=LWA]3@00X@30
079cM6d=<20`830PIS<=KW0=<SH^<3@a=B0b=Rh`=34e83Da=38^>3Da83<g<S<^
>C<i=21UL0eTI@d`830P<21V<`e^L0db=Rh`=34e838f;S0d<CDP=C4d<Rhh=C4P
<cLb<bhi<cTd86E`3FAc3G9dK@d0X@3007AcM6d=<20`830PIS<=KW0=<SH^<3@a
=B0b=Rh`=34e83Ha<CT^=30h=B0c=c8c;STc>C@PIG0=I6D=<20`830PIS<=KW0=
<SH^<3@a=B0b=Rh`=34e83Ha<CT^=30h=B0c=c8c;STc>C@PIG0=I7<=LWA]3@2Q
0<00M7=dK@d`830P<21V<`e^L0dd<bhd<38f83@c;S@`<SHP=34e<bhb=c8g838g
=3L^<cPa>B1UL0eTI@d`830P<21V<`e^L0dd<bhd<38f83@c;S@`<SHP=34e<bhb
=c8g838g=3L^<cPa>B1UL0eTL`ebM6d=0:40`01bLgA]3C0P<20`86Hc3Fi`3C8f
;S0d<CDP<SH^<3@a=B0c<CHh;S0c=3HP<CT`<Bh`<c8PIG0=I6D=<20`830PIS<=
KW0=<SH^<3@a=B0b=Rh`=34e83<a=SP^<3<d=R0a>C0a;S0c<R1UL0eTL`ebM6d=
0:40`01dLgA]3C0P<20`86Hc3Fi`3C8f;S0d<CDP<SH^<3@a=B0f<C4e;S0f>3<P
<CLd<2hd=38f86E`3FAU3C0P<20`86Hc3Fi`3C8f;S0d<CDP<SH^<3@a=B0f<C4e
;S0f>3<P<CLd<2hd=38f86E`3FAc3G9dK@d0X@30071cM6d=<20`830PIS<=KW0=
<c@^=c8b83<d;SLb<R0b=34h;SH`=cDP=c8d<Rhc<3@h86E`3FAU3C0P<20`86Hc
3Fi`3C<d;SLb<R0c=2hg<S8P<S@a>2hf<3Le83Lb=38^<c0d>21UL0eTL`ebM6d=
0:40`01`LgA]3C0P<20`86Hc3Fi`3C<d;SLb<R0c=2hg<S8P<SHb>Bha<3Ti83Lb
=38^<c0d>21UL0eTI@d`830P<21V<`e^L0dc=2hg<S8P<c@^=c8b838f<ST^<C0i
>B0g<S@b;S<`=3PPIG0=I7<=LWA]3@2Q0<00L7=dK@d`830P<21V<`e^L0dc=2hg
<S8P<c@^=c8b838f<ST^<C0i>B0g<3<h;S<a<SPPIG0=I6D=<20`830PIS<=KW0=
<c@^=c8b83<d;SLb<R0b=S8i;S4`>CTP=c0c>2hc<C8h86E`3FAc3G9dK@d0X@30
04EcM6d=<20`830PIS<=KW0=<c<g>Bhf<34h83Lb=CD^=STg>B1]M0dc<C@g;S<i
>34P=c0b<bhd>C@b86aY3FAc3G9dK@d00:40`01`LgA]3C0P<20`86Hc3Fi`3C<d
;SLb<R0c=2hg<S8P<c4d<Bhb=S0a83Lb=CD^<c8e=R1UL0eTI@d`830P<21V<`e^
L0dc=2hg<S8P<c@^=c8b83<a=34^<SH`<B0g<SDe;S<b=CHPIG0=I7<=LWA]3@2Q
0<00L7=dK@d`830P<21V<`e^L0dc=2hg<S8P<c@^=c8b83<c=cT^>CLd<R0g<SDe
;S<b=CHPIG0=I6D=<20`830PIS<=KW0=<c@^=c8b83<d;SLb<R0c<cLi;STg=38P
=c8e=Bhc<SDf86E`3FAc3G9dK@d0X@30071cM6d=<20`830PIS<=KW0=<c@^=c8b
83<d;SLb<R0c<cLi;STg=38P=c0a>2hg>34f86E`3FAU3C0P<20`86Hc3Fi`3C<d
;SLb<R0c=2hg<S8P<c<g>Bhi=c@b83L`<CP^=cPa=R1UL0eTL`ebM6d=0:40`01/
LgA]3C0P<20`86Hc3Fi`3C<d;SLb<R0c=2hg<S8P<c4c>Bh`>B0g<34h;SLh<CHP
IG0=I6D=<20`830PIS<=KW0=<c@^=c8b83<d;SLb<R0c<C<i;S0i83L`<CP^=cPa
=R1UL0eTL`ebM6d=0:40`01^LgA]3C0P<20`86Hc3Fi`3C<d;SLb<R0c=2hg<S8P
=CLb>Bha<cLf83Df=SH^=cTb86E`3FAU3C0P<20`86Hc3Fi`3C<d;SLb<R0c=2hg
<S8P=CLb>Bha<cLf83Df=SH^=cTb86E`3FAc3G9dK@d0X@30071cM6d=<20`830P
IS<=KW0=<c@^=c8b83<d;SLb<R0e=c<b;S<i<SPP=CLh<bhi=cPi86E`3FAU3C0P
<20`86Hc3Fi`3C<d;SLb<R0c=2hg<S8P=CLc<Rhc>C8h83Dg>3<^>CLh>B1UL0eT
L`ebM6d=0:40`01^LgA]3C0P<20`86Hc3Fi`3C<d;SLb<R0c=2hg<S8P=S@a=Bhi
>3<P=CDf=Rhi=SHa86E`3FAU3C0P<20`86Hc3Fi`3C<d;SLb<R0c=2hg<S8P=S@a
=Bhi>3<P=CDf=Rhi=SHa86E`3FAc3G9dK@d0X@30071cM6d=<20`830PIS<=KW0=
<c@^=c8b83<d;SLb<R0f=CTf;S4`<c4P=CDf=Rhi=SHa86E`3FAU3C0P<20`86Hc
3Fi`3C<d;SLb<R0c=2hg<S8P=SDi=Rha<3<a83De=SH^>CHf<B1UL0eTL`ebM6d=
0:40`01`LgA]3C0P<20`86Hc3Fi`3C<d;SLb<R0c=2hg<S8P=SD`=Rh`=3<a83Dg
=C<^=CTg<B1UL0eTI@d`830P<21V<`e^L0dc=2hg<S8P<c@^=c8b83He<3H^<3@c
<B0e=cDc;SDi=c4PIG0=I7<=LWA]3@2Q0<00L7=dK@d`830P<21V<`e^L0dc=2hg
<S8P<c@^=c8b83Li>3L^<CDe=R0g=STe;SPf<CDPIG0=I6D=<20`830PIS<=KW0=
<c@^=c8b83<d;SLb<R0g>CPg;S4e=CHP=cHi=Bhh=S4e86E`3FAc3G9dK@d0X@30
00YdIG9]JFiQM6D=0:00_`2P0;h0VP000?n?X0000003j0?X000010000000B000
04P0000@02000`08000000000002a?Z0000000?X0nP000000nX3j`000321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0KX7oPOn1ok[oj`36ooX0/?oj08_onP35ooT0looj087omOoj087o
POn1ok;oj`36ooX0/?oj08_onP35ooT0looj087omOoj087oPOn1ok;oj`36ooX0
/?oj08_onP35ooT0looj087omOoj0?Wo06j1oh7oPOnjonP0bOoj0;3onP2=ooP0
aOoh0?ConP21ooGonP21oh7oPOnbonP0bOoj0;3onP2=ooP0aOoh0?ConP21ooGo
nP21oh7oPOnbonP0bOoj0;3onP2=ooP0aOoh0?ConP21ooGonP3io`1^POn1oh7o
^_oW0<[onP2`ooX0S_og0<Gon03dooX0POoeooX0POn1oh7o/_oW0<[onP2`ooX0
S_og0<Gon03dooX0POoeooX0POn1oh7o/_oW0<[onP2`ooX0S_og0<Gon03dooX0
POoeooX0nOl0P87oPOn1ok[oiP3;ooX0`?oj0?SonP2>ooL0aOog0?GonP3NooX0
Wooj087oPOn1ok;oiP3;ooX0`?oj0?SonP2>ooL0aOog0?GonP3NooX0Wooj087o
POn1ok;oiP3;ooX0`?oj0?SonP2>ooL0aOog0?GonP3NooX0Wooj0?Wo0821oh7o
POnjonD0c?oj0<3onP3hooX0Soof0<Gom`3eooX0g_oj09oonP21oh7oPOnbonD0
c?oj0<3onP3hooX0Soof0<Gom`3eooX0g_oj09oonP21oh7oPOnbonD0c?oj0<3o
nP3hooX0Soof0<Gom`3eooX0g_oj09oonP3io`20POn1oh7o^_oT0<gonP30ooX0
n?oj08oomP35ooH0m_oj0=konP2OooX0POn1oh7o/_oT0<gonP30ooX0n?oj08oo
mP35ooH0m_oj0=konP2OooX0POn1oh7o/_oT0<gonP30ooX0n?oj08oomP35ooH0
m_oj0=konP2OooX0nOl0RH7oPOn1ok[on@3eooP0cOoj0<3onP21o`7oooX0`Ooe
0?OonP3NooX0Wooj087oPOn1ok;on@3eooP0cOoj0<3onP21o`7oooX0`Ooe0?Oo
nP3NooX0Wooj087oPOn1ok;on@3eooP0cOoj0<3onP21o`7oooX0`Ooe0?OonP3N
ooX0Wooj0?Wo08V1oh7oPOnjooT0m?oh0<konP30ooX0POl1oooj0<7om@3gooX0
g_oj09oonP21oh7oPOnbooT0m?oh0<konP30ooX0POl1oooj0<7om@3gooX0g_oj
09oonP21oh7oPOnbooT0m?oh0<konP30ooX0POl1oooj0<7om@3gooX0g_oj09oo
nP3io`29POn1oh7o^_oi0??on@3>ooX0`?oj087o0OoonP31oo@0n?oj0=konP2O
ooX0POn1oh7o/_oi0??on@3>ooX0`?oj087o0OoonP31oo@0n?oj0=konP2OooX0
POn1oh7o/_oi0??on@3>ooX0`?oj087o0OoonP31oo@0n?oj0=konP2OooX0nOl1
F87oPOn1ok[on@3cooT0m?oi0>konP3mooX0nooj0?OonP3cooT0n?ob0?conP3c
ooP0l_oj0?con`3PooP0mOob0>Won@3Uoo@0n?oj0??on@3hoo80o_oj0?WonP3i
ooX0mOoh0?ConP3mood0o?oj087oPOn1ok;on@3cooT0m?oi0>konP3mooX0nooj
0?OonP3cooT0n?ob0?conP3cooP0l_oj0?con`3PooP0mOob0>Won@3Uoo@0n?oj
0??on@3hoo80o_oj0?WonP3iooX0mOoh0?ConP3mood0o?oj087oPOn1ok;on@3c
ooT0m?oi0>konP3mooX0nooj0?OonP3cooT0n?ob0?conP3cooP0l_oj0?con`3P
ooP0mOob0>Won@3Uoo@0n?oj0??on@3hoo80o_oj0?WonP3iooX0mOoh0?ConP3m
ood0o?oj0?Wo0E^1oh7oPOnjooT0looi0?Ool`3cooH00OoonP3kooX0mooj0?Ko
l`3koo80o?oj0?Gom03dooX0o_og0>Com03goo80k?oc0>Sol`3iooX0m_oc0?_o
lP3nooX0nOoj0?WonP3goo@0m_oj0?koo03looX0POn1oh7o/_oi0??on@3goo<0
loof007oooX0nooj0?OonP3foo<0noob0?conP3eoo@0m?oj0?kom`3Too@0moob
0>col`3Xoo<0nOoj0?Kol`3koo80o_oj0?WonP3iooX0mood0?KonP3noo`0o?oj
087oPOn1ok;on@3cooT0mooc0??omP01oooj0?_onP3gooX0m_oc0?_olP3looX0
mOod0?ConP3nooL0i?od0?OolP3/oo<0j?oc0?WonP3foo<0noob0?konP3iooX0
nOoj0?Oom03fooX0o_ol0?conP3io`5dPOn1oh7o^_oi0??on@3hoo40mOod003o
nP3kooX0mooj0?Ool03moo80o?oj0?Ool03fooX00Ooom03Xoo00nOob0>gol03Z
ooX00?ok0?WonP3goo40o?ob0?konP3jooP0n_oj0?Wol03hooX00Ooon`3looX0
n_l0087oPOn1ok[on@3cooT0n?oa0?Gom000ooX0nooj0?OonP3goo00oOob0?co
nP3goo00m_oj007ooo@0j?o`0?WolP3]oo00j_oj003on`3iooX0mooa0?colP3n
ooX0n_oh0?[onP3ioo00n?oj007ooo/0o?oj0?[o0021oh7oPOnjooT0looi0?So
l@3eoo@00?oj0?_onP3gooX0moo`0?golP3looX0moo`0?KonP01oood0>Sol03i
oo80kOo`0>[onP00oo/0nOoj0?Ool@3loo80o_oj0?[on03jooX0nOo`0?SonP01
oook0?conP3jo`000FF1oh7oPOnjooT0looi0?Wok`3gon/0nooj0?OonP3honh0
o_ob0?conP3honh0mooj003olP3Zonh0n_ob0>kokP3[ooX00?oj0?[onP3honl0
oOob0?konP3jooP0n_oj0?[okP3iooX00?oj0?conP3ko`40087oPOn1ok[on@3c
ooT0nOo_0?Ooj`3kooX0mooj0?SokP3noo80o?oj0?SokP3gooX00?ob0>[okP3j
oo80k_o^0>_onP00ooX0n_oj0?Sok`3moo80o_oj0?[on03jooX0n_o^0?WonP00
ooX0o?oj0?_o0@00POn1oh7o^_oi0??on@3ionl0moo[0?_onP3gooX0n?o^0?ko
lP3looX0n?o^0?OonP00oo80j_o^0?[olP3^onh0jooj003onP3jooX0n?o_0?go
lP3nooX0n_oh0?[onP3jonh0nOoj003onP3looX0nol10001CH7oPOn1ok[on@3c
ooX0nOo]0?WojP3kooX0mooj0?Wok@3noo80o?oj0?Wok03honX0joo/0?_olP3_
ond0jooj007oooX0nooj0?Wok@3noo80oOok0?[on03joo/0n_o/0?[olP3looX0
o?on087oPOn1ok[on@3cooX0nOo]0?WojP3kooX0mooj0?Wok@3noo80o?oj0?Wo
k03honX0joo/0?_olP3_ond0jooj007oooX0nooj0?Wok@3noo80oOok0?[on03j
oo/0n_o/0?[olP3looX0o?on087oPOn1ok[on@3cooX0nOo]0?WojP3kooX0mooj
0?Wok@3noo80o?oj0?Wok03honX0joo/0?_olP3_ond0jooj007oooX0nooj0?Wo
k@3noo80oOok0?[on03joo/0n_o/0?[olP3looX0o?on005CPOn1oh7o^_oi0?Co
n@3jon/0nooY0?_onP3gooX0n_o[007ooo80o?oj0?[ojP3ionT0kOoZ0?colP3_
on`0k?oj007oooX0nooj0?[oj`01ooob0?gonP3kooP0nooj0?_ojP3koo80o?oj
0?goo@21oh7oPOnjooT0m?oi0?[oj`3konT0nooj0?OonP3jon/00OoolP3looX0
n_oZ0?Woj@3]onX0o?ob0>ook03/ooX00OoonP3kooX0n_o[007ooo80oOoj0?_o
n03kooX0nooZ0?_olP3looX0oOom087oPOn1ok[on@3dooT0n_o[0?_oj@3kooX0
mooj0?[oj`01ooob0?conP3jonX0nOoY0>gojP3loo80koo/0>conP01oooj0?_o
nP3jon/00OoolP3mooX0nooh0?_onP3konX0noob0?conP3mood00KJ1oh7oPOnj
ooT0mOoh0?[on@3kooT0nooh0?gomP3kooX0mooj0?[on@3kooT0nooj0?SonP3j
ooP0o?oh0?Wom`3looP0kOoh0?con03hooX0jooi0?con@3/ooX0o_oj0?conP3j
ooT0nooi0?_onP3iooX0nooh0?_onP3kooP0o?oh0?_olP3looX0oOom087oPOn1
ok[on@3eooP0n_oi0?_on@3kooP0oOof0?_onP3gooX0n_oi0?_on@3kooX0n?oj
0?[on03looP0nOog0?con03]ooP0o?oh0?SonP3[ooT0o?oi0>conP3nooX0o?oj
0?[on@3kooT0nooj0?WonP3kooP0nooj0?_on03looP0noob0?conP3mood0POn1
oh7o^_oi0?Gon03jooT0nooi0?_on03mooH0nooj0?OonP3jooT0nooi0?_onP3h
ooX0n_oh0?con03iooL0o?oh0>gon03looP0n?oj0>_on@3looT0k?oj0?konP3l
ooX0n_oi0?_on@3kooX0nOoj0?_on03kooX0nooh0?con03koo80o?oj0?goo@01
]X7oPOn1ok[oi@3jooT0nOoi0?gon@3iooP0nooj0?OonP3kooT0nOoi0?conP3h
ooX0nooi0?Son@3jooP0n_oi0>kon@3hooT0nOoj0>con@3jooX0k?oj0?konP3l
ooX0nooi0?Won@3looX0nOoj0?coo000oo`0o?oj0?con@3hooT0o?og0?OonP3n
oo`0POn1oh7o^_oU0?[on@3iooT0oOoi0?Won03kooX0mooj0?_on@3iooT0o?oj
0?SonP3kooT0n?oi0?[on03jooT0k_oi0?Son@3iooX0k?oi0?[onP3/ooX0o_oj
0?conP3kooT0nOoi0?conP3iooX0o?ol003oo03looX0o?oi0?Son@3looL0mooj
0?koo021oh7oPOnjonD0n_oi0?Won@3mooT0nOoh0?_onP3gooX0nooi0?Won@3l
ooX0n?oj0?_on@3hooT0n_oh0?[on@3^ooT0n?oi0?WonP3/ooT0n_oj0>conP3n
ooX0o?oj0?_on@3iooT0o?oj0?WonP3loo`00?ol0?conP3looT0n?oi0?com`3g
ooX0o_ol006iPOn1oh7o^_oV0?WonP3gooX0oOoj0?Oon@3kooX0mooj0?_onP3g
ooX0o?oj0?SonP3kooX0m_oj0?[on@3hooX0k_oj0?KonP3iooX0k?oj0?WonP3/
ooX0oOoj0?gonP3kooX0mooj0?conP3hoo/0o?ol003oo03loo/0nooj0?KonP3l
ooP0m_oj007ooo/0POn1oh7o^_oV0?WonP3gooX0oOoj0?Oon@3kooX0mooj0?_o
nP3gooX0o?oj0?SonP3kooX0m_oj0?[on@3hooX0k_oj0?KonP3iooX0k?oj0?Wo
nP3/ooX0oOoj0?gonP3kooX0mooj0?conP3hoo/0o?ol003oo03loo/0nooj0?Ko
nP3looP0m_oj007ooo/0POn1oh7o^_oV0?WonP3gooX0oOoj0?Oon@3kooX0mooj
0?_onP3gooX0o?oj0?SonP3kooX0m_oj0?[on@3hooX0k_oj0?KonP3iooX0k?oj
0?WonP3/ooX0oOoj0?gonP3kooX0mooj0?conP3hoo/0o?ol003oo03loo/0nooj
0?KonP3looP0m_oj007ooo/00KJ1oh7oPOnjonP0n?oj0?Gon`3mooX0mooi0?_o
nP3gooX0nooj0?OonP3looX0n?oj0?_onP3fooX0n_oj0?OonP3^ooX0m_oj0?Wo
nP3/ooX0nOoj0>conP3loo/0oOoj0?conP3eoo/0o?oj0?Son`3loo`00?ol0?co
n`3kooX0m_oj0?con@3eooX00?oj087oPOn1ok[oj03hooX0mOok0?gonP3gooT0
nooj0?OonP3kooX0mooj0?conP3hooX0nooj0?KonP3jooX0mooj0>konP3fooX0
nOoj0>conP3iooX0k?oj0?con`3mooX0o?oj0?Gon`3looX0n?ok0?coo000oo`0
o?ok0?_onP3fooX0o?oi0?GonP00ooX0POn1oh7o^_oX0?SonP3eoo/0oOoj0?Oo
n@3kooX0mooj0?_onP3gooX0o?oj0?SonP3kooX0m_oj0?[onP3gooX0k_oj0?Ko
nP3iooX0k?oj0?WonP3/ooX0o?ok0?gonP3looX0mOok0?conP3hoo/0o?ol003o
o03loo/0nooj0?KonP3looT0mOoj003onP01UH7oPOn1ok[oj03hooX0mOoj007o
ooX0mOoj0?_onP3gooX0o?oj0>[onP3hooX0o?oj0?ConP3kooX0mooj0>oonP3d
ooX0n_oj0=kon@3/ooX0o?oj0?konP3looX0mOoj0?gonP3hooX0oOol003oo03m
ooX0o?oj0?ConP3mooX0m?ob087oPOn1ok[oj03hooX0mOoj007oooX0mOoj0?_o
nP3gooX0o?oj0>[onP3hooX0o?oj0?ConP3kooX0mooj0>oonP3dooX0n_oj0=ko
n@3/ooX0o?oj0?konP3looX0mOoj0?gonP3hooX0oOol003oo03mooX0o?oj0?Co
nP3mooX0m?ob087oPOn1ok[oj03hooX0mOoj007oooX0mOoj0?_onP3gooX0o?oj
0>[onP3hooX0o?oj0?ConP3kooX0mooj0>oonP3dooX0n_oj0=kon@3/ooX0o?oj
0?konP3looX0mOoj0?gonP3hooX0oOol003oo03mooX0o?oj0?ConP3mooX0m?ob
005mPOn1oh7o^_oV0?[oi`01oooj0?GonP3kooX0mooj0?conP3ZooX0n?oj0?co
nP3dooX0nooj0?OonP3_ooX0m?oj0?[onP3RooD0k?oj0?_on`3nooX0o?oW0?go
nP3hooX0o_ok003on`3noo/0nooj0?ConP3mooX0m?ob087oPOn1ok[oiP3jonL0
0OoonP3eooX0nooj0?OonP3looX0j_oj0?SonP3looX0m?oj0?_onP3gooX0kooj
0?ConP3jooX0h_oe0>conP3koo/0o_oj0?coi`3mooX0n?oj0?kon`00oo/0o_ok
0?_onP3dooX0oOoj0?ColP21oh7oPOnjonH0n_oW007oooX0mOoj0?_onP3gooX0
o?oj0>[onP3hooX0o?oj0?ConP3kooX0mooj0>oonP3dooX0n_oj0>;om@3/ooX0
nook0?konP3lonL0oOoj0?SonP3noo/00?ok0?kon`3kooX0m?oj0?gonP3doo80
0H21oh7oPOnjonD0nooW007oooX0mOoj0?_onP3gooX0o?oj0>[onP3hooX0o?oj
0?ConP3kooX0mooj0>oonP3dooX0n_oj0>Ool03/ooX0nooj007oooX0o?oW0?go
nP3goo/0o_ol0?koo03noo/0nooj0?ConP3mooX0m?ob087oPOn1ok[oi@3konL0
0OoonP3eooX0nooj0?OonP3looX0j_oj0?SonP3looX0m?oj0?_onP3gooX0kooj
0?ConP3jooX0ioo`0>conP3kooX00OoonP3lonL0oOoj0?Oon`3noo`0o_ol0?ko
n`3kooX0m?oj0?gonP3doo80POn1oh7o^_oU0?_oi`01oooj0?GonP3kooX0mooj
0?conP3ZooX0n?oj0?conP3dooX0nooj0?OonP3_ooX0m?oj0?[onP3Woo00k?oj
0?_onP01oooj0?coi`3mooX0mook0?koo03noo`0o_ok0?_onP3dooX0oOoj0?Co
lP01RH7oPOn1ok[on@3fooP0nooW007oooX0mOoj0?_onP3gooX0o?oj0>[onP3h
ooX0o?oj0?ConP3kooX0mooj0>oonP3dooX0n_oj0>[ok@3/ooX0n_oj003onP3l
onL0oOoj0?Oon`3noo`0o_ol0?kon`3kooX0m?oj0?gonP3doo80POn1oh7o^_oi
0?Kon03konL00OoonP3eooX0nooj0?OonP3looX0j_oj0?SonP3looX0m?oj0?_o
nP3gooX0kooj0?ConP3jooX0j_o]0>conP3jooX00?oj0?coi`3mooX0mook0?ko
o03noo`0o_ok0?_onP3dooX0oOoj0?ColP21oh7oPOnjooT0m_oh0?_oi`01oooj
0?GonP3kooX0mooj0?conP3ZooX0n?oj0?conP3dooX0nooj0?OonP3_ooX0m?oj
0?[onP3Zond0k?oj0?[onP00ooX0o?oW0?gonP3goo/0o_ol0?koo03noo/0nooj
0?ConP3mooX0m?ob0069POn1oh7o^_oi0?Gon03lonL00OoonP3eooX0nooj0?Oo
nP3looX0j_oj0?SonP3looX0m?oj0?_onP3gooX0kooj0?ConP3jooX0joo/0>co
nP3jooX00?oj0?coi`3mooX0mook0?koo03noo`0o_ok0?_onP3dooX0oOoj0?Co
lP21oh7oPOnjooT0mOoh0?coi`01oooj0?GonP3kooX0mooj0?conP3ZooX0n?oj
0?conP3dooX0nooj0?OonP3_ooX0m?oj0?[onP3[on`0k?oj0?[onP00ooX0o?oW
0?gonP3goo/0o_ol0?koo03noo/0nooj0?ConP3mooX0m?ob087oPOn1ok[on@3e
ooP0o?oW007oooX0mOoj0?_onP3gooX0o?oj0>[onP3hooX0o?oj0?ConP3kooX0
mooj0>oonP3dooX0n_oj0>_ok03/ooX0n_oj003onP3lonL0oOoj0?Oon`3noo`0
o_ol0?kon`3kooX0m?oj0?gonP3doo800Hn1oh7oPOnjooT0m?oi0?coi`01oooj
0?GonP3kooX0mooj0?conP3ZooX0n?oj0?conP3dooX0nooj0?OonP3_ooX0m?oj
0?[onP3/ooD0o_oj0>conP3ioo<0o?oW0?gonP3foo/00Oooo03noo`00Ooon`3j
ooX0m?oj0?gonP3doo80POn1oh7o^_oi0?Con@3lonL00OoonP3eooX0nooj0?Oo
nP3looX0j_oj0?SonP3looX0m?oj0?_onP3gooX0kooj0?ConP3jooX0k?oe0?ko
nP3/ooX0nOoc0?coi`3mooX0m_ok007ooo`0o_ol007ooo/0n_oj0?ConP3mooX0
m?ob087oPOn1ok[on@3dooT0o?oW007oooX0mOoj0?_onP3gooX0o?oj0>[onP3h
ooX0o?oj0?ConP3kooX0mooj0>oonP3dooX0n_oj0>com@3nooX0k?oj0?Wol`3l
onL0oOoj0?Kon`01oool0?koo001oook0?[onP3dooX0oOoj0?ColP01TX7oPOn1
ok[on@3dooT0o?oj0>conP3eooX0nooj0?OonP3looX0j_oj0?SonP3looX0m?oj
0?_onP3gooX0kooj0?ConP3jooX0k?oi0?[onP3/ooX0n?od0?conP3ZooX0m_ok
003oo03loo`00?ok0?[onP3dooX0oOoj0?Con000oo`0POn1oh7o^_oi0?Con@3l
ooX0k?oj0?GonP3kooX0mooj0?conP3ZooX0n?oj0?conP3dooX0nooj0?OonP3_
ooX0m?oj0?[onP3/ooT0n_oj0>conP3hoo@0o?oj0>[onP3foo/00?ol0?coo000
oo/0n_oj0?ConP3mooX0m?oh003oo021oh7oPOnjooT0m?oi0?conP3/ooX0mOoj
0?_onP3gooX0o?oj0>[onP3hooX0o?oj0?ConP3kooX0mooj0>oonP3dooX0n_oj
0>con@3jooX0k?oj0?Som03looX0j_oj0?Kon`00oo`0o?ol003on`3jooX0m?oj
0?gonP3dooP00?ol006BPOn1oh7o^_oi0?Con@3looX0k?oj0?GonP3kooX0mooj
0?conP3ZooX0n?oj0?conP3dooX0nooj0?OonP3_ooX0m?oj0?[onP3]ooX0n?oj
0>conP3hoo@0o?oj0>[onP3foo/00?ol0?coo000oo/0n_oj0?ConP3mooX0m?oi
0?koo@21oh7oPOnjooT0m?oi0?conP3/ooX0mOoj0?_onP3gooX0o?oj0>[onP3h
ooX0o?oj0?ConP3kooX0mooj0>oonP3dooX0n_oj0>gonP3hooX0k?oj0?Som03l
ooX0j_oj0?Kon`00oo`0o?ol003on`3jooX0m?oj0?gonP3dooT0o_om087oPOn1
ok[on@3dooT0o?oj0>conP3eooX0nooj0?OonP3looX0j_oj0?SonP3looX0m?oj
0?_onP3gooX0kooj0?ConP3jooX0kOoj0?SonP3/ooX0n?od0?conP3ZooX0m_ok
003oo03loo`00?ok0?[onP3dooX0oOoj0?Con@3nood00Ij1oh7oPOnjooT0m?oi
0?con@3]ooT0mooi0?_onP3gooX0o?oi0?OonP3looX0n?oj0?_onP3fooX0n_oj
0?OonP3^ooX0m_oj0?WonP3]ooX0n?oj0>conP3gooD0o?oi0>_onP3foo/00?ol
0?coo000oo`0n?oj0?KonP3looX0m?oj0?goo@21oh7oPOnjooT0m?oi0?con@3]
ooT0mooi0?_onP3gooX0o?oi0?OonP3looX0n?oj0?_onP3fooX0n_oj0?OonP3^
ooX0m_oj0?WonP3]ooX0n?oj0>conP3gooD0o?oi0>_onP3foo/00?ol0?coo000
oo`0n?oj0?KonP3looX0m?oj0?goo@21oh7oPOnjooT0m?oi0?con@3]ooT0mooi
0?_onP3gooX0o?oi0?OonP3looX0n?oj0?_onP3fooX0n_oj0?OonP3^ooX0m_oj
0?WonP3]ooX0n?oj0>conP3gooD0o?oi0>_onP3foo/00?ol0?coo000oo`0n?oj
0?KonP3looX0m?oj0?goo@01]X7oPOn1ok[on@3dooT0nooj0?Oon@3nooX0mooi
0?_onP3hooT0nooj0?OonP3looX0n?oj0?_onP3fooX0n_oj0?OonP3^ooX0m_oj
0?WonP3]ooX0nOoi0>conP3gooD0nooj0?Oon@3mooX0mOol003oo03loo`00?ol
0?SonP3fooX0o?oj0?ConP3looh0POn1oh7o^_oi0?Con@3kooX0mooi0?konP3g
ooT0nooj0?Son@3kooX0mooj0?conP3hooX0nooj0?KonP3jooX0mooj0>konP3f
ooX0nOoj0>gonP3iooT0k?oj0?Oom@3kooX0mooi0?gonP3eoo`00?ol0?coo000
oo`0n?oj0?KonP3looX0m?oj0?cooP21oh7oPOnjooT0m?oi0?_onP3gooT0o_oj
0?Oon@3kooX0n?oi0?_onP3gooX0o?oj0?SonP3kooX0m_oj0?[onP3gooX0k_oj
0?KonP3iooX0kOoj0?Won@3/ooX0mooe0?_onP3gooT0oOoj0?Goo000oo`0o?ol
003oo03hooX0m_oj0?conP3dooX0o?on006NPOn1oh7o^_oi0?Con@3kooT0n?oi
0?kon@3iooP0nooi0?[on03kooT0nOoj0?_onP3hooX0nooi0?Son@3jooX0mooj
0>kon@3hooT0nOoj0>gonP3iooT0k?oj0?KomP3kooT0n?oi0?gonP3eooL0n_og
0?Son@3hooT0o?oj0?ConP3looh0POn1oh7o^_oi0?Con@3kooT0n?oi0?kon@3i
ooP0nooi0?[on03kooT0nOoj0?_onP3hooX0nooi0?Son@3jooX0mooj0>kon@3h
ooT0nOoj0>gonP3iooT0k?oj0?KomP3kooT0n?oi0?gonP3eooL0n_og0?Son@3h
ooT0o?oj0?ConP3looh0POn1oh7o^_oi0?Con@3kooT0n?oi0?kon@3iooP0nooi
0?[on03kooT0nOoj0?_onP3hooX0nooi0?Son@3jooX0mooj0>kon@3hooT0nOoj
0>gonP3iooT0k?oj0?KomP3kooT0n?oi0?gonP3eooL0n_og0?Son@3hooT0o?oj
0?ConP3looh00J61oh7oPOnjooT0m?oi0?_om`3looP0oOoh0?comP3jooT0o?og
0?_on03kooT0noof0?conP3jooP0o?oh0?WonP3gooX0kOoh0?con03hooX0kOoi
0?com`3/ooX0m_of0?_om`3looP0o?of0?Wom`3jooL0mooh0?con03kooX0m?oj
0?_o0@00POn1oh7o^_oi0?Con@3kooL0o?oh0?gon03looH0n_oi0?com`3kooP0
nooi0?_omP3looX0n_oh0?con03iooX0mooj0>gon03looP0n?oj0>gon@3looL0
k?oj0?KomP3kooL0o?oh0?comP3iooL0n_og0?Oon03looP0nooj0?ConP3ko`40
087oPOn1ok[on@3dooT0noog0?con03mooP0o?of0?[on@3looL0nooh0?_on@3k
ooH0o?oj0?[on03looP0nOoj0?OonP3]ooP0o?oh0?SonP3]ooT0o?og0>conP3f
ooH0noog0?con03looH0nOog0?[om`3gooP0o?oh0?_onP3dooX0nol10001=H7o
POn1ok[on@3dooT0n_oZ0?coj@3jonX0n_o/0?[omP3looX0n_oZ0?WonP3gooX0
kOoZ0?SonP3]onX0k?oj0?Gom`3jonX0o?of0?Wom`3jooP0m_oZ0?_onP3dooX0
nol10021oh7oPOnjooT0m?oi0?[ojP3lonT0n_oZ0?[ok03jooH0o?oj0?[ojP3i
ooX0mooj0>gojP3hooX0kOoZ0>conP3eooL0n_oZ0?comP3iooL0n_oh0?KojP3k
ooX0m?oj0?_o0@00POn1oh7o^_oi0?Con@3jonX0o?oY0?[ojP3jon`0n_of0?co
nP3jonX0nOoj0?OonP3]onX0n?oj0>gojP3/ooX0mOog0?[ojP3looH0nOog0?[o
n03fonX0nooj0?ConP3ko`40004bPOn1oh7o^_oi0?Con@3ion`0n_oZ0?[ojP3i
ond0n_of0?conP3ion`0n?oj0?OonP3/on`0mooj0>coj`3/ooX0m?oh0?Wok03k
ooH0n?oh0?[on03eon`0n_oj0?ConP3jo`00POn1oh7o^_oi0?Con@3ion`0n_oZ
0?[ojP3iond0n_of0?conP3ion`0n?oj0?OonP3/on`0mooj0>coj`3/ooX0m?oh
0?Wok03kooH0n?oh0?[on03eon`0n_oj0?ConP3jo`00POn1oh7o^_oi0?Con@3i
on`0n_oZ0?[ojP3iond0n_of0?conP3ion`0n?oj0?OonP3/on`0mooj0>coj`3/
ooX0m?oh0?Wok03kooH0n?oh0?[on03eon`0n_oj0?ConP3jo`000Db1oh7oPOnj
ooT0m?oi0?SokP3ioo800?oj0?Wol`00ooX0nOo^0?Som`3looX0n?o^0?OonP3g
ooX0joo^0?KonP3/oo<00?oj0>conP3dooP0n?o^0?Wom`3hooP0n_oh0?CokP3i
ooX0m?oj087oPOn1ok;on@3dooT0n?o^0?WolP00ooX0nOoc003onP3ionh0n?og
0?conP3honh0mooj0?OonP3[onh0m_oj0>col`00ooX0k?oj0?Con03honh0nOog
0?Son03jooP0m?o^0?WonP3dooX0POn1oh7o/_oi0?Con@3honh0nOob003onP3i
oo<00?oj0?WokP3hooL0o?oj0?SokP3gooX0mooj0>_okP3fooX0k?oc003onP3/
ooX0m?oh0?SokP3iooL0n?oh0?[on03donh0nOoj0?ConP3io`5EPOn1oh7o^_oi
0?Con03hoo00mood007oooX0nOod007oooX0n?o`0?Oom`3looX0moo`0?KonP3g
ooX0j_o`0?GonP3[ooD00Ooon@3]ooX0looi0?Ool03hooL0n?oi0?SonP3boo00
n?oj0?ConP21oh7oPOnbooT0m?oh0?Sol03goo@00OoonP3ioo@00OoonP3hoo00
moog0?conP3goo00m_oj0?OonP3Zoo00mOoj0>_om@01oooi0>gonP3cooT0moo`
0?Som`3hooT0n?oj0?;ol03hooX0m?oj087oPOn1ok;on@3dooP0n?o`0?Oom001
oooj0?Wom001oooj0?Sol03gooL0o?oj0?Ool03fooX0mooj0>[ol03eooX0jooe
007oooT0kOoj0??on@3goo00n?og0?Son@3hooX0l_o`0?SonP3dooX0nOl1C87o
POn1ok[on@3cooP0mood0??om`3nooX0moog0?konP3foo@0looi0?conP3eoo@0
m?oj0?OonP3Xoo@0looj0>[om`3mooX0kOoj0??on@3eoo@0m?oi0?Son@3hooX0
l?od0?KonP3dooX0POn1oh7o/_oi0??on03goo@0loog0?konP3gooL0o_oj0?Ko
m03cooT0o?oj0?Gom03dooX0mooj0>Som03cooX0j_og0?gonP3]ooX0looi0?Go
m03dooT0n?oi0?SonP3`oo@0m_oj0?ConP21oh7oPOnbooT0looh0?Oom03cooL0
o_oj0?Oom`3nooX0m_od0??on@3looX0mOod0?ConP3gooX0j?od0??onP3ZooL0
oOoj0>gonP3cooT0mOod0?Con@3hooT0n?oj0?3om03fooX0m?oj0?Wo08B1oh7o
POn>ooT0kook0>Won`3XooP0cooh0;oon03Aoo/0]?oi0;Kon021oh7oPOn1omko
n@3_oo/0jOok0>Son03?ooP0_ooh0=7on`2dooT0]_oh087oPOn1oh7og_oi0>oo
n`3Yoo/0j?oh0<oon02oooP0dOok0;Con@2fooP0dOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oVOl0<87oPOn1oh7oPOn6oh40U021oh7oPOn1oh7oQ_n109@0
POn1oh7oPOn1ohKoP@2D000`POn1oh7oPOn1ohKoP@2D087oPOn1oh7oPOn6oh40
U021oh7oPOn1oh7oQ_n109@00321oh7oPOn1oh7oQ_n109@0POn1oh7oPOn1ohKo
P@2D087oPOn1oh7oPOn6oh40U000<87oPOn1oh7oPOn6oh40U021oh7oPOn1oh7o
Q_n109@0POn1oh7oPOn1ohKoP@2D000fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7o
POn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0f
POn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7o
POn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0f
POn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7o
POn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0f
POn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7o
POn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0f
POn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7o
POn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0f
POn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7o
POn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0f
POn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7o
POn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0f
POn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7o
POn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0f
POn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7o
POn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0f
POn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7o
POn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0f
POn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7o
POn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0f
POn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7o
POn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0f
POn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7o
POn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0f
POn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7o
POn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0f
POn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7o
POn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0f
POn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7o
POn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0f
POn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oiko
o021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7o
POn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0
POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7o
POn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087o
POn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0@X7oPOn1oh7o
POn6oo`0_Oof087oPOn1oh7oPOn1oh7okOol0;gomP21oh7oPOn1oh7oPOn1ongo
o02mooH0POoXo`12POn1oh7oPOn1ohKoo031onh0POn1oh7oPOn1oh7oPOoaoo`0
`Oo^087oPOn1oh7oPOn1oh7olOol0<7okP21onco04:1oh7oPOn1oh7oQ_ol0<?o
jP21oh7oPOn1oh7oPOn1oo?oo033onX0POn1oh7oPOn1oh7oPOocoo`0`ooZ087o
k_l0@X7oPOn1oh7oPOn6oo`0aOoV087oPOn1oh7oPOn1oh7omOol0<GoiP21oh7o
POn1oh7oPOn1ooGoo035onH0POo`o`12POn1oh7oPOn1ohKoo037on<0POn1oh7o
POn1oh7oPOofoo`0aooS087oPOn1oh7oPOn1oh7om_ol0<Ooh`21oo7o04:1oh7o
POn1oh7oQ_ol0<Soh021oh7oPOn1oh7oPOn1ooSoo038on00POn1oh7oPOn1oh7o
POohoo`0b?oP087olol0CX7oPOn1oh7oPOn6oo`0bOod0?Som021oh7oPOn1oh7o
POn1ooWoo039oo@0n?od087oPOn1oh7oPOn1oh7onOol0<Wom03hoo@0POodo`1>
POn1oh7oPOn1ohKoo03:ooH0l_og087oPOn1oh7oPOn1oh7onOol0<[omP3booL0
POn1oh7oPOn1oh7oPOoioo`0b_of0?;om`21ooCo04j1oh7oPOn1oh7oQ_ol0<_o
m`3^ooP0POn1oh7oPOn1oh7oPOojoo`0boog0>kon021oh7oPOn1oh7oPOn1oo[o
o03;ooL0k_oh087omOl0CX7oPOn1oh7oPOn6oo`0c?oh0>_on021oh7oPOn1oh7o
POn1oo_oo03<ooP0jooh087oPOn1oh7oPOn1oh7onool0<con03[ooP0POofo`1>
POn1oh7oPOn1ohKoo03<ooT0jOoh087oPOn1oh7oPOn1oh7oo?ol0<con@3YooP0
POn1oh7oPOn1oh7oPOoloo`0c?oi0>Won021ooOo04j1oh7oPOn1oh7oQ_ol0<go
n@3WooT0POn1oh7oPOn1oh7oPOoloo`0cOoi0>Oon@21oh7oPOn1oh7oPOn1ooco
o03=ooT0iooi087omol0CX7oPOn1oh7oPOn6oo`0c_oi0>Gon@21oh7oPOn1oh7o
POn1oogoo03>ooT0iOoi087oPOn1oh7oPOn1oh7ooOol0<kon@3UooT0POoho`1>
POn1oh7oPOn1ohKoo03>ooT0iOoi087oPOn1oh7oPOn1oh7ooOol0<kon@3UooT0
POn1oh7oPOn1oh7oPOomoo`0c_oi0>Gon@21ooSo04j1oh7oPOn1oh7oQ_ol0<oo
n@3SooX0POn1oh7oPOn1oh7oPOomoo`0cooi0>?onP21oh7oPOn1oh7oPOn1oogo
o03?ooT0hooj087on?l0CX7oPOn1oh7oPOn6oo`0cooi0>?on@21oh7oPOn1oh7o
POn1ookoo03?ooT0hooi087oPOn1oh7oPOn1oh7oo_ol0<oon@3SooT0POoio`1>
POn1oh7oPOn1ohKoo03?ooX0hOoj087oPOn1oh7oPOn1oh7oo_ol0<oonP3QooX0
POn1oh7oPOn1oh7oPOonoo`0cooj0>7onP21ooWo04j1oh7oPOn1oh7oQ_ol0=3o
n@3QooX0POn1oh7oPOn1oh7oPOonoo`0d?oi0>7onP21oh7oPOn1oh7oPOn1ooko
o03@ooT0hOoj087onOl0@X7oPOn1oh7oPOn6oo`0d?oj087oPOn1oh7oPOn1oh7o
e_ol0=3onP21oh7oPOn1oh7oPOn1omKoo03@ooX0POoAo`12POn1oh7oPOn1ohKo
o03@ooX0POn1oh7oPOn1oh7oPOoFoo`0d?oj087oPOn1oh7oPOn1oh7oe_ol0=3o
nP21om7o04:1oh7oPOn1oh7oQ_ol0=3onP21oh7oPOn1oh7oPOn1omKoo03@ooX0
POn1oh7oPOn1oh7oPOoFoo`0d?oj087odOl0@X7oPOn1oh7oPOn6oo`0dOoi087o
POn1oh7oPOn1oh7oe_ol0=7on@21oh7oPOn1oh7oPOn1omKoo03AooT0POoAo`1A
POn1oh7oPOn1ohKoo03AooX0POl1oood087oPOn1oh7oPOn1onCoo03AooX0POl1
oood087oPOn1oh7oPOn1onCoo03AooX0POl1oood0=oo05B1oh7oPOn1oh7oQ_ol
0=7onP2Doo@0nOod087oPOn1oh7oPOn1onCoo03AooX0U?od0?Wom021oh7oPOn1
oh7oPOoToo`0dOoj09Com03ioo@0gol0E87oPOn1oh7oPOn6oo`0dOoj09Com03i
oo@0POn1oh7oPOn1oh7oi?ol0=7onP2Doo@0nOod087oPOn1oh7oPOn1onCoo03A
ooX0U?od0?Wom03Oo`1DPOn1oh7oPOn1ohKoo03AooX0U?od0?Wom021oh7oPOn1
oh7oPOoToo`0dOoj09Com03ioo@0POn1oh7oPOn1oh7oi?ol0=7onP2Doo@0nOod
0=oo05B1oh7oPOn1oh7oQ_ol0=7onP2Doo@0nOod087oPOn1oh7oPOn1onCoo03A
ooX0U?od0?Wom021oh7oPOn1oh7oPOoToo`0dOoj09Com03ioo@0gol0E87oPOn1
oh7oPOn6oo`0dOoj09Com03ioo@0POn1oh7oPOn1oh7oi?ol0=7onP2Doo@0nOod
087oPOn1oh7oPOn1onCoo03AooX0U?od0?Wom03Oo`1DPOn1oh7oPOn1ohKoo03A
ooX0U?od0?Wom021oh7oPOn1oh7oPOoToo`0dOoj09Com03ioo@0POn1oh7oPOn1
oh7oi?ol0=7onP2Doo@0nOod0=oo05B1oh7oPOn1oh7oQ_ol0=7onP2Doo@0nOod
087oPOn1oh7oPOn1onCoo03AooX0U?od0?Wom021oh7oPOn1oh7oPOoToo`0dOoj
09Com03ioo@0gol0E87oPOn1oh7oPOn6oo`0dOoj09Com03ioo@0POn1oh7oPOn1
oh7oi?ol0=7onP2Doo@0nOod087oPOn1oh7oPOn1onCoo03AooX0U?od0?Wom03O
o`1DPOn1oh7oPOn1ohKoo03AooX0U?od0?Wom021oh7oPOn1oh7oPOoToo`0dOoj
09Com03ioo@0POn1oh7oPOn1oh7oi?ol0=7onP2Doo@0nOod0=oo05B1oh7oPOn1
oh7oQ_ol0=7onP2Doo@0nOod087oPOn1oh7oPOn1onCoo03AooX0U?od0?Wom021
oh7oPOn1oh7oPOoToo`0dOoj09Com03ioo@0gol0E87oPOn1oh7oPOn6oo`0dOoj
09Com03ioo@0POn1oh7oPOn1oh7oi?ol0=7onP2Doo@0nOod087oPOn1oh7oPOn1
onCoo03AooX0U?od0?Wom03Oo`1/POn1oh7oPOn1ohKoo03@oo/0b_on0>konP3X
oo@0nOod087oPOn1oh7oPOn1onCoo03@oo/0b_on0>konP3Xoo@0nOod087oPOn1
oh7oPOn1onCoo03@oo/0b_on0>konP3Xoo@0nOod0=oo07R1oh7oPOn1oh7oQ_ol
0=3onP3PooX0loon0?3om@3[oo@0nOod087oPOn1oh7oPOn1onCoo03@ooX0h?oj
0??ooP3`ooD0jood0?Wom021oh7oPOn1oh7oPOoToo`0d?oj0>3onP3cooh0l?oe
0>_om03ioo@0gol0N87oPOn1oh7oPOn6oo`0d?oj0>3onP3dood0l_ob0>com03i
oo@0POn1oh7oPOn1oh7oi?ol0=3onP3PooX0m?om0?;olP3/oo@0nOod087oPOn1
oh7oPOn1onCoo03@ooX0h?oj0?Coo@3boo80k?od0?Wom03Oo`1hPOn1oh7oPOn1
ohKoo03@ooX0hOoi0?Coo@3coo00kOod0?Wom021oh7oPOn1oh7oPOoToo`0d?oj
0>7on@3dood0loo`0>gom03ioo@0POn1oh7oPOn1oh7oi?ol0=3onP3QooT0m?om
0??ol03]oo@0nOod0=oo08B1oh7oPOn1oh7oQ_ol0=3on@3RooX0m?ol0??on`3k
oo/0k_od0?Wom021oh7oPOn1oh7oPOoToo`0d?oi0>;onP3doo`0look0?_on`3^
oo@0nOod087oPOn1oh7oPOn1onCoo03@ooT0h_oj0?Coo03coo/0nook0>kom03i
oo@0gol0Q87oPOn1oh7oPOn6oo`0cooj0>;onP3eoo/0m?ol0?Soo03^oo@0nOod
087oPOn1oh7oPOn1onCoo03?ooX0h_oj0?Gon`3doo`0n?ol0>kom03ioo@0POn1
oh7oPOn1oh7oi?ol0<oonP3RooX0mOok0?Coo03hoo`0k_od0?Wom03Oo`24POn1
oh7oPOn1ohKoo03?ooX0hooi0?Wom`3dood0m_ol0>oom03ioo@0POn1oh7oPOn1
oh7oi?ol0<oonP3SooT0nOog0?Coo@3foo`0kood0?Wom021oh7oPOn1oh7oPOoT
oo`0cooj0>?on@3iooL0m?om0?Koo03_oo@0nOod0=oo08B1oh7oPOn1oh7oQ_ol
0<oon@3TooX0nood0?Coo@3eood0kood0?Wom021oh7oPOn1oh7oPOoToo`0cooi
0>ConP3koo@0m?om0?Goo@3_oo@0nOod087oPOn1oh7oPOn1onCoo03?ooT0i?oj
0?_om03dood0mOom0>oom03ioo@0gol0Q87oPOn1oh7oPOn6oo`0c_oj0>Gon@3k
oo@0mOol0?Goo@3_oo@0nOod087oPOn1oh7oPOn1onCoo03>ooX0iOoi0?_om03e
oo`0mOom0>oom03ioo@0POn1oh7oPOn1oh7oi?ol0<konP3UooT0nood0?Goo03e
ood0kood0?Wom03Oo`24POn1oh7oPOn1ohKoo03>ooT0i_oi0?_om03eood0m?om
0>oom03ioo@0POn1oh7oPOn1oh7oi?ol0<kon@3VooT0nood0?Goo@3dood0kood
0?Wom021oh7oPOn1oh7oPOoToo`0c_oi0>Kon@3koo@0mOom0?Coo@3_oo@0nOod
0=oo08B1oh7oPOn1oh7oQ_ol0<gon@3XooT0lOom0?Goo@3dood0kood0?Wom021
oh7oPOn1oh7oPOoToo`0cOoi0>Son@3aood0mOom0?Coo@3_oo@0nOod087oPOn1
oh7oPOn1onCoo03=ooT0j?oi0?7oo@3eood0m?om0>oom03ioo@0gol0Q87oPOn1
oh7oPOn6oo`0cOoh0>[on@3`ood0mOom0?Coo@3_oo@0nOod087oPOn1oh7oPOn1
onCoo03=ooP0j_oi0?3oo@3eood0m?om0>oom03ioo@0POn1oh7oPOn1oh7oi?ol
0<gon03ZooT0l?om0?Goo@3dood0kood0?Wom03Oo`1hPOn1oh7oPOn1ohKoo03<
ooP0k?oh0?3oo@3Uoo`0kood0?Wom021oh7oPOn1oh7oPOoToo`0c?oh0>con03`
ood0iOol0>oom03ioo@0POn1oh7oPOn1oh7oi?ol0<con03/ooP0l?om0>Goo03_
oo@0nOod0=oo07R1oh7oPOn1oh7oQ_ol0<_on03^ooP0koom0>Koo03^oo@0nOod
087oPOn1oh7oPOn1onCoo03;ooP0k_oh0>ooo@3Voo`0k_od0?Wom021oh7oPOn1
oh7oPOoToo`0booh0>kon03_ood0i_ol0>kom03ioo@0gol0N87oPOn1oh7oPOn6
oo`0b_og0?;om`3^ood0iook0>kom03ioo@0POn1oh7oPOn1oh7oi?ol0<[om`3b
ooL0k_om0>Oon`3^oo@0nOod087oPOn1oh7oPOn1onCoo03:ooL0l_og0>koo@3W
oo/0k_od0?Wom03Oo`1hPOn1oh7oPOn1ohKoo039ooD0n?oe0>goo@3]ooH0kOod
0?Wom021oh7oPOn1oh7oPOoToo`0bOoe0?Som@3]ood0kOof0>gom03ioo@0POn1
oh7oPOn1oh7oi?ol0<Wom@3hooD0kOom0>gomP3]oo@0nOod0=oo06b1oh7oPOn1
oh7oQ_ol0<SohP3/ood0kOoh0>_om03ioo@0POn1oh7oPOn1oh7oi?ol0<SohP3/
ood0kOoh0>_om03ioo@0POn1oh7oPOn1oh7oi?ol0<SohP3/ood0kOoh0>_om03i
oo@0gol0K87oPOn1oh7oPOn6oo`0aooT0>_oo@3]ooH0kOod0?Wom021oh7oPOn1
oh7oPOoToo`0aooT0>_oo@3]ooH0kOod0?Wom021oh7oPOn1oh7oPOoToo`0aooT
0>_oo@3]ooH0kOod0?Wom03Oo`1/POn1oh7oPOn1ohKoo036onH0j_om0>gom03_
oo@0nOod087oPOn1oh7oPOn1onCoo036onH0j_om0>gom03_oo@0nOod087oPOn1
oh7oPOn1onCoo036onH0j_om0>gom03_oo@0nOod0=oo06b1oh7oPOn1oh7oQ_ol
0<CojP3Xood0iooi0?3om03ioo@0POn1oh7oPOn1oh7oi?ol0<CojP3Xood0iooi
0?3om03ioo@0POn1oh7oPOn1oh7oi?ol0<CojP3Xood0iooi0?3om03ioo@0gol0
K87oPOn1oh7oPOn6oo`0`_o_0>Goo@3Too`0l?od0?Wom021oh7oPOn1oh7oPOoT
oo`0`_o_0>Goo@3Too`0l?od0?Wom021oh7oPOn1oh7oPOoToo`0`_o_0>Goo@3T
oo`0l?od0?Wom03Oo`1/POn1oh7oPOn1ohKoo02nooH0h_om0>?oo03aoo@0nOod
087oPOn1oh7oPOn1onCoo02nooH0h_om0>?oo03aoo@0nOod087oPOn1oh7oPOn1
onCoo02nooH0h_om0>?oo03aoo@0nOod0=oo0621oh7oPOn1oh7oQ_ol09Coo@3S
oo`0lOod0?Wom021oh7oPOn1oh7oPOoToo`0U?om0>?oo03aoo@0nOod087oPOn1
oh7oPOn1onCoo02Dood0hool0?7om03ioo@0gol0H87oPOn1oh7oPOn6oo`0U?om
0>;oo@3aoo@0nOod087oPOn1oh7oPOn1onCoo02Dood0h_om0?7om03ioo@0POn1
oh7oPOn1oh7oi?ol09Coo@3Rood0lOod0?Wom03Oo`1/POn1oh7oPOn1ohKoo02D
ood0m_om0?7oo@3aoo@0nOod087oPOn1oh7oPOn1onCoo02Dood0m_om0?7oo@3a
oo@0nOod087oPOn1oh7oPOn1onCoo02Dood0m_om0?7oo@3aoo@0nOod0=oo06b1
oh7oPOn1oh7oQ_ol09Coo@3food0lOom0?7om03ioo@0POn1oh7oPOn1oh7oi?ol
09Coo@3food0lOom0?7om03ioo@0POn1oh7oPOn1oh7oi?ol09Coo@3food0lOom
0?7om03ioo@0gol0K87oPOn1oh7oPOn6oo`0U?om0?Koo@3aood0lOod0?Wom021
oh7oPOn1oh7oPOoToo`0U?om0?Koo@3aood0lOod0?Wom021oh7oPOn1oh7oPOoT
oo`0U?om0?Koo@3aood0lOod0?Wom03Oo`1/POn1oh7oPOn1ohKoo02Dood0m_ol
0?;oo@3aoo@0nOod087oPOn1oh7oPOn1onCoo02Dood0m_ol0?;oo@3aoo@0nOod
087oPOn1oh7oPOn1onCoo02Dood0m_ol0?;oo@3aoo@0nOod0=oo06b1oh7oPOn1
oh7oQ_ol09Coo@3eood0loom0?3om03ioo@0POn1oh7oPOn1oh7oi?ol09Coo@3e
ood0loom0?3om03ioo@0POn1oh7oPOn1oh7oi?ol09Coo@3eood0loom0?3om03i
oo@0gol0K87oPOn1oh7oPOn6oo`0U?om0?Goo03eoo`0l?od0?Wom021oh7oPOn1
oh7oPOoToo`0U?om0?Goo03eoo`0l?od0?Wom021oh7oPOn1oh7oPOoToo`0U?om
0?Goo03eoo`0l?od0?Wom03Oo`1/POn1oh7oPOn1ohKoo02Dood0mOok0?Oon`3`
oo@0nOod087oPOn1oh7oPOn1onCoo02Dood0mOok0?Oon`3`oo@0nOod087oPOn1
oh7oPOn1onCoo02Dood0mOok0?Oon`3`oo@0nOod0=oo06b1oh7oPOn1oh7oQ_ol
09Coo@3doo/0n_oj0>oom03ioo@0POn1oh7oPOn1oh7oi?ol09Coo@3doo/0n_oj
0>oom03ioo@0POn1oh7oPOn1oh7oi?ol09Coo@3doo/0n_oj0>oom03ioo@0gol0
H87oPOn1oh7oPOn6oo`0U?om0??ok`3^oo@0nOod087oPOn1oh7oPOn1onCoo02D
ood0loo_0>kom03ioo@0POn1oh7oPOn1oh7oi?ol09Coo@3conl0k_od0?Wom03O
o`1PPOn1oh7oPOn1ohKoo02Dood0l_oa0>gom03ioo@0POn1oh7oPOn1oh7oi?ol
09Coo@3boo40kOod0?Wom021oh7oPOn1oh7oPOoToo`0U?om0?;ol@3]oo@0nOod
0=oo0621oh7oPOn1oh7oQ_ol09Coo@3aoo@0jood0?Wom021oh7oPOn1oh7oPOoT
oo`0U?om0?7om03[oo@0nOod087oPOn1oh7oPOn1onCoo02Dood0lOod0>_om03i
oo@0gol0FX7oPOn1oh7oPOn6oo`0POonooP0jOod0?Wom021oh7oPOn1oh7oPOoT
oo`0POonooP0jOod0?Wom021oh7oPOn1oh7oPOoToo`0POonooP0jOod0?Wom03O
o`1>POn1oh7oPOn1ohKoo021omgom03ioo@0POn1oh7oPOn1oh7oi?ol087ogOod
0?Wom021oh7oPOn1oh7oPOoToo`0POoMoo@0nOod0=oo04j1oh7oPOn1oh7oQ_ol
087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoMoo@0nOod087oPOn1oh7oPOn1
onCoo021omgom03ioo@0gol0CX7oPOn1oh7oPOn6oo`0POoMoo@0nOod087oPOn1
oh7oPOn1onCoo021omgom03ioo@0POn1oh7oPOn1oh7oi?ol087ogOod0?Wom03O
o`1>POn1oh7oPOn1ohKoo021omgom03ioo@0POn1oh7oPOn1oh7oi?ol087ogOod
0?Wom021oh7oPOn1oh7oPOoToo`0POoMoo@0nOod0=oo04j1oh7oPOn1oh7oQ_ol
087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoMoo@0nOod087oPOn1oh7oPOn1
onCoo021omgom03ioo@0gol0CX7oPOn1oh7oPOn6oo`0POoMoo@0nOod087oPOn1
oh7oPOn1onCoo021omgom03ioo@0POn1oh7oPOn1oh7oi?ol087ogOod0?Wom03O
o`1>POn1oh7oPOn1ohKoo021omgom03ioo@0POn1oh7oPOn1oh7oi?ol087ogOod
0?Wom021oh7oPOn1oh7oPOoToo`0POoMoo@0nOod0=oo04j1oh7oPOn1oh7oQ_ol
087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoMoo@0nOod087oPOn1oh7oPOn1
onCoo021omgom03ioo@0gol0CX7oPOn1oh7oPOn6oo`0POoMoo@0nOod087oPOn1
oh7oPOn1onCoo021omgom03ioo@0POn1oh7oPOn1oh7oi?ol087ogOod0?Wom03O
o`1>POn1oh7oPOn1ohKoo021omgom03ioo@0POn1oh7oPOn1oh7oi?ol087ogOod
0?Wom021oh7oPOn1oh7oPOoToo`0POoMoo@0nOod0=oo04j1oh7oPOn1oh7oQ_ol
087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoMoo@0nOod087oPOn1oh7oPOn1
onCoo021omgom03ioo@0gol0CX7oPOn1oh7oPOn6oo/0POoNoo@0nOod087oPOn1
oh7oPOn1onCon`21omkom03ioo@0POn1oh7oPOn1oh7oi?ok087og_od0?Wom03O
o`1>POn1oh7oPOn1ohOon021on3om03ioo@0POn1oh7oPOn1oh7oiOoh087oh?od
0?Wom021oh7oPOn1oh7oPOoUooP0POoPoo@0nOod0=oo04R1oh7oPOn1oh7oQoog
087ohOod0?WodP21oh7oPOn1oh7oQoog087ohOod0?WodP21oh7oPOn1oh7oQoog
087ohOod0?WodP00?87oPOn1oh7oPOn8oh40b@3iom80POn1oh7oPOn1ohSoP@39
0?WodP21oh7oPOn1oh7oR?n10<T0nOoB000lPOn1oh7oPOn1ohSoP@390?WodP21
oh7oPOn1oh7oR?n10<T0nOoB087oPOn1oh7oPOn8oh40b@3iom8003b1oh7oPOn1
oh7oROn10<P0nOoB087oPOn1oh7oPOn9oh40b03iom80POn1oh7oPOn1ohWoP@38
0?WodP00@X7oPOn1oh7oPOn8oh40b@3ioo@0POn1oh7oPOn1oh7oi_n10<T0nOod
087oPOn1oh7oPOn1onKoP@390?Wom03Oo`1>POn1oh7oPOn1ohSomP21on7om03i
oo@0POn1oh7oPOn1oh7oi_of087ohOod0?Wom021oh7oPOn1oh7oPOoVooH0POoQ
oo@0nOod0=oo04j1oh7oPOn1oh7oR?of087ohOod0?Wom021oh7oPOn1oh7oPOoV
ooH0POoQoo@0nOod087oPOn1oh7oPOn1onKomP21on7om03ioo@0gol0CX7oPOn1
oh7oPOn7ooP0POoPoo@0nOod087oPOn1oh7oPOn1onGon021on3om03ioo@0POn1
oh7oPOn1oh7oiOoh087oh?od0?Wom03Oo`1>POn1oh7oPOn1ohOon021on3om03i
oo@0POn1oh7oPOn1oh7oiOoh087oh?od0?Wom021oh7oPOn1oh7oPOoUooP0POoP
oo@0nOod0=oo04j1oh7oPOn1oh7oQ_ok087og_od0?Wom021oh7oPOn1oh7oPOoT
oo/0POoNoo@0nOod087oPOn1oh7oPOn1onCon`21omkom03ioo@0gol0CX7oPOn1
oh7oPOn6oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0POn1
oh7oPOn1oh7oi?ol087ogOod0?Wom03Oo`1>POn1oh7oPOn1ohKoo021omgom03i
oo@0POn1oh7oPOn1oh7oi?ol087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoM
oo@0nOod0=oo04j1oh7oPOn1oh7oQ_ol087ogOod0?Wom021oh7oPOn1oh7oPOoT
oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0gol0CX7oPOn1
oh7oPOn6oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0POn1
oh7oPOn1oh7oi?ol087ogOod0?Wom03Oo`1>POn1oh7oPOn1ohKoo021omgom03i
oo@0POn1oh7oPOn1oh7oi?ol087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoM
oo@0nOod0=oo04j1oh7oPOn1oh7oQ_ol087ogOod0?Wom021oh7oPOn1oh7oPOoT
oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0gol0CX7oPOn1
oh7oPOn6oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0POn1
oh7oPOn1oh7oi?ol087ogOod0?Wom03Oo`1>POn1oh7oPOn1ohKoo021omgom03i
oo@0POn1oh7oPOn1oh7oi?ol087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoM
oo@0nOod0=oo04j1oh7oPOn1oh7oQ_ol087ogOod0?Wom021oh7oPOn1oh7oPOoT
oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0gol0CX7oPOn1
oh7oPOn6oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0POn1
oh7oPOn1oh7oi?ol087ogOod0?Wom03Oo`1>POn1oh7oPOn1ohKoo021omgom03i
oo@0POn1oh7oPOn1oh7oi?ol087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoM
oo@0nOod0=oo04j1oh7oPOn1oh7oQ_ol087ogOod0?Wom021oh7oPOn1oh7oPOoT
oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0gol0CX7oPOn1
oh7oPOn6oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0POn1
oh7oPOn1oh7oi?ol087ogOod0?Wom03Oo`1>POn1oh7oPOn1ohKoo021omgom03i
oo@0POn1oh7oPOn1oh7oi?ol087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoM
oo@0nOod0=oo04j1oh7oPOn1oh7oQ_ol087ogOod0?Wom021oh7oPOn1oh7oPOoT
oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0gol0CX7oPOn1
oh7oPOn6oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0POn1
oh7oPOn1oh7oi?ol087ogOod0?Wom03Oo`1>POn1oh7oPOn1ohKoo021omgom03i
oo@0POn1oh7oPOn1oh7oi?ol087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoM
oo@0nOod0=oo04j1oh7oPOn1oh7oQ_ol087ogOod0?Wom021oh7oPOn1oh7oPOoT
oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0gol0CX7oPOn1
oh7oPOn6oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0POn1
oh7oPOn1oh7oi?ol087ogOod0?Wom03Oo`1>POn1oh7oPOn1ohKoo021omgom03i
oo@0POn1oh7oPOn1oh7oi?ol087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoM
oo@0nOod0=oo04j1oh7oPOn1oh7oQ_ol087ogOod0?Wom021oh7oPOn1oh7oPOoT
oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0gol0CX7oPOn1
oh7oPOn6oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0POn1
oh7oPOn1oh7oi?ol087ogOod0?Wom03Oo`1>POn1oh7oPOn1ohKoo021omgom03i
oo@0POn1oh7oPOn1oh7oi?ol087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoM
oo@0nOod0=oo04j1oh7oPOn1oh7oQ_ol087ogOod0?Wom021oh7oPOn1oh7oPOoT
oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0gol0CX7oPOn1
oh7oPOn6oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0POn1
oh7oPOn1oh7oi?ol087ogOod0?Wom03Oo`1>POn1oh7oPOn1ohKoo021omgom03i
oo@0POn1oh7oPOn1oh7oi?ol087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoM
oo@0nOod0=oo04j1oh7oPOn1oh7oQ_ol087ogOod0?Wom021oh7oPOn1oh7oPOoT
oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0gol0CX7oPOn1
oh7oPOn6oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0POn1
oh7oPOn1oh7oi?ol087ogOod0?Wom03Oo`1>POn1oh7oPOn1ohKoo021omgom03i
oo@0POn1oh7oPOn1oh7oi?ol087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoM
oo@0nOod0=oo04j1oh7oPOn1oh7oQ_ol087ogOod0?Wom021oh7oPOn1oh7oPOoT
oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0gol0CX7oPOn1
oh7oPOn6oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0POn1
oh7oPOn1oh7oi?ol087ogOod0?Wom03Oo`1>POn1oh7oPOn1ohKoo021omgom03i
oo@0POn1oh7oPOn1oh7oi?ol087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoM
oo@0nOod0=oo04j1oh7oPOn1oh7oQ_ol087ogOod0?Wom021oh7oPOn1oh7oPOoT
oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0gol0CX7oPOn1
oh7oPOn6oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0POn1
oh7oPOn1oh7oi?ol087ogOod0?Wom03Oo`1>POn1oh7oPOn1ohKoo021omgom03i
oo@0POn1oh7oPOn1oh7oi?ol087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoM
oo@0nOod0=oo04j1oh7oPOn1oh7oQ_ol087ogOod0?Wom021oh7oPOn1oh7oPOoT
oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0gol0CX7oPOn1
oh7oPOn6oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0POn1
oh7oPOn1oh7oi?ol087ogOod0?Wom03Oo`1>POn1oh7oPOn1ohKoo021omgom03i
oo@0POn1oh7oPOn1oh7oi?ol087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoM
oo@0nOod0=oo04j1oh7oPOn1oh7oQ_ol087ogOod0?Wom021oh7oPOn1oh7oPOoT
oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0gol0CX7oPOn1
oh7oPOn6oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0POn1
oh7oPOn1oh7oi?ol087ogOod0?Wom03Oo`1>POn1oh7oPOn1ohKoo021omgom03i
oo@0POn1oh7oPOn1oh7oi?ol087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoM
oo@0nOod0=oo04j1oh7oPOn1oh7oQ_ol087ogOod0?Wom021oh7oPOn1oh7oPOoT
oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0gol0CX7oPOn1
oh7oPOn6oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0POn1
oh7oPOn1oh7oi?ol087ogOod0?Wom03Oo`1>POn1oh7oPOn1ohKoo021omgom03i
oo@0POn1oh7oPOn1oh7oi?ol087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoM
oo@0nOod0=oo04j1oh7oPOn1oh7oQ_ol087ogOod0?Wom021oh7oPOn1oh7oPOoT
oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0gol0CX7oPOn1
oh7oPOn6oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0POn1
oh7oPOn1oh7oi?ol087ogOod0?Wom03Oo`1>POn1oh7oPOn1ohKoo021omgom03i
oo@0POn1oh7oPOn1oh7oi?ol087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoM
oo@0nOod0=oo04j1oh7oPOn1oh7oQ_ol087ogOod0?Wom021oh7oPOn1oh7oPOoT
oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0gol0CX7oPOn1
oh7oPOn6oo`0POoMoo@0nOod087oPOn1oh7oPOn1onCoo021omgom03ioo@0POn1
oh7oPOn1oh7oi?ol087ogOod0?Wom03Oo`1>POn1oh7oPOn1ohKoo021omgom03i
oo@0POn1oh7oPOn1oh7oi?ol087ogOod0?Wom021oh7oPOn1oh7oPOoToo`0POoM
oo@0nOod0=oo04:1oh7oPOn1oh7oQ_ol087ogOod087oPOn1oh7oPOn1olooo021
omgom021oh7oPOn1oh7oPOo?oo`0POoMoo@0b_l0=X7oPOn1oh7oPOn6oo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1
ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1
oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol
087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1
ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1
oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol
087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1
ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1
oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol
087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0?87oPOn1oh7oPOn6oo`0Toof
087oPOn1oh7oPOn1oiOoo02CooH0POn1oh7oPOn1oh7oUool09?omP2Bo`0lPOn1
oh7oPOn1ohKoo02Gonh0POn1oh7oPOn1oh7oVool09OokP21oh7oPOn1oh7oPOnK
oo`0Uoo^09Ko03b1oh7oPOn1oh7oQ_ol09WojP21oh7oPOn1oh7oPOnMoo`0VOoZ
087oPOn1oh7oPOn1oigoo02IonX0V?l0?87oPOn1oh7oPOn6oo`0VooV087oPOn1
oh7oPOn1oiooo02KonH0POn1oh7oPOn1oh7oWool09_oiP2Jo`0lPOn1oh7oPOn1
ohKoo02Mon<0POn1oh7oPOn1oh7oX?ol09goh`21oh7oPOn1oh7oPOnPoo`0WOoS
09_o03b1oh7oPOn1oh7oQ_ol09koh021oh7oPOn1oh7oPOnRoo`0W_oP087oPOn1
oh7oPOn1oj;oo02Non00WOl0B87oPOn1oh7oPOn6oo`0Wood0?Som021oh7oPOn1
oh7oPOnSoo`0Wood0?Som021oh7oPOn1oh7oPOnSoo`0Wood0?Som02No`18POn1
oh7oPOn1ohKoo02PooH0l_og087oPOn1oh7oPOn1oj?oo02PooH0l_og087oPOn1
oh7oPOn1oj?oo02PooH0l_og09ko04R1oh7oPOn1oh7oQ_ol0:7om`3^ooP0POn1
oh7oPOn1oh7oY?ol0:7om`3^ooP0POn1oh7oPOn1oh7oY?ol0:7om`3^ooP0Wol0
B87oPOn1oh7oPOn6oo`0X_oh0>_on021oh7oPOn1oh7oPOnUoo`0X_oh0>_on021
oh7oPOn1oh7oPOnUoo`0X_oh0>_on02Po`18POn1oh7oPOn1ohKoo02RooT0jOoh
087oPOn1oh7oPOn1ojKoo02RooT0jOoh087oPOn1oh7oPOn1ojKoo02RooT0jOoh
0:7o04R1oh7oPOn1oh7oQ_ol0:?on@3WooT0POn1oh7oPOn1oh7oY_ol0:?on@3W
ooT0POn1oh7oPOn1oh7oY_ol0:?on@3WooT0XOl0B87oPOn1oh7oPOn6oo`0Y?oi
0>Gon@21oh7oPOn1oh7oPOnWoo`0Y?oi0>Gon@21oh7oPOn1oh7oPOnWoo`0Y?oi
0>Gon@2Ro`18POn1oh7oPOn1ohKoo02TooT0iOoi087oPOn1oh7oPOn1ojOoo02T
ooT0iOoi087oPOn1oh7oPOn1ojOoo02TooT0iOoi0:;o04R1oh7oPOn1oh7oQ_ol
0:Gon@3SooX0POn1oh7oPOn1oh7oYool0:Gon@3SooX0POn1oh7oPOn1oh7oYool
0:Gon@3SooX0X_l0B87oPOn1oh7oPOn6oo`0YOoi0>?on@21oh7oPOn1oh7oPOnX
oo`0YOoi0>?on@21oh7oPOn1oh7oPOnXoo`0YOoi0>?on@2So`18POn1oh7oPOn1
ohKoo02UooX0hOoj087oPOn1oh7oPOn1ojSoo02UooX0hOoj087oPOn1oh7oPOn1
ojSoo02UooX0hOoj0:?o04R1oh7oPOn1oh7oQ_ol0:Kon@3QooX0POn1oh7oPOn1
oh7oZ?ol0:Kon@3QooX0POn1oh7oPOn1oh7oZ?ol0:Kon@3QooX0Xol0@X7oPOn1
oh7oPOn6oo`0Y_oj087oPOn1oh7oPOn1oh7o0?ol0:KonP21oh7oPOn1oh7oPOn1
o`3oo02VooX0POoko`12POn1oh7oPOn1ohKoo02VooX0POn1oh7oPOn1oh7oPOl0
oo`0Y_oj087oPOn1oh7oPOn1oh7o0?ol0:KonP21oo_o04:1oh7oPOn1oh7oQ_ol
0:KonP21oh7oPOn1oh7oPOn1o`3oo02VooX0POn1oh7oPOn1oh7oPOl0oo`0Y_oj
087onol0@X7oPOn1oh7oPOn6oo`0Yooi087oPOn1oh7oPOn1oh7o0?ol0:Oon@21
oh7oPOn1oh7oPOn1o`3oo02WooT0POoko`14POn1oh7oPOn1ohKoo02WooX0POn1
oh7oPOn1oh7oPOl1oool0:OonP21oh7oPOn1oh7oPOn1o`7ooo`0Yooj087on_l0
A87oPOn1oh7oPOn6oo`0Yooj087oPOn1oh7oPOn1oh7o0Oooo02WooX0POn1oh7o
POn1oh7oPOl1oool0:OonP21oo[o04B1oh7oPOn1oh7oQ_ol0:OonP21oh7oPOn1
oh7oPOn1o`7ooo`0Yooj087oPOn1oh7oPOn1oh7o0Oooo02WooX0POojo`14POn1
oh7oPOn1ohKoo02WooX0POn1oh7oPOn1oh7oPOl1oool0:OonP21oh7oPOn1oh7o
POn1o`7ooo`0Yooj087on_l0A87oPOn1oh7oPOn6oo`0Yooj087oPOn1oh7oPOn1
oh7o0Oooo02WooX0POn1oh7oPOn1oh7oPOl1oool0:OonP21oo[o04B1oh7oPOn1
oh7oQ_ol0:OonP21oh7oPOn1oh7oPOn1o`7ooo`0Yooj087oPOn1oh7oPOn1oh7o
0Oooo02WooX0POojo`14POn1oh7oPOn1ohKoo02WooX0POn1oh7oPOn1oh7oPOl1
oool0:OonP21oh7oPOn1oh7oPOn1o`7ooo`0Yooj087on_l0A87oPOn1oh7oPOn6
oo`0Yooj087oPOn1oh7oPOn1oh7o0Oooo02WooX0POn1oh7oPOn1oh7oPOl1oool
0:OonP21oo[o04B1oh7oPOn1oh7oQ_ol0:OonP21oh7oPOn1oh7oPOn1o`7ooo`0
Yooj087oPOn1oh7oPOn1oh7o0Oooo02WooX0POojo`14POn1oh7oPOn1ohKoo02W
ooX0POn1oh7oPOn1oh7oPOl1oool0:OonP21oh7oPOn1oh7oPOn1o`7ooo`0Yooj
087on_l0A87oPOn1oh7oPOn6oo`0Yooj087oPOn1oh7oPOn1oh7o0Oooo02WooX0
POn1oh7oPOn1oh7oPOl1oool0:OonP21oo[o04B1oh7oPOn1oh7oQ_ol0:OonP21
oh7oPOn1oh7oPOn1o`7ooo`0Yooj087oPOn1oh7oPOn1oh7o0Oooo02WooX0POoj
o`1DPOn1oh7oPOn1ohKoo02Voo/0b_on0>con@21oh7oPOn1oh7oPOoFoo`0Y_ok
0<[ooP3/ooT0POn1oh7oPOn1oh7oe_ol0:Kon`3:ooh0k?oi0=7o0621oh7oPOn1
oh7oQ_ol0:KonP3PooX0loon0>oom021oh7oPOn1oh7oPOoHoo`0Y_oj0>3onP3c
ooh0kood087oPOn1oh7oPOn1omSoo02VooX0h?oj0??ooP3_oo@0dol0H87oPOn1
oh7oPOn6oo`0Y_oj0>3onP3dood0l?oa087oPOn1oh7oPOn1om[oo02VooX0h?oj
0?Coo@3`oo40POn1oh7oPOn1oh7of_ol0:KonP3PooX0m?om0?3ol@3Eo`1PPOn1
oh7oPOn1ohKoo02VooX0hOoi0?Coo@3aoo00POn1oh7oPOn1oh7of_ol0:KonP3Q
ooT0m?om0?7ol021oh7oPOn1oh7oPOoJoo`0Y_oj0>7on@3dood0lOo`0=Go06b1
oh7oPOn1oh7oQ_ol0:Kon@3RooX0m?ol0?;on`3joo/0POn1oh7oPOn1oh7ofool
0:Kon@3RooX0m?ol0?;on`3joo/0POn1oh7oPOn1oh7ofool0:Kon@3RooX0m?ol
0?;on`3joo/0e_l0K87oPOn1oh7oPOn6oo`0YOoj0>;onP3eoo/0look0?Ooo021
oh7oPOn1oh7oPOoLoo`0YOoj0>;onP3eoo/0look0?Ooo021oh7oPOn1oh7oPOoL
oo`0YOoj0>;onP3eoo/0look0?Ooo03Go`1/POn1oh7oPOn1ohKoo02UooX0hooi
0?Wom`3coo`0mOom087oPOn1oh7oPOn1omcoo02UooX0hooi0?Wom`3coo`0mOom
087oPOn1oh7oPOn1omcoo02UooX0hooi0?Wom`3coo`0mOom0=Oo06b1oh7oPOn1
oh7oQ_ol0:Gon@3TooX0nood0??oo@3doo`0POn1oh7oPOn1oh7ogOol0:Gon@3T
ooX0nood0??oo@3doo`0POn1oh7oPOn1oh7ogOol0:Gon@3TooX0nood0??oo@3d
oo`0f?l0K87oPOn1oh7oPOn6oo`0Y?oj0>Gon@3koo@0m?ol0??oo@21oh7oPOn1
oh7oPOoMoo`0Y?oj0>Gon@3koo@0m?ol0??oo@21oh7oPOn1oh7oPOoMoo`0Y?oj
0>Gon@3koo@0m?ol0??oo@3Ho`1/POn1oh7oPOn1ohKoo02TooT0i_oi0?_om03d
ood0l_om087oPOn1oh7oPOn1omgoo02TooT0i_oi0?_om03dood0l_om087oPOn1
oh7oPOn1omgoo02TooT0i_oi0?_om03dood0l_om0=So06b1oh7oPOn1oh7oQ_ol
0:?on@3XooT0lOom0?Coo@3bood0POn1oh7oPOn1oh7ogOol0:?on@3XooT0lOom
0?Coo@3bood0POn1oh7oPOn1oh7ogOol0:?on@3XooT0lOom0?Coo@3bood0f?l0
K87oPOn1oh7oPOn6oo`0Xooh0>[on@3`ood0m?om0?;oo@21oh7oPOn1oh7oPOoM
oo`0Xooh0>[on@3`ood0m?om0?;oo@21oh7oPOn1oh7oPOoMoo`0Xooh0>[on@3`
ood0m?om0?;oo@3Ho`1PPOn1oh7oPOn1ohKoo02RooP0k?oh0?3oo@3Qood0POn1
oh7oPOn1oh7ogOol0:;on03/ooP0l?om0>7oo@21oh7oPOn1oh7oPOoMoo`0X_oh
0>con03`ood0hOom0=So0621oh7oPOn1oh7oQ_ol0:7on03^ooP0koom0>;oo021
oh7oPOn1oh7oPOoMoo`0XOoh0>kon03_ood0h_ol087oPOn1oh7oPOn1omgoo02Q
ooP0k_oh0>ooo@3Roo`0f?l0H87oPOn1oh7oPOn6oo`0X?og0?;om`3^ood0hool
087oPOn1oh7oPOn1omcoo02PooL0l_og0>koo@3Soo`0POn1oh7oPOn1oh7og?ol
0:3om`3booL0k_om0>?oo03Go`1PPOn1oh7oPOn1ohKoo02OooD0n?oe0>goo@3T
oo/0POn1oh7oPOn1oh7og?ol09oom@3hooD0kOom0>Con`21oh7oPOn1oh7oPOoL
oo`0Wooe0?Som@3]ood0i?ok0=Oo05B1oh7oPOn1oh7oQ_ol09kohP3/ood0iOok
087oPOn1oh7oPOn1om_oo02Non80k?om0>Gon`21oh7oPOn1oh7oPOoKoo`0W_oR
0>coo@3Uoo/0e_l0E87oPOn1oh7oPOn6oo`0WOoT0>_oo@3WooX0POn1oh7oPOn1
oh7of_ol09goi03[ood0iooj087oPOn1oh7oPOn1om[oo02Mon@0joom0>OonP3E
o`1DPOn1oh7oPOn1ohKoo02LonH0j_om0>Won@21oh7oPOn1oh7oPOoIoo`0W?oV
0>[oo@3YooT0POn1oh7oPOn1oh7ofOol09coiP3Zood0jOoi0=Co05B1oh7oPOn1
oh7oQ_ol09[ojP3Xood0j_oi087oPOn1oh7oPOn1omSoo02JonX0j?om0>[on@21
oh7oPOn1oh7oPOoHoo`0V_oZ0>Soo@3ZooT0dol0E87oPOn1oh7oPOn6oo`0V?o_
0>Goo@3/ooT0POn1oh7oPOn1oh7oe_ol09Sok`3Uood0k?oi087oPOn1oh7oPOn1
omKoo02Honl0iOom0>con@3Ao`1DPOn1oh7oPOn1ohKoo02DooH0h_om0>kon021
oh7oPOn1oh7oPOoEoo`0U?of0>;oo@3^ooP0POn1oh7oPOn1oh7oeOol09ComP3R
ood0k_oh0=3o04j1oh7oPOn1oh7oQ_ol087oj_om0>oon@21oh7oPOn1oh7oPOoC
oo`0POoZood0kooi087oPOn1oh7oPOn1om?oo021on[oo@3_ooT0c_l0CX7oPOn1
oh7oPOn6oo`0POoZood0l?oj087oPOn1oh7oPOn1om7oo021on[oo@3`ooX0POn1
oh7oPOn1oh7odOol087oj_om0?3onP3<o`1>POn1oh7oPOn1ohKoo021on[oo@3a
oo/0POn1oh7oPOn1oh7ocool087oj_om0?7on`21oh7oPOn1oh7oPOo?oo`0POoZ
ood0lOok0<[o04j1oh7oPOn1oh7oQ_ol087oj_om0?;on`21oh7oPOn1oh7oPOo>
oo`0POoZood0l_ok087oPOn1oh7oPOn1olkoo021on[oo@3boo/0bOl0CX7oPOn1
oh7oPOn6oo`0POoZood0lool087oPOn1oh7oPOn1olcoo021on[oo@3coo`0POn1
oh7oPOn1oh7oc?ol087oj_om0??oo037o`1>POn1oh7oPOn1ohKoo021on[oo@3c
ood0POn1oh7oPOn1oh7obool087oj_om0??oo@21oh7oPOn1oh7oPOo;oo`0POoZ
ood0loom0<Ko04j1oh7oPOn1oh7oQ_ol087oj_om0?Coo@21oh7oPOn1oh7oPOo:
oo`0POoZood0m?om087oPOn1oh7oPOn1ol[oo021on[oo@3dood0aOl0CX7oPOn1
oh7oPOn6oo`0POoZood0m?om087oPOn1oh7oPOn1ol[oo021on[oo@3dood0POn1
oh7oPOn1oh7ob_ol087oj_om0?Coo@35o`1PPOn1oh7oPOn1ohKoo02Voo@0nOod
0>Ooo@3dooh0POn1oh7oPOn1oh7obOol0:Kom03ioo@0ioom0?CooP21oh7oPOn1
oh7oPOo9oo`0Y_od0?Wom03Wood0m?on0<Co0621oh7oPOn1oh7oQ_ol0:Kom03i
oo@0ioom0?Goj@21oh7oPOn1oh7oPOoMoo`0Y_od0?Wom03Wood0mOoY087oPOn1
oh7oPOn1omgoo02Voo@0nOod0>Ooo@3eonT0f?l0H87oPOn1oh7oPOn6oo`0Y_od
0?Wom03Wood0mOoY087oPOn1oh7oPOn1omgoo02Voo@0nOod0>Ooo@3eonT0POn1
oh7oPOn1oh7ogOol0:Kom03ioo@0ioom0?Goj@3Ho`1PPOn1oh7oPOn1ohKoo02V
oo@0nOod0>Ooo@3eonT0POn1oh7oPOn1oh7ogOol0:Kom03ioo@0ioom0?Goj@21
oh7oPOn1oh7oPOoMoo`0Y_od0?Wom03Wood0mOoY0=So0621oh7oPOn1oh7oQ_ol
0:Kom03ioo@0ioom0?Goj@21oh7oPOn1oh7oPOoMoo`0Y_od0?Wom03Wood0mOoY
087oPOn1oh7oPOn1omgoo02Voo@0nOod0>Ooo@3eonT0f?l0B87oPOn1oh7oPOn6
oo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom021oh7oPOn1oh7oPOnK
oo`0Y_od0?Wom02Fo`18POn1oh7oPOn1ohKoo02Voo@0nOod087oPOn1oh7oPOn1
oi_oo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod09Ko04R1oh7oPOn1
oh7oQ_ol0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0POn1oh7oPOn1
oh7oVool0:Kom03ioo@0U_l0B87oPOn1oh7oPOn6oo`0Y_od0?Wom021oh7oPOn1
oh7oPOnKoo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom02Fo`18POn1
oh7oPOn1ohKoo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod087oPOn1
oh7oPOn1oi_oo02Voo@0nOod09Ko04R1oh7oPOn1oh7oQ_ol0:Kom03ioo@0POn1
oh7oPOn1oh7oVool0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0U_l0
B87oPOn1oh7oPOn6oo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom021
oh7oPOn1oh7oPOnKoo`0Y_od0?Wom02Fo`18POn1oh7oPOn1ohKoo02Voo@0nOod
087oPOn1oh7oPOn1oi_oo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod
09Ko04R1oh7oPOn1oh7oQ_ol0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03i
oo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0U_l0B87oPOn1oh7oPOn6oo`0Y_od
0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od
0?Wom02Fo`18POn1oh7oPOn1ohKoo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02V
oo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod09Ko04R1oh7oPOn1oh7oQ_ol
0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0POn1oh7oPOn1oh7oVool
0:Kom03ioo@0U_l0B87oPOn1oh7oPOn6oo`0Y_od0?Wom021oh7oPOn1oh7oPOnK
oo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom02Fo`18POn1oh7oPOn1
ohKoo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod087oPOn1oh7oPOn1
oi_oo02Voo@0nOod09Ko04R1oh7oPOn1oh7oQ_ol0:Kom03ioo@0POn1oh7oPOn1
oh7oVool0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0U_l0B87oPOn1
oh7oPOn6oo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom021oh7oPOn1
oh7oPOnKoo`0Y_od0?Wom02Fo`18POn1oh7oPOn1ohKoo02Voo@0nOod087oPOn1
oh7oPOn1oi_oo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod09Ko04R1
oh7oPOn1oh7oQ_ol0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0POn1
oh7oPOn1oh7oVool0:Kom03ioo@0U_l0B87oPOn1oh7oPOn6oo`0Y_od0?Wom021
oh7oPOn1oh7oPOnKoo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom02F
o`18POn1oh7oPOn1ohKoo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod
087oPOn1oh7oPOn1oi_oo02Voo@0nOod09Ko04R1oh7oPOn1oh7oQ_ol0:Kom03i
oo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03i
oo@0U_l0B87oPOn1oh7oPOn6oo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od
0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom02Fo`18POn1oh7oPOn1ohKoo02V
oo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02V
oo@0nOod09Ko04R1oh7oPOn1oh7oQ_ol0:Kom03ioo@0POn1oh7oPOn1oh7oVool
0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0U_l0B87oPOn1oh7oPOn6
oo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom021oh7oPOn1oh7oPOnK
oo`0Y_od0?Wom02Fo`18POn1oh7oPOn1ohKoo02Voo@0nOod087oPOn1oh7oPOn1
oi_oo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod09Ko04R1oh7oPOn1
oh7oQ_ol0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0POn1oh7oPOn1
oh7oVool0:Kom03ioo@0U_l0B87oPOn1oh7oPOn6oo`0Y_od0?Wom021oh7oPOn1
oh7oPOnKoo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom02Fo`18POn1
oh7oPOn1ohKoo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod087oPOn1
oh7oPOn1oi_oo02Voo@0nOod09Ko04R1oh7oPOn1oh7oQ_ol0:Kom03ioo@0POn1
oh7oPOn1oh7oVool0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0U_l0
B87oPOn1oh7oPOn6oo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom021
oh7oPOn1oh7oPOnKoo`0Y_od0?Wom02Fo`18POn1oh7oPOn1ohKoo02Voo@0nOod
087oPOn1oh7oPOn1oi_oo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod
09Ko04R1oh7oPOn1oh7oQ_ol0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03i
oo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0U_l0B87oPOn1oh7oPOn6oo`0Y_od
0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od
0?Wom02Fo`18POn1oh7oPOn1ohKoo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02V
oo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod09Ko04R1oh7oPOn1oh7oQ_ol
0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0POn1oh7oPOn1oh7oVool
0:Kom03ioo@0U_l0B87oPOn1oh7oPOn6oo`0Y_od0?Wom021oh7oPOn1oh7oPOnK
oo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom02Fo`18POn1oh7oPOn1
ohKoo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod087oPOn1oh7oPOn1
oi_oo02Voo@0nOod09Ko04R1oh7oPOn1oh7oQ_ol0:Kom03ioo@0POn1oh7oPOn1
oh7oVool0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0U_l0B87oPOn1
oh7oPOn6oo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom021oh7oPOn1
oh7oPOnKoo`0Y_od0?Wom02Fo`18POn1oh7oPOn1ohKoo02Voo@0nOod087oPOn1
oh7oPOn1oi_oo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod09Ko04R1
oh7oPOn1oh7oQ_ol0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0POn1
oh7oPOn1oh7oVool0:Kom03ioo@0U_l0B87oPOn1oh7oPOn6oo`0Y_od0?Wom021
oh7oPOn1oh7oPOnKoo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom02F
o`18POn1oh7oPOn1ohKoo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod
087oPOn1oh7oPOn1oi_oo02Voo@0nOod09Ko04R1oh7oPOn1oh7oQ_ol0:Kom03i
oo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03i
oo@0U_l0B87oPOn1oh7oPOn6oo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od
0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom02Fo`18POn1oh7oPOn1ohKoo02V
oo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02V
oo@0nOod09Ko04R1oh7oPOn1oh7oQ_ol0:Kom03ioo@0POn1oh7oPOn1oh7oVool
0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0U_l0B87oPOn1oh7oPOn6
oo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom021oh7oPOn1oh7oPOnK
oo`0Y_od0?Wom02Fo`1>POn1oh7oPOn1ohSon02Xoo@0nOod09Oo0021oh7oPOn1
oh7oR?oh0:Som03ioo@0Uol0087oPOn1oh7oPOn8ooP0Z?od0?Wom02Go`000561
oh7oPOn1oh7oROoe0:[om03ioo@0V?l10021oh7oPOn1oh7oROoe0:[om03ioo@0
V?l10021oh7oPOn1oh7oROoe0:[om03ioo@0V?l10000CX7oPOn1oh7oPOn;oo80
Zood0?Wom02Jood0POn1oh7oPOn1oh_olP2[oo@0nOod09[oo@21oh7oPOn1oh7o
Roob0:_om03ioo@0V_om001>POn1oh7oPOn1oh_ol@2/oo@0nOod09_oo021oh7o
POn1oh7oRooa0:com03ioo@0Vool087oPOn1oh7oPOn;oo40[?od0?Wom02Koo`0
04j1oh7oPOn1oh7oS?o`0:com03ioo@0Vool087oPOn1oh7oPOn<oo00[?od0?Wo
m02Koo`0POn1oh7oPOn1ohcol02/oo@0nOod09_oo000CX7oPOn1oh7oPOn=onh0
[Ood0?Wom02Loo/0POn1oh7oPOn1ohgokP2]oo@0nOod09con`21oh7oPOn1oh7o
SOo^0:gom03ioo@0W?ok001>POn1oh7oPOn1ohgokP2]oo@0nOod09gonP21oh7o
POn1oh7oSOo^0:gom03ioo@0WOoj087oPOn1oh7oPOn=onh0[Ood0?Wom02MooX0
03J1oh7oPOn1oh7oSOn=0?WoR@21oh7oPOn1oh7oSOn=0?WoR@21oh7oPOn1oh7o
SOn=0?WoR@00=X7oPOn1oh7oPOn>oh`0nOn9087oPOn1oh7oPOn>oh`0nOn9087o
POn1oh7oPOn>oh`0nOn9000fPOn1oh7oPOn1ohkoS03iohT0POn1oh7oPOn1ohko
S03iohT0POn1oh7oPOn1ohkoS03iohT003J1oh7oPOn1oh7oS_n<0?WoR@21oh7o
POn1oh7oS_n<0?WoR@21oh7oPOn1oh7oS_n<0?WoR@00=X7oPOn1oh7oPOn>oh`0
nOn9087oPOn1oh7oPOn>oh`0nOn9087oPOn1oh7oPOn>oh`0nOn9001>POn1oh7o
POn1ohgok@2^oo@0nOod09gonP21oh7oPOn1oh7oSOo]0:kom03ioo@0WOoj087o
POn1oh7oPOn=ond0[_od0?Wom02MooX004j1oh7oPOn1oh7oSOo^0:gom03ioo@0
WOoj087oPOn1oh7oPOn=onh0[Ood0?Wom02MooX0POn1oh7oPOn1ohgokP2]oo@0
nOod09gonP00CX7oPOn1oh7oPOn=onh0[Ood0?Wom02MooX0POn1oh7oPOn1ohgo
kP2]oo@0nOod09gonP21oh7oPOn1oh7oSOo^0:gom03ioo@0WOoj001>POn1oh7o
POn1ohcol02/oo@0nOod09con`21oh7oPOn1oh7oS?o`0:com03ioo@0W?ok087o
POn1oh7oPOn<oo00[?od0?Wom02Loo/005Z1oh7oPOn1oh7oRooa0?CooP2loo@0
nOod09_oo021oh7oPOn1oh7oRooa0?CooP2loo@0nOod09_oo021oh7oPOn1oh7o
Rooa0?CooP2loo@0nOod09_oo000FX7oPOn1oh7oPOn;oo80loon0;com03ioo@0
V_om087oPOn1oh7oPOn;oo80loon0;com03ioo@0V_om087oPOn1oh7oPOn;oo80
loon0;com03ioo@0V_om001MPOn1oh7oPOn1ohWom@3cood0_?od0?Wom02Ho`40
087oPOn1oh7oPOn9ooD0loom0;com03ioo@0V?l10021oh7oPOn1oh7oROoe0??o
o@2loo@0nOod09So0@0005Z1oh7oPOn1oh7oQooi0?7oo@2loo@0nOod09Oo0021
oh7oPOn1oh7oQooi0?7oo@2loo@0nOod09Oo0021oh7oPOn1oh7oQooi0?7oo@2l
oo@0nOod09Oo0000E87oPOn1oh7oPOn6oo`0l?ol0;com03ioo@0POn1oh7oPOn1
oh7oVool0?3oo02loo@0nOod087oPOn1oh7oPOn1oi_oo03`oo`0_?od0?Wom02F
o`1DPOn1oh7oPOn1ohKoo03aoo/0_?od0?Wom021oh7oPOn1oh7oPOnKoo`0lOok
0;com03ioo@0POn1oh7oPOn1oh7oVool0?7on`2loo@0nOod09Ko05B1oh7oPOn1
oh7oQ_ol0?Gom`2loo@0nOod087oPOn1oh7oPOn1oi_oo03eooL0_?od0?Wom021
oh7oPOn1oh7oPOnKoo`0mOog0;com03ioo@0U_l0E87oPOn1oh7oPOn6oo`0n?od
0;com03ioo@0POn1oh7oPOn1oh7oVool0?Som02loo@0nOod087oPOn1oh7oPOn1
oi_oo03hoo@0_?od0?Wom02Fo`1DPOn1oh7oPOn1ohKoo03hoo@0_?od0?Wom021
oh7oPOn1oh7oPOnKoo`0n?od0;com03ioo@0POn1oh7oPOn1oh7oVool0?Som02l
oo@0nOod09Ko05B1oh7oPOn1oh7oQ_ol0?Som02loo@0nOod087oPOn1oh7oPOn1
oi_oo03hoo@0_?od0?Wom021oh7oPOn1oh7oPOnKoo`0n?od0;com03ioo@0U_l0
E87oPOn1oh7oPOn6oo`0koom0;com03ioo@0POn1oh7oPOn1oh7oVool0>ooo@2l
oo@0nOod087oPOn1oh7oPOn1oi_oo03_ood0_?od0?Wom02Fo`1DPOn1oh7oPOn1
ohKoo03_ood0_?od0?Wom021oh7oPOn1oh7oPOnKoo`0koom0;com03ioo@0POn1
oh7oPOn1oh7oVool0>ooo@2loo@0nOod09Ko05B1oh7oPOn1oh7oQ_ol0>ooo@2l
oo@0nOod087oPOn1oh7oPOn1oi_oo03_ood0_?od0?Wom021oh7oPOn1oh7oPOnK
oo`0koom0;com03ioo@0U_l0E87oPOn1oh7oPOn6oo`0koom0;com03ioo@0POn1
oh7oPOn1oh7oVool0>ooo@2loo@0nOod087oPOn1oh7oPOn1oi_oo03_ood0_?od
0?Wom02Fo`1DPOn1oh7oPOn1ohKoo03_ood0_?od0?Wom021oh7oPOn1oh7oPOnK
oo`0koom0;com03ioo@0POn1oh7oPOn1oh7oVool0>ooo@2loo@0nOod09Ko05B1
oh7oPOn1oh7oQ_ol0>ooo@2loo@0nOod087oPOn1oh7oPOn1oi_oo03_ood0_?od
0?Wom021oh7oPOn1oh7oPOnKoo`0koom0;com03ioo@0U_l0E87oPOn1oh7oPOn6
oo`0koom0;com03ioo@0POn1oh7oPOn1oh7oVool0>ooo@2loo@0nOod087oPOn1
oh7oPOn1oi_oo03_ood0_?od0?Wom02Fo`1DPOn1oh7oPOn1ohKoo03_ood0_?od
0?Wom021oh7oPOn1oh7oPOnKoo`0koom0;com03ioo@0POn1oh7oPOn1oh7oVool
0>ooo@2loo@0nOod09Ko05B1oh7oPOn1oh7oQ_ol0>ooo@2loo@0nOod087oPOn1
oh7oPOn1oi_oo03_ood0_?od0?Wom021oh7oPOn1oh7oPOnKoo`0koom0;com03i
oo@0U_l0E87oPOn1oh7oPOn6oo`0koom0;com03ioo@0POn1oh7oPOn1oh7oVool
0>ooo@2loo@0nOod087oPOn1oh7oPOn1oi_oo03_ood0_?od0?Wom02Fo`1DPOn1
oh7oPOn1ohKoo03_ood0_?od0?Wom021oh7oPOn1oh7oPOnKoo`0koom0;com03i
oo@0POn1oh7oPOn1oh7oVool0>ooo@2loo@0nOod09Ko05B1oh7oPOn1oh7oQ_ol
0>ooo@2loo@0nOod087oPOn1oh7oPOn1oi_oo03_ood0_?od0?Wom021oh7oPOn1
oh7oPOnKoo`0koom0;com03ioo@0U_l0E87oPOn1oh7oPOn6oo`0koom0;com03i
oo@0POn1oh7oPOn1oh7oVool0>ooo@2loo@0nOod087oPOn1oh7oPOn1oi_oo03_
ood0_?od0?Wom02Fo`1DPOn1oh7oPOn1ohKoo03_ood0_?od0?Wom021oh7oPOn1
oh7oPOnKoo`0koom0;com03ioo@0POn1oh7oPOn1oh7oVool0>ooo@2loo@0nOod
09Ko05B1oh7oPOn1oh7oQ_ol0>ooo@2loo@0nOod087oPOn1oh7oPOn1oi_oo03_
ood0_?od0?Wom021oh7oPOn1oh7oPOnKoo`0koom0;com03ioo@0U_l0E87oPOn1
oh7oPOn6oo`0koom0;com03ioo@0POn1oh7oPOn1oh7oVool0>ooo@2loo@0nOod
087oPOn1oh7oPOn1oi_oo03_ood0_?od0?Wom02Fo`1DPOn1oh7oPOn1ohKoo03_
ood0_?od0?Wom021oh7oPOn1oh7oPOnKoo`0koom0;com03ioo@0POn1oh7oPOn1
oh7oVool0>ooo@2loo@0nOod09Ko05B1oh7oPOn1oh7oQ_ol0>ooo@2loo@0nOod
087oPOn1oh7oPOn1oi_oo03_ood0_?od0?Wom021oh7oPOn1oh7oPOnKoo`0koom
0;com03ioo@0U_l0E87oPOn1oh7oPOn6oo`0koom0;com03ioo@0POn1oh7oPOn1
oh7oVool0>ooo@2loo@0nOod087oPOn1oh7oPOn1oi_oo03_ood0_?od0?Wom02F
o`1DPOn1oh7oPOn1ohKoo03_ood0_?od0?Wom021oh7oPOn1oh7oPOnKoo`0koom
0;com03ioo@0POn1oh7oPOn1oh7oVool0>ooo@2loo@0nOod09Ko05B1oh7oPOn1
oh7oQ_ol0>ooo@2loo@0nOod087oPOn1oh7oPOn1oi_oo03_ood0_?od0?Wom021
oh7oPOn1oh7oPOnKoo`0koom0;com03ioo@0U_l0E87oPOn1oh7oPOn6oo`0koom
0;com03ioo@0POn1oh7oPOn1oh7oVool0>ooo@2loo@0nOod087oPOn1oh7oPOn1
oi_oo03_ood0_?od0?Wom02Fo`1DPOn1oh7oPOn1ohKoo03_ood0_?od0?Wom021
oh7oPOn1oh7oPOnKoo`0koom0;com03ioo@0POn1oh7oPOn1oh7oVool0>ooo@2l
oo@0nOod09Ko05B1oh7oPOn1oh7oQ_ol0>ooo@2loo@0nOod087oPOn1oh7oPOn1
oi_oo03_ood0_?od0?Wom021oh7oPOn1oh7oPOnKoo`0koom0;com03ioo@0U_l0
E87oPOn1oh7oPOn6oo`0koom0;com03ioo@0POn1oh7oPOn1oh7oVool0>ooo@2l
oo@0nOod087oPOn1oh7oPOn1oi_oo03_ood0_?od0?Wom02Fo`18POn1oh7oPOn1
ohKoo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod087oPOn1oh7oPOn1
oi_oo02Voo@0nOod09Ko04R1oh7oPOn1oh7oQ_ol0:Kom03ioo@0POn1oh7oPOn1
oh7oVool0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0U_l0B87oPOn1
oh7oPOn6oo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom021oh7oPOn1
oh7oPOnKoo`0Y_od0?Wom02Fo`18POn1oh7oPOn1ohKoo02Voo@0nOod087oPOn1
oh7oPOn1oi_oo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod09Ko04R1
oh7oPOn1oh7oQ_ol0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0POn1
oh7oPOn1oh7oVool0:Kom03ioo@0U_l0B87oPOn1oh7oPOn6oo`0Y_od0?Wom021
oh7oPOn1oh7oPOnKoo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom02F
o`18POn1oh7oPOn1ohKoo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod
087oPOn1oh7oPOn1oi_oo02Voo@0nOod09Ko04R1oh7oPOn1oh7oQ_ol0:Kom03i
oo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03i
oo@0U_l0B87oPOn1oh7oPOn6oo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od
0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom02Fo`18POn1oh7oPOn1ohKoo02V
oo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02V
oo@0nOod09Ko04R1oh7oPOn1oh7oQ_ol0:Kom03ioo@0POn1oh7oPOn1oh7oVool
0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0U_l0B87oPOn1oh7oPOn6
oo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom021oh7oPOn1oh7oPOnK
oo`0Y_od0?Wom02Fo`18POn1oh7oPOn1ohKoo02Voo@0nOod087oPOn1oh7oPOn1
oi_oo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod09Ko04R1oh7oPOn1
oh7oQ_ol0:Kom03ioo@0POn1oh7oPOn1oh7oVool0:Kom03ioo@0POn1oh7oPOn1
oh7oVool0:Kom03ioo@0U_l0B87oPOn1oh7oPOn6oo`0Y_od0?Wom021oh7oPOn1
oh7oPOnKoo`0Y_od0?Wom021oh7oPOn1oh7oPOnKoo`0Y_od0?Wom02Fo`18POn1
oh7oPOn1ohKoo02Voo@0nOod087oPOn1oh7oPOn1oi_oo02Voo@0nOod087oPOn1
oh7oPOn1oi_oo02Voo@0nOod09Ko03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1
ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1
oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol
087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1
ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1
oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol
087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1
ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1
oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol
087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1
ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1
oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol
087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1
ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1
oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol
087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1
ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1
oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol
087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1
oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1
ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1
oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol
087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1
oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ol3oR02Aol<0POn1oh7oPOn1ol3oR02A
ol<0POn1oh7oPOn1ol3oR02Aol<003J1oh7oPOn1oh7o`?n8097o``21oh7oPOn1
oh7o`?n8097o``21oh7oPOn1oh7o`?n8097o``00=X7oPOn1oh7oPOo0ohP0TOo3
087oPOn1oh7oPOo0ohP0TOo3087oPOn1oh7oPOo0ohP0TOo3000fPOn1oh7oPOn1
ol3oR02Aol<0POn1oh7oPOn1ol3oR02Aol<0POn1oh7oPOn1ol3oR02Aol<003J1
oh7oPOn1oh7o`?n8097o``21oh7oPOn1oh7o`?n8097o``21oh7oPOn1oh7o`?n8
097o``00=X7oPOn1oh7oPOo0ohP0TOo3087oPOn1oh7oPOo0ohP0TOo3087oPOn1
oh7oPOo0ohP0TOo3000fPOn1oh7oPOn1ol3oR02Aol<0POn1oh7oPOn1ol3oR02A
ol<0POn1oh7oPOn1ol3oR02Aol<003J1oh7oPOn1oh7o`?n8097o``21oh7oPOn1
oh7o`?n8097o``21oh7oPOn1oh7o`?n8097o``00=X7oPOn1oh7oPOo0ohP0TOo3
087oPOn1oh7oPOo0ohP0TOo3087oPOn1oh7oPOo0ohP0TOo3000fPOn1oh7oPOn1
ol3oR02Aol<0POn1oh7oPOn1ol3oR02Aol<0POn1oh7oPOn1ol3oR02Aol<003J1
oh7oPOn1oh7o`?n8097o``21oh7oPOn1oh7o`?n8097o``21oh7oPOn1oh7o`?n8
097o``00=X7oPOn1oh7oPOo0ohP0TOo3087oPOn1oh7oPOo0ohP0TOo3087oPOn1
oh7oPOo0ohP0TOo3000fPOn1oh7oPOn1ol3oR02Aol<0POn1oh7oPOn1ol3oR02A
ol<0POn1oh7oPOn1ol3oR02Aol<00321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0=X7oPOn1
oh7oPOo0ohP0TOo3087oPOn1oh7oPOo0ohP0TOo3087oPOn1oh7oPOo0ohP0TOo3
000fPOn1oh7oPOn1ol3oR02Aol<0POn1oh7oPOn1ol3oR02Aol<0POn1oh7oPOn1
ol3oR02Aol<003J1oh7oPOn1oh7o`?n8097o``21oh7oPOn1oh7o`?n8097o``21
oh7oPOn1oh7o`?n8097o``00=X7oPOn1oh7oPOo0ohP0TOo3087oPOn1oh7oPOo0
ohP0TOo3087oPOn1oh7oPOo0ohP0TOo3000fPOn1oh7oPOn1ol3oR02Aol<0POn1
oh7oPOn1ol3oR02Aol<0POn1oh7oPOn1ol3oR02Aol<003J1oh7oPOn1oh7o`?n8
097o``21oh7oPOn1oh7o`?n8097o``21oh7oPOn1oh7o`?n8097o``00=X7oPOn1
oh7oPOo0ohP0TOo3087oPOn1oh7oPOo0ohP0TOo3087oPOn1oh7oPOo0ohP0TOo3
000fPOn1oh7oPOn1ol3oR02Aol<0POn1oh7oPOn1ol3oR02Aol<0POn1oh7oPOn1
ol3oR02Aol<003J1oh7oPOn1oh7o`?n8097o``21oh7oPOn1oh7o`?n8097o``21
oh7oPOn1oh7o`?n8097o``00CX7oPOn1oh7oPOodooH0f?n80;comP3Qol<0POn1
oh7oPOn1ooComP3HohP0_?of0>7o``21oh7oPOn1oh7om?of0=SoR02looH0hOo3
001>POn1oh7oPOn1ooSokP3LohP0`?o^0>Go``21oh7oPOn1oh7on?o^0=coR030
onh0iOo3087oPOn1oh7oPOohonh0g?n80<3okP3Uol<004j1oh7oPOn1oh7on_oZ
0=koR032onX0ioo3087oPOn1oh7oPOojonX0g_n80<;ojP3Wol<0POn1oh7oPOn1
oo[ojP3NohP0`_oZ0>Oo``00CX7oPOn1oh7oPOolonH0h?n80<CoiP3Yol<0POn1
oh7oPOn1oocoiP3PohP0a?oV0>Wo``21oh7oPOn1oh7oo?oV0>3oR034onH0jOo3
0014POn1oh7oPOn1ookoh`2Woo`0S?oS087oPOn1oh7oPOnYon<0Yool08coh`21
oh7oPOn1oh7oZOoS0:Ooo02<on<0[?l0AH7oPOn1oh7oPOl1oooP0:Woo02=on00
POn1oh7oPOn1ojcoh02Yoo`0SOoP087oPOn1oh7oPOn/on00ZOol08goh02^o`1L
POn1oh7oPOn1o`3om03hoo@0Z_ol08kom03hoo@0POn1oh7oPOn1ojkom03hoo@0
Z_ol08kom03hoo@0POn1oh7oPOn1ojkom03hoo@0Z_ol08kom03hoo@0[ol0FX7o
POn1oh7oPOof0?;om`2Zoo`0Soof0?;om`21oh7oPOn1oh7o[oof0?;om`2Zoo`0
Soof0?;om`21oh7oPOn1oh7o[oof0?;om`2Zoo`0Soof0?;om`2_o`1JPOn1oh7o
POn2ooL0k_oh0:_oo02@ooL0k_oh087oPOn1oh7oPOnaooL0k_oh0:_oo02@ooL0
k_oh087oPOn1oh7oPOnaooL0k_oh0:_oo02@ooL0k_oh0;3o05Z1oh7oPOn1oh?o
n03[ooP0[?ol097on03[ooP0POn1oh7oPOn1ok?on03[ooP0[?ol097on03[ooP0
POn1oh7oPOn1ok?on03[ooP0[?ol097on03[ooP0/Ol0FX7oPOn1oh7oPooi0>Wo
n02]oo`0TOoi0>Won021oh7oPOn1oh7o]?oi0>Won02]oo`0TOoi0>Won021oh7o
POn1oh7o]?oi0>Won02]oo`0TOoi0>Won02bo`1JPOn1oh7oPOn4ooT0iooi0:go
o02BooT0iooi087oPOn1oh7oPOneooT0iooi0:goo02BooT0iooi087oPOn1oh7o
POneooT0iooi0:goo02BooT0iooi0;;o05Z1oh7oPOn1ohGon@3UooT0[_ol09?o
n@3UooT0POn1oh7oPOn1okOon@3UooT0[_ol09?on@3UooT0POn1oh7oPOn1okOo
n@3UooT0[_ol09?on@3UooT0/ol0FX7oPOn1oh7oQOoi0>Gon@2^oo`0Tooi0>Go
n@21oh7oPOn1oh7o]ooi0>Gon@2^oo`0Tooi0>Gon@21oh7oPOn1oh7o]ooi0>Go
n@2^oo`0Tooi0>Gon@2co`1JPOn1oh7oPOn6ooT0hooj0:koo02DooT0hooj087o
POn1oh7oPOnhooT0hooj0:koo02DooT0hooj087oPOn1oh7oPOnhooT0hooj0:ko
o02DooT0hooj0;?o05Z1oh7oPOn1ohKon@3SooT0[ool09Con@3SooT0POn1oh7o
POn1okWon@3SooT0[ool09Con@3SooT0POn1oh7oPOn1okWon@3SooT0[ool09Co
n@3SooT0]?l0FX7oPOn1oh7oQ_oj0>7onP2_oo`0U?oj0>7onP21oh7oPOn1oh7o
^Ooj0>7onP2_oo`0U?oj0>7onP21oh7oPOn1oh7o^Ooj0>7onP2_oo`0U?oj0>7o
nP2do`1JPOn1oh7oPOn7ooT0hOoj0:ooo02EooT0hOoj087oPOn1oh7oPOnjooT0
hOoj0:ooo02EooT0hOoj087oPOn1oh7oPOnjooT0hOoj0:ooo02EooT0hOoj0;Co
04:1oh7oPOn1ohOonP27oo`0UOoj087oPOn1oh7oPOnBooX0Qool09GonP21oh7o
POn1oh7oT_oj08Ooo02EooX0S?l0@X7oPOn1oh7oQooj08Ooo02EooX0POn1oh7o
POn1oi;onP27oo`0UOoj087oPOn1oh7oPOnBooX0Qool09GonP2<o`12POn1oh7o
POn7ooX0Qool09GonP21oh7oPOn1oh7oT_oj08Ooo02EooX0POn1oh7oPOn1oi;o
nP27oo`0UOoj08co04:1oh7oPOn1ohSon@27oo`0U_oi087oPOn1oh7oPOnCooT0
Qool09Kon@21oh7oPOn1oh7oTooi08Ooo02FooT0S?l0@X7oPOn1oh7oR?oj08Ko
o02FooX0POn1oh7oPOn1oi;onP26oo`0U_oj087oPOn1oh7oPOnBooX0Q_ol09Ko
nP2;o`12POn1oh7oPOn8ooX0Q_ol09KonP21oh7oPOn1oh7oT_oj08Koo02FooX0
POn1oh7oPOn1oi;onP26oo`0U_oj08_o04:1oh7oPOn1ohSonP26oo`0U_oj087o
POn1oh7oPOnBooX0Q_ol09KonP21oh7oPOn1oh7oT_oj08Koo02FooX0Rol0@X7o
POn1oh7oR?oj08Koo02FooX0POn1oh7oPOn1oi;onP26oo`0U_oj087oPOn1oh7o
POnBooX0Q_ol09KonP2;o`12POn1oh7oPOn8ooX0Q_ol09KonP21oh7oPOn1oh7o
T_oj08Koo02FooX0POn1oh7oPOn1oi;onP26oo`0U_oj08_o04:1oh7oPOn1ohSo
nP26oo`0U_oj087oPOn1oh7oPOnBooX0Q_ol09KonP21oh7oPOn1oh7oT_oj08Ko
o02FooX0Rol0@X7oPOn1oh7oR?oj08Koo02FooX0POn1oh7oPOn1oi;onP26oo`0
U_oj087oPOn1oh7oPOnBooX0Q_ol09KonP2;o`12POn1oh7oPOn8ooX0Q_ol09Ko
nP21oh7oPOn1oh7oT_oj08Koo02FooX0POn1oh7oPOn1oi;onP26oo`0U_oj08_o
04:1oh7oPOn1ohSonP26oo`0U_oj087oPOn1oh7oPOnBooX0Q_ol09KonP21oh7o
POn1oh7oT_oj08Koo02FooX0Rol0@X7oPOn1oh7oR?oj08Koo02FooX0POn1oh7o
POn1oi;onP26oo`0U_oj087oPOn1oh7oPOnBooX0Q_ol09KonP2;o`12POn1oh7o
POn8ooX0Q_ol09KonP21oh7oPOn1oh7oT_oj08Koo02FooX0POn1oh7oPOn1oi;o
nP26oo`0U_oj08_o04:1oh7oPOn1ohSonP26oo`0U_oj087oPOn1oh7oPOnBooX0
Q_ol09KonP21oh7oPOn1oh7oT_oj08Koo02FooX0Rol0LX7oPOn1oh7oQook0<[o
oP3]ooT0g?ol09Gon`3<ooT0k_oi087oPOn1oh7oPOoYoo/0b_on0>gon@3Loo`0
UOok0<con@3^ooT0POn1oh7oPOn1onWon`3:ooh0kOoi0=coo02Eoo/0c?oi0>ko
n@3So`2:POn1oh7oPOn7ooX0h?oj0??ooP3_ooD0g_ol09GonP3PooX0n?od0?;o
m@21oh7oPOn1oh7ojooj0>3onP3cooh0kooe0=koo02EooX0h?oj0?Som03booD0
POn1oh7oPOn1on_onP3PooX0loon0>oom@3Noo`0UOoj0>3onP3hoo@0l_oe0>Go
08Z1oh7oPOn1ohOonP3PooX0m?om0?3ol`3Ooo`0UOoj0>3onP3ioo40mOoc087o
POn1oh7oPOo/ooX0h?oj0?Coo@3`oo<0gool09GonP3PooX0nOoa0?Gol`21oh7o
POn1oh7ok?oj0>3onP3dood0l?oc0=ooo02EooX0h?oj0?Wol@3eoo<0i_l0RX7o
POn1oh7oQooj0>7on@3dood0lOoa0>3oo02EooX0hOoi0?[ol03foo40POn1oh7o
POn1ongonP3QooT0m?om0?7ol@3Poo`0UOoj0>7on@3joo00m_oa087oPOn1oh7o
POo]ooX0hOoi0?Coo@3aoo40h?ol09GonP3QooT0n_o`0?Kol@3Wo`2^POn1oh7o
POn7ooT0h_oj0?Coo03boo/0nook0>7oo02EooT0h_oj0?[on`3joo/0n?ok0?_o
n`21oh7oPOn1oh7ok_oi0>;onP3doo`0l_ok0?_on`3Qoo`0UOoi0>;onP3joo/0
n_ok0?Son`3koo/0POn1oh7oPOn1onkon@3RooX0m?ol0?;on`3koo/0hOol09Go
n@3RooX0n_ok0?[on`3hoo/0nook0>So0:j1oh7oPOn1ohKonP3RooX0mOok0?;o
o03hoo`0h_ol09ConP3RooX0nook0?Ooo03ioo`0n?ol087oPOn1oh7oPOo^ooX0
h_oj0?Gon`3boo`0n?ol0>;oo02DooX0h_oj0?_on`3goo`0nOol0?Soo021oh7o
POn1oh7ok_oj0>;onP3eoo/0l_ol0?Soo03Roo`0U?oj0>;onP3koo/0mool0?Wo
o03hoo`0jOl0[X7oPOn1oh7oQ_oj0>?on@3iooL0lool0?Koo@3Roo`0U?oj0>?o
n@3koo`0mOom0?[oo03food0POn1oh7oPOn1onkonP3SooT0nOog0??oo03food0
h_ol09ConP3SooT0nool0?Goo@3joo`0m_om087oPOn1oh7oPOo^ooX0hooi0?Wo
m`3coo`0m_om0>;oo02DooX0hooi0?_oo03eood0n_ol0?Koo@3Yo`2^POn1oh7o
POn6ooT0i?oj0?_om03cood0mOol0>?oo02DooT0i?oj0?[oo@3doo`0noom0?Go
o021oh7oPOn1oh7okooi0>ConP3koo@0loom0?Goo03Soo`0U?oi0>ConP3jood0
m?ol0?_oo@3eoo`0POn1oh7oPOn1onoon@3TooX0nood0??oo@3eoo`0hool09Co
n@3TooX0n_om0?Coo03kood0mOol0>[o0:j1oh7oPOn1ohGonP3UooT0nood0?Co
o03dood0hool09?onP3UooT0nool0??oo@3loo`0m?om087oPOn1oh7oPOo^ooX0
iOoi0?_om03doo`0m?om0>?oo02CooX0iOoi0?_oo03cood0o?ol0?Coo@21oh7o
POn1oh7ok_oj0>Gon@3koo@0m?ol0?Coo@3Soo`0Tooj0>Gon@3koo`0loom0?co
o03dood0j_l0[X7oPOn1oh7oQOoi0>Kon@3koo@0m?om0??oo@3Soo`0Tooi0>Ko
n@3kood0l_om0?coo@3cood0POn1oh7oPOn1onkon@3VooT0nood0?Coo@3cood0
hool09?on@3VooT0noom0?;oo@3lood0loom087oPOn1oh7oPOo^ooT0i_oi0?_o
m03dood0loom0>?oo02CooT0i_oi0?_oo@3bood0o?om0??oo@3Zo`2^POn1oh7o
POn4ooT0j?oi0?7oo@3dood0loom0>?oo02BooT0j?oi0?[oo@3bood0o?om0??o
o@21oh7oPOn1oh7okOoi0>Son@3aood0m?om0??oo@3Soo`0T_oi0>Son@3jood0
l_om0?coo@3cood0POn1oh7oPOn1ongon@3XooT0lOom0?Coo@3cood0hool09;o
n@3XooT0n_om0?;oo@3lood0loom0>[o0:j1oh7oPOn1ohCon03ZooT0l?om0?Co
o@3coo`0i?ol09;on03ZooT0nOom0?;oo@3lood0lool087oPOn1oh7oPOo^ooP0
j_oi0?3oo@3dood0lool0>Coo02BooP0j_oi0?Woo@3bood0o?om0??oo021oh7o
POn1oh7ok_oh0>[on@3`ood0m?om0??oo03Too`0T_oh0>[on@3iood0l_om0?co
o@3coo`0jol0XX7oPOn1oh7oPooh0>con03`ood0mOom0?7oo@3Too`0TOoh0>co
n03Vood0oOom0?7oo@21oh7oPOn1oh7okOoh0>con03`ood0mOom0?7oo@3Too`0
TOoh0>con03Vood0oOom0?7oo@21oh7oPOn1oh7okOoh0>con03`ood0mOom0?7o
o@3Too`0TOoh0>con03Vood0oOom0?7oo@3[o`2RPOn1oh7oPOn2ooP0k_oh0>oo
o@3eood0lOom0>Coo02@ooP0k_oh0>Koo03mood0lOom087oPOn1oh7oPOo/ooP0
k_oh0>ooo@3eood0lOom0>Coo02@ooP0k_oh0>Koo03mood0lOom087oPOn1oh7o
POo/ooP0k_oh0>ooo@3eood0lOom0>Coo02@ooP0k_oh0>Koo03mood0lOom0>_o
0::1oh7oPOn1oh7om`3booL0k_om0?Goo@3aood0i?ol08oom`3booL0i_ol0?co
o@3aood0POn1oh7oPOn1on_om`3booL0k_om0?Goo@3aood0i?ol08oom`3booL0
i_ol0?coo@3aood0POn1oh7oPOn1on_om`3booL0k_om0?Goo@3aood0i?ol08oo
m`3booL0i_ol0?coo@3aood0jol0Y87oPOn1oh7oPOl0ooD0n?oe0>goo@3eood0
lOom0>Coo02>ooD0n?oe0>Kon`3lood0lOom087oPOn1oh7oPOoZooD0n?oe0>go
o@3eood0lOom0>Coo02>ooD0n?oe0>Kon`3lood0lOom087oPOn1oh7oPOoZooD0
n?oe0>goo@3eood0lOom0>Coo02>ooD0n?oe0>Kon`3lood0lOom0>_o08f1oh7o
POn1oh7o0OoohP3/ood0mOom0?7oo@3Too`0SOoR0>Kon`3kood0lOom087oPOn1
oh7oPOoYon80k?om0?Goo@3aood0i?ol08gohP3Voo/0noom0?7oo@21oh7oPOn1
oh7ojOoR0>coo@3eood0lOom0>Coo02=on80i_ok0?_oo@3aood0jol0S87oPOn1
oh7oPOonon@0joom0?Goo@3aood0i?ol08coi03WooX0n_om0?7oo@21oh7oPOn1
oh7oj?oT0>_oo@3eood0lOom0>Coo02<on@0iooj0?[oo@3aood0POn1oh7oPOn1
onSoi03[ood0mOom0?7oo@3Too`0S?oT0>OonP3jood0lOom0>_o08b1oh7oPOn1
oh7ooOoV0>[oo@3eood0lOom0>Coo02;onH0j?oi0?Woo@3aood0POn1oh7oPOn1
onOoiP3Zood0mOom0?7oo@3Too`0RooV0>Son@3iood0lOom087oPOn1oh7oPOoW
onH0j_om0?Goo@3aood0i?ol08_oiP3XooT0nOom0?7oo@3[o`2<POn1oh7oPOn1
oo_ojP3Xood0mOom0?7oo@3Too`0ROoZ0>Oon@3hood0lOom087oPOn1oh7oPOoU
onX0j?om0?Goo@3aood0i?ol08WojP3WooT0n?om0?7oo@21oh7oPOn1oh7oiOoZ
0>Soo@3eood0lOom0>Coo029onX0iooi0?Soo@3aood0jol0S87oPOn1oh7oPOoi
onl0iOom0?Goo@3aood0i?ol08Ook`3VooT0m_om0?7oo@21oh7oPOn1oh7ohoo_
0>Goo@3eood0lOom0>Coo027onl0i_oi0?Koo@3aood0POn1oh7oPOn1on?ok`3U
ood0mOom0?7oo@3Too`0Qoo_0>Kon@3food0lOom0>_o08b1oh7oPOn1oh7omOof
0>;oo@3eood0lOom0>Coo023ooH0iOoh0?Goo@3aood0POn1oh7oPOn1omoomP3R
ood0mOom0?7oo@3Too`0Poof0>Gon03eood0lOom087oPOn1oh7oPOoOooH0h_om
0?Goo@3aood0i?ol08?omP3UooP0mOom0?7oo@3[o`1jPOn1oh7oPOn1ol_oo@3e
ood0lOom0>Coo021omgon@3cood0lOom087oPOn1oh7oPOneood0mOom0?7oo@3T
oo`0POoMooT0loom0?7oo@21oh7oPOn1oh7o]Oom0?Goo@3aood0i?ol087ogOoi
0??oo@3aood0jol0NX7oPOn1oh7oPOo;ood0mOom0?7oo@3Too`0POoNooX0lOom
0?7oo@21oh7oPOn1oh7o]Oom0?Goo@3aood0i?ol087og_oj0?7oo@3aood0POn1
oh7oPOn1okGoo@3eood0lOom0>Coo021omkonP3aood0lOom0>_o07Z1oh7oPOn1
oh7oboom0?Coo@3cood0hool087ogook0>koo@3cood0POn1oh7oPOn1okCoo@3d
ood0loom0>?oo021omoon`3^ood0loom087oPOn1oh7oPOndood0m?om0??oo@3S
oo`0POoOoo/0k_om0??oo@3Zo`1jPOn1oh7oPOn1ol_oo@3dood0loom0>?oo021
on3on`3]ood0loom087oPOn1oh7oPOndood0m?om0??oo@3Soo`0POoPoo/0kOom
0??oo@21oh7oPOn1oh7o]?om0?Coo@3cood0hool087oh?ok0>goo@3cood0j_l0
NX7oPOn1oh7oPOo;ood0m?om0??oo@3Soo`0POoQoo`0joom0??oo@21oh7oPOn1
oh7o]?om0?Coo@3cood0hool087ohOol0>_oo@3cood0POn1oh7oPOn1okCoo@3d
ood0loom0>?oo021on7oo03[ood0loom0>[o07Z1oh7oPOn1oh7oboom0?Coo@3c
ood0hool087ohOom0>[oo@3cood0POn1oh7oPOn1okCoo@3dood0loom0>?oo021
on7oo@3Zood0loom087oPOn1oh7oPOndood0m?om0??oo@3Soo`0POoQood0j_om
0??oo@3Zo`1jPOn1oh7oPOn1ol_oo@3cood0mOom0>;oo021on;oo@3Xood0mOom
087oPOn1oh7oPOncood0loom0?Goo@3Roo`0POoRood0j?om0?Goo@21oh7oPOn1
oh7o/oom0??oo@3eood0h_ol087oh_om0>Soo@3eood0jOl0NX7oPOn1oh7oPOo;
ood0lool0?Ooo03Roo`0POoRood0j?ol0?Ooo021oh7oPOn1oh7o/oom0??oo03g
oo`0h_ol087oh_om0>Soo03goo`0POn1oh7oPOn1ok?oo@3coo`0mool0>;oo021
on;oo@3Xoo`0mool0>Wo07Z1oh7oPOn1oh7oboom0?;oo03ioo`0hOol087oh_on
0>Koo03ioo`0POn1oh7oPOn1ok;oo@3boo`0nOol0>7oo021on;ooP3Voo`0nOol
087oPOn1oh7oPOnbood0l_ol0?Woo03Qoo`0POoRooh0i_ol0?Woo03Xo`1jPOn1
oh7oPOn1ol_oo@3boo/0o?oj0>7oo021on?oj@3joo/0o?oj087oPOn1oh7oPOnb
ood0l_ok0?conP3Qoo`0POoSonT0n_ok0?conP21oh7oPOn1oh7o/_om0?;on`3l
ooX0hOol087ohooY0?[on`3looX0j?l0HX7oPOn1oh7oPOo;ood0lOoa0>3oo021
on?oj@3ioo40POn1oh7oPOn1ok7oo@3aoo40h?ol087ohooY0?Wol@21oh7oPOn1
oh7o/Oom0?7ol@3Poo`0POoSonT0nOoa0>Oo06:1oh7oPOn1oh7oboom0?3ol`3O
oo`0POoSonT0n?oc087oPOn1oh7oPOn`ood0l?oc0=ooo021on?oj@3hoo<0POn1
oh7oPOn1ok3oo@3`oo<0gool087ohooY0?Sol`3Vo`1RPOn1oh7oPOn1ol_oo@3_
ooD0g_ol087ohooY0?Oom@21oh7oPOn1oh7o[oom0>oom@3Noo`0POoSonT0mooe
087oPOn1oh7oPOn_ood0kooe0=koo021on?oj@3gooD0iOl0BX7oPOn1oh7oPOnc
ooX0fool087o_ooj087oPOn1oh7oPOnDooX0fool087o_ooj087oPOn1oh7oPOnD
ooX0fool087o_ooj0>;o03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol
087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1
oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021
oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1
oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0
=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnN
oo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1
oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol
087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1
oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021
oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1
oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0
=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnN
oo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1
oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol
087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1
oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021
oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1
oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0
=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnN
oo`0POnIo`0fPOn1oh7oPOn1ohKoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1
oh7oPOn1oikoo021oiWo03J1oh7oPOn1oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol
087oPOn1oh7oPOn1oh7oW_ol087oVOl0=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1
oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnNoo`0POnIo`0fPOn1oh7oPOn1ohKoo021
oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oiWo03J1oh7oPOn1
oh7oQ_ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1oh7oW_ol087oVOl0
=X7oPOn1oh7oPOn6oo`0POn1oh7oPOn1oh7oPOnNoo`0POn1oh7oPOn1oh7oPOnN
oo`0POnIo`0lPOn1oh7oPOn1ohKoo021oi[o0021oh7oPOn1oh7oQ_ol087oV_l0
087oPOn1oh7oPOn6oo`0POnJo`0003n1oh7oPOn1oh7oQ_ol087oVol10021oh7o
POn1oh7oQ_ol087oVol10021oh7oPOn1oh7oQ_ol087oVol10000?87oPOn1oh7o
POn6oo`0POnMood0POn1oh7oPOn1ohKoo021oigoo@21oh7oPOn1oh7oQ_ol087o
WOom000lPOn1oh7oPOn1ohKoo021oikoo021oh7oPOn1oh7oQ_ol087oW_ol087o
POn1oh7oPOn6oo`0POnNoo`003b1oh7oPOn1oh7oQ_ol087oW_ol087oPOn1oh7o
POn6oo`0POnNoo`0POn1oh7oPOn1ohKoo021oikoo000?87oPOn1oh7oPOn6oo`0
POnOoo/0POn1oh7oPOn1ohKoo021oioon`21oh7oPOn1oh7oQ_ol087oWook000l
POn1oh7oPOn1ohOonP21oj7onP21oh7oPOn1oh7oQooj087oXOoj087oPOn1oh7o
POn7ooX0POnQooX003b1oh7oPOn1oh7oR?oh087oX_oj087oPOn1oh7oPOn8ooP0
POnRooX0POn1oh7oPOn1ohSon021oj;onP00?87oPOn1oh7oPOn8ooL0POnSooX0
POn1oh7oPOn1ohSom`21oj?onP21oh7oPOn1oh7oR?og087oXooj000`POn1oh7o
POn1oh[oP@2@087oPOn1oh7oPOn:oh40T021oh7oPOn1oh7oR_n109000321oh7o
POn1oh7oR_n10900POn1oh7oPOn1oh[oP@2@087oPOn1oh7oPOn:oh40T000<87o
POn1oh7oPOn:oh40T021oh7oPOn1oh7oR_n10900POn1oh7oPOn1oh[oP@2@000`
POn1oh7oPOn1oh[oP@2@087oPOn1oh7oPOn:oh40T021oh7oPOn1oh7oR_n10900
03b1oh7oPOn1oh7oROof087oXooj087oPOn1oh7oPOn9ooH0POnSooX0POn1oh7o
POn1ohWomP21oj?onP00?87oPOn1oh7oPOn8ooL0POnSooX0POn1oh7oPOn1ohSo
m`21oj?onP21oh7oPOn1oh7oR?og087oXooj000lPOn1oh7oPOn1ohSon021oj7o
n`21oh7oPOn1oh7oR?oh087oXOok087oPOn1oh7oPOn8ooP0POnQoo/003b1oh7o
POn1oh7oQooj087oWool087oPOn1oh7oPOn7ooX0POnOoo`0POn1oh7oPOn1ohOo
nP21oiooo000=X7oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087o
POn1oh7oPOn1oh7oWOom000iPOn1oh7oPOn1oh7oPOnKo`40087oPOn1oh7oPOn1
oh7oVol10021oh7oPOn1oh7oPOn1oi_o0@0003J1oh7oPOn1oh7oPOn1oi[o0021
oh7oPOn1oh7oPOn1oi[o0021oh7oPOn1oh7oPOn1oi[o0000<87oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0
<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9
o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0
<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9
o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0
<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9
o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7obOl0=X7oPOn1oh7oPOn1oh7oc_o<087oPOn1oh7oPOn1oh7oc_o<
087oPOn1oh7oPOn1oh7oc_o<000fPOn1oh7oPOn1oh7oPOo>ol`0POn1oh7oPOn1
oh7oPOo>ol`0POn1oh7oPOn1oh7oPOo>ol`003J1oh7oPOn1oh7oPOn1olkoc021
oh7oPOn1oh7oPOn1olkoc021oh7oPOn1oh7oPOn1olkoc000=X7oPOn1oh7oPOn1
oh7oc_o<087oPOn1oh7oPOn1oh7oc_o<087oPOn1oh7oPOn1oh7oc_o<000fPOn1
oh7oPOn1oh7oPOo>ol`0POn1oh7oPOn1oh7oPOo>ol`0POn1oh7oPOn1oh7oPOo>
ol`003J1oh7oPOn1oh7oPOn1olkoc021oh7oPOn1oh7oPOn1olkoc021oh7oPOn1
oh7oPOn1olkoc000=X7oPOn1oh7oPOn1oh7oc_o<087oPOn1oh7oPOn1oh7oc_o<
087oPOn1oh7oPOn1oh7oc_o<000fPOn1oh7oPOn1oh7oPOo>ol`0POn1oh7oPOn1
oh7oPOo>ol`0POn1oh7oPOn1oh7oPOo>ol`00321oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0fPOn1
oh7oPOn1oh7oPOneonD0POn1oh7oPOn1oh7oPOneonD0POn1oh7oPOn1oh7oPOne
onD003J1oh7oPOn1oh7oPOn1okGoi@21oh7oPOn1oh7oPOn1okGoi@21oh7oPOn1
oh7oPOn1okGoi@00=X7oPOn1oh7oPOn1oh7o]OoU087oPOn1oh7oPOn1oh7o]OoU
087oPOn1oh7oPOn1oh7o]OoU000fPOn1oh7oPOn1oh7oPOneonD0POn1oh7oPOn1
oh7oPOneonD0POn1oh7oPOn1oh7oPOneonD003J1oh7oPOn1oh7oPOn1okGoi@21
oh7oPOn1oh7oPOn1okGoi@21oh7oPOn1oh7oPOn1okGoi@00=X7oPOn1oh7oPOn1
oh7o]OoU087oPOn1oh7oPOn1oh7o]OoU087oPOn1oh7oPOn1oh7o]OoU000fPOn1
oh7oPOn1oh7oPOneonD0POn1oh7oPOn1oh7oPOneonD0POn1oh7oPOn1oh7oPOne
onD003J1oh7oPOn1oh7oPOn1okGoi@21oh7oPOn1oh7oPOn1okGoi@21oh7oPOn1
oh7oPOn1okGoi@00=X7oPOn1oh7oPOn1oh7o]OoU087oPOn1oh7oPOn1oh7o]OoU
087oPOn1oh7oPOn1oh7o]OoU000`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl009X0003oSj000000
0nP3j00000@0000004P000180000400P00<02000000000000/CjP0000003j0?X
0003j`?Z1m<0000`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0fWooh087oPOn1oh7oPOn1oh7oX_oh087o
POn1oh7oPOn1oh7oX_oh087oPOn1oh7oPOn1ohCo0932ooX0j?ob087onP3YooX0
S_oj0>WonP2booT0looj0<[onP2_oo`0]ook087oPOoHooX0j?ob087onP3YooX0
S_oj0>WonP2booT0looj0<[onP2_oo`0]ook087oPOoHooX0j?ob087onP3YooX0
S_oj0>WonP2booT0looj0<[onP2_oo`0]ook087oUol0]<Con03Zonh0Pooj0>Wo
nP2>ooX0jOoj0=cok@3[ooP0m?oj0<[onP2`oo`0mOoi0=Son@3joo`0POn1om[o
n03Zonh0Pooj0>WonP2>ooX0jOoj0=cok@3[ooP0m?oj0<[onP2`oo`0mOoi0=So
n@3joo`0POn1om[on03Zonh0Pooj0>WonP2>ooX0jOoj0=cok@3[ooP0m?oj0<[o
nP2`oo`0mOoi0=Son@3joo`0POnGo`2daOog0>_ok024ooX0jOoj08konP3YooX0
g?o]0>_on03dooX0b_oj0;3oo03gooD0fooh0?Woo021oh7og?og0>_ok024ooX0
jOoj08konP3YooX0g?o]0>_on03dooX0b_oj0;3oo03gooD0fooh0?Woo021oh7o
g?og0>_ok024ooX0jOoj08konP3YooX0g?o]0>_on03dooX0b_oj0;3oo03gooD0
fooh0?Woo021oiSo0<c5ooL0k?oZ08GonP3jooX0mooj08konP3jooX0mooj0=co
k@3[ooL0mOoj0<[onP2aoo`0n?oa0=kom`3ioo/0POn1omgom`3/onX0QOoj0?[o
nP3gooX0S_oj0?[onP3gooX0g?o]0>_om`3eooX0b_oj0;7oo03hoo40g_og0?Wo
n`21oh7ogOog0>cojP25ooX0n_oj0?OonP2>ooX0n_oj0?OonP3Lond0joog0?Go
nP3:ooX0/Ool0?Sol@3NooL0nOok087oVOl0c<KomP3]onP0Q_oj0?[onP3gooX0
S_oj0?[onP3gooX0g?o]0>_om`3eooX0b_oj0;;on`3hoo00goog0?Soo021oh7o
g_of0>goj026ooX0n_oj0?OonP2>ooX0n_oj0?OonP3Lond0joog0?GonP3:ooX0
/_ok0?Sol03OooL0n?ol087oPOoNooH0kOoX08KonP3jooX0mooj08konP3jooX0
mooj0=cok@3[ooL0mOoj0<[onP2boo/0n?o`0=oom`3hoo`0POnIo`3Ha_of0>ko
mP3looH0Qooj0?[onP3gooX0S_oj0?[onP3gooX0g?o]0>_omP3fooX0b_oj0;?o
n`3honl0h?of0?Son`21oh7ogoof0>komP3looH0Qooj0?[onP3gooX0S_oj0?[o
nP3gooX0g?o]0>_omP3fooX0b_oj0;?on`3honl0h?of0?Son`21oh7ogoof0>ko
mP3looH0Qooj0?[onP3gooX0S_oj0?[onP3gooX0g?o]0>_omP3fooX0b_oj0;?o
n`3honl0h?of0?Son`21oi[o0<36ooX0j_oh0?Son021ooWonP21onoonP3gooX0
g?o]0>_om@3gooX0b_oj0;?on`3iond0hOof0?Oon`21oh7oh?oj0>[on03hooP0
POoiooX0POo_ooX0mooj0=cok@3[ooD0mooj0<[onP2coo/0nOo]0>7omP3goo/0
POn1on3onP3ZooP0n?oh087onOoj087okooj0?OonP3Lond0jooe0?OonP3:ooX0
/ook0?Wok@3QooH0mook087oVol0c<KonP3[ooP0m_oh087on_oj087okooj0?Oo
nP3MooX0gOoe0?OonP3:ooX0]?ok0?Son@3mooT0h_oe0?Oon`21oh7oh?oj0>_o
n03fooP0POojooX0POo_ooX0mooj0=gonP3MooD0mooj0<[onP2doo/0n?oi0?go
n@3RooD0mook087oPOoPooX0jooh0?Kon021oo[onP21onoonP3gooX0gOoj0=go
m@3gooX0b_oj0;Con`3hooT0oOoi0>;om@3goo/0POnKo`3<a_oj0>_on@3dooT0
POojooX0POo_ooX0mooj0=gon`3Loo@0n?oj0<[onP2doo/0nOoi0?_on@3Too@0
mooj087oPOoQooX0jooi0?Con@21oo[onP21onoonP3gooX0gOok0=com03hooX0
b_oj0;Con`3iooT0nooi0>Com03gooX0POn1on7onP3[ooT0m?oi087on_oj087o
kooj0?OonP3Moo/0g?od0?SonP3:ooX0]?ok0?Won@3kooT0i?od0?OonP21oico
0KKi0>Oon03eoo80l?oh0?Con03eooT0m?oj0?con`3]ooT0k?oi0?GonP3noo80
nooj0??on@3^ooT0jOoj0?WonP3iooX0o?oj0?kolP3kooX0o?ok0>Son`3Loo@0
n?oj0??on03/ooX0oOoj0?Con@3^ooT0iOok0?SonP3iooX0i?ol003onP3foo/0
POnLooT0iooh0?GolP3`ooP0m?oh0?Gon@3dooX0o?ok0>gon@3/ooT0mOoj0?ko
lP3kooX0looi0>kon@3YooX0nOoj0?WonP3looX0o_ob0?_onP3loo/0j?ok0=co
m03hooX0looh0>conP3mooX0m?oi0>kon@3Uoo/0n?oj0?WonP3Too`00?oj0?Ko
n`21oicon@3WooP0mOob0?3on03dooP0mOoi0?ConP3loo/0kOoi0>con@3eooX0
o_ob0?_onP3cooT0k_oi0>WonP3iooX0nOoj0?conP3noo80nooj0?con`3Xoo/0
g?od0?SonP3cooP0k?oj0?gonP3dooT0k_oi0>Gon`3hooX0nOoj0>Coo000ooX0
m_ok087oW?l1^OX0j?od0?OolP3`ooT0l_oi0?Sol`3gooX0o_og0?;ol`3boo<0
n?oj0?kolP3kooX0m_oc0?Col`3/ooX0nOoj0?WonP3looX0o_ob0?_onP3nooL0
j_ok0=col`3iooX0mOod0?3omP01oooj0?Ool`3doo<0j?ok0?SonP3iooX0iOok
003onP3foo/0POnLooX0j?od0?OolP3`ooT0l_oi0?Sol`3gooX0o_og0?;ol`3b
oo<0n?oj0?kolP3kooX0m_oc0?Col`3/ooX0nOoj0?WonP3looX0o_ob0?_onP3n
ooL0j_ok0=col`3iooX0mOod0?3omP01oooj0?Ool`3doo<0j?ok0?SonP3iooX0
iOok003onP3foo/0POnLooX0j?od0?OolP3`ooT0l_oi0?Sol`3gooX0o_og0?;o
l`3boo<0n?oj0?kolP3kooX0m_oc0?Col`3/ooX0nOoj0?WonP3looX0o_ob0?_o
nP3nooL0j_ok0=col`3iooX0mOod0?3omP01oooj0?Ool`3doo<0j?ok0?SonP3i
ooX0iOok003onP3foo/0POnLo`78n`3Yoo00nOob0?3on@3booT0nOo`0?WonP01
oood0?Gol03eoo00n_oj0?kolP3kooX0mooa0?Kol03^ooX0n_oh0?[onP3looX0
o_ob0?_onP00oo<0k?ok0=conP00oo/0nOoj0?Ool03coo@00?oj0?Sol@3foo00
jooj0?SonP3iooX0i_ok007oooX0m_oj087oWOok0>Wol03ioo80l?oi0?;on@3i
oo00nOoj007ooo@0mOo`0?Gol03jooX0o_ob0?_onP3goo40m_o`0>konP3jooP0
n_oj0?conP3noo80nooj003ol`3/oo/0g?oj003on`3iooX0moo`0??om000ooX0
n?oa0?Kol03[ooX0n?oj0?WonP3Voo/00OoonP3fooX0POnMoo/0jOo`0?WolP3`
ooT0l_oi0?Wol03iooX00Ooom03eoo00mOo`0?[onP3noo80nooj0?Ool@3foo00
k_oj0?[on03jooX0o?oj0?kolP3kooX00?oc0>con`3LooX00?ok0?WonP3goo00
lood003onP3hoo40m_o`0>_onP3hooX0nOoj0>Kon`01oooj0?KonP21oigo0J[l
0>WokP3joo80l?oi0>?okP3jooX00?ob0?OokP3gonh0nooj0?kolP3kooX0n?o_
0?SokP3_ooX0n_oh0?[onP3looX0o_ob0?_onP00oo<0k?ok0=conP00ooX0n_oj
0?SokP3eon/0nOo_0?SokP3/oo/0n?oj0?OonP3Woo`0o_oj0?Gon`21oigoo03Y
onh0n_ob0?3on@3Sonh0n_oj003olP3gonh0moo^0?_onP3noo80nooj0?Sok`3h
onh0kooj0?[on03jooX0o?oj0?kolP3kooX00?oc0>con`3LooX00?oj0?[onP3h
onh0mOo[0?Wok`3honh0k?ok0?SonP3gooX0iool0?konP3eoo/0POnMoo`0jOo^
0?[olP3`ooT0hoo^0?[onP00oo80moo^0?OokP3kooX0o_ob0?_onP3honl0n?o^
0>oonP3jooP0n_oj0?conP3noo80nooj003ol`3/oo/0g?oj003onP3jooX0n?o^
0?Goj`3ionl0n?o^0>con`3hooX0mooj0>Ooo03nooX0mOok087oWOl1Y?`0j_o/
0?_olP3aooT0hoo]0?[oj@3iond0n?o]0?_onP3noo80nooj0?Wok@3jond0k_ok
0?[on03joo/0nooj0?kolP3konX0kOok007oooX0iOoj007oooX0nooj0?Wok03g
onX0n_o]0?[ok@3/oo/0n?oj0?OonP3Xoo/0o_oj0?GonP21oikoo03Zon`0noob
0?7on@3Sond0n_oY0?Wok@3hond0nooj0?kolP3kooX0nOo]0?[ok@3^oo/0n_oh
0?[on`3kooX0o_ob0?_ojP3]oo/00OoonP3UooX00OoonP3kooX0nOo/0?OojP3j
ond0n_o]0>con`3hooX0mooj0>Son`3nooX0mOoj087oW_ol0>[ok03koo80lOoi
0>?ok@3jonT0nOo]0?Sok@3kooX0o_ob0?_onP3iond0n_o]0>kon`3jooP0n_ok
0?_onP3noo80nooZ0>gon`01oooj0>GonP01oooj0?_onP3ion`0mooZ0?[ok@3j
ond0k?ok0?SonP3gooX0j?ok0?konP3eooX0POnNo`6Qo@3ZonX0o?ob0?7on@3S
on`0nooY0?Wok03jon/0o?oj0?kolP3kooX0n_o[0?_ok03_ooX0nooh0?_onP3k
ooX0o_ob0?_ojP3^oo/00?of0>OonP01oooj0?_onP3jonX0nOoY0?_oj`3kon`0
k_oj0?SonP3gooX0jOok0?gonP3eooX0POnNood0j_oZ0?colP3aooT0hoo/0?_o
j@3ion`0n_o[0?conP3noo80nooj0?[oj`3kon`0kooj0?_on03kooX0nooj0?ko
lP3konX0k_ok003omP3WooX00OoonP3kooX0n_oZ0?Woj@3kon/0noo/0>konP3h
ooX0mooj0>Won`3mooX0mOoj087oW_om0>[ojP3loo80lOoi0>?ok03konT0nOo/
0?[oj`3looX0o_ob0?_onP3jon/0noo/0>oonP3kooP0nooj0?_onP3noo80nooZ
0>kon`00ooH0iooj007oooX0nooj0?[ojP3ionT0noo[0?_ok03^ooX0n?oj0?Oo
nP3Yoo/0oOoj0?GonP21oiko0R;n0>Won03looP0n?oj0>gon@3SooT0o?oi0?_o
m`3looL0n_oi0?con@3jooT0nooi0?conP3jooX0mooj0?[on@3kooT0o?oi0?_o
n@3_ooX0nooh0?_onP3kooX0n_oj0?Oom`3looP0koo^0>SonP3nooX0o?oj0?[o
n03looP0nOoh0?gomP3kooT0nooi0?con@3kooT0k_oj0?SonP3gooX0jOok0?go
nP3eooX0POnNooh0jOoh0?con03hooX0kOoi0>?on@3looT0noog0?com`3jooT0
o?oi0?[on@3kooT0o?oj0?[onP3gooX0n_oi0?_on@3looT0nooi0>oonP3kooP0
nooj0?_onP3jooX0moog0?con03_onh0j?oj0?konP3looX0n_oh0?con03iooP0
oOof0?_on@3kooT0o?oi0?_on@3^ooX0n?oj0?OonP3Yoo/0oOoj0?GonP21oiko
oP3YooP0o?oh0?SonP3]ooT0hooi0?con@3kooL0o?og0?[on@3looT0n_oi0?_o
n@3looX0n_oj0?OonP3jooT0nooi0?con@3kooT0kooj0?_on03kooX0nooj0?[o
nP3gooL0o?oh0>ookP3XooX0o_oj0?conP3jooP0o?oh0?Won03mooH0nooi0?_o
n@3looT0nooi0>konP3hooX0mooj0>Won`3mooX0mOoj087oW_l2<@400>Won@3h
ooT0nOoj0>gon@3TooT0n_oj0?_on03iooT0nooi0?[onP3kooT0nOoi0?gonP3j
ooX0mooj0?_on@3iooT0oOoj0?Won@3`ooX0o?ol003oo03looX0nooj0?[onP3g
ooP0n_oi0>ook@3YooX0o_oj0?conP3kooT0n?oi0?_on@3iooP0o?oi0?Won@3m
ooX0nOoi0>oon`3gooX0mooj0>[on`3looX0m?ok087oW_l1003YooT0n?oi0?Wo
nP3]ooT0i?oi0?[onP3kooP0nOoi0?_on@3jooX0nooi0?Won@3mooX0n_oj0?Oo
nP3kooT0nOoi0?gonP3iooT0l?oj0?coo000oo`0o?oj0?_onP3jooX0mooh0?[o
n@3_ond0jOoj0?konP3looX0nooi0?Son@3kooT0nOoh0?con@3iooT0oOoj0?Wo
n@3_oo/0mooj0?OonP3Zoo/0o?oj0?Con`21oiko0@00jOoi0?Son@3iooX0kOoi
0>Con@3jooX0nooh0?Won@3kooT0n_oj0?_on@3iooT0oOoj0?[onP3gooX0nooi
0?Won@3mooX0nOoi0?3onP3loo`00?ol0?conP3kooX0n_oj0?Oon03jooT0koo]
0>WonP3nooX0o?oj0?_on@3hooT0nooi0?Won03looT0nOoi0?gonP3iooT0kook
0?OonP3gooX0j_ok0?conP3doo/0POnNo`8^003XooX0m_oj0?WonP3]ooT0i?oj
0?WonP3kooT0mooj0?_onP3iooX0nooj0?OonP3mooX0n_oj0?OonP3kooX0mooj
0?gonP3hooX0kook0?coo000oo`0o?ok0?[onP3jooX0mooi0?SonP3_on`0j_oj
0?gonP3mooX0nooj0?KonP3kooX0mooi0?conP3gooX0oOoj0?SonP3_oo/0mooj
0?OonP3[oo/0nooj0?ConP21oioo003XooX0m_oj0?WonP3]ooT0i?oj0?WonP3k
ooT0mooj0?_onP3iooX0nooj0?OonP3mooX0n_oj0?OonP3kooX0mooj0?gonP3h
ooX0kook0?coo000oo`0o?ok0?[onP3jooX0mooi0?SonP3_on`0j_oj0?gonP3m
ooX0nooj0?KonP3kooX0mooi0?conP3gooX0oOoj0?SonP3_oo/0mooj0?OonP3[
oo/0nooj0?ConP21oioo003XooX0m_oj0?WonP3]ooT0i?oj0?WonP3kooT0mooj
0?_onP3iooX0nooj0?OonP3mooX0n_oj0?OonP3kooX0mooj0?gonP3hooX0kook
0?coo000oo`0o?ok0?[onP3jooX0mooi0?SonP3_on`0j_oj0?gonP3mooX0nooj
0?KonP3kooX0mooi0?conP3gooX0oOoj0?SonP3_oo/0mooj0?OonP3[oo/0nooj
0?ConP21oioo0RCWooX0m_oj0?WonP3]ooT0i?oj0?WonP3kooT0mooi0?conP3i
ooX0nooj0?OonP3mooX0n_oj0?OonP3looX0mOok0?gonP3hooX0kook0?coo000
oo`0o?ok0?[onP3jooX0mooi0?SonP3_on/0jooj0?con`3mooX0nooj0?KonP3k
ooX0mooi0?gonP3eoo/0oOoj0?SonP3`ooX0mooj0?OonP3[oo/0nooj0?ConP21
ohGonP3fooX0nOoj0>gon@3TooX0nOoj0?_on@3gooT0o?oj0?WonP3kooX0mooj
0?gonP3jooX0mooj0?conP3eoo/0oOoj0?SonP3_oo/0o?ol003oo03loo/0n_oj
0?[onP3gooT0n?oj0>ooj`3[ooX0o?ok0?gonP3kooX0m_oj0?_onP3gooT0oOoj
0?Gon`3mooX0n?oj0?3onP3gooX0mooj0>_on`3kooX0m?oj087oQOoj0?KonP3i
ooX0kOoi0>ConP3iooX0nooi0?Oon@3looX0nOoj0?_onP3gooX0oOoj0?[onP3g
ooX0o?oj0?Gon`3mooX0n?oj0>oon`3loo`00?ol0?con`3jooX0n_oj0?Oon@3h
ooX0koo[0>_onP3loo/0oOoj0?_onP3fooX0nooj0?Oon@3mooX0mOok0?gonP3h
ooX0l?oj0?OonP3gooX0jook0?_onP3dooX0POnOo`80j?oj0?ConP3jooX0kOoi
0=Kon@3kooX0mOoj0>kon@3looX0jooj0?[onP3gooX0o?oj0?GonP3nooP0hOoj
0?goo000oo`0oOoj0?[onP3jooX0mooj0?OonP3_ooT0o?oh0>_onP3looX0o_oj
0?conP3dooX0oOoj0?GonP3mooX0mOoj0?kon03RooX0mooj0?OonP3moo<0o_ok
0?[onP3dooX0POn6ooX0m?oj0?[onP3]ooT0e_oi0?_onP3eooX0k_oi0?conP3[
ooX0n_oj0?OonP3looX0mOoj0?kon03QooX0oOol003oo03mooX0n_oj0?[onP3g
ooX0mooj0>oon@3looP0jooj0?conP3nooX0o?oj0?ConP3mooX0mOoj0?gonP3e
ooX0o_oh0>;onP3gooX0mooj0?gol`3noo/0n_oj0?ConP21ohKonP3dooX0n_oj
0>gon@3FooT0nooj0?GonP3^ooT0o?oj0>_onP3jooX0mooj0?conP3eooX0o_oh
0>7onP3moo`00?ol0?gonP3jooX0n_oj0?OonP3gooX0kooi0?con03[ooX0o?oj
0?konP3looX0m?oj0?gonP3eooX0oOoj0?GonP3nooP0h_oj0?OonP3gooX0oOoc
0?kon`3jooX0m?oj087oWol1j>SonP3dooX0n_oj0>gon@3JooD0nooj0?GonP3b
ooD0o?oj0>_onP3jooX0mooj0?coi`3noo@0iOoj0?kon`00oo/0o_ok0?WonP3j
ooX0mooj0?OonP3`ooT0nOoi0>conP3koo/0o_oj0?conP3dooX0oOoj0?GonP3m
onL0o_od0>KonP3gooX0mooj0?gol`3noo`0nOoj0?ConP21ohKonP3dooX0n_oj
0>gon@3JooD0nooj0?GonP3booD0o?oj0>_onP3jooX0mooj0?coi`3noo@0iOoj
0?kon`00oo/0o_ok0?WonP3jooX0mooj0?OonP3`ooT0nOoi0>conP3koo/0o_oj
0?conP3dooX0oOoj0?GonP3monL0o_od0>KonP3gooX0mooj0?gol`3noo`0nOoj
0?ConP21ohKonP3dooX0n_oj0>gon@3JooD0nooj0?GonP3booD0o?oj0>_onP3j
ooX0mooj0?coi`3noo@0iOoj0?kon`00oo/0o_ok0?WonP3jooX0mooj0?OonP3`
ooT0nOoi0>conP3koo/0o_oj0?conP3dooX0oOoj0?GonP3monL0o_od0>KonP3g
ooX0mooj0?gol`3noo`0nOoj0?ConP21oioo0N`00>WonP3dooX0n_oj0>gon@3O
oo00nooj0?GonP3goo00o?oj0>_onP3jooX0mooj0?coi`3moo00jOok0?koo03n
oo`0o_ok0?WonP3jooX0mooj0?OonP3PooT0k?oj0?_onP01oooj0?conP3dooX0
oOoj0?GonP3monL0oOo`0>_onP3gooX0mooj0?gol`01oook0?WonP3dooX0POnO
o`00jOoj0?ConP3jooX0kOoi0=ool03kooX0mOoj0?Ool03looX0jooj0?[onP3g
ooX0o?oW0?gol03Yoo/0o_ol0?koo03noo/0nOoj0?[onP3gooX0mooj0>3on@3/
ooX0nooj007oooX0o?oj0?ConP3mooX0mOoj0?goi`3moo00jooj0?OonP3gooX0
oOoc007ooo/0nOoj0?ConP21oioo003YooX0m?oj0?[onP3]ooT0goo`0?_onP3e
ooX0moo`0?conP3[ooX0n_oj0?OonP3lonL0oOo`0>Won`3noo`0o_ol0?kon`3i
ooX0n_oj0?OonP3gooX0h?oi0>conP3kooX00OoonP3looX0m?oj0?gonP3eooX0
oOoW0?gol03[ooX0mooj0?OonP3moo<00Ooon`3iooX0m?oj087oWol1g@00jOoj
0?ConP3jooX0kOoi0>;ok@3kooX0mOoj0?[ok@3looX0jooj0?[onP3gooX0o?oW
0?cok`3[oo/0o_ol0?koo03noo/0nOoj0?[onP3gooX0mooj0=oonP3/ooX0n_oj
003onP3looX0m?oj0?gonP3eooX0oOoW0?cok`3]ooX0mooj0?OonP3moo<00Ooo
j03hooX0POnOo`00jOoj0?ConP3jooX0kOoi0>;ok@3kooX0mOoj0?[ok@3looX0
jooj0?[onP3gooX0o?oW0?cok`3[oo/0o_ol0?koo03noo/0nOoj0?[onP3gooX0
mooj0=oonP3/ooX0n_oj003onP3looX0m?oj0?gonP3eooX0oOoW0?cok`3]ooX0
mooj0?OonP3moo<00Oooj03hooX0POnOo`00jOoj0?ConP3jooX0kOoi0>;ok@3k
ooX0mOoj0?[ok@3looX0jooj0?[onP3gooX0o?oW0?cok`3[oo/0o_ol0?koo03n
oo/0nOoj0?[onP3gooX0mooj0=oonP3/ooX0n_oj003onP3looX0m?oj0?gonP3e
ooX0oOoW0?cok`3]ooX0mooj0?OonP3moo<00Oooj03hooX0POnOo`7P0@00j_oj
0?ConP3jooX0kOoh0>Cok03kooX0mOoj0?_ok03looX0jooj0?[onP3gooX0o?oW
0?_okP3]oo/0o_ol0?koo03noo/0nOoj0?[onP3gooX0mooj0=oonP3/ooX0n_oj
003onP3looX0m?oj0?gonP3eooX0oOoW0?_okP3_ooX0mooj0?OonP3moo<00Ooo
j03hooX0POnOo`400>[onP3dooX0n_oj0>gon03Ton`0nooj0?GonP3kon`0o?oj
0>_onP3jooX0mooj0?coi`3konh0kOok0?koo03noo`0o_ok0?WonP3jooX0mooj
0?OonP3OooX0k?oj0?[onP00ooX0o?oj0?ConP3mooX0mOoj0?goi`3konh0kooj
0?OonP3gooX0oOoc007oonP0n?oj087oWol1003ZooX0m?oj0?[onP3]ooP0i?o/
0?_onP3eooX0noo/0?conP3[ooX0n_oj0?OonP3lonL0noo^0>gon`3noo`0o_ol
0?kon`3iooX0n_oj0?OonP3gooX0gooj0>conP3jooX00?oj0?conP3dooX0oOoj
0?GonP3monL0noo^0>oonP3gooX0mooj0?gol`01oooX0?SonP21oioo0O_n0>_o
nP3dooX0n_oj0>con@3booT0o?oe0?konP3kooX0mOoj0?com@3nooX0o?oj0>_o
nP3jooX0mooj0?coi`3hoo00kOok007ooo`0o_ol007ooo/0n?oj0?[onP3gooX0
mooj0=oonP3/ooX0nOoc0?conP3dooX0oOoj0?GonP3monL0n?o`0?3onP3gooX0
mooj0?gol`01oooX0?SonP21oioooP3[ooX0m?oj0?[onP3/ooT0l_oi0?com@3n
ooX0nooj0?GonP3looD0o_oj0?conP3[ooX0n_oj0?OonP3lonL0n?o`0>gon`01
oool0?koo001oook0?SonP3jooX0mooj0?OonP3OooX0k?oj0?Wol`3looX0m?oj
0?gonP3eooX0oOoW0?Sol03`ooX0mooj0?OonP3moo<00Oooj03hooX0POnOooh0
jooj0?ConP3jooX0k?oi0?;on@3looD0o_oj0?_onP3eooX0o?oe0?konP3looX0
jooj0?[onP3gooX0o?oW0?Sol03]oo/00Oooo03noo`00Ooon`3hooX0n_oj0?Oo
nP3gooX0gooj0>conP3ioo<0o?oj0?ConP3mooX0mOoj0?goi`3hoo00l?oj0?Oo
nP3gooX0oOoc007oonP0n?oj087oWol1i_h0jooj0?ConP3jooX0k?oi0?;on@3l
ooT0n_oj0?_onP3eooX0o?oi0?[onP3looX0jooj0?[onP3gooX0o?oj0>7om03]
oo/00?ol0?coo000oo/0n?oj0?[onP3gooX0mooj0=oonP3/ooX0n?od0?conP3d
ooX0oOoj0?GonP3mooX0hOod0?3onP3gooX0mooj0>goj03hooX0POnOooh0jooj
0?ConP3jooX0k?oi0?;on@3looT0n_oj0?_onP3eooX0o?oi0?[onP3looX0jooj
0?[onP3gooX0o?oj0>7om03]oo/00?ol0?coo000oo/0n?oj0?[onP3gooX0mooj
0=oonP3/ooX0n?od0?conP3dooX0oOoj0?GonP3mooX0hOod0?3onP3gooX0mooj
0>goj03hooX0POnOooh0jooj0?ConP3jooX0k?oi0?;on@3looT0n_oj0?_onP3e
ooX0o?oi0?[onP3looX0jooj0?[onP3gooX0o?oj0>7om03]oo/00?ol0?coo000
oo/0n?oj0?[onP3gooX0mooj0=oonP3/ooX0n?od0?conP3dooX0oOoj0?GonP3m
ooX0hOod0?3onP3gooX0mooj0>goj03hooX0POnOo`7Vo@3/ooX0m?oj0?[onP3/
ooP0m?oi0?conP3hooX0nooj0?Kon@3mooX0n?oj0?conP3[ooX0n_oj0?OonP3l
ooX0g?oh0>kon`00oo`0o?ol003on`3hooX0n_oj0?OonP3gooX0gooj0>conP3h
oo@0o?oj0?ConP3mooX0mOoj0?gonP3LooP0lOoj0?KonP3iooX0k?oX0?SonP21
oiooo@3/ooX0m?oj0?[onP3/ooP0m?oi0?conP3hooX0nooj0?Kon@3mooX0n?oj
0?conP3[ooX0n_oj0?OonP3looX0g?oh0>kon`00oo`0o?ol003on`3hooX0n_oj
0?OonP3gooX0gooj0>conP3hoo@0o?oj0?ConP3mooX0mOoj0?gonP3LooP0lOoj
0?KonP3iooX0k?oX0?SonP21oiooo@3/ooX0m?oj0?[onP3/ooP0m?oi0?conP3h
ooX0nooj0?Kon@3mooX0n?oj0?conP3[ooX0n_oj0?OonP3looX0g?oh0>kon`00
oo`0o?ol003on`3hooX0n_oj0?OonP3gooX0gooj0>conP3hoo@0o?oj0?ConP3m
ooX0mOoj0?gonP3LooP0lOoj0?KonP3iooX0k?oX0?SonP21oioo0QKm0>_onP3f
ooX0nOoj0>_on@3dooT0o?oj0?SonP3kooT0mooi0?gonP3hooX0o?oi0?OonP3m
ooX0n_oj0?OonP3looT0kOoj0?KonP3^oo/00?ol0?coo000oo`0mooj0?[onP3g
ooX0mooj0?3onP3gooX0k?oj0?Oom@3kooX0m_oj0?con@3gooT0oOoi0>gonP3f
ooX0lOoj0?KonP3iooX0k?oX0?SonP21oiooo@3[ooX0m_oj0?WonP3[ooT0m?oi
0?conP3hooX0nooi0?Oon@3mooX0n?oj0?con@3gooX0oOoj0?[onP3gooX0o?oi
0>gonP3fooX0k_ok003oo03loo`00?ol0?OonP3jooX0mooj0?OonP3`ooX0mooj
0>conP3gooD0nooj0?KonP3looT0mooi0?gon@3]ooX0m_oj0?7onP3fooX0nOoj
0>coj03hooX0POnOood0jooj0?KonP3iooX0jooi0?Con@3looX0n?oj0?_on@3g
ooT0oOoj0?SonP3looT0mooj0?gonP3jooX0mooj0?con@3]ooX0m_oj0>kon`00
oo`0o?ol003oo03gooX0n_oj0?OonP3gooX0l?oj0?OonP3/ooX0mooe0?_onP3f
ooX0o?oi0?Oon@3mooT0kOoj0?KonP3aooX0m_oj0?WonP3/onP0n?oj087oWol2
=?`0k?oj0?KonP3iooX0jooh0?Kon03looX0nOoi0?_on@3gooX0o?oj0?Won@3k
ooX0mooj0?gonP3jooX0mooj0?_onP3gooT00OoonP3fooX0kOol003oo03loo`0
0?ol0?OonP3jooX0mooj0?OonP3`ooT0nOoj0>_onP3gooD0nooj0?KonP3kooX0
mooi0?conP3gooT00OoonP3fooX0l?ok0?KonP3iooX0g_oj0?Con`21oikoo03/
ooX0m_oj0?WonP3[ooP0m_oh0?conP3iooT0nooi0?OonP3looX0nOoi0?_onP3g
ooX0oOoj0?[onP3gooX0nooj0?Oon@01oooj0?KonP3]oo`00?ol0?coo000oo`0
mooj0?[onP3gooX0mooj0?3on@3iooX0jooj0?Oom@3kooX0m_oj0?_onP3gooT0
o?oj0?Oon@01oooj0?KonP3`oo/0m_oj0?WonP3NooX0m?ok087oW_ol0>conP3f
ooX0nOoj0>_on03fooP0o?oj0?Won@3kooT0mooj0?conP3iooT0nooj0?OonP3m
ooX0n_oj0?OonP3kooX0mooi007oooX0m_oj0>goo000oo`0o?ol003oo03gooX0
n_oj0?OonP3gooX0l?oi0?WonP3[ooX0mooe0?_onP3fooX0nooj0?Oon@3looX0
mooi007oooX0m_oj0?3on`3fooX0nOoj0=konP3doo/0POnNo`8Lo03/ooT0n?oi
0?WonP3ZooP0n?oh0?_onP3iooT0nooh0?Won@3looX0nOoi0?_on@3iooX0o?oj
0?[onP3gooX0nooi0?Son@01oooi0?OonP3]ooL0n_og0?OonP3jooX0mooj0?Oo
nP3`ooT0n_oi0>_onP3fooH0nooi0?Son@3kooT0nOoh0?con@3hooT00Ooon@3g
ooX0l?ok0?Kon@3kooT0g_oj0?Con`21oikoo03/ooT0n?oi0?WonP3ZooP0n?oh
0?_onP3iooT0nooh0?Won@3looX0nOoi0?_on@3iooX0o?oj0?[onP3gooX0nooi
0?Son@01oooi0?OonP3]ooL0n_og0?OonP3jooX0mooj0?OonP3`ooT0n_oi0>_o
nP3fooH0nooi0?Son@3kooT0nOoh0?con@3hooT00Ooon@3gooX0l?ok0?Kon@3k
ooT0g_oj0?Con`21oikoo03/ooT0n?oi0?WonP3ZooP0n?oh0?_onP3iooT0nooh
0?Won@3looX0nOoi0?_on@3iooX0o?oj0?[onP3gooX0nooi0?Son@01oooi0?Oo
nP3]ooL0n_og0?OonP3jooX0mooj0?OonP3`ooT0n_oi0>_onP3fooH0nooi0?So
n@3kooT0nOoh0?con@3hooT00Ooon@3gooX0l?ok0?Kon@3kooT0g_oj0?Con`21
oiko0QKk0>con03looP0n?oj0>[omP3looL0n_oi0?com`3kooL0o?og0?con@3l
ooL0nooh0?_on@3looX0n_of0?_onP3kooL0o?oh0?gon03kooP0kOog0?[om`3g
ooX0n_of0?_onP3gooX0kooi0?con03[ooX0m_of0?[on03looP0n_oh0?comP3l
ooL0o?oh0?gon03kooP0l?oj0?Kon@3mooT0gOoj0?GonP21oikon`3/ooP0o?oh
0?SonP3ZooH0o?og0?[on@3looL0noog0?com`3looT0o?og0?_on03kooT0o?oj
0?[omP3kooX0noog0?con03mooP0nooh0>gom`3jooL0mooj0?[omP3kooX0mooj
0>oon@3looP0jooj0?KomP3jooP0o?oh0?[on03looH0o?og0?con03mooP0nooh
0?3onP3fooT0oOoi0=gonP3eooX0POnNoo/0k?oh0?con03hooX0j_of0?com`3j
ooT0o?og0?_om`3looL0o?oi0?com`3kooP0nooi0?conP3jooH0nooj0?_om`3l
ooP0oOoh0?_on03]ooL0n_og0?OonP3jooH0nooj0?OonP3_ooT0o?oh0>_onP3f
ooH0n_oh0?con03jooP0o?of0?com`3looP0oOoh0?_on03`ooX0m_oi0?gon@3M
ooX0mOoj087oW_l1K_/0k?oZ0?SonP3YonP0n_oZ0?_oj@3konX0n_o/0?_onP3j
ooH0nooj0?[ojP3monX0k?og0?[on03fooX0n_of0?_onP3gooX0koo/0>[onP3e
ooL0n_oZ0?Woj@3konX0oOoZ0>oonP3fond0gOoj0?GonP21oikon`3/onX0n?oj
0>Woj03jonX0nooY0?_ojP3jon`0nooj0?[omP3kooX0n_oZ0?gojP3/ooL0n_oh
0?KonP3jooH0nooj0?OonP3_on`0j_oj0?Gom`3jonX0nOoY0?_ojP3monX0kooj
0?Kok@3MooX0mOoj087oW_ok0>cojP3hooX0jOoX0?[ojP3konT0nooZ0?[ok03k
ooX0n_of0?_onP3jonX0oOoZ0>com`3jooP0m_oj0?[omP3kooX0mooj0>ook03Z
ooX0mOog0?[ojP3ionT0nooZ0?gojP3_ooX0m_o]0=gonP3eooX0POnNo`5^nP3/
on`0mooj0>SojP3hon/0nooZ0?Woj`3iond0nooj0?[omP3kooX0nOo/0?_oj`3[
ooP0n_oh0?KonP3jooH0nooj0?OonP3^onh0jOoj0?Con03ion`0mooZ0?[ok03k
on/0k_ok0?Gok`3LooX0mOok087oWOoj0>cok03gooX0j?oZ0?Soj`3konX0nOo[
0?Wok@3kooX0n_of0?_onP3ion`0noo[0>_on03jooP0m_oj0?[omP3kooX0mooj
0>kokP3YooX0m?oh0?Wok03gonX0n_o/0?_oj`3^oo/0mOo_0=conP3eoo/0POnM
ooX0k?o/0?OonP3XonX0n?o[0?_ojP3ion/0nOo]0?_onP3jooH0nooj0?Wok03k
on/0jooh0?[on03fooX0n_of0?_onP3gooX0k_o^0>WonP3dooP0nOo/0?OojP3j
on`0noo[0>kon`3eonl0g?oj0?Gon`21oigo0Iki0>cokP3fooX0ioo/0?Ool`00
ooX0nooj003olP3ioo<00?oj0?WokP3jooX0nOog0?_onP3honh0n_o/0>[on03j
ooP0m_oj0?Wom`3kooX0mooj0>gok`3YooX0m?oh0?SokP3foo800?oj0?WokP3j
on`0kOok0?Gok`3LooX0mOok087oWOoi0>cokP3fooX0ioo/0?Ool`00ooX0nooj
003olP3ioo<00?oj0?WokP3jooX0nOog0?_onP3honh0n_o/0>[on03jooP0m_oj
0?Wom`3kooX0mooj0>gok`3YooX0m?oh0?SokP3foo800?oj0?WokP3jon`0kOok
0?Gok`3LooX0mOok087oWOoi0>cokP3fooX0ioo/0?Ool`00ooX0nooj003olP3i
oo<00?oj0?WokP3jooX0nOog0?_onP3honh0n_o/0>[on03jooP0m_oj0?Wom`3k
ooX0mooj0>gok`3YooX0m?oh0?SokP3foo800?oj0?WokP3jon`0kOok0?Gok`3L
ooX0mOok087oWOl1YoT0joo`0?GonP3Vonh0mOoe007oooT0o?oj003ol`3gooD0
0Ooon@3ioo00nOoj0?Wom`3kooX0moo`0?SokP3YooT0n?oj0?GonP3iooL0nooj
0?OonP3/oo40j?oj0??on@3goo00m?od007oooX0n?o`0?SokP3/ooX0mOoa0=_o
nP3fooX0POnMooT0joo`0?GonP3Vonh0mOoe007oooT0o?oj003ol`3gooD00Ooo
n@3ioo00nOoj0?Wom`3kooX0moo`0?SokP3YooT0n?oj0?GonP3iooL0nooj0?Oo
nP3/oo40j?oj0??on@3goo00m?od007oooX0n?o`0?SokP3/ooX0mOoa0=_onP3f
ooX0POnMooT0joo`0?GonP3Vonh0mOoe007oooT0o?oj003ol`3gooD00Ooon@3i
oo00nOoj0?Wom`3kooX0moo`0?SokP3YooT0n?oj0?GonP3iooL0nooj0?OonP3/
oo40j?oj0??on@3goo00m?od007oooX0n?o`0?SokP3/ooX0mOoa0=_onP3fooX0
POnMo`6S0?oi0>[om03cooX0i?ob0?;om`3mooX0o?oj007oooH0m?og0?gonP3g
oo@0mooj0?Oon@3kooX0mOod0?Col@3XooT0n?oj0?GonP3gooT0nooj0?OonP3[
oo@0i_oj0??on@3eoo@0l?og0?konP3foo@0m?oa0>[on`3cooD0fOoj0?Kon`21
oi_on@3Zoo@0looj0>ColP3booL0oOoj0?conP01ooof0?Com`3mooX0mood0?Oo
nP3gooT0nooj0?Gom03doo40j?oi0?SonP3eooX0mooi0?_onP3gooX0jood0>Ko
nP3cooT0mOod0?3om`3nooX0m_od0?Col@3Zoo/0looe0=WonP3foo/0POnKooT0
j_od0??onP3Too80l_og0?gonP3looX00OoomP3dooL0oOoj0?Oom03gooX0mooi
0?_onP3eoo@0m?oa0>Son@3hooX0mOoj0?Oon@3kooX0mooj0>_om03VooX0looi
0?Gom03`ooL0o_oj0?Kom03doo40j_ok0??om@3IooX0m_ok087oW?l0g]oon03:
ooP0kOok0>oonP3mooX0l?ok0>Son030ooT0koog087olOoi0;Won03/oo/0iooi
0>oom`3Woo/0lOoi0<Gon`21oh7on_oh0<[on03]oo/0kooj0?gonP3`oo/0j?oh
0<3on@3_ooL0POoaooT0^Ooh0>con`3WooT0koog0>Oon`3aooT0aOok087oPOoj
ooP0b_oh0>gon`3_ooX0oOoj0?3on`3XooP0`?oi0>oom`21oo7on@2iooP0k?ok
0>Oon@3_ooL0iook0?7on@35oo/0POnLo`1:POoZooX0POn1oh7oPOokoo/0[ooj
087oPOn5ooX0POn1oh7oPOokoo/0[ooj087oPOn5ooX0POn1oh7oPOokoo/0[ooj
087oW?l0BX7oj_oj087oPOn1oh7onook0:oon`21oh7oQ?oj087oPOn1oh7onook
0:oon`21oh7oQ?oj087oPOn1oh7onook0:oon`21oi_o04Z1on[onP21oh7oPOn1
oo[oo02`ooX0POn1ohConP21oh7oPOn1oo[oo02`ooX0POn1ohConP21oh7oPOn1
oo[oo02`ooX0POnKo`1:POoZooX0POn1oh7oPOojoo/0/Ook087oPOn3ooX0POn1
oh7oPOojoo/0/Ook087oPOn3ooX0POn1oh7oPOojoo/0/Ook087oV_l0BX7oj_oj
087oPOn1oh7onOol0;;on`21oh7oP_oj087oPOn1oh7onOol0;;on`21oh7oP_oj
087oPOn1oh7onOol0;;on`21oiWo04Z1on[onP21oh7oPOn1ooSoo02coo/0POn1
oh;onP21oh7oPOn1ooSoo02coo/0POn1oh;onP21oh7oPOn1ooSoo02coo/0POnI
o`1:POoZooX0POn1oh7oPOohoo`0]?ok087oPOn1ooX0POn1oh7oPOohoo`0]?ok
087oPOn1ooX0POn1oh7oPOohoo`0]?ok087oV?l0CX7oj_oj087oPOn1oh7omool
0;Goo021oh7oPOl0ooX0POn1oh7oPOogoo`0]Ool087oPOn1o`3onP21oh7oPOn1
ooOoo02eoo`0POnGo`1>POoZooX0POn1oh7oPOofoo`0]ook087oPOn1o`3onP21
oh7oPOn1ooKoo02goo/0POn1oh7o0?oj087oPOn1oh7om_ol0;Oon`21oiOo0321
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0
<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9
o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0
<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9
o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0
<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9
o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0
<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9
o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo03J9ooH0POn1oh7oPOn1oh7oPOnT
ooH0POn1oh7oPOn1oh7oPOnTooH0POn1oh7oPOn1oh7oW?l0=XgokP21oh7oPOn1
oh7oPOn1ojcokP21oh7oPOn1oh7oPOn1ojcokP21oh7oPOn1oh7oPOnPo`0fSooZ
087oPOn1oh7oPOn1oh7o/?oZ087oPOn1oh7oPOn1oh7o/?oZ087oPOn1oh7oPOn1
oj;o03JAonH0POn1oh7oPOn1oh7oPOndonH0POn1oh7oPOn1oh7oPOndonH0POn1
oh7oPOn1oh7oY?l0=Y?oh`21oh7oPOn1oh7oPOn1okOoh`21oh7oPOn1oh7oPOn1
okOoh`21oh7oPOn1oh7oPOnUo`0fU?oP087oPOn1oh7oPOn1oh7o^_oP087oPOn1
oh7oPOn1oh7o^_oP087oPOn1oh7oPOn1ojOo04:Eoo@0n?od087oPOn1oh7oPOn1
oh7o_?od0?Som021oh7oPOn1oh7oPOn1okcom03hoo@0POn1oh7oPOn1oh7oZ?l0
@YKomP3booL0POn1oh7oPOn1oh7oPOnmooH0l_og087oPOn1oh7oPOn1oh7o_Oof
0?;om`21oh7oPOn1oh7oPOnXo`12Uoog0>kon021oh7oPOn1oh7oPOn1okoom`3^
ooP0POn1oh7oPOn1oh7oPOnoooL0k_oh087oPOn1oh7oPOn1ojWo04:HooP0jooh
087oPOn1oh7oPOn1oh7o`Ooh0>_on021oh7oPOn1oh7oPOn1ol7on03[ooP0POn1
oh7oPOn1oh7oZ_l0@YSon@3YooP0POn1oh7oPOn1oh7oPOo2ooT0jOoh087oPOn1
oh7oPOn1oh7o`_oi0>Won021oh7oPOn1oh7oPOn[o`12VOoi0>Oon@21oh7oPOn1
oh7oPOn1ol?on@3WooT0POn1oh7oPOn1oh7oPOo3ooT0iooi087oPOn1oh7oPOn1
oj_o04:JooT0iOoi087oPOn1oh7oPOn1oh7oaOoi0>Gon@21oh7oPOn1oh7oPOn1
olGon@3UooT0POn1oh7oPOn1oh7o[?l0@Y[on@3UooT0POn1oh7oPOn1oh7oPOo5
ooT0iOoi087oPOn1oh7oPOn1oh7oaOoi0>Gon@21oh7oPOn1oh7oPOn/o`12Vooi
0>?onP21oh7oPOn1oh7oPOn1olKon@3SooX0POn1oh7oPOn1oh7oPOo6ooT0hooj
087oPOn1oh7oPOn1ojco04:KooT0hooi087oPOn1oh7oPOn1oh7oaooi0>?on@21
oh7oPOn1oh7oPOn1olOon@3SooT0POn1oh7oPOn1oh7o[Ol0@Y_onP3QooX0POn1
oh7oPOn1oh7oPOo7ooX0hOoj087oPOn1oh7oPOn1oh7oaooj0>7onP21oh7oPOn1
oh7oPOn]o`12W?oi0>7onP21oh7oPOn1oh7oPOn1olSon@3QooX0POn1oh7oPOn1
oh7oPOo8ooT0hOoj087oPOn1oh7oPOn1ojgo03JLooX0POn1oh7oPOn1oh7oPOnP
ooX0POn1oh7oPOn1oh7oPOnPooX0POn1oh7oPOn1oh7oQOl0=YconP21oh7oPOn1
oh7oPOn1oj3onP21oh7oPOn1oh7oPOn1oj3onP21oh7oPOn1oh7oPOn5o`0fW?oj
087oPOn1oh7oPOn1oh7oX?oj087oPOn1oh7oPOn1oh7oX?oj087oPOn1oh7oPOn1
ohGo03JMooT0POn1oh7oPOn1oh7oPOnQooT0POn1oh7oPOn1oh7oPOnQooT0POn1
oh7oPOn1oh7oQOl0=YgonP21oh7oPOn1oh7oPOn1oj3onP21oh7oPOn1oh7oPOn1
oj3onP21oh7oPOn1oh7oPOn4o`0fWOoj087oPOn1oh7oPOn1oh7oX?oj087oPOn1
oh7oPOn1oh7oX?oj087oPOn1oh7oPOn1ohCo03JMooX0POn1oh7oPOn1oh7oPOnP
ooX0POn1oh7oPOn1oh7oPOnPooX0POn1oh7oPOn1oh7oQ?l0=YgonP21oh7oPOn1
oh7oPOn1oj3onP21oh7oPOn1oh7oPOn1oj3onP21oh7oPOn1oh7oPOn4o`0fWOoj
087oPOn1oh7oPOn1oh7oX?oj087oPOn1oh7oPOn1oh7oX?oj087oPOn1oh7oPOn1
ohCo03JMooX0POn1oh7oPOn1oh7oPOnPooX0POn1oh7oPOn1oh7oPOnPooX0POn1
oh7oPOn1oh7oQ?l0=YgonP21oh7oPOn1oh7oPOn1oj3onP21oh7oPOn1oh7oPOn1
oj3onP21oh7oPOn1oh7oPOn4o`0fWOoj087oPOn1oh7oPOn1oh7oX?oj087oPOn1
oh7oPOn1oh7oX?oj087oPOn1oh7oPOn1ohCo03JMooX0POn1oh7oPOn1oh7oPOnP
ooX0POn1oh7oPOn1oh7oPOnPooX0POn1oh7oPOn1oh7oQ?l0=YgonP21oh7oPOn1
oh7oPOn1oj3onP21oh7oPOn1oh7oPOn1oj3onP21oh7oPOn1oh7oPOn4o`0fWOoj
087oPOn1oh7oPOn1oh7oX?oj087oPOn1oh7oPOn1oh7oX?oj087oPOn1oh7oPOn1
ohCo03JMooX0POn1oh7oPOn1oh7oPOnPooX0POn1oh7oPOn1oh7oPOnPooX0POn1
oh7oPOn1oh7oQ?l0CYcon`3:ooh0i_om087oPOn1oh7oPOn1oh7on?ok0<[ooP3V
ood0POn1oh7oPOn1oh7oPOohoo/0b_on0>Koo@21oh7oPOn1oh7oPOoMo`1JW?oj
0>3onP3cooh0iool087oPOn1oh7oPOn1oh7on?oj0>3onP3cooh0iool087oPOn1
oh7oPOn1oh7on?oj0>3onP3cooh0iool087oPOn1oh7oPOn1omgo05ZLooX0h?oj
0?Coo@3Woo`0POn1oh7oPOn1oh7oPOohooX0h?oj0?Coo@3Woo`0POn1oh7oPOn1
oh7oPOohooX0h?oj0?Coo@3Woo`0POn1oh7oPOn1oh7ogOl0FYconP3QooT0m?om
0>Son`21oh7oPOn1oh7oPOn1ooSonP3QooT0m?om0>Son`21oh7oPOn1oh7oPOn1
ooSonP3QooT0m?om0>Son`21oh7oPOn1oh7oPOoMo`1JW?oi0>;onP3doo`0jOoj
087oPOn1oh7oPOn1oh7on?oi0>;onP3doo`0jOoj087oPOn1oh7oPOn1oh7on?oi
0>;onP3doo`0jOoj087oPOn1oh7oPOn1omgo05ZKooX0h_oj0?Gon`3ZooT0POn1
oh7oPOn1oh7oPOogooX0h_oj0?Gon`3ZooT0POn1oh7oPOn1oh7oPOogooX0h_oj
0?Gon`3ZooT0POn1oh7oPOn1oh7ogOl0FY_onP3SooT0nOog0>[on@21oh7oPOn1
oh7oPOn1ooOonP3SooT0nOog0>[on@21oh7oPOn1oh7oPOn1ooOonP3SooT0nOog
0>[on@21oh7oPOn1oh7oPOoMo`1JVooi0>ConP3koo@0jooh087oPOn1oh7oPOn1
oh7omooi0>ConP3koo@0jooh087oPOn1oh7oPOn1oh7omooi0>ConP3koo@0jooh
087oPOn1oh7oPOn1omgo06JJooX0iOoi0?_om03/oo`00?om087oPOn1oh7oPOn1
oh7om_oj0>Gon@3koo@0k?ol003oo@21oh7oPOn1oh7oPOn1ooKonP3UooT0nood
0>coo000ood0POn1oh7oPOn1oh7ogOl0JI[on@3VooT0nood0>goo001ooom087o
POn1oh7oPOn1oh7om_oi0>Kon@3koo@0kOol007oood0POn1oh7oPOn1oh7oPOof
ooT0i_oi0?_om03]oo`00Oooo@21oh7oPOn1oh7oPOoMo`1VVOoi0>Son@3aood0
kOom0?koo@21oh7oPOn1oh7oPOn1ooGon@3XooT0lOom0>goo@3nood0POn1oh7o
POn1oh7oPOoeooT0j?oi0?7oo@3]ood0o_om087oPOn1oh7oPOn1omgo06JIooP0
j_oi0?3oo@3^oo`0o_om087oPOn1oh7oPOn1oh7omOoh0>[on@3`ood0k_ol0?ko
o@21oh7oPOn1oh7oPOn1ooGon03ZooT0l?om0>koo03nood0POn1oh7oPOn1oh7o
gOl0IYSon03/ooP0l?om0>ooo03mood0POn1oh7oPOn1oh7oPOodooP0k?oh0?3o
o@3_oo`0oOom087oPOn1oh7oPOn1oh7om?oh0>con03`ood0kool0?goo@21oh7o
POn1oh7oPOoMo`1VUooh0>kon03_ood0l?ol0?coo@21oh7oPOn1oh7oPOn1oo?o
n03^ooP0koom0?3oo03lood0POn1oh7oPOn1oh7oPOocooP0k_oh0>ooo@3`oo`0
o?om087oPOn1oh7oPOn1omgo06JFooL0l_og0>koo@3aoo`0noom087oPOn1oh7o
POn1oh7ol_og0?;om`3^ood0lOol0?_oo@21oh7oPOn1oh7oPOn1oo;om`3booL0
k_om0?7oo03kood0POn1oh7oPOn1oh7ogOl0IYGom@3hooD0kOom0?7oo@3jood0
POn1oh7oPOn1oh7oPOoaooD0n?oe0>goo@3aood0n_om087oPOn1oh7oPOn1oh7o
lOoe0?Som@3]ood0lOom0?[oo@21oh7oPOn1oh7oPOoMo`1JU?oR0>coo@3boo`0
n_om087oPOn1oh7oPOn1oh7ol?oR0>coo@3boo`0n_om087oPOn1oh7oPOn1oh7o
l?oR0>coo@3boo`0n_om087oPOn1oh7oPOn1omgo05ZCon@0joom0??oo03iood0
POn1oh7oPOn1oh7oPOo_on@0joom0??oo03iood0POn1oh7oPOn1oh7oPOo_on@0
joom0??oo03iood0POn1oh7oPOn1oh7ogOl0FY;oiP3Zood0m?ol0?Soo@21oh7o
POn1oh7oPOn1onkoiP3Zood0m?ol0?Soo@21oh7oPOn1oh7oPOn1onkoiP3Zood0
m?ol0?Soo@21oh7oPOn1oh7oPOoMo`1JT?oZ0>Soo@3dood0moom087oPOn1oh7o
POn1oh7ok?oZ0>Soo@3dood0moom087oPOn1oh7oPOn1oh7ok?oZ0>Soo@3dood0
moom087oPOn1oh7oPOn1omgo05Z>onl0iOom0?Goo03good0POn1oh7oPOn1oh7o
POoZonl0iOom0?Goo03good0POn1oh7oPOn1oh7oPOoZonl0iOom0?Goo03good0
POn1oh7oPOn1oh7ogOl0FX[omP3Rood0m_ol0?Koo@21oh7oPOn1oh7oPOn1onKo
mP3Rood0m_ol0?Koo@21oh7oPOn1oh7oPOn1onKomP3Rood0m_ol0?Koo@21oh7o
POn1oh7oPOoMo`14POoPood0m_oX087oPOn1oh7oPOn1oh7o`Oom0?Koj021oh7o
POn1oh7oPOn1ol7oo@3fonP0POn1oh7oPOn1oh7oh_l0A87oh?om0?Koj021oh7o
POn1oh7oPOn1ol7oo@3fonP0POn1oh7oPOn1oh7oPOo1ood0m_oX087oPOn1oh7o
POn1on;o04B1on3oo@3fonP0POn1oh7oPOn1oh7oPOo1ood0m_oX087oPOn1oh7o
POn1oh7o`Oom0?Koj021oh7oPOn1oh7oPOoRo`14POoPood0m_oX087oPOn1oh7o
POn1oh7o`Oom0?Koj021oh7oPOn1oh7oPOn1ol7oo@3fonP0POn1oh7oPOn1oh7o
h_l0A87oh?om0>Koo@21oh7oPOn1oh7oPOn1okcoo@3Vood0POn1oh7oPOn1oh7o
POnlood0i_om087oPOn1oh7oPOn1omgo04B1on3oo@3Vood0POn1oh7oPOn1oh7o
POnlood0i_om087oPOn1oh7oPOn1oh7o_?om0>Koo@21oh7oPOn1oh7oPOoMo`14
POoPood0i_om087oPOn1oh7oPOn1oh7o_?om0>Koo@21oh7oPOn1oh7oPOn1okco
o@3Vood0POn1oh7oPOn1oh7ogOl0A87oh?om0>Koo@21oh7oPOn1oh7oPOn1okco
o@3Vood0POn1oh7oPOn1oh7oPOnlood0i_om087oPOn1oh7oPOn1omgo04B1on3o
o@3Vood0POn1oh7oPOn1oh7oPOnlood0i_om087oPOn1oh7oPOn1oh7o_?om0>Ko
o@21oh7oPOn1oh7oPOoMo`14POoPood0i_om087oPOn1oh7oPOn1oh7o_?om0>Ko
o@21oh7oPOn1oh7oPOn1okcoo@3Vood0POn1oh7oPOn1oh7ogOl0A87oh?om0>Ko
o@21oh7oPOn1oh7oPOn1okcoo@3Vood0POn1oh7oPOn1oh7oPOnlood0i_om087o
POn1oh7oPOn1omgo04B1on3oo@3Vood0POn1oh7oPOn1oh7oPOnlood0i_om087o
POn1oh7oPOn1oh7o_?om0>Koo@21oh7oPOn1oh7oPOoMo`14POoPood0i_om087o
POn1oh7oPOn1oh7o_?om0>Koo@21oh7oPOn1oh7oPOn1okcoo@3Vood0POn1oh7o
POn1oh7ogOl0@Y[om03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7o
POn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOnSo`12V_od0?Oom@21oh7oPOn1oh7o
POn1okcom03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oj?o
04:Joo@0mooe087oPOn1oh7oPOn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOn1okco
m03gooD0POn1oh7oPOn1oh7oXol0@Y[om03gooD0POn1oh7oPOn1oh7oPOnloo@0
mooe087oPOn1oh7oPOn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOnSo`12V_od0?Oo
m@21oh7oPOn1oh7oPOn1okcom03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087o
POn1oh7oPOn1oj?o04:Joo@0mooe087oPOn1oh7oPOn1oh7o_?od0?Oom@21oh7o
POn1oh7oPOn1okcom03gooD0POn1oh7oPOn1oh7oXol0@Y[om03gooD0POn1oh7o
POn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oh7o_?od0?Oom@21oh7oPOn1oh7o
POnSo`12V_od0?Oom@21oh7oPOn1oh7oPOn1okcom03gooD0POn1oh7oPOn1oh7o
POnloo@0mooe087oPOn1oh7oPOn1oj?o04:Joo@0mooe087oPOn1oh7oPOn1oh7o
_?od0?Oom@21oh7oPOn1oh7oPOn1okcom03gooD0POn1oh7oPOn1oh7oXol0@Y[o
m03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oh7o_?od0?Oo
m@21oh7oPOn1oh7oPOnSo`12V_od0?Oom@21oh7oPOn1oh7oPOn1okcom03gooD0
POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oj?o04:Joo@0mooe087o
POn1oh7oPOn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOn1okcom03gooD0POn1oh7o
POn1oh7oXol0@Y[om03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7o
POn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOnSo`12V_od0?Oom@21oh7oPOn1oh7o
POn1okcom03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oj?o
04:Joo@0mooe087oPOn1oh7oPOn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOn1okco
m03gooD0POn1oh7oPOn1oh7oXol0@Y[om03gooD0POn1oh7oPOn1oh7oPOnloo@0
mooe087oPOn1oh7oPOn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOnSo`12V_od0?Oo
m@21oh7oPOn1oh7oPOn1okcom03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087o
POn1oh7oPOn1oj?o04:Joo@0mooe087oPOn1oh7oPOn1oh7o_?od0?Oom@21oh7o
POn1oh7oPOn1okcom03gooD0POn1oh7oPOn1oh7oXol0@Y[om03gooD0POn1oh7o
POn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oh7o_?od0?Oom@21oh7oPOn1oh7o
POnSo`12V_od0?Oom@21oh7oPOn1oh7oPOn1okcom03gooD0POn1oh7oPOn1oh7o
POnloo@0mooe087oPOn1oh7oPOn1oj?o04:Joo@0mooe087oPOn1oh7oPOn1oh7o
_?od0?Oom@21oh7oPOn1oh7oPOn1okcom03gooD0POn1oh7oPOn1oh7oXol0@Y[o
m03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oh7o_?od0?Oo
m@21oh7oPOn1oh7oPOnSo`12V_od0?Oom@21oh7oPOn1oh7oPOn1okcom03gooD0
POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oj?o04:Joo@0mooe087o
POn1oh7oPOn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOn1okcom03gooD0POn1oh7o
POn1oh7oXol0@Y[om03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7o
POn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOnSo`12V_od0?Oom@21oh7oPOn1oh7o
POn1okcom03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oj?o
04:Joo@0mooe087oPOn1oh7oPOn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOn1okco
m03gooD0POn1oh7oPOn1oh7oXol0@Y[om03gooD0POn1oh7oPOn1oh7oPOnloo@0
mooe087oPOn1oh7oPOn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOnSo`12V_od0?Oo
m@21oh7oPOn1oh7oPOn1okcom03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087o
POn1oh7oPOn1oj?o04:Joo@0mooe087oPOn1oh7oPOn1oh7o_?od0?Oom@21oh7o
POn1oh7oPOn1okcom03gooD0POn1oh7oPOn1oh7oXol0@Y[om03gooD0POn1oh7o
POn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oh7o_?od0?Oom@21oh7oPOn1oh7o
POnSo`12V_od0?Oom@21oh7oPOn1oh7oPOn1okcom03gooD0POn1oh7oPOn1oh7o
POnloo@0mooe087oPOn1oh7oPOn1oj?o04:Joo@0mooe087oPOn1oh7oPOn1oh7o
_?od0?Oom@21oh7oPOn1oh7oPOn1okcom03gooD0POn1oh7oPOn1oh7oXol0@Y[o
m03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oh7o_?od0?Oo
m@21oh7oPOn1oh7oPOnSo`12V_od0?Oom@21oh7oPOn1oh7oPOn1okcom03gooD0
POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oj?o04:Joo@0mooe087o
POn1oh7oPOn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOn1okcom03gooD0POn1oh7o
POn1oh7oXol0@Y[om03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7o
POn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOnSo`12V_od0?Oom@21oh7oPOn1oh7o
POn1okcom03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oj?o
04:Joo@0mooe087oPOn1oh7oPOn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOn1okco
m03gooD0POn1oh7oPOn1oh7oXol0@Y[om03gooD0POn1oh7oPOn1oh7oPOnloo@0
mooe087oPOn1oh7oPOn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOnSo`12V_od0?Oo
m@21oh7oPOn1oh7oPOn1okcom03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087o
POn1oh7oPOn1oj?o04:Joo@0mooe087oPOn1oh7oPOn1oh7o_?od0?Oom@21oh7o
POn1oh7oPOn1okcom03gooD0POn1oh7oPOn1oh7oXol0@Y[om03gooD0POn1oh7o
POn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oh7o_?od0?Oom@21oh7oPOn1oh7o
POnSo`12V_od0?Oom@21oh7oPOn1oh7oPOn1okcom03gooD0POn1oh7oPOn1oh7o
POnloo@0mooe087oPOn1oh7oPOn1oj?o04:Joo@0mooe087oPOn1oh7oPOn1oh7o
_?od0?Oom@21oh7oPOn1oh7oPOn1okcom03gooD0POn1oh7oPOn1oh7oXol0@Y[o
m03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oh7o_?od0?Oo
m@21oh7oPOn1oh7oPOnSo`12V_od0?Oom@21oh7oPOn1oh7oPOn1okcom03gooD0
POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oj?o04:Joo@0mooe087o
POn1oh7oPOn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOn1okcom03gooD0POn1oh7o
POn1oh7oXol0@Y[om03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7o
POn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOnSo`12V_od0?Oom@21oh7oPOn1oh7o
POn1okcom03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oj?o
04:Joo@0mooe087oPOn1oh7oPOn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOn1okco
m03gooD0POn1oh7oPOn1oh7oXol0@Y[om03gooD0POn1oh7oPOn1oh7oPOnloo@0
mooe087oPOn1oh7oPOn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOnSo`12V_od0?Oo
m@21oh7oPOn1oh7oPOn1okcom03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087o
POn1oh7oPOn1oj?o04:Joo@0mooe087oPOn1oh7oPOn1oh7o_?od0?Oom@21oh7o
POn1oh7oPOn1okcom03gooD0POn1oh7oPOn1oh7oXol0@Y[om03gooD0POn1oh7o
POn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oh7o_?od0?Oom@21oh7oPOn1oh7o
POnSo`12V_od0?Oom@21oh7oPOn1oh7oPOn1okcom03gooD0POn1oh7oPOn1oh7o
POnloo@0mooe087oPOn1oh7oPOn1oj?o04:Joo@0mooe087oPOn1oh7oPOn1oh7o
_?od0?Oom@21oh7oPOn1oh7oPOn1okcom03gooD0POn1oh7oPOn1oh7oXol0@Y[o
m03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oh7o_?od0?Oo
m@21oh7oPOn1oh7oPOnSo`12V_od0?Oom@21oh7oPOn1oh7oPOn1okcom03gooD0
POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oj?o04:Joo@0mooe087o
POn1oh7oPOn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOn1okcom03gooD0POn1oh7o
POn1oh7oXol0@Y[om03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7o
POn1oh7o_?od0?Oom@21oh7oPOn1oh7oPOnSo`12V_od0?Oom@21oh7oPOn1oh7o
POn1okcom03gooD0POn1oh7oPOn1oh7oPOnloo@0mooe087oPOn1oh7oPOn1oj?o
03jJoo@0mon10840X`21oh7oPOn1ohkom03goh40P@2S087oPOn1oh7oS_od0?Oo
P@210:<0POn1oh7oPOoeo`0lS@3goh40P@2S087oPOn1oh7omOn=0?OoP@210:<0
POn1oh7oPOoeohd0mon10840X`21oh7oPOn1ooGo03b=0?OoP@210:<0POn1oh7o
POoeohd0mon10840X`21oh7oPOn1ooGoS@3goh40P@2S087oPOn1oh7omOl0?8d0
mon10840X`21oh7oPOn1ooGoS@3goh40P@2S087oPOn1oh7omOn=0?OoP@210:<0
POn1oh7oPOoeo`18S@3gooD0POn1ok?oo@21oh7oPOn1ooGoS@3gooD0POn1ok?o
o@21oh7oPOn1ooGoS@3gooD0POn1ok?oo@21oh7oPOn1ooGo04ZJoo@0mooe087o
POncood0POn1oh7oPOn>oo@0mooe087oPOncood0POn1oh7oPOn>oo@0mooe087o
POncood0POn1oh7oPOoeo`1:V_od0?Oom@21oh7o/oom087oPOn1oh7oS_od0?Oo
m@21oh7o/oom087oPOn1oh7oS_od0?Oom@21oh7o/oom087oPOn1oh7omOl0BY[o
m03gooD0POn1ok?oo@21oh7oPOn1ohkom03gooD0POn1ok?oo@21oh7oPOn1ohko
m03gooD0POn1ok?oo@21oh7oPOn1ooGo04ZJoo@0mooe087oPOncood0POn1oh7o
POn>oo@0mooe087oPOncood0POn1oh7oPOn>oo@0mooe087oPOncood0POn1oh7o
POoeo`1:V_od0?Oom@21oh7o/oom087oPOn1oh7oS_od0?Oom@21oh7o/oom087o
POn1oh7oS_od0?Oom@21oh7o/oom087oPOn1oh7omOl0BY[om03gooD0POn1ok?o
o@21oh7oPOn1ohkom03gooD0POn1ok?oo@21oh7oPOn1ohkom03gooD0POn1ok?o
o@21oh7oPOn1ooGo04ZJoo@0mooe087oPOncood0POn1oh7oPOn>oo@0mooe087o
POncood0POn1oh7oPOn>oo@0mooe087oPOncood0POn1oh7oPOoeo`1:V_od0?Oo
m@21oh7o/oom087oPOn1oh7oS_od0?Oom@21oh7o/oom087oPOn1oh7oS_od0?Oo
m@21oh7o/oom087oPOn1oh7omOl0BY[om03gooD0POn1ok?oo@21oh7oPOn1ohko
m03gooD0POn1ok?oo@21oh7oPOn1ohkom03gooD0POn1ok?oo@21oh7oPOn1ooGo
04ZJoo@0mooe087oPOncood0POn1oh7oPOn>oo@0mooe087oPOncood0POn1oh7o
POn>oo@0mooe087oPOncood0POn1oh7oPOoeo`1:V_od0?Oom@21oh7o/oom087o
POn1oh7oS_od0?Oom@21oh7o/oom087oPOn1oh7oS_od0?Oom@21oh7o/oom087o
POn1oh7omOl0BY[om03gooD0POn1ok?oo@21oh7oPOn1ohkom03gooD0POn1ok?o
o@21oh7oPOn1ohkom03gooD0POn1ok?oo@21oh7oPOn1ooGo04ZJoo@0mooe087o
POncood0POn1oh7oPOn>oo@0mooe087oPOncood0POn1oh7oPOn>oo@0mooe087o
POncood0POn1oh7oPOoeo`1:V_od0?Oom@21oh7o/oom087oPOn1oh7oS_od0?Oo
m@21oh7o/oom087oPOn1oh7oS_od0?Oom@21oh7o/oom087oPOn1oh7omOl0BY[o
m03gooD0POn1ok?oo@21oh7oPOn1ohkom03gooD0POn1ok?oo@21oh7oPOn1ohko
m03gooD0POn1ok?oo@21oh7oPOn1ooGo04ZJoo@0mooe087oPOncood0POn1oh7o
POn>oo@0mooe087oPOncood0POn1oh7oPOn>oo@0mooe087oPOncood0POn1oh7o
POoeo`1:V_od0?Oom@21oh7o/oom087oPOn1oh7oS_od0?Oom@21oh7o/oom087o
POn1oh7oS_od0?Oom@21oh7o/oom087oPOn1oh7omOl0BY[om03gooD0POn1ok?o
o@21oh7oPOn1ohkom03gooD0POn1ok?oo@21oh7oPOn1ohkom03gooD0POn1ok?o
o@21oh7oPOn1ooGo04ZJoo@0mooe087oPOncood0POn1oh7oPOn>oo@0mooe087o
POncood0POn1oh7oPOn>oo@0mooe087oPOncood0POn1oh7oPOoeo`1:V_od0?Oo
m@21oh7o/oom087oPOn1oh7oS_od0?Oom@21oh7o/oom087oPOn1oh7oS_od0?Oo
m@21oh7o/oom087oPOn1oh7omOl0BY[om03gooD0POn1ok?oo@21oh7oPOn1ohko
m03gooD0POn1ok?oo@21oh7oPOn1ohkom03gooD0POn1ok?oo@21oh7oPOn1ooGo
04ZJoo@0mooe087oPOncood0POn1oh7oPOn>oo@0mooe087oPOncood0POn1oh7o
POn>oo@0mooe087oPOncood0POn1oh7oPOoeo`1:V_od0?Oom@21oh7o/oom087o
POn1oh7oS_od0?Oom@21oh7o/oom087oPOn1oh7oS_od0?Oom@21oh7o/oom087o
POn1oh7omOl0BY[om03gooD0POn1ok?oo@21oh7oPOn1ohkom03gooD0POn1ok?o
o@21oh7oPOn1ohkom03gooD0POn1ok?oo@21oh7oPOn1ooGo04ZJoo@0mooe087o
POncood0POn1oh7oPOn>oo@0mooe087oPOncood0POn1oh7oPOn>oo@0mooe087o
POncood0POn1oh7oPOoeo`1:V_od0?Oom@21oh7o/oom087oPOn1oh7oS_od0?Oo
m@21oh7o/oom087oPOn1oh7oS_od0?Oom@21oh7o/oom087oPOn1oh7omOl0BY[o
m03gooD0POn1ok?oo@21oh7oPOn1ohkom03gooD0POn1ok?oo@21oh7oPOn1ohko
m03gooD0POn1ok?oo@21oh7oPOn1ooGo04ZJoo@0mooe087oPOncood0POn1oh7o
POn>oo@0mooe087oPOncood0POn1oh7oPOn>oo@0mooe087oPOncood0POn1oh7o
POoeo`1:V_od0?Oom@21oh7o/oom087oPOn1oh7oS_od0?Oom@21oh7o/oom087o
POn1oh7oS_od0?Oom@21oh7o/oom087oPOn1oh7omOl0BY[om03gooD0POn1ok?o
o@21oh7oPOn1ohkom03gooD0POn1ok?oo@21oh7oPOn1ohkom03gooD0POn1ok?o
o@21oh7oPOn1ooGo04ZJoo@0mooe087oPOncood0POn1oh7oPOn>oo@0mooe087o
POncood0POn1oh7oPOn>oo@0mooe087oPOncood0POn1oh7oPOoeo`1:V_od0?Oo
m@21oh7o/oom087oPOn1oh7oS_od0?Oom@21oh7o/oom087oPOn1oh7oS_od0?Oo
m@21oh7o/oom087oPOn1oh7omOl0BY[om03gooD0POn1ok?oo@21oh7oPOn1ohko
m03gooD0POn1ok?oo@21oh7oPOn1ohkom03gooD0POn1ok?oo@21oh7oPOn1ooGo
04ZJoo@0mooe087oPOncood0POn1oh7oPOn>oo@0mooe087oPOncood0POn1oh7o
POn>oo@0mooe087oPOncood0POn1oh7oPOoeo`1:V_od0?Oom@21oh7o/oom087o
POn1oh7oS_od0?Oom@21oh7o/oom087oPOn1oh7oS_od0?Oom@21oh7o/oom087o
POn1oh7omOl0BY[om03gooD0POn1ok?oo@21oh7oPOn1ohkom03gooD0POn1ok?o
o@21oh7oPOn1ohkom03gooD0POn1ok?oo@21oh7oPOn1ooGo04ZJoo@0mooe087o
POncood0POn1oh7oPOn>oo@0mooe087oPOncood0POn1oh7oPOn>oo@0mooe087o
POncood0POn1oh7oPOoeo`1:V_od0?Oom@21oh7o/oom087oPOn1oh7oS_od0?Oo
m@21oh7o/oom087oPOn1oh7oS_od0?Oom@21oh7o/oom087oPOn1oh7omOl0BY[o
m03gooD0POn1ok?oo@21oh7oPOn1ohkom03gooD0POn1ok?oo@21oh7oPOn1ohko
m03gooD0POn1ok?oo@21oh7oPOn1ooGo04ZJoo@0mooe087oPOncood0POn1oh7o
POn>oo@0mooe087oPOncood0POn1oh7oPOn>oo@0mooe087oPOncood0POn1oh7o
POoeo`1:V_od0?Oom@21oh7o/oom087oPOn1oh7oS_od0?Oom@21oh7o/oom087o
POn1oh7oS_od0?Oom@21oh7o/oom087oPOn1oh7omOl0BY[om03gooD0POn1ok?o
o@21oh7oPOn1ohkom03gooD0POn1ok?oo@21oh7oPOn1ohkom03gooD0POn1ok?o
o@21oh7oPOn1ooGo04ZJoo@0mooe087oPOncood0POn1oh7oPOn>oo@0mooe087o
POncood0POn1oh7oPOn>oo@0mooe087oPOncood0POn1oh7oPOoeo`1:V_od0?Oo
m@21oh7o/oom087oPOn1oh7oS_od0?Oom@21oh7o/oom087oPOn1oh7oS_od0?Oo
m@21oh7o/oom087oPOn1oh7omOl0BY[om03gooD0POn1ok?oo@21oh7oPOn1ohko
m03gooD0POn1ok?oo@21oh7oPOn1ohkom03gooD0POn1ok?oo@21oh7oPOn1ooGo
04ZJoo@0mooe087oPOncood0POn1oh7oPOn>oo@0mooe087oPOncood0POn1oh7o
POn>oo@0mooe087oPOncood0POn1oh7oPOoeo`1:V_od0?Oom@21oh7o/oom087o
POn1oh7oS_od0?Oom@21oh7o/oom087oPOn1oh7oS_od0?Oom@21oh7o/oom087o
POn1oh7omOl0BY[om03gooD0POn1ok?oo@21oh7oPOn1ohkom03gooD0POn1ok?o
o@21oh7oPOn1ohkom03gooD0POn1ok?oo@21oh7oPOn1ooGo04ZJoo@0mooe087o
POncood0POn1oh7oPOn>oo@0mooe087oPOncood0POn1oh7oPOn>oo@0mooe087o
POncood0POn1oh7oPOoeo`1:V_od0?Oom@21oh7o/oom087oPOn1oh7oS_od0?Oo
m@21oh7o/oom087oPOn1oh7oS_od0?Oom@21oh7o/oom087oPOn1oh7omOl0BY[o
m03gooD0POn1ok?oo@21oh7oPOn1ohkom03gooD0POn1ok?oo@21oh7oPOn1ohko
m03gooD0POn1ok?oo@21oh7oPOn1ooGo04ZJoo@0mooe087oPOncood0POn1oh7o
POn>oo@0mooe087oPOncood0POn1oh7oPOn>oo@0mooe087oPOncood0POn1oh7o
POoeo`1:V_od0?Oom@21oh7o/oom087oPOn1oh7oS_od0?Oom@21oh7o/oom087o
POn1oh7oS_od0?Oom@21oh7o/oom087oPOn1oh7omOl0BY[om03gooD0POn1ok?o
o@21oh7oPOn1ohkom03gooD0POn1ok?oo@21oh7oPOn1ohkom03gooD0POn1ok?o
o@21oh7oPOn1ooGo03R1oh7oPOnYood0POn1oh7oPOn1oh7oPOnMood0POn1oh7o
POn1oh7oPOnMood0POn1oh7oPOoeo`0hPOn1oh7oZOom087oPOn1oh7oPOn1oh7o
WOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7omOl0A87oPOn;ooH0Z_om087o
POn1oh7oPOn1oh7o0OoomP2Zood0POn1oh7oPOn1oh7oPOl1ooof0:[oo@21oh7o
POn1ooGo03j1oh7oSoo^0:koo@21oh7oPOn1oh7oPOn3onh0[_om087oPOn1oh7o
POn1oh?okP2^ood0POn1oh7oPOoeo`0nPOn1oi7ojP2`ood0POn1oh7oPOn1oh7o
QOoZ0;3oo@21oh7oPOn1oh7oPOn5onX0/?om087oPOn1oh7omOl0?X7oPOnConH0
/_om087oPOn1oh7oPOn1ohOoiP2bood0POn1oh7oPOn1oh7oQooV0;;oo@21oh7o
POn1ooGo03j1oh7oUOoS0;?oo@21oh7oPOn1oh7oPOn9on<0/oom087oPOn1oh7o
POn1ohWoh`2cood0POn1oh7oPOoeo`0nPOn1oiKoh02eood0POn1oh7oPOn1oh7o
R_oP0;Goo@21oh7oPOn1oh7oPOn:on00]Oom087oPOn1oh7omOl0BX7oPOnGoo@0
n?od0;Koo@21oh7oPOn1oh7oPOn;oo@0n?od0;Koo@21oh7oPOn1oh7oPOn;oo@0
n?od0;Koo@21oh7oPOn1ooGo04Z1oh7oV?of0?;om`2food0POn1oh7oPOn1oh7o
S?of0?;om`2food0POn1oh7oPOn1oh7oS?of0?;om`2food0POn1oh7oPOoeo`1:
POn1oiWom`3^ooP0]oom087oPOn1oh7oPOn1ohgom`3^ooP0]oom087oPOn1oh7o
POn1ohgom`3^ooP0]oom087oPOn1oh7omOl0BX7oPOnJooP0jooh0;Soo@21oh7o
POn1oh7oPOn>ooP0jooh0;Soo@21oh7oPOn1oh7oPOn>ooP0jooh0;Soo@21oh7o
POn1ooGo04Z1oh7oV_oi0>Won02iood0POn1oh7oPOn1oh7oS_oi0>Won02iood0
POn1oh7oPOn1oh7oS_oi0>Won02iood0POn1oh7oPOoeo`1:POn1oi_on@3WooT0
^Oom087oPOn1oh7oPOn1ohoon@3WooT0^Oom087oPOn1oh7oPOn1ohoon@3WooT0
^Oom087oPOn1oh7omOl0BX7oPOnLooT0iOoi0;[oo@21oh7oPOn1oh7oPOn@ooT0
iOoi0;[oo@21oh7oPOn1oh7oPOn@ooT0iOoi0;[oo@21oh7oPOn1ooGo04Z1oh7o
W?oi0>Gon@2jood0POn1oh7oPOn1oh7oT?oi0>Gon@2jood0POn1oh7oPOn1oh7o
T?oi0>Gon@2jood0POn1oh7oPOoeo`1:POn1oigon@3SooX0^_om087oPOn1oh7o
POn1oi7on@3SooX0^_om087oPOn1oh7oPOn1oi7on@3SooX0^_om087oPOn1oh7o
mOl0BX7oPOnMooT0hooi0;_oo@21oh7oPOn1oh7oPOnAooT0hooi0;_oo@21oh7o
POn1oh7oPOnAooT0hooi0;_oo@21oh7oPOn1ooGo04Z1oh7oWOoj0>7onP2kood0
POn1oh7oPOn1oh7oTOoj0>7onP2kood0POn1oh7oPOn1oh7oTOoj0>7onP2kood0
POn1oh7oPOoeo`1:POn1oikon@3QooX0^oom087oPOn1oh7oPOn1oi;on@3QooX0
^oom087oPOn1oh7oPOn1oi;on@3QooX0^oom087oPOn1oh7omOl0?X7oPOnNooX0
Toom087oPOn1oh7oPOn1oi;onP2Cood0POn1oh7oPOn1oh7oT_oj09?oo@21oh7o
POn1ooGo03j1oh7oW_oj09?oo@21oh7oPOn1oh7oPOnBooX0Toom087oPOn1oh7o
POn1oi;onP2Cood0POn1oh7oPOoeo`0nPOn1oikonP2Cood0POn1oh7oPOn1oh7o
T_oj09?oo@21oh7oPOn1oh7oPOnBooX0Toom087oPOn1oh7omOl0?X7oPOnOooT0
Toom087oPOn1oh7oPOn1oi?on@2Cood0POn1oh7oPOn1oh7oTooi09?oo@21oh7o
POn1ooGo03j1oh7oWooj09;oo@21oh7oPOn1oh7oPOnCooX0T_om087oPOn1oh7o
POn1oi?onP2Bood0POn1oh7oPOoeo`0nPOn1oioonP2Bood0POn1oh7oPOn1oh7o
Tooj09;oo@21oh7oPOn1oh7oPOnCooX0T_om087oPOn1oh7omOl0?X7oPOnOooX0
T_om087oPOn1oh7oPOn1oi?onP2Bood0POn1oh7oPOn1oh7oTooj09;oo@21oh7o
POn1ooGo03j1oh7oWooj09;oo@21oh7oPOn1oh7oPOnCooX0T_om087oPOn1oh7o
POn1oi?onP2Bood0POn1oh7oPOoeo`1FPOn1omKom@3hooD0jooj09;oo@21oh7o
POn1oh7oPOo:ooD0n?oe0>_onP2Bood0POn1oh7oPOn1oh7ob_oe0?Som@3[ooX0
T_om087oPOn1oh7omOl0EX7oPOoFooD0n?oe0>_onP2Bood0POn1oh7oPOn1oh7o
b_oe0?Som@3[ooX0T_om087oPOn1oh7oPOn1ol[om@3hooD0jooj09;oo@21oh7o
POn1ooGo05J1oh7oe_oe0?Som@3[ooX0T_om087oPOn1oh7oPOn1ol[om@3hooD0
jooj09;oo@21oh7oPOn1oh7oPOo:ooD0n?oe0>_onP2Bood0POn1oh7oPOoeo`1F
POn1omKom@3hooD0jooj09;oo@21oh7oPOn1oh7oPOo:ooD0n?oe0>_onP2Bood0
POn1oh7oPOn1oh7ob_oe0?Som@3[ooX0T_om087oPOn1oh7omOl0EX7oPOoFooD0
n?oe0>_onP2Bood0POn1oh7oPOn1oh7ob_oe0?Som@3[ooX0T_om087oPOn1oh7o
POn1ol[om@3hooD0jooj09;oo@21oh7oPOn1ooGo05J1oh7oe_oe0?Som@3[ooX0
T_om087oPOn1oh7oPOn1ol[om@3hooD0jooj09;oo@21oh7oPOn1oh7oPOo:ooD0
n?oe0>_onP2Bood0POn1oh7oPOoeo`1FPOn1omKom@3hooD0jooj09;oo@21oh7o
POn1oh7oPOo:ooD0n?oe0>_onP2Bood0POn1oh7oPOn1oh7ob_oe0?Som@3[ooX0
T_om087oPOn1oh7omOl0EX7oPOoFooD0n?oe0>_onP2Bood0POn1oh7oPOn1oh7o
b_oe0?Som@3[ooX0T_om087oPOn1oh7oPOn1ol[om@3hooD0jooj09;oo@21oh7o
POn1ooGo06j1oh7oe_oe0?Som@3Zoo/0c_oi0>Ooo@3[ood0POn1oh7oPOn1oh7o
b_oe0?Som@3Zoo/0c_oi0>Ooo@3[ood0POn1oh7oPOn1oh7ob_oe0?Som@3Zoo/0
c_oi0>Ooo@3[ood0POn1oh7oPOoeo`1jPOn1omKom@3hooD0j_oj0>3onP3joo@0
j_ol0>_oo@21oh7oPOn1oh7oPOo:ooD0n?oe0>[onP3PooX0n_od0>[oo03[ood0
POn1oh7oPOn1oh7ob_oe0?Som@3ZooX0h?oj0?[om03Zoo`0joom087oPOn1oh7o
mOl0NX7oPOoFooD0n?oe0>[onP3PooX0nooa0>coo03[ood0POn1oh7oPOn1oh7o
b_oe0?Som@3ZooX0h?oj0?_ol@3/oo`0joom087oPOn1oh7oPOn1ol[om@3hooD0
j_oj0>3onP3koo40k?ol0>_oo@21oh7oPOn1ooGo07Z1oh7oe_oe0?Som@3ZooX0
hOoi0?col03]oo/0joom087oPOn1oh7oPOn1ol[om@3hooD0j_oj0>7on@3loo00
kOok0>_oo@21oh7oPOn1oh7oPOo:ooD0n?oe0>[onP3QooT0o?o`0>gon`3[ood0
POn1oh7oPOoeo`26POn1omKom@3hooD0j_oi0>;onP3loo/0n_ok0>oonP3[ood0
POn1oh7oPOn1oh7ob_oe0?Som@3ZooT0h_oj0?con`3joo/0kooj0>_oo@21oh7o
POn1oh7oPOo:ooD0n?oe0>[on@3RooX0o?ok0?[on`3_ooX0joom087oPOn1oh7o
mOl0QX7oPOoFooD0n?oe0>WonP3RooX0oOok0?Ooo03aooT0joom087oPOn1oh7o
POn1ol[om@3hooD0jOoj0>;onP3moo/0mool0?7on@3[ood0POn1oh7oPOn1oh7o
b_oe0?Som@3YooX0h_oj0?gon`3goo`0lOoi0>_oo@21oh7oPOn1ooGo08J1oh7o
e_oe0?Som@3YooX0hooi0?goo03eood0lOoi0>_oo@21oh7oPOn1oh7oPOo:ooD0
n?oe0>WonP3SooT0oOol0?Goo@3aooT0joom087oPOn1oh7oPOn1ol[om@3hooD0
jOoj0>?on@3moo`0mOom0?7on@3[ood0POn1oh7oPOoeo`26POn1omKom@3hooD0
jOoi0>ConP3lood0m?ol0??on03[ood0POn1oh7oPOn1oh7ob_oe0?Som@3YooT0
i?oj0?coo@3doo`0looh0>_oo@21oh7oPOn1oh7oPOo:ooD0n?oe0>Won@3TooX0
o?om0?Coo03cooP0joom087oPOn1oh7omOl0TX7oPOoFooD0n?oe0>SonP3UooT0
oOol0??oo@3doo`00?om0>_oo@21oh7oPOn1oh7oPOo:ooD0n?oe0>SonP3UooT0
oOol0??oo@3doo`00?om0>_oo@21oh7oPOn1oh7oPOo:ooD0n?oe0>SonP3UooT0
oOol0??oo@3doo`00?om0>_oo@21oh7oPOn1ooGo09F1oh7oe_oe0?Som@3XooT0
i_oi0?goo@3bood0mOol007oood0joom087oPOn1oh7oPOn1ol[om@3hooD0j?oi
0>Kon@3mood0l_om0?Goo001ooom0>_oo@21oh7oPOn1oh7oPOo:ooD0n?oe0>So
n@3VooT0oOom0?;oo@3eoo`00Oooo@3[ood0POn1oh7oPOoeo`2BPOn1omKom@3h
ooD0iooi0>Son@3lood0l_om0?Goo@3nood0joom087oPOn1oh7oPOn1ol[om@3h
ooD0iooi0>Son@3lood0l_om0?Goo@3nood0joom087oPOn1oh7oPOn1ol[om@3h
ooD0iooi0>Son@3lood0l_om0?Goo@3nood0joom087oPOn1oh7omOl0TX7oPOoF
ooD0n?oe0>Oon03ZooT0noom0?;oo@3foo`0o_om0>_oo@21oh7oPOn1oh7oPOo:
ooD0n?oe0>Oon03ZooT0noom0?;oo@3foo`0o_om0>_oo@21oh7oPOn1oh7oPOo:
ooD0n?oe0>Oon03ZooT0noom0?;oo@3foo`0o_om0>_oo@21oh7oPOn1ooGo08J1
oh7oe_oe0?Som@3VooP0k?oh0>Soo@3goo`0oOom0>_oo@21oh7oPOn1oh7oPOo:
ooD0n?oe0>Kon03/ooP0j?om0?Ooo03mood0joom087oPOn1oh7oPOn1ol[om@3h
ooD0i_oh0>con03Xood0mool0?goo@3[ood0POn1oh7oPOoeo`26POn1omKom@3h
ooD0iOoh0>kon03Xoo`0n?ol0?coo@3[ood0POn1oh7oPOn1oh7ob_oe0?Som@3U
ooP0k_oh0>Soo03hoo`0o?om0>_oo@21oh7oPOn1oh7oPOo:ooD0n?oe0>Gon03^
ooP0j?ol0?Soo03lood0joom087oPOn1oh7omOl0QX7oPOoFooD0n?oe0>Com`3b
ooL0j?ol0?Soo03kood0joom087oPOn1oh7oPOn1ol[om@3hooD0i?og0?;om`3X
oo`0n?ol0?_oo@3[ood0POn1oh7oPOn1oh7ob_oe0?Som@3TooL0l_og0>Soo03h
oo`0noom0>_oo@21oh7oPOn1ooGo08J1oh7oe_oe0?Som@3SooD0n?oe0>Son`3h
ood0n_om0>_oo@21oh7oPOn1oh7oPOo:ooD0n?oe0>?om@3hooD0j?ok0?Soo@3j
ood0joom087oPOn1oh7oPOn1ol[om@3hooD0hooe0?Som@3Xoo/0n?om0?[oo@3[
ood0POn1oh7oPOoeo`1jPOn1omKom@3hooD0h_oR0>Son`3hoo`0n_om0>_oo@21
oh7oPOn1oh7oPOo:ooD0n?oe0>;ohP3Xoo/0n?ol0?[oo@3[ood0POn1oh7oPOn1
oh7ob_oe0?Som@3Ron80j?ok0?Soo03jood0joom087oPOn1oh7omOl0NX7oPOoF
ooD0n?oe0>7oi03YooX0n?ol0?Woo@3[ood0POn1oh7oPOn1oh7ob_oe0?Som@3Q
on@0jOoj0?Soo03iood0joom087oPOn1oh7oPOn1ol[om@3hooD0hOoT0>WonP3h
oo`0nOom0>_oo@21oh7oPOn1ooGo07Z1oh7oe_oe0?Som@3PonH0j_oi0?Soo03h
ood0joom087oPOn1oh7oPOn1ol[om@3hooD0h?oV0>[on@3hoo`0n?om0>_oo@21
oh7oPOn1oh7oPOo:ooD0n?oe0>3oiP3ZooT0n?ol0?Soo@3[ood0POn1oh7oPOoe
o`1jPOn1omKom@3hooD0g_oZ0>Won@3good0moom0>_oo@21oh7oPOn1oh7oPOo:
ooD0n?oe0=kojP3YooT0moom0?Ooo@3[ood0POn1oh7oPOn1oh7ob_oe0?Som@3N
onX0jOoi0?Ooo@3good0joom087oPOn1oh7omOl0NX7oPOoFooD0n?oe0=cok`3X
ooT0m_ol0?Ooo@3[ood0POn1oh7oPOn1oh7ob_oe0?Som@3Lonl0j?oi0?Koo03g
ood0joom087oPOn1oh7oPOn1ol[om@3hooD0g?o_0>Son@3foo`0moom0>_oo@21
oh7oPOn1ooGo07Z1oh7oe_oe0?Som@3HooH0iooh0?Koo03food0joom087oPOn1
oh7oPOn1ol[om@3hooD0f?of0>Oon03foo`0m_om0>_oo@21oh7oPOn1oh7oPOo:
ooD0n?oe0=SomP3WooP0m_ol0?Koo@3[ood0POn1oh7oPOoeo`1RPOn1omKom@3h
ooD0]?oi0?Coj03`ood0POn1oh7oPOn1oh7ob_oe0?Som@2dooT0m?oX0?3oo@21
oh7oPOn1oh7oPOo:ooD0n?oe0;Con@3donP0l?om087oPOn1oh7omOl0HX7oPOoF
ooD0n?oe0;GonP3bonP0l?om087oPOn1oh7oPOn1ol[om@3hooD0]Ooj0?;oj03`
ood0POn1oh7oPOn1oh7ob_oe0?Som@2eooX0l_oX0?3oo@21oh7oPOn1ooGo06:1
oh7oe_oe0?Som@2foo/0l?oX0?3oo@21oh7oPOn1oh7oPOo:ooD0n?oe0;Kon`3`
onP0l?om087oPOn1oh7oPOn1ol[om@3hooD0]_ok0?3oj03`ood0POn1oh7oPOoe
o`1RPOn1omKom@3hooD0]ook0>ooj03`ood0POn1oh7oPOn1oh7ob_oe0?Som@2g
oo/0kooX0?3oo@21oh7oPOn1oh7oPOo:ooD0n?oe0;Oon`3_onP0l?om087oPOn1
oh7omOl0HX7oPOoFooD0n?oe0;Soo03Mood0joom087oPOn1oh7oPOn1ol[om@3h
ooD0^?ol0=goo@3[ood0POn1oh7oPOn1oh7ob_oe0?Som@2hoo`0gOom0>_oo@21
oh7oPOn1ooGo06:1oh7oe_oe0?Som@2hood0g?om0>_oo@21oh7oPOn1oh7oPOo:
ooD0n?oe0;Soo@3Lood0joom087oPOn1oh7oPOn1ol[om@3hooD0^?om0=coo@3[
ood0POn1oh7oPOoeo`1RPOn1omKom@3hooD0^Oom0=_oo@3[ood0POn1oh7oPOn1
oh7ob_oe0?Som@2iood0foom0>_oo@21oh7oPOn1oh7oPOo:ooD0n?oe0;Woo@3K
ood0joom087oPOn1oh7omOl0HX7oPOoFooD0n?oe0;Woo@3Kood0joom087oPOn1
oh7oPOn1ol[om@3hooD0^Oom0=_oo@3[ood0POn1oh7oPOn1oh7ob_oe0?Som@2i
ood0foom0>_oo@21oh7oPOn1ooGo06:1oh7oe_oe0?Som@2iooh0f_om0>_oo@21
oh7oPOn1oh7oPOo:ooD0n?oe0;WooP3Jood0joom087oPOn1oh7oPOn1ol[om@3h
ooD0^Oon0=[oo@3[ood0POn1oh7oPOoeo`1RPOn1omKom@3hooD0^_oY0>koo@3[
ood0POn1oh7oPOn1oh7ob_oe0?Som@2jonT0k_om0>_oo@21oh7oPOn1oh7oPOo:
ooD0n?oe0;[oj@3^ood0joom087oPOn1oh7omOl0HX7oPOoFooD0n?oe0;[oj@3^
ood0joom087oPOn1oh7oPOn1ol[om@3hooD0^_oY0>koo@3[ood0POn1oh7oPOn1
oh7ob_oe0?Som@2jonT0k_om0>_oo@21oh7oPOn1ooGo06:1oh7oe_oe0?Som@2j
onT0k_om0>_oo@21oh7oPOn1oh7oPOo:ooD0n?oe0;[oj@3^ood0joom087oPOn1
oh7oPOn1ol[om@3hooD0^_oY0>koo@3[ood0POn1oh7oPOoeo`1RPOn1omKom@3h
ooD0^_oY0>koo@3[ood0POn1oh7oPOn1oh7ob_oe0?Som@2jonT0k_om0>_oo@21
oh7oPOn1oh7oPOo:ooD0n?oe0;[oj@3^ood0joom087oPOn1oh7omOl0D87oPOoF
ooD0n?oe087omOom087oPOn1oh7oPOn1ol[om@3hooD0POoeood0POn1oh7oPOn1
oh7ob_oe0?Som@21ooGoo@21oh7oPOn1ooGo0521oh7oe_oe0?Som@21ooGoo@21
oh7oPOn1oh7oPOo:ooD0n?oe087omOom087oPOn1oh7oPOn1ol[om@3hooD0POoe
ood0POn1oh7oPOoeo`1@POn1omKom@3hooD0POoeood0POn1oh7oPOn1oh7ob_oe
0?Som@21ooGoo@21oh7oPOn1oh7oPOo:ooD0n?oe087omOom087oPOn1oh7omOl0
D87oPOoFooD0n?oe087omOom087oPOn1oh7oPOn1ol[om@3hooD0POoeood0POn1
oh7oPOn1oh7ob_oe0?Som@21ooGoo@21oh7oPOn1ooGo0521oh7oe_oe0?Som@21
ooGoo@21oh7oPOn1oh7oPOo:ooD0n?oe087omOom087oPOn1oh7oPOn1ol[om@3h
ooD0POoeood0POn1oh7oPOoeo`1@POn1omKom@3hooD0POoeood0POn1oh7oPOn1
oh7ob_oe0?Som@21ooGoo@21oh7oPOn1oh7oPOo:ooD0n?oe087omOom087oPOn1
oh7omOl0D87oPOoFooD0n?oe087omOom087oPOn1oh7oPOn1ol[om@3hooD0POoe
ood0POn1oh7oPOn1oh7ob_oe0?Som@21ooGoo@21oh7oPOn1ooGo0521oh7oe_oe
0?Som@21ooGoo@21oh7oPOn1oh7oPOo:ooD0n?oe087omOom087oPOn1oh7oPOn1
ol[om@3hooD0POoeood0POn1oh7oPOoeo`1@POn1omKom@3hooD0POoeood0POn1
oh7oPOn1oh7ob_oe0?Som@21ooGoo@21oh7oPOn1oh7oPOo:ooD0n?oe087omOom
087oPOn1oh7omOl0D87oPOoFooD0n?oe087omOom087oPOn1oh7oPOn1ol[om@3h
ooD0POoeood0POn1oh7oPOn1oh7ob_oe0?Som@21ooGoo@21oh7oPOn1ooGo0521
oh7oe_oe0?Som@21ooGoo@21oh7oPOn1oh7oPOo:ooD0n?oe087omOom087oPOn1
oh7oPOn1ol[om@3hooD0POoeood0POn1oh7oPOoeo`1@POn1omKom@3hooD0POoe
ood0POn1oh7oPOn1oh7ob_oe0?Som@21ooGoo@21oh7oPOn1oh7oPOo:ooD0n?oe
087omOom087oPOn1oh7omOl0D87oPOoFooD0n?oe087omOom087oPOn1oh7oPOn1
ol[om@3hooD0POoeood0POn1oh7oPOn1oh7ob_oe0?Som@21ooGoo@21oh7oPOn1
ooGo0521oh7oe_oe0?Som@21ooGoo@21oh7oPOn1oh7oPOo:ooD0n?oe087omOom
087oPOn1oh7oPOn1ol[om@3hooD0POoeood0POn1oh7oPOoeo`1@POn1omKom@3h
ooD0POoeood0POn1oh7oPOn1oh7ob_oe0?Som@21ooGoo@21oh7oPOn1oh7oPOo:
ooD0n?oe087omOom087oPOn1oh7omOl0D87oPOoFooD0n?oe087omOom087oPOn1
oh7oPOn1ol[om@3hooD0POoeood0POn1oh7oPOn1oh7ob_oe0?Som@21ooGoo@21
oh7oPOn1ooGo0521oh7oe_oe0?Som@21ooSon021oh7oPOn1oh7oPOo<ooD0n?oe
087on?oh087oPOn1oh7oPOn1olcom@3hooD0POohooP0POn1oh7oPOogo`1@POn1
omKom@3hooD0POohooL0POn1oh7oPOn1oh7ocOoe0?Som@21ooSom`21oh7oPOn1
oh7oPOo=ooD0n?oe087on?og087oPOn1oh7on?l0D87oPOoFooD0n?oe087on?of
087oPOn1oh7oPOn1olkom@3hooD0POohooH0POn1oh7oPOn1oh7oc_oe0?Som@21
ooSomP21oh7oPOn1ooWo04B1oh7oe_oe0?SoP@3Q087oPOn1oh7oPOn1olkom@3h
oh40h@21oh7oPOn1oh7oPOo>ooD0n?n10>40POn1oh7oPOoio`150OooP@210<`0
n?n10>40POn1oh7oPOogoh40P@3<0?SoP@3Q087oPOn1oh7omon10840c03hoh40
h@21oh7oPOn1ooWo04@0oh40P@3;0?SoP@3Q087oPOn1oh7on?n10840b`3hoh40
h@21oh7oPOn1ooSoP@210</0n?n10>40POn1oh7oPOoio`140?n10840b`3hoh40
h@21oh7oPOn1ooSoP@210</0n?n10>40POn1oh7oPOohoh40P@3;0?SoP@3Q087o
POn1oh7onOl0D03oP@210</0n?oe087on?of087oPOn1oh7on?n10840b`3hooD0
POohooH0POn1oh7oPOohoh40P@3;0?Som@21ooSomP21oh7oPOn1ooWo05`0ood0
POn1om_om@3hooD0POohooL0POn1oh7oPOogood0POn1om_om@3hooD0POohooL0
POn1oh7oPOogood0POn1om_om@3hooD0POohooL0POn1oh7oPOoho`1L0?om087o
POoKooD0n?oe087on?oh087oPOn1oh7om_om087oPOoKooD0n?oe087on?oh087o
POn1oh7om_om087oPOoKooD0n?oe087on?oh087oPOn1oh7omol0G03oo@21oh7o
fooe0?Som@21ooOonP21oh7oPOn1ooGoo@21oh7ofooe0?Som@21ooOonP21oh7o
POn1ooGoo@21oh7ofooe0?Som@21ooOonP21oh7oPOn1ooKo05`0ood0POn1om_o
m@3hooD0POoeood0POn1oh7oPOodood0POn1om_om@3hooD0POoeood0POn1oh7o
POodood0POn1om_om@3hooD0POoeood0POn1oh7oPOoeo`1L0?om087oPOoKooD0
n?oe087omOom087oPOn1oh7om?om087oPOoKooD0n?oe087omOom087oPOn1oh7o
m?om087oPOoKooD0n?oe087omOom087oPOn1oh7omOl0G03oo@21oh7ofooe0?So
m@21ooGoo@21oh7oPOn1ooCoo@21oh7ofooe0?Som@21ooGoo@21oh7oPOn1ooCo
o@21oh7ofooe0?Som@21ooGoo@21oh7oPOn1ooGo05`0ood0POn1om_om@3hooD0
POoeood0POn1oh7oPOodood0POn1om_om@3hooD0POoeood0POn1oh7oPOodood0
POn1om_om@3hooD0POoeood0POn1oh7oPOoeo`1L0?om087oPOoKooD0n?oe087o
mOom087oPOn1oh7om?om087oPOoKooD0n?oe087omOom087oPOn1oh7om?om087o
POoKooD0n?oe087omOom087oPOn1oh7omOl0G03oo@21oh7ofooe0?Som@21ooGo
o@21oh7oPOn1ooCoo@21oh7ofooe0?Som@21ooGoo@21oh7oPOn1ooCoo@21oh7o
fooe0?Som@21ooGoo@21oh7oPOn1ooGo05`0ood0POn1om_om@3hooD0POoeood0
POn1oh7oPOodood0POn1om_om@3hooD0POoeood0POn1oh7oPOodood0POn1om_o
m@3hooD0POoeood0POn1oh7oPOoeo`1L0?om087oPOoKooD0n?oe087omOom087o
POn1oh7om?om087oPOoKooD0n?oe087omOom087oPOn1oh7om?om087oPOoKooD0
n?oe087omOom087oPOn1oh7omOl0G03oo@21oh7ofooe0?Som@21ooGoo@21oh7o
POn1ooCoo@21oh7ofooe0?Som@21ooGoo@21oh7oPOn1ooCoo@21oh7ofooe0?So
m@21ooGoo@21oh7oPOn1ooGo05`0ood0POn1om_om@3hooD0POoeood0POn1oh7o
POodood0POn1om_om@3hooD0POoeood0POn1oh7oPOodood0POn1om_om@3hooD0
POoeood0POn1oh7oPOoeo`1L0?om087oPOoKooD0n?oe087omOom087oPOn1oh7o
m?om087oPOoKooD0n?oe087omOom087oPOn1oh7om?om087oPOoKooD0n?oe087o
mOom087oPOn1oh7omOl0G03oo@21oh7ofooe0?Som@21ooGoo@21oh7oPOn1ooCo
o@21oh7ofooe0?Som@21ooGoo@21oh7oPOn1ooCoo@21oh7ofooe0?Som@21ooGo
o@21oh7oPOn1ooGo05`0ood0POn1om_om@3hooD0POoeood0POn1oh7oPOodood0
POn1om_om@3hooD0POoeood0POn1oh7oPOodood0POn1om_om@3hooD0POoeood0
POn1oh7oPOoeo`1L0?om087oPOoKooD0n?oe087omOom087oPOn1oh7om?om087o
POoKooD0n?oe087omOom087oPOn1oh7om?om087oPOoKooD0n?oe087omOom087o
POn1oh7omOl0G03oo@21oh7ofooe0?Som@21ooGoo@21oh7oPOn1ooCoo@21oh7o
fooe0?Som@21ooGoo@21oh7oPOn1ooCoo@21oh7ofooe0?Som@21ooGoo@21oh7o
POn1ooGo05`0ood0POn1om_om@3hooD0POoeood0POn1oh7oPOodood0POn1om_o
m@3hooD0POoeood0POn1oh7oPOodood0POn1om_om@3hooD0POoeood0POn1oh7o
POoeo`1L0?om087oPOoKooD0n?oe087omOom087oPOn1oh7om?om087oPOoKooD0
n?oe087omOom087oPOn1oh7om?om087oPOoKooD0n?oe087omOom087oPOn1oh7o
mOl0G03oo@21oh7ofooe0?Som@21ooGoo@21oh7oPOn1ooCoo@21oh7ofooe0?So
m@21ooGoo@21oh7oPOn1ooCoo@21oh7ofooe0?Som@21ooGoo@21oh7oPOn1ooGo
05`0ood0POn1om_om@3hooD0POoeood0POn1oh7oPOodood0POn1om_om@3hooD0
POoeood0POn1oh7oPOodood0POn1om_om@3hooD0POoeood0POn1oh7oPOoeo`1L
0?om087oPOoKooD0n?oe087omOom087oPOn1oh7om?om087oPOoKooD0n?oe087o
mOom087oPOn1oh7om?om087oPOoKooD0n?oe087omOom087oPOn1oh7omOl0G03o
o@21oh7ofooe0?Som@21ooGoo@21oh7oPOn1ooCoo@21oh7ofooe0?Som@21ooGo
o@21oh7oPOn1ooCoo@21oh7ofooe0?Som@21ooGoo@21oh7oPOn1ooGo05`0ood0
POn1om_om@3hooD0POoeood0POn1oh7oPOodood0POn1om_om@3hooD0POoeood0
POn1oh7oPOodood0POn1om_om@3hooD0POoeood0POn1oh7oPOoeo`1L0?om087o
POoKooD0n?oe087omOom087oPOn1oh7om?om087oPOoKooD0n?oe087omOom087o
POn1oh7om?om087oPOoKooD0n?oe087omOom087oPOn1oh7omOl0G03oo@21oh7o
fooe0?Som@21ooGoo@21oh7oPOn1ooCoo@21oh7ofooe0?Som@21ooGoo@21oh7o
POn1ooCoo@21oh7ofooe0?Som@21ooGoo@21oh7oPOn1ooGo05`0ood0POn1om_o
m@3hooD0POoeood0POn1oh7oPOodood0POn1om_om@3hooD0POoeood0POn1oh7o
POodood0POn1om_om@3hooD0POoeood0POn1oh7oPOoeo`1L0?om087oPOoKooD0
n?oe087omOom087oPOn1oh7om?om087oPOoKooD0n?oe087omOom087oPOn1oh7o
m?om087oPOoKooD0n?oe087omOom087oPOn1oh7omOl0G03oo@21oh7ofooe0?So
m@21ooGoo@21oh7oPOn1ooCoo@21oh7ofooe0?Som@21ooGoo@21oh7oPOn1ooCo
o@21oh7ofooe0?Som@21ooGoo@21oh7oPOn1ooGo05`0ood0POn1om_om@3hooD0
POoeood0POn1oh7oPOodood0POn1om_om@3hooD0POoeood0POn1oh7oPOodood0
POn1om_om@3hooD0POoeood0POn1oh7oPOoeo`1L0?om087oPOoKooD0n?oe087o
mOom087oPOn1oh7om?om087oPOoKooD0n?oe087omOom087oPOn1oh7om?om087o
POoKooD0n?oe087omOom087oPOn1oh7omOl0E840SP39ooD0n?oe087omOom087o
POn1oh7omOn108h0bOoe0?Som@21ooGoo@21oh7oPOn1ooGoP@2>0<Wom@3hooD0
POoeood0POn1oh7oPOoeo`1DP@2>0<Wom@3hooD0POoeood0POn1oh7oPOoeoh40
SP39ooD0n?oe087omOom087oPOn1oh7omOn108h0bOoe0?Som@21ooGoo@21oh7o
POn1ooGo05B108h0bOoe0?Som@21ooGoo@21oh7oPOn1ooGoP@2>0<Wom@3hooD0
POoeood0POn1oh7oPOoeoh40SP39ooD0n?oe087omOom087oPOn1oh7omOl0E840
SP39ooD0n?oe087omOom087oPOn1oh7omOn108h0bOoe0?Som@21ooGoo@21oh7o
POn1ooGoP@2>0<Wom@3hooD0POoeood0POn1oh7oPOoeo`1R0?om087oV?ol0<Wo
m@3hooD0POoeood0POn1oh7oPOodood0POnHoo`0bOoe0?Som@21ooGoo@21oh7o
POn1ooCoo@21oiSoo039ooD0n?oe087omOom087oPOn1oh7omOl0HP3oo@21oiSo
o039ooD0n?oe087omOom087oPOn1oh7om?om087oV?ol0<Wom@3hooD0POoeood0
POn1oh7oPOodood0POnHoo`0bOoe0?Som@21ooGoo@21oh7oPOn1ooGo0680ood0
POnHoo`0bOoe0?Som@21ooGoo@21oh7oPOn1ooCoo@21oiSoo039ooD0n?oe087o
mOom087oPOn1oh7om?om087oV?ol0<Wom@3hooD0POoeood0POn1oh7oPOoeo`1R
0?om087oV?ol0<Wom@3hooD0POoeood0POn1oh7oPOodood0POnHoo`0bOoe0?So
m@21ooGoo@21oh7oPOn1ooCoo@21oiSoo039ooD0n?oe087omOom087oPOn1oh7o
mOl0HP3oo@21oiSoo039ooD0n?oe087omOom087oPOn1oh7om?om087oV?ol0<Wo
m@3hooD0POoeood0POn1oh7oPOodood0POnHoo`0bOoe0?Som@21ooGoo@21oh7o
POn1ooGo0680ood0POnHoo`0bOoe0?Som@21ooGoo@21oh7oPOn1ooCoo@21oiSo
o039ooD0n?oe087omOom087oPOn1oh7om?om087oV?ol0<Wom@3hooD0POoeood0
POn1oh7oPOoeo`1R0?om087oV?ol0<Wom@3hooD0POoeood0POn1oh7oPOodood0
POnHoo`0bOoe0?Som@21ooGoo@21oh7oPOn1ooCoo@21oiSoo039ooD0n?oe087o
mOom087oPOn1oh7omOl0HP3oo@21oiSoo039ooD0n?oe087omOom087oPOn1oh7o
m?om087oV?ol0<Wom@3hooD0POoeood0POn1oh7oPOodood0POnHoo`0bOoe0?So
m@21ooGoo@21oh7oPOn1ooGo0680ood0POnHoo`0bOoe0?Som@21ooGoo@21oh7o
POn1ooCoo@21oiSoo039ooD0n?oe087omOom087oPOn1oh7om?om087oV?ol0<Wo
m@3hooD0POoeood0POn1oh7oPOoeo`1R0?om087oV?ol0<Wom@3hooD0POoeood0
POn1oh7oPOodood0POnHoo`0bOoe0?Som@21ooGoo@21oh7oPOn1ooCoo@21oiSo
o039ooD0n?oe087omOom087oPOn1oh7omOl0HP3oo@21oiSoo039ooD0n?oe087o
mOom087oPOn1oh7om?om087oV?ol0<Wom@3hooD0POoeood0POn1oh7oPOodood0
POnHoo`0bOoe0?Som@21ooGoo@21oh7oPOn1ooGo0680ood0POnHoo`0bOoe0?So
m@21ooGoo@21oh7oPOn1ooCoo@21oiSoo039ooD0n?oe087omOom087oPOn1oh7o
m?om087oV?ol0<Wom@3hooD0POoeood0POn1oh7oPOoeo`1R0?om087oV?ol0<Wo
m@3hooD0POoeood0POn1oh7oPOodood0POnHoo`0bOoe0?Som@21ooGoo@21oh7o
POn1ooCoo@21oiSoo039ooD0n?oe087omOom087oPOn1oh7omOl0HP3oo@21oiSo
o039ooD0n?oe087omOom087oPOn1oh7om?om087oV?ol0<Wom@3hooD0POoeood0
POn1oh7oPOodood0POnHoo`0bOoe0?Som@21ooGoo@21oh7oPOn1ooGo0680ood0
POnHoo`0bOoe0?Som@21ooGoo@21oh7oPOn1ooCoo@21oiSoo039ooD0n?oe087o
mOom087oPOn1oh7om?om087oV?ol0<Wom@3hooD0POoeood0POn1oh7oPOoeo`1R
0?om087oV?ol0<Wom@3hooD0POoeood0POn1oh7oPOodood0POnHoo`0bOoe0?So
m@21ooGoo@21oh7oPOn1ooCoo@21oiSoo039ooD0n?oe087omOom087oPOn1oh7o
mOl0HP3oo@21oiSoo039ooD0n?oe087omOom087oPOn1oh7om?om087oV?ol0<Wo
m@3hooD0POoeood0POn1oh7oPOodood0POnHoo`0bOoe0?Som@21ooGoo@21oh7o
POn1ooGo0680ood0POnHoo`0bOoe0?Som@21ooGoo@21oh7oPOn1ooCoo@21oiSo
o039ooD0n?oe087omOom087oPOn1oh7om?om087oV?ol0<Wom@3hooD0POoeood0
POn1oh7oPOoeo`1:0?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087o
W?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7omOl0BP3oo@21oiSo
o021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSo
o021oicoo@21oh7oPOn1ooGo04X0ood0POnHoo`0POnLood0POn1oh7oPOodood0
POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOoeo`1:
0?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7o
m?om087oV?ol087oW?om087oPOn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7o
POn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7o
POn1ooGo04X0ood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0
POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOoeo`1:0?om087oV?ol087o
W?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087o
W?om087oPOn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSo
o021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooGo04X0ood0
POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOodood0
POnHoo`0POnLood0POn1oh7oPOoeo`1:0?om087oV?ol087oW?om087oPOn1oh7o
m?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7o
mOl0BP3oo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7o
POn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooGo04X0ood0POnHoo`0POnLood0
POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0
POn1oh7oPOoeo`1:0?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087o
W?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7omOl0BP3oo@21oiSo
o021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSo
o021oicoo@21oh7oPOn1ooGo04X0ood0POnHoo`0POnLood0POn1oh7oPOodood0
POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOoeo`1:
0?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7o
m?om087oV?ol087oW?om087oPOn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7o
POn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7o
POn1ooGo04X0ood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0
POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOoeo`1:0?om087oV?ol087o
W?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087o
W?om087oPOn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSo
o021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooGo04X0ood0
POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOodood0
POnHoo`0POnLood0POn1oh7oPOoeo`1:0?om087oV?ol087oW?om087oPOn1oh7o
m?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7o
mOl0BP3oo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7o
POn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooGo04X0ood0POnHoo`0POnLood0
POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0
POn1oh7oPOoeo`1:0?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087o
W?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7omOl0BP3oo@21oiSo
o021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSo
o021oicoo@21oh7oPOn1ooGo04X0ood0POnHoo`0POnLood0POn1oh7oPOodood0
POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOoeo`1:
0?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7o
m?om087oV?ol087oW?om087oPOn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7o
POn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7o
POn1ooGo04X0ood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0
POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOoeo`1:0?om087oV?ol087o
W?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087o
W?om087oPOn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSo
o021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooGo04X0ood0
POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOodood0
POnHoo`0POnLood0POn1oh7oPOoeo`1:0?om087oV?ol087oW?om087oPOn1oh7o
m?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7o
mOl0BP3oo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7o
POn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooGo04X0ood0POnHoo`0POnLood0
POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0
POn1oh7oPOoeo`1:0?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087o
W?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7omOl0BP3oo@21oiSo
o021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSo
o021oicoo@21oh7oPOn1ooGo04X0ood0POnHoo`0POnLood0POn1oh7oPOodood0
POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOoeo`1:
0?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7o
m?om087oV?ol087oW?om087oPOn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7o
POn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7o
POn1ooGo04X0ood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0
POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOoeo`1:0?om087oV?ol087o
W?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087o
W?om087oPOn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSo
o021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooGo04X0ood0
POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOodood0
POnHoo`0POnLood0POn1oh7oPOoeo`1:0?om087oV?ol087oW?om087oPOn1oh7o
m?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7o
mOl0BP3oo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7o
POn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooGo04X0ood0POnHoo`0POnLood0
POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0
POn1oh7oPOoeo`1:0?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087o
W?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7omOl0BP3oo@21oiSo
o021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSo
o021oicoo@21oh7oPOn1ooGo04X0ood0POnHoo`0POnLood0POn1oh7oPOodood0
POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOoeo`1:
0?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7o
m?om087oV?ol087oW?om087oPOn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7o
POn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7o
POn1ooGo04X0ood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0
POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOoeo`1:0?om087oV?ol087o
W?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087o
W?om087oPOn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSo
o021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooGo04X0ood0
POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOodood0
POnHoo`0POnLood0POn1oh7oPOoeo`1F0?om08komP2Foo`0Soof09Woo@21oh7o
POn1ooCoo@2>ooH0U_ol08oomP2Iood0POn1oh7oPOodood0S_of09Koo02?ooH0
VOom087oPOn1oh7omOl0EP3oo@2Bonh0V_ol09?okP2Mood0POn1oh7oPOodood0
T_o^09[oo02Conh0WOom087oPOn1oh7om?om09;okP2Joo`0Too^09goo@21oh7o
POn1ooGo05H0ood0U?oZ09coo02EonX0Woom087oPOn1oh7om?om09CojP2Loo`0
UOoZ09ooo@21oh7oPOn1ooCoo@2DonX0W?ol09GojP2Oood0POn1oh7oPOoeo`1F
0?om09KoiP2Noo`0UooV0:7oo@21oh7oPOn1ooCoo@2FonH0W_ol09OoiP2Qood0
POn1oh7oPOodood0U_oV09koo02GonH0XOom087oPOn1oh7omOl0EP3oo@2Hon<0
Wool09Woh`2Rood0POn1oh7oPOodood0V?oS09ooo02Ion<0X_om087oPOn1oh7o
m?om09Soh`2Ooo`0VOoS0:;oo@21oh7oPOn1ooGo05H0ood0VOoP0:7oo02Jon00
Y?om087oPOn1oh7om?om09Woh02Qoo`0V_oP0:Coo@21oh7oPOn1ooCoo@2Ion00
XOol09[oh02Tood0POn1oh7oPOoeo`1^0?om09[om03hoo@0X_ol09_om03hoo@0
YOom087oPOn1oh7om?om09[om03hoo@0X_ol09_om03hoo@0YOom087oPOn1oh7o
m?om09[om03hoo@0X_ol09_om03hoo@0YOom087oPOn1oh7omOl0KP3oo@2KooH0
l_og0:;oo02LooH0l_og0:Goo@21oh7oPOn1ooCoo@2KooH0l_og0:;oo02LooH0
l_og0:Goo@21oh7oPOn1ooCoo@2KooH0l_og0:;oo02LooH0l_og0:Goo@21oh7o
POn1ooGo06h0ood0W?og0>kon02Soo`0WOog0>kon02Vood0POn1oh7oPOodood0
W?og0>kon02Soo`0WOog0>kon02Vood0POn1oh7oPOodood0W?og0>kon02Soo`0
WOog0>kon02Vood0POn1oh7oPOoeo`1^0?om09gon03[ooP0Y?ol09kon03[ooP0
Yoom087oPOn1oh7om?om09gon03[ooP0Y?ol09kon03[ooP0Yoom087oPOn1oh7o
m?om09gon03[ooP0Y?ol09kon03[ooP0Yoom087oPOn1oh7omOl0KP3oo@2MooT0
jOoh0:Goo02NooT0jOoh0:Soo@21oh7oPOn1ooCoo@2MooT0jOoh0:Goo02NooT0
jOoh0:Soo@21oh7oPOn1ooCoo@2MooT0jOoh0:Goo02NooT0jOoh0:Soo@21oh7o
POn1ooGo06h0ood0W_oi0>Oon@2Uoo`0Wooi0>Oon@2Xood0POn1oh7oPOodood0
W_oi0>Oon@2Uoo`0Wooi0>Oon@2Xood0POn1oh7oPOodood0W_oi0>Oon@2Uoo`0
Wooi0>Oon@2Xood0POn1oh7oPOoeo`1^0?om09oon@3UooT0Y_ol0:3on@3UooT0
ZOom087oPOn1oh7om?om09oon@3UooT0Y_ol0:3on@3UooT0ZOom087oPOn1oh7o
m?om09oon@3UooT0Y_ol0:3on@3UooT0ZOom087oPOn1oh7omOl0KP3oo@2OooT0
iOoi0:Koo02PooT0iOoi0:Woo@21oh7oPOn1ooCoo@2OooT0iOoi0:Koo02PooT0
iOoi0:Woo@21oh7oPOn1ooCoo@2OooT0iOoi0:Koo02PooT0iOoi0:Woo@21oh7o
POn1ooGo06h0ood0X?oi0>?onP2Voo`0XOoi0>?onP2Yood0POn1oh7oPOodood0
X?oi0>?onP2Voo`0XOoi0>?onP2Yood0POn1oh7oPOodood0X?oi0>?onP2Voo`0
XOoi0>?onP2Yood0POn1oh7oPOoeo`1^0?om0:3on@3SooT0Yool0:7on@3SooT0
Z_om087oPOn1oh7om?om0:3on@3SooT0Yool0:7on@3SooT0Z_om087oPOn1oh7o
m?om0:3on@3SooT0Yool0:7on@3SooT0Z_om087oPOn1oh7omOl0KP3oo@2PooX0
hOoj0:Ooo02QooX0hOoj0:[oo@21oh7oPOn1ooCoo@2PooX0hOoj0:Ooo02QooX0
hOoj0:[oo@21oh7oPOn1ooCoo@2PooX0hOoj0:Ooo02QooX0hOoj0:[oo@21oh7o
POn1ooGo06h0ood0XOoi0>7onP2Woo`0X_oi0>7onP2Zood0POn1oh7oPOodood0
XOoi0>7onP2Woo`0X_oi0>7onP2Zood0POn1oh7oPOodood0XOoi0>7onP2Woo`0
X_oi0>7onP2Zood0POn1oh7oPOoeo`1O0?om0:7onP21o`7ooo`0X_oj08;oo@21
oh7oPOn1ooCoo@2QooX0POl1oool0:;onP22ood0POn1oh7oPOodood0XOoj087o
0Oooo02RooX0P_om087oPOn1oh7omOl0G`3oo@2QooX0POl1oool0:;onP22ood0
POn1oh7oPOodood0XOoj087o0Oooo02RooX0P_om087oPOn1oh7om?om0:7onP21
o`7ooo`0X_oj08;oo@21oh7oPOn1ooGo05l0ood0XOoj087o0Oooo02RooX0P_om
087oPOn1oh7om?om0:7onP21o`7ooo`0X_oj08;oo@21oh7oPOn1ooCoo@2QooX0
POl1oool0:;onP22ood0POn1oh7oPOoeo`1O0?om0:;on@21o`7ooo`0Xooi08;o
o@21oh7oPOn1ooCoo@2RooT0POl1oool0:?on@22ood0POn1oh7oPOodood0X_oi
087o0Oooo02SooT0P_om087oPOn1oh7omOl0G03oo@2RooX0POonoo`0Xooj087o
o@21oh7oPOn1ooCoo@2RooX0POonoo`0Xooj087oo@21oh7oPOn1ooCoo@2RooX0
POonoo`0Xooj087oo@21oh7oPOn1ooGo05`0ood0X_oj087oo_ol0:?onP21ood0
POn1oh7oPOodood0X_oj087oo_ol0:?onP21ood0POn1oh7oPOodood0X_oj087o
o_ol0:?onP21ood0POn1oh7oPOoeo`1L0?om0:;onP21ookoo02SooX0POom087o
POn1oh7om?om0:;onP21ookoo02SooX0POom087oPOn1oh7om?om0:;onP21ooko
o02SooX0POom087oPOn1oh7omOl0G03oo@2RooX0POonoo`0Xooj087oo@21oh7o
POn1ooCoo@2RooX0POonoo`0Xooj087oo@21oh7oPOn1ooCoo@2RooX0POonoo`0
Xooj087oo@21oh7oPOn1ooGo05`0ood0X_oj087oo_ol0:?onP21ood0POn1oh7o
POodood0X_oj087oo_ol0:?onP21ood0POn1oh7oPOodood0X_oj087oo_ol0:?o
nP21ood0POn1oh7oPOoeo`1L0?om0:;onP21ookoo02SooX0POom087oPOn1oh7o
m?om0:;onP21ookoo02SooX0POom087oPOn1oh7om?om0:;onP21ookoo02SooX0
POom087oPOn1oh7omOl0G03oo@2RooX0POonoo`0Xooj087oo@21oh7oPOn1ooCo
o@2RooX0POonoo`0Xooj087oo@21oh7oPOn1ooCoo@2RooX0POonoo`0Xooj087o
o@21oh7oPOn1ooGo05`0ood0X_oj087oo_ol0:?onP21ood0POn1oh7oPOodood0
X_oj087oo_ol0:?onP21ood0POn1oh7oPOodood0X_oj087oo_ol0:?onP21ood0
POn1oh7oPOoeo`1L0?om0:;onP21ookoo02SooX0POom087oPOn1oh7om?om0:;o
nP21ookoo02SooX0POom087oPOn1oh7om?om0:;onP21ookoo02SooX0POom087o
POn1oh7omOl0G03oo@2RooX0POonoo`0Xooj087oo@21oh7oPOn1ooCoo@2RooX0
POonoo`0Xooj087oo@21oh7oPOn1ooCoo@2RooX0POonoo`0Xooj087oo@21oh7o
POn1ooGo05`0ood0X_oj087oo_ol0:?onP21ood0POn1oh7oPOodood0X_oj087o
o_ol0:?onP21ood0POn1oh7oPOodood0X_oj087oo_ol0:?onP21ood0POn1oh7o
POoeo`1L0?om0:;onP21ookoo02SooX0POom087oPOn1oh7om?om0:;onP21ooko
o02SooX0POom087oPOn1oh7om?om0:;onP21ookoo02SooX0POom087oPOn1oh7o
mOl0QP3oo@2Qoo/0c_oi0>oonP3Boo`0X_ok0=3onP3Tood0f_om087oPOn1oh7o
m?om0:7on`3>ooT0kooj0=;oo02Roo/0d?oj0>Coo@3Jood0POn1oh7oPOodood0
XOok0<kon@3_ooX0d_ol0:;on`3@ooX0i?om0=[oo@21oh7oPOn1ooGo09h0ood0
XOoj0>3onP3joo@0looe0=Goo02RooX0h?oj0?_om@3Xoo`0f_om087oPOn1oh7o
m?om0:7onP3PooX0n_od0??om@3Eoo`0X_oj0>3onP3kooD0j?ol0=[oo@21oh7o
POn1ooCoo@2QooX0h?oj0?[om03cooD0eOol0:;onP3PooX0nooe0>Soo03Jood0
POn1oh7oPOoeo`2N0?om0:7onP3PooX0nooa0?OolP3Foo`0X_oj0>3onP3moo80
jOol0=[oo@21oh7oPOn1ooCoo@2QooX0h?oj0?_ol@3goo80e_ol0:;onP3PooX0
oOob0>Woo03Jood0POn1oh7oPOodood0XOoj0>3onP3koo40moob0=Koo02RooX0
h?oj0?golP3Yoo`0f_om087oPOn1oh7omOl0WP3oo@2QooX0hOoi0?col03hoo00
eool0:;onP3QooT0o_o`0>_on`3Jood0POn1oh7oPOodood0XOoj0>7on@3loo00
n?o`0=Ooo02RooX0hOoi0?kol03[oo/0f_om087oPOn1oh7om?om0:7onP3QooT0
o?o`0?Sol03Goo`0X_oj0>7on@3noo00jook0=[oo@21oh7oPOn1ooGo0<80ood0
XOoi0>;onP3loo/0n_ok0?Won`3koo/0f?ol0:;on@3RooX0oOok0?_on`3]ooX0
f_om087oPOn1oh7om?om0:7on@3RooX0o?ok0?[on`3ioo/0nook0=Soo02RooT0
h_oj0?gon`3koo/0kOoj0=[oo@21oh7oPOn1ooCoo@2QooT0h_oj0?con`3joo/0
nOok0?_on`3Hoo`0X_oi0>;onP3moo/0nook0>gonP3Jood0POn1oh7oPOoeo`32
0?om0:3onP3RooX0oOok0?Ooo03koo`0n?ol0=Soo02QooX0h_oj0?koo03hoo`0
k_oi0=[oo@21oh7oPOn1ooCoo@2PooX0h_oj0?gon`3goo`0nool0?Soo03Hoo`0
XOoj0>;onP3noo`0n?ol0>kon@3Jood0POn1oh7oPOodood0X?oj0>;onP3moo/0
mool0?_oo03hoo`0f?ol0:7onP3RooX0o_ol0?Soo03^ooT0f_om087oPOn1oh7o
mOl0`P3oo@2PooX0hooi0?goo03eood0noom0?Koo03Ioo`0XOoj0>?on@3nood0
m_ol0>oon@3Jood0POn1oh7oPOodood0X?oj0>?on@3moo`0mOom0?_oo@3foo`0
fOol0:7onP3SooT0o_om0?Koo03_ooT0f_om087oPOn1oh7om?om0:3onP3SooT0
oOol0?Goo@3kood0m_ol0=Woo02QooX0hooi0?koo@3foo`0kooi0=[oo@21oh7o
POn1ooGo0<80ood0X?oi0>ConP3lood0m?ol0?coo@3eood0fOol0:7on@3TooX0
oOom0?Goo@3`ooP0f_om087oPOn1oh7om?om0:3on@3TooX0o?om0?Coo03lood0
mOom0=Woo02QooT0i?oj0?goo@3eood0l?oh0=[oo@21oh7oPOn1ooCoo@2PooT0
i?oj0?coo@3doo`0o?om0?Goo@3Ioo`0XOoi0>ConP3mood0mOom0?3on03Jood0
POn1oh7oPOoeo`3>0?om09oonP3UooT0oOol0??oo@3moo`0mOom0=Woo02PooX0
iOoi0?koo03eood0lOol003oo@3Jood0POn1oh7oPOodood0Wooj0>Gon@3moo`0
loom0?goo03eood0fOol0:3onP3UooT0o_ol0?Goo@3aoo`00?om0=[oo@21oh7o
POn1ooCoo@2OooX0iOoi0?goo03cood0oOol0?Goo@3Ioo`0X?oj0>Gon@3noo`0
mOom0?7oo000ood0f_om087oPOn1oh7omOl0d@3oo@2OooT0i_oi0?goo@3bood0
oOom0?Coo@3Ioo`0X?oi0>Kon@3nood0m?om0?;oo001ooom0=[oo@21oh7oPOn1
ooCoo@2OooT0i_oi0?goo@3bood0oOom0?Coo@3Ioo`0X?oi0>Kon@3nood0m?om
0?;oo001ooom0=[oo@21oh7oPOn1ooCoo@2OooT0i_oi0?goo@3bood0oOom0?Co
o@3Ioo`0X?oi0>Kon@3nood0m?om0?;oo001ooom0=[oo@21oh7oPOn1ooGo0<h0
ood0W_oi0>Son@3lood0l_om0?goo@3dood0fOol09oon@3XooT0oOom0?Coo@3b
ood0o_om0=[oo@21oh7oPOn1ooCoo@2NooT0j?oi0?coo@3bood0oOom0?Coo@3I
oo`0Wooi0>Son@3mood0m?om0?;oo@3nood0f_om087oPOn1oh7om?om09kon@3X
ooT0o?om0?;oo@3mood0m?om0=Woo02OooT0j?oi0?goo@3dood0l_om0?koo@3J
ood0POn1oh7oPOoeo`3>0?om09kon03ZooT0noom0?;oo@3mood0m?om0=Woo02O
ooP0j_oi0?coo@3dood0lool0?koo@3Jood0POn1oh7oPOodood0W_oh0>[on@3k
ood0l_om0?goo@3dood0fOol09oon03ZooT0o?om0?Coo@3coo`0o_om0=[oo@21
oh7oPOn1ooCoo@2NooP0j_oi0?_oo@3bood0oOom0?Coo@3Ioo`0Wooh0>[on@3l
ood0m?om0??oo03nood0f_om087oPOn1oh7omOl0ZP3oo@2MooP0k?oh0>Soo@3]
oo`0fOol09kon03/ooP0k?ol0?Coo03mood0f_om087oPOn1oh7om?om09gon03/
ooP0j?om0>goo03Ioo`0W_oh0>con03/oo`0m?ol0?goo@3Jood0POn1oh7oPOod
ood0WOoh0>con03Xood0kOol0=Woo02NooP0k?oh0>coo03doo`0oOom0=[oo@21
oh7oPOn1ooGo0:X0ood0W?oh0>kon03Xoo`0k_ol0=Soo02MooP0k_oh0>coo03d
oo`0o?om0=[oo@21oh7oPOn1ooCoo@2LooP0k_oh0>Soo03^oo`0f?ol09gon03^
ooP0k?ol0?Coo03lood0f_om087oPOn1oh7om?om09con03^ooP0j?ol0>koo03H
oo`0WOoh0>kon03/oo`0m?ol0?coo@3Jood0POn1oh7oPOoeo`2Z0?om09_om`3b
ooL0j?ol0>kon`3Hoo`0W?og0?;om`3/oo/0mOol0?_oo@3Jood0POn1oh7oPOod
ood0Voog0?;om`3Xoo`0k_ok0=Soo02LooL0l_og0>con`3eoo`0noom0=[oo@21
oh7oPOn1ooCoo@2KooL0l_og0>Soo03^oo/0f?ol09com`3booL0k?ok0?Goo03k
ood0f_om087oPOn1oh7omOl0ZP3oo@2JooD0n?oe0>Son`3dooH0eool09_om@3h
ooD0lOof0?Coo@3jood0f_om087oPOn1oh7om?om09[om@3hooD0j?ok0?ComP3G
oo`0Vooe0?Som@3aooH0m?om0?[oo@3Jood0POn1oh7oPOodood0V_oe0?Som@3X
oo/0m?of0=Ooo02KooD0n?oe0?7omP3dood0n_om0=[oo@21oh7oPOn1ooGo0980
ood0VOoR0>Son`3cooP0eOol09[ohP3`ooP0lool0?[oo@3Jood0POn1oh7oPOod
ood0VOoR0>Son`3cooP0eOol09[ohP3`ooP0lool0?[oo@3Jood0POn1oh7oPOod
ood0VOoR0>Son`3cooP0eOol09[ohP3`ooP0lool0?[oo@3Jood0POn1oh7oPOoe
o`2B0?om09Soi03YooX0l_of0=Ooo02Ion@0koof0?Koo03iood0f_om087oPOn1
oh7om?om09Soi03YooX0l_of0=Ooo02Ion@0koof0?Koo03iood0f_om087oPOn1
oh7om?om09Soi03YooX0l_of0=Ooo02Ion@0koof0?Koo03iood0f_om087oPOn1
oh7omOl0TP3oo@2GonH0j_oi0?7om03Ioo`0V?oV0>kom03ioo`0n?om0=[oo@21
oh7oPOn1ooCoo@2GonH0j_oi0?7om03Ioo`0V?oV0>kom03ioo`0n?om0=[oo@21
oh7oPOn1ooCoo@2GonH0j_oi0?7om03Ioo`0V?oV0>kom03ioo`0n?om0=[oo@21
oh7oPOn1ooGo0980ood0UOoZ0>Won@3ZooT0f_ol09KojP3VooT0n_om0?Ooo@3J
ood0POn1oh7oPOodood0UOoZ0>Won@3ZooT0f_ol09KojP3VooT0n_om0?Ooo@3J
ood0POn1oh7oPOodood0UOoZ0>Won@3ZooT0f_ol09KojP3VooT0n_om0?Ooo@3J
ood0POn1oh7oPOoeo`2B0?om09?ok`3XooT0iOol0=[oo02Donl0h?ol0?_oo03g
ood0f_om087oPOn1oh7om?om09?ok`3XooT0iOol0=[oo02Donl0h?ol0?_oo03g
ood0f_om087oPOn1oh7om?om09?ok`3XooT0iOol0=[oo02Donl0h?ol0?_oo03g
ood0f_om087oPOn1oh7omOl0TP3oo@2?ooH0iooh0>?oo03Koo`0T?of0=coo03m
oo`0m_om0=[oo@21oh7oPOn1ooCoo@2?ooH0iooh0>?oo03Koo`0T?of0=coo03m
oo`0m_om0=[oo@21oh7oPOn1ooCoo@2?ooH0iooh0>?oo03Koo`0T?of0=coo03m
oo`0m_om0=[oo@21oh7oPOn1ooGo07X0ood0POo[ooT0hOol0=_oo021on3oo03m
onP0goom087oPOn1oh7om?om087ojooi0>7oo03Koo`0POoPoo`0oOoX0=ooo@21
oh7oPOn1ooCoo@21on_on@3Qoo`0fool087oh?ol0?goj03Oood0POn1oh7oPOoe
o`1j0?om087ok?oj0=koo@3Koo`0POoOood0oOoX0=ooo@21oh7oPOn1ooCoo@21
onconP3Nood0fool087ogoom0?goj03Oood0POn1oh7oPOodood0POo/ooX0g_om
0=_oo021omooo@3monP0goom087oPOn1oh7omOl0TP3oo@21ongon`3`ood0lOom
0=_oo021oo?oo@3aood0oOoX0=ooo@21oh7oPOn1ooCoo@21ongon`3`ood0lOom
0=_oo021oo?oo@3aood0oOoX0=ooo@21oh7oPOn1ooCoo@21ongon`3`ood0lOom
0=_oo021oo?oo@3aood0oOoX0=ooo@21oh7oPOn1ooGo0980ood0POo^oo/0koom
0?7oo@3Koo`0POocood0lOom0?goj03Oood0POn1oh7oPOodood0POo^oo/0koom
0?7oo@3Koo`0POocood0lOom0?goj03Oood0POn1oh7oPOodood0POo^oo/0koom
0?7oo@3Koo`0POocood0lOom0?goj03Oood0POn1oh7oPOoeo`2B0?om087okool
0>goo@3aood0fool087oloom0?7oo@3]ood0f_om087oPOn1oh7om?om087okool
0>goo@3aood0fool087oloom0?7oo@3]ood0f_om087oPOn1oh7om?om087okool
0>goo@3aood0fool087oloom0?7oo@3]ood0f_om087oPOn1oh7omOl0TP3oo@21
onooo@3/oo`0l_om0=_oo021oo?oo03bood0kOom0=[oo@21oh7oPOn1ooCoo@21
onooo@3/oo`0l_om0=_oo021oo?oo03bood0kOom0=[oo@21oh7oPOn1ooCoo@21
onooo@3/oo`0l_om0=_oo021oo?oo03bood0kOom0=[oo@21oh7oPOn1ooGo0980
ood0POo`ood0j_om0??oo@3Joo`0POobood0loom0>coo@3Jood0POn1oh7oPOod
ood0POo`ood0j_om0??oo@3Joo`0POobood0loom0>coo@3Jood0POn1oh7oPOod
ood0POo`ood0j_om0??oo@3Joo`0POobood0loom0>coo@3Jood0POn1oh7oPOoe
o`2B0?om087ol?om0>[oo03eoo`0f_ol087ol_ol0?Goo03/ood0f_om087oPOn1
oh7om?om087ol?om0>[oo03eoo`0f_ol087ol_ol0?Goo03/ood0f_om087oPOn1
oh7om?om087ol?om0>[oo03eoo`0f_ol087ol_ol0?Goo03/ood0f_om087oPOn1
oh7omOl0]P3oo@2Noo@0n?oe0?GooP3Yoo/0mook0=[oo02Roo@0nOod0??on`3g
oo/0k?om0=[oo@21oh7oPOn1ooCoo@2Noo@0n?oe0?GooP3Yoo/0mook0=[oo02R
oo@0nOod0??on`3goo/0k?om0=[oo@21oh7oPOn1ooCoo@2Noo@0n?oe0?GooP3Y
oo/0mook0=[oo02Roo@0nOod0??on`3goo/0k?om0=[oo@21oh7oPOn1ooGo0;H0
ood0W_od0?Som@3fonT0o?ok0?[onP3Ioo`0X_od0?Wom03boo/0n_oj0>_oo@3J
ood0POn1oh7oPOodood0W_od0?Som@3fonT0o?ok0?[onP3Ioo`0X_od0?Wom03b
oo/0n_oj0>_oo@3Jood0POn1oh7oPOodood0W_od0?Som@3fonT0o?ok0?[onP3I
oo`0X_od0?Wom03boo/0n_oj0>_oo@3Jood0POn1oh7oPOoeo`2N0?om09kom03h
ooD0m_oY0?_ok`3Hoo`0X_od0?Wom03aonl0j_om0=[oo@21oh7oPOn1ooCoo@2N
oo@0n?oe0?Koj@3konl0f?ol0:;om03ioo@0lOo_0>[oo@3Jood0POn1oh7oPOod
ood0W_od0?Som@3fonT0noo_0=Soo02Roo@0nOod0?7ok`3Zood0f_om087oPOn1
oh7omOl0WP3oo@2Noo@0n?oe0?Koj@3joo40eool0:;om03ioo@0l?oa0>Woo@3J
ood0POn1oh7oPOodood0W_od0?Som@3fonT0n_oa0=Ooo02Roo@0nOod0?3ol@3Y
ood0f_om087oPOn1oh7om?om09kom03hooD0m_oY0?[ol@3Goo`0X_od0?Wom03`
oo40jOom0=[oo@21oh7oPOn1ooGo09h0ood0W_od0?Som@3fonT0nOod0=Goo02R
oo@0nOod0>oom03Wood0f_om087oPOn1oh7om?om09kom03hooD0m_oY0?Wom03E
oo`0X_od0?Wom03_oo@0ioom0=[oo@21oh7oPOn1ooCoo@2Noo@0n?oe0?Koj@3i
oo@0eOol0:;om03ioo@0kood0>Ooo@3Jood0POn1oh7oPOoeo`260?om09kom03h
ooD0e?oh0=?oo02Roo@0nOod0>gon02jood0POn1oh7oPOodood0W_od0?Som@3D
ooP0dool0:;om03ioo@0kOoh0;[oo@21oh7oPOn1ooCoo@2Noo@0n?oe0=Con03C
oo`0X_od0?Wom03]ooP0^_om087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02R
oo@0nOod09goo@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21
oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0
ood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2M
oo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02M
ood0POn1oh7oPOoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1
oh7om?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03h
ooD0WOol0:;om03ioo@0WOom087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02R
oo@0nOod09goo@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21
oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0
ood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2M
oo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02M
ood0POn1oh7oPOoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1
oh7om?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03h
ooD0WOol0:;om03ioo@0WOom087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02R
oo@0nOod09goo@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21
oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0
ood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2M
oo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02M
ood0POn1oh7oPOoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1
oh7om?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03h
ooD0WOol0:;om03ioo@0WOom087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02R
oo@0nOod09goo@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21
oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0
ood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2M
oo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02M
ood0POn1oh7oPOoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1
oh7om?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03h
ooD0WOol0:;om03ioo@0WOom087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02R
oo@0nOod09goo@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21
oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0
ood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2M
oo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02M
ood0POn1oh7oPOoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1
oh7om?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03h
ooD0WOol0:;om03ioo@0WOom087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02R
oo@0nOod09goo@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21
oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0
ood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2M
oo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02M
ood0POn1oh7oPOoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1
oh7om?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03h
ooD0WOol0:;om03ioo@0WOom087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02R
oo@0nOod09goo@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21
oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0
ood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2M
oo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02M
ood0POn1oh7oPOoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1
oh7om?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03h
ooD0WOol0:;om03ioo@0WOom087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02R
oo@0nOod09goo@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21
oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0
ood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2M
oo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02M
ood0POn1oh7oPOoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1
oh7om?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03h
ooD0WOol0:;om03ioo@0WOom087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02R
oo@0nOod09goo@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21
oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0
ood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2M
oo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02M
ood0POn1oh7oPOoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1
oh7om?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03h
ooD0WOol0:;om03ioo@0WOom087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02R
oo@0nOod09goo@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21
oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0
ood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2M
oo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02M
ood0POn1oh7oPOoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1
oh7om?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03h
ooD0WOol0:;om03ioo@0WOom087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02R
oo@0nOod09goo@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21
oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0
ood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2M
oo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02M
ood0POn1oh7oPOoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1
oh7om?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03h
ooD0WOol0:;om03ioo@0WOom087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02R
oo@0nOod09goo@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21
oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0
ood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2M
oo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02M
ood0POn1oh7oPOoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1
oh7om?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03h
ooD0WOol0:;om03ioo@0WOom087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02R
oo@0nOod09goo@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21
oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0
ood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2M
oo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02M
ood0POn1oh7oPOoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1
oh7om?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03h
ooD0WOol0:;om03ioo@0WOom087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02R
oo@0nOod09goo@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21
oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0
ood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2M
oo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02M
ood0POn1oh7oPOoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1
oh7om?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03h
ooD0WOol0:;om03ioo@0WOom087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02R
oo@0nOod09goo@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21
oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0
ood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2M
oo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02M
ood0POn1oh7oPOoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1
oh7om?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03h
ooD0WOol0:;om03ioo@0WOom087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02R
oo@0nOod09goo@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21
oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0
ood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2M
oo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02M
ood0POn1oh7oPOoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1
oh7om?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03h
ooD0WOol0:;om03ioo@0WOom087oPOn1oh7omOl0K?X0X?od0?Som@2Moo`0X_od
0?Wom02Mood0POn1oh7oPOoeooX0X?od0?Som@2Moo`0X_od0?Wom02Mood0POn1
oh7oPOoeooX0X?od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7oPOoeo`1/n02R
oo@0n?oe09oon02Too@0nOod0:3on021oh7oPOn1ooOon02Roo@0n?oe09oon02T
oo@0nOod0:3on021oh7oPOn1ooOon02Roo@0n?oe09oon02Too@0nOod0:3on021
oh7oPOn1ooOo06cg0:?om03hooD0X?oe0:Kom03ioo@0XOoe087oPOn1oh7onOog
0:?om03hooD0X?oe0:Kom03ioo@0XOoe087oPOn1oh7onOog0:?om03hooD0X?oe
0:Kom03ioo@0XOoe087oPOn1oh7onOl0K?H0Y?od0?Som@2Roo80Yood0?Wom02R
oo<0POn1oh7oPOojooH0Y?od0?Som@2Roo80Yood0?Wom02Roo<0POn1oh7oPOoj
ooH0Y?od0?Som@2Roo80Yood0?Wom02Roo<0POn1oh7oPOojo`1/m@2Uoo@0n?oe
0:;ol@2Xoo@0nOod0:?ol@21oh7oPOn1oo_om@2Uoo@0n?oe0:;ol@2Xoo@0nOod
0:?ol@21oh7oPOn1oo_om@2Uoo@0n?oe0:;ol@2Xoo@0nOod0:?ol@21oh7oPOn1
oo_o06ce0:Gom03hooD0Xoo`0:Som03ioo@0Xooa087oPOn1oh7onooe0:Gom03h
ooD0Xoo`0:Som03ioo@0Xooa087oPOn1oh7onooe0:Gom03hooD0Xoo`0:Som03i
oo@0Xooa087oPOn1oh7onol0K?@0Y_od0?Som@2Tonh0ZOod0?Wom02Tonl0POn1
oh7oPOoloo@0Y_od0?Som@2Tonh0ZOod0?Wom02Tonl0POn1oh7oPOoloo@0Y_od
0?Som@2Tonh0ZOod0?Wom02Tonl0POn1oh7oPOolo`12S03hoh40X03ioh@0POn1
oh7oPOomoh`0n?n10:00nOn4087oPOn1oh7ooOn<0?SoP@2P0?WoQ021oh7oPOn1
oogo04:<0?SoP@2P0?WoQ021oh7oPOn1oogoS03hoh40X03ioh@0POn1oh7oPOom
oh`0n?n10:00nOn4087oPOn1oh7ooOl0@X`0n?n10:00nOn4087oPOn1oh7ooOn<
0?SoP@2P0?WoQ021oh7oPOn1oogoS03hoh40X03ioh@0POn1oh7oPOomo`12S03h
oh40X03ioh@0POn1oh7oPOomoh`0n?n10:00nOn4087oPOn1oh7ooOn<0?SoP@2P
0?WoQ021oh7oPOn1oogo04:<0?SoP@2P0?WoQ021oh7oPOn1oogoS03hoh40X03i
oh@0POn1oh7oPOomoh`0n?n10:00nOn4087oPOn1oh7ooOl0K?@0Y_od0?Som@2U
on`0Z_od0?Wom02Von`0POn1oh7oPOomoo@0Y_od0?Som@2Uon`0Z_od0?Wom02V
on`0POn1oh7oPOomoo@0Y_od0?Som@2Uon`0Z_od0?Wom02Von`0POn1oh7oPOom
o`1/m02Voo@0n?oe0:Cok@2Zoo@0nOod0:Gok@21oh7oPOn1oogom02Voo@0n?oe
0:Cok@2Zoo@0nOod0:Gok@21oh7oPOn1oogom02Voo@0n?oe0:Cok@2Zoo@0nOod
0:Gok@21oh7oPOn1oogo06cd0:Kom03hooD0Y?o^0:Wom03ioo@0YOo]087oPOn1
oh7ooOod0:Kom03hooD0Y?o^0:Wom03ioo@0YOo]087oPOn1oh7ooOod0:Kom03h
ooD0Y?o^0:Wom03ioo@0YOo]087oPOn1oh7ooOl0K?D0YOod0?Som@2Tonh0ZOod
0?Wom02Uonh0POn1oh7oPOolooD0YOod0?Som@2Tonh0ZOod0?Wom02Uonh0POn1
oh7oPOolooD0YOod0?Som@2Tonh0ZOod0?Wom02Uonh0POn1oh7oPOolo`2:mP3d
ooT0^Ood0?Som@2Soo00n_oj0;Kom03ioo@0Y?o`0?;oo@21oh7oPOn>ooH0m?oi
0;Wom03hooD0Xoo`0?[onP2foo@0nOod0:Col03bood0POn1oh7oS_of0?Con@2i
oo@0n?oe0:?ol03jooX0]_od0?Wom02Too00l_om087oPOn1ohko08[g0?Kom02k
oo@0n?oe0:;ol@3looD0^Ood0?Wom02Soo40lool087oPOn1ohkom`3foo@0^ood
0?Som@2Roo40o?oe0;Wom03ioo@0Xooa0??oo021oh7oPOn>ooL0m_od0;_om03h
ooD0X_oa0?com@2ioo@0nOod0:?ol@3coo`0POn1oh7oS_l0R_P0m_oa0;gom03h
ooD0X_ob0?golP2joo@0nOod0:;ol`3boo`0POn1oh7oS_oh0?Kol@2moo@0n?oe
0:;olP3moo80^_od0?Wom02Roo<0l_ol087oPOn1ohkon03foo40_Ood0?Som@2R
oo80oOob0;[om03ioo@0X_oc0?;oo021oh7oPOn>o`2:nP3eoo00_Ood0?Som@2P
ooD0oOo`0;_om03ioo@0XOoe0?;on`21oh7oPOn>ooX0mOo`0;gom03hooD0X?oe
0?gol02koo@0nOod0:7om@3boo/0POn1oh7oS_oj0?Gol02moo@0n?oe0:3om@3m
oo00^ood0?Wom02QooD0l_ok087oPOn1ohko0:@0ood0m?ok0?[on`2noo@0n?oe
09oon03koo/0nook0;com03ioo@0Wooi0?7onP21oh7oPOn=ood0m?ok0?[on`2n
oo@0n?oe09oon03koo/0nook0;com03ioo@0Wooi0?7onP21oh7oPOn=ood0m?ok
0?[on`2noo@0n?oe09oon03koo/0nook0;com03ioo@0Wooi0?7onP21oh7oPOn>
o`2T0?om0?Gon`3goo`0_ood0?Som@2Moo`0n_ol0?Soo02loo@0nOod09goo@3`
ooT0POn1oh7oSOom0?Gon`3goo`0_ood0?Som@2Moo`0n_ol0?Soo02loo@0nOod
09goo@3`ooT0POn1oh7oSOom0?Gon`3goo`0_ood0?Som@2Moo`0n_ol0?Soo02l
oo@0nOod09goo@3`ooT0POn1oh7oS_l0Y03oo@3eoo`0mOom0;oom03hooD0WOol
0?[oo@3foo`0_Ood0?Wom02Mood0l?oi087oPOn1ohgoo@3eoo`0mOom0;oom03h
ooD0WOol0?[oo@3foo`0_Ood0?Wom02Mood0l?oi087oPOn1ohgoo@3eoo`0mOom
0;oom03hooD0WOol0?[oo@3foo`0_Ood0?Wom02Mood0l?oi087oPOn1ohko0:@0
ood0mOom0?Coo030oo@0n?oe09goo03jood0mOom0;gom03ioo@0WOom0?7on021
oh7oPOn=ood0mOom0?Coo030oo@0n?oe09goo03jood0mOom0;gom03ioo@0WOom
0?7on021oh7oPOn=ood0mOom0?Coo030oo@0n?oe09goo03jood0mOom0;gom03i
oo@0WOom0?7on021oh7oPOn>o`2`0?om0?Koo03cood0`?od0?Som@2Moo`0nool
0?Goo@2moo@0nOod09goo@3boo`00?om087oPOn1ohgoo@3foo`0loom0<3om03h
ooD0WOol0?_oo03eood0_Ood0?Wom02Mood0l_ol003oo@21oh7oPOn=ood0m_ol
0??oo@30oo@0n?oe09goo03koo`0mOom0;gom03ioo@0WOom0?;oo000ood0POn1
oh7oS_l0/`3oo@3food0l_om0<3om03hooD0WOol0?_oo@3dood0_Ood0?Wom02M
ood0lool007oood0POn1oh7oSOom0?Koo@3bood0`?od0?Som@2Moo`0noom0?Co
o@2moo@0nOod09goo@3coo`00Oooo@21oh7oPOn=ood0m_om0?;oo@30oo@0n?oe
09goo03kood0m?om0;gom03ioo@0WOom0??oo001ooom087oPOn1ohko0;00ood0
m_om0?;oo@30oo@0n?oe09goo03kood0m?om0;gom03ioo@0WOom0??oo@3nood0
POn1oh7oSOom0?Koo@3bood0`?od0?Som@2Moo`0noom0?Coo@2moo@0nOod09go
o@3cood0o_om087oPOn1ohgoo@3food0l_om0<3om03hooD0WOol0?_oo@3dood0
_Ood0?Wom02Mood0loom0?koo@21oh7oPOn>o`2`0?om0?Koo@3bood0`?od0?So
m@2Moo`0noom0?Coo@2moo@0nOod09goo@3doo`0o_om087oPOn1ohgoo@3food0
l_om0<3om03hooD0WOol0?_oo@3dood0_Ood0?Wom02Mood0m?ol0?koo@21oh7o
POn=ood0m_om0?;oo@30oo@0n?oe09goo03kood0m?om0;gom03ioo@0WOom0?Co
o03nood0POn1oh7oS_l0V03oo@3Sood0`?od0?Som@2Moo`0jool0;gom03ioo@0
WOom0?Goo03mood0POn1oh7oSOom0>?oo@30oo@0n?oe09goo03[oo`0_Ood0?Wo
m02Mood0mOol0?goo@21oh7oPOn=ood0hoom0<3om03hooD0WOol0>_oo02moo@0
nOod09goo@3eoo`0oOom087oPOn1ohko09P0ood0i?ol0<3om03hooD0WOol0>co
o02loo@0nOod09goo@3foo`0o?om087oPOn1ohgoo@3Too`0`?od0?Som@2Moo`0
k?ol0;com03ioo@0WOom0?Koo03lood0POn1oh7oSOom0>Coo030oo@0n?oe09go
o03/oo`0_?od0?Wom02Mood0m_ol0?coo@21oh7oPOn>o`2H0?om0>Goo02ooo@0
n?oe09goo03]oo/0_?od0?Wom02Mood0mool0?_oo@21oh7oPOn=ood0iOol0;oo
m03hooD0WOol0>gon`2loo@0nOod09goo@3goo`0noom087oPOn1ohgoo@3Uoo`0
_ood0?Som@2Moo`0kOok0;com03ioo@0WOom0?Ooo03kood0POn1oh7oS_l0V03o
o@3Voo/0_ood0?Som@2Moo`0loof0;_om03ioo@0WOom0?Ooo@3jood0POn1oh7o
SOom0>Kon`2ooo@0n?oe09goo03cooH0^ood0?Wom02Mood0moom0?[oo@21oh7o
POn=ood0i_ok0;oom03hooD0WOol0??omP2koo@0nOod09goo@3good0n_om087o
POn1ohko09P0ood0iook0;kom03hooD0WOol0??on02ioo@0nOod09goo@3hoo`0
n_om087oPOn1ohgoo@3Woo/0__od0?Som@2Moo`0looh0;Wom03ioo@0WOom0?So
o03jood0POn1oh7oSOom0>Oon`2noo@0n?oe09goo03cooP0^Ood0?Wom02Mood0
n?ol0?[oo@21oh7oPOn>o`2H0?om0>WonP2moo@0n?oe09goo03cooH0^ood0?Wo
m02Mood0nOol0?Woo@21oh7oPOn=ood0jOoj0;gom03hooD0WOol0??omP2koo@0
nOod09goo@3ioo`0nOom087oPOn1ohgoo@3YooX0_Ood0?Som@2Moo`0loof0;_o
m03ioo@0WOom0?Woo03iood0POn1oh7oS_l0V03oo@3[ooT0_?od0?Som@2Moo`0
lood0;gom03ioo@0WOom0?[oo03hood0POn1oh7oSOom0>_on@2loo@0n?oe09go
o03coo@0_Ood0?Wom02Mood0n_ol0?Soo@21oh7oPOn=ood0jooi0;com03hooD0
WOol0??om02moo@0nOod09goo@3joo`0n?om087oPOn1ohko09P0ood0k?oi0;_o
m03hooD0WOol0>gon@2noo@0nOod09goo@3jood0moom087oPOn1ohgoo@3/ooT0
^ood0?Som@2Moo`0kOoi0;kom03ioo@0WOom0?[oo@3good0POn1oh7oSOom0>co
n@2koo@0n?oe09goo03]ooT0__od0?Wom02Mood0n_om0?Ooo@21oh7oPOn>o`2H
0?om0>kon@2ioo@0n?oe09goo03Zoo`0__od0?Wom02Mood0nool0?Ooo@21oh7o
POn=ood0k_oi0;Wom03hooD0WOol0>[oo02noo@0nOod09goo@3koo`0moom087o
POn1ohgoo@3^ooT0^Ood0?Som@2Moo`0j_ol0;kom03ioo@0WOom0?_oo03good0
POn1oh7oS_l0V03oo@3`ooP0^?od0?Som@2Moo`0jOol0;oom03ioo@0WOom0?co
o03food0POn1oh7oSOom0?3on02hoo@0n?oe09goo03Yoo`0_ood0?Wom02Mood0
o?ol0?Koo@21oh7oPOn=ood0l?oh0;Som03hooD0WOol0>Woo02ooo@0nOod09go
o@3loo`0m_om087oPOn1ohko08`0ood0lOoi0;Kom03hooD0WOol0>Woo02ooo@0
nOod09goo@3lonP0POn1oh7oT_om0?7on@2foo@0n?oe09goo03Yoo`0_ood0?Wo
m02Mood0o?oX087oPOn1oi;oo@3aooT0]_od0?Som@2Moo`0jOol0;oom03ioo@0
WOom0?coj021oh7oPOnCo`2<0?om0?;onP2doo@0n?oe09goo03Xood0_ood0?Wo
m02Mood0o?oX087oPOn1oi;oo@3booX0]?od0?Som@2Moo`0j?om0;oom03ioo@0
WOom0?coj021oh7oPOnBood0l_oj0;Com03hooD0WOol0>Soo@2ooo@0nOod09go
o@3lonP0POn1oh7oTol0V03oo@3coo/0/_od0?Som@2Moo`0o?om0?7oo@2ooo@0
nOod09goo@3lonP0POn1oh7oT_om0??on`2boo@0n?oe09goo03lood0lOom0;oo
m03ioo@0WOom0?coj021oh7oPOnBood0look0;;om03hooD0WOol0?coo@3aood0
_ood0?Wom02Mood0o?oX087oPOn1oi?o09P0ood0m?ok0;7om03hooD0WOol0?co
o@3aood0_ood0?Wom02Mood0o?oX087oPOn1oi;oo@3doo/0/Ood0?Som@2Moo`0
o?om0?7oo@2ooo@0nOod09goo@3lonP0POn1oh7oT_om0?Con`2aoo@0n?oe09go
o03lood0lOom0;oom03ioo@0WOom0?coj021oh7oPOnCo`2H0?om0?Goo02_oo@0
n?oe09goo03lood0lOom0;oom03ioo@0WOom0>coo@21oh7oPOn=ood0mOol0:oo
m03hooD0WOol0?coo@3aood0_ood0?Wom02Mood0k?om087oPOn1ohgoo@3eoo`0
[ood0?Som@2Moo`0o?om0?7oo@2ooo@0nOod09goo@3/ood0POn1oh7oS_l0V03o
o@3eood0[_od0?Som@2Moo`0o?ol0?;oo@2ooo@0nOod09goo@3/ood0POn1oh7o
SOom0?Goo@2^oo@0n?oe09goo03loo`0l_om0;oom03ioo@0WOom0>coo@21oh7o
POn=ood0mOom0:kom03hooD0WOol0?coo03bood0_ood0?Wom02Mood0k?om087o
POn1ohko09P0ood0m_om0:gom03hooD0WOol0?_oo@3cood0__od0?Wom02Mood0
k?om087oPOn1ohgoo@3food0[Ood0?Som@2Moo`0noom0??oo@2noo@0nOod09go
o@3/ood0POn1oh7oSOom0?Koo@2]oo@0n?oe09goo03kood0loom0;kom03ioo@0
WOom0>coo@21oh7oPOn>o`2H0?om0?Koo@2]oo@0n?oe09goo03koo`0mOol0;ko
m03ioo@0WOom0>coo@21oh7oPOn=ood0m_om0:gom03hooD0WOol0?_oo03eoo`0
__od0?Wom02Mood0k?om087oPOn1ohgoo@3food0[Ood0?Som@2Moo`0nool0?Go
o02noo@0nOod09goo@3/ood0POn1oh7oS_l0V03oo@3fooh0[?od0?Som@2Moo`0
nook0?Oon`2noo@0nOod09goo@3/ood0POn1oh7oSOom0?KooP2/oo@0n?oe09go
o03koo/0mook0;kom03ioo@0WOom0>coo@21oh7oPOn=ood0m_on0:com03hooD0
WOol0?_on`3goo/0__od0?Wom02Mood0k?om087oPOn1ohko09P0ood0mooY0<3o
m03hooD0WOol0?[on`3jooX0_Ood0?Wom02Mood0k?om087oPOn1ohgoo@3gonT0
`?od0?Som@2Moo`0n_ok0?[onP2moo@0nOod09goo@3/ood0POn1oh7oSOom0?Oo
j@30oo@0n?oe09goo03joo/0n_oj0;gom03ioo@0WOom0>coo@21oh7oPOn>o`2<
0?om0?Ooj@30oo@0n?oe09goo03ionl0_?od0?Wom02Mood0k?om087oPOn1ohgo
o@3gonT0`?od0?Som@2Moo`0nOo_0;com03ioo@0WOom0>coo@21oh7oPOn=ood0
mooY0<3om03hooD0WOol0?Wok`2loo@0nOod09goo@3/ood0POn1oh7oS_l0S03o
o@3gonT0`?od0?Som@2Moo`0n?oa0;_om03ioo@0WOom0>coo@21oh7oPOn=ood0
mooY0<3om03hooD0WOol0?Sol@2koo@0nOod09goo@3/ood0POn1oh7oSOom0?Oo
j@30oo@0n?oe09goo03hoo40^ood0?Wom02Mood0k?om087oPOn1ohko08`0ood0
mooY0<3om03hooD0WOol0?Oom02ioo@0nOod09goo@3/ood0POn1oh7oSOom0?Oo
j@30oo@0n?oe09goo03goo@0^Ood0?Wom02Mood0k?om087oPOn1ohgoo@3gonT0
`?od0?Som@2Moo`0mood0;Wom03ioo@0WOom0>coo@21oh7oPOn>o`1j0?om09ko
m03hooD0WOol0?Gon02goo@0nOod09goo@21oh7oPOn1ooCoo@2Noo@0n?oe09go
o03eooP0]ood0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0mOoh0;Oo
m03ioo@0WOom087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02Roo@0nOod09go
o@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooCo
o@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0ood0W_od0?So
m@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wo
m02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7o
POoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09ko
m03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03hooD0WOol0:;o
m03ioo@0WOom087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02Roo@0nOod09go
o@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooCo
o@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0ood0W_od0?So
m@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wo
m02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7o
POoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09ko
m03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03hooD0WOol0:;o
m03ioo@0WOom087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02Roo@0nOod09go
o@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooCo
o@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0ood0W_od0?So
m@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wo
m02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7o
POoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09ko
m03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03hooD0WOol0:;o
m03ioo@0WOom087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02Roo@0nOod09go
o@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooCo
o@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0ood0W_od0?So
m@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wo
m02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7o
POoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09ko
m03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03hooD0WOol0:;o
m03ioo@0WOom087oPOn1oh7omOl0KP3oo@2Noo@0n?oe09goo02Roo@0nOod09go
o@21oh7oPOn1ooCoo@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooCo
o@2Noo@0n?oe09goo02Roo@0nOod09goo@21oh7oPOn1ooGo06h0ood0W_od0?So
m@2Moo`0X_od0?Wom02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wo
m02Mood0POn1oh7oPOodood0W_od0?Som@2Moo`0X_od0?Wom02Mood0POn1oh7o
POoeo`1^0?om09kom03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09ko
m03hooD0WOol0:;om03ioo@0WOom087oPOn1oh7om?om09kom03hooD0WOol0:;o
m03ioo@0WOom087oPOn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7oPOn1ooCo
o@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooGo
04X0ood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7o
POodood0POnHoo`0POnLood0POn1oh7oPOoeo`1:0?om087oV?ol087oW?om087o
POn1oh7om?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087o
POn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oico
o@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooGo04X0ood0POnHoo`0
POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0
POnLood0POn1oh7oPOoeo`1:0?om087oV?ol087oW?om087oPOn1oh7om?om087o
V?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7omOl0BP3o
o@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooCo
o@21oiSoo021oicoo@21oh7oPOn1ooGo04X0ood0POnHoo`0POnLood0POn1oh7o
POodood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7o
POoeo`1:0?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087o
POn1oh7om?om087oV?ol087oW?om087oPOn1oh7omOl0BP3oo@21oiSoo021oico
o@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oico
o@21oh7oPOn1ooGo04X0ood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0
POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOoeo`1:0?om087o
V?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7om?om087o
V?ol087oW?om087oPOn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7oPOn1ooCo
o@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooGo
04X0ood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7o
POodood0POnHoo`0POnLood0POn1oh7oPOoeo`1:0?om087oV?ol087oW?om087o
POn1oh7om?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087o
POn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oico
o@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooGo04X0ood0POnHoo`0
POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0
POnLood0POn1oh7oPOoeo`1:0?om087oV?ol087oW?om087oPOn1oh7om?om087o
V?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7omOl0BP3o
o@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooCo
o@21oiSoo021oicoo@21oh7oPOn1ooGo04X0ood0POnHoo`0POnLood0POn1oh7o
POodood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7o
POoeo`1:0?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087o
POn1oh7om?om087oV?ol087oW?om087oPOn1oh7omOl0BP3oo@21oiSoo021oico
o@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oico
o@21oh7oPOn1ooGo04X0ood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0
POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOoeo`1:0?om087o
V?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7om?om087o
V?ol087oW?om087oPOn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7oPOn1ooCo
o@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooGo
04X0ood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7o
POodood0POnHoo`0POnLood0POn1oh7oPOoeo`1:0?om087oV?ol087oW?om087o
POn1oh7om?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087o
POn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oico
o@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooGo04X0ood0POnHoo`0
POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0
POnLood0POn1oh7oPOoeo`1:0?om087oV?ol087oW?om087oPOn1oh7om?om087o
V?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7omOl0BP3o
o@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooCo
o@21oiSoo021oicoo@21oh7oPOn1ooGo04X0ood0POnHoo`0POnLood0POn1oh7o
POodood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7o
POoeo`1:0?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087o
POn1oh7om?om087oV?ol087oW?om087oPOn1oh7omOl0BP3oo@21oiSoo021oico
o@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oico
o@21oh7oPOn1ooGo04X0ood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0
POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOoeo`1:0?om087o
V?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7om?om087o
V?ol087oW?om087oPOn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7oPOn1ooCo
o@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooGo
04X0ood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7o
POodood0POnHoo`0POnLood0POn1oh7oPOoeo`1:0?om087oV?ol087oW?om087o
POn1oh7om?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087o
POn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oico
o@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooGo04X0ood0POnHoo`0
POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0
POnLood0POn1oh7oPOoeo`0faP2<ohP0TOn8087oPOn1oj_oaP2<ohP0TOn8087o
POn1oj_oaP2<ohP0TOn8087oPOn1oj_o03K608coR02AohP0POn1oh7oZoo608co
R02AohP0POn1oh7oZoo608coR02AohP0POn1oh7oZol0=/H0S?n8097oR021oh7o
POn[olH0S?n8097oR021oh7oPOn[olH0S?n8097oR021oh7oPOn[o`0faP2<ohP0
TOn8087oPOn1oj_oaP2<ohP0TOn8087oPOn1oj_oaP2<ohP0TOn8087oPOn1oj_o
03K608coR02AohP0POn1oh7oZoo608coR02AohP0POn1oh7oZoo608coR02AohP0
POn1oh7oZol0=/H0S?n8097oR021oh7oPOn[olH0S?n8097oR021oh7oPOn[olH0
S?n8097oR021oh7oPOn[o`0faP2<ohP0TOn8087oPOn1oj_oaP2<ohP0TOn8087o
POn1oj_oaP2<ohP0TOn8087oPOn1oj_o03K608coR02AohP0POn1oh7oZoo608co
R02AohP0POn1oh7oZoo608coR02AohP0POn1oh7oZol0=/H0S?n8097oR021oh7o
POn[olH0S?n8097oR021oh7oPOn[olH0S?n8097oR021oh7oPOn[o`0faP2<ohP0
TOn8087oPOn1oj_oaP2<ohP0TOn8087oPOn1oj_oaP2<ohP0TOn8087oPOn1oj_o
03K608coR02AohP0POn1oh7oZoo608coR02AohP0POn1oh7oZoo608coR02AohP0
POn1oh7oZol0=/H0S?n8097oR021oh7oPOn[olH0S?n8097oR021oh7oPOn[olH0
S?n8097oR021oh7oPOn[o`0faP2<ohP0TOn8087oPOn1oj_oaP2<ohP0TOn8087o
POn1oj_oaP2<ohP0TOn8087oPOn1oj_o0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0=/H0
S?n8097oR021oh7oPOn[olH0S?n8097oR021oh7oPOn[olH0S?n8097oR021oh7o
POn[o`0faP2<ohP0TOn8087oPOn1oj_oaP2<ohP0TOn8087oPOn1oj_oaP2<ohP0
TOn8087oPOn1oj_o03K608coR02AohP0POn1oh7oZoo608coR02AohP0POn1oh7o
Zoo608coR02AohP0POn1oh7oZol0=/H0S?n8097oR021oh7oPOn[olH0S?n8097o
R021oh7oPOn[olH0S?n8097oR021oh7oPOn[o`0faP2<ohP0TOn8087oPOn1oj_o
aP2<ohP0TOn8087oPOn1oj_oaP2<ohP0TOn8087oPOn1oj_o03K608coR02AohP0
POn1oh7oZoo608coR02AohP0POn1oh7oZoo608coR02AohP0POn1oh7oZol0=/H0
S?n8097oR021oh7oPOn[olH0S?n8097oR021oh7oPOn[olH0S?n8097oR021oh7o
POn[o`0faP2<ohP0TOn8087oPOn1oj_oaP2<ohP0TOn8087oPOn1oj_oaP2<ohP0
TOn8087oPOn1oj_o03K608coR02AohP0POn1oh7oZoo608coR02AohP0POn1oh7o
Zoo608coR02AohP0POn1oh7oZol0=/H0S?n8097oR021oh7oPOn[olH0S?n8097o
R021oh7oPOn[olH0S?n8097oR021oh7oPOn[o`0faP2<ohP0TOn8087oPOn1oj_o
aP2<ohP0TOn8087oPOn1oj_oaP2<ohP0TOn8087oPOn1oj_o03K608coR02AohP0
POn1oh7oZoo608coR02AohP0POn1oh7oZoo608coR02AohP0POn1oh7oZol0=/H0
S?n8097oR021oh7oPOn[olH0S?n8097oR021oh7oPOn[olH0S?n8097oR021oh7o
POn[o`1:0?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087o
POn1oh7om?om087oV?ol087oW?om087oPOn1oh7omOl0G03oo@21ookomP2Voo`0
Q_of0:;oo@21oh7oPOn1ooCoo@21ookomP2Voo`0Q_of0:;oo@21oh7oPOn1ooCo
o@21ookomP2Voo`0Q_of0:;oo@21oh7oPOn1ooGo05H0ood0P_o^0:[oo02:onh0
Y_om087oPOn1oh7om?om08;okP2Zoo`0R_o^0:Koo@21oh7oPOn1ooCoo@22onh0
Z_ol08[okP2Vood0POn1oh7oPOoeo`1F0?om08CojP2/oo`0S?oZ0:Soo@21oh7o
POn1ooCoo@24onX0[?ol08cojP2Xood0POn1oh7oPOodood0Q?oZ0:coo02<onX0
Z?om087oPOn1oh7omOl0EP3oo@26onH0[_ol08koiP2Zood0POn1oh7oPOodood0
Q_oV0:koo02>onH0Z_om087oPOn1oh7om?om08KoiP2^oo`0S_oV0:[oo@21oh7o
POn1ooGo05H0ood0R?oS0:ooo02@on<0Zoom087oPOn1oh7om?om08Soh`2_oo`0
T?oS0:_oo@21oh7oPOn1ooCoo@28on<0[ool093oh`2[ood0POn1oh7oPOoeo`1F
0?om08Woh02aoo`0TOoP0:goo@21oh7oPOn1ooCoo@29on00/Ool097oh02]ood0
POn1oh7oPOodood0ROoP0;7oo02Aon00[Oom087oPOn1oh7omOl0KP3oo@2:oo@0
n?od0;;oo02Boo@0n?od0:koo@21oh7oPOn1ooCoo@2:oo@0n?od0;;oo02Boo@0
n?od0:koo@21oh7oPOn1ooCoo@2:oo@0n?od0;;oo02Boo@0n?od0:koo@21oh7o
POn1ooGo06h0ood0Roof0?;om`2boo`0Toof0?;om`2^ood0POn1oh7oPOodood0
Roof0?;om`2boo`0Toof0?;om`2^ood0POn1oh7oPOodood0Roof0?;om`2boo`0
Toof0?;om`2^ood0POn1oh7oPOoeo`1^0?om08com`3^ooP0/ool09Com`3^ooP0
[oom087oPOn1oh7om?om08com`3^ooP0/ool09Com`3^ooP0[oom087oPOn1oh7o
m?om08com`3^ooP0/ool09Com`3^ooP0[oom087oPOn1oh7omOl0KP3oo@2=ooP0
jooh0;Coo02EooP0jooh0;3oo@21oh7oPOn1ooCoo@2=ooP0jooh0;Coo02EooP0
jooh0;3oo@21oh7oPOn1ooCoo@2=ooP0jooh0;Coo02EooP0jooh0;3oo@21oh7o
POn1ooGo06h0ood0SOoi0>Won02eoo`0UOoi0>Won02aood0POn1oh7oPOodood0
SOoi0>Won02eoo`0UOoi0>Won02aood0POn1oh7oPOodood0SOoi0>Won02eoo`0
UOoi0>Won02aood0POn1oh7oPOoeo`1^0?om08kon@3WooT0]Ool09Kon@3WooT0
/Oom087oPOn1oh7om?om08kon@3WooT0]Ool09Kon@3WooT0/Oom087oPOn1oh7o
m?om08kon@3WooT0]Ool09Kon@3WooT0/Oom087oPOn1oh7omOl0KP3oo@2?ooT0
iOoi0;Koo02GooT0iOoi0;;oo@21oh7oPOn1ooCoo@2?ooT0iOoi0;Koo02GooT0
iOoi0;;oo@21oh7oPOn1ooCoo@2?ooT0iOoi0;Koo02GooT0iOoi0;;oo@21oh7o
POn1ooGo06h0ood0Sooi0>Gon@2foo`0Uooi0>Gon@2bood0POn1oh7oPOodood0
Sooi0>Gon@2foo`0Uooi0>Gon@2bood0POn1oh7oPOodood0Sooi0>Gon@2foo`0
Uooi0>Gon@2bood0POn1oh7oPOoeo`1^0?om093on@3SooX0]_ol09Son@3SooX0
/_om087oPOn1oh7om?om093on@3SooX0]_ol09Son@3SooX0/_om087oPOn1oh7o
m?om093on@3SooX0]_ol09Son@3SooX0/_om087oPOn1oh7omOl0KP3oo@2@ooT0
hooi0;Ooo02HooT0hooi0;?oo@21oh7oPOn1ooCoo@2@ooT0hooi0;Ooo02HooT0
hooi0;?oo@21oh7oPOn1ooCoo@2@ooT0hooi0;Ooo02HooT0hooi0;?oo@21oh7o
POn1ooGo06h0ood0T?oj0>7onP2goo`0V?oj0>7onP2cood0POn1oh7oPOodood0
T?oj0>7onP2goo`0V?oj0>7onP2cood0POn1oh7oPOodood0T?oj0>7onP2goo`0
V?oj0>7onP2cood0POn1oh7oPOoeo`1^0?om097on@3QooX0]ool09Won@3QooX0
/oom087oPOn1oh7om?om097on@3QooX0]ool09Won@3QooX0/oom087oPOn1oh7o
m?om097on@3QooX0]ool09Won@3QooX0/oom087oPOn1oh7omOl0EP3oo@2AooX0
Sool09WonP2;ood0POn1oh7oPOodood0TOoj08ooo02IooX0Room087oPOn1oh7o
m?om097onP2?oo`0VOoj08_oo@21oh7oPOn1ooGo05H0ood0TOoj08ooo02IooX0
Room087oPOn1oh7om?om097onP2?oo`0VOoj08_oo@21oh7oPOn1ooCoo@2AooX0
Sool09WonP2;ood0POn1oh7oPOoeo`1F0?om097onP2?oo`0VOoj08_oo@21oh7o
POn1ooCoo@2AooX0Sool09WonP2;ood0POn1oh7oPOodood0TOoj08ooo02IooX0
Room087oPOn1oh7omOl0EP3oo@2BooT0Sool09[on@2;ood0POn1oh7oPOodood0
T_oi08ooo02JooT0Room087oPOn1oh7om?om09;on@2?oo`0V_oi08_oo@21oh7o
POn1ooGo05H0ood0T_oj08koo02JooX0R_om087oPOn1oh7om?om09;onP2>oo`0
V_oj08[oo@21oh7oPOn1ooCoo@2BooX0S_ol09[onP2:ood0POn1oh7oPOoeo`1F
0?om09;onP2>oo`0V_oj08[oo@21oh7oPOn1ooCoo@2BooX0S_ol09[onP2:ood0
POn1oh7oPOodood0T_oj08koo02JooX0R_om087oPOn1oh7omOl0EP3oo@2BooX0
S_ol09[onP2:ood0POn1oh7oPOodood0T_oj08koo02JooX0R_om087oPOn1oh7o
m?om09;onP2>oo`0V_oj08[oo@21oh7oPOn1ooGo05H0ood0T_oj08koo02JooX0
R_om087oPOn1oh7om?om09;onP2>oo`0V_oj08[oo@21oh7oPOn1ooCoo@2BooX0
S_ol09[onP2:ood0POn1oh7oPOoeo`1F0?om09;onP2>oo`0V_oj08[oo@21oh7o
POn1ooCoo@2BooX0S_ol09[onP2:ood0POn1oh7oPOodood0T_oj08koo02JooX0
R_om087oPOn1oh7omOl0EP3oo@2BooX0S_ol09[onP2:ood0POn1oh7oPOodood0
T_oj08koo02JooX0R_om087oPOn1oh7om?om09;onP2>oo`0V_oj08[oo@21oh7o
POn1ooGo05H0ood0T_oj08koo02JooX0R_om087oPOn1oh7om?om09;onP2>oo`0
V_oj08[oo@21oh7oPOn1ooCoo@2BooX0S_ol09[onP2:ood0POn1oh7oPOoeo`1F
0?om09;onP2>oo`0V_oj08[oo@21oh7oPOn1ooCoo@2BooX0S_ol09[onP2:ood0
POn1oh7oPOodood0T_oj08koo02JooX0R_om087oPOn1oh7omOl0EP3oo@2BooX0
S_ol09[onP2:ood0POn1oh7oPOodood0T_oj08koo02JooX0R_om087oPOn1oh7o
m?om09;onP2>oo`0V_oj08[oo@21oh7oPOn1ooGo05H0ood0T_oj08koo02JooX0
R_om087oPOn1oh7om?om09;onP2>oo`0V_oj08[oo@21oh7oPOn1ooCoo@2BooX0
S_ol09[onP2:ood0POn1oh7oPOoeo`1F0?om09;onP2>oo`0V_oj08[oo@21oh7o
POn1ooCoo@2BooX0S_ol09[onP2:ood0POn1oh7oPOodood0T_oj08koo02JooX0
R_om087oPOn1oh7omOl0EP3oo@2BooX0S_ol09[onP2:ood0POn1oh7oPOodood0
T_oj08koo02JooX0R_om087oPOn1oh7om?om09;onP2>oo`0V_oj08[oo@21oh7o
POn1ooGo08H0ood0TOok0<gonP3/ooT0i_ol09Won`36ood0l?oi0>;oo@21oh7o
POn1ooCoo@2Aoo/0cOoj0>con@3Voo`0VOok0<Koo@3`ooT0h_om087oPOn1oh7o
m?om097on`3=ooX0k?oi0>Koo02Ioo/0a_om0?3on@3Rood0POn1oh7oPOoeo`2N
0?om097onP3PooX0n?oe0?7om@3Xoo`0VOoj0>3onP3`oo`0l_oe0>Coo@21oh7o
POn1ooCoo@2AooX0h?oj0?Som@3aooD0j?ol09WonP3PooX0l?ol0?;om@3Tood0
POn1oh7oPOodood0TOoj0>3onP3hooD0lOoe0>Soo02IooX0h?oj0?3oo03booD0
i?om087oPOn1oh7omOl0WP3oo@2AooX0h?oj0?[olP3coo<0jOol09WonP3PooX0
l?ol0??ol`3Uood0POn1oh7oPOodood0TOoj0>3onP3joo80looc0>Woo02IooX0
h?oj0?3oo03coo<0iOom087oPOn1oh7om?om097onP3PooX0n_ob0??ol`3Yoo`0
VOoj0>3onP3`oo`0looc0>Goo@21oh7oPOn1ooGo09h0ood0TOoj0>7on@3koo00
mOoa0>[oo02IooX0hOoi0?7on`3doo40i_om087oPOn1oh7om?om097onP3QooT0
noo`0?Gol@3Zoo`0VOoj0>7on@3aoo/0m?oa0>Koo@21oh7oPOn1ooCoo@2AooX0
hOoi0?_ol03eoo40j_ol09WonP3QooT0lOok0?Col@3Vood0POn1oh7oPOoeo`32
0?om097on@3RooX0n_ok0?_on`3goo/0nook0>_oo02IooT0h_oj0?7onP3eoo/0
nook0>Ooo@21oh7oPOn1ooCoo@2AooT0h_oj0?[on`3koo/0mook0?_on`3[oo`0
VOoi0>;onP3aooX0mOok0?_on`3Wood0POn1oh7oPOodood0TOoi0>;onP3joo/0
nook0?Oon`3koo/0jool09Won@3RooX0lOoj0?Gon`3koo/0ioom087oPOn1oh7o
mOl0`P3oo@2@ooX0h_oj0?_oo03hoo`0mool0?Soo03/oo`0V?oj0>;onP3booT0
mOol0?Soo03Xood0POn1oh7oPOodood0T?oj0>;onP3koo`0n?ol0?Ooo03hoo`0
k?ol09SonP3RooX0l_oi0?Goo03hoo`0j?om087oPOn1oh7om?om093onP3RooX0
nool0?Soo03goo`0n?ol0>coo02HooX0h_oj0?;on@3eoo`0n?ol0>Soo@21oh7o
POn1ooGo0<80ood0T?oj0>?on@3kood0m_ol0?Woo03food0k?ol09SonP3SooT0
l_oi0?Koo03food0j?om087oPOn1oh7om?om093onP3SooT0noom0?Koo03ioo`0
m_om0>coo02HooX0hooi0?;on@3foo`0m_om0>Soo@21oh7oPOn1ooCoo@2@ooX0
hooi0?_oo@3foo`0nOol0?Koo@3/oo`0V?oj0>?on@3booT0m_ol0?Koo@3Xood0
POn1oh7oPOoeo`320?om093on@3TooX0n_om0?Goo@3iood0mOol0>goo02HooT0
i?oj0?;on03food0mOol0>Woo@21oh7oPOn1ooCoo@2@ooT0i?oj0?[oo@3eood0
nOom0?Goo03]oo`0V?oi0>ConP3booP0m_om0?Goo03Yood0POn1oh7oPOodood0
T?oi0>ConP3jood0mOom0?Woo@3eoo`0kOol09Son@3TooX0l_oh0?Koo@3eoo`0
jOom087oPOn1oh7omOl0cP3oo@2?ooX0iOoi0?_oo03eood0n_ol0?Coo@3]oo`0
Uooj0>Gon@3coo`00?om0?Ooo03dood0jOom087oPOn1oh7om?om08oonP3UooT0
nool0?Goo@3joo`0m?om0>goo02GooX0iOoi0??oo000ood0mool0?Coo@3Yood0
POn1oh7oPOodood0Sooj0>Gon@3koo`0mOom0?[oo03dood0kOol09OonP3UooT0
lool003oo@3goo`0m?om0>Woo@21oh7oPOn1ooGo0=40ood0Sooi0>Kon@3kood0
m?om0?[oo@3cood0kOol09Oon@3VooT0m?ol007oood0moom0??oo@3Yood0POn1
oh7oPOodood0Sooi0>Kon@3kood0m?om0?[oo@3cood0kOol09Oon@3VooT0m?ol
007oood0moom0??oo@3Yood0POn1oh7oPOodood0Sooi0>Kon@3kood0m?om0?[o
o@3cood0kOol09Oon@3VooT0m?ol007oood0moom0??oo@3Yood0POn1oh7oPOoe
o`3>0?om08kon@3XooT0n_om0?Coo@3jood0loom0>goo02FooT0j?oi0??oo@3n
ood0moom0??oo@3Yood0POn1oh7oPOodood0S_oi0>Son@3jood0m?om0?[oo@3c
ood0kOol09Kon@3XooT0loom0?koo@3good0loom0>Woo@21oh7oPOn1ooCoo@2>
ooT0j?oi0?[oo@3dood0n_om0??oo@3]oo`0U_oi0>Son@3cood0o_om0?Ooo@3c
ood0jOom087oPOn1oh7omOl0cP3oo@2>ooP0j_oi0?Woo@3dood0n_om0??oo03^
oo`0U_oh0>[on@3coo`0o_om0?Ooo@3coo`0j_om087oPOn1oh7om?om08kon03Z
ooT0nOom0?Coo@3jood0lool0>koo02FooP0j_oi0??oo03nood0moom0??oo03Z
ood0POn1oh7oPOodood0S_oh0>[on@3iood0m?om0?[oo@3coo`0k_ol09Kon03Z
ooT0lool0?koo@3good0lool0>[oo@21oh7oPOn1ooGo0<80ood0SOoh0>con03Y
oo`0noom0?7oo@3^oo`0UOoh0>con03doo`0oOom0?Soo@3aood0j_om087oPOn1
oh7om?om08gon03/ooP0jOol0?_oo@3aood0k_ol09Gon03/ooP0m?ol0?goo@3h
ood0lOom0>[oo@21oh7oPOn1ooCoo@2=ooP0k?oh0>Woo03kood0lOom0>koo02E
ooP0k?oh0?Coo03mood0n?om0?7oo@3Zood0POn1oh7oPOoeo`320?om08con03^
ooP0jOol0?[oo@3aood0k_ol09Con03^ooP0m?ol0?coo@3hood0lOom0>[oo@21
oh7oPOn1ooCoo@2<ooP0k_oh0>Woo03jood0lOom0>koo02DooP0k_oh0?Coo03l
ood0n?om0?7oo@3Zood0POn1oh7oPOodood0S?oh0>kon03Yoo`0n_om0?7oo@3^
oo`0U?oh0>kon03doo`0o?om0?Soo@3aood0j_om087oPOn1oh7omOl0`P3oo@2;
ooL0l_og0>Won`3jood0lOom0>koo02CooL0l_og0?Coo03kood0n?om0?7oo@3Z
ood0POn1oh7oPOodood0Roog0?;om`3Yoo/0n_om0?7oo@3^oo`0Toog0?;om`3d
oo`0noom0?Soo@3aood0j_om087oPOn1oh7om?om08_om`3booL0jOok0?[oo@3a
ood0k_ol09?om`3booL0m?ol0?_oo@3hood0lOom0>[oo@21oh7oPOn1ooGo0<80
ood0R_oe0?Som@3^ooH0nOom0?7oo@3^oo`0T_oe0?Som@3cood0n_om0?Soo@3a
ood0j_om087oPOn1oh7om?om08[om@3hooD0k_of0?Woo@3aood0k_ol09;om@3h
ooD0loom0?[oo@3hood0lOom0>[oo@21oh7oPOn1ooCoo@2:ooD0n?oe0>komP3i
ood0lOom0>koo02BooD0n?oe0??oo@3jood0n?om0?7oo@3Zood0POn1oh7oPOoe
o`2Z0?om08WohP3]ooP0moom0?7oo@3^oo`0TOoR0??oo03jood0n?om0?7oo@3Z
ood0POn1oh7oPOodood0ROoR0>gon03good0lOom0>koo02Aon80lool0?[oo@3h
ood0lOom0>[oo@21oh7oPOn1ooCoo@29on80kOoh0?Ooo@3aood0k_ol097ohP3c
oo`0n_om0?Soo@3aood0j_om087oPOn1oh7omOl0ZP3oo@28on@0k?of0?Woo@3a
ood0k_ol093oi03coo`0nOom0?Soo@3aood0j_om087oPOn1oh7om?om08Soi03/
ooH0nOom0?7oo@3^oo`0T?oT0??oo03iood0n?om0?7oo@3Zood0POn1oh7oPOod
ood0R?oT0>comP3iood0lOom0>koo02@on@0lool0?Woo@3hood0lOom0>[oo@21
oh7oPOn1ooGo0:X0ood0QooV0>_om03kood0lOom0>koo02?onH0lool0?Soo@3h
ood0lOom0>[oo@21oh7oPOn1ooCoo@27onH0jood0?_oo@3aood0k_ol08ooiP3c
oo`0n?om0?Soo@3aood0j_om087oPOn1oh7om?om08OoiP3[oo@0noom0?7oo@3^
oo`0SooV0??oo03hood0n?om0?7oo@3Zood0POn1oh7oPOoeo`2Z0?om08GojP3S
ooT0o?om0?7oo@3^oo`0SOoZ0?7oo@3good0n?om0?7oo@3Zood0POn1oh7oPOod
ood0QOoZ0>?on@3lood0lOom0>koo02=onX0lOom0?Ooo@3hood0lOom0>[oo@21
oh7oPOn1ooCoo@25onX0hooi0?coo@3aood0k_ol08gojP3aood0moom0?Soo@3a
ood0j_om087oPOn1oh7omOl0ZP3oo@23onl0gOol0?coo@3aood0k_ol08_ok`3_
oo`0moom0?Soo@3aood0j_om087oPOn1oh7om?om08?ok`3Moo`0o?om0?7oo@3^
oo`0Roo_0>ooo03good0n?om0?7oo@3Zood0POn1oh7oPOodood0Poo_0=goo03l
ood0lOom0>koo02;onl0kool0?Ooo@3hood0lOom0>[oo@21oh7oPOn1ooGo0;<0
ood0POl1ooof0=Woo03mood0lOom0>koo027ooH0kOol0?Koo@3hood0lOom0>[o
o@21oh7oPOn1ooCoo@21o`7oooH0fOol0?goo@3aood0k_ol08OomP3]oo`0m_om
0?Soo@3aood0j_om087oPOn1oh7om?om087o0OoomP3Ioo`0oOom0?7oo@3^oo`0
Qoof0>goo03food0n?om0?7oo@3Zood0POn1oh7oPOoeo`2B0?om087oc?ol0?go
o@3aood0k_ol087oj?oX0?goo@3aood0j_om087oPOn1oh7om?om087oc?ol0?go
o@3aood0k_ol087oj?oX0?goo@3aood0j_om087oPOn1oh7om?om087oc?ol0?go
o@3aood0k_ol087oj?oX0?goo@3aood0j_om087oPOn1oh7omOl0TP3oo@21ol_o
o@3mood0lOom0>koo021onSoj03mood0lOom0>[oo@21oh7oPOn1ooCoo@21ol_o
o@3mood0lOom0>koo021onSoj03mood0lOom0>[oo@21oh7oPOn1ooCoo@21ol_o
o@3mood0lOom0>koo021onSoj03mood0lOom0>[oo@21oh7oPOn1ooGo09h0ood0
POoOood0lOom0?coo@3cood0kOol087oj?oX0?coo@3cood0jOom087oPOn1oh7o
m?om087ogoom0?7oo@3lood0loom0>goo021onSoj03lood0loom0>Woo@21oh7o
POn1ooCoo@21omooo@3aood0o?om0??oo@3]oo`0POoXonP0o?om0??oo@3Yood0
POn1oh7oPOoeo`2N0?om087ogoom0?7oo@3lood0loom0>goo021onSoj03lood0
loom0>Woo@21oh7oPOn1ooCoo@21omooo@3aood0o?om0??oo@3]oo`0POoXonP0
o?om0??oo@3Yood0POn1oh7oPOodood0POoOood0lOom0?coo@3cood0kOol087o
j?oX0?coo@3cood0jOom087oPOn1oh7omOl0WP3oo@21omooo@3aood0o?om0??o
o@3]oo`0POoHood0moom0??oo@3Yood0POn1oh7oPOodood0POoOood0lOom0?co
o@3cood0kOol087of?om0?Ooo@3cood0jOom087oPOn1oh7om?om087ogoom0?7o
o@3lood0loom0>goo021omSoo@3good0loom0>Woo@21oh7oPOn1ooGo09h0ood0
POoOoo`0l_om0?coo@3cood0kOol087of?om0?Ooo@3cood0jOom087oPOn1oh7o
m?om087ogool0?;oo@3lood0loom0>goo021omSoo@3good0loom0>Woo@21oh7o
POn1ooCoo@21omooo03bood0o?om0??oo@3]oo`0POoHood0moom0??oo@3Yood0
POn1oh7oPOoeo`2N0?om087og_om0??oo@3jood0mOom0>coo021omSoo@3food0
mOom0>Soo@21oh7oPOn1ooCoo@21omkoo@3cood0n_om0?Goo@3/oo`0POoHood0
m_om0?Goo@3Xood0POn1oh7oPOodood0POoNood0loom0?[oo@3eood0k?ol087o
f?om0?Koo@3eood0j?om087oPOn1oh7omOl0WP3oo@21omkoo03eoo`0n_ol0?Oo
o03/oo`0POoHood0m_ol0?Ooo03Xood0POn1oh7oPOodood0POoNoo`0mOol0?[o
o03goo`0k?ol087of?om0?Koo03goo`0j?om087oPOn1oh7om?om087og_ol0?Go
o03joo`0mool0>coo021omSoo@3foo`0mool0>Soo@21oh7oPOn1ooGo09h0ood0
POoNoo/0mook0?Woo03ioo`0jool087of?om0?Goo03ioo`0ioom087oPOn1oh7o
m?om087og_ok0?Oon`3ioo`0nOol0>_oo021omSoo@3eoo`0nOol0>Ooo@21oh7o
POn1ooCoo@21omkon`3goo/0nOol0?Woo03[oo`0POoHood0mOol0?Woo03Wood0
POn1oh7oPOoeo`2N0?om087ogOok0?[onP3hoo/0o?oj0>_oo021omSoo@3eoo/0
o?oj0>Ooo@21oh7oPOn1ooCoo@21omgon`3jooX0n?ok0?conP3[oo`0POoHood0
mOok0?conP3Wood0POn1oh7oPOodood0POoMoo/0n_oj0?Son`3looX0jool087o
f?om0?Gon`3looX0ioom087oPOn1oh7omOl0NP3oo@21omcok`3foo40j_ol087o
f?om0?Col@3Vood0POn1oh7oPOodood0POoLonl0m_oa0>[oo021omSoo@3doo40
i_om087oPOn1oh7om?om087og?o_0?Kol@3Zoo`0POoHood0m?oa0>Koo@21oh7o
POn1ooGo07X0ood0POoKoo40m?oc0>Woo021omSoo@3coo<0iOom087oPOn1oh7o
m?om087ofooa0?Col`3Yoo`0POoHood0looc0>Goo@21oh7oPOn1ooCoo@21om_o
l@3doo<0jOol087of?om0??ol`3Uood0POn1oh7oPOoeo`1j0?om087of_od0?7o
m@3Xoo`0POoHood0l_oe0>Coo@21oh7oPOn1ooCoo@21om[om03aooD0j?ol087o
f?om0?;om@3Tood0POn1oh7oPOodood0POoJoo@0lOoe0>Soo021omSoo@3booD0
i?om087oPOn1oh7omOl0KP3oo@21omSon03]ooX0iOol087o`ooj0>7oo@21oh7o
POn1ooCoo@21omSon03]ooX0iOol087o`ooj0>7oo@21oh7oPOn1ooCoo@21omSo
n03]ooX0iOol087o`ooj0>7oo@21oh7oPOn1ooGo04X0ood0POnHoo`0POnLood0
POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0
POn1oh7oPOoeo`1:0?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087o
W?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7omOl0BP3oo@21oiSo
o021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSo
o021oicoo@21oh7oPOn1ooGo04X0ood0POnHoo`0POnLood0POn1oh7oPOodood0
POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOoeo`1:
0?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7o
m?om087oV?ol087oW?om087oPOn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7o
POn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7o
POn1ooGo04X0ood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0
POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOoeo`1:0?om087oV?ol087o
W?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087o
W?om087oPOn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSo
o021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooGo04X0ood0
POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOodood0
POnHoo`0POnLood0POn1oh7oPOoeo`1:0?om087oV?ol087oW?om087oPOn1oh7o
m?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7o
mOl0BP3oo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7o
POn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooGo04X0ood0POnHoo`0POnLood0
POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0
POn1oh7oPOoeo`1:0?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087o
W?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7omOl0BP3oo@21oiSo
o021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSo
o021oicoo@21oh7oPOn1ooGo04X0ood0POnHoo`0POnLood0POn1oh7oPOodood0
POnHoo`0POnLood0POn1oh7oPOodood0POnHoo`0POnLood0POn1oh7oPOoeo`1:
0?om087oV?ol087oW?om087oPOn1oh7om?om087oV?ol087oW?om087oPOn1oh7o
m?om087oV?ol087oW?om087oPOn1oh7omOl0BP3oo@21oiSoo021oicoo@21oh7o
POn1ooCoo@21oiSoo021oicoo@21oh7oPOn1ooCoo@21oiSoo021oicoo@21oh7o
POn1ooGo04Sj087oV_ol087oW?om087oPOn1oh7omOoj087oV_ol087oW?om087o
POn1oh7omOoj087oV_ol087oW?om087oPOn1oh7omOl0B?T0POnKoo`0POnLood0
POn1oh7oPOoeooT0POnKoo`0POnLood0POn1oh7oPOoeooT0POnKoo`0POnLood0
POn1oh7oPOoeo`18m`21oigoo021oicoo@21oh7oPOn1ooGom`21oigoo021oico
o@21oh7oPOn1ooGom`21oigoo021oicoo@21oh7oPOn1ooGo04Sf087oW_ol087o
W?om087oPOn1oh7omOof087oW_ol087oW?om087oPOn1oh7omOof087oW_ol087o
W?om087oPOn1oh7omOl0B?D0POnOoo`0POnLood0POn1oh7oPOoeooD0POnOoo`0
POnLood0POn1oh7oPOoeooD0POnOoo`0POnLood0POn1oh7oPOoeo`18m@21oioo
o021oicoo@21oh7oPOn1ooGom@21oiooo021oicoo@21oh7oPOn1ooGom@21oioo
o021oicoo@21oh7oPOn1ooGo04Sd087oXOoj087oW_oi087oPOn1oh7on?od087o
XOoj087oW_oi087oPOn1oh7on?od087oXOoj087oW_oi087oPOn1oh7on?l0B?@0
POnRooP0POnPooL0POn1oh7oPOoioo@0POnRooP0POnPooL0POn1oh7oPOoioo@0
POnRooP0POnPooL0POn1oh7oPOoio`18m021oj;om`21oj7omP21oh7oPOn1oo[o
m021oj;om`21oj7omP21oh7oPOn1oo[om021oj;om`21oj7omP21oh7oPOn1oo[o
03J10840P@2P087oPOn1oh7on_n10840P@2P087oPOn1oh7on_n10840P@2P087o
POn1oh7on_l0=X40P@210:00POn1oh7oPOojoh40P@210:00POn1oh7oPOojoh40
P@210:00POn1oh7oPOojo`0fP@210840X021oh7oPOn1oo[oP@210840X021oh7o
POn1oo[oP@210840X021oh7oPOn1oo[o03J10840P@2P087oPOn1oh7on_n10840
P@2P087oPOn1oh7on_n10840P@2P087oPOn1oh7on_l0B?@0POnSooH0POnQooH0
POn1oh7oPOojoo@0POnSooH0POnQooH0POn1oh7oPOojoo@0POnSooH0POnQooH0
POn1oh7oPOojo`18m021oj;om`21oj7om`21oh7oPOn1ooWom021oj;om`21oj7o
m`21oh7oPOn1ooWom021oj;om`21oj7om`21oh7oPOn1ooWo04Se087oXOoh087o
Wooi087oPOn1oh7on?oe087oXOoh087oWooi087oPOn1oh7on?oe087oXOoh087o
Wooi087oPOn1oh7on?l0B?H0POnOooX0POnNooT0POn1oh7oPOohooH0POnOooX0
POnNooT0POn1oh7oPOohooH0POnOooX0POnNooT0POn1oh7oPOoho`0fm`21oh7o
POn1oh7oPOn1oj?om`21oh7oPOn1oh7oPOn1oj?om`21oh7oPOn1oh7oPOn1oj?o
03Kh087oPOn1oh7oPOn1oh7oX_oh087oPOn1oh7oPOn1oh7oX_oh087oPOn1oh7o
POn1oh7oX_l0=_X0POn1oh7oPOn1oh7oPOnPooX0POn1oh7oPOn1oh7oPOnPooX0
POn1oh7oPOn1oh7oPOnPo`0h0?om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOn1oh7oW_l0>03oo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oiko03P0ood0POn1oh7o
POn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnNo`0h
0?om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7o
POn1oh7oW_l0>03oo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1oiko04@0ood0j_oi087oPOn1oh7oPOn1oh7o_?om0>[o
n@21oh7oPOn1oh7oPOn1okcoo@3ZooT0POn1oh7oPOn1oh7oPOnmo`140?om0>co
m@21oh7oPOn1oh7oPOn1okkoo@3/ooD0POn1oh7oPOn1oh7oPOnnood0k?oe087o
POn1oh7oPOn1oh7o_ol0A03oo@3]oo<0POn1oh7oPOn1oh7oPOnoood0kOoc087o
POn1oh7oPOn1oh7o_oom0>gol`21oh7oPOn1oh7oPOn1ol3o04@0ood0k_oa087o
POn1oh7oPOn1oh7o`?om0>kol@21oh7oPOn1oh7oPOn1ol3oo@3^oo40POn1oh7o
POn1oh7oPOo1o`1@0?om0>oon`3koo/0POn1oh7oPOn1oh7oPOo1ood0kook0?_o
n`21oh7oPOn1oh7oPOn1ol7oo@3_oo/0nook087oPOn1oh7oPOn1oh7o`_l0D03o
o@3_oo`0n?ol087oPOn1oh7oPOn1oh7o`_om0>ooo03hoo`0POn1oh7oPOn1oh7o
POo2ood0kool0?Soo021oh7oPOn1oh7oPOn1ol?o0500ood0l?ol0?Koo@21oh7o
POn1oh7oPOn1ol;oo@3`oo`0m_om087oPOn1oh7oPOn1oh7o`_om0?3oo03food0
POn1oh7oPOn1oh7oPOo3o`1@0?om0?3oo@3eoo`0POn1oh7oPOn1oh7oPOo3ood0
l?om0?Goo021oh7oPOn1oh7oPOn1ol?oo@3`ood0mOol087oPOn1oh7oPOn1oh7o
a?l0D03oo@3aoo`0m?om087oPOn1oh7oPOn1oh7o`oom0?7oo03dood0POn1oh7o
POn1oh7oPOo3ood0lOol0?Coo@21oh7oPOn1oh7oPOn1olCo0500ood0lOom0??o
o@21oh7oPOn1oh7oPOn1ol?oo@3aood0loom087oPOn1oh7oPOn1oh7o`oom0?7o
o@3cood0POn1oh7oPOn1oh7oPOo4o`1@0?om0?7oo@3cood0POn1oh7oPOn1oh7o
POo3ood0lOom0??oo@21oh7oPOn1oh7oPOn1ol?oo@3aood0loom087oPOn1oh7o
POn1oh7oa?l0D03oo@3aood0lool087oPOn1oh7oPOn1oh7oa?om0?7oo@3coo`0
POn1oh7oPOn1oh7oPOo4ood0lOom0??oo021oh7oPOn1oh7oPOn1olGo0500ood0
l_om0?7oo@21oh7oPOn1oh7oPOn1olCoo@3bood0lOom087oPOn1oh7oPOn1oh7o
a?om0?;oo@3aood0POn1oh7oPOn1oh7oPOo5o`1@0?om0?;oo@3aood0POn1oh7o
POn1oh7oPOo4ood0l_om0?7oo@21oh7oPOn1oh7oPOn1olCoo@3bood0lOom087o
POn1oh7oPOn1oh7oaOl0D03oo@3bood0lOom087oPOn1oh7oPOn1oh7oa?om0?;o
o@3aood0POn1oh7oPOn1oh7oPOo4ood0l_om0?7oo@21oh7oPOn1oh7oPOn1olGo
0500ood0l_om0?7oo@21oh7oPOn1oh7oPOn1olCoo@3bood0lOom087oPOn1oh7o
POn1oh7oa?om0?;oo@3aood0POn1oh7oPOn1oh7oPOo5o`1@0?om0?;oo@3aood0
POn1oh7oPOn1oh7oPOo4ood0l_om0?7oo@21oh7oPOn1oh7oPOn1olCoo@3bood0
lOom087oPOn1oh7oPOn1oh7oaOl0D03oo@3bood0lOom087oPOn1oh7oPOn1oh7o
a?om0?;oo@3aood0POn1oh7oPOn1oh7oPOo4ood0l_om0?7oo@21oh7oPOn1oh7o
POn1olGo0500ood0l_om0?7oo@21oh7oPOn1oh7oPOn1olCoo@3bood0lOom087o
POn1oh7oPOn1oh7oa?om0?;oo@3aood0POn1oh7oPOn1oh7oPOo5o`1@0?om0?;o
o@3aood0POn1oh7oPOn1oh7oPOo4ood0l_om0?7oo@21oh7oPOn1oh7oPOn1olCo
o@3bood0lOom087oPOn1oh7oPOn1oh7oaOl0D03oo@3bood0lOom087oPOn1oh7o
POn1oh7oa?om0?;oo@3aood0POn1oh7oPOn1oh7oPOo4ood0l_om0?7oo@21oh7o
POn1oh7oPOn1olGo0500ood0l_om0?7oo@21oh7oPOn1oh7oPOn1olCoo@3bood0
lOom087oPOn1oh7oPOn1oh7oa?om0?;oo@3aood0POn1oh7oPOn1oh7oPOo5o`1@
0?om0?;oo@3aood0POn1oh7oPOn1oh7oPOo4ood0l_om0?7oo@21oh7oPOn1oh7o
POn1olCoo@3bood0lOom087oPOn1oh7oPOn1oh7oaOl0D03oo@3bood0lOom087o
POn1oh7oPOn1oh7oa?om0?;oo@3aood0POn1oh7oPOn1oh7oPOo4ood0l_om0?7o
o@21oh7oPOn1oh7oPOn1olGo0500ood0lOom0??oo@21oh7oPOn1oh7oPOn1ol?o
o@3aood0loom087oPOn1oh7oPOn1oh7o`oom0?7oo@3cood0POn1oh7oPOn1oh7o
POo4o`1@0?om0?7oo@3cood0POn1oh7oPOn1oh7oPOo3ood0lOom0??oo@21oh7o
POn1oh7oPOn1ol?oo@3aood0loom087oPOn1oh7oPOn1oh7oa?l0D03oo@3aood0
loom087oPOn1oh7oPOn1oh7o`oom0?7oo@3cood0POn1oh7oPOn1oh7oPOo3ood0
lOom0??oo@21oh7oPOn1oh7oPOn1olCo0500ood0lOom0??oo@21oh7oPOn1oh7o
POn1ol?oo@3aood0loom087oPOn1oh7oPOn1oh7o`oom0?7oo@3cood0POn1oh7o
POn1oh7oPOo4o`1@0?om0?3oo@3eood0POn1oh7oPOn1oh7oPOo2ood0l?om0?Go
o@21oh7oPOn1oh7oPOn1ol;oo@3`ood0mOom087oPOn1oh7oPOn1oh7o`ol0D03o
o@3`oo`0mool087oPOn1oh7oPOn1oh7o`_om0?3oo03goo`0POn1oh7oPOn1oh7o
POo2ood0l?ol0?Ooo021oh7oPOn1oh7oPOn1ol?o0500ood0kool0?Woo021oh7o
POn1oh7oPOn1ol7oo@3_oo`0nOol087oPOn1oh7oPOn1oh7o`Oom0>ooo03ioo`0
POn1oh7oPOn1oh7oPOo2o`1@0?om0>oon`3looX0POn1oh7oPOn1oh7oPOo1ood0
kook0?conP21oh7oPOn1oh7oPOn1ol7oo@3_oo/0o?oj087oPOn1oh7oPOn1oh7o
`_l0A03oo@3^oo40POn1oh7oPOn1oh7oPOo0ood0k_oa087oPOn1oh7oPOn1oh7o
`?om0>kol@21oh7oPOn1oh7oPOn1ol7o04@0ood0kOoc087oPOn1oh7oPOn1oh7o
_oom0>gol`21oh7oPOn1oh7oPOn1okooo@3]oo<0POn1oh7oPOn1oh7oPOo0o`14
0?om0>com@21oh7oPOn1oh7oPOn1okkoo@3/ooD0POn1oh7oPOn1oh7oPOnnood0
k?oe087oPOn1oh7oPOn1oh7o_ol0A03oo@3ZooX0POn1oh7oPOn1oh7oPOnkood0
j_oj087oPOn1oh7oPOn1oh7o^oom0>[onP21oh7oPOn1oh7oPOn1okco03P0ood0
POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7o
POnNo`0h0?om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087o
POn1oh7oPOn1oh7oW_l0>03oo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7o
POn1oigoo@21oh7oPOn1oh7oPOn1oiko03P0ood0POn1oh7oPOn1oh7oPOnMood0
POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnNo`0h0?om087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oW_l0>03o
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7o
POn1oiko03P0ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0
POn1oh7oPOn1oh7oPOnNo`0h0?om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOn1oh7oW_l0>03oo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oiko03P0ood0POn1oh7o
POn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnNo`0h
0?om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7o
POn1oh7oW_l0>03oo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1oiko03P0ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7o
POn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnNo`0h0?om087oPOn1oh7oPOn1oh7o
WOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oW_l0>03oo@21oh7o
POn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oiko
03P0ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POn1oh7o
POn1oh7oPOnNo`0h0?om087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7o
WOom087oPOn1oh7oPOn1oh7oW_l0>03oo@21oh7oPOn1oh7oPOn1oigoo@21oh7o
POn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oiko03P0ood0POn1oh7oPOn1oh7o
POnMood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnNo`0fcP21oh7o
POn1oh7oPOn1olcocP21oh7oPOn1oh7oPOn1olcocP21oh7oPOn1oh7oPOn1olco
03K>087oPOn1oh7oPOn1oh7oc?o>087oPOn1oh7oPOn1oh7oc?o>087oPOn1oh7o
POn1oh7oc?l0=/h0POn1oh7oPOn1oh7oPOo<olh0POn1oh7oPOn1oh7oPOo<olh0
POn1oh7oPOn1oh7oPOo<o`0fcP21oh7oPOn1oh7oPOn1olcocP21oh7oPOn1oh7o
POn1olcocP21oh7oPOn1oh7oPOn1olco03K>087oPOn1oh7oPOn1oh7oc?o>087o
POn1oh7oPOn1oh7oc?o>087oPOn1oh7oPOn1oh7oc?l0=/h0POn1oh7oPOn1oh7o
POo<olh0POn1oh7oPOn1oh7oPOo<olh0POn1oh7oPOn1oh7oPOo<o`0fcP21oh7o
POn1oh7oPOn1olcocP21oh7oPOn1oh7oPOn1olcocP21oh7oPOn1oh7oPOn1olco
03K>087oPOn1oh7oPOn1oh7oc?o>087oPOn1oh7oPOn1oh7oc?o>087oPOn1oh7o
POn1oh7oc?l0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo03KS087oPOn1oh7oPOn1oh7o]ooS087o
POn1oh7oPOn1oh7o]ooS087oPOn1oh7oPOn1oh7o]ol0=^<0POn1oh7oPOn1oh7o
POngon<0POn1oh7oPOn1oh7oPOngon<0POn1oh7oPOn1oh7oPOngo`0fh`21oh7o
POn1oh7oPOn1okOoh`21oh7oPOn1oh7oPOn1okOoh`21oh7oPOn1oh7oPOn1okOo
03KS087oPOn1oh7oPOn1oh7o]ooS087oPOn1oh7oPOn1oh7o]ooS087oPOn1oh7o
POn1oh7o]ol0=^<0POn1oh7oPOn1oh7oPOngon<0POn1oh7oPOn1oh7oPOngon<0
POn1oh7oPOn1oh7oPOngo`0fh`21oh7oPOn1oh7oPOn1okOoh`21oh7oPOn1oh7o
POn1okOoh`21oh7oPOn1oh7oPOn1okOo03KS087oPOn1oh7oPOn1oh7o]ooS087o
POn1oh7oPOn1oh7o]ooS087oPOn1oh7oPOn1oh7o]ol0=^<0POn1oh7oPOn1oh7o
POngon<0POn1oh7oPOn1oh7oPOngon<0POn1oh7oPOn1oh7oPOngo`0fh`21oh7o
POn1oh7oPOn1okOoh`21oh7oPOn1oh7oPOn1okOoh`21oh7oPOn1oh7oPOn1okOo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`2J0000oh<D000000?X0<D00004000000180000B000
0100800300P00000000000;4nX0000000nP0_P001m<3jPR>00002X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l0VP000?n?X000
0003j0?X000010000000B00004P0000@02000`08000000000002a?Z0000000?X
0nP3jP001m03j`000321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0>87o
POn1oh7oPOn1ooKon@21oh7oPOn1oh7oPOn1oj7on@21oh7oPOn1oh7oPOn1oj7o
n@21ojco03R1oh7oPOn1oh7oPOohooD0POn1oh7oPOn1oh7oPOnUooD0POn1oh7o
POn1oh7oPOnUooD0POn^o`0hPOn1oh7oPOn1oh7onOoc087oPOn1oh7oPOn1oh7o
Yooc087oPOn1oh7oPOn1oh7oYooc087o[ol0>87oPOn1oh7oPOn1oo[ol@21oh7o
POn1oh7oPOn1ojWol@21oh7oPOn1oh7oPOn1ojWol@21ok3o04[PooT0POn1oh7o
POn1ojCon`3koo/0POn@ooT0POn1oh7oPOn1ojCon`3koo/0POn@ooT0POn1oh7o
POn1ojCon`3koo/0POnao`1:h_oe087oPOn1oh7oPOnVoo`0n?ol087oTooe087o
POn1oh7oPOnVoo`0n?ol087oTooe087oPOn1oh7oPOnVoo`0n?ol087o/_l0B^?o
l`21oh7oPOn1oh7oZ?ol0?Koo@21oiCol`21oh7oPOn1oh7oZ?ol0?Koo@21oiCo
l`21oh7oPOn1oh7oZ?ol0?Koo@21ok;o04[Too40POn1oh7oPOn1ojWoo@3eoo`0
POnFoo40POn1oh7oPOn1ojWoo@3eoo`0POnFoo40POn1oh7oPOn1ojWoo@3eoo`0
POnco`1FiOok0?_on`21oh7oPOn1oh7oZool0?Coo@21oiOon`3koo/0POn1oh7o
POn1oj_oo03dood0POnGoo/0nook087oPOn1oh7oPOn[oo`0m?om087o/ol0E^Go
o03hoo`0POn1oh7oPOn1ojcoo@3cood0POnGoo`0n?ol087oPOn1oh7oPOn/ood0
loom087oUool0?Soo021oh7oPOn1oh7o[?om0??oo@21ok?o05KVoo`0m_om087o
POn1oh7oPOn/ood0loom087oV?ol0?Koo@21oh7oPOn1oh7o[?om0??oo@21oiSo
o03food0POn1oh7oPOn1ojcoo@3cood0POnco`1Fi_om0?Goo021oh7oPOn1oh7o
[Oom0??oo021oiWoo@3eoo`0POn1oh7oPOn1ojgoo@3coo`0POnIood0mOol087o
POn1oh7oPOn]ood0lool087o]?l0E^Ooo03dood0POn1oh7oPOn1ojkoo@3aood0
POnJoo`0m?om087oPOn1oh7oPOn^ood0lOom087oV_ol0?Coo@21oh7oPOn1oh7o
[_om0?7oo@21okCo05KWood0loom087oPOn1oh7oPOn^ood0lOom087oV_om0??o
o@21oh7oPOn1oh7o[_om0?7oo@21oi[oo@3cood0POn1oh7oPOn1ojkoo@3aood0
POndo`1Fioom0??oo@21oh7oPOn1oh7o[_om0?7oo@21oi[oo@3cood0POn1oh7o
POn1ojkoo@3aood0POnJood0loom087oPOn1oh7oPOn^ood0lOom087o]?l0E^Oo
o@3coo`0POn1oh7oPOn1ojooo@3aood0POnJood0lool087oPOn1oh7oPOn_ood0
lOom087oV_om0??oo021oh7oPOn1oh7o[oom0?7oo@21okCo05KXood0lOom087o
POn1oh7oPOn_ood0lOom087oVoom0?7oo@21oh7oPOn1oh7o[oom0?7oo@21oi_o
o@3aood0POn1oh7oPOn1ojooo@3aood0POndo`1Rj?om0?7oo@21oh7oPOofood0
POn1okkoo@3aood0POnKood0lOom087oPOn1ooKoo@21oh7o__om0?7oo@21oi_o
o@3aood0POn1oh7om_om087oPOnnood0lOom087o]?l0H^Soo@3aood0POn1oh7o
mool087oPOnnood0lOom087oVoom0?7oo@21oh7oPOogoo`0POn1okkoo@3aood0
POnKood0lOom087oPOn1ooOoo021oh7o__om0?7oo@21okCo06;Xood0lOom087o
POn1ooOoo021oh7o__om0?7oo@21oi_oo@3aood0POn1oh7omool087oPOnnood0
lOom087oVoom0?7oo@21oh7oPOogoo`0POn1okkoo@3aood0POndo`1Rj?om0?7o
o@21oh7oPOohoo/0POn1okkoo@3aood0POnKood0lOom087oPOn1ooSon`21oh7o
__om0?7oo@21oi_oo@3aood0POn1oh7on?ok087oPOnnood0lOom087o]?l0H^So
o@3aood0POn1oh7onOoj087oPOnnood0lOom087oVoom0?7oo@21oh7oPOoiooX0
POn1okkoo@3aood0POnKood0lOom087oPOn1ooWonP21oh7o__om0?7oo@21okCo
06;Xood0lOom087oPOn1oo[on@21oh7o__om0?7oo@21oi_oo@3aood0POn1oh7o
n_oi087oPOnnood0lOom087oVoom0?7oo@21oh7oPOojooT0POn1okkoo@3aood0
POndo`1Rj?om0?7oo@21oh7oPOojooT0POn1okkoo@3aood0POnKood0lOom087o
POn1oo[on@21oh7o__om0?7oo@21oi_oo@3aood0POn1oh7on_oi087oPOnnood0
lOom087o]?l0H^Soo@3aood0POn1oh7onooh087oPOnmood0loom087oV_om0?7o
o@21oh7oPOokooP0POn1okgoo@3cood0POnJood0lOom087oPOn1oo_on021oh7o
_Oom0??oo@21ok?o06kXood0lOom087oPOn1oocoo000ood0POn1okgoo@3cood0
POnJood0lOom087oPOn1oocoo000ood0POn1okgoo@3cood0POnJood0lOom087o
POn1oocoo000ood0POn1okgoo@3cood0POnco`1aj?om0?7oo@21oh7oPOomoo`0
0Oooo@21oh7o_Oom0??oo@21oi[oo@3aood0POn1oh7ooOol007oood0POn1okgo
o@3cood0POnJood0lOom087oPOn1oogoo001ooom087oPOnmood0loom087o/ol0
K^Soo@3aood0POn1oh7ooOom0?koo@21oh7o_Oom0??oo@21oi[oo@3aood0POn1
oh7ooOom0?koo@21oh7o_Oom0??oo@21oi[oo@3aood0POn1oh7ooOom0?koo@21
oh7o_Oom0??oo@21ok?o06kWood0loom087oPOn1oogoo03nood0POn1okcoo@3e
ood0POnHood0loom087oPOn1oogoo03nood0POn1okcoo@3eood0POnHood0loom
087oPOn1oogoo03nood0POn1okcoo@3eood0POnbo`1^ioom0??oo@21oh7oPOon
oo`0oOom087oPOnloo`0mool087oV?om0??oo@21oh7oPOonoo`0oOom087oPOnl
oo`0mool087oV?om0??oo@21oh7oPOonoo`0oOom087oPOnloo`0mool087o/_l0
LNOoo@3cood0POn1oh7o0Oooo03lood0POn1ok_oo03ioo`0POnGood0loom087o
POn1o`7ooo`0o?om087oPOnkoo`0nOol087oUoom0??oo@21oh7oPOl1oool0?co
o@21oh7o^ool0?Woo021ok7o06kWood0loom087oPOn1o`3oo03kood0POn1ok_o
n`3looX0POnGood0loom087oPOn1o`3oo03kood0POn1ok_on`3looX0POnGood0
loom087oPOn1o`3oo03kood0POn1ok_on`3looX0POnao`1Ui_om0?Goo@21oh7o
POl1ooom0?[oo@21oh7o^_oa087oUOom0?Goo@21oh7oPOl1ooom0?[oo@21oh7o
^_oa087oUOom0?Goo@21oh7oPOl1ooom0?[oo@21oh7o^_oa087o/?l0H^Koo03g
oo`0POn1oh7o0?ol0?[oo@21oh7o^Ooc087oU?ol0?Ooo021oh7oPOl0oo`0n_om
087oPOnioo<0POnDoo`0mool087oPOn1o`3oo03jood0POn1okWol`21ojoo06;U
oo`0nOol087oPOn1o`3oo03iood0POn1okSom@21oi;oo03ioo`0POn1oh7o0?ol
0?Woo@21oh7o^?oe087oT_ol0?Woo021oh7oPOl0oo`0nOom087oPOnhooD0POn^
o`1LiOok0?conP21oh7oPOol0?Soo@21oh7o]_oj087oSook0?conP21oh7oPOol
0?Soo@21oh7o]_oj087oSook0?conP21oh7oPOol0?Soo@21oh7o]_oj087oZol0
D>Col@21oh7oPOl0ood0moom087oPOn1oh7o_?oa087oPOn1o`3oo@3good0POn1
oh7oPOnloo40POn1oh7o0?om0?Ooo@21oh7oPOn1omWo053Soo<0POn1oh7o0?ol
0?Ooo@21oh7oPOn1ok_ol`21oh7oPOl0oo`0moom087oPOn1oh7o^ooc087oPOn1
o`3oo03good0POn1oh7oPOoIo`1@h_oe087oPOn1o`3oo03food0POn1oh7oPOnj
ooD0POn1oh7o0?ol0?Koo@21oh7oPOn1ok[om@21oh7oPOl0oo`0m_om087oPOn1
oh7ofOl0A>3onP21oh7oPOomonP0POn1oh7oPOnmooX0POn1oh7ooOoX087oPOn1
oh7o_Ooj087oPOn1oogoj021oh7oPOn1omko03R1oh7oPOoEonP0POn1oh7oPOn1
oh7oPOnbonP0POn1oh7oPOn1oh7oPOnbonP0POn1oh7oPOoNo`0hPOn1oh7oeOoX
087oPOn1oh7oPOn1oh7o/_oX087oPOn1oh7oPOn1oh7o/_oX087oPOn1oh7og_l0
>87oPOn1omGoj021oh7oPOn1oh7oPOn1ok;oj021oh7oPOn1oh7oPOn1ok;oj021
oh7oPOn1omko03R1oh7oPOo5ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1
oh7oPOnMood0POn1oh7oPOoIo`0hPOn1oh7oaOom087oPOn1oh7oPOn1oh7oWOom
087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7ofOl0>87oPOn1olGoo@21oh7oPOn1
oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1omWo04:1oh7oPOo5
ood0POn1oj7o0021oh7oPOn1oh7oo_om087oPOnQo`00POn1oh7oPOn1ookoo@21
oh7oXOl0087o^_l0A<Gol`21oh7oSoom087oPOnWoo@0POn4oo<0POn1ohooo@21
oh7oYood087oQ?oc087oPOn?ood0POn1ojOom021ol3o04C7onh0POn1oi;oo@21
oh7oZ_o^087oROo^087oPOnBood0POn1oj[okP21ohWokP21oh7oT_om087oPOnZ
onh0POo3o`14booX087oPOnDood0POn1ojgoj021oi3oj021oh7oU?om087oPOn]
onP0POn@onP0POn1oiCoo@21oh7o[OoX087oa_l0A<goh`21oh7oUoom087oPOn_
on@0POnDon<0POn1oiOoo@21oh7o[ooT087oU?oS087oPOnGood0POn1ojooi021
olSo04C?oml0POn1oiWoo@21oh7o/_oN087oVOoO087oPOnIood0POn1ok;ogP21
oiWog`21oh7oVOom087oPOnbomh0POo;o`0nd?oM087oPOn1oh7oPOo8om`0POnK
omd0POn1oh7oPOn1olSog021oi_og@21oh7oPOn1oh7ob?oL087oc?l0?]7ofP21
oh7oPOn1oh7obooJ087oWOoJ087oPOn1oh7oPOo;omX0POnMomX0POn1oh7oPOn1
ol_ofP21olgo03kComL0POn1oh7oPOn1olkoe`21oj3oe`21oh7oPOn1oh7oc_oG
087oX?oG087oPOn1oh7oPOo>omL0POo>o`14e?oE087oPOnloo<0POn1oj?oe021
oj?oe@21oh7o_?oc087oPOnSom@0POnSomD0POn1okcol`21oh7oXooD087od?l0
A=God`21oh7o_oo^087oPOnWom80POnUom<0POn1okookP21oh7oYooB087oYOoC
087oPOnoonh0POn1ojOodP21om7o04CFom40POn1ol?oj021oh7oZoo@087oYooA
087oPOo3onP0POn1oj_od021ojOod@21oh7o`ooX087oPOn[om00POoBo`14eoo?
087oPOo6on@0POn1ojkoc`21ojSoc`21oh7oa_oT087oPOn^oll0POnXoll0POn1
olKoi021oh7o[_o?087od_l0A=Soc@21oh7ob?oR087oPOn`old0POnZold0POn1
olSohP21oh7o/?o=087oZ_o=087oPOo8on80POn1ok3oc@21om?o04CIol/0POn1
olcog@21oh7o/oo;087o[?o;087oPOo<omd0POn1ok?ob`21ojcob`21oh7oc?oM
087oPOncol/0POoDo`14fOo;087oPOo=omX0POn1okGob`21ojcob`21oh7ocOoJ
087oPOneol/0POn/ol/0POn1olgofP21oh7o]Oo;087oe?l0A=[ob@21oh7od?oG
087oPOngolT0POn^olT0POn1om3oe`21oh7o]oo9087o[_o9087oPOo@omL0POn1
okOob@21omGo04CJolP0POn1om;oe@21oh7o^?o8087o[oo8087oPOoBomD0POn1
okSob021ojoob021oh7od_oE087oPOnholP0POoFo`14foo7087oPOoCom<0POn1
ok[oa`21ok3oa`21oh7odooC087oPOnjolL0POn`olL0POn1om?od`21oh7o^_o7
087oe_l0A=_oa`21oh7oe?oA087oPOnkolL0POn`olL0POn1omCod@21oh7o^oo7
087o/?o7087oPOoDom40POn1ok_oa`21omKo04CLolD0POn1omKoc`21oh7o_?o6
087o/_o5087oPOoFoll0POn1okcoaP21ok;oa@21oh7oe_o?087oPOnlolH0POoG
o`14g?o5087oPOoGold0POn1okgoaP21ok;oa@21oh7oeoo=087oPOnmolH0POnb
olD0POn1omOoc@21oh7o_Oo6087oeol0A=coa@21oh7oeoo=087oPOnnol@0POnc
olD0POn1omOoc@21oh7o__o4087o/oo5087oPOoGold0POn1okkoa021omSo04CM
ol<0POn1omWob`21oh7o_oo4087o]?o3087oPOoIol/0POn1okooa021okCo``21
oh7ofOo;087oPOnool@0POoHo`14gOo3087oPOoIolX0POn1ol3oa021okCo``21
oh7ofOo:087oPOo0ol@0POndol<0POn1omWobP21oh7o`?o4087of?l0A=go``21
oh7of_o9087oPOo0ol<0POneol<0POn1om[ob@21oh7o`?o3087o]Oo3087oPOoJ
olT0POn1ol3o``21omWo04CMol00POn1omgob021oh7o`Oo0087o^?o0087oPOoM
olP0POn1ol7o`021okSo`021oh7ogOo8087oPOo1ol00POoLo`0ngOnH087oQ_o7
087oPOo2okd0POnjoiP0POn6olL0POn1ol;o_@21ok[oV021ohKoa`21oh7o`_nm
087og_l0A=goP@3a087o[Oo6087oPOo3ok/0POnloh40l@21ojgoaP21oh7o`onk
087o_?n10?40POn]olH0POn1ol?o^`21on3o04CMoh40b@21omKoa@21oh7o`oni
087o__n10<T0POoFolD0POn1ol?o^@21okkoP@39087oe_o5087oPOo3okT0POoR
o`1@gOn10:40POonolD0POn1ol?o`P00ooH0POo1oh40X@21ookoa@21oh7o`oo2
003omP21ol7oP@2Q087oo_o5087oPOo3ol800?of087oiOl0D=goP@210?T0Yoo3
087oPOo4ol80o_of087o`on10840n@2Wol<0POn1olCo`P3nooH0POo3oh40P@3i
0:Oo``21oh7oa?o20?komP21onOo053Moh40P@3A0<oo``21oh7o`oo30?comP21
olGoP@210=40coo3087oPOo3ol<0o?of087oaOn10840d@3?ol<0POn1ol?o``3l
ooH0POoYo`1@gOn10840ZP3fol<0POn1ol?oa03iooH0POo7oh40P@2Z0?Ko``21
oh7o`oo40?WomP21olOoP@210:X0m_o3087oPOo3ol@0nOof087ojol0B]goP@21
0840h@21oh7o`oo40?KomP21ol[oP@210840h@21oh7o`oo40?KomP21ol[oP@21
0840h@21oh7o`oo40?KomP21onko053Mol<0n_n10840YP21oh7o`oo40?ComP21
olco``3joh40P@2V087oPOo3ol@0m?of087oc?o30?[oP@210:H0POn1ol?oa03d
ooH0POo`o`1@gOo30<goP@210=<0POn1ol?oa03booH0POo>ol<0cOn10840d`21
oh7o`oo40?;omP21olko``3=oh40P@3C087oPOo3ol@0l_of087ol_l0D=coa@2O
oh40P@00087oPOo3ol@0l?of087ocoo509ooP@210000POn1ol?oa03`ooH0POo?
olD0Won108400021oh7o`oo40?3omP21ooCo053LolD0POoboh40[@21oh7o`_o4
0>komP21om;oa@21oo;oP@2]087oPOo2ol@0k_of087od_o5087ol_n10:d0POn1
ol;oa03^ooH0POogo`1@g?o5087oa_n10=T0POn1ol;o`P3^ooH0POoDolD0POo6
oh40f@21oh7o`_o20>komP21omCoa@21olKoP@3I087oPOo2ol80k_of087onOl0
B]_oa`21oiSoQP21oh7o`_no0>oomP21omGoa`21oiSoQP21oh7o`_no0>oomP21
omGoa`21oiSoQP21oh7o`_no0>oomP21oo_o053KolH0POn1onco/`21oh7o`_nm
0>oomP21omOoaP21oh7ok?nc087oPOo2okd0koof087oeoo6087oPOo/ok<0POn1
ol;o_@3_ooH0POomo`1@f_o5087oPOoNol<0POn1ol7o_03^ooH0POoIolD0POn1
omko``21oh7o`Onl0>komP21omWoa@21oh7og_o3087oPOo1ok`0k_of087o0?l0
C][o``21oh7oh?o3087oPOo1okX0k_of087ofoo3087oPOoPol<0POn1ol7o^P3^
ooH0POoKol<0POn1on3o``21oh7o`Onj0>komP22o`1>fOo1087oPOoSol<0POn1
ol3o^03_ooH0POoLol40POn1on?o``21oh7o`?nh0>oomP21omco`@21oh7ohoo3
087oPOo0okP0koof08Co04kHol00POn1onCoa021oh7o_ong0>oomP21omgo`021
oh7oi?o4087oPOnookL0koof087ogOo0087oPOoTol@0POn1okoo]`3_ooH0Q_l0
C]So_P21oh7oi_o5087oPOnnokD0k_of087oh?nn087oPOoVolD0POn1okko]@3^
ooH0POoPokh0POn1onKoa@21oh7o__ne0>komP29o`1Jeonm087oPOoXolD0POn1
okgob@00ond0k_of087ohOnm087oPOoXolD0POn1okgob@00ond0k_of087ohOnm
087oPOoXolD0POn1okgob@00ond0k_of08_o06KFok/0POn1on[oa`21oh7o^oo@
003on`3nond0koof087oh_nk087oPOoZolL0POn1ok_od000oo/0o_o]0>oomP21
on;o^`21oh7oj_o7087oPOnkom000?ok0?kok@3_ooH0SOl0L]God`3non/0POn1
oncoa`21oh7o^_oB0?koo03lond0koof087ohooC0?koj`21oh7ok?o7087oPOnj
om80o_ol0?cok@3_ooH0POoSom<0o_o[087oPOo/olL0POn1ok[odP3noo`0o?o]
0>oomP2?o`1be?oE0?_oj`21oh7okOo8087oPOniomD0nool0?_ok@3^ooH0POoU
omD0noo[087oPOo]olP0POn1okWoe@3koo`0noo]0>komP21onGoe@3kon/0POn1
ongob021oh7o^OoE0?_oo03kond0k_of09;o07;ComL0n?o[087oPOo_olT0POn1
okOoe`3ioo`0n_o]0>komP21onKoe`3hon/0POn1onoob@21oh7o]ooG0?Woo03j
ond0k_of087oi_oG0?Soj`21oh7okoo9087oPOngomL0nOol0?[ok@3^ooH0U?l0
L]7of@3eon/0POn1oo?ob021oh7o]OoJ0?Son`3hond0koof087oi_oI0?Goj`21
oh7oloo8087oPOneomX0n?ok0?Sok@3_ooH0POoVomT0mOo[087oPOocolP0POn1
okGofP3hoo/0n?o]0>oomP2Fo`1bd?oI0?Coj`21oh7om_o8087oPOncom`0m_ok
0?Ook@3_ooH0POoWomT0m?o[087oPOofolP0POn1ok?og03foo/0moo]0>oomP21
onOof@3don/0POn1ooKob021oh7o/ooL0?Kon`3gond0koof09So07;?omX0l_o[
087oPOojolL0POn1ok7og@3eoo/0m_o]0>komP21onWofP3bon/0POn1oo[oa`21
oh7o/OoM0?Gon`3fond0k_of087ojOoJ0?;oj`21oh7on_o7087oPOnaomd0mOok
0?Kok@3^ooH0Vol0L/gof`3aon/0POn1oogoa`21oh7o[OoO0?Goo03dond0k_of
087ojOoK0?7oj`21oh7ooOo7087oPOn]oml0mOol0?Cok@3^ooH0POoYom/0lOo[
087oPOomolL0POn1ojgog`3eoo`0m?o]0>komP2Mo`1hb_oY003omP3_on/0POn2
olH0POn1oj[oh03eoo`0l_o]0>oomP21onSoj@00ooH0koo[087oP_o6087oPOnZ
on00mOol0?;ok@3_ooH0POoXonT00?of0>ooj`21oh;oaP21oh7oZ_oP0?Goo03b
ond0koof09oo07_:onT00OoomP3^on/0POn5olH0POn1ojWog`3eoo`0lOo]0>oo
mP21on[oj@01ooof0>koj`21ohGoaP21oh7oZOoO0?Goo03aond0koof087oj_oY
007oooH0k_o[087oQOo6087oPOnYoml0mOol0?7ok@3_ooH0XOl0X/Com@3hooH0
kOo[087oROob003oe@21oh7oZ?om007ooo400Ooom`3doo`0l?o]0>komP21onOo
m@3hooH0kOo[087oROob003oe@21oh7oZ?om007ooo400Ooom`3doo`0l?o]0>ko
mP21onOom@3hooH0kOo[087oROob003oe@21oh7oZ?om007ooo400Ooom`3doo`0
l?o]0>komP2To`2L`?oi0?Som@3/on/0POn=oo80o_oE087oPOnXood0n?oh0?ko
m`3eoo/0koo]0>komP21onGon@3hooD0k?o[087oSOob0?koe@21oh7oZ?om0?So
n03nooL0mOok0>ook@3^ooH0POoUooT0n?oe0>coj`21ohgolP3nomD0POn1ojSo
o@3hooP0o_og0?Gon`3_ond0k_of0:Ko09c0ooT0moof0>Woj`21oi7olP3komP0
POn1ojOoo@3hooP0oOog0?Gon`3]ond0koof087oiooi0?OomP3Yon/0POnAoo80
nooH087oPOnWood0n?oh0?gom`3eoo/0kOo]0>oomP21onOon@3gooH0jOo[087o
TOob0?_of021oh7oYoom0?Son03mooL0mOok0>gok@3_ooH0Z?l0W<3on@3fooH0
j?o[087oUOob0?Sof`21oh7oYOom0?Son03looL0mOol0>_ok@3_ooH0POoYooT0
m_of0>Soj`21oiGolP3hom/0POn1ojGoo@3hooP0o?og0?Goo03[ond0koof087o
jOoi0?KomP3Xon/0POnEoo80n?oK087oPOnUood0n?oh0?com`3eoo`0joo]0>oo
mP2Zo`2L`?oi0?GomP3Won/0POnHoo80mOoN087oPOnTood0n?oh0?_om`3eoo`0
j_o]0>komP21oncon@3eooH0ioo[087oV?ob0?GogP21oh7oY?om0?Son03kooL0
mOol0>[ok@3^ooH0POo/ooT0mOof0>Ooj`21oiSolP3eomh0POn1ojCoo@3hooP0
noog0?Goo03Zond0k_of0:go09c0ooT0m?of0>Koj`21oicolP3bon40POn1oj;o
o@3hooP0noof0?Goo03Yond0k_of087ok_oi0?ComP3Von/0POnLoo80l_oQ087o
POnRood0n?oh0?_omP3eoo`0jOo]0>komP21onkon@3dooH0i_o[087oW?ob0?;o
h@21oh7oX_om0?Son03kooH0mOol0>Wok@3^ooH0[ol0W<3on@3cooH0i?o[087o
X?ob0?7oh021oh7oXoom0?Son03jooL0m?ol0>Ook@3_ooH0POo`ooT0loof0>Co
j`21oj3olP3aon00POn1oj?oo@3hooP0n_og0?Coo03Wond0koof087ol?oi0??o
mP3Ton/0POnPoo80lOoP087oPOnSood0n?oh0?[om`3doo`0ioo]0>oomP2ao`2L
`?oi0?;omP3Son/0POnToo80kooP087oPOnSood0n?oh0?Wom`3eoo/0i_o]0>oo
mP21oo;on@3booH0hoo[087oY?ob0>ooh021oh7oXoom0?Son03iooL0mOok0>Ko
k@3_ooH0POobooT0l_of0>?oj`21ojColP3_on00POn1oj?oo@3hooP0nOog0?Go
n`3Vond0koof0;?o0;[0ooT0l_oe0>;oj`21ojOolP3^ooT00Ooom@01ooog087o
POnTood0n?oh0?Som`3eoo/0iOo]0>komP21ooGon@3booD0h_o[087oYoob0>ko
n@01oooe007oooL0POn1ojCoo@3hooP0n?og0?Gon`3Uond0k_of087omOoi0?;o
m@3Ron/0POnWoo80k_oi007oooD00Ooom`21oh7oY?om0?Son03hooL0mOok0>Go
k@3^ooH0]_l0Z<3on@3aooH0h?o[087oZoob0>con@3`ooP0POn1ojCoo@3hooP0
moog0?Gon`3Tond0k_of087omooi0?7omP3Pon/0POn[oo80k?oi0?3on021oh7o
Y?om0?Son03gooL0mOok0>Cok@3^ooH0POogooT0lOof0>3oj`21oj_olP3/ooT0
l?oh087oPOnTood0n?oh0?Oom`3eoo/0i?o]0>komP2ho`2X`?oi0?3omP3Non/0
POn_oo80jooi0>oon021oh7oYOom0?Son03fooL0mOol0>7ok@3_ooH0POoiooT0
l?of0=koj`21ojoolP3[ooT0kooh087oPOnUood0n?oh0?Kom`3eoo`0hOo]0>oo
mP21ooWon@3`ooH0g_o[087o[oob0>_on@3_ooP0POn1ojGoo@3hooP0m_og0?Go
o03Qond0koof0;[o0:S0ooT0koof0=goj`21ok?olP3YooT0koog087oPOnVood0
n?oh0?KomP3eoo`0h?o]0>oomP21oo_on@3_ooH0gOo[087o/oob0>Won@3_ooL0
POn1ojKoo@3hooP0m_of0?Goo03Pond0koof087onooi0>oomP3Mon/0POncoo80
jOoi0>oom`21oh7oY_om0?Son03fooH0mOol0>3ok@3_ooH0_?l0Z<3on@3^ooH0
g?o[087o]_oc0>Oon@3^ooP0POn1ojKoo@3hooP0mOof0?Goo03Oond0k_of087o
o_oi0>komP3Lon/0POnfoo<0iooi0>kon021oh7oY_om0?Son03eooH0mOol0=oo
k@3^ooH0POonooT0k_of0=coj`21okKol`3WooT0k_oh087oPOnVood0n?oh0?Go
mP3eoo`0goo]0>komP2oo`2X`?oi0>gomP3Kon/0POnjoo80i_oi0>kom`21oh7o
Yoom0?Son03dooL0mOok0=kok@3^ooH0POl0ooT0kOof0=_oj`21ok[olP3VooT0
k_og087oPOnWood0n?oh0?Com`3eoo/0g_o]0>komP21o`3on@3]ooH0foo[087o
^_ob0>Kon@3^ooL0POn1ojOoo@3hooP0m?og0?Gon`3Nond0k_of0<7o0:C0ooT0
k?of0=Wok021okkolP3UooP0kOog087oPOnXood0n?oh0??om`3eoo/0g?o]0>oo
mP22ooT0k?of0=Wok021okkolP3UooP0kOog087oPOnXood0n?oh0??om`3eoo/0
g?o]0>oomP22ooT0k?of0=Wok021okkolP3UooP0kOog087oPOnXood0n?oh0??o
m`3eoo/0g?o]0>oomP33o`2T`?oi0>com@3Hon/0POo2oo80i?oi0>_on021oh7o
Z?om0?Son03booL0mOok0=_ok@3_ooH0Q?oi0>com@3Hon/0POo2oo80i?oi0>_o
n021oh7oZ?om0?Son03booL0mOok0=_ok@3_ooH0Q?oi0>com@3Hon/0POo2oo80
i?oi0>_on021oh7oZ?om0?Son03booL0mOok0=_ok@3_ooH0aOl0Y<3on@3[ooH0
e_o[087oa_ob0>;on@3[ooL0POn1ojWoo@3hooP0lOog0?Goo03Iond0k_of08Oo
n@3[ooH0e_o[087oa_ob0>;on@3[ooL0POn1ojWoo@3hooP0lOog0?Goo03Iond0
k_of08Oon@3[ooH0e_o[087oa_ob0>;on@3[ooL0POn1ojWoo@3hooP0lOog0?Go
o03Iond0k_of0<So0:C0ooT0j_of0=Goj`21olWolP3QooT0j_oh087oPOnYood0
n?oh0?3om`3eoo`0f?o]0>komP29ooT0j_of0=Goj`21olWolP3QooT0j_oh087o
POnYood0n?oh0?3om`3eoo`0f?o]0>komP29ooT0j_of0=Goj`21olWolP3QooT0
j_oh087oPOnYood0n?oh0?3om`3eoo`0f?o]0>komP3:o`2T`?oi0>WomP3Con`0
POo=oo80gooi0>Won021oh7oZ_om0?Son03`ooH0mOol0=Kok@3_ooH0Rooi0>Wo
mP3Con`0POo=oo80gooi0>Won021oh7oZ_om0?Son03`ooH0mOol0=Kok@3_ooH0
Rooi0>WomP3Con`0POo=oo80gooi0>Won021oh7oZ_om0?Son03`ooH0mOol0=Ko
k@3_ooH0c?l0Y<3on@3XooH0d_o[087odOob0=kon@3YooL0POn1oj_oo@3hooP0
koog0?Coo03Eond0koof08gon@3XooH0d_o[087odOob0=kon@3YooL0POn1oj_o
o@3hooP0koog0?Coo03Eond0koof08gon@3XooH0d_o[087odOob0=kon@3YooL0
POn1oj_oo@3hooP0koog0?Coo03Eond0koof0<ko0:C0ooT0ioof0=7oj`21omGo
lP3LooT0j?oh087oPOn[ood0n?oh0>kom`3eoo/0e?o]0>komP2@ooT0ioof0=7o
j`21omGolP3LooT0j?oh087oPOn[ood0n?oh0>kom`3eoo/0e?o]0>komP2@ooT0
ioof0=7oj`21omGolP3LooT0j?oh087oPOn[ood0n?oh0>kom`3eoo/0e?o]0>ko
mP3Ao`2T`?oi0>KomP3@on/0POoHoo80fooi0>Som`21oh7o[?om0?Son03]ooL0
mOok0=?ok03_ooH0T_oi0>KomP3@on/0POoHoo80fooi0>Som`21oh7o[?om0?So
n03]ooL0mOok0=?ok03_ooH0T_oi0>KomP3@on/0POoHoo80fooi0>Som`21oh7o
[?om0?Son03]ooL0mOok0=?ok03_ooH0dol0Y<3on@3VooD0c_o/087og?ob0=Wo
n@3WooL0POn1ojgoo@3hooP0k?og0?Goo03@ond0koof09Con@3VooD0c_o/087o
g?ob0=Won@3WooL0POn1ojgoo@3hooP0k?og0?Goo03@ond0koof09Con@3VooD0
c_o/087og?ob0=Won@3WooL0POn1ojgoo@3hooP0k?og0?Goo03@ond0koof0=Go
0:C0ooT0iOof0<coj`21on3olP3HooT0i_oh087oPOn]ood0n?oh0>_om`3eoo`0
coo]0>oomP2FooT0iOof0<coj`21on3olP3HooT0i_oh087oPOn]ood0n?oh0>_o
m`3eoo`0coo]0>oomP2FooT0iOof0<coj`21on3olP3HooT0i_oh087oPOn]ood0
n?oh0>_om`3eoo`0coo]0>oomP3Go`2T`?oi0>ComP3;on/0POoToo80e_oi0>Ko
m`21oh7o[_om0?Son03[ooH0mOol0<kok@3^ooH0VOoi0>ComP3;on/0POoToo80
e_oi0>Kom`21oh7o[_om0?Son03[ooH0mOol0<kok@3^ooH0VOoi0>ComP3;on/0
POoToo80e_oi0>Kom`21oh7o[_om0?Son03[ooH0mOol0<kok@3^ooH0f_l0Y<3o
n@3SooH0b_o[087oiooc0=Con@3UooP0POn1ojkoo@3hooP0j_og0?Coo03=on`0
koof09_on@3SooH0b_o[087oiooc0=Con@3UooP0POn1ojkoo@3hooP0j_og0?Co
o03=on`0koof09_on@3SooH0b_o[087oiooc0=Con@3UooP0POn1ojkoo@3hooP0
j_og0?Coo03=on`0koof0=co0:C0ooT0h_of0<Sok021on_olP3CooT0i?oh087o
POn_ood0n?oh0>Wom`3eoo/0boo]0>oomP2MooT0h_of0<Sok021on_olP3CooT0
i?oh087oPOn_ood0n?oh0>Wom`3eoo/0boo]0>oomP2MooT0h_of0<Sok021on_o
lP3CooT0i?oh087oPOn_ood0n?oh0>Wom`3eoo/0boo]0>oomP3No`2T`?oi0>7o
mP37on/0POo`oo80dOoi0>Com`21oh7o/?om0?Son03XooL0mOok0<[ok@3_ooH0
Wooi0>7omP37on/0POo`oo80dOoi0>Com`21oh7o/?om0?Son03XooL0mOok0<[o
k@3_ooH0Wooi0>7omP37on/0POo`oo80dOoi0>Com`21oh7o/?om0?Son03XooL0
mOok0<[ok@3_ooH0h?l0Y<3on@3PooH0a_o[087oloob0=3on@3SooP0POn1ok3o
o@3hooP0ioog0?Gon`39ond0k_of0:;on@3PooH0a_o[087oloob0=3on@3SooP0
POn1ok3oo@3hooP0ioog0?Gon`39ond0k_of0:;on@3PooH0a_o[087oloob0=3o
n@3SooP0POn1ok3oo@3hooP0ioog0?Gon`39ond0k_of0>?o0:C0ooT0h?of0<Co
j`21ooOolP3>ooT0hoog087oPOnaood0n?oh0>Kom`3eoo`0aoo/0>oomP2TooT0
h?of0<Coj`21ooOolP3>ooT0hoog087oPOnaood0n?oh0>Kom`3eoo`0aoo/0>oo
mP2TooT0h?of0<Coj`21ooOolP3>ooT0hoog087oPOnaood0n?oh0>Kom`3eoo`0
aoo/0>oomP3Uo`2T`?oi0=oomP32on`0POojoo80c_oh0>;on021oh7o/Oom0?So
n03VooH0mOol0<Gok@3_ooH0Y_oi0=oomP32on`0POojoo80c_oh0>;on021oh7o
/Oom0?Son03VooH0mOol0<Gok@3_ooH0Y_oi0=oomP32on`0POojoo80c_oh0>;o
n021oh7o/Oom0?Son03VooH0mOol0<Gok@3_ooH0iol0Yl3on@3NooH0`Oo[087o
0OoolP3<ooT0h?oh087oPOnbood0n?oh0>GomP3eoo`0a?o]0>oomP2XooT0g_of
0<7oj`21o`7ooo80c?oi0>3on021oh7o/_om0?Son03UooH0mOol0<Cok@3_ooH0
Z?oi0=komP31on/0POl1ooob0<con@3PooP0POn1ok;oo@3hooP0iOof0?Goo034
ond0koof0>Wo09k0ooT0gOof0<3oj`22oo80booi0>3om`21oh7o/oom0?Son03T
ooL0mOok0<?ok@3^ooH0Zooi0=gomP30on/0P_ob0<_on@3PooL0POn1ok?oo@3h
ooP0i?og0?Gon`33ond0k_of0:_on@3MooH0`?o[08;olP3;ooT0h?og087oPOnc
ood0n?oh0>Com`3eoo/0`oo]0>komP3/o`2N`?oi0=comP2oon/0Q_ob0<Won@3O
ooP0POn1ok?oo@3hooP0hoog0?Gon`32on`0koof0:gon@3LooH0_oo[08KolP39
ooT0gooh087oPOncood0n?oh0>?om`3eoo/0`_o/0>oomP2]ooT0g?of0;ooj`26
oo80bOoi0=oon021oh7o/oom0?Son03SooL0mOok0<;ok03_ooH0k_l0W/3on@3K
ooH0_Oo/08WolP38ooT0goog087oPOndood0n?oh0>;om`3eoo/0`?o]0>oomP2_
ooT0foof0;gok029oo80b?oi0=oom`21oh7o]?om0?Son03RooL0mOok0<3ok@3_
ooH0[ooi0=_omP2mon`0ROob0<Son@3OooL0POn1okCoo@3hooP0h_og0?Gon`30
ond0koof0?3o09k0ooT0fooe0;coj`2>oo80a_oi0=kom`21oh7o]Oom0?Son03Q
ooL0mOol0;kok@3_ooH0/Ooi0=_om@2lon/0S_ob0<Kon@3NooL0POn1okGoo@3h
ooP0hOog0?Goo02nond0koof0;7on@3KooD0_?o[08kolP36ooT0g_og087oPOne
ood0n?oh0>7om`3eoo`0__o]0>oomP3bo`2N`?oi0=[omP2jon/0TOob0<Gon@3M
ooP0POn1okGoo@3hooP0h?og0?Goo02mond0k_of0;Con@3JooH0^_o[097olP35
ooT0gOoh087oPOneood0n?oh0>3om`3eoo`0_Oo]0>komP2dooT0f_of0;[oj`2A
oo80aOoi0=gon021oh7o]Oom0?Son03PooL0mOol0;gok@3^ooH0mOl0W/3on@3I
ooH0^Oo[09GolP33ooT0gOog087oPOnfood0n?oh0>3omP3eoo`0_?o/0>oomP2f
ooT0fOof0;Woj`2Eoo80`ooi0=gom`21oh7o]_om0?Son03PooH0mOol0;cok03_
ooH0]_oi0=WomP2ion/0UOob0<?on@3MooL0POn1okKoo@3hooP0h?of0?Goo02l
on`0koof0?Oo09k0ooT0f?of0;Ook02Ioo80`Ooi0=con021oh7o]_om0?Son03O
ooL0m?ol0;[ok@3_ooH0^?oi0=SomP2gon`0VOob0<7on@3LooP0POn1okKoo@3h
ooP0goog0?Coo02jond0koof0;Son@3HooH0]oo/09WolP31ooT0g?oh087oPOnf
ood0n?oh0=oom`3doo`0^_o]0>oomP3io`2N`?oi0=OomP2fon/0WOob0<3on@3K
ooP0POn1okOoo@3hooP0g_og0?Gon`2iond0koof0;[on@3GooH0]_o[09golP30
ooT0fooh087oPOngood0n?oh0=kom`3eoo/0^Oo]0>oomP2jooT0eoof0;Koj`2M
oo80`?oi0=_on021oh7o]oom0?Son03NooL0mOok0;Wok@3_ooH0nol0W/3on@3F
ooH0]Oo[0:7olP2nooT0foog087oPOnhood0n?oh0=gom`3eoo/0^?o]0>komP2m
ooT0e_of0;Goj`2Qoo80__oi0=_om`21oh7o^?om0?Son03MooL0mOok0;Sok@3^
ooH0_Ooi0=KomP2eon/0XOob0;kon@3KooL0POn1okSoo@3hooP0gOog0?Gon`2h
ond0k_of0?ko09k0ooT0eOof0;Coj`2Too80_Ooi0=[on021oh7o^?om0?Son03L
ooL0mOol0;Kok03_ooH0_ooi0=GomP2don/0Y?ob0;gon@3JooP0POn1okSoo@3h
ooP0g?og0?Goo02fon`0koof0;oon@3EooH0]?o[0:ColP2mooT0f_oh087oPOnh
ood0n?oh0=com`3eoo`0]_o/0>oomP00o`2L`?oi0=Gom@2bon`0Z?ob0;_on@3J
ooL0POn1okWoo@3hooP0foog0?Goo02dond0koog0<3on@3EooD0/_o/0:SolP2k
ooT0f_og087oPOniood0n?oh0=_om`3eoo`0]?o]0>oom`30ooT0eOoe0;;ok02X
oo80^ooi0=[om`21oh7o^Oom0?Son03KooL0mOol0;Cok@3_ooL009c0ooT0e?of
0;3oj`2/oo80^_oi0=Wom`21oh7o^_om0?Son03KooH0mOol0;?ok@3_ooT0`?oi
0=ComP2`on/0[?ob0;[on@3IooL0POn1ok[oo@3hooP0foof0?Goo02cond0kooi
0<3on@3DooH0/?o[0:colP2jooT0fOog087oPOnjood0n?oh0=_omP3eoo`0/oo]
0>oon@00W<3on@3CooH0[oo[0;3olP2hooT0f?oh087oPOnjood0n?oh0=[om`3d
oo`0/_o]0>koo030ooT0doof0:ooj`2`oo80^?oi0=Son021oh7o^_om0?Son03J
ooL0m?ol0;;ok@3^oo`0`?oi0=?omP2_on/0/?ob0;Son@3HooP0POn1ok[oo@3h
ooP0f_og0?Coo02bond0k_ol002L`?oi0=;omP2^on/0/oob0;Son03HooL0POn1
ok_oo@3hooP0fOog0?Gon`2aon`0koon0<3on@3BooH0[_o[0;?olP2hooP0f?og
087oPOnkood0n?oh0=Wom`3eoo/0/Oo/0>oooP30ooT0d_of0:koj`2coo80^?oh
0=Som`21oh7o^oom0?Son03IooL0mOok0;7ok03_ooh009c0ooT0dOof0:cok02g
oo80]_oi0=Kon021oh7o^oom0?Son03HooL0mOok0:ook@3_o`00`?oi0=7omP2/
on`0]oob0;Kon@3FooP0POn1ok_oo@3hooP0f?og0?Gon`2_ond0kol00<3on@3A
ooH0[?o/0;OolP2fooT0e_oh087oPOnkood0n?oh0=Som`3eoo/0[oo]0>oo0000
T/3on@3@ooH0Zoo[0;_olP2eooT0eOoh087oPOnlood0n?oh0=Oom`3eoo`0[Oo]
0:oon@3@ooH0Zoo[0;_olP2eooT0eOoh087oPOnlood0n?oh0=Oom`3eoo`0[Oo]
0:oon@3@ooH0Zoo[0;_olP2eooT0eOoh087oPOnlood0n?oh0=Oom`3eoo`0[Oo]
0?3o09;0ooT0coof0:[oj`2ooo80/ooi0=Gom`21oh7o_Oom0?Son03FooL0mOol
0:cok@2aooT0coof0:[oj`2ooo80/ooi0=Gom`21oh7o_Oom0?Son03FooL0mOol
0:cok@2aooT0coof0:[oj`2ooo80/ooi0=Gom`21oh7o_Oom0?Son03FooL0mOol
0:cok@3bo`2B`?oi0<oomP2Xon/0`_ob0;;on@3DooP0POn1okgoo@3hooP0e_of
0?Goo02[on`0]?oi0<oomP2Xon/0`_ob0;;on@3DooP0POn1okgoo@3hooP0e_of
0?Goo02[on`0]?oi0<oomP2Xon/0`_ob0;;on@3DooP0POn1okgoo@3hooP0e_of
0?Goo02[on`0mOl0T/3on@3>ooH0Y_o/0<KolP2`ooT0e?og087oPOnnood0n?oh
0=Gom`3doo`0ZOo]0;Kon@3>ooH0Y_o/0<KolP2`ooT0e?og087oPOnnood0n?oh
0=Gom`3doo`0ZOo]0;Kon@3>ooH0Y_o/0<KolP2`ooT0e?og087oPOnnood0n?oh
0=Gom`3doo`0ZOo]0?Oo09;0ooT0cOof0:Goj`3;oo40[ooi0=?om`21oh7o_oom
0?Son03DooL0m?ol0:Sok@2hooT0cOof0:Goj`3;oo40[ooi0=?om`21oh7o_oom
0?Son03DooL0m?ol0:Sok@2hooT0cOof0:Goj`3;oo40[ooi0=?om`21oh7o_oom
0?Son03DooL0m?ol0:Sok@3io`2B`?oi0<comP2Ton/0c_ob0:gon@3BooP0POn1
okooo@3hooP0doog0?Gon`2Wond0^_oi0<comP2Ton/0c_ob0:gon@3BooP0POn1
okooo@3hooP0doog0?Gon`2Wond0^_oi0<comP2Ton/0c_ob0:gon@3BooP0POn1
okooo@3hooP0doog0?Gon`2Wond0nol0T/3on@3;ooH0Xoo[0=;olP2[ooT0d_og
087oPOo0ood0n?oh0=;om`3eoo/0Y_o/0;gon@3;ooH0Xoo[0=;olP2[ooT0d_og
087oPOo0ood0n?oh0=;om`3eoo/0Y_o/0;gon@3;ooH0Xoo[0=;olP2[ooT0d_og
087oPOo0ood0n?oh0=;om`3eoo/0Y_o/0?ko09;0ooT0b_of0:7ok03Eoo80Z_oi
0=7on021oh7o`?om0?Son03AooL0mOol0:?ok@2oooT0b_of0:7ok03Eoo80Z_oi
0=7on021oh7o`?om0?Son03AooL0mOol0:?ok@2oooT0b_of0:7ok03Eoo80Z_oi
0=7on021oh7o`?om0?Son03AooL0mOol0:?ok@00o`2@`?oi0<WomP2Pon`0fOob
0:Son@3@ooP0POn1ol7oo@3hooP0dOof0?Goo02Ronh0`?oi0<WomP2Pon`0fOob
0:Son@3@ooP0POn1ol7oo@3hooP0dOof0?Goo02Ronh0`?oi0<WomP2Pon`0fOob
0:Son@3@ooP0POn1ol7oo@3hooP0dOof0?Goo02Ronh00930ooT0bOof09koj`3M
oo80Yooi0=3om`21oh7o`_om0?Son03@ooH0mOol0:7ol030ooT0bOof09koj`3M
oo80Yooi0=3om`21oh7o`_om0?Son03@ooH0mOol0:7ol030ooT0bOof09koj`3M
oo80Yooi0=3om`21oh7o`_om0?Son03@ooH0mOol0:7ol000T<3on@38ooH0WOo[
0>7olP2UooT0cooh087oPOo2ood0n?oh0<oom`3doo`0X?ob0<3on@38ooH0WOo[
0>7olP2UooT0cooh087oPOo2ood0n?oh0<oom`3doo`0X?ob0<3on@38ooH0WOo[
0>7olP2UooT0cooh087oPOo2ood0n?oh0<oom`3doo`0X?ob002@`?oi0<OomP2K
on`0i?ob0:Con@3?ooL0POn1ol?oo@3hooP0c_og0?Gon`2NooD0`?oi0<OomP2K
on`0i?ob0:Con@3?ooL0POn1ol?oo@3hooP0c_og0?Gon`2NooD0`?oi0<OomP2K
on`0i?ob0:Con@3?ooL0POn1ol?oo@3hooP0c_og0?Gon`2NooD00930ooT0a_of
09[ok03Xoo80X_oi0<kon021oh7o`oom0?Son03=ooL0mOok09gom`30ooT0a_of
09[ok03Xoo80X_oi0<kon021oh7o`oom0?Son03=ooL0mOok09gom`30ooT0a_of
09[ok03Xoo80X_oi0<kon021oh7o`oom0?Son03=ooL0mOok09gom`00T<3on@35
ooH0VOo[0>colP2QooT0cOoh087oPOo4ood0n?oh0<com`3eoo`0Vooi0<3on@35
ooH0VOo[0>colP2QooT0cOoh087oPOo4ood0n?oh0<com`3eoo`0Vooi0<3on@35
ooH0VOo[0>colP2QooT0cOoh087oPOo4ood0n?oh0<com`3eoo`0Vooi002@`?oi
0<ComP2Hon/0l?ob0:3on03=ooL0POn1olGoo@3hooP0boog0?Goo02Joo/0`?oi
0<ComP2Hon/0l?ob0:3on03=ooL0POn1olGoo@3hooP0boog0?Goo02Joo/0`?oi
0<ComP2Hon/0l?ob0:3on03=ooL0POn1olGoo@3hooP0boog0?Goo02Joo/00930
ooT0`oof09Kok03doo40Wooi0<_on021oh7oaOom0?Son03;ooH0mOol09SooP30
ooT0`oof09Kok03doo40Wooi0<_on021oh7oaOom0?Son03;ooH0mOol09SooP30
ooT0`oof09Kok03doo40Wooi0<_on021oh7oaOom0?Son03;ooH0mOol09SooP00
T<3on@33ooH0U?o/0?OolP2MooT0boog087oPOo6ood0n?oh0<[om`3doo`0Uol0
0<3on@33ooH0U?o/0?OolP2MooT0boog087oPOo6ood0n?oh0<[om`3doo`0Uol0
0<3on@33ooH0U?o/0?OolP2MooT0boog087oPOo6ood0n?oh0<[om`3doo`0Uol0
002:`?oi0<;omP2Con/0o?oa09con@3:ooL0POn1olOoo@3hooP0bOog0?Gon`21
omKon@32ooH0Too[0?col@2LooT0b_og087oPOo7ood0n?oh0<Wom`3eoo/0POoF
ooT0`_of09?oj`3loo40W?oi0<[om`21oh7oaoom0?Son039ooL0mOok09Oo08g0
ooT0`Oof09;oj`01ooob09[on@39ooP0POn1olOoo@3hooP0b?og0?Gon`21omOo
n@31ooH0T_o[007ooo80V_oi0<Won021oh7oaoom0?Son038ooL0mOok087oeooi
0<7omP2Bon/00OoolP2JooT0bOoh087oPOo7ood0n?oh0<Som`3eoo/0V?l0O/3o
n@30ooH0T?oO09Son@39ooL0POn1olSoo@3hooP0aoog0?Goo021omOon@30ooH0
T?oO09Son@39ooL0POn1olSoo@3hooP0aoog0?Goo021omOon@30ooH0T?oO09So
n@39ooL0POn1olSoo@3hooP0aoog0?Goo02Ho`1n`?oi0;oomP2?on80Uooi0<So
n021oh7ob?om0?Son036ooL0mOol087of?oi0;oomP2?on80Uooi0<Son021oh7o
b?om0?Son036ooL0mOol087of?oi0;oomP2?on80Uooi0<Son021oh7ob?om0?So
n036ooL0mOol09Wo07k0ooT0__of08koiP2EooT0aooh087oPOo9ood0n?oh0<Ko
mP3eoo`0POoIooT0__of08koiP2EooT0aooh087oPOo9ood0n?oh0<KomP3eoo`0
POoIooT0__of08koiP2EooT0aooh087oPOo9ood0n?oh0<KomP3eoo`0V_l0O/3o
n@2mooH0SOoY09Con@37ooL0POn1ol[oo@3hooP0aOog0?Coo021om[on@2mooH0
SOoY09Con@37ooL0POn1ol[oo@3hooP0aOog0?Coo021om[on@2mooH0SOoY09Co
n@37ooL0POn1ol[oo@3hooP0aOog0?Coo02Ko`1n`?oi0;gomP2:on`0U?oi0<Ko
n021oh7ob_om0?Son034ooL0m?ol087ofooi0;gomP2:on`0U?oi0<Kon021oh7o
b_om0?Son034ooL0m?ol087ofooi0;gomP2:on`0U?oi0<Kon021oh7ob_om0?So
n034ooL0m?ol09co07k0ooT0_?of08Wok02FooT0a_og087oPOo;ood0n?oh0<?o
m`3eoo/0POoLooT0_?of08Wok02FooT0a_og087oPOo;ood0n?oh0<?om`3eoo/0
POoLooT0_?of08Wok02FooT0a_og087oPOo;ood0n?oh0<?om`3eoo/0WOl0O/3o
n@2kooH0RooX09Won@35ooL0POn1olcoo@3hooP0`_og0?Gon`21omgon@2kooH0
RooX09Won@35ooL0POn1olcoo@3hooP0`_og0?Gon`21omgon@2kooH0RooX09Wo
n@35ooL0POn1olcoo@3hooP0`_og0?Gon`2No`1n`?oi0;[omP2=onD0Vooi0<Co
n021oh7oc?om0?Son031ooL0mOol087ogOoi0;[omP2=onD0Vooi0<Con021oh7o
c?om0?Son031ooL0mOol087ogOoi0;[omP2=onD0Vooi0<Con021oh7oc?om0?So
n031ooL0mOol09ko07k0ooT0^Oof093oh@2MooT0a?og087oPOo=ood0n?oh0<7o
mP3eoo`0POoNooT0^Oof093oh@2MooT0a?og087oPOo=ood0n?oh0<7omP3eoo`0
POoNooT0^Oof093oh@2MooT0a?og087oPOo=ood0n?oh0<7omP3eoo`0Wol0O/3o
n@2hooH0TooM09oon@33ooP0POn1olgoo@3hooP0`?of0?Goo021omoon@2hooH0
TooM09oon@33ooP0POn1olgoo@3hooP0`?of0?Goo021omoon@2hooH0TooM09oo
n@33ooP0POn1olgoo@3hooP0`?of0?Goo02Po`2:`?oi0;SomP2Doo80o_o[0:?o
n032ooP0POn1olkoo@3hooP0_oog0?Coo021on3on@2hooH0U?ob0?koj`2SooP0
`_oh087oPOo>ood0n?oh0;oom`3doo`0POoPooT0^?of09ColP3non/0Xooh0<;o
n021oh7oc_om0?Son02oooL0m?ol0:7o08[0ooT0]oof09Ool@3kon/0YOoi0<7o
m`21oh7ocoom0?Son02nooL0mOok087ohOoi0;OomP2Goo40noo[0:Gon@31ooL0
POn1olooo@3hooP0__og0?Gon`21on7on@2gooH0Uooa0?_oj`2UooT0`Oog087o
POo?ood0n?oh0;kom`3eoo/0X_l0R/3on@2fooH0VOob0?Kok02WooT0`?oh087o
POo?ood0n?oh0;gom`3eoo/0POoRooT0]_of09WolP3fon`0Yooi0<3on021oh7o
coom0?Son02mooL0mOok087oh_oi0;KomP2Ioo80m_o/0:Oon@30ooP0POn1oloo
o@3hooP0_Oog0?Gon`2So`2:`?oi0;GomP2Loo80l_o/0:Won@30ooL0POn1om3o
o@3hooP0_?og0?Goo021on;on@2eooH0W?ob0?;ok02YooT0`?og087oPOo@ood0
n?oh0;com`3eoo`0POoRooT0]Oof09colP3bon`0ZOoi0<3om`21oh7od?om0?So
n02looL0mOol0:?o08[0ooT0]?of09kolP3_on/0[?oi0;oom`21oh7odOom0?So
n02kooL0mOol087ohooi0;ComP2Noo80koo[0:con@2oooL0POn1om7oo@3hooP0
^oog0?Goo021on?on@2dooH0W_ob0>ooj`2/ooT0_oog087oPOoAood0n?oh0;_o
m`3eoo`0Y?l0R/3on@2cooH0XOob0>_oj`2^ooT0__oh087oPOoAood0n?oh0;_o
mP3eoo`0POoTooT0/oof0:7olP3[on/0[_oi0;kon021oh7odOom0?Son02kooH0
mOol087oi?oi0;?omP2Qoo80joo[0:kon@2nooP0POn1om7oo@3hooP0^oof0?Go
o02Uo`2:`?oi0;;omP2Soo80ioo/0;3on@2nooL0POn1om;oo@3hooP0^_og0?Co
o021onGon@2booH0Xoob0>Ook02`ooT0__og087oPOoBood0n?oh0;[om`3doo`0
POoUooT0/_of0:?olP3Won`0/?oi0;kom`21oh7od_om0?Son02jooL0m?ol0:Ko
08[0ooT0/_of0:GolP3Son`0/_oi0;gon021oh7od_om0?Son02iooL0mOok087o
i_oi0;;omP2Uoo80hoo/0;;on@2mooP0POn1om;oo@3hooP0^Oog0?Gon`21onKo
n@2booH0YOob0>?ok02booT0_Ooh087oPOoBood0n?oh0;Wom`3eoo/0Yol0R/3o
n@2aooH0Yoob0>3oj`2eooT0_?oh087oPOoCood0n?oh0;Som`3eoo/0POoWooT0
/Oof0:OolP3Pon/0]Ooi0;con021oh7odoom0?Son02hooL0mOok087oiooi0;7o
mP2Woo80h?o[0;Gon@2looP0POn1om?oo@3hooP0^?og0?Gon`2Xo`2:`?oi0;3o
mP2Zoo80g?o[0;Oon@2looL0POn1omCoo@3hooP0]oog0?Goo021onOon@2`ooH0
Z_ob0=coj`2gooT0_?og087oPOoDood0n?oh0;Oom`3eoo`0POoWooT0/?of0:[o
lP3Lon/0]ooi0;com`21oh7oe?om0?Son02gooL0mOol0:So08[0ooT0[oof0:co
lP3Hon`0^Ooi0;_on021oh7oe?om0?Son02fooL0mOol087oj?oi0:oomP2/oo80
f?o/0;Won@2kooP0POn1omCoo@3hooP0]_og0?Goo021onSon@2_ooH0[?ob0=So
k02iooT0^ooh087oPOoDood0n?oh0;Kom`3eoo`0ZOl0R/3on@2^ooH0[oob0=Co
k02kooT0^oog087oPOoEood0n?oh0;KomP3eoo`0POoYooT0[_of0:oolP3Don`0
^ooi0;_om`21oh7oeOom0?Son02fooH0mOol087ojOoi0:komP2_oo80e?o/0;_o
n@2kooL0POn1omGoo@3hooP0]_of0?Goo02Zo`2:`?oi0:gomP2boo40dOo[0;ko
n@2jooP0POn1omGoo@3hooP0]Oog0?Coo021on[on@2]ooH0/_oa0=7oj`2nooT0
^_oh087oPOoEood0n?oh0;Gom`3doo`0POoZooT0[Oof0;;ol@3Aon/0__oi0;[o
n021oh7oeOom0?Son02eooL0m?ol0:_o08[0ooT0[?of0;ColP3=on/0`?oi0;Wo
n021oh7oe_om0?Son02dooL0m?ol087ojooi0:comP2doo80cOo[0<3on@2iooP0
POn1omKoo@3hooP0]?og0?Coo021on_on@2/ooH0]?ob0<goj`30ooT0^Ooh087o
POoFood0n?oh0;Com`3doo`0[?l0R/3on@2/ooH0]_oa0<Wok032ooT0^Oog087o
POoGood0n?oh0;?om`3eoo/0POo/ooT0[?of0;Kol@39on`0`_oi0;Wom`21oh7o
eoom0?Son02cooL0mOok087ok?oi0:comP2foo40bOo/0<;on@2iooL0POn1omOo
o@3hooP0/oog0?Gon`2]o`2:`?oi0:_omP2hoo80aOo/0<Con@2hooP0POn1omOo
o@3hooP0/_og0?Goo021oncon@2[ooH0^?ob0<Gok034ooT0^?oh087oPOoGood0
n?oh0;;om`3eoo`0POo/ooT0Zoof0;SolP35on`0a?oi0;Son021oh7oeoom0?So
n02booL0mOol0:go08[0ooT0Z_of0;_ol@32on/0b?oh0;Som`21oh7of?om0?So
n02aooL0mOol087okOoi0:[omP2koo40`_o[0<Son02hooL0POn1omSoo@3hooP0
/Oog0?Goo021ongon@2ZooH0^ooa0<;oj`38ooP0^?og087oPOoHood0n?oh0;7o
m`3eoo`0[_l0R/3on@2YooH0_Oob0;koj`3:ooT0]_og087oPOoIood0n?oh0;7o
mP3eoo`0POo^ooT0ZOof0;golP2non/0b_oi0;Kom`21oh7ofOom0?Son02aooH0
mOol087ok_oi0:WomP2moo80__o[0<[on@2fooL0POn1omWoo@3hooP0/Oof0?Go
o02_o`2:`?oi0:SomP30oo80^Oo/0<con@2eooP0POn1omWoo@3hooP0/?og0?Co
o021onoon@2XooH0`?ob0;Wok03<ooT0]Ooh087oPOoIood0n?oh0;3om`3doo`0
POo_ooT0Z?of0<3olP2ion`0c?oi0;Gon021oh7ofOom0?Son02`ooL0m?ol0;3o
08[0ooT0Yoof0<;olP2fon`0c_oi0;Gom`21oh7of_om0?Son02_ooL0m?ol087o
l?oi0:OomP32oo80]_o/0<kon@2eooL0POn1om[oo@3hooP0[oog0?Coo021oo3o
n@2WooH0`_ob0;Kok03>ooT0]Oog087oPOoJood0n?oh0:oom`3doo`0/Ol0R/3o
n@2VooL0a?ob0;;oj`3AooT0]?oh087oPOoJood0n?oh0:kom`3eoo/0POoaooT0
Y_og0<ColP2bon/0dOoi0;Con021oh7of_om0?Son02^ooL0mOok087olOoi0:Ko
m`34oo80/_o[0=7on@2dooP0POn1om[oo@3hooP0[_og0?Gon`2bo`2:`?oi0:Ko
mP36oo80[oo[0=?on@2cooP0POn1om_oo@3hooP0[Oog0?Gon`21oo;on@2VooH0
a_ob0:ooj`3CooT0/ooh087oPOoKood0n?oh0:gom`3eoo/0POobooT0Y_of0<Ko
lP2_on/0dooi0;?on021oh7ofoom0?Son02]ooL0mOok0;?o08[0ooT0YOof0<Wo
lP2Zon`0eOoi0;?om`21oh7og?om0?Son02/ooL0mOol087ol_oi0:GomP39oo80
Z_o/0=Gon@2cooL0POn1omcoo@3hooP0[?og0?Goo021oo;on@2UooH0bOob0:[o
k03EooT0/oog087oPOoLood0n?oh0:com`3eoo`0/ol0R/3on@2TooH0c?oa0:Oo
k03GooT0/_oh087oPOoLood0n?oh0:comP3eoo`0POocooT0Y?of0<col@2Won`0
eooi0;;on021oh7og?om0?Son02/ooH0mOol087olooi0:ComP3<oo40Yoo/0=Oo
n@2booP0POn1omcoo@3hooP0[?of0?Goo02do`2:`?oi0:?omP3>oo80Xoo/0=Wo
n@2booL0POn1omgoo@3hooP0Zoof0?Goo021ooCon@2SooH0c_ob0:?ok03IooT0
/_og087oPOoMood0n?oh0:_omP3eoo`0POodooT0Xoof0<kolP2Son`0fOoi0;;o
m`21oh7ogOom0?Son02[ooH0mOol0;Go08[0ooT0X_of0=7ol@2Pon/0g?oi0;7o
m`21oh7og_om0?Son02ZooL0m?ol087omOoi0:;omP3Aoo40X?o[0=con@2aooL0
POn1omkoo@3hooP0Z_og0?Coo021ooGon@2RooH0dOoa0:3oj`3LooT0/Oog087o
POoNood0n?oh0:[om`3doo`0]_l0R/3on@2QooH0doob09_ok03NooT0/?oh087o
POoNood0n?oh0:Wom`3eoo/0POofooT0XOof0=?olP2Kon`0g_oi0;3on021oh7o
g_om0?Son02YooL0mOok087om_oi0:7omP3Coo80Voo/0=kon@2`ooP0POn1omko
o@3hooP0ZOog0?Gon`2go`2:`?oi0:3om`3Eoo40V?o/0>3on@2`ooL0POn1omoo
o@3hooP0Z?og0?Gon`21ooOon@2PooL0eOoa09Sok03PooT0/?og087oPOoOood0
n?oh0:Som`3eoo/0POogooT0X?og0=Gol@2Hon`0h?oi0;3om`21oh7ogoom0?So
n02XooL0mOok0;So08[0ooT0X?of0=OolP2Don`0h_oi0:oon021oh7ogoom0?So
n02WooL0mOol087omooi0:3omP3Goo80U?o/0>;on@2_ooP0POn1omooo@3hooP0
Yoog0?Goo021ooOon@2PooH0eoob09Cok03RooT0[ooh087oPOoOood0n?oh0:Oo
m`3eoo`0^?l0R/3on@2OooH0f_oa097oj`3UooT0[_oh087oPOoPood0n?oh0:Ko
m`3eoo`0POohooT0Woof0=[ol@2Aon/0iOoi0:kon021oh7oh?om0?Son02VooL0
mOol087on?oi09oomP3Joo40TOo[0>Gon@2^ooP0POn1on3oo@3hooP0Y_og0?Go
o02io`2:`?oi09komP3Loo80S?o/0>Oon@2^ooL0POn1on7oo@3hooP0Y_of0?Go
o021ooWon@2NooH0g?ob08cok03WooT0[_og087oPOoQood0n?oh0:KomP3eoo`0
POoiooT0W_of0=colP2<on`0iooi0:kom`21oh7ohOom0?Son02VooH0mOol0;[o
08[0ooT0WOof0=oolP28on`0j_oh0:gon021oh7ohOom0?Son02UooL0m?ol087o
n_oi09gomP3Ooo80R?o/0>[on02]ooP0POn1on7oo@3hooP0YOog0?Coo021oo[o
n@2MooH0goob08Sok03ZooP0[Ooh087oPOoQood0n?oh0:Gom`3doo`0^ol0R/3o
n@2LooH0hOob08Gok03/ooT0[?og087oPOoRood0n?oh0:Com`3doo`0POokooT0
W?of0>7olP25on`0k?oi0:com`21oh7oh_om0?Son02TooL0m?ol087onooi09co
mP3Qoo80QOo/0>con@2/ooL0POn1on;oo@3hooP0Y?og0?Coo02lo`2:`?oi09_o
mP3Too80POo[0>oon@2[ooP0POn1on;oo@3hooP0Xoog0?Gon`21oocon@2KooH0
i?ob087oj`3_ooT0Zooh087oPOoRood0n?oh0:?om`3eoo/0POolooT0Voof0>Co
lP21on/0kooi0:_on021oh7oh_om0?Son02SooL0mOok0;go0930ooT0Voof0>Go
lP21oogok03aooT0Z_oh087oPOoSood0n?oh0:;om`3eoo`0POolooT0Voof0>Go
lP21oogok03aooT0Z_oh087oPOoSood0n?oh0:;om`3eoo`0POolooT0Voof0>Go
lP21oogok03aooT0Z_oh087oPOoSood0n?oh0:;om`3eoo`0_Ol0T<3on@2JooH0
j?ob087onOo/0??on@2ZooL0POn1onCoo@3hooP0XOog0?Goo021oogon@2JooH0
j?ob087onOo/0??on@2ZooL0POn1onCoo@3hooP0XOog0?Goo021oogon@2JooH0
j?ob087onOo/0??on@2ZooL0POn1onCoo@3hooP0XOog0?Goo02no`2@`?oi09Wo
mP3[oo40POofon`0mOoi0:Won021oh7oi?om0?Son02QooH0mOol087oo_oi09Wo
mP3[oo40POofon`0mOoi0:Won021oh7oi?om0?Son02QooH0mOol087oo_oi09Wo
mP3[oo40POofon`0mOoi0:Won021oh7oi?om0?Son02QooH0mOol0;oo09;0ooT0
V?of0>golP21oo;oj`3hooT0ZOog087oPOoUood0n?oh0:3om`3doo`0POl1oooi
09SomP3]oo80POobon/0n?oi0:Wom`21oh7oiOom0?Son02PooL0m?ol087o0Ooo
n@2HooH0kOob087ol_o[0?Son@2YooL0POn1onGoo@3hooP0X?og0?Coo030o`2@
`?oi09OomP3`oo40POo^on`0n_oi0:Som`21oh7oi_om0?Son02OooL0m?ol087o
0?oi09OomP3`oo40POo^on`0n_oi0:Som`21oh7oi_om0?Son02OooL0m?ol087o
0?oi09OomP3`oo40POo^on`0n_oi0:Som`21oh7oi_om0?Son02OooL0m?ol0<7o
08c0ooT0U_of0?;olP21on[ok03looT0Yooh087oPOoVood0n?oh09kom`3eoo/0
POoi09KomP3boo80POoZon`0o?oi0:Oon021oh7oi_om0?Son02NooL0mOok087o
n@2FooH0l_ob087oj_o/0?con@2WooP0POn1onKoo@3hooP0W_og0?Gon`32o`2<
`?oi09GomP3eoo40POoWon`0o_oi0:Oom`21oh7oioom0?Son02MooL0mOok08;o
n@2EooH0mOoa087oioo/0?kon@2WooL0POn1onOoo@3hooP0WOog0?Gon`22ooT0
UOof0?Gol@21onOok03nooT0Yoog087oPOoWood0n?oh09gom`3eoo/0`ol0P<3o
n@2EooH0m_ob087ohooS0:Kon021oh7oioom0?Son02LooL0mOol08;on@2EooH0
m_ob087ohooS0:Kon021oh7oioom0?Son02LooL0mOol08;on@2EooH0m_ob087o
hooS0:Kon021oh7oioom0?Son02LooL0mOol0<?o0830ooT0U?of0?Wol@21omoo
iP2UooP0POn1onSoo@3hooP0W?of0?Goo023ooT0U?of0?Wol@21omooiP2UooP0
POn1onSoo@3hooP0W?of0?Goo023ooT0U?of0?Wol@21omooiP2UooP0POn1onSo
o@3hooP0W?of0?Goo034o`20`?oi09?omP3koo80POoKonP0YOog087oPOoYood0
n?oh09_omP3eoo`0Q?oi09?omP3koo80POoKonP0YOog087oPOoYood0n?oh09_o
mP3eoo`0Q?oi09?omP3koo80POoKonP0YOog087oPOoYood0n?oh09_omP3eoo`0
aOl0P<3on@2BooH0o_oa087of?oZ0:Con021oh7ojOom0?Son02JooL0m?ol08Go
n@2BooH0o_oa087of?oZ0:Con021oh7ojOom0?Son02JooL0m?ol08Gon@2BooH0
o_oa087of?oZ0:Con021oh7ojOom0?Son02JooL0m?ol0<Ko0830ooT0TOof003o
lP21omCoj`2UooL0POn1on[oo@3hooP0VOog0?Coo026ooT0TOof003olP21omCo
j`2UooL0POn1on[oo@3hooP0VOog0?Coo026ooT0TOof003olP21omCoj`2UooL0
POn1on[oo@3hooP0VOog0?Coo037o`1d`?oi093oj@21olook02VooL0POn1on_o
o@3hooP0V?og0?Gon`27ooT0T?oY087ocoo/0:Kom`21oh7ojoom0?Son02HooL0
mOok08Oon@2@onT0POo?on`0Y_og087oPOo[ood0n?oh09Som`3eoo/0b?l0M<3o
n@2?on/0POo<on`0Yooh087oPOo[ood0n?oh09Oom`3eoo`0Qooi08ooj`21olco
k02WooP0POn1on_oo@3hooP0Uoog0?Goo027ooT0Soo[087oc?o/0:Oon021oh7o
joom0?Son02GooL0mOol0<So07C0ooT0Soo]087ob?o/0:Wom`21oh7ok?om0?So
n02FooL0mOol08Son@2?ond0POo8on`0ZOog087oPOo/ood0n?oh09Kom`3eoo`0
R?oi08ook@21olSok02YooL0POn1oncoo@3hooP0U_og0?Goo039o`1d`?oi08ko
k`21olGoj`2[ooP0POn1oncoo@3hooP0U_of0?Goo029ooT0S_o_087oaOo[0:_o
n021oh7ok?om0?Son02FooH0mOol08Won@2>onl0POo5on/0Zooh087oPOo/ood0
n?oh09KomP3eoo`0b_l0M<3on@2=oo80POo0on`0[?oh087oPOo]ood0n?oh09Go
m`3doo`0R_oi08golP21ol3ok02/ooP0POn1ongoo@3hooP0UOog0?Coo02:ooT0
SOob087o`?o/0:con021oh7okOom0?Son02EooL0m?ol0<_o07C0ooT0Sooa087o
_ooZ0:kom`21oh7ok_om0?Son02DooL0m?ol08_on@2?oo40POnoonX0[_og087o
POo^ood0n?oh09Com`3doo`0Rooi08ool@21okoojP2^ooL0POn1onkoo@3hooP0
U?og0?Coo03<o`1d`?oi093ol@21okkoj02_ooP0POn1onkoo@3hooP0Toog0?Go
n`2<ooT0T?oa087o__oX0:oon021oh7ok_om0?Son02CooL0mOok08con@2@oo40
POnnonP0[ooh087oPOo^ood0n?oh09?om`3eoo/0cOl0M<3on@2Bonh0POnoonD0
/_og087oPOo_ood0n?oh09;om`3eoo`0S?oi09;okP21okooi@2booL0POn1onoo
o@3hooP0T_og0?Goo02<ooT0T_o^087o_ooU0;;om`21oh7okoom0?Son02BooL0
mOol0<go0830ooT0Too]087o_ooi003ok02cooL0POn1oo3oo@3hooP0TOog0?Go
o02=ooT0Too]087o_ooi003ok02cooL0POn1oo3oo@3hooP0TOog0?Goo02=ooT0
Too]087o_ooi003ok02cooL0POn1oo3oo@3hooP0TOog0?Goo03>o`20`?oi09Go
jP21ol3on@3non`0]?oh087oPOo`ood0n?oh097omP3eoo`0S_oi09GojP21ol3o
n@3non`0]?oh087oPOo`ood0n?oh097omP3eoo`0S_oi09GojP21ol3on@3non`0
]?oh087oPOo`ood0n?oh097omP3eoo`0col0P<3on@2FonP0POo1ooT0o?o/0;Ko
m`21oh7olOom0?Son02@ooL0m?ol08oon@2FonP0POo1ooT0o?o/0;Kom`21oh7o
lOom0?Son02@ooL0m?ol08oon@2FonP0POo1ooT0o?o/0;Kom`21oh7olOom0?So
n02@ooL0m?ol0=3o08c0ooT0V?oa003omP21ol;on@3jon/0^?oh087oPOoaood0
n?oh08oom`3doo`0T?oi09Sol@00ooH0POo2ooT0n_o[0;Son021oh7olOom0?So
n02?ooL0m?ol093on@2Hoo400?of087o`_oi0?[oj`2hooP0POn1oo7oo@3hooP0
Soog0?Coo03Ao`2<`?oi09WolP3mooH0POo3ooT0moo/0;Won021oh7ol_om0?So
n02>ooL0mOok097on@2Ioo80oOof087o`ooi0?Ook02iooP0POn1oo;oo@3hooP0
S_og0?Gon`2AooT0VOob0?gomP21ol?on@3gon`0^Ooh087oPOobood0n?oh08ko
m`3eoo/0d_l0S<3on@2Koo80n_of087oa?oi0?Gok02kooL0POn1oo?oo@3hooP0
SOog0?Goo02AooT0Voob0?[omP21olCon@3eon`0^oog087oPOocood0n?oh08go
m`3eoo`0TOoi09_olP3jooH0POo4ooT0mOo/0;_om`21oh7oloom0?Son02=ooL0
mOol0=;o08c0ooT0WOoa0?SomP21olGon@3con`0_?oh087oPOocood0n?oh08co
m`3eoo`0T_oi09gol@3hooH0POo5ooT0loo/0;con021oh7oloom0?Son02<ooL0
mOol09;on@2Moo40n?of087oaOoi0??ok02looP0POn1oo?oo@3hooP0S?og0?Go
o03Co`2<`?oi09kolP3eooL0POo5ooT0lOo[0;oom`21oh7om?om0?Son02<ooH0
mOol09?on@2Noo80mOog087oaOoi0?7oj`2oooL0POn1ooCoo@3hooP0S?of0?Go
o02CooT0W_ob0?Gom`21olGon@3aon/0_oog087oPOodood0n?oh08comP3eoo`0
e?l0S<3on@2Poo40m?of087oaooh0>kok030ooP0POn1ooCoo@3hooP0Roog0?Co
o02DooT0X?oa0?ComP21olOon03^on`0`?oh087oPOodood0n?oh08_om`3doo`0
U?oi0:3ol@3dooH0POo7ooP0k_o/0<3on021oh7om?om0?Son02;ooL0m?ol0=Go
08c0ooT0XOob0?7omP21olSon@3[on`0`Ooh087oPOoeood0n?oh08[om`3doo`0
UOoi0:7olP3aooH0POo8ooT0joo/0<7on021oh7omOom0?Son02:ooL0m?ol09Go
n@2Qoo80lOof087ob?oi0>_ok031ooP0POn1ooGoo@3hooP0R_og0?Coo03Fo`2<
`?oi0:?ol@3_ooH0POo9ooT0jOo/0<?om`21oh7om_om0?Son029ooL0m?ol09Ko
n@2Soo40koof087obOoi0>Wok033ooL0POn1ooKoo@3hooP0ROog0?Coo02FooT0
Xooa0>oomP21olWon@3Yon`0`oog087oPOofood0n?oh08Wom`3doo`0eol0S<3o
n@2Too80k?of087ob_oi0>Ooj`35ooP0POn1ooKoo@3hooP0R?og0?Gon`2GooT0
Y?ob0>comP21ol[on@3Won/0aOoh087oPOofood0n?oh08Som`3eoo/0Uooi0:Co
lP3/ooH0POo:ooT0ioo[0<Gon021oh7om_om0?Son028ooL0mOok0=So08c0ooT0
Y_oa0>[omP21ol_on@3Ton`0aoog087oPOogood0n?oh08Oom`3eoo`0Uooi0:Ko
l@3ZooH0POo;ooT0i?o/0<Oom`21oh7omoom0?Son027ooL0mOol09Oon@2Voo40
j_of087obooi0>Cok037ooL0POn1ooOoo@3hooP0Qoog0?Goo03Ho`2<`?oi0:Oo
lP3WooL0POo;ooT0h_o/0<Som`21oh7on?om0?Son027ooH0mOol09Son@2Woo80
ioog087obooi0>;ok038ooL0POn1ooSoo@3hooP0Qoof0?Goo02HooT0Yoob0>Oo
m`21ol_on@3Ron`0b?og087oPOohood0n?oh08OomP3eoo`0fOl0S<3on@2Yoo40
iOog087oc?oi0>3ok039ooP0POn1ooSoo@3hooP0Q_of0?Goo02IooT0ZOoa0>Go
m`21olcon@3Pon`0bOoh087oPOohood0n?oh08KomP3eoo`0VOoi0:Wol@3UooL0
POo<ooT0h?o/0<Won021oh7on?om0?Son026ooH0mOol0=[o08c0ooT0Z_ob0>?o
mP21olgon@3Non`0boog087oPOoiood0n?oh08Gom`3doo`0V_oi0:[olP3SooH0
POo=ooT0g_o/0<_om`21oh7onOom0?Son025ooL0m?ol09[on@2Zoo80hoof087o
cOoi0=kok03;ooL0POn1ooWoo@3hooP0QOog0?Coo03Ko`2<`?oi0:col@3QooH0
POo>ooT0foo/0<gon021oh7onOom0?Son024ooL0m?ol09_on@2/oo40hOof087o
c_oi0=_ok03=ooP0POn1ooWoo@3hooP0Q?og0?Coo02KooT0[?oa0>7omP21olko
n@3Kon`0cOoh087oPOoiood0n?oh08Com`3doo`0g?l0S<3on@2]oo80g_of087o
cooi0=Wok03>ooP0POn1oo[oo@3hooP0Poog0?Gon`2LooT0[Oob0=komP21oloo
n@3Ion`0c_oh087oPOojood0n?oh08?om`3eoo/0W?oi0:golP3NooH0POo?ooT0
fOo/0<kon021oh7on_om0?Son023ooL0mOok0=go08c0ooT0[oob0=_omP21om3o
n@3Gon`0d?og087oPOokood0n?oh08;om`3eoo`0W?oi0:oolP3KooH0POo@ooT0
eoo/0=3om`21oh7onoom0?Son022ooL0mOol09con@2_oo80foof087od?oi0=Oo
k03@ooL0POn1oo_oo@3hooP0P_og0?Goo03Mo`2<`?oi0;7ol@3IooH0POoAooT0
eOo/0=7on021oh7onoom0?Son021ooL0mOol09gon@2aoo40fOof087odOoi0=Go
k03AooP0POn1oo_oo@3hooP0POog0?Goo02MooT0/Ooa0=WomP21om7on@3Eon`0
dOoh087oPOokood0n?oh087om`3eoo`0g_l0S<3on@2boo80e_og087odOoi0=;o
k03DooL0POn1oocoo@3hooP0POof0?Goo02NooT0/_ob0=Kom`21om7on@3Bon`0
e?og087oPOolood0n?oh087omP3eoo`0W_oi0;;olP3FooL0POoAooT0d_o/0=Co
m`21oh7oo?om0?Son021ooH0mOol0=oo09;0ooT0]?oa0=GomP21om;on@3@on`0
eOog087oPOomood0n?oh087o0?og0?Coo02OooT0]?oa0=GomP21om;on@3@on`0
eOog087oPOomood0n?oh087o0?og0?Coo02OooT0]?oa0=GomP21om;on@3@on`0
eOog087oPOomood0n?oh087o0?og0?Coo03Po`2E`?oi0;GolP3BooH0POoCooT0
c_o/0=Kon021oh7ooOom0?Son021o`7oooL0m?ol0:3on@2eoo80d_of087odooi
0<kok03FooP0POn1oogoo@3hooP0POl1ooog0?Coo02PooT0]Oob0=;omP21om?o
n@3>on`0e_oh087oPOomood0n?oh087o0Ooom`3doo`0hOl0T/3on@2goo40d?of
087oe?oi0<cok03HooL0POn1ookoo@3hooP0POonooL0mOok0:7on@2goo40d?of
087oe?oi0<cok03HooL0POn1ookoo@3hooP0POonooL0mOok0:7on@2goo40d?of
087oe?oi0<cok03HooL0POn1ookoo@3hooP0POonooL0mOok0>;o09;0ooT0^?ob
0<gomP21omKon039on`0f_oh087oPOonood0n?oh087ooOog0?Goo02QooT0^?ob
0<gomP21omKon039on`0f_oh087oPOonood0n?oh087ooOog0?Goo02QooT0^?ob
0<gomP21omKon039on`0f_oh087oPOonood0n?oh087ooOog0?Goo03Ro`2E`?oi
0;[ol@3;ooH0POoGooT0a_o/0=_on021oh7o0Oooo@3hooP0POolooL0mOol0:;o
n@2joo40boof087oeooi0<Kok03KooP0POn1o`7oood0n?oh087oo?og0?Goo02R
ooT0^_oa0<_omP21omOon@36on`0fooh087oPOl1ooom0?Son021oocom`3eoo`0
hol0T/3on@2koo80b?of087of?oi0<Cok03MooL0POn1o`3oo@3hooP0POolooH0
mOol0:?on@2koo80b?of087of?oi0<Cok03MooL0POn1o`3oo@3hooP0POolooH0
mOol0:?on@2koo80b?of087of?oi0<Cok03MooL0POn1o`3oo@3hooP0POolooH0
mOol0>Co09;0ooT0_Ooa0<Kom`21omSon@32on`0g_oh087oPOl0ood0n?oh087o
noog0?Coo02TooT0_Ooa0<Kom`21omSon@32on`0g_oh087oPOl0ood0n?oh087o
noog0?Coo02TooT0_Ooa0<Kom`21omSon@32on`0g_oh087oPOl0ood0n?oh087o
noog0?Coo03Uo`2<`?oi0;kolP34ooH0POoIooT0_oo/0>7om`21oh7oo@3hooP0
POojooL0m?ol0:Gon@2noo80a?of087ofOoi0;ook03QooL0POn1ood0n?oh087o
n_og0?Coo02UooT0__ob0<ComP21omWon@2oon`0hOog087oPOom0?Son021oo[o
m`3doo`0i_l0S<3on@30oo40`_of087of_oi0;gok03RooP0POn1ood0n?oh087o
nOog0?Coo02VooT0`?oa0<;omP21om[on@2mon`0h_oh087oPOom0?Son021ooWo
m`3doo`0Y_oi0<3ol@32ooH0POoJooT0_Oo/0>;on021oh7oo@3hooP0POoiooL0
m?ol0>Oo09_0ooT0`_oa0;oomP21om_on@2kon`0hooh007ooo<0POnBood0n?oh
087on?og0?Gon`2WooT0`_oa0;oomP21om_on@2kon`0hooh007ooo<0POnBood0
n?oh087on?og0?Gon`2WooT0`_oa0;oomP21om_on@2kon`0hooh007ooo<0POnB
ood0n?oh087on?og0?Gon`3Xo`2<`?oi0<?ol@2mooH0POoLooT0^Oo/0>Goh`21
oiOoo@3hooP0POogooL0mOol0:Oon@33oo40_Oof087og?oi0;Wok03Uon<0POnG
ood0n?oh087omoog0?Goo02WooT0`ooa0;gomP21omcon@2ion`0iOoS087oUoom
0?Son021ooOom`3eoo`0j?l0S<3on@35oo40^_of087ogOoi0;Kok03Won80POnI
ood0n?oh087omoof0?Goo02XooT0aOoa0;[omP21omgon@2fon`0iooR087oVOom
0?Son021ooOomP3eoo`0Z?oi0<Gol@2jooH0POoMooT0]_o/0>OohP21oiWoo@3h
ooP0POogooH0mOol0>Wo08c0ooT0a_ob0;OomP21omkon@2don`0jOoP087oVoom
0?Son021ooKomP3eoo`0ZOoi0<KolP2gooH0POoNooT0]?o/0>Woh021oi_oo@3h
ooP0POofooH0mOol0:Won@36oo80]oof087og_oi0;Cok03Yon00POnKood0n?oh
087om_of0?Goo03Zo`2<`?oi0<Sol@2eooL0POoNooT0/_o/0>cog@21oigoo@3h
ooP0POoeooL0m?ol0:[on@38oo40]Oog087og_oi0;;ok03/omd0POnMood0n?oh
087omOog0?Coo02ZooT0b?oa0;Gom`21omkon@2bon`0k?oM087oWOom0?Son021
ooGom`3doo`0jol0S<3on@39oo80/oof087ogooi0;3ok03_omX0POnOood0n?oh
087om?og0?Coo02[ooT0bOob0;?omP21omoon@2`on`0kooJ087oWoom0?Son021
ooCom`3doo`0Zooi0<WolP2cooH0POoOooT0/?o/0>oofP21oiooo@3hooP0POod
ooL0m?ol0>co08c0ooT0booa0;7omP21on3on@2]on`0m?oG087oX?om0?Son021
oo?om`3eoo/0[?oi0<_ol@2aooH0POoPooT0[Oo/0?Coe`21oj3oo@3hooP0POoc
ooL0mOok0:con@3;oo40/Oof087oh?oi0:gok03domL0POnPood0n?oh087oloog
0?Gon`3]o`2<`?oi0<colP2^ooH0POoQooT0Zoo/0?Ooe@21oj7oo@3hooP0POob
ooL0mOol0:con@3<oo80[_of087ohOoi0:_ok03gomD0POnQood0n?oh087ol_og
0?Goo02/ooT0c?ob0:komP21on7on@2[on`0mooE087oXOom0?Son021oo;om`3e
oo`0kOl0S<3on@3>oo40[?of087oh_oi0:Wok03iomD0POnQood0n?oh087olOog
0?Goo02]ooT0c_oa0:comP21on;on@2Yon`0nOoE087oXOom0?Son021oo7om`3e
oo`0[Ooi0<kol@2/ooH0POoRooT0ZOo/0?Woe@21oj7oo@3hooP0POoaooL0mOol
0>ko08c0ooT0coob0:WomP21on?on@2Won`0o?oC087oX_om0?Son021oo7omP3e
oo`0[_oi0<oolP2YooH0POoSooT0Yoo/0?cod`21oj;oo@3hooP0POoaooH0mOol
0:kon@3?oo80ZOof087ohooi0:Ook03lom<0POnRood0n?oh087olOof0?Goo03_
o`2<`?oi0=7ol@2WooL0POoTooT0Xoo/003od@21oj?oo@3hooP0POo`ooL0m?ol
0:oon@3Aoo40Yoog087oi?oi0:?ok000om40POnSood0n?oh087ol?og0?Coo02_
ooT0dOoa0:Oom`21onCon@2Son`00?oA087oXoom0?Son021oo3om`3doo`0l?l0
P<3on@3Boo80Y?og087oiOoi0:7o_021ojCoo@3hooP0POo_ooL0m?ol0;3on@3B
oo80Y?og087oiOoi0:7o_021ojCoo@3hooP0POo_ooL0m?ol0;3on@3Boo80Y?og
087oiOoi0:7o_021ojCoo@3hooP0POo_ooL0m?ol0?7o0830ooT0e?oa0:?omP21
onKon@2Ookd0POnUood0n?oh087ok_og0?Coo02aooT0e?oa0:?omP21onKon@2O
okd0POnUood0n?oh087ok_og0?Coo02aooT0e?oa0:?omP21onKon@2Ookd0POnU
ood0n?oh087ok_og0?Coo03bo`20`?oi0=Kol@2PooH0POoWooT0WOnn087oY_om
0?Son021ongom`3eoo`0/Ooi0=Kol@2PooH0POoWooT0WOnn087oY_om0?Son021
ongom`3eoo`0/Ooi0=Kol@2PooH0POoWooT0WOnn087oY_om0?Son021ongom`3e
oo`0l_l0P<3on@3Goo40W_of087oj?oi09[o`@21ojKoo@3hooP0POo/ooL0mOol
0;;on@3Goo40W_of087oj?oi09[o`@21ojKoo@3hooP0POo/ooL0mOol0;;on@3G
oo40W_of087oj?oi09[o`@21ojKoo@3hooP0POo/ooL0mOol0??o08c0ooT0fOoa
09_omP21onWon@2Hol80k?oj087o`oom0?Son021oncomP3eoo`0/ooi0=Wol@2K
ooH0POoYooT0V?o20>conP21ol?oo@3hooP0POo/ooH0mOol0;?on@3Ioo40Voof
087ojOoi09So`P3/ooX0POo3ood0n?oh087ok?of0?Goo03do`2?`?oi0=[olP2H
ooH0POoZooT0U_o30>oom@21olKoo@01oooa087ojoog0?Coo02dooT0f_ob09So
mP21on[on@2Fol<0kooe087oa_om007ooo40POo[ooL0m?ol0;Con@3Joo80V?of
087oj_oi09Ko``3_ooD0POo6ood00Oool@21on_om`3doo`0mOl0P<3on@3Loo40
U_og087oj_oi09Coa@3aoo80POo7on/0POoZooL0m?ol0;Gon@3Loo40U_og087o
j_oi09Coa@3aoo80POo7on/0POoZooL0m?ol0;Gon@3Loo40U_og087oj_oi09Co
a@3aoo80POo7on/0POoZooL0m?ol0?Ko0830ooT0gOob09?om`21on_on@2BolH0
loo`087ob?oX087ok?og0?Coo02fooT0gOob09?om`21on_on@2BolH0loo`087o
b?oX087ok?og0?Coo02fooT0gOob09?om`21on_on@2BolH0loo`087ob?oX087o
k?og0?Coo03go`2<`?oi0=ool@2BooH0POo/ooT0Too50??on`3koo/0POo;on@0
POo]ooL0mOol0;Kon@3Ooo40T_of087ok?oi09?oa@3coo/0nook087obooT087o
kOog0?Goo02fooT0gooa09;omP21oncon@2ColD0look0?_on`21ol_oi021ongo
m`3eoo`0mol0S<3on@3Poo80Soof087okOoi09?oa@3doo`0n?ol087oc?oR087o
kOog0?Goo02gooT0h?ob08oomP21ongon@2ColD0m?ol0?Soo021olcohP21ongo
m`3eoo`0]ooi0>3olP2?ooH0POo]ooT0Too50?Coo03hoo`0POo<on80POo]ooL0
mOol0?So08c0ooT0h_oa08gomP21onkon@2Dol<0mOom0?Koo021oloogP21onoo
mP3eoo`0^?oi0>;ol@2=ooH0POo^ooT0U?o30?Goo@3foo`0POo?omh0POo_ooH0
mOol0;Son@3Roo40SOof087ok_oi09Co``3eood0m_ol087ocooN087okoof0?Go
o03io`2<`?oi0>?olP2:ooH0POo_ooT0U?o30?Goo@3eood0POoAomX0POo`ooL0
m?ol0;Won@3Soo80R_of087okooi09Co``3eood0mOom087odOoJ087ol?og0?Co
o02iooT0hoob08[omP21onoon@2Dol<0mOom0?Goo@21om7ofP21oo3om`3doo`0
n_l0S<3on@3Uoo40R?of087ol?oi09Co``3foo`0mOom087od_oH087ol?og0?Co
o02jooT0iOoa08SomP21oo3on@2Dol<0m_ol0?Goo@21om;of021oo3om`3doo`0
^_oi0>Gol@28ooH0POo`ooT0U?o30?Koo03eood0POoBomP0POo`ooL0m?ol0?_o
09S0ooT00_oo0>WolP25ooL0POo`ooT0U?o30?Koo@3dood0POoDomD0POo`ooL0
m?ol0;_on@02ool0jOob08Gom`21oo3on@2Dol<0m_om0?Coo@21omCoe@21oo3o
m`3doo`0^ooi00;oo`3Yoo80QOog087ol?oi09Co``3food0m?om087oe?oE087o
l?og0?Coo03lo`2:`?o`0?7ol@23ooL0POobooT0Too30?Koo@3dood0POoEom<0
POo`ooL0mOog0<3ol03aoo40Poog087ol_oi09?o``3food0m?om087oeOoC087o
l?og0?Gom`30oo00lOoa08?om`21oo;on@2Col<0m_om0?Coo@21omGod`21oo3o
m`3eooL007k2onT0n?oa087omP21oo?on@2Eol40m_om0?Coo@21omKod@21oo3o
hP32onT0n?oa087omP21oo?on@2Eol40m_om0?Coo@21omKod@21oo3ohP32onT0
n?oa087omP21oo?on@2Eol40m_om0?Coo@21omKod@21oo3ohP00NlCoi@3koo40
POl1ooof087om?oi0:Wo[@3Voo`0POoFom00POoiomX0a?oU0?_ol@21o`7oooH0
POodooT0ZOn]0>Koo021omKod021ooWofP34onD0nooa087o0OoomP21ooCon@2Y
ojd0i_ol087oe_o@087onOoJ001eaOoR007ooo40POolooH0POoeooT0_?nJ0>Oo
o021omKocP2;olT0aOoR007ooo40POolooH0POoeooT0_?nJ0>Ooo021omKocP2;
olT0aOoR007ooo40POolooH0POoeooT0_?nJ0>Ooo021omKocP2;olT006K7om00
POoiooH0POofooT0d?n60>Son`21omOoc@2KokT0aoo@087onOof087om_oi0=3o
QP3Xoo/0POoGold0Voni0<Ood021ooWomP21ooKon@3@ohH0j?ok087oeoo=09_o
^@00N<Sod021ooOom`21ooKon@3Soh40l`3^ooH0POoGol/0[?nj0?Goo038om00
POogooL0POofooT0hon10?<0k_of087oeoo;0:co^P3eoo`0b?o@087omoog087o
m_oi0>?oP@3c0>komP21omOob`2/okX0mOol0024b_o@087om?og087omooi0?Oo
P@3O0>kon021omGobP2mok/0n_og0?Coo@3:om00POodooL0POogooT0mon10=l0
k_oh087oeOo:0;go^`3jooL0m?om0<[od021ooCom`21ooOon@3goh40g`3^ooP0
POoEolX0_Onk0?[om`3dood007S;om00POocooH0POoioh40c03^ooH0POoHolT0
c_nk0>Som`3eood0boo@087oloof087onOn10<`0k_of087of?o90<ko^`3XooL0
mOom0<_od021oo?omP21ooWoP@3<0>komP21omSob@3>ok/0j?og0?Goo@00L/co
d@21oo3omP2>oh40^03^oo@0POoJolP0gonk0=Oom`3eooh0c?oA087ol?of08ko
P@2h0>kom021om[ob03Ook/0eoog0?GooP3<om40POo`ooH0S_n10;P0k_od087o
f_o80=oo^`3GooL0mOon0024cOoA087ok_of0:;oP@3U007ool<0j?oi087og?o7
0>oo_036ooH0mOl1003=om40POo^ooH0X_n10>D00Ooo``3XooT0POoLolL0konl
0<KomP3eo`400<god@21onkomP2Roh40i@01ooo30>Son@21omcoa`3_ok`0a_of
0?Go0@0007k>om00POo]ooH0]on10>@0k?o30>Goo021omcoaP00okd0]?og0?Co
003>om00POo]ooH0]on10>@0k?o30>Goo021omcoaP00okd0]?og0?Co003>om00
POo]ooH0]on10>@0k?o30>Goo021omcoaP00okd0]?og0?Co0000J<ooc`21onco
mP3;oh40i@3GolD0hool087ogOnB0:;om`32oll0POo/ooH0bon10>D0eoo50>?o
o021omgoTP2RooL0`_o?087ok?of0<_oP@3U0=Ooa@3Soo`0POoMoi80X_og0?Co
07G@old0POo/ooL0gon10>@0a?o50>?oo021omkoXP2@ooL0mol1003@old0POo/
ooL0gon10>@0a?o50>?oo021omkoXP2@ooL0mol1003@old0POo/ooL0gon10>@0
a?o50>?oo021omkoXP2@ooL0mol10000K=7ob`21oncom`3coh40i@2`olD0h_om
087og_nc087oo_o/0=7ob`21oncom`3coh40i@2`olD0h_om087og_nc087oo_o/
0=7ob`21oncom`3coh40i@2`olD0h_om087og_nc087oo_o/001/dOo;087ok?n1
0>00W?o70?Goo@3aood0POoNol<0POolomh0dOo;087ok?n10>00W?o70?Goo@3a
ood0POoNol<0POolomh0dOo;087ok?n10>00W?o70?Goo@3aood0POoNol<0POol
omh007;BolT0POoloh40i@00ooT0TOo70?Goo@3aood0POoNol@0S?o=0=;ob@21
oocoP@3U003on@2AolL0mOom0?7oo@21omkoa02<old0d_o9087oo?n10>D00?oi
097oa`3eood0lOom087og_o408coc@00K=;ob02Aoh40i03^ooT0Soo90?Coo@3a
ood0POoNol@0WOnl0=;ob02Aoh40i03^ooT0Soo90?Coo@3aood0POoNol@0WOnl
0=;ob02Aoh40i03^ooT0Soo90?Coo@3aood0POoNol@0WOnl001/doo70:CoP@3U
0=[on@2>olX0m?ol0?;oo@21omoo`P2^oj`0doo70:CoP@3U0=[on@2>olX0m?ol
0?;oo@21omoo`P2^oj`0doo70:CoP@3U0=[on@2>olX0m?ol0?;oo@21omoo`P2^
oj`006cColH0^On10>@0aooi08kob`3bood0loom087og_o20;ooV`3ColH0^On1
0>@0aooi08kob`3bood0loom087og_o20;ooV`3ColH0^On10>@0aooi08kob`3b
ood0loom087og_o20;ooV`00K=?oaP3<oh40i@2cooT0SOo=0?7oo03eoo`0POoN
ol80d?n:0=?oaP3<oh40i@2cooT0SOo=0?7oo03eoo`0POoNol80d?n:0=?oaP3<
oh40i@2cooT0SOo=0?7oo03eoo`0POoNol80d?n:001ee?o50>3oP@3T0:3on@2=
old0lOok0?Oon`21omko`P3Poh40o03BolD0h?n10>@0X?oi08goc@3aoo/0mook
087og_o20>3oP@3l0=;oa@3Poh40i02PooT0SOo=0?7on`3goo/0POoNol80h?n1
0?`00Ooo083Dol@0m?n10>D0S?oi08coc`3_oo/0n_oj087ogOo20?7oP@3k0?ko
mP3@ol@0m?n10>D0S?oi08coc`3_oo/0n_oj087ogOo20?7oP@3k0?komP3@ol@0
m?n10>D0S?oi08coc`3_oo/0n_oj087ogOo20?7oP@3k0?komP3mo`1[e?n10:h0
0OoomP26ooT0RooA0>gok`21omcoP@2m0>comP3Aoh40[P01ooof08Kon@2;om40
kOo_087og?n10;d0k?of0=7oP@2^007oooH0Q_oi08_od@3]onl0POoLoh40_@3/
ooH0o_l0J=CoP@320>[omP27ooT0S?oA0>_ol@21om[oP@3?0=[om`3Aoh40`P3Z
ooH0Qooi08cod@3[oo40POoJoh40c`3JooL0dOn10<80j_of08Oon@2<om40jooa
087of_n10<l0f_og0?ko06WDoh40e@3FooH0R?oi08god@3Yoo@0POoHoh40g`39
ooL0d_n10=D0e_of08Son@2=om40jOod087of?n10=l0bOog0=;oP@3E0=KomP28
ooT0SOoA0>Wom021omSoP@3O0<Wom`01ool0J=CoP@3Y0<7om`28ooT0S_oA0>Ko
n021omKoP@3`0;Oom`3Coh40j@31ooL0R?oi08kod@3VooP0POoFoh40l02gooL0
don10>T0`Oog08Son@2>om40i_oh087oe_n10?00]oog003o05CEoh40n`2]ooL0
ROoi08oodP21ok3oP@2UooL0eOn10?/0[Oog08Won@2?om80POn`oh40YOog0=Go
P@3k0:gom`29ooT0SooB087o/?n10:Gom`00F]GoS`2HooL0R_oi08oom`00oml0
POn^oi80Tooh0=GoS`2HooL0R_oi08oom`00oml0POn^oi80Tooh0=GoS`2HooL0
R_oi08oom`00oml0POn^oi80Tooh001YeOnR08GomP2;ooT0T?og007ooml0POo1
ooh0l?nS08?on03Eoj80QOof08_on@2@ooL00Ooog`21ol7ooP3`oj<0Pooh0=Go
XP25ooH0Rooi093om`01oooO087o`Oon0?3oX`23ooP007;EokH0POo`ooH0S?oi
097om`3lon<0POnoooh0l?nd087olOoi0=Go]P21oo3omP2<ooT0TOog0?coh`21
okoooP3`ok@0POoaooT0eOnf087ol?of08con@2AooL0o?oS087o_oon0?3o]021
oo7on@00L]Go`P21on?omP2=ooT0T_og0?Soj@21okgoo@3`okX0POoZooX0eOo2
087ohoof08gon@2BooL0n?oY087o_Oom0?3o^P21on[onP3Eol80POoSooH0SOoi
09;om`3honT0POnmood0l?nj087oj_oj001be?o3087oh_of08oon@2BooL0m?o^
087o^oom0?3o]`21oncon`3Dol<0POoRooH0Sooi09;om`3donh0POnkood0l?ng
087ok?ok0=Co``21on;omP2?ooT0T_og0?CokP21ok_oo@3`okL0POo/oo/007;[
ooh0kOo4087oh?og08oon@2CooH0POnLoo`0konf087okOol0>_ooP3]ol@0POoP
ooL0Sooi09?omP21oicoo03_okH0POo]oo`0joon0>goa021on3om`2?ooT0Toof
087oW?ol0>oo]P21ongoo000PN_ooP3]ol@0POoOooL0T?oi09ComP21oicon`3_
olT00OookP21onkoo@3[ooh0kOo4087ogoog093on@2DooH0POnLoo/0koo9007o
onh0POo^ood0joon0>goa021omoom`2@ooT0U?of087oW?ok0>oob@01ooo^087o
k_om001nk?om0>goa021omkom`2AooT0UOof087oWoog0>kobP3monh0POo`ood0
k?om0>goa021omkom`2AooT0UOof087oWoog0>kobP3monh0POo`ood0k?om0>go
a021omkom`2AooT0UOof087oWoog0>kobP3monh0POo`ood007k/ood0kOo4087o
g_of09;on@2EooL0POnQoo@0kOo<0?[okP21oo7ooP3/ood0kOo4087og_of09;o
n@2EooL0POnQoo@0kOo<0?[okP21oo7ooP3/ood0kOo4087og_of09;on@2EooL0
POnQoo@0kOo<0?[okP21oo7ooP00PNgoo03]olD0POoLooH0Tooi09Kom`21oj3o
m03]old0moo^087ol_l1003]oo`0kOo5087og?of09?on@2FooL0POnPoo@0kOo=
0?OokP21oo;o0@00kOol0>goa@21omcomP2CooT0U_og087oX?od0>goc@3gonh0
POobo`40001nk_ok0>coaP21om_omP2DooT0Uoog087oWood0>coc`3donh0POoc
o`00k_ok0>coaP21om_omP2DooT0Uoog087oWood0>coc`3donh0POoco`00k_ok
0>coaP21om_omP2DooT0Uoog087oWood0>coc`3donh0POoco`0007CbooL0k?o6
087of_of09Gon@2HooL0POnEood0joo@0?7ok`21onGom`3/olH0POoJooH0UOoi
09Som`21oiGoo@3[om00lOo_087oiOog0>coaP21om[omP2EooT0V?og087oUOom
0>_od03aonl0POodo`1dmOod0>coa`21omSom`2EooT0VOog087oU?om0>[odP3^
onl0POoZoo@0k?o7087of?og09Gon@2IooL0POnDood0j_oB0>kok`21on[om03/
olL0POoHooL0UOoi09Wom`21oiCoo@3Zom80k_o_087om_l0M?Gom03/olL0POoG
ooL0U_oi09[omP21oiCoo@3YomD0j_o^087okOod0>coa`21omOom`2FooT0V_of
087oU?om0>Woe@3Zonh0POo]oo@0k?o7087oeoog09Kon@2JooH0POnDood0jOoE
0>[okP21ooWo07Ceoo@0joo9087oeOog09Oon@2KooH0POnCood0j?oF0>SokP21
onoom03[olT0POoEooL0Uooi09_omP21oi?oo@3XomH0j?o^087okood0>_ob@21
omGom`2GooT0Voof087oToom0>SoeP3Xonh0POoko`1dk?om0>[obP21omGomP2H
ooT0Voog087oT_om0>Koe`3Wonh0POoXood0j_o:087oeOof09Son@2KooL0POnB
ood0i_oG0>OokP21onSoo@3ZolX0POoEooH0V?oi09_om`21oi;oo@3VomL0ioo^
087ooOl0MNcoo@3Zol/0POoCooH0VOoi09com`21oi7oo@3UomH0ioo^087oj_om
0>[ob`21om?omP2IooT0W?og087oTOom0>GoeP3Wonh0POoZood0j_o;087odoof
09Won@2LooL0POnAood0iOoF0>OokP21o`7oo`1bk?om0>Wob`21om?omP2JooT0
WOog087oT?om0>Coe@3Wonh0POo/ood0jOo;087odoof09[on@2MooL0POn@ood0
i?oE0>OokP21oncoo@3Yol/0POoCooH0V_oi09gom`21oi3oo@3TomD0ioo^087o
07k/ood0j?o:087oe?of09_on@2NooL0POn?ood0h_oR0?con@3Wonh0POo^ood0
j?o:087oe?of09_on@2NooL0POn?ood0h_oR0?con@3Wonh0POo^ood0j?o:087o
e?of09_on@2NooL0POn?ood0h_oR0?con@3Wonh0Pol0O^coo@3WolT0POoEooL0
Vooi09oom`21ohkoo@3PonH0n?oi0>OokP21oo3oo@3WolT0POoEooL0Vooi09oo
m`21ohkoo@3PonH0n?oi0>OokP21oo3oo@3WolT0POoEooL0Vooi09oom`21ohko
o@3PonH0n?oi0>OokP25o`1nk?om0>Koa`21omOom`2MooT0Woof087oS_om0=oo
j@3dooT0i_o_087ol_om0>Koa`21omOom`2MooT0Woof087oS_om0=ooj@3dooT0
i_o_087ol_om0>Koa`21omOom`2MooT0Woof087oS_om0=ooj@3dooT0i_o_08Oo
07k/ood0i_o5087ofOof09kon@2PooH0POn=ood0fOod0>gon@3Vonl0POodood0
i_o5087ofOof09kon@2PooH0POn=ood0fOod0>gon@3Vonl0POodood0i_o5087o
fOof09kon@2PooH0POn=ood0fOod0>gon@3Vonl0ROl0L^coo@3Uol@0POoJooH0
Wooi0:3om`21ohcoo@2fooT0i_o^087omoom0>Goa021om[omP2OooT0X?og087o
S?om0;Kon@3Vonh0POogood0iOo4087of_of09oon@2PooL0POn<ood0]_oi0>Ko
kP2<o`1bk?om0>?oa021om_omP2PooT0XOog087oRoom0;Con03Wonh0POoiood0
hoo4087ofoof0:3on@2QooL0POn;ood0]?oh0>OokP21ooWoo@3Sol@0POoKooH0
X?oi0:7om`21oh_oo@2dooP0ioo^08ko07k/ood0hOoL0?kok021omcomP2QooT0
X_og087oR_om0;;on03Wonh0POokood0hOoL0?kok021omcomP2QooT0X_og087o
R_om0;;on03Wonh0POokood0hOoL0?kok021omcomP2QooT0X_og087oR_om0;;o
n03Wonh0T?l0O^coo@3Pomh0noo/087ogOog0:7on@2SooL0POn9ood0/?oh0>Oo
kP21oogoo@3Pomh0noo/087ogOog0:7on@2SooL0POn9ood0/?oh0>OokP21oogo
o@3Pomh0noo/087ogOog0:7on@2SooL0POn9ood0/?oh0>OokP2Bo`20k?om0>3o
g`3hon`0POoNooL0X_oi0:Com`21ohSoo@2]ooT0ioo^087o0Oooo@3Poml0n?o/
087og_og0:;on@2TooL0POn8ood0[Ooi0>OokP21o`7oood0h?oO0?Sok021omko
m`2RooT0Y?og087oR?om0:gon@3Wonh0U?l0N^coo@3Mon@0m?o/087ogoog0:?o
n@2UooH0POn8ood0Zooi0>OokP21ood0gOoT0?Cok021omoom`2SooT0YOof087o
R?om0:_on@3Wonh0POom0=goi03don`0POoOooL0Xooi0:GomP21ohSoo@2[ooT0
ioo^09Ko07[/ood0fooY0>kok@21on7omP2TooT0Y_of087oQoom0:Won@3Wonh0
Poom0=_oj@3^ond0POoQooH0Y?oi0:KomP21ohOoo@2YooT0ioo^08?oo@3KonT0
k_o]087ohOof0:Con@2VooH0POn7ood0ZOoi0>OokP2Ho`1jk?om0=SokP3Zon`0
POoSooH0YOoi0:OomP21ohKoo@2WooT0i_o_08Goo@3Honh0j_o/087ohoof0:Go
n@2WooH0POn6ood0Yooi0>Kok`25ood0f?o^0>[ok021on?omP2UooT0Yoof087o
Q_om0:Oon@3Vonl0V_l0K^coo@2/on`0POoTooH0Y_oi0:Oom`21ohGoo@2UooP0
ioo_08Ooo@2/on`0POoTooH0Y_oi0:Oom`21ohGoo@2UooP0ioo_08Ooo@2/on`0
POoTooH0Y_oi0:Oom`21ohGoo@2UooP0ioo_09co06k/ood0Z_o/087oiOof0:Oo
n@2XooL0POn4ood0Xooh0>OokP2:ood0Z_o/087oiOof0:Oon@2XooL0POn4ood0
Xooh0>OokP2:ood0Z_o/087oiOof0:Oon@2XooL0POn4ood0Xooh0>OokP2Oo`1^
k?om0:Sok021onKom`2WooT0ZOog087oPoom0:7on03Wonh0S?om0:Sok021onKo
m`2WooT0ZOog087oPoom0:7on03Wonh0S?om0:Sok021onKom`2WooT0ZOog087o
Poom0:7on03Wonh0XOl0K^coo@2Von`0POoWooL0Z?oi0:[om`21oh;oo@2NooT0
ioo^08koo@2Von`0POoWooL0Z?oi0:[om`21oh;oo@2NooT0ioo^08koo@2Von`0
POoWooL0Z?oi0:[om`21oh;oo@2NooT0ioo^0:?o06k/ood0Y?o/087oj?og0:Wo
n@2[ooL0POn1ood0W?oi0>OokP2@ood0Y?o/087oj?og0:Won@2[ooL0POn1ood0
W?oi0>OokP2@ood0Y?o/087oj?og0:Won@2[ooL0POn1ood0W?oi0>OokP2Uo`1^
k?om0:;ok021on[omP2[ooT0Zoof087oPOom09[on@3Wonh0T_om0:;ok021on[o
mP2[ooT0Zoof087oPOom09[on@3Wonh0T_om0:;ok021on[omP2[ooT0Zoof087o
POom09[on@3Wonh0Yol0J>coo@2Pon`0POo[ooH0[?oi0:comP21oh7oTooi0>Oo
kP2Dood0X?o/087ojoof0:con@2/ooH0POn1oi?on@3Wonh0U?om0:3ok021on_o
mP2/ooT0[?of087oPOnCooT0ioo^0:Wo06S/ood0WOo]087ok?of0:gon@2/ooL0
POn1oi3on03Xonh0U_om09gok@21oncomP2]ooT0[?og087oPOn@ooP0j?o^09Ko
o@2Mond0POo/ooH0[Ooi0:com`21oh7oT?oh0>SokP2[o`1Xk?om09_ok021onko
mP2^ooT0[Oog087oPOn=ooP0ioo_09Soo@2Kon`0POo^ooH0[_oi0:gom`21oh7o
SOoh0>Ook`2Hood0Voo/087ok_of0:kon@2]ooL0POn1ohgon03Wonl0[Ol0J>co
o@2Ion`0POo_ooL0[_oi0:kom`21oh7oR_oh0>Ook`2Jood0VOo/087okoog0:ko
n@2^ooL0POn1oh[on03Wonl0V_om09Wok021onoom`2^ooT0[_og087oPOn:ooP0
ioo_0:oo06:1ookok021oo3om`2_ooT0[oog087oPOn6ooT0ioo^087o[oo/087o
l?og0:oon@2_ooL0POn1ohKon@3Wonh0POn_on`0POo`ooL0[ooi0:oom`21oh7o
Q_oi0>OokP2bo`1RPOolon`0POoaooL0/?oi0;3om`21oh7oPooi0>OokP21ojoo
k021oo7om`2`ooT0/?og087oPOn3ooT0ioo^087o[oo/087olOog0;3on@2`ooL0
POn1oh?on@3Wonh0]?l0HX7on_o/087oloof0;7on@2aooH0POn1oh7on@3Wonh0
POn_on`0POocooH0/Ooi0;7omP21oh7oPOoi0>OokP21ojook021oo?omP2aooT0
/Oof087oPOn1ooT0ioo^0;Ko06R1ooSok021ooComP2booT0/_of087oPOn1ooko
n@3Wonh0POn_on`0POodooH0/_oi0;;omP21oh7oPOonooT0ioo^087o[oo/087o
m?of0;;on@2booH0POn1oh7oo_oi0>OokP2ho`1XPOofon`0POoeooH0/ooi0;;o
m`21oh7oPOokooT0ioo^087o[oo/087omOof0;?on@2booL0POn1oh7onooi0>Oo
kP21ojook021ooGomP2cooT0/_og087oPOn1oo_on@3Wonh0^_l0J87om?o/087o
m_og0;?on@2cooL0POn1oh7on?oh0>SokP21ojook021ooKom`2cooT0/oog087o
POn1ooSon03Xonh0POn_on`0POofooL0/ooi0;?om`21oh7oPOohooP0j?o^0;co
06R1oo7ok@21ooOom`2dooT0]?og087oPOn1ooGon03Xonh0POn^ond0POogooL0
]?oi0;Com`21oh7oPOoeooP0j?o^087o[_o]087omoog0;Con@2dooL0POn1oh7o
mOoh0>SokP2no`1XPOo_on`0POoiooL0]Ooi0;Gom`21oh7oPOobooP0ioo_087o
[_o/087onOog0;Gon@2eooL0POn1oh7ol_oh0>Ook`21ojkok021ooWom`2eooT0
]Oog087oPOn1oo;on03Wonl0`?l0J87okOo/087on_og0;Kon@2fooL0POn1oh7o
k_oi0>Ook`21ojkok021oo[om`2fooT0]_og087oPOn1onkon@3Wonl0POn^on`0
POojooL0]_oi0;Kom`21oh7oPOo^ooT0ioo_0<;o06R1on_ok021oocomP2gooT0
]oof087oPOn1oncon@3Wonh0POn_on`0POolooH0]ooi0;OomP21oh7oPOo/ooT0
ioo^087o[oo/087oo?of0;Oon@2gooH0POn1oh7ok?oi0>OokP35o`1XPOoYon`0
POomooH0^?oi0;SomP21oh7oPOoYooT0ioo^087o[oo/087ooOof0;Son@2hooH0
POn1oh7ojOoi0>OokP21ojook021oogomP2hooT0^?of087oPOn1onWon@3Wonh0
aol0J87oioo/087oo_of0;[on@2hooH0POn1oh7oi_oi0>OokP21ojook021ooko
mP2jooT0^?of087oPOn1onKon@3Wonh0POn_on`0POonooH0^_oi0;SomP21oh7o
POoVooT0ioo^0<Wo06^1onGok021o`7oooL0^_oi0;Som`21oh7oPOoSooP0j?o^
087o[oo/087o0Ooom`2jooT0^?og087oPOn1on?on03Xonh0POn_on`0POl1ooog
0;[on@2hooL0POn1oh7ohooh0>SokP3;o`1XPOoSon`0POl0ooL0^ooi0;Wom`21
oh7oPOoPooP0j?o^087o[oo/087o0?og0;_on@2iooL0POn1oh7oh?oh0>SokP21
ojook021o`3om`2kooT0^Oog087oPOn1on3on03Xonh0cOl0HX7ohOo/087om`2l
ooT0^_og087oPOn1omgon03Xonh0POn_on`0POog0;con@2jooL0POn1oh7ogOoh
0>SokP21ojook021ooL0_?oi0;[om`21oh7oPOoMooP0j?o^0<oo06:1omkok@22
ooL0_Ooi0;_om`21oh7oPOoIooT0j?o^087o[_o]08;om`2mooT0^oog087oPOn1
omWon@3Xonh0POn^ond0P_og0;gon@2kooL0POn1oh7ofOoi0>SokP3Ao`1RPOoL
on`0QOof0;kon@2looL0POn1oh7oe_oi0>Ook`21ojkok025ooH0__oi0;com`21
oh7oPOoFooT0ioo_087o[_o/08GomP2nooT0_?og087oPOn1omKon@3Wonl0dol0
HX7of_o/08KomP2oooT0_Oof087oPOn1omCon@3Wonl0POn^on`0Q_of0;oon@2m
ooH0POn1oh7oe?oi0>Ook`21ojkok026ooH0_ooi0;gomP21oh7oPOoDooT0ioo_
0=Go06:1omSok027ooH0`?oi0;komP21oh7oPOoAooT0ioo^087o[oo/08OomP30
ooT0__of087oPOn1om7on@3Wonh0POn_on`0Qoof0<3on@2nooH0POn1oh7odOoi
0>OokP3Ho`1RPOoFon`0R?og0<3on@2nooL0POn1oh7oc_oh0>SokP21ojook028
ooL0`?oi0;kom`21oh7oPOo>ooP0j?o^087o[oo/08Som`30ooT0__og087oPOn1
olkon03Xonh0f_l0HX7oe?o/08Wom`31ooT0_oog087oPOn1ol_on03Xonh0POn_
on`0ROog0<7on@2oooL0POn1oh7obooh0>SokP21ojook029ooL0`Ooi0;oom`21
oh7oPOo;ooP0j?o^0=co06:1om;ok02:ooL0`_oi0<3om`21oh7oPOo8ooP0j?o^
087o[oo/08[om`32ooT0`?og087oPOn1olSon03Xonh0POn_on`0R_og0<;on@30
ooL0POn1oh7ob?oh0>SokP3No`1RPOo@on`0S?of0<?on@31ooL0POn1oh7oa?oi
0>SokP21ojook02<ooH0`ooi0<7om`21oh7oPOo4ooT0j?o^087o[oo/08comP33
ooT0`Oog087oPOn1olCon@3Xonh0h?l0HX7oc_o/08gomP34ooT0`_og087oPOn1
ol7on@3Xonh0POn_on`0SOof0<Con@32ooL0POn1oh7o`Ooi0>SokP21ojook02=
ooH0a?oi0<;om`21oh7oPOo1ooT0j?o^0>;o06:1ol_ok@2>ooH0aOoi0<?omP21
oh7oPOnoooT0j?o^087o[_o]08komP35ooT0`oof087oPOn1okoon@3Xonh0POn^
ond0S_of0<Gon@33ooH0POn1oh7o_ooi0>SokP3To`1RPOo9on`0T?of0<Kon@34
ooH0POn1oh7o_?oi0>Ook`21ojkok02@ooH0a_oi0<ComP21oh7oPOnlooT0ioo_
087o[_o/093omP36ooT0a?of087oPOn1okcon@3Wonl0i_l0HX7oaoo/097om`37
ooT0`oog087oPOn1okWon@3Wonl0POn^on`0TOog0<Oon@33ooL0POn1oh7o^Ooi
0>Ook`21ojkok02AooL0aooi0<?om`21oh7oPOniooT0ioo_0>So06:1olGok02B
ooL0b?oi0<Com`21oh7oPOnfooP0j?o_087o[_o/09;om`38ooT0a?og087oPOn1
okKon03Xonl0POn^on`0T_og0<Son@34ooL0POn1oh7o]_oh0>Sok`3Zo`1RPOo3
on`0Toog0<Won@35ooL0POn1oh7o/ooh0>SokP21ojook02CooL0bOoi0<Gom`21
oh7oPOncooP0j?o^087o[oo/09?om`39ooT0aOog087oPOn1ok?on03Xonh0kOl0
HX7o`Oo/09GomP3:ooT0a_og087oPOn1ok3on03Xonh0POn_on`0UOof0<[on@36
ooL0POn1oh7o/?oh0>SokP21ojook02EooH0b_oi0<Kom`21oh7oPOn`ooP0j?o^
0>oo06:1okook02FooH0booi0<Oom`21oh7oPOn/ooT0j?o^087o[oo/09KomP3;
ooT0aoog087oPOn1ojcon@3Xonh0POn_on`0U_of0<_on@37ooL0POn1oh7o[?oi
0>SokP3ao`1RPOnmon`0Uoof0<con@38ooH0POn1oh7oZ_oi0>SokP21ojook02G
ooH0c?oi0<SomP21oh7oPOnZooT0j?o^087o[oo/09OomP3<ooT0b?of087oPOn1
oj[on@3Xonh0lol0HX7o^oo/09Som`3<ooT0bOof087oPOn1ojOon@3Xonh0POn_
on`0V?og0<con@39ooH0POn1oh7oYooi0>SokP21ojook02HooL0c?oi0<WomP21
oh7oPOnWooT0j?o^0?Go06R1okSok@2IooL0cOoi0<[omP21ohOooP21oj7on@3X
onh0POn^ond0VOog0<gon@3:ooH0POn7ooh0POnQooT0j?o^087o[_o]09Wom`3=
ooT0b_of087oQoon087oXOoi0>SokP3go`1XPOnfon`0Voog0<kon@3:ooL0POn6
oo`0POnQooP0jOo^087o[_o/09_om`3>ooT0b_og087oQ_ol087oXOoh0>WokP21
ojkok02KooL0c_oi0<[om`21ohKoo021oj7on03Yonh0nOl0J87o]?o/09com`3?
ooT0boog087oQOoi087oX_oh0>Sok`21ojkok02LooL0cooi0<_om`21ohGon@21
oj;on03Xonl0POn^on`0W?og0<oon@3;ooL0POn5ooT0POnRooP0j?o_0?_o06R1
ok;ok02NooH0d?oi0<com`21ohComP21oj?on03Xonl0POn^on`0W_of0=3on@3<
ooL0POn4ooH0POnSooP0j?o_087o[_o/09komP3@ooT0c?og087oQ?of087oXooh
0>Sok`3mo`1XPOn`on`0Woof0=7on@3=ooL0POn3oo<0POnSooT0j?o^087o[oo/
09oomP3AooT0cOog087oPooc087oXooi0>SokP21ojook02OooH0dOoi0<gom`21
oh?ol`21oj?on@3Xonh00?l0IX7o[_o/0:3omP3BooT0c_og087oP_oa087oXooi
0>Sok`21ojkok02PooH0d_oi0<kom`21oh;ol@21oj?on@3Xonl0POn^on`0X?of
0=;on@3>ooL0POn2oo40POnSooT0j?o_001VPOn/on`0XOog0=;on@3?ooH0POn2
onh0POnTooT0j?oa087o[?o/0:7om`3BooT0coof087oP_o^087oY?oi0>Sol@21
ojcok02QooL0d_oi0<oomP21oh;okP21ojCon@3Xoo4006J1oj[ok02RooL0dooi
0=3omP21oh7oj`21ojGon@3Xoo<0POnZon`0X_og0=?on@3@ooH0POn1on/0POnU
ooT0j?oc087oZ_o/0:;om`3CooT0d?of087oPOo[087oYOoi0>Sol`00K87oZ?o/
0:?om`3DooT0d?og087oPOl0onT0POnUooP0jOoe087oZ?o/0:?om`3DooT0d?og
087oPOl0onT0POnUooP0jOoe087oZ?o/0:?om`3DooT0d?og087oPOl0onT0POnU
ooP0jOoe001_POnUond0Y?og0=Kon@3@ooL0POn1o`7oonH0POnVooP0jOog087o
YOo]0:Com`3FooT0d?og087oPOl1oooV087oY_oh0>Wom`21ojGok@2TooL0e_oi
0=3om`21oh7o0OooiP21ojKon03YooL006b1oj?ok@2VooH0eooi0=7om`21oh7o
o_oS087oYooh0>Won@21oj?ok@2VooH0eooi0=7om`21oh7oo_oS087oYooh0>Wo
n@21oj?ok@2VooH0eooi0=7om`21oh7oo_oS087oYooh0>Won@00K87oXOo/0:So
mP3HooT0d_og087oPOomon00POnWooT0j?ol087oXOo/0:SomP3HooT0d_og087o
POomon00POnWooT0j?ol087oXOo/0:SomP3HooT0d_og087oPOomon00POnWooT0
j?ol001/POnOon`0ZOof0=Won@3CooL0POomoh40g@21ojOon@3Xooh0POnOon`0
ZOof0=Won@3CooL0POomoh40g@21ojOon@3Xooh0POnOon`0ZOof0=Won@3CooL0
POomoh40g@21ojOon@3Xooh006b1oigok02ZooL0fOoi0=ComP21oogoP@3J087o
Z?oi0>So0021oigok02ZooL0fOoi0=ComP21oogoP@3J087oZ?oi0>So0021oigo
k02ZooL0fOoi0=ComP21oogoP@3J087oZ?oi0>So0000HX7oVoo/0:_om`3JooT0
eOof087oo?n10=L0POnYooT0POn3on`0Zoog0=[on@3EooH0POoloh40e`21ojWo
n@21oh?ok02[ooL0f_oi0=GomP21oocoP@3G087oZOoi0>Wo06:1oiWok02/ooL0
fooi0=Gom`21oo_oP@3E087oZOoi087oPoo/0:com`3KooT0eOog087onon10=D0
POnYooT0POn3on`0[?og0=_on@3EooL0POokoh40e@21ojWon@3[o`1RPOnGon`0
[Oog0=con@3FooL0POn1ooWod`21oj[on021ohCok02]ooL0g?oi0=Kom`21oh7o
nOoC087oZ_oh087oQ?o/0:gom`3LooT0e_og087oPOoiom<0POnZooP0k_l0HX7o
UOo/0:oomP3MooT0eoog087oPOohomH0POnUooP0POn4on`0[oof0=gon@3GooL0
POn1ooSoeP21ojGon021ohCok02_ooH0gOoi0=Oom`21oh7on?oF087oYOoh0?3o
06:1oi?ok02`ooH0g_oi0=Som`21oh7omooI087oX?oh087oQ?o/0;3omP3NooT0
f?og087oPOogomT0POnPooP0POn4on`0/?of0=kon@3HooL0POn1ooOof@21oj3o
n03bo`1RPOn@ond0/Oog0=kon@3IooL0POn1ooKog021oi[on@21oh?ok@2aooL0
g_oi0=Wom`21oh7om_oL087oV_oi087oPoo]0;7om`3NooT0fOog087oPOofom`0
POnJooT0m?l0HX7oS_o/0;?om`3OooT0f_of087oPOofomh0POnFooT0POn3on`0
/oog0=oon@3JooH0POn1ooKogP21oiKon@21oh?ok02cooL0gooi0=[omP21oh7o
m_oN087oU_oi0?Ko06:1ohcok02dooL0h?oi0=_omP21oh7omOoQ087oTOoi087o
Poo/0;Com`3PooT0foof087oPOoeon40POnAooT0POn3on`0]?og0>3on@3KooH0
POn1ooGoh@21oi7on@3ho`1RPOn:on`0]Oog0>7on@3LooH0POn1ooCoi021ohco
n@21oh?ok02eooL0hOoi0=comP21oh7om?oT087oS?oi087oPoo/0;Gom`3QooT0
g?of087oPOodon@0POn<ooT0n_l0HX7oR?o/0;OomP3RooT0g?og087oPOoconL0
POn7ooP0POn4on`0]oof0>;on@3LooL0POn1oo?oi`21ohOon021ohCok02gooH0
h_oi0=com`21oh7olooW087oQooh0?go06>1ohKok02hooH0i?oi0=com`21oh7o
l_oZ087oP_oh087oQ?o/0;SomP3TooT0g?og087oPOobonX0POn2ooP0POn4on`0
^?of0>Con@3LooL0POn1oo;ojP21oh;on001ool0IX7oQ?o/0;WomP3UooT0gOog
087oPOoaond0POn1oogon021ohCok02iooH0iOoi0=gom`21oh7olOo]087oPOom
ooP0POn4on`0^Oof0>Gon@3MooL0POn1oo7ok@21oh7ooOoh001VPOn2on`0^_og
0>Gon@3NooL0POn1oo3ol021oh7omook087oP_o/0;[om`3UooT0g_og087oPOo`
oo00POn1ooOon`21oh;ok02jooL0iOoi0=kom`21oh7ol?o`087oPOogoo/006b1
oh7o0?o/0;_om`3VooT0goog087oPOo_oo<0POn1oo;oo@21oh7o0?o/0;_om`3V
ooT0goog087oPOo_oo<0POn1oo;oo@21oh7o0?o/0;_om`3VooT0goog087oPOo_
oo<0POn1oo;oo@00Kh7oPOomond0_?og0>Oon@3PooH0POn1onoom@21oh7ok_l1
0021oh7ooOo]0;com`3WooT0h?of087oPOo_ooD0POn1onko0@00POn1oogok@2l
ooL0iooi0>3omP21oh7okooe087oPOo^o`40001RPOn1oo_ok02nooL0j?oi0>7o
mP21oh7ok_oh087oPOn1oh7ohoo/0;kom`3XooT0hOof087oPOo^ooP0POn1oh7o
POoSon`0__og0>Son@3QooH0POn1onkon021oh7ojOl0HX7oPOoion`0`?of0>Wo
n@3QooL0POn1ongon`21oh7oPOn1omkok030ooH0jOoi0>7om`21oh7okOok087o
POn1oh7og_o/0<3omP3YooT0hOog087oPOo]oo/0POn1onKo06:1oh7omoo/0<7o
mP3ZooT0h_og087oPOo/ooh0POn1oh7oPOoIon`0`Oof0>[on@3RooL0POn1onco
oP21oh7oPOn1omWok031ooH0j_oi0>;om`21oh7ok?on087oPOoSo`1FPOn1ooGo
k032ooH0jooi0>?om`21oh7oPOn1oh7oPOnnon`0`_of0>_on@3SooL0POn1oh7o
POn1oh7o__o/0<;omP3[ooT0hoog087oPOn1oh7ob_l0EX7oPOocon`0`oog0>_o
n@3TooL0POn1oh7oPOn1oh7o^oo/0<?om`3[ooT0i?og087oPOn1oh7oPOn1ok_o
k033ooL0jooi0>Com`21oh7oPOn1olWo05J1oh7olOo/0<Com`3/ooT0iOog087o
POn1oh7oPOn1okSok034ooL0k?oi0>Gom`21oh7oPOn1oh7oPOnhon`0a?og0>co
n@3UooL0POn1oh7oPOo8o`1FPOn1onook035ooL0kOoi0>KomP21oh7oPOn1oh7o
POnfon`0aOog0>gon@3VooH0POn1oh7oPOn1oh7o]_o/0<Gom`3]ooT0i_of087o
POn1oh7ob?l0EX7oPOo]on`0a_og0>kon@3WooH0POn1oh7oPOn1oh7o/oo/0<Ko
m`3^ooT0ioof087oPOn1oh7oPOn1ok?ok036ooL0k_oi0>OomP21oh7oPOn1olOo
05J1oh7oj_o]0<SomP3_ooT0ioog087oPOn1oh7oPOn1ojook@38ooH0kooi0>Oo
m`21oh7oPOn1oh7oPOn_ond0b?of0>oon@3WooL0POn1oh7oPOo6o`1FPOn1onSo
k03:ooH0l?oi0>Som`21oh7oPOn1oh7oPOn/on`0b_of0?3on@3XooL0POn1oh7o
POn1oh7o[?o/0<[omP3`ooT0j?og087oPOn1oh7oaOl0EX7oPOoVon`0boof0?7o
n@3YooL0POn1oh7oPOn1oh7oZOo/0<_omP3aooT0jOog087oPOn1oh7oPOn1ojWo
k03;ooH0lOoi0>Wom`21oh7oPOn1olCo05J1oh7oi?o/0<com`3booT0jOog087o
POn1oh7oPOn1ojKok03<ooL0l_oi0>Wom`21oh7oPOn1oh7oPOnVon`0c?og0?;o
n@3YooL0POn1oh7oPOo3o`1FPOn1on;ok03=ooL0looi0>[om`21oh7oPOn1oh7o
POnSon`0cOog0??on@3ZooL0POn1oh7oPOn1oh7oXoo/0<gom`3cooT0j_og087o
POn1oh7o`_l0EX7oPOoPon`0c_og0?Con@3[ooH0POn1oh7oPOn1oh7oXOo/0<ko
m`3dooT0joof087oPOn1oh7oPOn1oj7ok03>ooL0m?oi0>_omP21oh7oPOn1ol;o
05J1oh7og_o/0<oom`3eooT0k?of087oPOn1oh7oPOn1oikok03?ooL0mOoi0>co
mP21oh7oPOn1oh7oPOnNon`0coog0?Gon@3/ooH0POn1oh7oPOo1o`1FPOn1omco
k03AooH0m_oi0>gomP21oh7oPOn1oh7oPOnKon`0dOof0?Kon@3]ooH0POn1oh7o
POn1oh7oVoo/0=7omP3fooT0kOof087oPOn1oh7o`?l0EX7oPOoJon`0d_of0?Oo
n@3]ooL0POn1oh7oPOn1oh7oV?o/0=;omP3gooT0kOog087oPOn1oh7oPOn1oiSo
k03BooH0mooi0>gom`21oh7oPOn1okoo05J1oh7oeoo]0=?om`3gooT0k_og087o
POn1oh7oPOn1oiCok@3CooL0mooi0>kom`21oh7oPOn1oh7oPOnDond0doog0?Oo
n@3^ooL0POn1oh7oPOnno`1FPOn1omGok03EooL0n?oi0>oom`21oh7oPOn1oh7o
POnAon`0eOog0?Son@3_ooL0POn1oh7oPOn1oh7oTOo/0=Gom`3hooT0koog087o
POn1oh7o_Ol0EX7oPOoCon`0e_og0?Won@3`ooL0POn1oh7oPOn1oh7oS_o/0=Ko
m`3iooT0l?og087oPOn1oh7oPOn1ohkok03FooL0nOoi0?3om`21oh7oPOn1okco
05J1oh7odOo/0=Oom`3jooT0lOog087oPOn1oh7oPOn1oh_ok03GooL0n_oi0?7o
m`21oh7oPOn1oh7oPOn;on`0eoog0?[on@3aooL0POn1oh7oPOnko`1FPOn1oloo
k03HooL0noob0?WomP21oh7oPOn1oh7oPOn9on`0f?og0?_olP3iooH0POn1oh7o
POn1oh7oROo/0=Som`3koo80nOof087oPOn1oh7o^ol0FH7oPOo=on`0f_of003o
j@01ooof087oPOn1oh7oPOn1ohKok03JooH00?oY007oooH0POn1oh7oPOn1oh7o
Q_o/0=[omP00onT00OoomP21oh7oPOn1ok[o03j1oh7oboo/0=_odP21oh7oPOn1
oh7oPOn3on`0fooB087oPOn1oh7oPOn1oh?ok03Kom80POn1oh7oPOnio`12POn1
olWok03Lom@0POn1oh7oPOn1oh7oPOl0on`0g?oD087oPOn1oh7oPOn1oh7o0?o/
0=coe021oh7oPOn1okSo04:1oh7oaoo/0=goeP21oh7oPOn1oh7oPOn1oogok03M
omH0POn1oh7oPOn1oh7oPOomon`0gOoF087oPOn1oh7o]ol0@X7oPOo4ond0g_oH
087oPOn1oh7oPOn1oh7onOo]0=kof021oh7oPOn1oh7oPOn1ooWok@3NomP0POn1
oh7oPOnfo`12POn1ol;ok03RomL0POn1oh7oPOn1oh7oPOogon`0h_oG087oPOn1
oh7oPOn1oh7omoo/0>;oe`21oh7oPOn1okKo04:1oh7o`?o/0>Goe@21oh7oPOn1
oh7oPOn1ooKok03UomD0POn1oh7oPOn1oh7oPOofon`0iOoE087oPOn1oh7o]ol0
@X7oPOnnon`0iooE087oPOn1oh7oPOn1oh7om?o/0>Ooe@21oh7oPOn1oh7oPOn1
ooCok03WomD0POn1oh7oPOngo`12POn1okcok03Zom<0POn1oh7oPOn1oh7oPOoc
on`0j_oC087oPOn1oh7oPOn1oh7oloo/0>[od`21oh7oPOn1okSo04:1oh7o^_o/
0>god@21oh7oPOn1oh7oPOn1oo;ok03]om40POn1oh7oPOn1oh7oPOobon`0kOoA
087oPOn1oh7o^Ol0@X7oPOnhon`0l?o?087oPOn1oh7oPOn1oh7olOo/0?3oc`21
oh7oPOn1oh7oPOn1oo7ok03`oll0POn1oh7oPOnjo`12POn1okKok03cold0POn1
oh7oPOn1oh7oPOo`on`0loo=087oPOn1oh7oPOn1oh7ol?o/0??oc@21oh7oPOn1
ok_o04:1oh7o]?o/0?Kob`21oh7oPOn1oh7oPOn1onook03fol/0POn1oh7oPOn1
oh7oPOo_on`0m_o;087oPOn1oh7o_?l0@X7oPOnaond0n?o;087oPOn1oh7oPOn1
oh7ok?o]0?Sob`21oh7oPOn1oh7oPOn1oncok@3hol/0POn1oh7oPOnlo`12POn1
ojook03lolT0POn1oh7oPOn1oh7oPOo[on`0o?o9087oPOn1oh7oPOn1oh7ojoo/
0?cob@21oh7oPOn1okgo04:1oh7o[Oo/0?kob021oh7oPOn1oh7oPOn1on[ok03n
olP0POn1oh7oPOn1oh7oPOoZon`0o_o8087oPOn1oh7o__l0=X7oPOn[ok80POn1
oh7oPOn1oh7oPOoXok80POn1oh7oPOn1oh7oPOoXok80POn1oh7oPOnno`0fPOn1
ojWo/`21oh7oPOn1oh7oPOn1onOo/`21oh7oPOn1oh7oPOn1onOo/`21oh7oPOn1
okoo03J1oh7oYone087oPOn1oh7oPOn1oh7oiOne087oPOn1oh7oPOn1oh7oiOne
087oPOn1oh7o_ol0=X7oPOnUokL0POn1oh7oPOn1oh7oPOoSokL0POn1oh7oPOn1
oh7oPOoSokL0POn1oh7oPOnoo`0fPOn1oj?o^021oh7oPOn1oh7oPOn1on;o^021
oh7oPOn1oh7oPOn1on;o^021oh7oPOn1ol3o04R1oh7oXOnj087oe_om087od_om
087oPOn1oh7o`_nj087oe_om087od_om087oPOn1oh7o`_nj087oe_om087od_om
087oX_l0D87oPOnNokd0POoFood0POoBood0`oom087oPOn1oh7o_@21omKoo@21
om;oo@33ood0POn1oh7oPOnm087oe_om087od_om0<?oo@21onCo05J1oh7oW?no
087oe_om087od_om0<Coo021oh7oPOn1o`7ookl0POoFood0POoBood0a?ol087o
POn1oh7o0Ooo_`21omKoo@21om;oo@34oo`0POoTo`1DPOn1oi[o`@21omKoo@21
om;oo@34oo`0POn1oh7oPOomol40POoFood0POoBood0a?ol087oPOn1oh7ooOo1
087oe_om087od_om0<Coo021onCo05B1oh7oV?o3087oe_om087od_om0<Gon`21
oh7oPOn1oo_o``21omKoo@21om;oo@35oo/0POn1oh7oPOokol<0POoFood0POoB
ood0aOok087oi?l0E87oPOnHol<0POoFood0POoBood0a_oj087oPOn1oh7onoo3
087oe_om087od_om0<KonP21oh7oPOn1oo_o``21omKoo@21om;oo@36ooX0POoT
o`1DPOn1oiSo``21omKoo@21om;oo@37ooT0POn1oh7oPOokol<0POoFood0POoB
ood0aooi087oPOn1oh7onoo3087oe_om087od_om0<Oon@21onCo05B1oh7oV?o3
087oe_om087od_om0<Oon@21oh7oPOn1oo_o``21omKoo@21om;oo@37ooT0POn1
oh7oPOokol<0POoFood0POoBood0aooi087oi?l0E87oPOnHol<0POoFood0POoB
ood0b?oh087oPOn1oh7onoo3087oe_om087od_om0<Son021oh7oPOn1oo_o``21
omKoo@21om;oo@38ooP0POoTo`3`POn1oiSo``2Nood0o?om0?GonP3eood0o?ok
0?Coo@3cooT0k_oj0>gonP3Vood0o?oj0>oon@3]ooX0oOom0??onP3Noo`00?om
087oPOn1oh7onoo309koo@3lood0mOoj0?Goo@3loo/0m?om0??on@3^ooX0kOoj
0>Koo@3looX0kooi0>gonP3mood0looj0=koo000ood0POn1oh7oPOokol<0W_om
0?coo@3eooX0mOom0?con`3dood0looi0>konP3]ooX0i_om0?conP3_ooT0kOoj
0?goo@3cooX0g_ol003oo@21onCo0?J1oh7oV?o309koo@3noo/0n?oe0?Ooo@3n
ooH0moom0?Kom03booD0looe0>Soo@3nooH0looe0?7omP01ooom0?Kom@3Qoo`0
0Oooo@21oh7oPOn1oo_o``2Nood0o_ok0?Som@3good0o_of0?Ooo@3foo@0l_oe
0??om@3Xood0o_of0??om@3aooH00Oooo@3fooD0hOol007oood0POn1oh7oPOok
ol<0W_om0?kon`3hooD0moom0?komP3good0m_od0?;om@3cooD0j?om0?komP3c
ooD0lOof007oood0m_oe0>7oo001ooom087oi?l0nH7oPOnHol<0W_om007oooX0
nOob0?Woo@01oood0?Soo@3goo40mOoc0?GolP3Zood00Ooom03eoo80mOoc003o
o@3goo80hoom0?koo@21oh7oPOn1oo_o``2Nood00OoonP3ioo80nOom007ooo@0
n?om0?Ool@3eoo<0mOob0>[oo@01oood0?GolP3eoo<00?om0?OolP3Sood0o_om
087oPOn1oh7onoo309koo@01oooj0?WolP3iood00Ooom03hood0mooa0?Gol`3e
oo80j_om007ooo@0mOob0?Gol`00ood0moob0>?oo@3nood0POoTo`3TPOn1oiSo
``2Nood00?oi0?[ol03jood00?ob0?Woo@3honl0mooa0?Ool03[ood00?ob0?Oo
l03fonh0n?o`0>Goo03nood0POn1oh7oPOokol<0W_om003on@3joo00n_om003o
lP3iood0n?o_0?Ool@3goo00joom003olP3goo00m_o^0?Sol03Uoo`0o_om087o
POn1oh7onoo309koo@00ooT0n_o`0?[oo@00oo80nOom0?Sok`3goo40moo`0>_o
o@00oo80moo`0?KokP3hoo00iOol0?koo@21onCo0Bb1oh7oV?o309kon@3foo/0
nooj0?_on03looX0n_om0?Won`3joo/0n?ok0?conP3ioo/0nooj0>con03loo/0
n?ok0?_onP3hoo/0o?oh0?Won`3kooX0iool0?goo@21oh7oPOn1oo_o``2NooT0
m_ok0?_onP3kooP0o?oj0?[oo@3ioo/0n_ok0?Son`3looX0nOok0?_onP3/ooP0
o?ok0?Son`3kooX0n?ok0?con03ioo/0nooj0>Ooo03mood0POn1oh7oPOokol<0
W_oi0?Kon`3kooX0nooh0?conP3jood0nOok0?[on`3hoo/0o?oj0?Won`3kooX0
k?oh0?con`3hoo/0nooj0?Son`3looP0nOok0?_onP3Woo`0oOom087oi?l1;87o
POnGolD0WOoj0?Koo03goo`0nooj0?Soo03jood0nOol0?Ooo03joo`0n?ol0?[o
o03goo`0k?oj0?Soo@3ioo`0mool0?Woo03hooX0n_ol0?Ooo03Xoo`0o?om087o
POn1oh7on_o509gonP3foo`0mool0?_onP3hoo`0n_om0?Woo03goo`0n_ol0?So
o03joo`0mool0>conP3hood0nOol0?Ooo03ioo`0n?oj0?[oo03goo`0j?ol0?co
o@21oh7oPOn1oo[oa@2MooX0m_ol0?Ooo03kooX0n?ol0?[oo@3ioo`0mool0?[o
o03hoo`0n_ol0?Ooo03/ooX0n?om0?Woo03goo`0nOol0?SonP3joo`0mool0>So
o03lood0POoTo`4/POn1oiOoa@2Moo/0mOom0?Goo03loo/0m_ol0?_oo@3joo`0
mOom0?[oo@3food0n_om0?Goo03]oo/0mool0?[oo@3eoo`0n_om0?Kon`3jood0
mOol0>[oo03kood0POn1oh7oPOojolD0WOok0?Goo@3eoo`0o?ok0?Koo03kood0
n_ol0?Goo@3jood0m_om0?[oo@3eoo`0kOok0?Ooo03jood0mOol0?[oo@3foo/0
n_om0?Goo03Zoo`0noom087oPOn1oh7on_o509gon`3eood0mOol0?con`3foo`0
noom0?[oo03eood0n_om0?Koo@3jood0mOol0>gon`3goo`0n_om0?Goo03jood0
m_ok0?[oo@3eoo`0j_ol0?_oo@21onCo0Bb1oh7oUoo509goo03eood0loom0?co
o03dood0noom0?[oo@3dood0nool0?Koo03lood0loom0>goo03eood0nool0?Co
o@3koo`0mOol0?_oo@3cood0j_om0?[oo@21oh7oPOn1oo[oa@2Moo`0mOom0??o
o@3loo`0m?om0?_oo@3jood0m?om0?_oo03foo`0o?om0??oo@3]oo`0mOom0?_o
o03dood0nool0?Goo03kood0loom0>[oo@3jood0POn1oh7oPOojolD0WOol0?Go
o@3cood0o?ol0?Coo@3kood0n_om0?Coo@3koo`0m_ol0?coo@3cood0kOol0?Go
o@3koo`0m?om0?_oo03eoo`0noom0??oo@3Zood0n_om087oi?l1;87oPOnFolL0
W?om0?Coo@3coo`0oOol0?Coo@3kood0n_om0?Coo@3kood0m?om0?coo@3coo`0
k_ol0?Goo@3kood0loom0?_oo@3doo`0noom0??oo03/oo`0n_om087oPOn1oh7o
nOo709coo@3dood0lool0?goo03dood0noom0?[oo@3dood0noom0?Coo@3lood0
lool0>koo03eood0noom0??oo@3kood0m?ol0?_oo@3coo`0k?ol0?[oo@21oh7o
POn1ooWoa`2Lood0m?om0??oo03moo`0m?om0?_oo@3jood0m?om0?_oo@3dood0
o?om0??oo03^oo`0mOom0?_oo@3cood0noom0?Coo03kood0lool0>coo03jood0
POoTo`4PPOn1oiKoa`2Lood0m?on0?7oo@3moo`0m?ol0?coo@3Yood0noom0?Co
o@3looh0lOom0>koo@3dood0noom0?;oo@3lood0m?ol0?_ooP3aood0kOol0?Wo
o@21oh7oPOn1ooWoa`2Lood0m?on0?7oo@3moo`0m?ol0?coo@3Yood0noom0?Co
o@3looh0lOom0>koo@3dood0noom0?;oo@3lood0m?ol0?_ooP3aood0kOol0?Wo
o@21oh7oPOn1ooWoa`2Lood0m?on0?7oo@3moo`0m?ol0?coo@3Yood0noom0?Co
o@3looh0lOom0>koo@3dood0noom0?;oo@3lood0m?ol0?_ooP3aood0kOol0?Wo
o@21onCo0AB1oh7oUOo909_oo@3eood0lOom0?goo@3bood0o?om0>[oo03lood0
joom0?7oo@3^ood0m?om0?coo@3aood0oOom0?;oo@3lood0lOom0>koo03hood0
POn1oh7oPOoholT0Voom0?Goo@3aood0oOom0?;oo@3lood0j_ol0?coo@3[ood0
lOom0>koo@3dood0o?om0?7oo@3mood0l_om0?coo@3aood0k_ol0?Soo@21oh7o
POn1ooSob@2Kood0mOom0?7oo@3mood0l_om0?coo@3Zoo`0o?om0>_oo@3aood0
k_om0?Coo@3lood0lOom0?goo@3bood0o?om0?7oo@3^oo`0n?om087oi?l0l87o
POnDolX0Voom0?Goj@3mood0l_om0?coo@3]ooT0o?om0>_oj@3^ood0m?om0?co
o@3aood0oOom0?;oo@3lonT0k_om0?Ooo@21oh7oPOn1ooOobP2Kood0mOoY0?go
o@3bood0o?om0>gon@3lood0jooY0>koo@3dood0o?om0?7oo@3mood0l_om0?co
j@3^ood0moom087oPOn1oh7omoo:09_oo@3eonT0oOom0?;oo@3lood0kOoi0?co
o@3[onT0k_om0?Coo@3lood0lOom0?goo@3bood0o?oY0>koo@3good0POoTo`3`
POn1oiCob`2Jood0mOoY0?goo@3bood0o?om0?ColP3lood0jooY0>koo@3dood0
o?om0?7oo@3mood0l_om0?coj@3_oo`0moom087oPOn1oh7omoo;09[oo@3eonT0
oOom0?;oo@3lood0m?ob0?coo@3[onT0k_om0?Coo@3lood0lOom0?goo@3bood0
o?oY0>ooo03good0POn1oh7oPOogol/0V_om0?Goj@3mood0l_om0?coo@3doo80
o?om0>_oj@3^ood0m?om0?coo@3aood0oOom0?;oo@3lonT0kool0?Ooo@21onCo
0?21oh7oToo=09Woo@3eonT0oOom0?;oo@3lood0moo_0?coo@3[onT0k_om0?Co
o@3lood0lOom0?goo@3bood0o?oY0?3oo03food0POn1oh7oPOofold0VOom0?Go
j@3mood0l_om0?coo@3gonl0o?om0>_oj@3^ood0m?om0?coo@3aood0oOom0?;o
o@3lonT0l?ol0?Koo@21oh7oPOn1ooKoc@2Iood0mOoY0?goo@3bood0o?om0?Oo
k`3lood0jooY0>koo@3dood0o?om0?7oo@3mood0l_om0?coj@3`oo`0m_om087o
i?l0l87oPOnCold0VOom0?Goj@3mood0l_om0?coo@3hoo<00?om0?coo@3[onT0
k_om0?Coo@3lood0lOom0?goo@3bood0o?oY0?3oj021oh7oPOn1oo_oc@2Iood0
mOoY0?goo@3bood0o?om0?Sol`00ood0o?om0>_oj@3^ood0m?om0?coo@3aood0
oOom0?;oo@3lonT0l?oX087oPOn1oh7onoo=09Woo@3eonT0oOom0?;oo@3lood0
n?oc003oo@3lood0jooY0>koo@3dood0o?om0?7oo@3mood0l_om0?coj@3`onP0
POoYo`3`POn1oi;oc`2Hood0mOom0>Woo@3bood0o?om0?WomP3lood0o?om0>_o
o@3Jood0m?om0?coo@3aood0oOom0?;oo@3lood0g?oX087oPOn1oh7on_o?09So
o@3eood0jOom0?;oo@3lood0nOof0?coo@3lood0joom0=[oo@3dood0o?om0?7o
o@3mood0l_om0?coo@3LonP0POn1oh7oPOojoll0V?om0?Goo@3Yood0l_om0?co
o@3iooH0o?om0?coo@3[ood0f_om0?Coo@3lood0lOom0?goo@3bood0o?om0=co
j021onWo0?21oh7oTOoA09Ooo@3eood0jOom0?;oo@3lood0n_ok0?Koo@3lood0
joom0=[oo@3dood0o?om0?7oo@3mood0l_om0?coo@3LonP0POn1oh7oPOoiom40
Uoom0?Goo@3Yood0l_om0?coo@3joo/0m_om0?coo@3[ood0f_om0?Coo@3lood0
lOom0?goo@3bood0o?om0=coj021oh7oPOn1ooWod@2Good0mOom0>Woo@3bood0
o?om0?[on`3food0o?om0>_oo@3Jood0m?om0?coo@3aood0oOom0?;oo@3lood0
g?oX087ojOl0l87oPOn@om<0U_om0?Goo@3Yood0l_om0?coo@3koo`0m?om0?co
o@3[ood0f_om0?Coo@3lood0lOom0?goo@3bood0o?om0=coj021oh7oPOn1ooSo
d`2Food0mOom0>Woo@3bood0o?om0?_oo03dood0o?om0>_oo@3Jood0m?om0?co
o@3aood0oOom0?;oo@3lood0g?oX087oPOn1oh7on?oC09Koo@3eood0jOom0?;o
o@3lood0nool0?Coo@3lood0joom0=[oo@3dood0o?om0?7oo@3mood0l_om0?co
o@3LonP0POoYo`3lPOn1ohooe@2Eood0mOol0>[oo@3cood0noom0?_oo@3cood0
o?ol0?Coo@3moo`0foom0?Coo@3loo`0loom0?coo03doo`0o?ol0<goo@21oh7o
POn1oo;oe@2Eood0mOol0>[oo@3cood0noom0?_oo@3cood0o?ol0?Coo@3moo`0
foom0?Coo@3loo`0loom0?coo03doo`0o?ol0<goo@21oh7oPOn1oo;oe@2Eood0
mOol0>[oo@3cood0noom0?_oo@3cood0o?ol0?Coo@3moo`0foom0?Coo@3loo`0
loom0?coo03doo`0o?ol0<goo@21onCo0B21oh7oSOoH09Coo@3dood0l_om0?go
o03dood0noom0?_oo@3cood0noom0?Coo@3lood0l_om0>koo@3dood0noom0??o
o@3kood0m?ol0?_oo@3bood0h?om087oPOn1oh7ol?oH09Coo@3dood0l_om0?go
o03dood0noom0?_oo@3cood0noom0?Coo@3lood0l_om0>koo@3dood0noom0??o
o@3kood0m?ol0?_oo@3bood0h?om087oPOn1oh7ol?oH09Coo@3dood0l_om0?go
o03dood0noom0?_oo@3cood0noom0?Coo@3lood0l_om0>koo@3dood0noom0??o
o@3kood0m?ol0?_oo@3bood0h?om087oi?l1887oPOn<om/0T_om0?Coo@3coo`0
oOol0?Goo03kood0noom0?Coo03kood0mOom0?_oo@3coo`0k_om0?Coo@3kood0
m?ol0?_oo03foo/0noom0??oo03Pood0POn1oh7oPOo_om/0T_om0?Coo@3coo`0
oOol0?Goo03kood0noom0?Coo03kood0mOom0?_oo@3coo`0k_om0?Coo@3kood0
m?ol0?_oo03foo/0noom0??oo03Pood0POn1oh7oPOo_om/0T_om0?Coo@3coo`0
oOol0?Goo03kood0noom0?Coo03kood0mOom0?_oo@3coo`0k_om0?Coo@3kood0
m?ol0?_oo03foo/0noom0??oo03Pood0POoTo`4PPOn1oh[og`2@ood0m?ol0?Go
o03loo/0m_ol0?_oo@3kood0mOok0?_oo03goo`0nool0?Goo03]ood0m?om0?_o
o03eood0n_ol0?Kon`3koo`0mOol0=ooo@21oh7oPOn1ongog`2@ood0m?ol0?Go
o03loo/0m_ol0?_oo@3kood0mOok0?_oo03goo`0nool0?Goo03]ood0m?om0?_o
o03eood0n_ol0?Kon`3koo`0mOol0=ooo@21oh7oPOn1ongog`2@ood0m?ol0?Go
o03loo/0m_ol0?_oo@3kood0mOok0?_oo03goo`0nool0?Goo03]ood0m?om0?_o
o03eood0n_ol0?Kon`3koo`0mOol0=ooo@21onCo0B21oh7oR_oO093oo@3coo`0
mook0?conP3hoo`0n_om0?_oo03gooX0n_ol0?Soo03joo`0mook0>goo@3dood0
n_ol0?Ooo03ioo`0n?oj0?[oo03goo/0goom087oPOn1oh7okOoO093oo@3coo`0
mook0?conP3hoo`0n_om0?_oo03gooX0n_ol0?Soo03joo`0mook0>goo@3dood0
n_ol0?Ooo03ioo`0n?oj0?[oo03goo/0goom087oPOn1oh7okOoO093oo@3coo`0
mook0?conP3hoo`0n_om0?_oo03gooX0n_ol0?Soo03joo`0mook0>goo@3dood0
n_ol0?Ooo03ioo`0n?oj0?[oo03goo/0goom087oi?l1887oPOn8on<0S_om0?;o
n`3kooX0nooh0?con`3iood0n_ok0?_on03ioo`0nook0?Son`3kooX0k?om0?Co
o@3jooX0nook0?Oon`3looP0nOok0?_onP3Nood0POn1oh7oPOo[on<0S_om0?;o
n`3kooX0nooh0?con`3iood0n_ok0?_on03ioo`0nook0?Son`3kooX0k?om0?Co
o@3jooX0nook0?Oon`3looP0nOok0?_onP3Nood0POn1oh7oPOo[on<0S_om0?;o
n`3kooX0nooh0?con`3iood0n_ok0?_on03ioo`0nook0?Son`3kooX0k?om0?Co
o@3jooX0nook0?Oon`3looP0nOok0?_onP3Nood0POoTo`3HPOn1ohGoj@2;ood0
lOo`0?[ok@3iood0n_oa003onP3loo40m_o`0>_oo@3dood0nOo`0?KolP00ood0
n?o`0=goo@21oh7oPOn1onSoj@2;ood0lOo`0?[ok@3iood0n_oa003onP3loo40
m_o`0>_oo@3dood0nOo`0?KolP00ood0n?o`0=goo@21oh7oPOn1onSoj@2;ood0
lOo`0?[ok@3iood0n_oa003onP3loo40m_o`0>_oo@3dood0nOo`0?KolP00ood0
n?o`0=goo@21onCo0>N1oh7oP_o^08Woo@3`oo80nOom003ol`3hood0nOoc0?ko
n`3koo80mOob0>[oo@3dood0n?ob0?Com001ooom0?OolP3Lood0POn1oh7oPOoU
onh0ROom0?3olP3iood00?oc0?Soo@3ioo<0o_ok0?_olP3eoo80j_om0?Coo@3h
oo80m?od007oood0moob0=coo@21oh7oPOn1onGokP29ood0l?ob0?Woo@00oo<0
n?om0?Wol`3noo/0noob0?GolP3Zood0m?om0?SolP3doo@00Oooo@3goo80g?om
087oi?l0hh7oPOn1oh7omoom0>oom03hood00OoomP3food0n?of0?con`3iooH0
l_od0>Woo@3dood0m_oe0?7om`3nood0m_od0=_oo@21oh7oPOn1oh7of_om0>oo
m03hood00OoomP3food0n?of0?con`3iooH0l_od0>Woo@3dood0m_oe0?7om`3n
ood0m_od0=_oo@21oh7oPOn1oh7of_om0>oom03hood00OoomP3food0n?of0?co
n`3iooH0l_od0>Woo@3dood0m_oe0?7om`3nood0m_od0=_oo@21onCo09R1oh7o
POn1omoon@3eood0oOoj0>GonP3ioo`0mooj0>kon@34ooT0kOok0>_on@21oh7o
POn1oh7oUOoi0?Goo@3mooX0iOoj0?Woo03gooX0k_oi0<Con@3]oo/0jooi087o
POn1oh7oPOnEooT0mOom0?gonP3UooX0nOol0?OonP3^ooT0a?oi0>gon`3[ooT0
POngo`0hPOn1oh7oPOo;ood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7o
POnMood0POn1oh7odol0>87oPOn1oh7oboom087oPOn1oh7oPOn1oh7oWOom087o
POn1oh7oPOn1oh7oWOom087oPOn1om?o03R1oh7oPOn1ol_oo@21oh7oPOn1oh7o
POn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOoCo`0hPOn1oh7oPOo;ood0
POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POn1oh7odol0>87o
POn1oh7oboom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087o
POn1om?o03R1oh7oPOn1ol_oo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7o
POn1oigoo@21oh7oPOoCo`0hPOn1oh7oPOo;ood0POn1oh7oPOn1oh7oPOnMood0
POn1oh7oPOn1oh7oPOnMood0POn1oh7odol0>87oPOn1oh7oboom087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087oPOn1om?o03R1oh7oPOn1ol_o
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOoCo`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
03R1oh7oPOodooT0POn1oh7oPOn1oh7oPOnQooT0POn1oh7oPOn1oh7oPOnQooT0
POn1oh7oPOn^o`0hPOn1oh7omood087oPOn1oh7oPOn1oh7oY_od087oPOn1oh7o
POn1oh7oY_od087oPOn1oh7o/?l0>87oPOn1ooSol@21oh7oPOn1oh7oPOn1ojWo
l@21oh7oPOn1oh7oPOn1ojWol@21oh7oPOn1ok;o03R1oh7oPOoioo00POn1oh7o
POn1oh7oPOnZoo00POn1oh7oPOn1oh7oPOnZoo00POn1oh7oPOnbo`14POn1oh7o
n_ok0?[on`21oh7oPOn1oh7oPOn1ojcon`3joo/0POn1oh7oPOn1oh7oPOn/oo/0
n_ok087oPOn1oh7o/ol0A87oPOn1oo_on`3goo`0POn1oh7oPOn1oh7oPOn^oo/0
mool087oPOn1oh7oPOn1oh7o[_ok0?Ooo021oh7oPOn1okCo04B1oh7oPOokoo`0
mOom087oPOn1oh7oPOn1oh7o[_ol0?Goo@21oh7oPOn1oh7oPOn1ojkoo03eood0
POn1oh7oPOndo`14POn1oh7onoom0?Coo021oh7oPOn1oh7oPOn1ojooo@3doo`0
POn1oh7oPOn1oh7oPOn_ood0m?ol087oPOn1oh7o]Ol0A87oPOn1oocoo03cood0
POn1oh7oPOn1oh7oPOn`oo`0loom087oPOn1oh7oPOn1oh7o/?ol0??oo@21oh7o
POn1okGo04B1oh7oPOolood0l_om087oPOn1oh7oPOn1oh7o/?om0?;oo@21oh7o
POn1oh7oPOn1ok3oo@3bood0POn1oh7oPOneo`14POn1oh7oo?om0?;oo@21oh7o
POn1oh7oPOn1ok3oo@3bood0POn1oh7oPOn1oh7oPOn`ood0l_om087oPOn1oh7o
]Ol0A87oPOn1oocoo@3bood0POn1oh7oPOn1oh7oPOn`ood0l_om087oPOn1oh7o
POn1oh7o/?om0?;oo@21oh7oPOn1okGo04Z1oh7oPOoYood0POn1ojKo0038o`00
POn1oh7oPOncood0POn1ojKo0038o`00POn1oh7oPOncood0POn1ojKo0038o`00
POo;o`1:POn1oh7oj_ol087oPOnYooX0c_oj087oPOn1oh7o]ool087oPOnYooX0
c_oj087oPOn1oh7o]ool087oPOnYooX0c_oj087oc_l0BX7oPOn1on_oo021oh7o
ZOog0=7on021oh7oPOn1okWoo021oh7oZOog0=7on021oh7oPOn1okWoo021oh7o
ZOog0=7on021oloo04Z1oh7oPOo/oo/0POn1oj[om@3Doo@0POn1oh7oPOnloo/0
POn1oj[om@3Doo@0POn1oh7oPOnloo/0POn1oj[om@3Doo@0POoAo`1:POn1oh7o
kOok087oPOnZoo<0eOoc087oPOn1oh7o__ok087oPOnZoo<0eOoc087oPOn1oh7o
__ok087oPOnZoo<0eOoc087od_l0G87oPOn1onoonP21om3o003?o`00Soob0=Ko
lP21oh7oPOn1ol3onP21om3o003?o`00Soob0=KolP21oh7oPOn1ol3onP21om3o
003?o`00Soob0=KolP21om;o05b1oh7oPOoaooT0POoBooX0eOoj09;olP3Foo80
POn1oh7oPOo2ooT0POoBooX0eOoj09;olP3Foo80POn1oh7oPOo2ooT0POoBooX0
eOoj09;olP3Foo80POoBo`1@POn1oh7ol_oi087odooe0=_om@2DokL0POn1oh7o
POo4ooT0POoCooD0fooe09Co]`21oh7oPOn1olCon@21om?om@3KooD0U?ng087o
dol0D87oPOn1ooCon@21om;ol`3Loo@0U_nf087oPOn1oh7oa_oi087od_oc0=co
m02FokH0POn1oh7oPOo6ooT0POoBoo<0g?od09Ko]P21om?o0521oh7oPOofooP0
POoAoo<0gOob09Oo]P21oh7oPOn1olSon021om7ol`3Moo80Uonf087oPOn1oh7o
b?oh087odOoc0=golP2GokH0POoCo`1@POn1oh7omooi087od?ob0=golP2FokL0
POn1oh7oPOo9ooT0POo@oo80gOob09Ko]`21oh7oPOn1olWon@21om3olP3Moo80
U_ng087odol0G87oPOn1ooSonP21olkol@3Ooo00Uoob0=KolP21oh7oPOn1olWo
nP21olkol@3Ooo00Uoob0=KolP21oh7oPOn1olWonP21olkol@3Ooo00Uoob0=Ko
lP21om;o05b1oh7oPOoioo/0POo=oo00goo`09OolP3Foo80POn1oh7oPOo:oo/0
POo=oo00goo`09OolP3Foo80POn1oh7oPOo:oo/0POo=oo00goo`09OolP3Foo80
POoBo`1LPOn1oh7on_ok087oc?o`0=ool02Foo80eoob087oPOn1oh7obook087o
c?o`0=ool02Foo80eoob087oPOn1oh7obook087oc?o`0=ool02Foo80eoob087o
d_l0G87oPOn1oo_oo021ol[ol03Ooo00UOob0=WolP21oh7oPOn1ol_oo021ol[o
l03Ooo00UOob0=WolP21oh7oPOn1ol_oo021ol[ol03Ooo00UOob0=WolP21om7o
05b1oh7oPOokood0POo8oo40goo`09Gol@3Koo80POn1oh7oPOo:ood0POo8oo40
goo`09Gol@3Koo80POn1oh7oPOo:ood0POo8oo40goo`09Gol@3Koo80POo@o`1g
POn1oh7oo?om087oaoob0=kol@2BooX00Ooon`3Moo/00?oj087oPOn1oh7obOom
087oaoob0=kol@2BooX00Ooon`3Moo/00?oj087oPOn1oh7obOom087oaoob0=ko
l@2BooX00Ooon`3Moo/00?oj087oc_l0M87oPOn1oocoo@21olOolP3Moo80T?om
0?gon`3Ooo/0o_ol087oPOn1oh7ob?om087oaoob0=golP2@ood0oOok0=oon`3n
oo`0POn1oh7oPOo8ood0POo7oo80gOob093oo@3moo/0gook0?koo021olgo07B1
oh7oPOolooh0POo5oo<0gOoc08ooo@3loo/0hOok0?goo021oh7oPOn1olSooP21
olGol`3Moo<0Soom0?con`3Qoo/0oOol087oPOn1oh7ob?on087oaOoc0=gol`2?
ood0o?ok0>7on`3moo`0POo=o`1dPOn1oh7ooOoY087of?oc0=ool`2>ood0nook
0>?on`3loo`0POn1oh7oPOo9onT0POoHoo<0gooc08koo@3koo/0hook0?coo021
oh7oPOn1olWoj@21omSol`3Ooo<0S_om0?_on`3Soo/0o?ol087ocOl0M87oPOn1
oogoj@21omOol`3Qoo<0SOom0?[on`3Uoo/0nool087oPOn1oh7obOoY087oeooc
0>7ol`2=ood0n_ok0>Gon`3koo`0POn1oh7oPOo9onT0POoGoo<0hOoc08goo@3j
oo/0iOok0?_oo021olgo08b1oh7oPOomonT0POoFooX00?ok0>?on`00oo/0Room
0?Won`3Woo/0n_ol087oPOn1oh7obOoY087oe_oj003on`3Soo/00?ok08_oo@3i
oo/0iook0?[oo021oh7oPOn1olWoj@21omKonP00oo/0hook003on`2;ood0nOok
0>Oon`3joo`0POo=o`20POn1oh7ooOoY087ocOok0>Gon`2kooh0c?om0?Son`3Y
oo/0nOol087oPOn1oh7obOoY087ocOok0>Gon`2kooh0c?om0?Son`3Yoo/0nOol
087oPOn1oh7obOoY087ocOok0>Gon`2kooh0c?om0?Son`3Yoo/0nOol087ocOl0
N87oPOn1oh7o/?ok0>Oon`2joo`0c_om0?Oon`3[oo/0n?ol087oPOn1oh7oPOn1
oocon`3Woo/0^_ol0<koo@3goo/0jook0?Soo021oh7oPOn1oh7oPOoloo/0iook
0;[oo03>ood0mook0>_on`3hoo`0POo=o`1hPOn1oh7oPOn_oo/0jOok0;Won@3A
ood0m_ok0>gon`3goo`0POn1oh7oPOn1oh7onook0>Won`2iooT0dOom0?Kon`3]
oo/0mool087oPOn1oh7oPOn1oo_on`3Yoo/0^Ooi0=7oo@3foo/0kOok0?Ooo021
olgo07R1oh7oPOn1ojkon`3[oo/0^?of0=Coo@3eoo/0kook0?Koo021oh7oPOn1
oh7oPOojoo/0jook0;SomP3Dood0mOok0>oon`3foo`0POn1oh7oPOn1oh7on_ok
0>_on`2hooH0e?om0?Gon`3_oo/0m_ol087ocOl0N87oPOn1oh7o[Ook0>gon`2g
oo<0eoom0?Con`3aoo/0mOol087oPOn1oh7oPOn1ooWon`3]oo/0]ooc0=Ooo@3d
oo/0lOok0?Goo021oh7oPOn1oh7oPOoioo/0kOok0;Ool`3Good0m?ok0?7on`3e
oo`0POo=o`1hPOn1oh7oPOn/oo/0kook0;Kol@3Iood0look0??on`3doo`0POn1
oh7oPOn1oh7on?ok0>oon`2foo40fOom0??on`3coo/0m?ol087oPOn1oh7oPOn1
ooSon`3_oo/0]_oa0=Woo@3coo/0look0?Coo021olgo07R1oh7oPOn1oj_on`3a
oo/0]Oo^0=coo@3boo/0mOok0??oo021oh7oPOn1oh7oPOogoo/0lOok0;GokP3L
ood0l_ok0?Gon`3coo`0POn1oh7oPOn1oh7omook0?7on`2eonh0g?om0?;on`3e
oo/0lool087ocOl0N87oPOn1oh7oZ_ok0??on`2don/0goom0?7on`3goo/0l_ol
087oPOn1oh7oPOn1ooKon`3coo/0]?o[0=ooo@3aoo/0mook0?;oo021oh7oPOn1
oh7oPOofoo/0look0;Coj`3Oood0lOok0?Oon`3boo`0POo=o`1hPOn1oh7oPOnY
oo/0mOok0;?oj@3Qood0l?ok0?Won`3aoo`0POn1oh7oPOn1oh7omOok0?Gon`2c
onT0hOom0?3on`3ioo/0lOol087oPOn1oh7oPOn1ooGon`3eoo/0/ooY0>7oo@3`
oo/0nOok0?7oo021olgo08N1oh7oPOn1ojSon`00ooX00Ooon`2bonH0i?om0>oo
n`3koo/0l?ol087oPOn1oh7oPOn1ooCon`00ooX00Ooon`2bonH0i?om0>oon`3k
oo/0l?ol087oPOn1oh7oPOn1ooCon`00ooX00Ooon`2bonH0i?om0>oon`3koo/0
l?ol087ocOl0K87oPOn1oh7oYoo]0;7oh`3Wood0k_ok0?gon`3_oo`0POn1oh7o
POn1oh7oloo]0;7oh`3Wood0k_ok0?gon`3_oo`0POn1oh7oPOn1oh7oloo]0;7o
h`3Wood0k_ok0?gon`3_oo`0POo=o`1_POn1oh7oPOnVonl0/?oP0>[oo@3]oo/0
0Ooon`3^oo`0POn1oh7oPOn1oh7ol_o_0;3oh03Zood0kOok007ooo/0k_ol087o
POn1oh7oPOn1oo;ok`2`on00j_om0>gon`01oook0>koo021olgo0621oh7oPOn1
ojGol@2_omh0k?om0>com@3]oo`0POn1oh7oPOn1oh7olOoa0:oogP3/ood0k?oe
0>goo021oh7oPOn1oh7oPOoaoo40[ooN0>coo@3/ooD0kOol087ocOl0H87oPOn1
oh7oYOob0:kof`3_ood0joog0>coo021oh7oPOn1oh7oPOoaoo80[_oK0>ooo@3[
ooL0k?ol087oPOn1oh7oPOn1oo7olP2^om/0koom0>_om`3/oo`0POo=o`1PPOn1
oh7oPOnUoo80h?nV0?;oo@3ZooT0jool087oPOn1oh7oPOn1oo7olP3PojH0l_om
0>[on@3[oo`0POn1oh7oPOn1oh7olOob0>3oYP3bood0j_oi0>_oo021olgo0621
oh7oPOn1ojGol@3Qoj@0m?om0>Won`3Zoo`0POn1oh7oPOn1oh7olOoa0>7oY03d
ood0jOok0>[oo021oh7oPOn1oh7oPOoaoo40hOnT0?Coo@3Yoo/0j_ol087ocOl0
H87oPOn1oh7oY_o`0>7oX@3good0j_oi0>_oo021oh7oPOn1oh7oPOoboo00hOnQ
0?Ooo@3ZooT0jool087oPOn1oh7oPOn1oo;ol03Qoj40moom0>[on@3[oo`0POo=
o`1PPOn1oh7oPOnVoo00hOnT0?Coo@3[ooL0k?ol087oPOn1oh7oPOn1oo;ol03Q
oj@0m?om0>_om`3/oo`0POn1oh7oPOn1oh7ol_o`0>7oY03dood0joog0>coo021
olgo0621oh7oPOn1ojGol@2_omP0l_om0>com@3]oo`0POn1oh7oPOn1oh7olOoa
0:oof03bood0k?oe0>goo021oh7oPOn1oh7oPOoaoo40[ooH0?;oo@3/ooD0kOol
087ocOl0Kh7oPOn1oh7oYOob0:kof`3_ood0kOok007ooo/0k_ol087oPOn1oh7o
POn1oo7olP2^om/0koom0>gon`01oook0>koo021oh7oPOn1oh7oPOoaoo80[_oK
0>ooo@3]oo/00Ooon`3^oo`0POo=o`1/POn1oh7oPOnUoo80[_oN0>coo@3^oo/0
oOok0>ooo021oh7oPOn1oh7oPOoaoo80[_oN0>coo@3^oo/0oOok0>ooo021oh7o
POn1oh7oPOoaoo80[_oN0>coo@3^oo/0oOok0>ooo021olgo06b1oh7oPOn1ojCo
l`2^on40jOom0>oon`3koo/0l?ol087oPOn1oh7oPOn1oo3ol`2^on40jOom0>oo
n`3koo/0l?ol087oPOn1oh7oPOn1oo3ol`2^on40jOom0>oon`3koo/0l?ol087o
cOl0K87oPOn1oh7oYOoa0:ooh`3Wood0l?ok0?Won`3aoo`0POn1oh7oPOn1oh7o
lOoa0:ooh`3Wood0l?ok0?Won`3aoo`0POn1oh7oPOn1oh7olOoa0:ooh`3Wood0
l?ok0?Won`3aoo`0POo=o`1/POn1oh7oPOnVonl0/?oV0>Coo@3aoo/0mook0?;o
o021oh7oPOn1oh7oPOobonl0/?oV0>Coo@3aoo/0mook0?;oo021oh7oPOn1oh7o
POobonl0/?oV0>Coo@3aoo/0mook0?;oo021olgo06b1oh7oPOn1ojOok@2aonT0
hOom0?;on`3eoo/0lool087oPOn1oh7oPOn1oo?ok@2aonT0hOom0?;on`3eoo/0
lool087oPOn1oh7oPOn1oo?ok@2aonT0hOom0?;on`3eoo/0lool087ocOl0N87o
POn1oh7oZ?ok0?Oon`2bon/0goom0??on`3coo/0m?ol087oPOn1oh7oPOn1ooCo
n`3goo/0/_o[0=ooo@3coo/0look0?Coo021oh7oPOn1oh7oPOodoo/0mook0;;o
j`3Oood0look0??on`3doo`0POo=o`1hPOn1oh7oPOnYoo/0mOok0;?okP3Lood0
m?ok0?7on`3eoo`0POn1oh7oPOn1oh7omOok0?Gon`2conh0g?om0?Con`3aoo/0
mOol087oPOn1oh7oPOn1ooGon`3eoo/0/oo^0=coo@3doo/0lOok0?Goo021olgo
07R1oh7oPOn1oj[on`3coo/0]?oa0=Woo@3eoo/0kook0?Koo021oh7oPOn1oh7o
POofoo/0look0;Col@3Iood0mOok0>oon`3foo`0POn1oh7oPOn1oh7om_ok0??o
n`2doo40fOom0?Gon`3_oo/0m_ol087ocOl0N87oPOn1oh7oZook0?7on`2eoo<0
eoom0?Kon`3]oo/0mool087oPOn1oh7oPOn1ooOon`3aoo/0]Ooc0=Ooo@3foo/0
kOok0?Ooo021oh7oPOn1oh7oPOogoo/0lOok0;Gol`3Good0m_ok0>gon`3goo`0
POo=o`1hPOn1oh7oPOn/oo/0kook0;KomP3Dood0mook0>_on`3hoo`0POn1oh7o
POn1oh7on?ok0>oon`2fooH0e?om0?Oon`3[oo/0n?ol087oPOn1oh7oPOn1ooSo
n`3_oo/0]_of0=Coo@3goo/0jook0?Soo021olgo07R1oh7oPOn1ojgon`3]oo/0
]ooi0=7oo@3hoo/0jOok0?Woo021oh7oPOn1oh7oPOoioo/0kOok0;Oon@3Aood0
n?ok0>Won`3ioo`0POn1oh7oPOn1oh7onOok0>gon`2gooT0dOom0?Son`3Yoo/0
nOol087ocOl0N87oPOn1oh7o[_ok0>_on`2hoo`0c_om0?Won`3Woo/0n_ol087o
POn1oh7oPOn1oo[on`3[oo/0^?ol0<koo@3ioo/0iook0?[oo021oh7oPOn1oh7o
POojoo/0jook0;Soo03>ood0nOok0>Oon`3joo`0POo=o`2<POn1oh7oPOngo`00
n_ok0>Won`3jo`00`Oon0<coo@3joo/0iOok0?_oo021oh7oPOn1oh7oPol00?[o
n`3Yoo/0n_l00<7ooP3<ood0n_ok0>Gon`3koo`0POn1oh7oPOn1oh?o003joo/0
jOok0?[o0031ooh0c?om0?[on`3Uoo/0nool087ocOl0P87oPOn1oh7o^_oj0?ko
n`3Woo/0o_oj08coo@3koo/0hook0?coo021oh7oPOn1oh7oQ_oj0?kon`3Woo/0
o_oj08coo@3koo/0hook0?coo021oh7oPOn1oh7oQ_oj0?kon`3Woo/0o_oj08co
o@3koo/0hook0?coo021olgo06R1oh7oPOn1okcol03Uoo00S_om0?con`3Qoo/0
oOol087oPOn1oh7oPOn8oo00iOo`08koo@3loo/0hOok0?goo021oh7oPOn1oh7o
R?o`0>Gol02>ood0o?ok0>7on`3moo`0POo=o`1XPOn1oh7oPOnmoo00hoo`08oo
o@3moo/0gook0?koo021oh7oPOn1oh7oROo`0>?ol02?ood0oOok0=oon`3noo`0
POn1oh7oPOn1ohWol03Soo00Soom0?gon`3Ooo/0o_ol087ocOl0J87oPOn1oh7o
_Ooa0>7ol02AooX00?ok0=gon`00ooX0POn1oh7oPOn1oh[ol@3Qoo00TOoj003o
n`3Moo/00?oj087oPOn1oh7oPOn:oo40hOo`097onP00oo/0gOok003onP21olko
0521oh7oPOn1okkol@3Ooo40Toob0=_olP21oh7oPOn1oh7oSOoa0=ool@2Coo80
foob087oPOn1oh7oPOn=oo40gooa09?olP3Koo80POo@o`1@POn1oh7oPOnnoo40
goo`09GolP3Ioo80POn1oh7oPOn1ohkol@3Ooo00UOob0=WolP21oh7oPOn1oh7o
S_oa0=ool02Eoo80fOob087odOl0D87oPOn1oh7o_oo`0=ool02Foo80eoob087o
POn1oh7oPOn@oo00goo`09KolP3Goo80POn1oh7oPOn1oi3ol03Ooo00U_ob0=Oo
lP21om;o0521oh7oPOn1okool03Ooo00Uooa0=OolP21oh7oPOn1oh7oT?o`0=oo
l02Goo40eoob087oPOn1oh7oPOn@oo00goo`09Ool@3Goo80POoBo`1@POn1oh7o
POnooo00goo`09Ool@3Goo40POn1oh7oPOn1oi7ol03Ooo00Uooa0=Ool@21oh7o
POn1oh7oTOo`0=ool02Goo40eooa087odol0A87oPOn1oh7o__oa0=ool02GokL0
POn1oh7oPOn1oi3ol@3Ooo00Uong087oPOn1oh7oPOn@oo40goo`09Oo]`21om?o
04B1oh7oPOn1okkolP3Noo40U_ng087oPOn1oh7oPOn@oo80g_oa09Ko]`21oh7o
POn1oh7oT?ob0=kol@2FokL0POoCo`14POn1oh7oPOnnoo80gOob09Ko]`21oh7o
POn1oh7oT?ob0=golP2FokL0POn1oh7oPOn1oi3olP3Moo80U_ng087odol0A87o
POn1oh7o_Ooc0=com02EokL0POn1oh7oPOn1ohool`3Loo@0UOng087oPOn1oh7o
POn?oo<0g?od09Go]`21om?o0521oh7oPOn1okcom@3KooD0U?oa0=OolP21oh7o
POn1oh7oSOoe0=_om@2Doo40eoob087oPOn1oh7oPOn=ooD0fooe09Col@3Goo80
POoBo`1@POn1oh7oPOnkooL0f?oh09?ol@3Goo80POn1oh7oPOn1ohcom`3HooP0
Tooa0=OolP21oh7oPOn1oh7oS?og0=Son02Coo40eoob087od_l0D87oPOn1oh7o
^_oj0=Gon`2@oo<0eOoc087oPOn1oh7oPOn;ooX0eOok093ol`3Eoo<0POn1oh7o
POn1oh_onP3Eoo/0T?oc0=Gol`21om;o04:1oh7oPOn1oh7oSooe0=?omP21oh7o
POn1oh7oPOn1omkom@3CooH0POn1oh7oPOn1oh7oPOoNooD0doof087od?l0@X7o
POn1oh7oPOn>ooH0doof087oPOn1oh7oPOn1oh7ogOof0=?omP21oh7oPOn1oh7o
POn1omgomP3CooH0POo@o`12POn1oh7oPOn1ohcon`3>ooX0POn1oh7oPOn1oh7o
POoIoo/0c_oj087oPOn1oh7oPOn1oh7ofOok0<konP21olko0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
09X0003oSj0000000nP3j00000@0000004P000180000400P00<0200000000000
0/CjP0000003j0?X0nX3j`O@1m<0000`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
bOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1olWo04:1oh7oQoom087odoom087oPOn1oh7oPOn1olooo@21om?o
o@21oh7oPOn1oh7oPOo?ood0POoCood0POn1oh7obOl0B87oPOn7ood0POoCood0
b_oi087oPOn1oh7oPOn>ood0POoCood0b_oi087oPOn1oh7oPOn>ood0POoCood0
b_oi087oPOn8o`18POn1ohOoo@21om?oo@3<ooD0POn1oh7oPOn1oi3oo@21om?o
o@3<ooD0POn1oh7oPOn1oi3oo@21om?oo@3<ooD0POn1oh[o04R1oh7oQoom087o
doom0<gol`21oh7oPOn1oh7oTOom087odoom0<gol`21oh7oPOn1oh7oTOom087o
doom0<gol`21oh7oRol0B87oPOn7ood0POoCood0c_oa087oPOn1oh7oPOnBood0
POoCood0c_oa087oPOn1oh7oPOnBood0POoCood0c_oa087oPOn<o`1DPOn1ohOo
o@21om?oo@3?oo/0nook087oPOn1oh7oPOnCood0POoCood0cook0?_on`21oh7o
POn1oh7oToom087odoom0<oon`3koo/0POn1ohgo05B1oh7oQoom087odoom0<oo
o03hoo`0POn1oh7oPOn1oiCoo@21om?oo@3?oo`0n?ol087oPOn1oh7oPOnDood0
POoCood0cool0?Soo021oh7oS_l0E87oPOn7ood0POoCood0d?ol0?Koo@21oh7o
POn1oh7oU?om087odoom0=3oo03food0POn1oh7oPOn1oiCoo@21om?oo@3@oo`0
m_om087oPOn>o`1DPOn1ohOoo@21om?oo@3@ood0mOol087oPOn1oh7oPOnEood0
POoCood0d?om0?Goo021oh7oPOn1oh7oUOom087odoom0=3oo@3eoo`0POn1ohoo
0>Z1oh7od?om0?coo@3eooX0m?om0?con`3dood0looi0>konP3]ooX0ioom0?co
nP3_ooT0kOoj0?goo@3booX0iool0?Coo@21oh7oPOn1oh7og_om0?coo@3eooX0
m?om0?con`3dood0looi0>konP3]ooX0ioom0?conP3_ooT0kOoj0?goo@3booX0
iool0?Coo@21oh7oPOn1oh7og_om0?coo@3eooX0m?om0?con`3dood0looi0>ko
nP3]ooX0ioom0?conP3_ooT0kOoj0?goo@3booX0iool0?Coo@21oh7oSol0kH7o
POo@ood0o_ok0?Som@3food0o_of0?Ooo@3foo@0l_oe0??om@3Yood0o_of0??o
m@3aooH00Oooo@3eooD0jOom0??oo@21oh7oPOn1oh7og_om0?kon`3hooD0m_om
0?komP3good0m_od0?;om@3cooD0jOom0?komP3cooD0lOof007oood0mOoe0>Wo
o@3cood0POn1oh7oPOn1omkoo@3noo/0n?oe0?Koo@3nooH0moom0?Kom03booD0
looe0>Woo@3nooH0looe0?7omP01ooom0?Gom@3Yood0loom087oPOn?o`3cPOn1
om3oo@01oooj0?WolP3hood00Ooom03hood0mooa0?Gol`3eoo80joom007ooo@0
mOob0?Gol`00ood0m_ob0>_oo@3cood0POn1oh7oPOn1omkoo@01oooj0?WolP3h
ood00Ooom03hood0mooa0?Gol`3eoo80joom007ooo@0mOob0?Gol`00ood0m_ob
0>_oo@3cood0POn1oh7oPOn1omkoo@01oooj0?WolP3hood00Ooom03hood0mooa
0?Gol`3eoo80joom007ooo@0mOob0?Gol`00ood0m_ob0>_oo@3cood0POn1ohoo
0=j1oh7od?om003on@3joo00nOom003olP3iood0n?o_0?Ool@3goo00k?om003o
lP3goo00m_o^0?Ool03/ood0lool087oPOn1oh7oPOoOood00?oi0?[ol03iood0
0?ob0?Woo@3honl0mooa0?Ool03/ood00?ob0?Ool03fonh0moo`0>coo@3coo`0
POn1oh7oPOn1omooo@00ooT0n_o`0?Woo@00oo80nOom0?Sok`3goo40moo`0>co
o@00oo80moo`0?KokP3goo00k?om0??oo021oh7oT?l19X7oPOo@ooT0m_ok0?_o
nP3jooP0o?oj0?[oo@3ioo/0n_ok0?Son`3looX0nOok0?_onP3]ooP0o?ok0?So
n`3kooX0n?ok0?con03hoo/0nooj0>koo@3aood0POn1oh7oPOn1omoon@3foo/0
nooj0?[on03looX0n_om0?Won`3joo/0n?ok0?conP3ioo/0nooj0>gon03loo/0
n?ok0?_onP3hoo/0o?oh0?Son`3kooX0k_om0?7oo@21oh7oPOn1oh7ogooi0?Ko
n`3kooX0n_oh0?conP3jood0nOok0?[on`3hoo/0o?oj0?Won`3kooX0kOoh0?co
n`3hoo/0nooj0?Son`3looP0n?ok0?_onP3^ood0lOom087oPOn@o`4VPOn1om3o
nP3foo`0mool0?[onP3hoo`0n_om0?Woo03goo`0n_ol0?Soo03joo`0mool0>go
nP3hood0nOol0?Ooo03ioo`0n?oj0?Woo03goo`0k_om0?7oo@21oh7oPOn1oh7o
gooj0?Koo03goo`0n_oj0?Soo03jood0nOol0?Ooo03joo`0n?ol0?[oo03goo`0
kOoj0?Soo@3ioo`0mool0?Woo03hooX0nOol0?Ooo03^ood0lOom087oPOn1oh7o
POoOooX0m_ol0?Ooo03jooX0n?ol0?[oo@3ioo`0mool0?[oo03hoo`0n_ol0?Oo
o03]ooX0n?om0?Woo03goo`0nOol0?SonP3ioo`0mool0>koo@3aood0POn1oi3o
0BJ1oh7od?ok0?Goo@3eoo`0nook0?Koo03kood0n_ol0?Goo@3jood0m_om0?[o
o@3eoo`0k_ok0?Ooo03jood0mOol0?[oo@3foo/0nOom0?Goo03_ood0lOom087o
POn1oh7oPOoOoo/0mOom0?Goo03koo/0m_ol0?_oo@3joo`0mOom0?[oo@3food0
n_om0?Goo03^oo/0mool0?[oo@3eoo`0n_om0?Kon`3iood0mOol0>ooo@3aood0
POn1oh7oPOn1omoon`3eood0mOol0?_on`3foo`0noom0?[oo03eood0n_om0?Ko
o@3jood0mOol0>kon`3goo`0n_om0?Goo03jood0m_ok0?Woo@3eoo`0koom0?7o
o@21oh7oT?l19X7oPOo@oo`0mOom0??oo@3koo`0m?om0?_oo@3jood0m?om0?_o
o03foo`0o?om0??oo@3^oo`0mOom0?_oo03dood0nool0?Goo03jood0loom0>oo
o@3aood0POn1oh7oPOn1omooo03eood0loom0?_oo03dood0noom0?[oo@3dood0
nool0?Koo03lood0loom0>koo03eood0nool0?Coo@3koo`0mOol0?[oo@3cood0
koom0?7oo@21oh7oPOn1oh7ogool0?Goo@3cood0nool0?Coo@3kood0n_om0?Co
o@3koo`0m_ol0?coo@3cood0k_ol0?Goo@3koo`0m?om0?_oo03eoo`0n_om0??o
o@3_ood0lOom087oPOn@o`4VPOn1om3oo@3dood0lool0?coo03dood0noom0?[o
o@3dood0noom0?Coo@3lood0lool0>ooo03eood0noom0??oo@3kood0m?ol0?[o
o@3coo`0l?om0?7oo@21oh7oPOn1oh7ogoom0?Coo@3coo`0o?ol0?Coo@3kood0
n_om0?Coo@3kood0m?om0?coo@3coo`0kool0?Goo@3kood0loom0?_oo@3doo`0
n_om0??oo03`ood0lOom087oPOn1oh7oPOoOood0m?om0??oo03loo`0m?om0?_o
o@3jood0m?om0?_oo@3dood0o?om0??oo03_oo`0mOom0?_oo@3cood0noom0?Co
o03jood0lool0?3oo@3aood0POn1oi3o0AZ1oh7od?om0?CooP3aood0o?ol0?Co
o03lood0jOom0?_oo@3dood0o?on0?7oo@3_ood0m?om0?_oo@3bood0o?om0?Co
o03jooh0lOom0?3oo@3aood0POn1oh7oPOn1omooo@3dooh0lOom0?coo03doo`0
o?om0>Woo@3kood0m?om0?cooP3aood0koom0?Coo@3kood0l_om0?coo@3doo`0
n_on0?7oo@3`ood0lOom087oPOn1oh7oPOoOood0m?on0?7oo@3loo`0m?ol0?co
o@3Yood0noom0?Coo@3looh0lOom0>ooo@3dood0noom0?;oo@3lood0m?ol0?[o
oP3aood0l?om0?7oo@21oh7oT?l13X7oPOo@ood0mOom0?7oo@3lood0l_om0?co
o@3Zoo`0o?om0>_oo@3aood0koom0?Coo@3lood0lOom0?goo@3bood0noom0?7o
o@3`ood0lOom087oPOn1oh7oPOoOood0mOom0?7oo@3lood0l_om0?coo@3Zoo`0
o?om0>_oo@3aood0koom0?Coo@3lood0lOom0?goo@3bood0noom0?7oo@3`ood0
lOom087oPOn1oh7oPOoOood0mOom0?7oo@3lood0l_om0?coo@3Zoo`0o?om0>_o
o@3aood0koom0?Coo@3lood0lOom0?goo@3bood0noom0?7oo@3`ood0lOom087o
POn@o`3ZPOn1om3oo@3eonT0o?om0?;oo@3lood0kOoi0?coo@3[onT0koom0?Co
o@3lood0lOom0?goo@3bood0nooY0?3oo@3aood0POn1oh7oPOn1omooo@3eonT0
o?om0?;oo@3lood0kOoi0?coo@3[onT0koom0?Coo@3lood0lOom0?goo@3bood0
nooY0?3oo@3aood0POn1oh7oPOn1omooo@3eonT0o?om0?;oo@3lood0kOoi0?co
o@3[onT0koom0?Coo@3lood0lOom0?goo@3bood0nooY0?3oo@3aood0POn1oi3o
0>Z1oh7od?om0?Goj@3lood0l_om0?coo@3doo80o?om0>_oj@3_ood0m?om0?co
o@3aood0oOom0?;oo@3konT0l?om0?7oo@21oh7oPOn1oh7ogoom0?Goj@3lood0
l_om0?coo@3doo80o?om0>_oj@3_ood0m?om0?coo@3aood0oOom0?;oo@3konT0
l?om0?7oo@21oh7oPOn1oh7ogoom0?Goj@3lood0l_om0?coo@3doo80o?om0>_o
j@3_ood0m?om0?coo@3aood0oOom0?;oo@3konT0l?om0?7oo@21oh7oT?l0jX7o
POo@ood0mOoY0?coo@3bood0o?om0?Ook`3lood0jooY0>ooo@3dood0o?om0?7o
o@3mood0l_om0?_oj@3`ood0lOom087oPOn1oh7oPOoOood0mOoY0?coo@3bood0
o?om0?Ook`3lood0jooY0>ooo@3dood0o?om0?7oo@3mood0l_om0?_oj@3`ood0
lOom087oPOn1oh7oPOoOood0mOoY0?coo@3bood0o?om0?Ook`3lood0jooY0>oo
o@3dood0o?om0?7oo@3mood0l_om0?_oj@3`ood0lOom087oPOn@o`3fPOn1om3o
o@3eonT0o?om0?;oo@3lood0n?oc003oo@3lood0jooY0>ooo@3dood0o?om0?7o
o@3mood0l_om0?_oj@3`ood0lOom087oPOn1oh7oPOoOood0mOoY0?coo@3bood0
o?om0?Sol`00ood0o?om0>_oj@3_ood0m?om0?coo@3aood0oOom0?;oo@3konT0
l?om0?7oo@21oh7oPOn1oh7ogoom0?Goj@3lood0l_om0?coo@3hoo<00?om0?co
o@3[onT0koom0?Coo@3lood0lOom0?goo@3bood0nooY0?3oo@3aood0POn1oi3o
0?J1oh7od?om0?Goo@3Xood0l_om0?coo@3iooH0o?om0?coo@3[ood0foom0?Co
o@3lood0lOom0?goo@3bood0noom0=coo@3aood0POn1oh7oPOn1omooo@3eood0
j?om0?;oo@3lood0nOof0?coo@3lood0joom0=_oo@3dood0o?om0?7oo@3mood0
l_om0?_oo@3Lood0lOom087oPOn1oh7oPOoOood0mOom0>Soo@3bood0o?om0?Wo
mP3lood0o?om0>_oo@3Kood0m?om0?coo@3aood0oOom0?;oo@3kood0g?om0?7o
o@21oh7oT?l0mX7oPOo@ood0mOom0>Soo@3bood0o?om0?[on`3food0o?om0>_o
o@3Kood0m?om0?coo@3aood0oOom0?;oo@3kood0foom0??oo@21oh7oPOn1oh7o
g_om0?Goo@3Xood0l_om0?coo@3joo/0m_om0?coo@3[ood0foom0?Coo@3lood0
lOom0?goo@3bood0noom0=_oo@3cood0POn1oh7oPOn1omkoo@3eood0j?om0?;o
o@3lood0n_ok0?Koo@3lood0joom0=_oo@3dood0o?om0?7oo@3mood0l_om0?_o
o@3Kood0loom087oPOn?o`3fPOn1om3oo@3eood0j?om0?;oo@3lood0nool0?Co
o@3lood0joom0=_oo@3dood0o?om0?7oo@3mood0l_om0?_oo@3Kood0loom087o
POn1oh7oPOoNood0mOom0>Soo@3bood0o?om0?_oo03dood0o?om0>_oo@3Kood0
m?om0?coo@3aood0oOom0?;oo@3kood0foom0??oo@21oh7oPOn1oh7og_om0?Go
o@3Xood0l_om0?coo@3koo`0m?om0?coo@3[ood0foom0?Coo@3lood0lOom0?go
o@3bood0noom0=_oo@3cood0POn1ohoo0@:1oh7od?om0?Goo03Yood0loom0?_o
o@3kood0loom0?coo03dood0oOol0=coo@3dood0o?ol0??oo@3loo`0m?ol0?_o
o03Lood0loom087oPOn1oh7oPOoNood0mOol0>Woo@3cood0noom0?_oo@3cood0
o?ol0?Coo@3moo`0g?om0?Coo@3loo`0loom0?coo03doo`0nool0=coo@3cood0
POn1oh7oPOn1omkoo@3eoo`0jOom0??oo@3kood0noom0??oo@3loo`0m?om0?go
o03Lood0m?om0?coo03cood0o?ol0?Coo03koo`0g?om0??oo@21oh7oSol19X7o
POo@ood0m?om0?;oo@3loo`0m?om0?_oo@3kood0loom0?_oo@3dood0o?om0?;o
o@3_ood0m?om0?_oo@3cood0noom0?Coo03jood0l_om0>ooo@3cood0POn1oh7o
POn1omkoo@3dood0l_om0?coo03dood0noom0?_oo@3cood0noom0?Coo@3lood0
l_om0>ooo@3dood0noom0??oo@3kood0m?ol0?[oo@3bood0koom0??oo@21oh7o
POn1oh7og_om0?Coo@3bood0o?ol0?Coo@3kood0noom0??oo@3kood0m?om0?co
o@3bood0koom0?Coo@3kood0loom0?_oo@3doo`0n_om0?;oo@3_ood0loom087o
POn?o`4VPOn1om3oo@3dood0lool0?coo03eoo`0noom0?_oo@3doo`0noom0?Go
o@3kood0lool0>ooo@3dood0noom0?Coo03koo`0m_ok0?[oo@3coo`0k_om0?Go
o@21oh7oPOn1oh7ogOom0?Coo@3coo`0o?ol0?Goo03kood0noom0?Coo03kood0
mOom0?_oo@3coo`0koom0?Coo@3kood0m?ol0?_oo03foo/0n_om0??oo03^ood0
mOom087oPOn1oh7oPOoMood0m?om0??oo03loo`0mOol0?_oo@3kood0m?ol0?_o
o@3eood0noom0??oo03_ood0m?om0?_oo@3doo`0nool0?Kon`3jood0lool0>ko
o@3eood0POn1ohko0BJ1oh7od?om0?Coo03eoo`0nook0?Koo03kood0noom0?Go
n`3koo`0mool0?_oo03eoo`0k_om0?Coo@3koo`0mOom0?[oo03foo/0n_ol0?Go
o03]oo`0mool087oPOn1oh7oPOoMood0m?ol0?Goo03koo/0m_ol0?_oo@3kood0
mOok0?_oo03goo`0nool0?Goo03^ood0m?om0?_oo03eood0n_ol0?Kon`3joo`0
mOol0>goo03goo`0POn1oh7oPOn1omgoo@3doo`0mOol0?_on`3foo`0noom0?_o
o@3eoo/0nool0?Ooo03koo`0mOol0>koo@3dood0nool0?Goo@3joo`0m_ok0?[o
o03eoo`0kOol0?Ooo021oh7oS_l19X7oPOo@ood0lool0?Oon`3kooX0n?ol0?[o
o@3koo`0mooj0?[oo03hoo`0n_ol0?Oon`3^ood0m?om0?[oo03goo`0nOol0?So
nP3ioo`0mook0>coo03ioo`0POn1oh7oPOn1omcoo@3coo`0mook0?_onP3hoo`0
n_om0?_oo03gooX0n_ol0?Soo03joo`0mook0>koo@3dood0n_ol0?Ooo03ioo`0
n?oj0?Woo03goo/0k?ol0?Woo021oh7oPOn1oh7og?om0??oo03goo/0nooj0?So
o03jood0nool0?OonP3joo`0n?ol0?[oo03goo/0k_om0?Coo@3joo`0mool0?Wo
o03hooX0nOol0?Oon`3/oo`0nOol087oPOn=o`4VPOn1om3oo@3boo/0nooj0?[o
n03loo/0nOom0?[on`3kooP0nOol0?_on`3hoo/0nooj0>goo@3dood0n_oj0?_o
n`3goo/0o?oh0?Son`3kooX0jook0?conP21oh7oPOn1oh7og?om0?;on`3kooX0
n_oh0?con`3iood0n_ok0?_on03ioo`0nook0?Son`3kooX0kOom0?Coo@3jooX0
nook0?Oon`3looP0n?ok0?_onP3[oo/0o?oj087oPOn1oh7oPOoLood0l_ok0?_o
nP3jooP0o?ok0?Woo@3joo/0nooh0?Woo03koo/0n?ok0?_onP3]ood0m?om0?[o
nP3koo/0mook0?con03hoo/0nooj0>_on`3looX0POn1ohgo0=:1oh7od?om0?7o
l03iond0nOom0?[ol@00ooX0o?oa0?Kol03/ood0m?om0?Wol03foo800?om0?Oo
l03Yoo40POn1oh7oPOn1om_oo@3aoo00nOo]0?Woo@3joo400?oj0?col@3foo00
k?om0?Coo@3ioo00m_ob003oo@3goo00jOoa087oPOn1oh7oPOoKood0lOo`0?Wo
k@3iood0n_oa003onP3loo40m_o`0>coo@3dood0nOo`0?KolP00ood0moo`0>Wo
l@21oh7oS?l0hH7oPOo@ood0l?ob0?Soo@00oo<0n?om0?Wol`3noo/0noob0?Go
lP3[ood0m?om0?SolP3doo@00Oooo@3foo80iooc087oPOn1oh7oPOoJood0l?ob
0?Soo@00oo<0n?om0?Wol`3noo/0noob0?GolP3[ood0m?om0?SolP3doo@00Ooo
o@3foo80iooc087oPOn1oh7oPOoJood0l?ob0?Soo@00oo<0n?om0?Wol`3noo/0
noob0?GolP3[ood0m?om0?SolP3doo@00Oooo@3foo80iooc087oPOn;o`3QPOn1
om3oo@3_oo@0moom007oooH0m_om0?SomP3loo/0nOof0?;om03Zood0m?om0?Ko
m@3aooL0o_om0?Gom03UooD0POn1oh7oPOn1omWoo@3_oo@0moom007oooH0m_om
0?SomP3loo/0nOof0?;om03Zood0m?om0?Kom@3aooL0o_om0?Gom03UooD0POn1
oh7oPOn1omWoo@3_oo@0moom007oooH0m_om0?SomP3loo/0nOof0?;om03Zood0
m?om0?Kom@3aooL0o_om0?Gom03UooD0POn1oh[o0::1oh7o^?oi0?Coo@3mooX0
iOoj0?Woo03gooX0k_oi0<Gon@3]oo/0j_oi0>3onP21oh7oPOn1oh7o__oi0?Co
o@3mooX0iOoj0?Woo03gooX0k_oi0<Gon@3]oo/0j_oi0>3onP21oh7oPOn1oh7o
__oi0?Coo@3mooX0iOoj0?Woo03gooX0k_oi0<Gon@3]oo/0j_oi0>3onP21oh7o
Qol0>87oPOnSood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0
POn1oh7oPOn1oo_o03R1oh7oXoom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7o
POn1oh7oWOom087oPOn1oh7oPOoko`0hPOn1oj?oo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7onol0>87oPOnSood0POn1oh7o
POn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oo_o03R1oh7o
Xoom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7o
POoko`0hPOn1oj?oo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7onol0>87oPOnSood0POn1oh7oPOn1oh7oPOnMood0POn1oh7o
POn1oh7oPOnMood0POn1oh7oPOn1oo_o03R1oh7oXoom087oPOn1oh7oPOn1oh7o
WOom087oPOn1oh7oPOn1oh7oWOom087oPOn1oh7oPOoko`0hPOn1oj?oo@21oh7o
POn1oh7oPOn1oigoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oPOn1oh7onol0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0f
0021oh7oPOn1oh7oPOn1oi[o0021oh7oPOn1oh7oPOn1oi[o0021oh7oPOn1oh7o
POn1oi[o03Kn087oPOn1oh7oPOn1oh7oW?on087oPOn1oh7oPOn1oh7oW?on087o
POn1oh7oPOn1oh7oW?l0=_/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7o
POnOoo/0POn1oh7oPOn1oh7oPOnOo`0fn@21oh7oPOn1oh7oPOn1oj7on@21oh7o
POn1oh7oPOn1oj7on@21oh7oPOn1oh7oPOn1oj7o03Kg087oPOn1oh7oPOn1oh7o
Xoog087oPOn1oh7oPOn1oh7oXoog087oPOn1oh7oPOn1oh7oXol0>03omP21oh7o
POn1oh7oPOn1ojComP21oh7oPOn1oh7oPOn1ojComP21oh7oPOn1oh7oPOn1ojGo
03SmooH0POn1oh7oPOn1oh7oPOnTooH0POn1oh7oPOn1oh7oPOnTooH0POn1oh7o
POn1oh7oPOnXo`0hnoof087oPOn1oh7oPOn1oh7oY?of087oPOn1oh7oPOn1oh7o
Y?of087oPOn1oh7oPOn1oh7oZ_l0>?WomP21oh7oPOn1oh7oPOn1ojComP21oh7o
POn1oh7oPOn1ojComP21oh7oPOn1oh7oPOn1ojco03SgooH0POn1oh7oPOn1oh7o
POnTooH0POn1oh7oPOn1oh7oPOnTooH0POn1oh7oPOn1oh7oPOn^o`0hm?of087o
POn1oh7oPOn1oh7oY?of087oPOn1oh7oPOn1oh7oY?of087oPOn1oh7oPOn1oh7o
/Ol0>?;omP21oh7oPOn1oh7oPOn1ojComP21oh7oPOn1oh7oPOn1ojComP21oh7o
POn1oh7oPOn1ok?o03S`ooH0POn1oh7oPOn1oh7oPOnTooH0POn1oh7oPOn1oh7o
POnTooH0POn1oh7oPOn1oh7oPOneo`12003_ooH0POn1oh7oPOn1oh7oPOngo`00
koof087oPOn1oh7oPOn1oh7o]ol00>oomP21oh7oPOn1oh7oPOn1okOo04;n0>ko
mP21oh7oPOn1oh7oPOn1ok[ooP3^ooH0POn1oh7oPOn1oh7oPOnjooh0k_of087o
POn1oh7oPOn1oh7o^_l0@_/0koof087oPOn1oh7oPOn1oh7o_?ok0>oomP21oh7o
POn1oh7oPOn1okcon`3_ooH0POn1oh7oPOn1oh7oPOnlo`12n@3_ooH0POn1oh7o
POn1oh7oPOnnooT0koof087oPOn1oh7oPOn1oh7o__oi0>oomP21oh7oPOn1oh7o
POn1okko04;g0>oomP21oh7oPOn1oh7oPOn1ol3om`3_ooH0POn1oh7oPOn1oh7o
POo0ooL0koof087oPOn1oh7oPOn1oh7o`?l0@_D0k_of087oPOn1oh7oPOn1oh7o
`ooe0>komP21oh7oPOn1oh7oPOn1ol?om@3^ooH0POn1oh7oPOn1oh7oPOo3o`12
lP3_ooH0POn1oh7oPOn1oh7oPOo5oo80koof087oPOn1oh7oPOn1oh7oaOob0>oo
mP21oh7oPOn1oh7oPOn1olGo04;`0>oomP21oh7oPOn1oh7oPOn1olOol03_ooH0
POn1oh7oPOn1oh7oPOo7oo00koof087oPOn1oh7oPOn1oh7oaol0@^h0kooe087o
POn1oh7oPOn1oh7ob_o^0>oom@21oh7oPOn1oh7oPOn1ol[okP3_ooD0POn1oh7o
POn1oh7oPOo:o`140?o]0>komP21oh7oPOn1oh7oPOn1ol_ok@3^ooH0POn1oh7o
POn1oh7oPOo;ond0k_of087oPOn1oh7oPOn1oh7oc?l0A?kok03_ooH0POn1oh7o
POn1oh7oPOo;on`0koof087oPOn1oh7oPOn1oh7oboo/0>oomP21oh7oPOn1oh7o
POn1olko04Ckond0koof087oPOn1oh7oPOn1oh7ob_o]0>oomP21oh7oPOn1oh7o
POn1ol[ok@3_ooH0POn1oh7oPOn1oh7oPOo@o`1AnOo]0>komP21oh7oe_l0087o
POn1oh7oPOogond0k_of087oPOoFo`00POn1oh7oPOn1ooOok@3^ooH0POn1omKo
0021oh7oPOn1oh7o0Ooo06kgond0k_of087oPOoKooX0fOoi087onook0=con`21
oh7oPOoOond0k_of087oPOoKooX0fOoi087onook0=con`21oh7oPOoOond0k_of
087oPOoKooX0fOoi087onook0=con`21oh7oPOoYo`1^mOo/0>oomP21oh7og_oh
0=_om`21ooconP3MooX0POn1oh7og_o/0>oomP21oh7og_oh0=_om`21ooconP3M
ooX0POn1oh7og_o/0>oomP21oh7og_oh0=_om`21ooconP3MooX0POn1oh7oj_l0
K_;ok@3_ooH0POn1on;om03NooD0POl0ooD0h_oe087oPOn1omgok@3_ooH0POn1
on;om03NooD0POl0ooD0h_oe087oPOn1omgok@3_ooH0POn1on;om03NooD0POl0
ooD0h_oe087oPOn1onco06S`ond0k_of087oPOoUoo<0h?oc08;ol`3Soo@0POn1
oh7og?o]0>komP21oh7oiOoc0>3ol`22oo<0hood087oPOn1omcok@3^ooH0POn1
onGol`3Poo<0P_oc0>?om021oh7oPOo]o`1Xk_o/0>oomP21oh7oj?ob0>7ol@23
oo80iOob087oPOn1om_ok03_ooH0POn1onSolP3Qoo40Poob0>GolP21oh7oPOoK
on`0koof087oPOoXoo80hOoa08?olP3Uoo80POn1oh7ok_l0J>cok03_ooH0POn1
on[olP3Qoo40Q?oa0>GolP21oh7oPOoIon`0koof087oPOoZoo80hOoa08Col@3U
oo80POn1oh7ofOo/0>oomP21oh7oj_ob0>7ol@24oo40iOob087oPOn1onko06SY
ond0koof087oPOo/oo40h_oa08Col@3Uoo40POn1oh7oeoo]0>oomP21oh7ok?oa
0>;ol@24oo40iOoa087oPOn1omOok@3_ooH0POn1oncol@3Roo40Q?oa0>Gol@21
oh7oPOo_o`1Lioo]0>komP21oh7ol?o`0>;ol@24olD0POn1oh7oeOo]0>komP21
oh7ol?o`0>;ol@24olD0POn1oh7oeOo]0>komP21oh7ol?o`0>;ol@24olD0POn1
oh7okol0G>Gok03_ooH0POn1oo;ol03Roo40Q?o5087oPOn1om?ok03_ooH0POn1
oo;ol03Roo40Q?o5087oPOn1om?ok03_ooH0POn1oo;ol03Roo40Q?o5087oPOn1
onoo05cSon`0koof087oPOocoo40h_oa08Coa@21oh7oPOoAon`0koof087oPOoc
oo40h_oa08Coa@21oh7oPOoAon`0koof087oPOocoo40h_oa08Coa@21oh7oPOo_
o`1Lh?o]0>oomP21oh7omOob0>7ol@24olD0POn1oh7oc_o]0>oomP21oh7omOob
0>7ol@24olD0POn1oh7oc_o]0>oomP21oh7omOob0>7ol@24olD0POn1oh7okol0
J=kok@3^ooH0POn1ooSolP3Qoo40Q?oa0>GolP21oh7oPOo;ond0k_of087oPOoh
oo80hOoa08Col@3Uoo80POn1oh7oboo]0>komP21oh7on?ob0>7ol@24oo40iOob
087oPOn1onko06SLon`0koof087oPOoioo<0h?oc08;olP3Uoo80POn1oh7obOo/
0>oomP21oh7onOoc0>3ol`22oo80iOob087oPOn1olWok03_ooH0POn1ooWol`3P
oo<0P_ob0>GolP21oh7oPOo^o`1Xf_o/0>oomP21oh7onooc0=oom021oo@0hood
087oPOn1olKok03_ooH0POn1oo_ol`3Ooo@0POod0>?om021oh7oPOo6on`0koof
087oPOokoo<0good087om03Soo@0POn1oh7okOl0K]Ook@3_ooH0POn1oocol`3P
ooD0POl0ooD0h_oe087oPOn1ol;ok@3_ooH0POn1oocol`3PooD0POl0ooD0h_oe
087oPOn1ol;ok@3_ooH0POn1oocol`3PooD0POl0ooD0h_oe087oPOn1onco07CE
ond0k_of087oPOomoo@0h_og0<3ooP2oooL0hOog087oPOn1okook@3^ooH0POn1
oogom03RooL0`?on0;oom`3QooL0POn1oh7o_oo]0>komP21oh7ooOod0>;om`30
ooh0_oog0>7om`21oh7oPOo[o`1ddoo/0>oomP21oh7omool0>?oo02joo`0`?oh
0>7on021oh7oPOnlon`0koof087oPOogoo`0hool0;[oo030ooP0hOoh087oPOn1
okcok03_ooH0POn1ooOoo03Soo`0^_ol0<3on03QooP0POn1oh7oj_l0M=7ok03_
ooH0POn1ooSoo03Uoo`0^Ooi0;goo@3Soo`0POn1oh7o]Oo/0>oomP21oh7on?ol
0>Goo02iooT0_Oom0>?oo021oh7oPOneon`0koof087oPOohoo`0iOol0;Won@2m
ood0hool087oPOn1onGo07C>ond0koof087oPOoioo`0iool0;SomP30ood0hool
087oPOn1ok;ok@3_ooH0POn1ooWoo03Woo`0^?of0<3oo@3Soo`0POn1oh7o/_o]
0>oomP21oh7onOol0>Ooo02hooH0`?om0>?oo021oh7oPOoUo`1dc?o]0>komP21
oh7onool0>Woo02goo<0`_om0>Goo021oh7oPOn_ond0k_of087oPOokoo`0jOol
0;Ool`32ood0iOol087oPOn1ojook@3^ooH0POn1oo_oo03Yoo`0]ooc0<;oo@3U
oo`0POn1oh7oi?l0M<[ok03_ooH0POn1oogon`3[oo`0]_oa0<Coo@3Voo/0POn1
oh7o[Oo/0>oomP21oh7ooOok0>_oo02foo40a?om0>Kon`21oh7oPOn]on`0koof
087oPOomoo/0jool0;Kol@34ood0i_ok087oPOn1onCo07C8on`0koof087oPOon
oo`0k?ol0;GokP36ooh0i_ol087oPOn1oj[ok03_ooH0POn1ookoo03/oo`0]Oo^
0<KooP3Voo`0POn1oh7oZ_o/0>oomP21oh7oo_ol0>coo02eonh0a_on0>Koo021
oh7oPOoSo`1gaOo]0>oomP21oh7o0Oooo03_oo/0]?o[0<Woo@3Xoo`0POn1oh7o
Y_o]0>oomP21oh7o0Oooo03_oo/0]?o[0<Woo@3Xoo`0POn1oh7oY_o]0>oomP21
oh7o0Oooo03_oo/0]?o[0<Woo@3Xoo`0POn1oh7oh_l0K/?ok@3^ooH0POn1oo`0
lOok0;?oj@3:ooh0j?ol087oPOn1ojCok@3^ooH0POn1oo`0lOok0;?oj@3:ooh0
j?ol087oPOn1ojCok@3^ooH0POn1oo`0lOok0;?oj@3:ooh0j?ol087oPOn1on;o
07[1on`0koof087oP_ol0?gon`3moo/0/_oV0<goo@3Zoo`0POn1oh7oXOo/0>oo
mP21oh;oo03moo/0oOok0;;oiP3=ood0j_ol087oPOn1oj7ok03_ooH0POn2oo`0
oOok0?gon`2bonH0cOom0>[oo021oh7oPOoQo`1m_oo/0>oomP21oh?oo03nooX0
0Ooon`2aon<0coon0>[oo021oh7oPOnOon`0koof087oPool0?konP01oook0;7o
h`3?ooh0j_ol087oPOn1oiook03_ooH0POn3oo`0o_oj007ooo/0/OoS0<oooP3Z
oo`0POn1oh7ohOl0H[cok@3_ooH0POn5on/0/?oP0=;oo@3/oo`0POn1oh7oVoo]
0>oomP21ohGoj`2`on00d_om0>coo021oh7oPOnKond0koof087oQOo[0;3oh03B
ood0k?ol087oPOn1on3o06:jond0k_of087oQoo]0:oogP3Dood0k?ol087oPOn1
oiWok@3^ooH0POn7ond0[ooN0=Coo@3/oo`0POn1oh7oVOo]0>komP21ohOok@2_
omh0e?om0>coo021oh7oPOoPo`1R^?o/0>oomP21ohSok`2^om/0e_om0>koo021
oh7oPOnFon`0koof087oR?o_0:kof`3Food0k_ol087oPOn1oiKok03_ooH0POn8
onl0[_oK0=Koo@3^oo`0POn1oh7ogol0H[Kok03_ooH0POn9oo40fonZ0=Woo@3^
oo`0POn1oh7oU?o/0>oomP21ohWol@3KojX0fOom0>koo021oh7oPOnDon`0koof
087oROoa0=_oZP3Iood0k_ol087oPOn1omoo06:cond0koof087oRoo`0=coZ03J
ood0l?ol087oPOn1oi3ok@3_ooH0POn;oo00g?nX0=[oo@3`oo`0POn1oh7oT?o]
0>oomP21oh_ol03LojP0f_om0?3oo021oh7oPOoNo`1R/Oo]0>komP21ohkol03L
ojD0gOom0?3oo021oh7oPOn>ond0k_of087oS_o`0=coY@3Mood0l?ol087oPOn1
ohkok@3^ooH0POn>oo00g?nU0=goo@3`oo`0POn1oh7og_l0HZook03_ooH0POn@
oo00g?nX0=Woo@3boo`0POn1oh7oRoo/0>oomP21oi3ol03LojP0fOom0?;oo021
oh7oPOn;on`0koof087oT?o`0=coZ03Iood0l_ol087oPOn1omgo06:]on`0koof
087oT_o`0:kof@3Food0look087oPOn1ohWok03_ooH0POnBoo00[_oI0=Koo@3c
oo/0POn1oh7oROo/0>oomP21oi;ol02^omT0e_om0??on`21oh7oPOoMo`1RZ_o]
0>oomP21oiCol@2]om`0doom0??oo021oh7oPOn5ond0koof087oU?oa0:gog03C
ood0lool087oPOn1ohGok@3_ooH0POnDoo40[OoL0=?oo@3coo`0POn1oh7og?l0
HZSok@3^ooH0POnFoo80[OoN0=3oo@3eoo`0POn1oh7oP_o]0>komP21oiKolP2]
omh0d?om0?Goo021oh7oPOn2ond0k_of087oU_ob0:gogP3@ood0mOol087oPOn1
om_o06JVon`0koof087oV?ob0:goh@3=ood0mOol087oPOn1oh7o0?o/0>oomP21
oiSolP2]on40cOom0?Goo021oh7oPOn1o`3ok03_ooH0POnHoo80[OoQ0<goo@3e
oo`0POn1oh7ofol0IZCok03_ooH0POnIoo@0[?oT0<Woo@3goo`0POn1oh7oPOom
on`0koof087oVOod0:coi039ood0mool087oPOn1oh7ooOo/0>oomP21oiWom02/
on@0bOom0?Ooo021oh7oPOoJo`1VXOo]0>oomP21oi_om@2[onL0a_om0?Ooo021
oh7oPOn1oo[ok@3_ooH0POnKooD0ZooW0<Koo@3goo`0POn1oh7oPOojond0koof
087oVooe0:_oi`36ood0mool087oPOn1om[o06JOond0k_of087oW?oh0:[ojP32
ood0nOol087oPOn1oh7omoo]0>komP21oicon02ZonX0`_om0?Woo021oh7oPOn1
ooOok@3^ooH0POnLooP0Z_oZ0<;oo@3ioo`0POn1oh7ofOl0IYgok03_ooH0POnM
oo/0Z?o]0;ooo@3ioo`0POn1oh7oPOoeon`0koof087oWOok0:Sok@2oood0nOol
087oPOn1oh7omOo/0>oomP21oigon`2Xond0_oom0?Woo021oh7oPOoIo`1VVoo/
0>oomP21oikoo02Xoo00_?ol0?_oo021oh7oPOn1oo;ok03_ooH0POnNoo`0Z?o`
0;coo03koo`0POn1oh7oPOobon`0koof087oW_ol0:Sol02loo`0nool087oPOn1
omSo06JHond0koof087oX?ol0:Sol`2hood0nool087oPOn1oh7okoo]0>oomP21
oj3oo02Xoo<0^?om0?_oo021oh7oPOn1onook@3_ooH0POnPoo`0Z?oc0;Soo@3k
oo`0POn1oh7of?l0IYKok@3^ooH0POnSoo`0Z?oe0;Koo03moo`0POn1oh7oPOo/
ond0k_of087oXool0:Som@2foo`0oOol087oPOn1oh7ok?o]0>komP21oj?oo02X
ooD0]_ol0?goo021oh7oPOoGo`1VU?o/0>oomP21ojGoo02XooP0/_om0?kon`21
oh7oPOn1on[ok03_ooH0POnUoo`0Z?oh0;;oo@3noo/0POn1oh7oPOoZon`0koof
087oYOol0:Son02bood0o_ok087oPOn1omOo05ZBon`0koof087oYool0:Son`2_
ooD0POn1oh7oPOoWon`0koof087oYool0:Son`2_ooD0POn1oh7oPOoWon`0koof
087oYool0:Son`2_ooD0POn1oh7oe_l0FXook@3_ooH0POnYoo`0Z?on0:_omP21
oh7oPOn1onCok@3_ooH0POnYoo`0Z?on0:_omP21oh7oPOn1onCok@3_ooH0POnY
oo`0Z?on0:_omP21oh7oPOoFo`1DSOo]0>komP21ojcoo021oloom@21oh7oPOn1
on?ok@3^ooH0POn/oo`0POo?ooD0POn1oh7oPOoSond0k_of087o[?ol087ocooe
087oPOn1omOo05B;on`0koof087o[_ol087od?oc087oPOn1oh7oh_o/0>oomP21
ojkoo021om3ol`21oh7oPOn1on;ok03_ooH0POn^oo`0POo@oo<0POn1oh7of?l0
E8Wok03_ooH0POn`oo`0POoAoo80POn1oh7oPOoPon`0koof087o/?ol087odOob
087oPOn1oh7oh?o/0>oomP21ok3oo021om7olP21oh7oPOoHo`1DQ_o]0>oomP21
ok;oo021om7olP21oh7oPOn1omgok@3_ooH0POnboo`0POoAoo80POn1oh7oPOoM
ond0koof087o/_ol087odOob087oPOn1omSo05B4ond0k_of087o]Ool087odOoa
087oPOn1oh7og?o]0>komP21okGoo021om7ol@21oh7oPOn1omcok@3^ooH0POne
oo`0POoAoo40POn1oh7ofOl0E8;ok03_ooH0POngoo`0POoBoo00POn1oh7oPOoJ
on`0koof087o]ool087od_o`087oPOn1oh7of_o/0>oomP21okOoo021om;ol021
oh7oPOoIo`1FPOl0on`0koof087o^_oi087oe?o`087oPOn1oh7of?o/0>oomP21
ok[on@21omCol021oh7oPOn1omSok03_ooH0POnjooT0POoDoo00POn1oh7ofOl0
EX7ooOo]0>oomP21okkom@21omGol@21oh7oPOn1omGok@3_ooH0POnnooD0POoE
oo40POn1oh7oPOoEond0koof087o__oe087oeOoa087oPOn1omWo05J1oo_ok@3^
ooH0POo2oo<0POoFoo80POn1oh7oPOoBond0k_of087o`_oc087oe_ob087oPOn1
oh7od_o]0>komP21ol;ol`21omKolP21oh7oPOoHo`1FPOoion`0koof087oa?ob
087oeoob087oPOn1oh7od?o/0>oomP21olColP21omOolP21oh7oPOn1om3ok03_
ooH0POo4oo80POoGoo80POn1oh7of?l0EX7omoo/0>oomP21olOol@21omOolP21
oh7oPOn1olkok03_ooH0POo7oo40POoGoo80POn1oh7oPOo>on`0koof087oaooa
087oeoob087oPOn1omSo05J1ooCok@3_ooH0POo9oo40POoFoo<0POn1oh7oPOo;
ond0koof087obOoa087oe_oc087oPOn1oh7oboo]0>oomP21olWol@21omKol`21
oh7oPOoHo`1FPOobon`0koof087oc?oa087oeOoe087oPOn1oh7ob?o/0>oomP21
olcol@21omGom@21oh7oPOn1olSok03_ooH0POo<oo40POoEooD0POn1oh7oeol0
EX7ol?o/0>oomP21olkol@21omCom`21oh7oPOn1olGok03_ooH0POo>oo40POoD
ooL0POn1oh7oPOo5on`0koof087oc_oa087oe?og087oPOn1omKo04Z1onkok03_
ooH0POo@oo40POn1oh7oPOn1ohcok03_ooH0POo@oo40POn1oh7oPOn1ohcok03_
ooH0POo@oo40POn1oh7oPOnOo`1:POo[ond0koof087od_oa087oPOn1oh7oPOn9
ond0koof087od_oa087oPOn1oh7oPOn9ond0koof087od_oa087oPOn1oh7oWol0
BX7ojOo/0>oomP21omGol@21oh7oPOn1oh7oQoo/0>oomP21omGol@21oh7oPOn1
oh7oQoo/0>oomP21omGol@21oh7oPOn1oioo04Z1onOok03_ooH0POoGoo40POn1
oh7oPOn1ohGok03_ooH0POoGoo40POn1oh7oPOn1ohGok03_ooH0POoGoo40POn1
oh7oPOnOo`1:POoUon`0koof087of?oc087oPOn1oh7oPOn2on`0koof087of?oc
087oPOn1oh7oPOn2on`0koof087of?oc087oPOn1oh7oW_l0CX7oh_o]0>oomP21
omWom@21oh7oPOn1oh7oPOonond0koof087ofOoe087oPOn1oh7oPOn1ookok@3_
ooH0POoIooD0POn1oh7oPOnMo`1>POoPon`0koof087ofoog087oPOn1oh7oPOn1
oo_ok03_ooH0POoKooL0POn1oh7oPOn1oh7onoo/0>oomP21om_om`21oh7oPOn1
oico04j1omkok03_ooH0POoKoo/0POn1oh7oPOn1oh7omoo/0>oomP21om_on`21
oh7oPOn1oh7oPOogon`0koof087ofook087oPOn1oh7oV_l0A87og?o/0>oomP21
oh7oPOn1oh7oPOn1ol_ok03_ooH0POn1oh7oPOn1oh7oPOo;on`0koof087oPOn1
oh7oPOn1oo3o04B1omWok@3_ooH0POn1oh7oPOn1oh7oPOo:ond0koof087oPOn1
oh7oPOn1oh7ob_o]0>oomP21oh7oPOn1oh7oPOobo`14POoGon`0koof087oPOn1
oh7oPOn1oh7oboo/0>oomP21oh7oPOn1oh7oPOn1ol_ok03_ooH0POn1oh7oPOn1
oh7omOl0A87oeOo/0>oomP21oh7oPOn1oh7oPOn1ol_ok03_ooH0POn1oh7oPOn1
oh7oPOo;on`0koof087oPOn1oh7oPOn1ooOo04B1om?ok03_ooH0POn1oh7oPOn1
oh7oPOo;on`0koof087oPOn1oh7oPOn1oh7oboo/0>oomP21oh7oPOn1oh7oPOoi
o`14POo@ond0koof087oPOn1oh7oPOn1oh7ob_o]0>oomP21oh7oPOn1oh7oPOn1
ol[ok@3_ooH0POn1oh7oPOn1oh7onol0A87oc_o/0>oomP21oh7oPOn1oh7oPOn1
ol_ok03_ooH0POn1oh7oPOn1oh7oPOo;on`0koof087oPOn1oh7oPOn1ooko04B1
olcok03_ooH0POn1oh7oPOn1oh7oPOo;on`0koof087oPOn1oh7oPOn1oh7oboo/
0>oomP21oh7oPOn1oh7oPOl0o`12POo:on`0koof087oPOn1oh7oPOn1oh7oboo/
0>oomP21oh7oPOn1oh7oPOn1ol_ok03_ooH0POn1oh7oPOn1oh;o04:1olOok@3_
ooH0POn1oh7oPOn1oh7oPOo:ond0koof087oPOn1oh7oPOn1oh7ob_o]0>oomP21
oh7oPOn1oh7oQ?l0@X7oaOo/0>oomP21oh7oPOn1oh7oPOn1ol_ok03_ooH0POn1
oh7oPOn1oh7oPOo;on`0koof087oPOn1oh7oPOn7o`12POo3on`0koof087oPOn1
oh7oPOn1oh7oboo/0>oomP21oh7oPOn1oh7oPOn1ol_ok03_ooH0POn1oh7oPOn1
ohWo04:1ol7ok03_ooH0POn1oh7oPOn1oh7oPOo;on`0koof087oPOn1oh7oPOn1
oh7oboo/0>oomP21oh7oPOn1oh7oRol0@X7o__o]0>oomP21oh7oPOn1oh7oPOn1
ol[ok@3_ooH0POn1oh7oPOn1oh7oPOo:ond0koof087oPOn1oh7oPOn=o`1>POnl
on`0koof0>_om021oh7oPOn1oh7oPOn1onkok03_ooH0jood087oPOn1oh7oPOn1
oh7ok_o/0>oomP3[oo@0POn1oh7oPOn1ok?o04j1ok[ok03_ooH0l?o^087oPOn1
oh7oPOn1oh7okoo/0>oomP3`onh0POn1oh7oPOn1oh7oPOo_on`0koof0?3okP21
oh7oPOn1oh7o]_l0CX7o^?o/0>oomP3eonP0POn1oh7oPOn1oh7oPOo`on`0koof
0?Goj021oh7oPOn1oh7oPOn1oo3ok03_ooH0mOoX087oPOn1oh7oPOnio`1>POne
ond0koof0?Woi021oh7oPOn1oh7oPOn1onook@3_ooH0nOoT087oPOn1oh7oPOn1
oh7okoo]0>oomP3ion@0POn1oh7oPOn1ok_o04j1ok?ok03_ooH0oOoR087oPOn1
oh7oPOn1oh7ok_o/0>oomP3mon80POn1oh7oPOn1oh7oPOo^on`0koof0?gohP21
oh7oPOn1oh7o_?l0@X7o/Oo/0>ood`21oh7oPOn1oh7oPOn1onkok03_om<0POn1
oh7oPOn1oh7oPOo^on`0kooC087oPOn1oh7oPOnno`12POn_on`0kooC087oPOn1
oh7oPOn1oh7ok_o/0>ood`21oh7oPOn1oh7oPOn1onkok03_om<0POn1oh7oPOn1
ol3o04:1ojcok@3_om@0POn1oh7oPOn1oh7oPOo/ond0kooD087oPOn1oh7oPOn1
oh7ok?o]0>ooe021oh7oPOn1oh7o`Ol0B87oZ_o/0?3oe@21oh7oPOn1oh7odOob
087oZ_o/0?3oe@21oh7oPOn1oh7odOob087oZ_o/0?3oe@21oh7oPOn1oh7odOob
0018POnXon`0looC087oPOn1oh7oPOoRon80POnXon`0looC087oPOn1oh7oPOoR
on80POnXon`0looC087oPOn1oh7oPOoRon8004R1ojKok03fom40POn1oh7oPOn1
ooCod@21ojKok03fom40POn1oh7oPOn1ooCod@21ojKok03fom40POn1oh7oPOn1
ooCod@00@X7oXoo]0?Sod021oh7oPOn1ohKo`021oj?ok@3hom00POn1oh7oPOn6
ol00POnSond0n?o@087oPOn1oh7oQ_o00012POnQon`0o?o>087oPOn1oh7oUon`
087oXOo/0?cocP21oh7oPOn1oiOo/021oj7ok03lolh0POn1oh7oPOnGok0004F1
oiook001ooo=087oPOn1oh7oZ?nO087oWoo/007oold0POn1oh7oPOnXoil0POnO
on`00Oooc@21oh7oPOn1ojSoW`00=X7oWOng087oPOn1oh7o^_n>087oWOng087o
POn1oh7o^_n>087oWOng087oPOn1oh7o^_n>000lPOnJokT0POn1oh7oPOo;oh40
oP21oi[o^@21oh7oPOn1ol_oP@3n087oV_ni087oPOn1oh7obon10?h003j1oiSo
^`21oh7oPOn1omcoP@3k087oR_nk087oPOn1oh7og?n10?/0POn:ok/0POn1oh7o
POoLoh40n`3co`12POnFok`0POn1oh7oPOo]oh40o021oh7omonl087oPOn1oh7o
kOn10?`0POn1ooOo_021oh7oPOn1ongoP@3l0>;o04:1oiCo_P21oh7oPOn1ooko
P@3k087oPOoUokh0POn1oh7oPOonoh40n`21oh7oiOnn087oPOn1oh7oo_n10?/0
d_l0?87oU?nm087oPOn1oi3oP@3k087oPOoDokd0POn1oh7oT?n10?/0POn1omCo
_@21oh7oPOn@oh40n`31o`18POnTojd0k_oj087oPOn1ok[oP@3l087oPOoCojd0
k_oj087oPOn1ok[oP@3l087oPOoCojd0k_oj087oPOn1ok[oP@3l0;3o05B1okCo
W@3`ooD0POn1onCom021ooSoP@3k087oPOoCoid0l?oe087oPOoToo@0POohoh40
n`21oh7odonM0?3om@21oh7oi?od087on?n10?/0X?l0CX7oaOn;0??olP21oh7o
j?o^08coP@3k087oPOoCoh/0loob087oPOoXonh0S?n10?/0POn1om?oR`3coo80
POn1onSokP2<oh40n`2?o`1FPOoEoh40n`3doo00POn1oncoj02Ooh40o021oh7o
d_n10?/0m?o`087oPOo/onP0Won10?`0POn1om;oP@3k0?Col021oh7ok?oX09oo
P@3l087oo_l0LX7oiOna0?Soa03doo/0nook087oPOo_on@0/_n10?/0POojooD0
POoUok40n?o40?Con`3koo/0POn1onooi02boh40n`21oo[om@21onGo/@3hol@0
m?ok0?_on`21oh7okooT0;;oP@3k087on_oe001bPOoeok80ioo40?Goo03hoo`0
POn1oo;og`35oh40n`21oo_oh`21ooGo/P3Wol@0mOol0?Soo021oh7ol_oO0<Go
P@3k087onooS087omOnb0>Ooa03eoo`0n?ol087oPOoboml0aOn10?/0POokon<0
06b6ok80eoo20?Koo@3foo`0POn1oo?ogP3Foh40o021oo_odP26ok80eoo20?Ko
o@3foo`0POn1oo?ogP3Foh40o021oo_odP26ok80eoo20?Koo@3foo`0POn1oo?o
gP3Foh40o021oo_odP00K9Ko/`36ol80m_om0?Goo@21oh7omOoJ0>WoP@3k087o
oOo009Ko/`36ol80m_om0?Goo@21oh7omOoJ0>WoP@3k087ooOo009Ko/`36ol80
m_om0?Goo@21oh7omOoJ0>WoP@3k087ooOo0001/Y_nd0;Go`P3goo`0mOom087o
POofomP0non10?/0POomojl0Y_nd0;Go`P3goo`0mOom087oPOofomP0non10?/0
POomojl0Y_nd0;Go`P3goo`0mOom087oPOofomP0non10?/0POomojl006:fokD0
Y?o20?Ooo@3dood0POn1ooSoP@3K087ooOn_0:Go]@2Tol80moom0?Coo@21oh7o
n?n10=/0POomojl0YOne0:Co`P3good0m?om087oPOohoh40f`21oogo[`3`o`1U
aond09Co`P3good0m?om087oPOoioh40jP21o`7oojl0Y?nd09Co`P3good0m?om
087oPOoioh40jP21o`7oojl0Y?nd09Co`P3good0m?om087oPOoioh40jP21o`7o
ojl0g_l0IMOo]@23ol80moom0?Coo@21oh7on_n10?X0POl1oon`0:;o]@23ol80
moom0?Coo@21oh7on_n10?X0POl1oon`0:;o]@23ol80moom0?Coo@21oh7on_n1
0?X0POl1oon`0<co05cWokH0POl1oone0>Ooo021oh7onon:087o0Ooo/@2PokH0
POl1oone0>Ooo021oh7onon:087o0Ooo/@2PokH0POl1oone0>Ooo021oh7onon:
087o0Ooo/@2jo`1In?nf087o0OooY@3Woo`0POn1oo_oVP21o`3o/@2OokH0POl1
oonU0>Ooo021oh7ononJ087o0?na09oo]P21o`7oojD0iool087oPOokoiX0POl0
ok40Z?l0C[h0POonoiD0j?ok087oPOolojT0POnb09Ko_P21ookoU@3Xoo/0POn1
oocoZ@21ok80U_nn087oo_nE0>Son`21oh7oo?nY087o/P2Fo`1@c`21ookoQ03^
ooH0POn1oo_o^P21ok<0Qoo<087oo_n40>komP21oh7ononj087o/`27ol`0POon
oh@0k_of087oPOokokX0POnc08OooP00FMl0POl1oon10?<0k_oh087oPOojolT0
Ponc08Kob`21o`7ooh40l`3^ooP0POn1oo[ob@23ok<0Q_o;087o0OooP@3c0>ko
n021oh7on_o908?o/`26ond0063`087oo_n10>@0kOof087oPOololP0UOnd08Co
h03noo00POonoh40i03]ooH0POn1oocob02Eok@0Q?oP0?kol021ookoP@3T0>go
mP21oh7oo?o809Go]024on00o_l0FH7oo_n10=<0kOod087oPOl1ooo70:Ko]@23
on00POoZoh40d`3]oo@0POn1o`7oolL0Y_ne08?oh021on[oP@3C0>gom021oh7o
0Oooa`2VokD0PooP0>go05B?oh40``3VooT0POn1o`3oa`2hokD0P_oO087ojon1
0<<0i_oi087oPOl0olL0^?ne08;og`21on_oP@330>Kon@21oh7o0?o70;So]@22
oml0gOl0IP00X?n10?/0loo70>?oo021oh7o0?o60<[o]P21oml0c?l00:3oP@3k
0??oa`3Soo`0POn1o`3oaP3:okH0POoO0<co002Poh40n`3colL0hool087oPOl0
olH0b_nf087og`3<o`1V002aoh40n`3QolP0h_ol087oPOo60=co]P21o`3og`2k
o`00/On10?/0hOo80>;oo021oh7oaP3LokH0POl0oml0^ol00;7oP@3k0>7ob03R
oo`0POn1olH0g?nf087o0?oO0;_o06`10033oh40nP3AolT0hOol087oP_o40>ko
]`21o`7ooml0Z_l10033oh40nP3AolT0hOol087oP_o40>ko]`21o`7ooml0Z_l1
0033oh40nP3AolT0hOol087oP_o40>ko]`21o`7ooml0Z_l0JOh0e?n10?/0_oo:
0>3oo@21oh;oa001oonh087ooOoP09WooP3Doh40n`2oolX0h?om087oP_o4007o
okP0POomon00VOon0=CoP@3k0;oobP3Pood0POn2ol@00Ooo^021oogoh02Io`1V
o@3Voh40n`2]ol`0loom0?7oo@21oh;oR`21oocoh028ood0i_n10?/0[Oo<0??o
o@3aood0POn2oh/0POolon00R?om0>KoP@3k0:goc03cood0lOom087oP_n;087o
o?oP08So07Sl0?OoP@3l09coc@3bood0lOom087oTOon0?GoW@21oo_og`21ooSo
o03goh40o02Lold0l_om0?7oo@21oi7ooP3eoid0POokoml0POohoo`0mon10?`0
W?o=0?;oo@3aood0POnAooh0mOnM087onooO087on?l0K840o@2;oll0lOom0?7o
o@21oi7ooP3eojl0POojoml0POoWoh40o@2;oll0lOom0?7oo@21oi7ooP3eojl0
POojoml0POoWoh40o@2;oll0lOom0?7oo@21oi7ooP3eojl0POojoml0POoWo`1/
SP21ooWod03aoo`0l_om087oT_om0?Ko`021ooWog`21omKoSP21ooWod03aoo`0
l_om087oT_om0?Ko`021ooWog`21omKoSP21ooWod03aoo`0l_om087oT_om0?Ko
`021ooWog`21omKo06JO087oiooB0>ooo@3cood0POnAood0m_o208Sog`21olGo
W`21onOodP3_ood0loom087oTOom0?Ko`P28oml0POo5oil0POoWom80koom0??o
o@21oi7oo@3fol80R?oO087oaOl0IZl0POoHom<0kOol0?Goo021oi;oo03fol80
V?oP087o]?n_087of?oC0>goo03eoo`0POnBoo`0m_o209Soh021okCo[`21omSo
d`3]oo`0mOol087oT_ol0?Ko`P2Hon00POndo`1V`021olSodP3]oo/0mook087o
Took0?Ko`P2Yon00POnSol00POo8om80kOok0?Oon`21oi?on`3fol80ZOoP087o
Xoo0087ob?oB0>gon`3goo/0POnCoo/0m_o20:Woh021oj?o06KA087o^?oB0>_o
n`3jooX0POnFooL0m_o20;[og`21oi?od@21okSodP3[oo/0n_oj087oU_og0?Ko
`P2joml0POnCom40POnhom80jook0?[onP21oiKom`3fol80^_oO087oTol0F^40
POnYom<0j?o_087oV?od0?Ko`P3;oml0POn2on40POnYom<0j?o_087oV?od0?Ko
`P3;oml0POn2on40POnYom<0j?o_087oV?od0?Ko`P3;oml0POn2o`1PlP21oiWo
d`3Voo40POnGoo@0mOo30=cog`21oh7olOob087oVOoC0>Kol@21oiOom03eol<0
g?oO087oPOoaoo80POnIom<0i_oa087oUood0?Go``3Loml0POn1oo7o06kjoo`0
POnGooH0o_oR0>?om021oiGom03eol@0k?oO087oPOoIoo`0POnGooH0o_oR0>?o
m021oiGom03eol@0k?oO087oPOoIoo`0POnGooH0o_oR0>?om021oiGom03eol@0
k?oO087oPOoPo`1^nOol087oV?og0?_oiP3OooP0POn:ood0mOo40?coh021oh7o
aool087oV?og0?_oiP3OooP0POn:ood0mOo40?coh021oh7oaool087oV?og0?_o
iP3OooP0POn:ood0mOo40?coh021oh7ocol0G?Soo021oi[om`3ionT0POn1omgo
o@3eojl0POn1okGoo021oi[om`3ionT0POn1omgoo@3eojl0POn1okGoo021oi[o
m`3ionT0POn1omgoo@3eojl0POn1okko05cgoo`0POnLooL0m?ob087oPOoHood0
mOno087oPOnToo`0POnLooL0m?ob087oPOoHood0mOno087oPOnToo`0POnLooL0
m?ob087oPOoHood0mOno087oPOn^o`1[m_ol087oW_og0??oo021oh7oc_om0?Co
aP01ooom087oPOnSoo`0POnNooL0lool087oPOo>ood0m?o6007oood0POn1oj?o
o021oikom`3coo`0POn1olkoo@3dolH00Oooo@21oh7o[_l0J?Goo021oj3omP3d
oo`0POn1olgoo@3dolH0oOom087oPOnToo`0POnPooH0m?ol087oPOo=ood0m?o6
0?goo@21oh7oY?ol087oX?of0?Coo021oh7ocOom0?CoaP3mood0POn1ok3o06Se
oo`0POnQooH0m?ol087oPOo<ood0m?o70?WooP21oh7oY_ol087oXOof0?Coo021
oh7oc?om0?Coa`3iooh0POn1ojKoo021oj7omP3doo`0POn1olcoo@3dolL0nOon
087oPOnbo`1b003eoo`0POnSooH0m?ok087oPOo<ood0m?o70?OooP21oh7o]?l0
0?Goo021oj?omP3doo/0POn1olcoo@3dolL0moon087oPOndo`00mOol087oXoof
0?Con`21oh7oc?om0?Coa`3gooh0POn1okCo07D1003eoo`0POnTooL0m?ok087o
POo;ood0loo90?CooP21oh7o]_l1003eoo`0POnTooL0m?ok087oPOo;ood0loo9
0?CooP21oh7o]_l1003eoo`0POnTooL0m?ok087oPOo;ood0loo90?CooP21oh7o
]_l0M@400?Coo021ojKom`3doo/0POn1ol[oo@3colT0l_on087oPOnho`400?Co
o021ojKom`3doo/0POn1ol[oo@3colT0l_on087oPOnho`400?Coo021ojKom`3d
oo/0POn1ol[oo@3colT0l_on087oPOnho`1boP3doo`0POnXooL0m?ok087oPOo9
ood0l_o;0>oooP21oh7o^_on0?Coo021ojSom`3doo/0POn1olWoo@3bol/0koon
087oPOnjooh0m?ol087oZ?og0?Con`21oh7obOom0?;ob`3_ooh0POn1ok[o07;m
0?Coo021oj[om`3coo`0POn1olSoo@3aol`0kOon087oPOnlood0m?ol087oZ_og
0??oo021oh7ob?om0?7oc03]ooh0POn1okcoo@3doo`0POnZooL0lool087oPOo8
ood0lOo<0>gooP21oh7o_?l0L_`0mOol087oZoof0?Coo021oh7oaoom0?7obP3]
ood0POn1okooo03eoo`0POn[ooH0m?ol087oPOo7ood0lOo:0>goo@21oh7o_ool
0?Goo021oj_omP3doo`0POn1olOoo@3aolX0kOom087oPOnoo`1bn`3eoo`0POn]
ooH0m?ol087oPOo6ood0l?o90>goo@21oh7o`Ook0?Goo021ojgomP3doo`0POn1
olKoo@3`olT0kOom087oPOo1oo/0mOol087o[Oof0?Coo021oh7oa_om0?3ob@3]
ood0POn1ol7o07;j0?Goo021ojoomP3doo/0POn1olKoo@3_olP0kOom087oPOo3
ooX0mOol087o[oof0?Con`21oh7oa_om0>oob03]ood0POn1ol?onP3eoo`0POn_
ooH0m?ok087oPOo6ood0koo80>goo@21oh7o`ol0O_X0m?ol087o/?og0?Con`21
oh7oaOom0>kodP00ooL0kOom087oPOo5ooX0m?ol087o/?og0?Con`21oh7oaOom
0>kodP00ooL0kOom087oPOo5ooX0m?ol087o/?og0?Con`21oh7oaOom0>kodP00
ooL0kOom087oPOo5o`1nn@3doo`0POnbooL0m?ok087oPOo4ood0kOoE0?com`3/
ooh0POn1olOon@3doo`0POnbooL0m?ok087oPOo4ood0kOoE0?com`3/ooh0POn1
olOon@3doo`0POnbooL0m?ok087oPOo4ood0kOoE0?com`3/ooh0POn1olOo07kh
0?Coo021okCom`3doo/0POn1ol?oo@3/omH0n_of0>gooP21oh7obOoh0?Coo021
okCom`3doo/0POn1ol?oo@3/omH0n_of0>gooP21oh7obOoh0?Coo021okCom`3d
oo/0POn1ol?oo@3/omH0n_of0>gooP21oh7obOl0O_L0m?om087o]Oof0?Coo021
oh7o`_om0>[of@3gooH0kOon087oPOo;ooL0m?om087o]Oof0?Coo021oh7o`_om
0>[of@3gooH0kOon087oPOo;ooL0m?om087o]Oof0?Coo021oh7o`_om0>[of@3g
ooH0kOon087oPOo;o`200?og0?Goo021okOomP3doo`0POn1ol7oo@3Yom`0loof
0>gooP21oh7oc?og0?Goo021okOomP3doo`0POn1ol7oo@3Yom`0loof0>gooP21
oh7oc?og0?Goo021okOomP3doo`0POn1ol7oo@3Yom`0loof0>gooP21oh7ocOl0
P03omP3eoo`0POniooH0m?ol087oPOo0ood0j?oL0?;omP3]ooh0POn1olkomP3e
oo`0POniooH0m?ol087oPOo0ood0j?oL0?;omP3]ooh0POn1olkomP3eoo`0POni
ooH0m?ol087oPOo0ood0j?oL0?;omP3]ooh0POn1oloo0841ooog0?Coo021ok_o
mP3doo/0POn1ol3oo@3Vom/0l_og0>goo@21oh7od?og0?Coo021ok_omP3doo/0
POn1ol3oo@3Vom/0l_og0>goo@21oh7od?og0?Coo021ok_omP3doo/0POn1ol3o
o@3Vom/0l_og0>goo@21oh7od_l0P?kom`3doo`0POnlooL0m?ok087oPOnoood0
i?oK0?;om`3]ood0POn1om7om`3doo`0POnlooL0m?ok087oPOnoood0i?oK0?;o
m`3]ood0POn1om7om`3doo`0POnlooL0m?ok087oPOnoood0i?oK0?;om`3]ood0
POn1omCo083mooL0m?ol087o__og0?Con`21oh7o__om0>?ofP3booL0kOom087o
POoBooL0m?ol087o__og0?Con`21oh7o__om0>?ofP3booL0kOom087oPOoBooL0
m?ol087o__og0?Con`21oh7o__om0>?ofP3booL0kOom087oPOoFo`2<o?og0?Co
o021ol3om`3doo/0POn1okgoo@3Moo@0o_o^0?;omP3^ood0POn1om?om`3doo`0
POo0ooL0m?ok087oPOnmood0gOod0?kokP3booH0k_om087oPOoCooL0m?ol087o
`?og0?Con`21oh7o_Oom0=gom03nonh0l_of0>koo@21oh7of?l0P?_om`3eoo`0
POo1ooH0mOok087oPOnlood0boo^0?;omP3^ood0POn1omCom`3eoo`0POo1ooH0
mOok087oPOnlood0boo^0?;omP3^ood0POn1omCom`3eoo`0POo1ooH0mOok087o
POnlood0boo^0?;omP3^ood0POn1om[o07gkooH0mOol087o`oof0?Coo021oh7o
POl1ooo^0?;omP3^ood0POn1omKomP3eoo`0POo3ooH0m?ol087oPOn1o`7oonh0
l_of0>koo@21oh7oe_of0?Goo021ol?omP3doo`0POn1oh7o0OookP3booH0k_om
087oPOoLo`1jn_of0?Goo021olGomP3doo`0POn1oh7oo?o^0?;omP3]ooh0POn1
omOomP3eoo`0POo5ooH0m?ol087oPOn1oocokP3booH0kOon087oPOoGooH0mOol
087oaOof0?Coo021oh7oPOolonh0l_of0>gooP21oh7og_l0N_Wom`3doo`0POo7
ooH0m?ol087oPOn1ooSok`3aooL0kOon087oPOoHooL0m?ol087oaoof0?Coo021
oh7oPOohonl0lOog0>gooP21oh7of?og0?Coo021olOomP3doo`0POn1oh7on?o_
0?7om`3]ooh0POn1on3o07[hooL0m?ol087ob?og0?Con`21oh7oPOofonl0lOog
0>gooP21oh7ofOog0?Coo021olSom`3doo/0POn1oh7om_o_0?7om`3]ooh0POn1
omWom`3doo`0POo8ooL0m?ok087oPOn1ooKok`3aooL0kOon087oPOoRo`1jmoog
0?Coo021ol[om`3doo/0POn1oh7oloo^0?;om`3]ood0POn1om_om`3doo`0POo:
ooL0m?ok087oPOn1oo?okP3booL0kOom087oPOoKooL0m?ol087ob_og0?Con`21
oh7oPOoconh0l_og0>goo@21oh7oiOl0N_Kom`3eoo`0POo;ooL0m?ok087oPOn1
oo3okP3booH0k_om087oPOoLooL0mOol087oboog0?Con`21oh7oPOo`onh0l_of
0>koo@21oh7og?og0?Goo021ol_om`3doo/0POn1oh7ol?o^0?;omP3^ood0POn1
onOo07[eooL0mOol087ocOof0?Gon`21oh7oPOo]onh0l_of0>koo@21oh7ogOog
0?Goo021olgomP3eoo/0POn1oh7okOo^0?;omP3^ood0POn1omgom`3eoo`0POo=
ooH0mOok087oPOn1ongokP3booH0k_om087oPOoYo`1jmOof0?Goo021oloomP3d
oo`0POn1oh7oj_o^0?;omP3^ood0POn1omoomP3eoo`0POo?ooH0m?ol087oPOn1
on[okP3booH0k_om087oPOoOooH0mOol087ocoof0?Coo021oh7oPOoZonh0l_of
0>koo@21oh7ojol0N_Com`3doo`0POoAooH0m?ol087oPOn1onOokP3booH0k_om
087oPOoPooL0m?ol087odOof0?Coo021oh7oPOoWonh0l_of0>koo@21oh7oh?og
0?Coo021om7omP3doo`0POn1oh7oioo^0?;omP3^ood0POn1ongo07[cooL0m?ol
087odoof0?Coo021oh7oPOoTonh0lOog0>koo@21oh7ohOog0?Coo021om?omP3d
oo`0POn1oh7oi?o^0?7om`3^ood0POn1on7om`3doo`0POoCooH0m?ol087oPOn1
onCokP3aooL0k_om087oPOo_o`1jl_og0?Coo021omGomP3doo/0POn1oh7oh_o^
0?7om`3^ood0POn1on;om`3doo`0POoEooH0m?ok087oPOn1on;okP3aooL0k_om
087oPOoRooL0m?ol087oeOof0?Con`21oh7oPOoRonh0lOog0>koo@21oh7olOl0
N_7om`3dood0POoEooL0m?ok087oPOn1omkok`3aooL0kOon087oPOoSooL0m?om
087oeOog0?Con`21oh7oPOoNonl0lOog0>gooP21oh7ohoog0?Coo@21omGom`3d
oo/0POn1oh7og_o_0?7om`3]ooh0POn1oo?o07[`ooL0mOol087oeoog0?Con`21
oh7oPOoKonl0lOog0>gooP21oh7oi?og0?Goo021omOom`3doo/0POn1oh7ofoo_
0?7om`3]ooh0POn1onCom`3eoo`0POoGooL0m?ok087oPOn1om_ok`3aooL0kOon
087oPOoeo`1jl?of0?Goo021omWomP3eoo/0POn1oh7of?o^0?;omP3^ood0POn1
onOomP3eoo`0POoIooH0mOok087oPOn1omSokP3booH0k_om087oPOoWooH0mOol
087ofOof0?Gon`21oh7oPOoHonh0l_of0>koo@21oh7on?l0N^oom`3doo`0POoK
ooH0m?ol087oPOn1omGokP3booH0k_om087oPOoXooL0m?ol087ofoof0?Coo021
oh7oPOoEonh0l_of0>koo@21oh7oj?og0?Coo021om_omP3doo`0POn1oh7oeOo^
0?;omP3^ood0POn1oo[o07[^ooL0m?ol087ogOof0?Coo021oh7oPOoBonh0l_of
0>koo@21oh7ojOog0?Coo021omgomP3doo`0POn1oh7od_o^0?;omP3^ood0POn1
onWom`3doo`0POoMooH0m?ol087oPOn1om;okP3booH0k_om087oPOolo`1jkOog
0?Coo021omoomP3doo`0POn1oh7ocoo^0?;omP3^ood0POn1on[om`3doo`0POoO
ooH0m?ol087oPOn1olookP3booH0k_om087oPOoZooL0m?ol087ogoof0?Coo021
oh7oPOo?onh0l_of0>koo@21oh7oo_l0N^com`3doo`0POoQooH0m?ok087oPOn1
olgokP3aooL0k_om087oPOo[ooL0m?ol087ohOof0?Con`21oh7oPOo=onh0lOog
0>koo@21oh7ojoog0?Coo021on7omP3doo/0POn1oh7ocOo^0?7om`3^ood0POn1
o`3o07S[ooL0mOol087ohOog0?Con`21oh7oPOo:onh0lOog0>koo@21oh7ok?og
0?Goo021on7om`3doo/0POn1oh7ob_o^0?7om`3^ood0POn1oncom`3eoo`0POoQ
ooL0m?ok087oPOn1ol[okP3aooL0k_om087oP_l0N>_omP3eoo`0POoSooL0m?ok
087oPOn1olOokP3aooL0k_om087oPOo^ooH0mOol087ohoog0?Con`21oh7oPOo7
onh0lOog0>koo@21oh7ok_of0?Goo021on?om`3doo/0POn1oh7oaoo^0?7om`3^
ood0POn4o`1hj_of0?Goo021onGomP3eoo/0POn1oh7o`oo_0?7omP3_ood0POn1
onoomP3eoo`0POoUooH0mOok087oPOn1ol?ok`3aooH0koom087oPOo_ooH0mOol
087oiOof0?Gon`21oh7oPOo3onl0lOof0>ooo@21ohKo07SYooL0m?ol087oioof
0?Gon`21oh7oPOo0onl0lOof0>kooP21oh7ol?og0?Coo021onOomP3eoo/0POn1
oh7o`?o_0?7omP3^ooh0POn1oo3om`3doo`0POoWooH0mOok087oPOn1ol3ok`3a
ooH0k_on087oR?l0N>Som`3doo`0POoYooH0m?ol087oPOn1okgokP3booH0k_om
087oPOobooL0m?ol087ojOof0?Coo021oh7oPOnmonh0l_of0>koo@21oh7ol_og
0?Coo021onWomP3doo`0POn1oh7o_Oo^0?;omP3^ood0POn;o`1hioog0?Coo021
on_omP3doo`0POn1oh7o^_o^0?;omP3^ood0POn1oo?om`3doo`0POo[ooH0m?ol
087oPOn1ok[okP3booH0k_om087oPOocooL0m?ol087ojoof0?Coo021oh7oPOnj
onh0l_of0>koo@21ohgo07SVooL0mOol087ok?of0?Coo021oh7oPOngonh0lOog
0>koo@21oh7om?og0?Goo021oncomP3doo`0POn1oh7o]oo^0?7om`3^ood0POn1
ooCom`3eoo`0POo/ooH0m?ol087oPOn1okOokP3aooL0k_om087oSol0N>Gom`3e
oo`0POo]ooL0m?ok087oPOn1okGokP3aooL0k_om087oPOoeooL0mOol087okOog
0?Con`21oh7oPOneonh0lOog0>koo@21oh7omOog0?Goo021ongom`3doo/0POn1
oh7o]Oo^0?7om`3^ood0POnAo`1hiOof0?Goo021onoom`3doo/0POn1oh7o/_o^
0?7om`3^ood0POn1ooOomP3eoo`0POo_ooL0m?ok087oPOn1ok;okP3aooL0k_om
087oPOogooH0mOol087okoog0?Con`21oh7oPOnbonh0lOog0>koo@21oi?o07ST
ooL0m?ol087olOof0?Gon`21oh7oPOn_onh0lOof0>ooo@21oh7on?og0?Coo021
oo7omP3eoo/0POn1oh7o[oo^0?7omP3_ood0POn1ooSom`3doo`0POoaooH0mOok
087oPOn1ojookP3aooH0koom087oUOl0N>?om`3doo`0POocooH0mOok087oPOn1
ojcokP3aooH0koom087oPOoiooL0m?ol087oloof0?Gon`21oh7oPOn/onh0lOof
0>ooo@21oh7onOog0?Coo021oo?omP3eoo/0POn1oh7o[?o^0?7omP3_ood0POnG
o`1hh_og0?Coo021ooGomP3doo`0POn1oh7oZ?o_0?7omP3_ood0POn1oo[om`3d
oo`0POoeooH0m?ol087oPOn1ojSok`3aooH0koom087oPOojooL0m?ol087omOof
0?Coo021oh7oPOnXonl0lOof0>ooo@21oiWo07SQooL0m?om087om_of0?Coo021
oh7oPOnUonl0lOof0>ooo@21oh7onoog0?Coo@21ooKomP3doo`0POn1oh7oYOo_
0?7omP3_ood0POn1oo_om`3dood0POofooH0m?ol087oPOn1ojGok`3aooH0koom
087oVol0N>3om`3eoo`0POohooH0m?ol087oPOn1oj;okP3aooL0kool087oPOom
ooL0mOol087on?of0?Coo021oh7oPOnRonh0lOog0>ooo021oh7ooOog0?Goo021
ooSomP3doo`0POn1oh7oX_o^0?7om`3_oo`0POnNo`1jh?of0?Goo021ooWom`3d
oo/0POn1oh7oX?o^0?7om`3^ood0POn1o`7oooH0mOol087onOog0?Con`21oh7o
POnPonh0lOog0>koo@21oh7o0OoomP3eoo`0POoiooL0m?ok087oPOn1oj3okP3a
ooL0k_om087oX?l0N=oom`3doo`0POokooL0m?ok087oPOn1oigokP3aooL0k_om
087oPOl0ooL0m?ol087onoog0?Con`21oh7oPOnMonh0lOog0>koo@21oh7o0?og
0?Coo021oo_om`3doo/0POn1oh7oWOo^0?7om`3^ood0POnRo`1dg_og0?Coo021
oogomP3eoo/0POn1oh7oV_o^0?7om`3^ood0POn1ooL0m?ol087ooOof0?Gon`21
oh7oPOnJonh0lOog0>koo@21oh7om`3doo`0POomooH0mOok087oPOn1oi[okP3a
ooL0k_om087oY?l0Mmgom`3doo`0POl1ooof0?Gon`21oh7oPOnGonh0lOof0>oo
o@21oh;om`3doo`0POl1ooof0?Gon`21oh7oPOnGonh0lOof0>ooo@21oh;om`3d
oo`0POl1ooof0?Gon`21oh7oPOnGonh0lOof0>ooo@21ojKo07CLooL0m?om087o
0?of0?Coo021oh7oPOnDonh0lOof0>ooo@21oh?om`3dood0POl0ooH0m?ol087o
POn1oiCokP3aooH0koom087oPoog0?Coo@21o`3omP3doo`0POn1oh7oU?o^0?7o
mP3_ood0POnXo`1^foog0?Goo022ooH0m?ol087oPOn1oi7okP3aooH0koom087o
Q?og0?Goo022ooH0m?ol087oPOn1oi7okP3aooH0koom087oQ?og0?Goo022ooH0
m?ol087oPOn1oi7okP3aooH0koom087oZ_l0K]_omP3eoo`0Q?of0?Coo021oh7o
POn=onl0lOof0>ooo@21ohKomP3eoo`0Q?of0?Coo021oh7oPOn=onl0lOof0>oo
o@21ohKomP3eoo`0Q?of0?Coo021oh7oPOn=onl0lOof0>ooo@21ojco06kJooL0
m?ol08Gom`3doo/0POn1oh7oRoo_0?3om`3_ood0POn7ooL0m?ol08Gom`3doo/0
POn1oh7oRoo_0?3om`3_ood0POn7ooL0m?ol08Gom`3doo/0POn1oh7oRoo_0?3o
m`3_ood0POn^o`1^fOog0?Coo027ooL0m?ok087oPOn1ohSokP3aooL0kool087o
ROog0?Coo027ooL0m?ok087oPOn1ohSokP3aooL0kool087oROog0?Coo027ooL0
m?ok087oPOn1ohSokP3aooL0kool087o/Ol0K]Som`3doo`0ROof0?Gon`21oh7o
POn5onh0lOog0>ooo021oh[om`3doo`0ROof0?Gon`21oh7oPOn5onh0lOog0>oo
o021oh[om`3doo`0ROof0?Gon`21oh7oPOn5onh0lOog0>ooo021ok?o06kGooL0
m?ol08_omP3eoo/0POn1oh7oP_o^0?7omP3_ood0POn;ooL0m?ol08_omP3eoo/0
POn1oh7oP_o^0?7omP3_ood0POn;ooL0m?ol08_omP3eoo/0POn1oh7oP_o^0?7o
mP3_ood0POneo`1ge_og0?Coo@2<ooH0mOok087oPOn1oh7o0OookP3aooH0koom
087oS?og0?Coo@2<ooH0mOok087oPOn1oh7o0OookP3aooH0koom087oS?og0?Co
o@2<ooH0mOok087oPOn1oh7o0OookP3aooH0koom087o]ol0M=KomP3eoo`0S_of
0?Coo021oh7oPOn1oocokP3aooH0koom087oS_of0?Goo02>ooH0m?ol087oPOn1
oh7oo?o^0?7omP3_ood0POn>ooH0mOol08komP3doo`0POn1oh7oPOolonh0lOof
0>ooo@21okWo07CEooH0mOol093omP3doo`0POn1oh7oPOoionh0lOof0>ooo@21
ohoomP3eoo`0T?of0?Coo021oh7oPOn1ooWokP3aooH0koom087oSoof0?Goo02@
ooH0m?ol087oPOn1oh7onOo^0?7omP3_ood0POnko`1de?og0?Coo02AooL0m?ol
087oPOn1oh7om_o^0?3om`3_ood0POn@ooL0m?ol097om`3doo`0POn1oh7oPOof
onh0l?og0>ooo@21oi3om`3doo`0TOog0?Coo021oh7oPOn1ooKokP3`ooL0koom
087o_Ol0M=?om`3doo`0Toog0?Con`21oh7oPOn1oo?ok`3`ooL0koom087oTOog
0?Coo02CooL0m?ok087oPOn1oh7oloo_0?3om`3_ood0POnAooL0m?ol09?om`3d
oo/0POn1oh7oPOoconl0l?og0>ooo@21okoo07CBooL0m?ol09GomP3eoo/0POn1
oh7oPOo`onl0l?og0>ooo@21oi;om`3doo`0UOof0?Gon`21oh7oPOn1oo3ok`3`
ooL0koom087oT_og0?Coo02EooH0mOok087oPOn1oh7ol?o_0?3om`3_ood0POo1
o`1ddOog0?Coo@2FooH0mOok087oPOn1oh7okOo^0?7omP3`ood0POnCooL0m?om
09KomP3eoo/0POn1oh7oPOo]onh0lOof0?3oo@21oi?om`3dood0U_of0?Gon`21
oh7oPOn1ongokP3aooH0l?om087o`ol0M=3om`3eoo`0V?of0?Gon`21oh7oPOn1
on[okP3aooH0l?ol087oUOog0?Goo02HooH0mOok087oPOn1oh7oj_o^0?7omP3`
oo`0POnEooL0mOol09SomP3eoo/0POn1oh7oPOoZonh0lOof0?3oo021olKo07C@
ooH0mOol09[omP3doo`0POn1oh7oPOoWonh0lOof0?3oo021oiOomP3eoo`0V_of
0?Coo021oh7oPOn1onOokP3aooH0l?ol087oUoof0?Goo02JooH0m?ol087oPOn1
oh7oioo^0?7omP3`oo`0POo8o`1dcoog0?Coo02LooH0m?ol087oPOn1oh7oi?o^
0?7omP3_ood0POnHooL0m?ol09comP3doo`0POn1oh7oPOoTonh0lOof0>ooo@21
oiSom`3doo`0W?of0?Coo021oh7oPOn1onCokP3aooH0koom087ob_l0M<kom`3d
oo`0WOog0?Coo021oh7oPOn1on7okP3`ooL0koom087oVOog0?Coo02MooL0m?ol
087oPOn1oh7ohOo^0?3om`3_ood0POnIooL0m?ol09gom`3doo`0POn1oh7oPOoQ
onh0l?og0>ooo@21olco07C=ooL0m?ol09oom`3doo/0POn1oh7oPOoOonh0l?og
0>ooo@21oi[om`3doo`0Woog0?Con`21oh7oPOn1omookP3`ooL0koom087oV_og
0?Coo02OooL0m?ok087oPOn1oh7ogoo^0?3om`3_ood0POo>o`1dc?og0?Coo@2P
ooH0mOok087oPOn1oh7og?o^0?3om`3_ood0POnKooL0m?om0:3omP3eoo/0POn1
oh7oPOoLonh0l?og0>ooo@21oi_om`3dood0X?of0?Gon`21oh7oPOn1omcokP3`
ooL0koom087od?l0Q<_om`3eoo`0X_of0?Gon`21oh7odoon087oROo_0?3om`3_
ood0POoCo`00boog0?Goo02RooH0mOok087oPOoCooh0POn9onl0l?og0>ooo@21
om?o003;ooL0mOol0:;omP3eoo/0POn1om?ooP21ohWok`3`ooL0koom087odol0
0027boof0?Goo02TooH0mOok087oPOoBoo`0POn9onl0l?of0?3oo@21omKo0@00
boof0?Goo02TooH0mOok087oPOoBoo`0POn9onl0l?of0?3oo@21omKo0@00boof
0?Goo02TooH0mOok087oPOoBoo`0POn9onl0l?of0?3oo@21omKo0@0008C:ooL0
m?ol0:KomP3doo`0POn1om7on@21oh[okP3aooH0l?om087ofOon0<[om`3doo`0
Y_of0?Coo021oh7odOoi087oR_o^0?7omP3`ood0POoIooh0b_og0?Coo02VooH0
m?ol087oPOoAooT0POn:onh0lOof0?3oo@21omWooP00SP00b_og0?Coo02XooH0
m?ol087oPOo@ooH0POn;onh0lOof0?3oo021omgooP01o`3:ooL0m?ol0:SomP3d
oo`0POn1om3omP21oh_okP3aooH0l?ol087ogOon007o0<[om`3doo`0Z?of0?Co
o021oh7od?of087oRoo^0?7omP3`oo`0POoMooh00?l0T?h0boog0?Coo02ZooH0
m?ol087oPOo?oo@0POn;onh0lOof0?3oo021on3oo@00ooh0boog0?Coo02ZooH0
m?ol087oPOo?oo@0POn;onh0lOof0?3oo021on3oo@00ooh0boog0?Coo02ZooH0
m?ol087oPOo?oo@0POn;onh0lOof0?3oo021on3oo@00o`2Co03<ooL0m?ol0:_o
m`3doo/0POn1olool@21ohcokP3`ooL0l?ol087ohoom007ooo`0c?og0?Coo02[
ooL0m?ok087oPOo?oo40POn<onh0l?og0?3oo021on?oo@01oool0<com`3doo`0
Zoog0?Con`21oh7ocooa087oS?o^0?3om`3`oo`0POoSood00Ooo093j0<gom`3d
ood0[?of0?Gon`21oh7oc_o^087oSOo^0?3om`3`oo`0POoVood0o_oj0<gom`3d
ood0[?of0?Gon`21oh7oc_o^087oSOo^0?3om`3`oo`0POoVood0o_oj0<gom`3d
ood0[?of0?Gon`21oh7oc_o^087oSOo^0?3om`3`oo`0POoVood0o_l0T?P0coof
0?Goo02^ooH0mOok087oPOo=on`0POn=onh0l?og0>ooo@21onSooP3mooP0coof
0?Goo02^ooH0mOok087oPOo=on`0POn=onh0l?og0>ooo@21onSooP3mooP0coof
0?Goo02^ooH0mOok087oPOo=on`0POn=onh0l?og0>ooo@21onSooP3mo`2@mP3@
ooH0mOol0;3omP3eoo/0POn1olcoj@21ohkokP3`ooH0l?om087ojoon0?comP3@
ooH0mOol0;3omP3eoo/0POn1olcoj@21ohkokP3`ooH0l?om087ojoon0?comP3@
ooH0mOol0;3omP3eoo/0POn1olcoj@21ohkokP3`ooH0l?om087ojoon0?co093d
0=7om`3doo`0/_of0?Gon`21oh7obooV087oS_o_0?3omP3`ood0POo^ooh0nood
0=7om`3doo`0/_of0?Gon`21oh7obooV087oS_o_0?3omP3`ood0POo^ooh0nood
0=7om`3doo`0/_of0?Gon`21oh7obooV087oS_o_0?3omP3`ood0POo^ooh0nol0
T?80d_og0?Coo02dooH0m?ol087oPOo:on@0POn>onl0l?of0?3oo@21oo7ooP3j
oo80d_og0?Coo02dooH0m?ol087oPOo:on@0POn>onl0l?of0?3oo@21oo7ooP3j
oo80d_og0?Coo02dooH0m?ol087oPOo:on@0POn>onl0l?of0?3oo@21oo7ooP3j
o`2@k`3DooL0m?ol0;KomP3doo`0POn1olWoh@21ohook`3`ooH0l?om087om?om
0?[ok`3DooL0m?ol0;KomP3doo`0POn1olWoh@21ohook`3`ooH0l?om087om?om
0?[ok`3DooL0m?ol0;KomP3doo`0POn1olWoh@21ohook`3`ooH0l?om087om?om
0?[o0980onh0eOog0?Coo@2fooL0m?ol087oPOo8oml0POn?onh0l?og0?3oo021
ooSoo@3honh0eOog0?Coo@2fooL0m?ol087oPOo8oml0POn?onh0l?og0?3oo021
ooSoo@3honh0eOog0?Coo@2fooL0m?ol087oPOo8oml0POn?onh0l?og0?3oo021
ooSoo@3io`2Bo_o^0=Kom`3eoo`0^?of0?Gon`21oh7ob?oL087oT?o^0?3om`3`
oo`0POokood0mOo^0=Kom`3eoo`0^?of0?Gon`21oh7ob?oL087oT?o^0?3om`3`
oo`0POokood0mOo^0=Kom`3eoo`0^?of0?Gon`21oh7ob?oL087oT?o^0?3om`3`
oo`0POokood0n?l0W?cokP3HooH0mOol0;[omP3eoo/0POo^oh40/P21oi7okP3`
ooL0l?ol087ooOon0?So003lonh0f?of0?Goo02jooH0mOok087ok_n10;80POnA
onh0l?og0?3oo021oogooP3ho`00o?o^0=SomP3eoo`0^_of0?Gon`21onkoP@2b
087oTOo^0?3om`3`oo`0POomooh0n?l0002On_o^0=Wom`3doo`0_?of0?Gon`21
ongoP@2`087oTOo^0?3omP3aoo`0POl0ooh0n?l1003jonh0fOog0?Coo02looH0
mOok087okOn10;00POnAonh0l?of0?7oo021o`3ooP3ho`400?[okP3IooL0m?ol
0;comP3eoo/0POo]oh40/021oi7okP3`ooH0lOol087o0?on0?So0@0009Khonh0
f_og0?Coo02nooH0mOok087ok?n10:d0POnBonh0l?of0?7oo023ooh0n?on0?So
kP3JooL0m?ol0;komP3eoo/0POo/oh40[@21oi;okP3`ooH0lOol08?ooP3hooh0
n?o^0=[om`3doo`0__of0?Gon`21oncoP@2]087oT_o^0?3omP3aoo`0Poon0?So
oP00U_KokP3KooL0m?ol0<3omP3doo`0POo[oh40/021ohgokP3`ooH0l?om08Ko
oP3hood0m_o^0=_om`3doo`0`?of0?Coo021on_oP@2`087oSOo^0?3omP3`ood0
Q_on0?Soo@3fonh0foog0?Coo030ooH0m?ol087ojon10;00POn=onh0l?of0?3o
o@26ooh0n?om002Floo_0=com`3dood0`Oof0?Coo021oh7o`ooJ087oR?o^0?3o
mP3`ood0ROom0?Woo03conl0g?og0?Coo@31ooH0m?ol087oPOo3omX0POn8onh0
l?of0?3oo@29ood0nOol0??ok`3LooL0m?om0<7omP3doo`0POn1ol?ofP21ohSo
kP3`ooH0l?om08Woo@3ioo`009Saonl0gOog0?Goo032ooL0m?ol087oPOo2om`0
POn3onl0koog0?3oo@2<ood0n?om0?3ok`3MooL0mOol0<;om`3doo`0POn1ol;o
g021oh?ok`3_ooL0l?om08coo@3hood0l?o_0=gom`3eoo`0`_og0?Coo021oh7o
`_oL087oPoo_0>oom`3`ood0S?om0?Soo@00o`2Nkoo^0>3omP3eoo`0a?of0?Go
n`21oh7o`_oO087oPOononl0koog0?3oo@2?ood0n?ol0>kokP3PooH0mOol0<Co
mP3eoo/0POn1ol;og`21oh7oo_o_0>oom`3`ood0Soom0?Soo03^onh0h?of0?Go
o034ooH0mOok087oPOo2oml0POn1ookok`3_ooL0l?om08ooo@3hoo`00?l0Wngo
kP3QooL0m?ol0<KomP3eoo/0POn1ol7ohP21oh7onOo^0?3om`3`oo`0T_on0?So
o03[onh0hOog0?Coo036ooH0mOok087oPOo1on80POn1ooWokP3`ooL0l?ol09;o
oP3hoo`0joo^0>7om`3doo`0a_of0?Gon`21oh7o`OoR087oPOoionh0l?og0?3o
o02Booh0n?ol007oo`2Njoo^0>;om`3doo`0b?of0?Gon`21oh7o`?oU087oPOod
onh0l?og0?3oo02Eooh0n?ol0>SokP3RooL0m?ol0<SomP3eoo/0POn1ol3oi@21
oh7om?o^0?3om`3`oo`0UOon0?Soo03Xonh0h_og0?Coo038ooH0mOok087oPOo0
onD0POn1ooCokP3`ooL0l?ol09GooP3hoo`0o_l0W^WokP3SooL0m?ol0<[omP3e
oo/0POn1okooj021oh7okoo^0?3omP3aoo`0V?on0?Soo03Uonh0hoog0?Coo03:
ooH0mOok087oPOnoonP0POn1onookP3`ooH0lOol09SooP3hoo`0iOo^0>?om`3d
oo`0b_of0?Gon`21oh7o_ooX087oPOo_onh0l?of0?7oo02Hooh0n?ol0?go0:/1
003Yonh0i?og0?Coo@3;ooH0m?ol087oPOnnonX0POn1on_okP3`ooH0lOol09_o
o@3ioo`0o?l1003Yonh0i?og0?Coo@3;ooH0m?ol087oPOnnonX0POn1on_okP3`
ooH0lOol09_oo@3ioo`0o?l1003Yonh0i?og0?Coo@3;ooH0m?ol087oPOnnonX0
POn1on_okP3`ooH0lOol09_oo@3ioo`0o?l0Z?d0jOo^0>Gom`3dood0cOof0?Co
o021oh7o_Oo]087oPOoVonh0l?of0?7oo02Nood0nOol0?_oo@3Yonh0iOog0?Co
o@3=ooH0m?ol087oPOnmond0POn1onKokP3`ooH0lOol09koo@3ioo`0noom0>Wo
kP3UooL0m?om0<gomP3doo`0POn1okgok@21oh7oi_o^0?3omP3aoo`0W_om0?Wo
o03ko`2Xn`3Yonh0ioof0?Goo03>ooH0mOol087oPOnloo00POn1on7okP3`ooH0
lOol0:7oo@3hood0n_ok0>WokP3WooH0mOol0<komP3eoo`0POn1okcol021oh7o
hOo^0?3omP3aoo`0XOom0?Soo@3joo/0jOo^0>OomP3eoo`0c_of0?Goo021oh7o
_?o`087oPOoQonh0l?of0?7oo02Qood0n?om0?[o0:Si0>Sok`3XooL0m?ol0=3o
mP3eoo/0POn1okcol`21oh7og?o^0>oom`3`ood0Y?om0?Soo03jooT0j?o_0>So
m`3doo`0d?of0?Gon`21oh7o_?oc087oPOoLonh0koog0?3oo@2Tood0n?ol0?[o
n@3Xonl0j?og0?Coo03@ooH0mOok087oPOnloo<0POn1omcokP3_ooL0l?om0:Co
o@3hoo`0n_l0Z`7oooP0jOo_0>Wom`3doo`0d_of0?Gon`21oh7o^oof087oPOoF
onl0koog0?3oo@2Vooh0n?ol0?Oon03Yonl0jOog0?Coo03BooH0mOok087oPOnk
ooH0POn1omKok`3_ooL0l?om0:KooP3hoo`0mooh0>Wok`3YooL0m?ol0=;omP3e
oo/0POn1ok_omP21oh7oe_o_0>oom`3`ood0Y_on0?Soo03io`2ZoOoh0>WokP3[
ooL0m?ol0=ComP3eoo/0POn1ok[on@21oh7odOo_0>oom`3`ood0ZOon0?Soo03d
ooP0jOo^0>_om`3doo`0e?of0?Gon`21oh7o^_oi087oPOoAonl0koog0?3oo@2Y
ooh0n?ol0?Con03Yonh0joog0?Coo03DooH0mOok087oPOnjooT0POn1om7ok`3_
ooL0l?om0:WooP3hoo`0n?l0]?_on03Yonh0k?og0?Coo03FooH0mOok087oPOni
oo/0POn1olgokP3`ooH0lOol0:gooP3hoo`0n?l00?_on03Yonh0k?og0?Coo03F
ooH0mOok087oPOnioo/0POn1olgokP3`ooH0lOol0:gooP3hoo`0n?l00?_on03Y
onh0k?og0?Coo03FooH0mOok087oPOnioo/0POn1olgokP3`ooH0lOol0:gooP3h
oo`0n?l0002gn?oi0>WokP3]ooL0m?om0=OomP3eoo/0POn1okSooP21oh7ob?o^
0?3omP3aoo`0/?om0?Woo03ho`400?Son@3Yonh0kOog0?Coo@3GooH0mOok087o
POnhooh0POn1olSokP3`ooH0lOol0;3oo@3ioo`0n?l1003hooT0jOo^0>gom`3d
ood0eoof0?Gon`21oh7o^?on087oPOo8onh0l?of0?7oo02`ood0nOol0?So0@00
0;7fooT0jOo^0>oomP3eoo`0fOof0?Coo021oh7oPOn1oh7onOo^0?3omP3aoo`0
/oom0?Woo03go`400?Kon@3Yonh0koof0?Goo03IooH0m?ol087oPOn1oh7oPOoi
onh0l?of0?7oo02cood0nOol0?Oo0@00m_oi0>WokP3_ooH0mOol0=WomP3doo`0
POn1oh7oPOn1ooWokP3`ooH0lOol0;?oo@3ioo`0mol10000[_Con@3Yonh0l?of
0?Goo03JooH0mOol087oPOn1oh7oPOofonh0l?of0?7oo02food0nOol0?OooP3d
ooT0jOo^0?3omP3eoo`0f_of0?Goo021oh7oPOn1oh7om_o^0?3omP3aoo`0]_om
0?Woo03gooh0m?oi0>WokP3`ooH0mOol0=[omP3eoo`0POn1oh7oPOn1ooKokP3`
ooH0lOol0;Koo@3ioo`0moon002^l_oi0>WokP3aooL0m?ol0=comP3eoo`0POn1
oh7oPOn1oo?okP3_ooL0lOol0;Woo@3hoo`0n?om0?;on@3Yonh0lOog0?Coo03L
ooH0mOol087oPOn1oh7oPOoconh0koog0?7oo02iood0n?ol0?Soo@3booT0jOo^
0?7om`3doo`0g?of0?Goo021oh7oPOn1oh7oloo^0>oom`3aoo`0^Oom0?Soo03h
ood00:k`ooT0jOo^0?;om`3doo`0g_of0?Gon`21oh7oPOn1oh7olOo^0>oom`3a
oo`0^oon0?Soo03hoo`0l?oi0>WokP3booL0m?ol0=komP3eoo/0POn1oh7oPOn1
oo7okP3_ooL0lOol0;_ooP3hoo`0n?ol0?3on@3Yonh0l_og0?Coo03NooH0mOok
087oPOn1oh7oPOoaonh0koog0?7oo02kooh0n?ol0?Soo000[^kon03Yonl0loog
0?Coo03PooH0mOok087oPOn1oh7oPOo^onh0koog0?7oo02nooh0n?ol0?Son`3^
ooP0jOo_0??om`3doo`0h?of0?Gon`21oh7oPOn1oh7ok_o^0>oom`3aoo`0__on
0?Soo03hoo/0k_oh0>Wok`3cooL0m?ol0>3omP3eoo/0POn1oh7oPOn1onkokP3_
ooL0lOol0;kooP3hoo`0n?ok002^k?oh0>Wok`3dooL0m?om0>7omP3eoo/0POn1
oh7oPOn1on[ok`3_ooH0l_ol0<7ooP3hoo`0n?oj0>con03Yonl0m?og0?Coo@3Q
ooH0mOok087oPOn1oh7oPOoZonl0koof0?;oo031ooh0n?ol0?SonP3/ooP0jOo_
0?Com`3dood0hOof0?Gon`21oh7oPOn1oh7oj_o_0>oomP3boo`0`Oon0?Soo03h
ooX00:kZooP0jOo^0?Kom`3eoo`0hoof0?Gon`21oh7oPOn1oh7oioo_0>oomP3a
ood0a?om0?Woo03hooT0j_oh0>WokP3fooL0mOol0>?omP3eoo/0POn1oh7oPOn1
onOok`3_ooH0lOom0<Coo@3ioo`0n?oi0>[on03Yonh0m_og0?Goo03SooH0mOok
087oPOn1oh7oPOoWonl0koof0?7oo@34ood0nOol0?Son@00a^Oon@3Yonh0n?of
0?Goo03loo@0moof0?Coo021oh7oPOn1oh7oi?o^0?3omP3aoo`0fOod0?goo@3i
oo`0mooi0>Oon@3Yonh0n?of0?Goo03loo@0moof0?Coo021oh7oPOn1oh7oi?o^
0?3omP3aoo`0fOod0?goo@3ioo`0mooi0>Oon@3Yonh0n?of0?Goo03loo@0moof
0?Coo021oh7oPOn1oh7oi?o^0?3omP3aoo`0fOod0?goo@3ioo`0mooi002jiOoi
0>WokP3iooL0m?ol003okP3jooH0mOol087oPOn1oh7oPOoQonh0l?of0?7oo03N
onX0nOol0?Oon03UooT0jOo^0?Wom`3doo`00?o^0?[omP3eoo`0POn1oh7oPOn1
on7okP3`ooH0lOol0=kojP3ioo`0mooh0>Gon@3Yonh0nOog0?Coo000onh0n_of
0?Goo021oh7oPOn1oh7ohOo^0?3omP3aoo`0g_oZ0?Woo03gooP00:kSooT0jOo^
0?[om`3donH0o_of0?Goo021oh7oPOn1oh7og_o^0>oom`3aoo`0hooX0?Soo@3g
ooL0hooi0>WokP3jooL0m?oV0?komP3eoo`0POn1oh7oPOn1omkokP3_ooL0lOol
0>?oj03hood0moog0>?on@3Yonh0n_og0?CoiP3nooH0mOol087oPOn1oh7oPOoN
onh0koog0?7oo03SonP0n?om0?Oom`00Y>7on@3Yonh0noog0?Gof@3eoo/0POn1
oh7oPOn1omcokP3_ooL0lOol0>Ooi03koo`0n?og0>3on@3Yonh0noog0?Gof@3e
oo/0POn1oh7oPOn1omcokP3_ooL0lOol0>Ooi03koo`0n?og0>3on@3Yonh0noog
0?Gof@3eoo/0POn1oh7oPOn1omcokP3_ooL0lOol0>Ooi03koo`0n?og003o0:GO
ooP0j_o^0?com`3gomT0mOok087oPOn1oh7oPOoIonh0koog0?7oo03Zon40o_ol
0?Som`3MooP0j_o^0?com`3gomT0mOok087oPOn1oh7oPOoIonh0koog0?7oo03Z
on40o_ol0?Som`3MooP0j_o^0?com`3gomT0mOok087oPOn1oh7oPOoIonh0koog
0?7oo03Zon40o_ol0?Som`01ool0YMgon03Zonh0oOog0?[of03eoo/0POn1oh7o
POn1omKokP3_ooL0lOol0>kogP00oo`0n?of0=_on03Zonh0oOog0?[of03eoo/0
POn1oh7oPOn1omKokP3_ooL0lOol0>kogP00oo`0n?of0=_on03Zonh0oOog0?[o
f03eoo/0POn1oh7oPOn1omKokP3_ooL0lOol0>kogP00oo`0n?of007oo`2Kfooh
0>Wok`01ooof0?goe`3eoo/0POn1oh7oPOn1om?okP3_ooH0l_ol0?;oe`3hooH0
f?oh0>Wok`01ooof0?goe`3eoo/0POn1oh7oPOn1om?okP3_ooH0l_ol0?;oe`3h
ooH0f?oh0>Wok`01ooof0?goe`3eoo/0POn1oh7oPOn1om?okP3_ooH0l_ol0?;o
e`3hooH0o_l0V=Son@3Yonl00?og0?koe`3doo`0POn1oh7oPOn1olook`3_ooH0
l_ol0?Goe`3gooL0e?oi0>Wok`00ooL0o_oG0?Coo021oh7oPOn1oh7ocoo_0>oo
mP3boo`0mOoG0?Oom`3DooT0jOo_003om`3nomL0m?ol087oPOn1oh7oPOo?onl0
koof0?;oo03eomL0moog0?go083FooT0jOni0?Goo021oh7oPOn1oh7oc?o_0>oo
mP3boo`0nOoE0?Som`3AooT0jOni0?Goo021oh7oPOn1oh7oc?o_0>oomP3boo`0
nOoE0?Som`3AooT0jOni0?Goo021oh7oPOn1oh7oc?o_0>oomP3boo`0nOoE0?So
m`3lo`20e?oi0>Wo^P3goo`0POn1oh7oPOn1olWokP3`ooH0lOol0?god`3jooL0
c_oi0>Wo^P3goo`0POn1oh7oPOn1olWokP3`ooH0lOol0?god`3jooL0c_oi0>Wo
^P3goo`0POn1oh7oPOn1olWokP3`ooH0lOol0?god`3jooL0nol0Pm;on@3Yok/0
nOok087oPOn1oh7oPOo7onh0koog0?7oo001oooB0?com`3;ooT0jOnk0?Won`21
oh7oPOn1oh7oaoo^0>oom`3aoo`00OoodP3looL0booi0>Wo^`3ioo/0POn1oh7o
POn1olOokP3_ooL0lOol007oom80o?og0?[o07C@ooP0j_nl0?_on`21oh7oPOn1
oh7oa?o^0>oom`3aol`0o_og0<Son03Zok`0nook087oPOn1oh7oPOo4onh0koog
0?7oc03nooL0b?oh0>[o_03koo/0POn1oh7oPOn1olCokP3_ooL0lOo<0?kom`3i
o`1dc_oh0>[o_@3moo/0POn1oh7oPOn1ol7okP3_ooL0lOo=003omP36ooP0j_nm
0?gon`21oh7oPOn1oh7o`Oo^0>oom`3aold00?of0<Kon03Zokd0oOok087oPOn1
oh7oPOo1onh0koog0?7oc@00ooH0nOl0J<con03Zokl0o_ok087oPOn1oh7oPOnn
onh0koof0?Co`P33ooP0j_no0?kon`21oh7oPOn1oh7o__o^0>oomP3dol80`ooh
0>[o_`3noo/0POn1oh7oPOn1okkokP3_ooH0m?o20?So06S9ooT0j_o0003on`21
oh7oPOn1oh7o^oo^0>oomP3fol<0_ooi0>[o`000oo/0POn1oh7oPOn1ok_okP3_
ooH0m_o30;oon@3Zol000?ok087oPOn1oh7oPOnkonh0koof0?Ko``3go`1Laooi
0>Wo_@21oh7oPOn1oh7o^?o^0>oomP3iol<0_?oi0>Wo_@21oh7oPOn1oh7o^?o^
0>oomP3iol<0_?oi0>Wo_@21oh7oPOn1oh7o^?o^0>oomP3iol<0m_l0G<Gon@3Y
ol00POn1oh7oPOn1okCok`3_ooH0noo40;Won@3Yol00POn1oh7oPOn1okCok`3_
ooH0noo40;Won@3Yol00POn1oh7oPOn1okCok`3_ooH0noo40?Go05c3ooT0jOo3
087oPOn1oh7oPOnaonl0k_og0?koa02fooT0jOo3087oPOn1oh7oPOnaonl0k_og
0?koa02fooT0jOo3087oPOn1oh7oPOnaonl0k_og0?koa03do`1L`Ooi0>Woa@21
oh7oPOn1oh7o[oo^0>oom`00olD0/ooi0>Woa@21oh7oPOn1oh7o[oo^0>oom`00
olD0/ooi0>Woa@21oh7oPOn1oh7o[oo^0>oom`00olD0lol0D;oon03/olH0POn1
oh7oPOn1ojcokP3_ok`0/Ooh0>coaP21oh7oPOn1oh7o[?o^0>oo_02aooP0k?o6
087oPOn1oh7oPOn/onh0konl0??o052mooP0k_o6087oPOn1oh7oPOnZonh0kono
0:kon03^olH0POn1oh7oPOn1oj[okP3_okl0[_oh0>koaP21oh7oPOn1oh7oZ_o^
0>oo_`3bo`1@^ooh0?7oa@21oh7oPOn1oh7oZ?o^0>oo`P2[ooP0lOo5087oPOn1
oh7oPOnXonh0koo20:_on03aolD0POn1oh7oPOn1ojSokP3_ol80lOl0D;Son@3c
ol@0POn1oh7oPOn1ojOokP3_ol<0ZOoi0??oa021oh7oPOn1oh7oYoo^0>oo``2Y
ooT0loo4087oPOn1oh7oPOnWonh0koo30?;o052fooT0mOo4087oPOn1oh7oPOnU
onh0l?o40:Oon@3eol@0POn1oh7oPOn1ojGokP3`ol@0Yooi0?Goa021oh7oPOn1
oh7oYOo^0?3oa03bo`1@]?oi0?Ooa021oh7oPOn1oh7oXoo^0?;oa02UooT0moo4
087oPOn1oh7oPOnSonh0l_o40:Gon@3gol@0POn1oh7oPOn1oj?okP3bol@0l_l0
D;;on@3iol@0POn1oh7oPOn1oj3ok`3dol<0Y?oi0?Woa021oh7oPOn1oh7oX?o_
0?Co``2TooT0nOo4087oPOn1oh7oPOnPonl0m?o30??o052`ooP0oOo2087oPOn1
oh7oPOnOonl0moo20:;on03mol80POn1oh7oPOn1oiook`3gol80X_oh0?go`P21
oh7oPOn1oh7oWoo_0?Oo`P3co`1C[_oh007ool80POn1oh7oPOn1oigokP3jol80
X?oh007ool80POn1oh7oPOn1oigokP3jol80X?oh007ool80POn1oh7oPOn1oigo
kP3jol80lol0A:co^@21oh7oPOn1oh7oVoo^0?co`P2NokT0POn1oh7oPOn1oi_o
kP3lol80W_ni087oPOn1oh7oPOnKonh0o?o20??o04BYok`0POn1oh7oPOn1oiWo
kP3nol80Vonl087oPOn1oh7oPOnIonh0o_o209_o_021oh7oPOn1oh7oVOo^0?ko
`P3co`14Yonn087oPOn1oh7oPOnGonh00?o209Wo_P21oh7oPOn1oh7oUoo^003o
`P2Iokh0POn1oh7oPOn1oiOokP00ol80lol0>:Go`021oh7oPOn1oh7oUOn`09Oo
`021oh7oPOn1oh7oUOn`09Oo`021oh7oPOn1oh7oUOn`0??o03RSol80POn1oh7o
POn1oi?o/P2Eol80POn1oh7oPOn1oi?o/P2Eol80POn1oh7oPOn1oi?o/P3co`0h
X_o4087oPOn1oh7oPOn@okD0Too4087oPOn1oh7oPOn@okD0Too4087oPOn1oh7o
POn@okD0l_l0>:;oa021oh7oPOn1oh7oSOnh09?oa021oh7oPOn1oh7oSOnh09?o
a021oh7oPOn1oh7oSOnh0?;o03RRol@0POn1oh7oPOn1oh_o^P2Col@0POn1oh7o
POn1oh_o^P2Col@0POn1oh7oPOn1oh_o^P3bo`0hX_o4087oPOn1oh7oPOn9ok`0
Too4087oPOn1oh7oPOn9ok`0Too4087oPOn1oh7oPOn9ok`0l_l0>:7oaP21oh7o
POn1oh7oQ_no097oaP21oh7oPOn1oh7oQ_no097oaP21oh7oPOn1oh7oQ_no0?7o
03RQolH0POn1oh7oPOn1ohCo`@2AolH0POn1oh7oPOn1ohCo`@2AolH0POn1oh7o
POn1ohCo`@3ao`0hXOo7087oPOn1oh7oPOn1ol@0T?o7087oPOn1oh7oPOn1ol@0
T?o7087oPOn1oh7oPOn1ol@0l?l0Aj7oa`21oh7oPOn1okOo0@00POo;olH0T?o7
087oPOn1oh7o]ol10021ol_oaP2@olL0POn1oh7oPOngo`40087oboo60?3o04BP
olP0POn1oh7oPOnhood0POo:olP0Soo8087oPOn1oh7o^?om087ob_o808oob021
oh7oPOn1okSoo@21ol[ob03`o`14X?o9087oPOn1oh7o^Ooj087ob_o908oob@21
oh7oPOn1okWonP21ol[ob@2?olT0POn1oh7oPOniooX0POo:olT0l?l0A9oobP21
oh7oPOn1ok[onP21olWobP2=olX0POn1oh7oPOnjooX0POo9olX0SOo:087oPOn1
oh7o^_oj087obOo:0>oo04BNol`0POn1oh7oPOnjooX0POo7ol/0S?o<087oPOn1
oh7o^_oj087oaoo;08coc021oh7oPOn1ok[onP21olOob`3_o`14W_o=087oPOn1
oh7o^_ok087oa?o>08[oc@21oh7oPOn1ok[on`21olCocP2:old0POn1oh7oPOnj
oo/0POo4olh0kOl0A9goc`21oh7oPOn1ok_onP21ol;od028oll0POn1oh7oPOnk
ooX0POo2om00R?o?087oPOn1oh7o^ooj087o`_o@0>co04BLom00POn1oh7oPOnl
ooX0POo0om40Qoo@087oPOn1oh7o_?oj087o`?oA08Ood021oh7oPOn1okconP21
ol3od@3/o`14VooB087oPOn1oh7o_?oj087o_ooB08GodP21oh7oPOn1okconP21
okoodP25om80POn1oh7oPOnlooX0POnoom80jol0A9[oe@21oh7oPOn1ok_on`21
okcoe@22omD0POn1oh7oPOnkoo/0POnlomD0P_oE087oPOn1oh7o^ook087o_?oE
0>Wo04BIomH0POn1oh7oPOnmooX0POnjomH0POoF087oPOn1oh7o_Ooj087o^_oF
087oeP21oh7oPOn1okgonP21ok[oeP3Yo`18UooI087oPOn1oh7o_Ooj087o]ooI
087oo_oI087oPOn1oh7o_Ooj087o]ooI087oo_oI087oPOn1oh7o_Ooj087o]ooI
0>So04RFom`0POn1oh7oPOnlooX0POneom`0POokom`0POn1oh7oPOnlooX0POne
om`0POokom`0POn1oh7oPOnlooX0POneom`0i_l0B9GogP21oh7oPOn1okcon`21
ok;ogP21ooWogP21oh7oPOn1okcon`21ok;ogP21ooWogP21oh7oPOn1okcon`21
ok;ogP3Uo`18TooR087oPOn1oh7o_?oj087o[ooR087omOoR087oPOn1oh7o_?oj
087o[ooR087omOoR087oPOn1oh7o_?oj087o[ooR0>?o04RAonH0POn1oh7oPOnk
ooX0POn/onD0POobonH0POn1oh7oPOnkooX0POn/onD0POobonH0POn1oh7oPOnk
ooX0POn/onD0h_l0B93oj@21oh7oPOn1ok[onP21oj[oj021onooj@21oh7oPOn1
ok[onP21oj[oj021onooj@21oh7oPOn1ok[onP21oj[oj03Po`18R_od087oPOn1
oh7o]_ok087oX_od087ohood087oPOn1oh7o]_ok087oX_od087ohood087oPOn1
oh7o]_ok087oX_od0=[o03R1oh7oPOn1oh7o]?oj087oPOn1oh7oPOn1oh7oX?oj
087oPOn1oh7oPOn1oh7oX?oj087oPOo]o`0hPOn1oh7oPOn1okGonP21oh7oPOn1
oh7oPOn1oj3onP21oh7oPOn1oh7oPOn1oj3onP21oh7ok?l0>87oPOn1oh7oPOnf
ooX0POn1oh7oPOn1oh7oPOnPooX0POn1oh7oPOn1oh7oPOnPooX0POn1on_o03R1
oh7oPOn1oh7o]ook087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook
087oPOoYo`0hPOn1oh7oPOn1okWonP21oh7oPOn1oh7oPOn1oj3onP21oh7oPOn1
oh7oPOn1oj3onP21oh7oj?l0>87oPOn1oh7oPOnjooX0POn1oh7oPOn1oh7oPOnP
ooX0POn1oh7oPOn1oh7oPOnPooX0POn1onOo03R1oh7oPOn1oh7o^ooj087oPOn1
oh7oPOn1oh7oX?oj087oPOn1oh7oPOn1oh7oX?oj087oPOoVo`0hPOn1oh7oPOn1
okcon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7oi?l0
@X_on@21oh7oPOn1ok_on`21oh7oPOo]ooT0POn1oh7oPOnkoo/0POn1oh7okOoi
087oPOn1oh7o^ook087oPOoSo`12S_od087oPOn1oh7o_ooj087oPOn1onoom021
oh7oPOn1okoonP21oh7oPOo_oo@0POn1oh7oPOnoooX0POn1on;o04:?oo40POn1
oh7oPOo2ooX0POn1oh7okooa087oPOn1oh7o`_oj087oPOn1onool@21oh7oPOn1
ol;onP21oh7ohOl0@Y3ol021oh7oPOn1ol?onP21oh7oPOo_oo00POn1oh7oPOo3
ooX0POn1oh7okoo`087oPOn1oh7o`ooj087oPOoPo`1DTOok0?[on`21oh7oPOn1
olGon`21oh_on@21oncon`3joo/0POn1oh7oPOo5oo/0POn;ooT0POo/oo/0n_ok
087oPOn1oh7oaOok087oRooi0=co05BBoo/0mool087oPOn1oh7ob?oj087oSOod
087okook0?Ooo021oh7oPOn1olSonP21ohgom021onoon`3goo`0POn1oh7oPOo8
ooX0POn=oo@0g_l0E9;oo03eood0POn1oh7oPOo9ooX0POn=oo40POoaoo`0mOom
087oPOn1oh7obOoj087oSOoa087olOol0?Goo@21oh7oPOn1olWonP21ohgol@3P
o`1DT_om0?Coo021oh7oPOn1ol_onP21ohgol021oo7oo@3doo`0POn1oh7oPOo;
ooX0POn=oo00POoaood0m?ol087oPOn1oh7obooj087oSOo`0>3o062Coo`0loom
087oPOn1oh7oc?ok087oS?ok0?[on`21oo?oo03cood0POn1oh7oPOo<oo/0POn<
oo/0n_ok087olool0??oo@21oh7oPOn1olcon`21ohcon`3joo/0hOl0H9?oo@3b
ood0POn1oh7oPOo>ooX0POn<oo/0mool087om?om0?;oo@21oh7oPOn1olkonP21
ohcon`3goo`0POodood0l_om087oPOn1oh7oc_oj087oS?ok0?Ooo03Ro`1PToom
0?;oo@21oh7oPOn1oloonP21oh_oo03eood0POodood0l_om087oPOn1oh7ocooj
087oRool0?Goo@21ooCoo@3bood0POn1oh7oPOo?ooX0POn;oo`0mOom0>;o062C
ood0l_om087oPOn1oh7od?oj087oR_om0?Coo021ooGoo@3bood0POn1oh7oPOo@
ooX0POn:ood0m?ol087omOom0?;oo@21oh7oPOn1om3onP21oh[oo@3doo`0hol0
EX7o0?om087oPOn1oh7odOok087oROol0??oo@21on;oo@21oh7oPOn1om7on`21
ohWoo03cood0POoRood0POn1oh7oPOoAoo/0POn9oo`0loom0>?o05B1oo`0POn1
oh7oPOoCooX0POn8ood0l_om087ohool087oPOn1oh7odooj087oR?om0?;oo@21
on?oo021oh7oPOn1om?onP21ohSoo@3bood0hol0E8;oo021oh7oPOn1om?onP21
ohOoo@3bood0POoToo`0POn1oh7oPOoCooX0POn7ood0l_om087oi?ol087oPOn1
oh7odooj087oQoom0?;oo@3So`1DPook087oPOn1oh7oe?oj087oQ_om0?;oo@21
onGon`21oh7oPOn1omConP21ohKoo@3bood0POoUoo/0POn1oh7oPOoDooX0POn6
ood0l_om0>?o04j4oo/0POn1oh7oPOoDoo/0POn1oo7oo@21onKon`21oh7oPOn1
omCon`21oh7olOom087oi_ok087oPOn1oh7oe?ok087oPOoaood0hol0CXKonP21
oh7oPOn1omGonP21oh7olOol087oj?oj087oPOn1oh7oeOoj087oPOoaoo`0POoX
ooX0POn1oh7oPOoEooX0POn1oo7oo03So`1>R?oi087oPOn1oh7oeOoj087oPOoa
oo`0POoYooT0POn1oh7oPOoEooX0POn1oo7oo021onWon@21oh7oPOn1omGonP21
oh7olOol0>;o04j9ooT0POn1oh7oPOoEooX0POn1oo7on`21on[on@21oh7oPOn1
omGonP21oh7olOok087oj_oi087oPOn1oh7oeOoj087oPOoaoo/0h_l0CX_on@21
oh7oPOn1omCon`21oh7ol?ok087ojooi087oPOn1oh7oe?ok087oPOo`oo/0POo[
ooT0POn1oh7oPOoDoo/0POn1oo3on`3Qo`1>SOoh087oPOn1oh7oeOoj087oPOoa
ooX0POo/ooP0POn1oh7oPOoEooX0POn1oo7onP21oncon021oh7oPOn1omGonP21
oh7olOoj0>3o04j>ooT0POn1oh7oPOoDooX0POn1oo;on@21oncon@21oh7oPOn1
omConP21oh7ol_oi087ok?oi087oPOn1oh7oe?oj087oPOobooT0gol0CXoonP21
oh7oPOn1om?onP21oh7ol_oi087ok?oj087oPOn1oh7odooj087oPOobooT0POo/
ooX0POn1oh7oPOoCooX0POn1oo;on@3No`1>T?ok087oPOn1oh7od_ok087oPOob
ooT0POo[oo/0POn1oh7oPOoBoo/0POn1oo;on@21on_on`21oh7oPOn1om;on`21
oh7ol_oi0=co04jAoo/0POn1oh7oPOoBoo/0POn1oo?on021on_on`21oh7oPOn1
om;on`21oh7olooh087ojook087oPOn1oh7od_ok087oPOocooP0fol0CY;oo021
oh7oPOn1om;onP21oh7olooi087oj_ol087oPOn1oh7od_oj087oPOocooT0POoZ
oo`0POn1oh7oPOoBooX0POn1oo?on@3Io`1>T_om087oPOn1oh7od_oj087oPOoc
ooX0POoXood0POn1oh7oPOoBooX0POn1oo?onP21onSoo@21oh7oPOn1om;onP21
oh7olooj0=Oo04jCood0POn1oh7oPOoBooX0POn1oo?on`21onOoo@21oh7oPOn1
om;onP21oh7olook087oioom087oPOn1oh7od_oj087oPOocoo/0eOl0CY?oo@21
oh7oPOn1om?on`21oh7ol_ok087oi_om087oPOn1oh7odook087oPOoboo/0POoV
ood0POn1oh7oPOoCoo/0POn1oo;on`3Do`1>Toon087oPOn1oh7oe?oj087oPOob
oo`0POoTooh0POn1oh7oPOoDooX0POn1oo;oo021onCooP21oh7oPOn1omConP21
oh7ol_ol0=;o04jDonT0POn1oh7oPOoYooX0POn1oo7oo@21onCoj@21oh7oPOn1
onWonP21oh7olOom087oi?oY087oPOn1oh7ojOoj087oPOoaood0dOl0CYCoj@21
oh7oPOn1on[onP21oh7olOom087ohooY087oPOn1oh7oj_oj087oPOoaood0POoS
onT0POn1oh7oPOoZooX0POn1oo7oo@3@o`1>U?oY087oPOn1oh7ojook087oPOo_
ood0POoSonT0POn1oh7oPOo[oo/0POn1onooo@21on?oj@21oh7oPOn1on_on`21
oh7okoom0=3o04jDonT0POn1oh7oPOo]ooX0POn1onkooP21on;oj@21oh7oPOn1
ongonP21oh7ok_on087oh_oY087oPOn1oh7okOoj087oPOo^ooh0col0A87oPOn1
oh7oPOoYooX0POn1onkoj@21oh7oPOn1oh7obooj087oPOo^onT0POn1oh7oPOn1
ol_onP21oh7ok_oY0>?o04B1oh7oPOn1oh7oj_oj087oPOo]onT0POn1oh7oPOn1
olconP21oh7okOoY087oPOn1oh7oPOo<ooX0POn1ongoj@3So`14POn1oh7oPOn1
on_on`21oh7ojooY087oPOn1oh7oPOo=oo/0POn1on_oj@21oh7oPOn1oh7ocOok
087oPOo[onT0hol0A87oPOn1oh7oPOo]ooX0POn1on[oj@21oh7oPOn1oh7ocooj
087oPOoZonT0POn1oh7oPOn1oloonP21oh7oj_oY0>?o03R1oh7oPOn1oh7ok_oj
087oPOn1oh7oPOn1oh7oX?oj087oPOn1oh7oPOn1oh7oX?oj087oPOnco`0hPOn1
oh7oPOn1onoonP21oh7oPOn1oh7oPOn1oj3onP21oh7oPOn1oh7oPOn1oj3onP21
oh7o/_l0>87oPOn1oh7oPOo`oo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1
oh7oPOnOoo/0POn1ok3o03R1oh7oPOn1oh7ol_oj087oPOn1oh7oPOn1oh7oX?oj
087oPOn1oh7oPOn1oh7oX?oj087oPOn_o`0hPOn1oh7oPOn1oo?onP21oh7oPOn1
oh7oPOn1oj3onP21oh7oPOn1oh7oPOn1oj3onP21oh7o[_l0>87oPOn1oh7oPOod
ooX0POn1oh7oPOn1oh7oPOnPooX0POn1oh7oPOn1oh7oPOnPooX0POn1ojgo03R1
oh7oPOn1oh7omOok087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook
087oPOn[o`0hPOn1oh7oPOn1ooOonP21oh7oPOn1oh7oPOn1oj3onP21oh7oPOn1
oh7oPOn1oj3onP21oh7oZ_l0>87oPOn1oh7oPOohooX0POn1oh7oPOn1oh7oPOnP
ooX0POn1oh7oPOn1oh7oPOnPooX0POn1ojWo03R1oh7oPOn1oh7onOoj087oPOn1
oh7oPOn1oh7oX?oj087oPOn1oh7oPOn1oh7oX?oj087oPOnXo`0hPOn1oh7oPOn1
oo[on`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7oY_l0
>87oPOn1oh7oPOokoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnO
oo/0POn1ojGo03R1oh7oPOn1oh7ooOoj087oPOn1oh7oPOn1oh7oX?oj087oPOn1
oh7oPOn1oh7oX?oj087oPOnTo`0hPOn1oh7oPOn1ookonP21oh7oPOn1oh7oPOn1
oj3onP21oh7oPOn1oh7oPOn1oj3onP21oh7oXol0>H7oPOn1oh7oPOl1oooj087o
POn1oh7oPOn1oh7oX?oj087oPOn1oh7oPOn1oh7oX?oj087oPOnRo`0hPOn1oh7o
POn1o`3on`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7o
X?l0=X7oPOn1oh7oP_oj087oPOn1oh7oPOn1oh7oX?oj087oPOn1oh7oPOn1oh7o
X?oj087oPOnOo`0fPOn1oh7oPOn3ooX0POn1oh7oPOn1oh7oPOnPooX0POn1oh7o
POn1oh7oPOnPooX0POn1oiko03J1oh7oPOn1ohConP21oh7oPOn1oh7oPOn1oj3o
nP21oh7oPOn1oh7oPOn1oj3onP21oh7oWOl0=X7oPOn1oh7oQOok087oPOn1oh7o
POn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOnKo`0fPOn1oh7oPOn7ooX0
POn1oh7oPOn1oh7oPOnPooX0POn1oh7oPOn1oh7oPOnPooX0POn1oi[o03J1oh7o
POn1ohSonP21oh7oPOn1oh7oPOn1oj3onP21oh7oPOn1oh7oPOn1oj3onP21oh7o
VOl0=X7oPOn1oh7oROoj087oPOn1oh7oPOn1oh7oX?oj087oPOn1oh7oPOn1oh7o
X?oj087oPOnHo`0fPOn1oh7oPOn:oo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7o
POn1oh7oPOnOoo/0POn1oiKo03J1oh7oPOn1ohconP21oh7oPOn1oh7oPOn1oj3o
nP21oh7oPOn1oh7oPOn1oj3onP21oh7oUOl0=X7oPOn1oh7oSOoj087oPOn1oh7o
POn1oh7oX?oj087oPOn1oh7oPOn1oh7oX?oj087oPOnDo`0fPOn1oh7oPOn>ooX0
POn1oh7oPOn1oh7oPOnPooX0POn1oh7oPOn1oh7oPOnPooX0POn1oi?o03J1oh7o
POn1ohoon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7o
TOl0=X7oPOn1oh7oTOoj087oPOn1oh7oPOn1oh7oX?oj087oPOn1oh7oPOn1oh7o
X?oj087oPOn@o`0fPOn1oh7oPOnBooX0POn1oh7oPOn1oh7oPOnPooX0POn1oh7o
POn1oh7oPOnPooX0POn1ohoo03J1oh7oPOn1oi?onP21oh7oPOn1oh7oPOn1oj3o
nP21oh7oPOn1oh7oPOn1oj3onP21oh7oS_l0=X7oPOn1oh7oU?ok087oPOn1oh7o
POn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOn<o`0fPOn1oh7oPOnEoo/0
POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh_o03J1oh7o
POn1oiOonP21oh7oPOn1oh7oPOn1oj3onP21oh7oPOn1oh7oPOn1oj3onP21oh7o
R_l0=X7oPOn1oh7oV?oj087oPOn1oh7oPOn1oh7oX?oj087oPOn1oh7oPOn1oh7o
X?oj087oPOn9o`1APOn1oh7oPOnIooX0POl1ooom087odoom087oPOn1oh7oPOoH
ooX0POl1ooom087odoom087oPOn1oh7oPOoHooX0POl1ooom087odoom0<3o05J1
oh7oPOn1oi[on`21oogoo@21om?oo@3;ooX0POn1oh7oPOnFoo/0POomood0POoC
ood0booj087oPOn1oh7oU_ok087ooOom087odoom0<_onP3mo`1FPOn1oh7oPOnL
ooX0POolood0POoCood0cOoe087oPOn1oh7oVooj087oo?om087odoom0<gom@21
oh7oPOn1oi_onP21oocoo@21om?oo@3=ooD00?l0E87oPOn1oh7oWOoj087onoom
087odoom0<oolP21oh7oPOn1oigonP21oo_oo@21om?oo@3?oo80POn1oh7oPOnM
ooX0POokood0POoCood0coob001DPOn1oh7oPOnNooX0POojood0POoCood0d?oa
087oPOn1oh7oW_oj087on_om087odoom0=3ol@21oh7oPOn1oikonP21oo[oo@21
om?oo@3@oo400621oh7oPOn1oioon`21ooSoo@21om?oo@3@oo/0noom087oPOn1
oh7oWook087on?om087odoom0=3on`3kood0POn1oh7oPOnOoo/0POohood0POoC
ood0d?ok0?_oo@00H87oPOn1oh7oXOoj087omoom087odoom0=7oo03hooh0POn1
oh7oPOnQooX0POogood0POoCood0dOol0?SooP21oh7oPOn1oj7onP21ooOoo@21
om?oo@3Aoo`0n?on001SPOn1oh7oPOnRooX0POofood0POoCood0dOom0?Ko0@00
POn1oh7oPOnRooX0POofood0POoCood0dOom0?Ko0@00POn1oh7oPOnRooX0POof
ood0POoCood0dOom0?Ko0@000621oh7oPOn1oj?onP21ooGoo@21om?oo@3Aood0
mOl0087oPOn1oh7oXooj087omOom087odoom0=7oo@3eo`00POn1oh7oPOnSooX0
POoeood0POoCood0dOom0?Go0000l87oPOn1oh7oY?ok0;coo@3lood0mOoj0?Co
o@3loo/0m?om0??on@3^ooX0kOoj0>Ooo@3looX0kooi0>gonP3mood0l_oj0>So
o03eo`00POn1oh7oPOnToo/0_?om0?coo@3eooX0m?om0?con`3dood0looi0>ko
nP3]ooX0ioom0?conP3_ooT0kOoj0?goo@3booX0j?ol0?Go0021oh7oPOn1ojCo
n`2lood0o?om0?GonP3dood0o?ok0?Coo@3cooT0k_oj0>gonP3Wood0o?oj0>oo
n@3]ooX0oOom0?;onP3Xoo`0mOl0003oPOn1oloom021oh7oiOoj0;_oo@3noo/0
n?oe0?Koo@3nooH0moom0?Kom03booD0looe0>Woo@3nooH0looe0?7omP01ooom
0?Gom@3Zood0m?l0087oPOo?oo@0POn1onGonP2kood0o_ok0?Som@3food0o_of
0?Ooo@3foo@0l_oe0??om@3Yood0o_of0??om@3aooH00Oooo@3eooD0j_om0?Co
0021oh7ocood087oPOoUooX0^oom0?kon`3hooD0m_om0?komP3good0m_od0?;o
m@3cooD0jOom0?komP3cooD0lOof007oood0mOoe0>[oo@3do`000@F1oh7odOo_
087oPOoYooX0^_om007oooX0nOob0?Soo@01oood0?Soo@3goo40mOoc0?GolP3[
ood00Ooom03eoo80mOoc003oo@3foo80k?om0?Co0021oh7odOo_087oPOoYooX0
^_om007oooX0nOob0?Soo@01oood0?Soo@3goo40mOoc0?GolP3[ood00Ooom03e
oo80mOoc003oo@3foo80k?om0?Co0021oh7odOo_087oPOoYooX0^_om007oooX0
nOob0?Soo@01oood0?Soo@3goo40mOoc0?GolP3[ood00Ooom03eoo80mOoc003o
o@3foo80k?om0?Co0000l87oPOoEonP0POn1ongonP2iood00?oi0?[ol03iood0
0?ob0?Woo@3honl0mooa0?Ool03/ood00?ob0?Ool03fonh0moo`0>goo@3do`00
POn1omGoj021oh7okOoj0;Woo@00ooT0n_o`0?Woo@00oo80nOom0?Sok`3goo40
moo`0>coo@00oo80moo`0?KokP3goo00kOom0?Co0021oh7oeOoX087oPOo]ooX0
^Oom003on@3joo00nOom003olP3iood0n?o_0?Ool@3goo00k?om003olP3goo00
m_o^0?Ool03]ood0m?l0004_POn1omKoi@21oh7ol?ok0;Oon@3foo/0nooj0?[o
n03looX0n_om0?Won`3joo/0n?ok0?conP3ioo/0nooj0>gon03loo/0n?ok0?_o
nP3hoo/0o?oh0?Son`3kooX0g_l10021oh7oe_oU087oPOo`oo/0]ooi0?Kon`3k
ooX0n_oh0?conP3jood0nOok0?[on`3hoo/0o?oj0?Won`3kooX0kOoh0?con`3h
oo/0nooj0?Son`3looP0n?ok0?_onP3No`40087oPOoFonD0POn1oo3on`2gooT0
m_ok0?_onP3jooP0o?oj0?[oo@3ioo/0n_ok0?Son`3looX0nOok0?_onP3]ooP0
o?ok0?Son`3kooX0n?ok0?con03hoo/0nooj0=ko0@000Bb1oh7of?oQ087oPOod
ooX0]_oj0?Koo03goo`0n_oj0?Soo03jood0nOol0?Ooo03joo`0n?ol0?[oo03g
oo`0kOoj0?Soo@3ioo`0mool0?Woo03hooX0nOol0?Ooo03Oooh0POn1omSoh@21
oh7om?oj0;KonP3foo`0mool0?[onP3hoo`0n_om0?Woo03goo`0n_ol0?Soo03j
oo`0mool0>gonP3hood0nOol0?Ooo03ioo`0n?oj0?Woo03goo`0goon087oPOoH
on40POn1ooConP2fooX0m_ol0?Ooo03jooX0n?ol0?[oo@3ioo`0mool0?[oo03h
oo`0n_ol0?Ooo03]ooX0n?om0?Woo03goo`0nOol0?SonP3ioo`0mool0=oooP01
;87oPOoJomh0POn1ooKonP2eoo/0mOom0?Goo03koo/0m_ol0?_oo@3joo`0mOom
0?[oo@3food0n_om0?Goo03^oo/0mool0?[oo@3eoo`0n_om0?Kon`3iood0mOol
0>7oo@21oh7of_oN087oPOofooX0]Ook0?Goo@3eoo`0nook0?Koo03kood0n_ol
0?Goo@3jood0m_om0?[oo@3eoo`0k_ok0?Ooo03jood0mOol0?[oo@3foo/0nOom
0?Goo03Qood0POn1om[ogP21oh7om_oj0;Gon`3eood0mOol0?_on`3foo`0noom
0?[oo03eood0n_om0?Koo@3jood0mOol0>kon`3goo`0n_om0?Goo03jood0m_ok
0?Woo@3eoo`0hOom004/POn1om_of`21oh7onOoj0;Coo03eood0loom0?_oo03d
ood0noom0?[oo@3dood0nool0?Koo03lood0loom0>koo03eood0nool0?Coo@3k
oo`0mOol0?[oo@3cood0ioog087oPOoKom/0POn1ooWonP2doo`0mOom0??oo@3k
oo`0m?om0?_oo@3jood0m?om0?_oo03foo`0o?om0??oo@3^oo`0mOom0?_oo03d
ood0nool0?Goo03jood0loom0>Oom`21oh7ofooK087oPOoiooX0]?ol0?Goo@3c
ood0nool0?Coo@3kood0n_om0?Coo@3koo`0m_ol0?coo@3cood0k_ol0?Goo@3k
oo`0m?om0?_oo03eoo`0n_om0??oo@3WooL00Bj1oh7ogOoG087oPOoloo/0/_om
0?Coo@3coo`0o?ol0?Coo@3kood0n_om0?Coo@3kood0m?om0?coo@3coo`0kool
0?Goo@3kood0loom0?_oo@3doo`0n_om0??oo03XooP0POn1omcoe`21oh7oo?ok
0;;oo@3dood0lool0?coo03dood0noom0?[oo@3dood0noom0?Coo@3lood0lool
0>ooo03eood0noom0??oo@3kood0m?ol0?[oo@3coo`0j?oh087oPOoLomL0POn1
oocon`2bood0m?om0??oo03loo`0m?om0?_oo@3jood0m?om0?_oo@3dood0o?om
0??oo03_oo`0mOom0?_oo@3cood0noom0?Coo03jood0lool0>Son000o`4SPOn1
omkoe@21oh7o0OoonP2aood0m?on0?7oo@3loo`0m?ol0?coo@3Yood0noom0?Co
o@3looh0lOom0>ooo@3dood0noom0?;oo@3lood0m?ol0?[ooP3aood0j?og087o
POoNomD0POn1o`7oooX0/Oom0?CooP3aood0o?ol0?Coo03lood0jOom0?_oo@3d
ood0o?on0?7oo@3_ood0m?om0?_oo@3bood0o?om0?Coo03jooh0lOom0>Som`21
oh7og_oE087oPOl1oooj0;7oo@3dooh0lOom0?coo03doo`0o?om0>Woo@3kood0
m?om0?cooP3aood0koom0?Coo@3kood0l_om0?coo@3doo`0n_on0?7oo@3XooL0
0@j1oh7ogooC087oPOoj0;3oo@3eood0lOom0?coo@3bood0o?om0>[oo03lood0
joom0?7oo@3_ood0m?om0?coo@3aood0oOom0?;oo@3kood0lOom0>Som`21oh7o
gooC087oPOoj0;3oo@3eood0lOom0?coo@3bood0o?om0>[oo03lood0joom0?7o
o@3_ood0m?om0?coo@3aood0oOom0?;oo@3kood0lOom0>Som`21oh7ogooC087o
POoj0;3oo@3eood0lOom0?coo@3bood0o?om0>[oo03lood0joom0?7oo@3_ood0
m?om0?coo@3aood0oOom0?;oo@3kood0lOom0>Som`00jX7oPOoPom40POn3ooX0
[oom0?Goj@3lood0l_om0?coo@3]ooT0o?om0>_oj@3_ood0m?om0?coo@3aood0
oOom0?;oo@3konT0h_om087oPOoPom40POn3ooX0[oom0?Goj@3lood0l_om0?co
o@3]ooT0o?om0>_oj@3_ood0m?om0?coo@3aood0oOom0?;oo@3konT0h_om087o
POoPom40POn3ooX0[oom0?Goj@3lood0l_om0?coo@3]ooT0o?om0>_oj@3_ood0
m?om0?coo@3aood0oOom0?;oo@3konT0h_om003ZPOn1on7oc`21ohGon`2]ood0
mOoY0?coo@3bood0o?om0?ColP3lood0jooY0>ooo@3dood0o?om0?7oo@3mood0
l_om0?_oj@3Oo`00POn1on7oc`21ohGon`2]ood0mOoY0?coo@3bood0o?om0?Co
lP3lood0jooY0>ooo@3dood0o?om0?7oo@3mood0l_om0?_oj@3Oo`00POn1on7o
c`21ohGon`2]ood0mOoY0?coo@3bood0o?om0?ColP3lood0jooY0>ooo@3dood0
o?om0?7oo@3mood0l_om0?_oj@3Oo`000>21oh7oh_o>087oQ_ok0:coo@3eonT0
o?om0?;oo@3lood0moo_0?coo@3[onT0koom0?Coo@3lood0lOom0?goo@3bood0
nooY087oPOnoolh0POn6oo/0[?om0?Goj@3lood0l_om0?coo@3gonl0o?om0>_o
j@3_ood0m?om0?coo@3aood0oOom0?;oo@3konT0POn1okoocP21ohKon`2/ood0
mOoY0?coo@3bood0o?om0?Ook`3lood0jooY0>ooo@3dood0o?om0?7oo@3mood0
l_om0?_oj@3No`3/POn1on;oc@21ohWonP2[ood0mOoY0?coo@3bood0o?om0?So
l`00ood0o?om0>_oj@3_ood0m?om0?coo@3aood0oOom0?;oo@3konT0POn1okoo
c@21ohWonP2[ood0mOoY0?coo@3bood0o?om0?Sol`00ood0o?om0>_oj@3_ood0
m?om0?coo@3aood0oOom0?;oo@3konT0POn1okooc@21ohWonP2[ood0mOoY0?co
o@3bood0o?om0?Sol`00ood0o?om0>_oj@3_ood0m?om0?coo@3aood0oOom0?;o
o@3konT0g_l0k87oPOoSol/0POn;ooX0Z_om0?Goo@3Xood0l_om0?coo@3iooH0
o?om0?coo@3[ood0foom0?Coo@3lood0lOom0?goo@3bood0noom087oPOn/ol/0
POn;ooX0Z_om0?Goo@3Xood0l_om0?coo@3iooH0o?om0?coo@3[ood0foom0?Co
o@3lood0lOom0?goo@3bood0noom087oPOn/ol/0POn;ooX0Z_om0?Goo@3Xood0
l_om0?coo@3iooH0o?om0?coo@3[ood0foom0?Coo@3lood0lOom0?goo@3bood0
noom0<[o0?R1oh7ohoo;087oS?oj0:Woo@3eood0j?om0?;oo@3lood0n_ok0?Ko
o@3lood0joom0=_oo@3dood0o?om0?7oo@3mood0l_om0?_oo@3Mood0POn1omCo
b`21ohconP2Yood0mOom0>Soo@3bood0o?om0?[on`3food0o?om0>_oo@3Kood0
m?om0?coo@3aood0oOom0?;oo@3kood0gOom087oPOoDol/0POn<ooX0ZOom0?Go
o@3Xood0l_om0?coo@3joo/0m_om0?coo@3[ood0foom0?Coo@3lood0lOom0?go
o@3bood0noom0=goo@3bo`3hPOn1onCob@21ohkon`2Wood0mOom0>Soo@3bood0
o?om0?_oo03dood0o?om0>_oo@3Kood0m?om0?coo@3aood0oOom0?;oo@3kood0
gOom087oPOoEolT0POn>oo/0Yoom0?Goo@3Xood0l_om0?coo@3koo`0m?om0?co
o@3[ood0foom0?Coo@3lood0lOom0?goo@3bood0noom0=goo@21oh7oeOo9087o
S_ok0:Ooo@3eood0j?om0?;oo@3lood0nool0?Coo@3lood0joom0=_oo@3dood0
o?om0?7oo@3mood0l_om0?_oo@3Mood0l_l1187oPOoUolL0POnAooX0Y_om0?Go
o03Yood0loom0?_oo@3kood0loom0?coo03dood0oOol0=coo@3dood0o?ol0??o
o@3loo`0m?ol0?_oo03Nood0POn1omKoa`21oi7onP2Vood0mOol0>Woo@3cood0
noom0?_oo@3cood0o?ol0?Coo@3moo`0g?om0?Coo@3loo`0loom0?coo03doo`0
nool0=koo@21oh7oe_o7087oTOoj0:Koo@3eoo`0jOom0??oo@3kood0noom0??o
o@3loo`0m?om0?goo03Lood0m?om0?coo03cood0o?ol0?Coo03koo`0g_om0?;o
0BR1oh7oiOo7087oT_oj0:Goo@3dood0l_om0?coo03dood0noom0?_oo@3cood0
noom0?Coo@3lood0l_om0>ooo@3dood0noom0??oo@3kood0m?ol0?[oo@3bood0
lOol087oPOoGolL0POnBooX0YOom0?Coo@3bood0o?ol0?Coo@3kood0noom0??o
o@3kood0m?om0?coo@3bood0koom0?Coo@3kood0loom0?_oo@3doo`0n_om0?;o
o@3aoo`0POn1omOoa`21oi;onP2Uood0m?om0?;oo@3loo`0m?om0?_oo@3kood0
loom0?_oo@3dood0o?om0?;oo@3_ood0m?om0?_oo@3cood0noom0?Coo03jood0
l_om0?7oo03co`4XPOn1onGoa`21oi?onP2Tood0m?om0??oo03loo`0mOol0?_o
o@3kood0m?ol0?_oo@3eood0noom0??oo03_ood0m?om0?_oo@3doo`0nool0?Ko
n`3jood0lool0?3oo@21oh7oeoo7087oTooj0:Coo@3dood0lool0?coo03eoo`0
noom0?_oo@3doo`0noom0?Goo@3kood0lool0>ooo@3dood0noom0?Coo03koo`0
m_ok0?[oo@3coo`0l?om087oPOoGolL0POnCooX0Y?om0?Coo@3coo`0o?ol0?Go
o03kood0noom0?Coo03kood0mOom0?_oo@3coo`0koom0?Coo@3kood0m?ol0?_o
o03foo/0n_om0??oo03`ood0lol1<X7oPOoVolD0POnEoo/0X_om0?Coo03eoo`0
nook0?Koo03kood0noom0?Gon`3koo`0mool0?_oo03eoo`0k_om0?Coo@3koo`0
mOom0?[oo03foo/0n_ol0?Goo03_oo`0mOl0087oPOoVolD0POnEoo/0X_om0?Co
o03eoo`0nook0?Koo03kood0noom0?Gon`3koo`0mool0?_oo03eoo`0k_om0?Co
o@3koo`0mOom0?[oo03foo/0n_ol0?Goo03_oo`0mOl0087oPOoVolD0POnEoo/0
X_om0?Coo03eoo`0nook0?Koo03kood0noom0?Gon`3koo`0mool0?_oo03eoo`0
k_om0?Coo@3koo`0mOom0?[oo03foo/0n_ol0?Goo03_oo`0mOl0004ePOn1onKo
a@21oiOonP2Qood0lool0?Oon`3kooX0n?ol0?[oo@3koo`0mooj0?[oo03hoo`0
n_ol0?Oon`3^ood0m?om0?[oo03goo`0nOol0?SonP3ioo`0mook0>oon`3go`40
087oPOoVolD0POnGooX0XOom0??oo03goo/0nooj0?Soo03jood0nool0?OonP3j
oo`0n?ol0?[oo03goo/0k_om0?Coo@3joo`0mool0?Woo03hooX0nOol0?Oon`3_
oo/0mol10021oh7oi_o5087oUooj0:7oo@3coo`0mook0?_onP3hoo`0n_om0?_o
o03gooX0n_ol0?Soo03joo`0mook0>koo@3dood0n_ol0?Ooo03ioo`0n?oj0?Wo
o03goo/0kook0?Oo0@000C:1oh7oioo3087oVOoj0:3oo@3boo/0nooj0?[on03l
oo/0nOom0?[on`3kooP0nOol0?_on`3hoo/0nooj0>goo@3dood0n_oj0?_on`3g
oo/0o?oh0?Son`3kooX0kOok0?[oo@21oh7oioo3087oVOoj0:3oo@3boo/0nooj
0?[on03loo/0nOom0?[on`3kooP0nOol0?_on`3hoo/0nooj0>goo@3dood0n_oj
0?_on`3goo/0o?oh0?Son`3kooX0kOok0?[oo@21oh7oioo3087oVOoj0:3oo@3b
oo/0nooj0?[on03loo/0nOom0?[on`3kooP0nOol0?_on`3hoo/0nooj0>goo@3d
ood0n_oj0?_on`3goo/0o?oh0?Son`3kooX0kOok0?[oo@00jX7oPOoWol@00_l0
087oW?oj09ooo@3aoo00nOo]0?Woo@3joo400?oj0?col@3foo00k?om0?Coo@3i
oo00m_ob003oo@3goo00jooa087oPOoWol@00_l0087oW?oj09ooo@3aoo00nOo]
0?Woo@3joo400?oj0?col@3foo00k?om0?Coo@3ioo00m_ob003oo@3goo00jooa
087oPOoWol@00_l0087oW?oj09ooo@3aoo00nOo]0?Woo@3joo400?oj0?col@3f
oo00k?om0?Coo@3ioo00m_ob003oo@3goo00jooa003lPOn1onOoa03no`40087o
Wook09goo@3`oo80n?om003ol`3hood0nOoc0?kon`3koo80mOob0>_oo@3dood0
n?ob0?Com001ooom0?KolP3Yoo80POn1onOoa03no`40087oWook09goo@3`oo80
n?om003ol`3hood0nOoc0?kon`3koo80mOob0>_oo@3dood0n?ob0?Com001ooom
0?KolP3Yoo80POn1onOoa03no`40087oWook09goo@3`oo80n?om003ol`3hood0
nOoc0?kon`3koo80mOob0>_oo@3dood0n?ob0?Com001ooom0?KolP3Yoo800?^1
oh7oioo30?gooP21ojConP2Lood0kood0?Ooo@01ooof0?Koo@3hooH0o?ok0?Wo
mP3boo@0j_om0?Coo@3fooD0lOog0?koo@3eoo@0iood087oPOoVol<0oOon087o
Y?oj09coo@3_oo@0moom007oooH0m_om0?SomP3loo/0nOof0?;om03Zood0m?om
0?Kom@3aooL0o_om0?Gom03Woo@0POn1onKo``3mooh0POnTooX0W?om0>oom03g
ood00OoomP3food0n?of0?con`3iooH0l_od0>[oo@3dood0m_oe0?7om`3nood0
mOod0>Oom000o`3>POn1onOo``3jo`40087o`ol1003WooX0Pooi0?Coo@3mooX0
iOoj0?Woo03gooX0k_oi0<Gon@3]oo/0j_oi0>;on021oh7oi?o30?[o0@00POo3
o`400>OonP23ooT0m?om0?gonP3UooX0nOol0?OonP3^ooT0aOoi0>gon`3ZooT0
h_oh087oPOoTol<0n_l10021ol?o0@00iooj08?on@3dood0oOoj0>GonP3ioo`0
mooj0>kon@35ooT0kOok0>[on@3RooP0o_l0IH7oPOoWol<0n?l10021olGooP3Y
ooX0POo]ood0POn1oh7oPOoHol<0n?l10021olGooP3YooX0POo]ood0POn1oh7o
POoHol<0n?l10021olGooP3YooX0POo]ood0POn1oo;o06F1oh7oioo30?Ko0@00
POo8oo`0jook087ojoom087oPOn1oh7of?o30?Ko0@00POo8oo`0jook087ojoom
087oPOn1oh7of?o30?Ko0@00POo8oo`0jook087ojoom087oPOobo`1UPOn1onOo
``3do`40087ob_ol0>gonP21on[oo@21oh7oPOn1omSo``3do`40087ob_ol0>go
nP21on[oo@21oh7oPOn1omSo``3do`40087ob_ol0>gonP21on[oo@21oh7ol_l0
IH7oPOoWol<0l_l10021olgonP3_ooX0POoYood0POn1oh7oPOoHol<0l_l10021
olgonP3_ooX0POoYood0POn1oh7oPOoHol<0l_l10021olgonP3_ooX0POoYood0
POn1oo;o06F1oh7oioo30?3o0@00POo?ooT0lOoj087oj?om087oPOn1oh7of?o3
0?3o0@00POo?ooT0lOoj087oj?om087oPOn1oh7of?o30?3o0@00POo?ooT0lOoj
087oj?om087oPOobo`1aPOn1ookooP3]ol<0k_l10021om;om`3coo/0POoVood0
POn1oh7oPOo_ooh0kOo30>ko0@00POoBooL0look087oi_om087oPOn1oh7okoon
0>go``3^o`40087od_og0??on`21onKoo@21oh7ol_l0LH7oPOonooh0kOo40>_o
0@00POoDooH0m_oj087oiOom087oPOn1oh7okoon0>goa03[o`40087oe?of0?Ko
nP21onGoo@21oh7oPOn1onoooP3]ol@0jol10021omComP3fooX0POoUood0POn1
oo;o06n1oh7o0Oooo@3]ol@0jOon087of?od0?SonP21onCoo@21oh7oPOn1oo3o
o@3]ol@0jOon087of?od0?SonP21onCoo@21oh7oPOn1oo3oo@3]ol@0jOon087o
f?od0?SonP21onCoo@21oh7ol_l0LX7oPOl1ooom0>goa03Vo`40087of_oc0?[o
nP21on?oo@21oh7oPOn1oo3oo@3]ol@0i_l10021om[ol`3jooX0POoSood0POn1
oh7oPOo`ood0kOo40>Ko0@00POoJoo<0n_oj087ohoom087oPOobo`1UPOn1o`3o
o03/ol<0i_l10021omgol@3loo/0POn1oh7oPOn1olgoo03/ol<0i_l10021omgo
l@3loo/0POn1oh7oPOn1olgoo03/ol<0i_l10021omgol@3loo/0POn1oh7oc_l0
Kh7oPOok0>coa@00ooh0i_l10021omool@3moo/0POn1oh7oPOn1olgon`3/olD0
0?on0>Ko0@00POoOoo40oOok087oPOn1oh7oPOo=oo/0k?o5003ooP3Vo`40087o
gooa0?gon`21oh7oPOo=o`1_POn5ooL0k?o60?gooP3Vo`40087oh_o_003onP21
oh7oPOn1oh7od?og0>coaP3mooh0i_l10021on;ok`00ooX0POn1oh7oPOn1om3o
m`3/olH0oOon0>Ko0@00POoRonl00?oj087oPOn1olco06>1ohSom03[olL0noon
0>Ko0@00POoTonP0POn1oh7oPOn1om;om03[olL0noon0>Ko0@00POoTonP0POn1
oh7oPOn1om;om03[olL0noon0>Ko0@00POoTonP0POn1oh7obol0Hh7oR?od0>_o
a`3iooh0i_l10021onOoj021oh7oPOn1oh7odOod0>_oa`3iooh0i_l10021onOo
j021oh7oPOn1oh7odOod0>_oa`3iooh0i_l10021onOoj021oh7oPOo:o`1SPOn8
oo@0joo80?KooP3Vo`40087ojOoZ087oPOn1oh7oPOo?oo@0joo80?KooP3Vo`40
087ojOoZ087oPOn1oh7oPOo?oo@0joo80?KooP3Vo`40087ojOoZ087oPOn1olSo
06J1oh7o0Oooo@3ZolT0m?on0>Ko0@00POo/onT0POn1oh7oPOn1olKoo@3ZolT0
m?on0>Ko0@00POo/onT0POn1oh7oPOn1olKoo@3ZolT0m?on0>Ko0@00POo/onT0
POn1oh7ob?l0Hh7oPOl1ooom0>Wob`3aood0ioon087okooX087oPOn1oh7oPOo7
ood0jOo;0?7oo@3Wooh0POo_onP0POn1oh7oPOn1olOoo@3Yol/0lOom0>OooP21
onooj021oh7oPOo9o`1VPOn1o`7oood0jOo;0>ooo@3Vo`40087ol_oW087oPOn1
oh7oPOo7ood0jOo;0>ooo@3Vo`40087ol_oW087oPOn1oh7oPOo7ood0jOo;0>oo
o@3Vo`40087ol_oW087oPOn1olWo06J1oh7o0Oooo@3Xold0k?om0>Ko0@00POod
onH0POn1oh7oPOn1olSoo@3Xold0k?om0>Ko0@00POodonH0POn1oh7oPOn1olSo
o@3Xold0k?om0>Ko0@00POodonH0POn1oh7ob_l0IX7oPOl1ooom0>Ooc03/ood0
i_l10021ooOoi021oh7oPOn1oh7obOom0>Ooc03/ood0i_l10021ooOoi021oh7o
POn1oh7obOom0>Ooc03/ood0i_l10021ooOoi021oh7oPOo;o`1VPOn1o`7oood0
i_o;0>_ooP3Vo`40087onOoS087oPOn1oh7oPOo:ood0i_o;0>_ooP3Vo`40087o
nOoS087oPOn1oh7oPOo:ood0i_o;0>_ooP3Vo`40087onOoS087oPOn1olco06J1
oh7o0Oooo@3VolT0joon0>Ko0@00POolon40POn1oh7oPOn1ol_oo@3VolT0joon
0>Ko0@00POolon40POn1oh7oPOn1ol_oo@3VolT0joon0>Ko0@00POolon40POn1
oh7ocOl0MH7oPOl1ooom0>Coe@01ooog0>_ooP3Vo`40087oo_oP087oPOn1oh7o
POo<ood0i?oE007oooL0joon0>Ko0@00POonon00POn1oh7oPOn1olcoo@3TomD0
0Ooom`3[ooh0i_l10021ookoh021oh7oPOo>o`1/POn1o`7oood0i?oF0?com`3[
ooh0i_l10021omh0POn1oh7oPOn1olgoo@3TomH0o?og0>_ooP3Vo`40087ogP21
oh7oPOn1oh7ocOom0>CoeP3looL0joon0>Ko0@00POoN087oPOn1oloo06b1oh7o
0Oooo@3RomT0nOof0>cooP3Vo`4008?ogP21oh7oPOn1oh7ocOom0>;of@3iooH0
k?on0>Ko0@00PooN087oPOn1oh7oPOo=ood0h_oI0?WomP3/ooh0i_l10023omh0
POn1oh7ocol0JH7oPOl1ooom0>7og03eooH0k?om0>OooP27om`0POn1oh7oPOn1
olkoo@3Qom`0mOof0>coo@3Wooh0QooL087oPOn1oh7oPOo>ood0hOoL0?GomP3/
ood0ioon08Oog021oh7oPOo@o`1/POn1o`7oood0h?oN0?;omP3/ood0i_l10029
om/0POn1oh7oPOn1olooo@3Pomh0l_of0>coo@3Vo`4008Wof`21oh7oPOn1oh7o
coom0>3ogP3booH0k?om0>Ko0@00ROoK087oPOn1om7o06b1oh7o0Oooo@3Non00
l?of0>coo@3Vo`4008cof@21oh7oPOn1oh7od?om0=koh03`ooH0k?om0>Ko0@00
S?oI087oPOn1oh7oPOo@ood0g_oP0?3omP3/ood0i_l1002<omT0POn1oh7od_l0
K87oPOl1ooom0=coh03_ooL0k?om0>Ko0@00S_oM087oPOn1oh7oPOo<ood0g?oP
0>oom`3/ood0i_l1002>omd0POn1oh7oPOn1olcoo@3Lon00koog0>coo@3Vo`40
08kog@21oh7oPOo>o`1/POn1o`7oood0f_oP0>oom`3/ood0i_l1002Aon00POn1
oh7oPOn1olSoo@3Jon00koog0>coo@3Vo`40097oh021oh7oPOn1oh7ob?om0=[o
h03_ooL0k?om0>Ko0@00TOoP087oPOn1ol[o06b1oh7o0Oooo@3Eon<0koog0>co
o@3Vo`4009?oh`21oh7oPOn1oh7oaOom0=Goh`3_ooL0k?om0>Ko0@00TooS087o
POn1oh7oPOo5ood0eOoS0>oom`3/ood0i_l1002Con<0POn1oh7oaol0OX7oPOl1
ooom0<SokP3_ooL0joon0>Ko0@00U_oV087o/ol0087ogol0087oPOncood0b?o^
0>oom`3[ooh0i_l1002FonH0POnco`00POoOo`00POn1ok?oo@38onh0koog0>_o
oP3Vo`4009KoiP21ok?o0021omoo002eo`1nPOn1o`7oood0a_o^0>oom`3[ooh0
i_l1002HonX0POnbooX0POoUooX0POn1okKoo@36onh0koog0>_ooP3Vo`4009So
jP21ok;onP21onGonP21oh7o]_om0<KokP3_ooL0joon0>Ko0@00V?oZ087o/_oj
087oiOoj0;So07j1oh7o0Oooo@34onh0koof0>cooP3Vo`4009_ok@21ok3omP21
onWomP21oh7o^?om0<CokP3_ooH0k?on0>Ko0@00Voo]087o/?of087ojOof087o
POnhood0a?o^0>oomP3/ooh0i_l1002Kond0POn`ooH0POoYooH0^_l0Nh7oPOl1
ooom0<7ok`3_ooH0k?om0>OooP2Noo40POn/ooD0POo[ooD0POn1okSoo@31onl0
koof0>coo@3Wooh0W_oa087o[?oe087ojooe087oPOnhood0`Oo_0>oomP3/ood0
ioon09kol@21ojcom@21on_om@2jo`1nPOn1o`7oood0_oo_0>oomP3/ood0i_l1
002Qoo@0POnYoo<0POo]oo<0POn1okWoo@2oonl0koof0>coo@3Vo`400:7om021
ojWol`21ongol`21oh7o^Oom0;ook`3_ooH0k?om0>Ko0@00XOod087oZOoc087o
kOoc0;_o07j1oh7o0Oooo@2monh0l?of0>coo@3Vo`400:?om`21ojOolP21onko
l@21oh7o^_om0;gokP3`ooH0k?om0>Ko0@00Xoog087oYoob087ok_oa087oPOnj
ood0_Oo^0?3omP3/ood0i_l1002SooL0POnWoo80POo^oo40_?l0OX7oPOl1ooom
0;_okP3_ooL0k?om0>Ko0@00Y_oj087oXooa087okoo`087oPOnkood0^oo^0>oo
m`3/ood0i_l1002VooX0POnSoo40POo_oo00POn1ok_oo@2konh0koog0>coo@3V
o`400:KonP21oj?ol@21onool02mo`1nPOn1o`7oood0^Oo^0>oom`3/ood0i_l1
002Xooh0POnPoo00POo_oo00POn1ok_oo@2ionh0koog0>coo@3Vo`400:SooP21
oj3ol021onool021oh7o^oom0;WokP3_ooL0k?om0>Ko0@00Z?on087oX?o`087o
koo`0;go07R1oh7o0Oooo@2gonh0koog0>coo@3Vo`40087oPOo6oo00POo_oo00
POn1ok_oo@2gonh0koog0>coo@3Vo`40087oPOo6oo00POo_oo00POn1ok_oo@2g
onh0koog0>coo@3Vo`40087oPOo6oo00POo_oo00_Ol0Kh7oPOn_onh0koog0>co
o@3Vo`40087oPOo8oo00POo_oo00POn1oh7ojoo^0>oom`3/ood0i_l10021oh7o
b?o`087okoo`087oPOn1on_okP3_ooL0k?om0>Ko0@00POn1olSol021onool02m
o`1_POn1ojgokP3_ooL0joon0>Ko0@00POn1olWol@21onool021oh7oPOoYonh0
koog0>_ooP3Vo`40087oPOo9oo40POo_oo00POn1oh7ojOo^0>oom`3[ooh0i_l1
0021oh7obOoa087okoo`0;go06n1oh7oZoo^0>oomP3/ooh0i_l10021oh7oboob
087ok_oa087oPOn1onKokP3_ooH0k?on0>Ko0@00POn1ol_olP21onkol@21oh7o
POoVonh0koof0>cooP3Vo`40087oPOo;oo80POo^oo40_?l0K87oPOnXonl0koof
0>coo@3Wooh0POn1olkolP21onkol@21oh7oPOoSonl0koof0>coo@3Wooh0POn1
olkolP21onkol@21oh7oPOoSonl0koof0>coo@3Wooh0POn1olkolP21onkol@2l
o`1_POn1ojKok`3_ooH0k?om0>Ko0@00POn1olool`21ongol`21oh7oPOoPonl0
koof0>coo@3Vo`40087oPOo?oo<0POo]oo<0POn1oh7oh?o_0>oomP3/ood0i_l1
0021oh7ocooc087okOoc0;_o06n1oh7oY?o^0?3omP3/ood0i_l10021oh7od?oe
087ojooe087oPOn1omgokP3`ooH0k?om0>Ko0@00POn1om3om@21on_om@21oh7o
POoMonh0l?of0>coo@3Vo`40087oPOo@ooD0POo[ooD0^_l0Kh7oPOnRonh0koog
0>coo@3Vo`40087oPOoAooL0POoXooP0POn1oh7of_o^0>oom`3/ood0i_l10021
oh7odOog087oj?oh087oPOn1om[okP3_ooL0k?om0>Ko0@00POn1om7om`21onSo
n02io`1_POn1oj3okP3_ooL0k?om0>Ko0@00POn1om;onP21onGon`21oh7oPOoF
onh0koog0>coo@3Vo`40087oPOoBooX0POoUoo/0POn1oh7oe_o^0>oom`3/ood0
i_l10021oh7od_oj087oiOok0;Oo07F1oh7oW_o^0>oom`3/ood0i_l10021oh7o
d_om0;3ooP2good0POn1oh7odoo^0>oom`3/ood0i_l10021oh7od_om0;3ooP2g
ood0POn1oh7odoo^0>oom`3/ood0i_l10021oh7od_om0;3ooP2good0]_l0MH7o
POnLonh0koog0>coo@3Vo`40087oPOoDood0/?ol0;Woo@21oh7oPOoAonh0koog
0>coo@3Vo`40087oPOoDood0/?ol0;Woo@21oh7oPOoAonh0koog0>coo@3Vo`40
087oPOoDood0/?ol0;Woo@2fo`1ePOn1oi[okP3_ooL0k?om0>Ko0@00POn1omKo
o@2`ooT0_?om087oPOn1olookP3_ooL0k?om0>Ko0@00POn1omKoo@2`ooT0_?om
087oPOn1olookP3_ooL0k?om0>Ko0@00POn1omKoo@2`ooT0_?om0;Ko07F1oh7o
V?o^0>oomP3/ooh0i_l10021oh7of?om0;3omP2oood0POn1oh7ocOo^0>oomP3/
ooh0i_l10021oh7of?om0;3omP2oood0POn1oh7ocOo^0>oomP3/ooh0i_l10021
oh7of?om0;3omP2oood0]_l0LX7oPOnEonl0koof0>coo@3Wooh0POn1om_oo@2`
oo<0`_om087oPOn1ol[ok`3_ooH0k?om0>OooP21oh7ofoom0;3ol`32ood0POn1
oh7ob_o_0>oomP3/ood0ioon087oPOoKood0/?oc0<;oo@2fo`1ePOn1oi?ok`3_
ooH0k?om0>Ko0@00POn1omgoo@2`oo40a?om087oPOn1olSok`3_ooH0k?om0>Ko
0@00POn1omgoo@2`oo40a?om087oPOn1olSok`3_ooH0k?om0>Ko0@00POn1omgo
o@2`oo40a?om0;Ko07F1oh7oTOo^0?3omP3/ood0i_l10021oh7ogoom0;3okP37
ood0POn1oh7oa_o^0?3omP3/ood0i_l10021oh7ogoom0;3okP37ood0POn1oh7o
a_o^0?3omP3/ood0i_l10021oh7ogoom0;3okP37ood0]_l0MH7oPOn?onh0koog
0>coo@3Vo`40087oPOoQood0/?o[0<[oo@21oh7oPOo4onh0koog0>coo@3Vo`40
087oPOoQood0/?o[0<[oo@21oh7oPOo4onh0koog0>coo@3Vo`40087oPOoQood0
/?o[0<[oo@2fo`1ePOn1ohgokP3_ooL0k?om0>Ko0@00POn1on?oo@2`onT0c?om
087oPOn1ol;okP3_ooL0k?om0>Ko0@00POn1on?oo@2`onT0c?om087oPOn1ol;o
kP3_ooL0k?om0>Ko0@00POn1on?oo@2`onT0c?om0;Ko07F1oh7oRoo^0>oom`3/
ood0i_l10021oh7oiooj0;7oiP3?ood0POn1oh7o`?o^0>oom`3/ood0i_l10021
oh7oiooj0;7oiP3?ood0POn1oh7o`?o^0>oom`3/ood0i_l10021oh7oiooj0;7o
iP3?ood0]_l0MH7oPOn9onh0koog0>coo@3Vo`40087oPOo[ooH0/ooS0=;oo@21
oh7oPOnnonh0koog0>coo@3Vo`40087oPOo[ooH0/ooS0=;oo@21oh7oPOnnonh0
koog0>coo@3Vo`40087oPOo[ooH0/ooS0=;oo@2fo`1ePOn1ohOokP3_ooL0k?om
0>Ko0@00POn1ongom@2don00eOom087oPOn1okcokP3_ooL0k?om0>Ko0@00POn1
ongom@2don00eOom087oPOn1okcokP3_ooL0k?om0>Ko0@00POn1ongom@2don00
eOom0;Ko07F1oh7oQOo^0>oomP3]ood0i_l10021oh7ol?oc0;GogP3Good0POn1
oh7o^_o^0>oomP3]ood0i_l10021oh7ol?oc0;GogP3Good0POn1oh7o^_o^0>oo
mP3]ood0i_l10021oh7ol?oc0;GogP3Good0]_l0MH7oPOn2onl0koof0>goo03W
o`40087oPOocoo80]OoK0=[oo@21oh7oPOngonl0koof0>goo03Wo`40087oPOoc
oo80]OoK0=[oo@21oh7oPOngonl0koof0>goo03Wo`40087oPOocoo80]OoK0=[o
o@2fo`1dPOn1oh7o0?o_0>oomP3/ood0ioon087oPOofoo40i?nZ0=goo@21oh7o
POneonl0koof0>coo@3Wooh0POn1ooKol@3TojX0gOom087oPOn1okGok`3_ooH0
k?om0>OooP21oh7om_oa0>CoZP3Mood0]_l0Mh7oPOn1ookokP3`ooH0k?om0>Ko
0@00POn1ooWol03TojP0goom087oPOn1ok?okP3`ooH0k?om0>Ko0@00POn1ooWo
l03TojP0goom087oPOn1ok?okP3`ooH0k?om0>Ko0@00POn1ooWol03TojP0goom
0;Ko07N1oh7oPOolonh0koog0>coo@3Vo`40087oPOokoo00i?nU0>;oo@21oh7o
POnaonh0koog0>coo@3Vo`40087oPOokoo00i?nU0>;oo@21oh7oPOnaonh0koog
0>coo@3Vo`40087oPOokoo00i?nU0>;oo@2fo`1gPOn1oh7on_o^0>oom`3/ood0
i_l10021oh7ooOo`0>CoZ03Oood0POn1oh7o[oo^0>oom`3/ood0i_l10021oh7o
oOo`0>CoZ03Oood0POn1oh7o[oo^0>oom`3/ood0i_l10021oh7ooOo`0>CoZ03O
ood0]_l0Mh7oPOn1ooSokP3_ooL0k?om0>Ko0@00POn1ookol@2fomP0gOom087o
POn1ojgokP3_ooL0k?om0>Ko0@00POn1ookol@2fomP0gOom087oPOn1ojgokP3_
ooL0k?om0>Ko0@00POn1ookol@2fomP0gOom0;Ko07N1oh7oPOofonh0koog0>co
o@3Vo`40087oPOl0oo80]OoK0=[oo@21oh7oPOn[onh0koog0>coo@3Vo`40087o
POl0oo80]OoK0=[oo@21oh7oPOn[onh0koog0>coo@3Vo`40087oPOl0oo80]OoK
0=[oo@2fo`1aPOn1oh7om?o^0>oom`3/ood0i_l10021oh;olP2eomh0eoom087o
POn1ojWokP3_ooL0k?om0>Ko0@00POn2oo80]OoN0=Ooo@21oh7oPOnYonh0koog
0>coo@3Vo`40087oP_ob0;GogP3Good0]_l0LH7oPOn1oo;okP3_ooH0kOom0>Ko
0@00POn3oo<0]OoQ0=Coo@21oh7oPOnWonh0koof0>goo@3Vo`40087oPooc0;Go
h@3Dood0POn1oh7oYoo^0>oomP3]ood0i_l10021oh?ol`2eon40e?om0;Ko0761
oh7oPOo_onl0koof0>goo03Wo`40087oQ?oe0;Coh`3Bood0POn1oh7oY?o_0>oo
mP3]oo`0iol10021ohCom@2don<0d_om087oPOn1ojCok`3_ooH0kOol0>Oo0@00
POn4ooD0]?oS0=;oo@2fo`1^POn1oh7okOo_0>oomP3]oo`0ioon087oQ_og0;?o
iP3?ood0POn1oh7oX_o_0>oomP3]oo`0ioon087oQ_og0;?oiP3?ood0POn1oh7o
X_o_0>oomP3]oo`0ioon087oQ_og0;?oiP3?ood0]_l0LH7oPOn1on_okP3`ooH0
k?om0>Ko0@00POn7ooX0/OoY0<coo@21oh7oPOnPonh0l?of0>coo@3Vo`40087o
Qooj0;7oj@3<ood0POn1oh7oX?o^0?3omP3/ood0i_l10021ohOonP2aonT0c?om
0;Ko0761oh7oPOoYonh0koog0>coo@3Vo`40087oQoom0;3oj`3:ood0POn1oh7o
W_o^0>oom`3/ood0i_l10021ohOoo@2`on/0b_om087oPOn1oikokP3_ooL0k?om
0>Ko0@00POn7ood0/?o[0<[oo@2fo`1aPOn1oh7oioo^0>oom`3/ood0i_l10021
ohWoo@2`onh0aoom087oPOn1oicokP3_ooL0k?om0>Ko0@00POn9ood0/?o^0<Oo
o@21oh7oPOnLonh0koog0>coo@3Vo`40087oROom0;3okP37ood0]_l0LH7oPOn1
onGokP3_ooL0k?om0>Ko0@00POn;ood0/?oa0<Coo@21oh7oPOnJonh0koog0>co
o@3Vo`40087oRoom0;3ol@34ood0POn1oh7oV_o^0>oom`3/ood0i_l10021oh_o
o@2`oo40a?om0;Ko0761oh7oPOoSonh0koog0>coo@3Vo`40087oSOom0;3ol`33
oo/0POn1oh7oVOo^0>oom`3/ood0i_l10021ohgoo@2`oo<0`ook087oPOn1oiWo
kP3_ooL0k?om0>Ko0@00POn=ood0/?oc0<?on`2go`1aPOn1oh7ohOo^0>oom`3/
ood0i_l10021ohooo@2`ooH0`?oj087oPOn1oiSokP3_ooL0k?om0>Ko0@00POn?
ood0/?of0<3onP21oh7oPOnHonh0koog0>coo@3Vo`40087oSoom0;3omP30ooX0
^?l0LH7oPOn1omookP3_ooH0kOom0>Ko0@00POnAood0/?oi0<3om@21oh7oPOnH
onh0koof0>goo@3Vo`40087oTOom0;3on@30ooD0POn1oh7oV?o^0>oomP3]ood0
i_l10021oi7oo@2`ooT0`?oe0;[o0761oh7oPOoLonl0koof0>goo@3Vo`40087o
Toom0;3oo02noo<0POn1oh7oU_o_0>oomP3]ood0i_l10021oi?oo@2`oo`0__oc
087oPOn1oiKok`3_ooH0kOom0>Ko0@00POnCood0/?ol0;kol`2ko`1^POn1oh7o
f_o_0>oomP3]oo`0ioon087oU_om0;3ooP2loo80POn1oh7oUOo_0>oomP3]oo`0
ioon087oU_om0;3ooP2loo80POn1oh7oUOo_0>oomP3]oo`0ioon087oU_om0;3o
oP2loo80_?l0Jh7oPOn1omSokP3`ooH0kOol0>Ko0@00POnHood0POoYoo40POn1
oh7oToo^0?3omP3]oo`0i_l10021oiSoo@21onWol@21oh7oPOnConh0l?of0>go
o03Vo`40087oV?om087ojOoa0;co06^1oh7oPOoFonh0koog0>coo@3Vo`40087o
W?oj087oj_o`087oPOn1oi;okP3_ooL0k?om0>Ko0@00POnLooX0POoZoo00POn1
oh7oT_o^0>oom`3/ood0i_l10021oiconP21on[ol02mo`1[POn1oh7oe?o^0>oo
m`3/ood0i_l10021oj3omP21oncol021oh7oPOn@onh0koog0>coo@3Vo`40087o
X?of087ok?o`087oPOn1oi3okP3_ooL0k?om0>Ko0@00POnPooH0POo/oo00_Ol0
Jh7oPOn1om;okP3_ooL0k?om0>Ko0@00POnRooD0POo]oo00POn1oh7oS_o^0>oo
m`3/ood0i_l10021oj;om@21ongol021oh7oPOn>onh0koog0>coo@3Vo`40087o
X_oe087okOo`0;go06^1oh7oPOo@onh0koog0>coo@3Vo`40087oYOoc087ok_o`
087oPOn1ohcokP3_ooL0k?om0>Ko0@00POnUoo<0POo^oo00POn1oh7oS?o^0>oo
m`3/ood0i_l10021ojGol`21onkol02mo`1[POn1oh7oc_o^0>oom`3/ood0i_l1
0021ojSolP21onkol@21oh7oPOn9onh0koog0>coo@3Vo`40087oZ?ob087ok_oa
087oPOn1ohWokP3_ooL0k?om0>Ko0@00POnXoo80POo^oo40_?l0Jh7oPOn1olco
kP3_ooL0k?om0>Ko0@00POnZoo40POo_oo40POn1oh7oQoo^0>oom`3/ood0i_l1
0021oj[ol@21onool@21oh7oPOn7onh0koog0>coo@3Vo`40087oZ_oa087okooa
0;co06^1oh7oPOo9onl0koof0>goo@3Vo`40087o[Oo`087ok_ob087oPOn1ohCo
k`3_ooH0kOom0>Ko0@00POn]oo00POo^oo80POn1oh7oQ?o_0>oomP3]ood0i_l1
0021ojgol021onkolP2lo`1XPOn1oh7oaoo_0>oomP3]oo`0ioon087o/?o`087o
kOod087oPOn1oh7ok`3_ooH0kOol0>OooP21ok3ol021ongom021oh7oPOn1onl0
koof0>goo03Wooh0POn`oo00POo]oo@0^ol0Kh7oPOn1olGokP3`ooH0kOol0>Ko
0@00POnboo00POo]ooD0POn1oh7oPOononh0l?of0>goo03Vo`40087o/_o`087o
kOoe087oPOn1oh7oo_o^0?3omP3]oo`0i_l10021ok;ol021ongom@2jo`1_POn1
oh7o`oo^0?3omP3]oo`0i_l10021ok?ol@21on_on021oh7oPOn1oo_okP3`ooH0
kOol0>Ko0@00POncoo40POo[ooP0POn1oh7oPOokonh0l?of0>goo03Vo`40087o
/ooa087ojooh0;Wo06n1oh7oPOo1onh0koog0>goo03Vo`40087o]Oob087ojOok
087oPOn1oh7omoo^0>oom`3]oo`0i_l10021okGolP21onWon`21oh7oPOn1ooOo
kP3_ooL0kOol0>Ko0@00POneoo80POoYoo/0]ol0Hh7oPOn1okookP3_ooL0k?om
0>Ko0@00POngoo80POn1oh7oPOn1omOokP3_ooL0k?om0>Ko0@00POngoo80POn1
oh7oPOn1omOokP3_ooL0k?om0>Ko0@00POngoo80POnIo`1SPOn1oh7o_Oo^0>oo
m`3/ood0i_l10021okSol`21oh7oPOn1oh7oeOo^0>oom`3/ood0i_l10021okSo
l`21oh7oPOn1oh7oeOo^0>oom`3/ood0i_l10021okSol`21oiWo06>1oh7oPOnk
onh0koog0>coo@3Vo`40087o^Ooe087oPOn1oh7oPOoBonh0koog0>coo@3Vo`40
087o^Ooe087oPOn1oh7oPOoBonh0koog0>coo@3Vo`40087o^Ooe087oV?l0Hh7o
POn1okWokP3_ooL0k?om0>Ko0@00POnjooL0POn1oh7oPOn1olookP3_ooL0k?om
0>Ko0@00POnjooL0POn1oh7oPOn1olookP3_ooL0k?om0>Ko0@00POnjooL0POnG
o`1SPOn1oh7o]_o_0>oomP3]ood0i_l10021ok_onP21oh7oPOn1oh7ob_o_0>oo
mP3]ood0i_l10021ok_onP21oh7oPOn1oh7ob_o_0>oomP3]ood0i_l10021ok_o
nP21oiGo05Z1oh7oPOndonl0koof0>goo03Wooh0POn1oh7oPOn1oh7oPOononl0
koof0>goo03Wooh0POn1oh7oPOn1oh7oPOononl0koof0>goo03Wooh0POn1oh7o
bol0GH7oPOn1ok;ok`3_ooH0kOol0>Ko0@00POn1oh7oPOn1oh7oPOononl0koof
0>goo03Vo`40087oPOn1oh7oPOn1oh7oo_o_0>oomP3]oo`0i_l10021oh7oPOo=
o`1MPOn1oh7o/?o^0?3omP3]oo`0i_l10021oh7oPOn1oh7oPOn1ookokP3`ooH0
kOol0>Ko0@00POn1oh7oPOn1oh7oPOononh0l?of0>goo03Vo`40087oPOn1oloo
05f1oh7oPOn^onh0koog0>goo03Vo`40087oPOn1oh7oPOn1oh7oo_o^0>oom`3]
oo`0i_l10021oh7oPOn1oh7oPOn1ookokP3_ooL0kOol0>Ko0@00POn1oh7odOl0
GH7oPOn1ojcokP3_ooL0kOol0>Ko0@00POn1oh7oPOn1oh7oPOononh0koog0>go
o03Vo`40087oPOn1oh7oPOn1oh7oo_o^0>oom`3]oo`0i_l10021oh7oPOoCo`1M
POn1oh7oZ_o^0>oom`3/ood0i_l10021oh7oPOn1oh7oPOn1ookokP3_ooL0k?om
0>Ko0@00POn1oh7oPOn1oh7oPOononh0koog0>coo@3Vo`40087oPOn1omGo05f1
oh7oPOnXonh0koog0>coo@3Vo`40087oPOn1oh7oPOn1oh7oo_o^0>oom`3/ood0
i_l10021oh7oPOn1oh7oPOn1ookokP3_ooL0k?om0>Ko0@00POn1oh7oeol0GH7o
POn1ojKokP3_ooL0k?om0>Ko0@00POn1oh7oPOn1oh7oPOononh0koog0>coo@3V
o`40087oPOn1oh7oPOn1oh7oo_o^0>oom`3/ood0i_l10021oh7oPOoIo`1MPOn1
oh7oY?o^0>oomP3]ood0i_l10021oh7oPOn1oh7oPOn1ookokP3_ooH0kOom0>Ko
0@00POn1oh7oPOn1oh7oPOononh0koof0>goo@3Vo`40087oPOn1om_o05Z1oh7o
POnQonl0koof0>goo03Wooh0POn1oh7oPOn1oh7oPOononl0koof0>goo03Wooh0
POn1oh7oPOn1oh7oPOononl0koof0>goo03Wooh0POn1oh7og_l0GH7oPOn1oioo
k`3_ooH0kOol0>Ko0@00POn1oh7oPOn1oh7oPOononl0koof0>goo03Vo`40087o
POn1oh7oPOn1oh7oo_o_0>oomP3]oo`0i_l10021oh7oPOoPo`1MPOn1oh7oWOo^
0?3omP3]oo`0i_l10021oh7oPOn1oh7oPOn1ookokP3`ooH0kOol0>Ko0@00POn1
oh7oPOn1oh7oPOononh0l?of0>goo03Vo`40087oPOn1on;o05f1oh7oPOnKonh0
koog0>goo03Vo`40087oPOn1oh7oPOn1oh7oo_o^0>oom`3]oo`0i_l10021oh7o
POn1oh7oPOn1ookokP3_ooL0kOol0>Ko0@00POn1oh7oi?l0GH7oPOn1oiWokP3_
ooL0kOol0>Ko0@00POn1oh7oPOn1oh7oPOononh0koog0>goo03Vo`40087oPOn1
oh7oPOn1oh7oo_o^0>oom`3]oo`0i_l10021oh7oPOoVo`1MPOn1oh7oUoo^0>oo
m`3]oo`0i_l10021oh7oPOn1oh7oPOn1ookokP3_ooL0kOol0>Ko0@00POn1oh7o
POn1oh7oPOononh0koog0>goo03Vo`40087oPOn1onSo05f1oh7oPOnEonh0koog
0>coo@3Vo`40087oPOn1oh7oPOn1oh7oo_o^0>oom`3/ood0i_l10021oh7oPOn1
oh7oPOn1ookokP3_ooL0k?om0>Ko0@00POn1oh7oj_l0GH7oPOn1oi?okP3_ooL0
k?om0>Ko0@00POn1oh7oPOn1oh7oPOononh0koog0>coo@3Vo`40087oPOn1oh7o
POn1oh7oo_o^0>oom`3/ood0i_l10021oh7oPOo/o`1MPOn1oh7oTOo^0>oomP3]
ood0i_l10021oh7oPOn1oh7oPOn1ookokP3_ooH0kOom0>Ko0@00POn1oh7oPOn1
oh7oPOononh0koof0>goo@3Vo`40087oPOn1onko05Z1oh7oPOn>onl0koof0>go
o03Wooh0POn1oh7oPOn1oh7oPOononl0koof0>goo03Wooh0POn1oh7oPOn1oh7o
POononl0koof0>goo03Wooh0POn1oh7olOl0GH7oPOn1ohcok`3_ooH0kOol0>Ko
0@00POn1oh7oPOn1oh7oPOononl0koof0>goo03Vo`40087oPOn1oh7oPOn1oh7o
o_o_0>oomP3]oo`0i_l10021oh7oPOoco`1MPOn1oh7oR_o^0?3omP3]oo`0i_l1
0021oh7oPOn1oh7oPOn1ookokP3`ooH0kOol0>Ko0@00POn1oh7oPOn1oh7oPOon
onh0l?of0>goo03Vo`40087oPOn1ooGo05f1oh7oPOn8onh0koog0>goo03Vo`40
087oPOn1oh7oPOn1oh7oo_o^0>oom`3]oo`0i_l10021oh7oPOn1oh7oPOn1ooko
kP3_ooL0kOol0>Ko0@00POn1oh7omol0GH7oPOn1ohKokP3_ooL0kOol0>Ko0@00
POn1oh7oPOn1oh7oPOononh0koog0>goo03Vo`40087oPOn1oh7oPOn1oh7oo_o^
0>oom`3]oo`0i_l10021oh7oPOoio`1MPOn1oh7oQ?o^0>oom`3]oo`0i_l10021
oh7oPOn1oh7oPOn1ookokP3_ooL0kOol0>Ko0@00POn1oh7oPOn1oh7oPOononh0
koog0>goo03Vo`40087oPOn1oo_o05f1oh7oPOn2onh0koog0>goo03Vo`40087o
POn1oh7oPOn1oh7oo_o^0>oom`3]oo`0i_l10021oh7oPOn1oh7oPOn1ookokP3_
ooL0kOol0>Ko0@00POn1oh7ooOl0IH7oPOn1oh7o0?o^0>oom`3]oo`0i_l1003l
oo@0POn1oh7oPOn1oh7oT?o^0>oom`3]oo`0i_l1003loo@0POn1oh7oPOn1oh7o
T?o^0>oom`3]oo`0i_l1003loo@0POn1oi7o05J1oh7oPOn1ookokP3_ooH0kOom
0>Kok021oh7oPOn1oh7oPOnAonh0koof0>goo@3Von`0POn1oh7oPOn1oh7oTOo^
0>oomP3]ood0i_o/087oPOnDo`1FPOn1oh7oPOokonl0koof0>goo03ZonP0POn1
oh7oPOn1oh7oTOo_0>oomP3]oo`0j_oX087oPOn1oh7oPOn1oi7ok`3_ooH0kOol
0>[oj021oh7oUol0EX7oPOn1oh7onOo_0>oomP3]oo`0k_oT087oPOn1oh7oPOn1
oi7ok`3_ooH0kOol0>koi021oh7oPOn1oh7oPOnAonl0koof0>goo03^on@0POn1
oiWo05J1oh7oPOn1ooOokP3`ooH0kOol0?7ohP21oh7oPOn1oh7oPOn@onh0l?of
0>goo03aon80POn1oh7oPOn1oh7oT?o^0?3omP3]oo`0lOoR087oPOnJo`1FPOn1
oh7oPOoeonh0koog0>goo03eomh0POn1oh7oPOn1oh7oT?o^0>oom`3]oo`0mOoN
087oPOn1oh7oPOn1oi3okP3_ooL0kOol0?GogP21oh7oW?l0EX7oPOn1oh7oloo^
0>oom`3]oo`0nOoJ087oPOn1oh7oPOn1oi3okP3_ooL0kOol0?WofP21oh7oPOn1
oh7oPOn@onh0koog0>goo03iomX0POn1oiko05J1oh7oPOn1oo7okP3_ooL0kOol
0?cof021oh7oPOn1oh7oPOn?onh0koog0>goo03lomP0POn1oh7oPOn1oh7oSoo^
0>oom`3]oo`0o?oH087oPOnOo`1FPOn1oh7oPOo_onh0koog0>goo000omD0POn1
oh7oPOn1oh7oS_o^0>oom`3]oo`00?oE087oPOn1oh7oPOn1ohkokP3_ooL0kOol
003oe@21oh7oX?l0BX7oPOn1oh7okOo^0>oom`3]om00POn1oh7oPOn1oh7oSOo^
0>oom`3]om00POn1oh7oPOn1oh7oSOo^0>oom`3]om00POn1oj7o04Z1oh7oPOn1
on_okP3_ooH0k_oA087oPOn1oh7oPOn1ohcokP3_ooH0k_oA087oPOn1oh7oPOn1
ohcokP3_ooH0k_oA087oPOnRo`1:POn1oh7oPOoXonl0koof0?3od021oh7oPOn1
oh7oPOn:onl0koof0?3od021oh7oPOn1oh7oPOn:onl0koof0?3od021oh7oXol0
BX7oPOn1oh7oi_o_0>oomP3colh0POn1oh7oPOn1oh7oROo_0>oomP3colh0POn1
oh7oPOn1oh7oROo_0>oomP3colh0POn1ojCo04Z1oh7oPOn1onCokP3`ooH0m_o=
087oPOn1oh7oPOn1ohOokP3`ooH0m_o=087oPOn1oh7oPOn1ohOokP3`ooH0m_o=
087oPOnTo`1:POn1oh7oPOoRonh0koog0?Wob`21oh7oPOn1oh7oPOn6onh0koog
0?Wob`21oh7oPOn1oh7oPOn6onh0koog0?Wob`21oh7oYOl0BX7oPOn1oh7oh?o^
0>oom`3kolX0POn1oh7oPOn1oh7oQOo^0>oom`3kolX0POn1oh7oPOn1oh7oQOo^
0>oom`3kolX0POn1ojKo04Z1oh7oPOn1omkokP3_ooL0o_o9087oPOn1oh7oPOn1
oh?okP3_ooL0o_o9087oPOn1oh7oPOn1oh?okP3_ooL0o_o9087oPOnVo`1:POn1
oh7oPOoLonh0koog003ob021oh7oPOn1oh7oPOn2onh0koog003ob021oh7oPOn1
oh7oPOn2onh0koog003ob021oh7oYol0@X7oPOn1oh7of_o^0>oo_`21oh7oPOn1
oh7oPOn1o`3okP3_okl0POn1oh7oPOn1oh7oPOl0onh0kono087oPOnWo`14POn1
oh7oPOoHonh0koo0087oPOn1oh7oPOn1oh7o0OookP3_ol00POn1oh7oPOn1oh7o
POl1ooo^0>oo`021oh7oZ?l0@X7oPOn1oh7oeOo_0>oo`P21oh7oPOn1oh7oPOn1
oocok`3_ol80POn1oh7oPOn1oh7oPOolonl0koo2087oPOnXo`12POn1oh7oPOoC
onl0koo4087oPOn1oh7oPOn1oh7on_o_0>ooa021oh7oPOn1oh7oPOn1oo[ok`3_
ol@0POn1ojSo04:1oh7oPOn1om7okP3aol@0POn1oh7oPOn1oh7oPOoionh0lOo4
087oPOn1oh7oPOn1oh7onOo^0?7oa021oh7oZOl0@X7oPOn1oh7ocoo^0??oa021
oh7oPOn1oh7oPOn1ooOokP3col@0POn1oh7oPOn1oh7oPOogonh0loo4087oPOnY
o`12POn1oh7oPOo=onh0mOo4087oPOn1oh7oPOn1oh7omOo^0?Goa021oh7oPOn1
oh7oPOn1ooGokP3eol@0POn1ojWo04:1oh7oPOn1ol_okP3gol@0POn1oh7oPOn1
oh7oPOoconh0moo4087oPOn1oh7oPOn1oh7oloo^0?Ooa021oh7oZOl0@X7oPOn1
oh7obOo^0?[o`P21oh7oPOn1oh7oPOn1oo;okP3jol80POn1oh7oPOn1oh7oPOob
onh0n_o2087oPOnZo`12POn1oh7oPOo7onh0o?o2087oPOn1oh7oPOn1oh7ol?o^
0?co`P21oh7oPOn1oh7oPOn1oo3okP3lol80POn1oj[o04:1oh7oPOn1olGokP3n
ol80POn1oh7oPOn1oh7oPOo^onh0o_o2087oPOn1oh7oPOn1oh7ok_o^0?ko`P21
oh7oZ_l0@X7oPOn1oh7o`_o_003o`P21oh7oPOn1oh7oPOn1on_ok`00ol80POn1
oh7oPOn1oh7oPOo[onl00?o2087oPOnZo`0fPOn1oh7oPOo0ok40POn1oh7oPOn1
oh7oPOoYok40POn1oh7oPOn1oh7oPOoYok40POn1oj[o03J1oh7oPOn1okko/`21
oh7oPOn1oh7oPOn1onOo/`21oh7oPOn1oh7oPOn1onOo/`21oh7oZ_l0=X7oPOn1
oh7o_?ne087oPOn1oh7oPOn1oh7oiOne087oPOn1oh7oPOn1oh7oiOne087oPOnZ
o`0fPOn1oh7oPOnjokP0POn1oh7oPOn1oh7oPOoRokP0POn1oh7oPOn1oh7oPOoR
okP0POn1ojWo03J1oh7oPOn1okSo^P21oh7oPOn1oh7oPOn1on3o^P21oh7oPOn1
oh7oPOn1on3o^P21oh7oZOl0=X7oPOn1oh7o]_nl087oPOn1oh7oPOn1oh7og_nl
087oPOn1oh7oPOn1oh7og_nl087oPOnYo`0fPOn1oh7oPOndokh0POn1oh7oPOn1
oh7oPOoLokh0POn1oh7oPOn1oh7oPOoLokh0POn1ojWo03J1oh7oPOn1ok;o`@21
oh7oPOn1oh7oPOn1omWo`@21oh7oPOn1oh7oPOn1omWo`@21oh7oZ?l0=X7oPOn1
oh7o[oo4087oPOn1oh7oPOn1oh7oe_o4087oPOn1oh7oPOn1oh7oe_o4087oPOnX
o`0fPOn1oh7oPOn]olL0POn1oh7oPOn1oh7oPOoColL0POn1oh7oPOn1oh7oPOoC
olL0POn1ojOo03J1oh7oPOn1ojgoa`21oh7oPOn1oh7oPOn1om?oa`21oh7oPOn1
oh7oPOn1om?oa`21oh7oYol0=X7oPOn1oh7o[?o8087oPOn1oh7oPOn1oh7od_o8
087oPOn1oh7oPOn1oh7od_o8087oPOnWo`0fPOn1oh7oPOn/olT0POn1oh7oPOn1
oh7oPOoAolT0POn1oh7oPOn1oh7oPOoAolT0POn1ojKo03J1oh7oPOn1oj_obP21
oh7oPOn1oh7oPOn1om3obP21oh7oPOn1oh7oPOn1om3obP21oh7oY_l0=X7oPOn1
oh7oZ_o<087oPOn1oh7oPOn1oh7oc_o<087oPOn1oh7oPOn1oh7oc_o<087oPOnU
o`0fPOn1oh7oPOnZold0POn1oh7oPOn1oh7oPOo=old0POn1oh7oPOn1oh7oPOo=
old0POn1ojCo03J1oh7oPOn1ojWoc`21oh7oPOn1oh7oPOn1ol_oc`21oh7oPOn1
oh7oPOn1ol_oc`21oh7oXol0=X7oPOn1oh7oZ?o@087oPOn1oh7oPOn1oh7ob_o@
087oPOn1oh7oPOn1oh7ob_o@087oPOnSo`0fPOn1oh7oPOnWom80POn1oh7oPOn1
oh7oPOo8om80POn1oh7oPOn1oh7oPOo8om80POn1oj;o03J1oh7oPOn1ojKoe@21
oh7oPOn1oh7oPOn1olGoe@21oh7oPOn1oh7oPOn1olGoe@21oh7oX?l0=X7oPOn1
oh7oYOoF087oPOn1oh7oPOn1oh7oa?oF087oPOn1oh7oPOn1oh7oa?oF087oPOnP
o`0fPOn1oh7oPOnSomT0POn1oh7oPOn1oh7oPOo1omT0POn1oh7oPOn1oh7oPOo1
omT0POn1oioo03J1oh7oPOn1oj;og021oh7oPOn1oh7oPOn1okkog021oh7oPOn1
oh7oPOn1okkog021oh7oWOl0=X7oPOn1oh7oXOoN087oPOn1oh7oPOn1oh7o_?oN
087oPOn1oh7oPOn1oh7o_?oN087oPOnLo`0fPOn1oh7oPOnOon80POn1oh7oPOn1
oh7oPOnhon80POn1oh7oPOn1oh7oPOnhon80POn1oi[o03J1oh7oPOn1oigoiP21
oh7oPOn1oh7oPOn1okCoiP21oh7oPOn1oh7oPOn1okCoiP21oh7oV?l0=X7oPOn1
oh7oW?oY087oPOn1oh7oPOn1oh7o/OoY087oPOn1oh7oPOn1oh7o/OoY087oPOnF
o`0fPOn1oh7oPOnFoo@0POn1oh7oPOn1oh7oPOnVoo@0POn1oh7oPOn1oh7oPOnV
oo@0POn1oi7o0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7obOl0>87oPOn1oh7oPOobooT0POn1oh7oPOn1oh7oPOnQ
ooT0POn1oh7oPOn1oh7oPOnQooT0POn1ok3o03R1oh7oPOn1oh7omOod087oPOn1
oh7oPOn1oh7oY_od087oPOn1oh7oPOn1oh7oY_od087oPOnbo`0hPOn1oh7oPOn1
ooKol@21oh7oPOn1oh7oPOn1ojWol@21oh7oPOn1oh7oPOn1ojWol@21oh7o]?l0
>87oPOn1oh7oPOogoo00POn1oh7oPOn1oh7oPOnZoo00POn1oh7oPOn1oh7oPOnZ
oo00POn1okCo04B1oh7oPOn1oh7on?ok0?[on`21oh7oPOn1oh7oPOn1ojcon`3j
oo/0POn1oh7oPOn1oh7oPOn/oo/0n_ok087oPOneo`14POn1oh7oPOn1ooWon`3g
oo`0POn1oh7oPOn1oh7oPOn^oo/0mool087oPOn1oh7oPOn1oh7o[_ok0?Ooo021
oh7o]_l0A87oPOn1oh7oPOoioo`0mOom087oPOn1oh7oPOn1oh7o[_ol0?Goo@21
oh7oPOn1oh7oPOn1ojkoo03eood0POn1okKo04B1oh7oPOn1oh7onOom0?Coo021
oh7oPOn1oh7oPOn1ojooo@3doo`0POn1oh7oPOn1oh7oPOn_ood0m?ol087oPOng
o`14POn1oh7oPOn1oo[oo03cood0POn1oh7oPOn1oh7oPOn`oo`0loom087oPOn1
oh7oPOn1oh7o/?ol0??oo@21oh7o]ol0A87oPOn1oh7oPOojood0l_om087oPOn1
oh7oPOn1oh7o/?om0?;oo@21oh7oPOn1oh7oPOn1ok3oo@3bood0POn1okOo04B1
oh7oPOn1oh7on_om0?;oo@21oh7oPOn1oh7oPOn1ok3oo@3bood0POn1oh7oPOn1
oh7oPOn`ood0l_om087oPOngo`14POn1oh7oPOn1oo[oo@3bood0POn1oh7oPOn1
oh7oPOn`ood0l_om087oPOn1oh7oPOn1oh7o/?om0?;oo@21oh7o]ol0>87oPOn1
oh7oPOoWood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnMood0POn1
okOo03R1oh7oPOn1oh7oj?ol087oPOn1oh7oPOn1oh7oW_ol087oPOn1oh7oPOn1
oh7oW_ol087oPOngo`0hPOn1oh7oPOn1onWoo021oh7oPOn1oh7oPOn1oikoo021
oh7oPOn1oh7oPOn1oikoo021oh7o]_l0>87oPOn1oh7oPOoZoo/0POn1oh7oPOn1
oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1okKo03R1oh7oPOn1oh7ojook
087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOneo`0hPOn1
oh7oPOn1ongonP21oh7oPOn1oh7oPOn1oj3onP21oh7oPOn1oh7oPOn1oj3onP21
oh7o]?l0>87oPOn1oh7oPOo_ooT0POn1oh7oPOn1oh7oPOnQooT0POn1oh7oPOn1
oh7oPOnQooT0POn1ok?o03R1oh7oPOn1oh7ol?oi087oPOn1oh7oPOn1oh7oXOoi
087oPOn1oh7oPOn1oh7oXOoi087oPOnbo`0hPOn1oh7oPOn1oo;on@21oh7oPOn1
oh7oPOn1oj7on@21oh7oPOn1oh7oPOn1oj7on@21oh7o/?l0>87oPOn1oh7oPOod
ooP0POn1oh7oPOn1oh7oPOnRooP0POn1oh7oPOn1oh7oPOnRooP0POn1ojoo03R1
oh7oPOn1oh7omOoi087oPOn1oh7oPOn1oh7oXOoi087oPOn1oh7oPOn1oh7oXOoi
087oPOn]o`0hPOn1oh7oPOn1ooKonP21oh7oPOn1oh7oPOn1oj3onP21oh7oPOn1
oh7oPOn1oj3onP21oh7oZol0>87oPOn1oh7oPOogoo/0POn1oh7oPOn1oh7oPOnO
oo/0POn1oh7oPOn1oh7oPOnOoo/0POn1ojWo03R1oh7oPOn1oh7on?ok087oPOn1
oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOnXo`0hPOn1oh7oPOn1
ooWoo021oh7oPOn1oh7oPOn1oikoo021oh7oPOn1oh7oPOn1oikoo021oh7oY_l0
>87oPOn1oh7oPOoiood0POn1oh7oPOn1oh7oPOnMood0POn1oh7oPOn1oh7oPOnM
ood0POn1ojGo03R1oh7oPOn1oh7on_om087oPOn1oh7oPOn1oh7oWOom087oPOn1
oh7oPOn1oh7oWOom087oPOnTo`0hPOn1oh7oPOn1oo[oo@21oh7oPOn1oh7oPOn1
oigoo@21oh7oPOn1oh7oPOn1oigoo@21oh7oY?l0>87oPOn1oh7oPOojooh0POn1
oh7oPOn1oh7oPOnLooh0POn1oh7oPOn1oh7oPOnLooh0POn1oj?o03R1oh7oPOn1
oh7onooY087oPOn1oh7oPOn1oh7o/OoY087oPOn1oh7oPOn1oh7o/OoY087oPOng
o`0hPOn1oh7oPOn1oo_oj@21oh7oPOn1oh7oPOn1ok7oj@21oh7oPOn1oh7oPOn1
ok7oj@21oh7o]ol0>87oPOn1oh7oPOokonT0POn1oh7oPOn1oh7oPOnaonT0POn1
oh7oPOn1oh7oPOnaonT0POn1okOo03R1oh7oPOn1oh7onooY087oPOn1oh7oPOn1
oh7o/OoY087oPOn1oh7oPOn1oh7o/OoY087oPOngo`0`POn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0
<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9
o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1olWo002J0000oh<D000000?X0<D00004000000180000B00001008003
00P00000000000;4nX0000000nP0_P?Z1m<7d0R>00002X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7o
POn1oh7o/_l02X7oPOn1oh7o/_l04Z?om021olWom021olWom02Wo`0BY_o^087o
coo^087ocoo^0:[o01:/onD0POoHonD0POoHonD0[Ol04[cod`21on[od`21on[o
d`2_o`0BcOo1087oo?o1087oo?o10;3o00kNojh0Son^08oo[P2bo`0>k_nL0:7o
W02Qoi`0]?l03`7oohX0/on:0;?oRP2eo`0<Q`2fohL0]_n70;Ko00b60;OoQP2g
ohH0]ol038D0^?n50;SoQ@2ho`0H^`3kom00^Onk0?_od02iok/0noo@0;Wo01S<
0>_ocP2jol`0joo>0;[oc03[olh0^_l06=d0foo=0;[og@3Kold0^_oM0=_oc@2j
o`0Hk@3<ol/0^oo]0<cob`2kond0c?o;0;_o01Sn0;_obP2looh0^oo:0;cooP2k
olX0_?l06[Wob@3/ooX0T?o90>conP2@olT0k?oj0=So01ZiolP0kooe09?ob03_
ooD0Too80>oom@3Ko`0J^_o70?7olP2EolL0lOob09Goa`3aoo80g?l06[[oaP3c
oo00U_o60??ol02FolH0loo`0=go02K8okP0look0?_on`2UokP0look0?_on`2U
okP0look0?_on`3No`0VfOnW0?Coo03hoo`0]_nW0?Coo03hoo`0]_nW0?Coo03h
oo`0g_l09^_oU03eood0m_ol0<WoU03eood0m_ol0<WoU03eood0m_ol0=oo02Kl
oh<0mOom0?Goo@3Joh<0mOom0?Goo@3Joh<0mOom0?Goo@3Oo`0ZP@3n0?Koo03e
ood0gon10?h0m_ol0?Goo@3Ooh40oP3foo`0mOom0=oo033:0?;oa03food0m?om
0=oobP3bol@0m_om0?Coo@3OolX0l_o40?Koo@3dood0gol0<=`0hOo20?Ooo@3d
ood0gooL0>7o`P3good0m?om0=oog03Qol80moom0?Coo@3Oo`0`kP3?ol80moom
0?Coo@3Oonh0coo20?Ooo@3dood0goo^0<oo`P3good0m?om0=oo02@00;go`P3W
oo`0gol00;go`P3Woo`0gol00;go`P3Woo`0gol06[co`P3Xoo`0VOo20>Soo02I
ol80j?ol0=ko01Zlol80jOok09Wo`P3Yoo/0VOo20>Won`3No`0J`?nn0>oomP2L
okh0koof09co_P3_ooH0gOl06]7o[@3_ooP0Zon]0>oon02[ojd0kooh0=_o02KR
oml0o?o40>komP2noml0o?o40>komP2noml0o?o40>komP3Mo`0VlooO0>_oa03^
oo@0dOoO0>_oa03^oo@0dOoO0>_oa03^oo@0gol09>80f_o40>Son@3Pon80f_o4
0>Son@3Pon80f_o40>Son@3Po`0Tl`39ol@0iOol0>3ol`39ol@0iOol0>3ol`39
ol@0iOol0>3o01ZjolH0hool09[oaP3Soo`0V_o60>?oo03Qo`0J^_o60>?oo02J
olH0hool09[oaP3Soo`0hOl06[[oa`3Qood0V_o70>7oo@2JolL0hOom0>7o02Jj
olL0mOom0?7oo@2JolL0mOom0?7oo@2JolL0mOom0?7oo@3Qo`0V^Oo80?Goo@3a
ood0VOo80?Goo@3aood0VOo80?Goo@3aood0hOl09[Wob@3dood0lOom09Wob@3d
ood0lOom09Wob@3dood0lOom0>7o02JholX0m?ol0?;oo@2HolX0m?ol0?;oo@2H
olX0m?ol0?;oo@3Qo`0V]oo<0?;oo@3cood0U_o<0?;oo@3cood0U_o<0?;oo@3c
ood0h?l09[Ooc@3aoo`0mOol09Koc@3aoo`0mOol09Koc@3aoo`0mOol0>3o02Jf
oll0l?ok0?Oon`2Eoll0l?ok0?Oon`2Eoll0l?ok0?Oon`3Po`0V]_o?0>oon`3j
ooX0U?o?0>oon`3jooX0U?o?0>oon`3jooX0gol06[Ooc`3]onl0U?o?0>gok`2D
oll0kOo_0=ko02Vhooh00Oooe@3Zoo40U?on007oomD0j_oa09CooP01oooE0>[o
l@3Mo`0V^?on0?koeP3Yoo@0T_on0?koeP3Yoo@0T_on0?koeP3Yoo@0fol09[Wo
oP3komT0i_oh097ooP3komT0i_oh097ooP3komT0i_oh0=Wo01jjooh0nOoL087o
k?on0?Wog021oncooP3iom`0/ol07[_ooP3homd0POo/ooh0n?oM087ok?on0?So
g@2bo`0N_?on0?SogP21on_ooP3homh0POo[ooh0n?oN0;3o02Zmooh0n?ok003o
iP21on[ooP3hoo/00?oV087oj_on0?Son`00onH0[_l0:[kooP3goo`0o_oY087o
jOon0?Ooo03nonT0POoYooh0mool0?koj@2/o`0Z__on0?Soo03hoo<0POoTooh0
n?ol0?Sol`21onCooP3hoo`0n?oc0:Oo02Zoooh0n?ol0?SomP21on7ooP3hoo`0
n?of087ohOon0?Soo03hooH0Xol0:/3ooP3hoo`0n?of087ohOon0?Soo03hooH0
POoQooh0n?ol0?SomP2Ro`0Z`Oon0?Son`3iooH0POoQooh0n?ok0?WomP21on7o
oP3hoo/0nOof0:7o02[2ooh0n?ok0?Som`21on7ooP3hoo/0n?og087ohOon0?So
n`3hooL0X?l0:/?ooP3hoo/0n?og087ohOon0?Son`3hooL0POoQooh0n?ok0?So
m`2Oo`0Za?on0?Ooo03hooL0POoQooh0mool0?Som`21on7ooP3goo`0n?og09ko
02[4ooh0n?ol0?Som`21on3ooP3hoo`0n?og087oh?on0?Soo03hooL0WOl0:/Go
oP3hoo`0n?og087oh?on0?Soo03hooL0POoPooh0n?ol0?Som`2Lo`0Za_on0?So
o03hooH0POoQooh0n?ol0?SomP21on7ooP3hoo`0n?of09co02[7ooh0n?ol0?So
mP21on7ooP3hoo`0n?of087ohOon0?Soo03hooH0Vol0:/SooP3hoo/0n?og087o
hOon0?Son`3hooL0POoQooh0n?ok0?Som`2Jo`0ZbOon0?Son`3hooL0POoQooh0
n?ok0?Som`21on7ooP3hoo/0n?og09Wo02[:ood0n?ol0?Som`21on7oo@3hoo`0
n?og087ohOom0?Soo03hooL0V?l0:/[ooP3hoo`0n?og087oh?on0?Soo03hooL0
POoPooh0n?ol0?Som`2Go`0Zboon0?Soo03hooL0POoPooh0n?ol0?Som`21on3o
oP3hoo`0n?og09Ko02[<ooh0n?ol0?SomP21on7ooP3hoo`0n?of087ohOon0?So
o03hooH0U_l0:/gooP3hoo`0n?of087ohOon0?Soo03hooH0POoQooh0n?ol0?So
mP2Eo`0Zc_on0?Son`3hooL0POoQooh0n?ok0?Som`21on7ooP3hoo/0n?og09Co
02[?ooh0n?ok0?Som`21on7ooP3hoo/0n?og087ohOon0?Son`3hooL0Tol0:]3o
o@3ioo/0n?og087ohOom0?Won`3hooL0POoQood0nOok0?Som`2Bo`0Zd?on0?So
o03hooL0POoPooh0n?ol0?Som`21on3ooP3hoo`0n?og097o02[Aooh0n?ol0?So
m`21on3ooP3hoo`0n?og087oh?on0?Soo03hooL0T?l0:];ooP3hoo`0n?of087o
hOon0?Soo03hooH0POoQooh0n?ol0?SomP2@o`0Zdoon0?Soo03hooH0POoQooh0
n?ol0?SomP21on7ooP3hoo`0n?of08oo02[Dooh0n?ok0?Som`21on7ooP3hoo/0
n?og087ohOon0?Son`3hooL0S_l0:]GooP3hoo/0n?og087ohOon0?Son`3hooL0
POoQooh0n?ok0?Som`2=o`0Ze_om0?Won`3hooL0POoQood0nOok0?Som`21on7o
o@3ioo/0n?og08co02[Fooh0n?ol0?Som`21on3ooP3hoo`0n?og087oh?on0?So
o03hooL0Rol0:]OooP3hoo`0n?og087oh?on0?Soo03hooL0POoPooh0n?ol0?So
m`2:o`0Zf?on0?Soo03hooH0POoQooh0n?ol0?SomP21on7ooP3hoo`0n?of08[o
02[Iooh0n?ol0?SomP21on7ooP3hoo`0n?of087ohOon0?Soo03hooH0ROl0:][o
oP3hoo`0moog087ohOon0?Soo03gooL0POoQooh0n?ol0?Oom`28o`0Zfoon0?So
n`3hooL0POoQooh0n?ok0?Som`21on7ooP3hoo/0n?og08Oo02[Lood0nOok0?So
m`21on7oo@3ioo/0n?og087ohOom0?Won`3hooL0Q_l0:]goo@3hoo`0n?og087o
hOom0?Soo03hooL0POoQood0n?ol0?Som`25o`0ZgOon0?Soo03hooL0POoPooh0
n?ol0?Som`21on3ooP3hoo`0n?og08Co02[Nooh0n?ol0?SomP21on7ooP3hoo`0
n?of087ohOon0?Soo03hooH0Q?l0:]oooP3hoo`0n?of087ohOon0?Soo03hooH0
POoQooh0n?ol0?SomP23o`0Zh?on0?Soo03gooL0POoQooh0n?ol0?Oom`21on7o
oP3hoo`0moog08;o02[Qooh0n?ok0?Som`21on7ooP3hoo/0n?og087ohOon0?So
n`3hooL0POl0;>;oo@3ioo/0n?og087ohOom0?Won`3hooL0POoQood0nOok0?So
m`21o`3o02gSood0n?ol0?Som`21on7oo@3hoo`0n?og087ohOom0?Soo03hooL0
POl1ool0;>?ooP3hoo`0n?og087oh?on0?Soo03hooL0POoPooh0n?ol0?Som`21
ooko02cTooh0n?ol0?SomP21on7ooP3hoo`0n?of087ohOon0?Soo03hooH0POon
o`0/iOon0?Soo03hooH0POoQooh0n?ol0?SomP21on7ooP3hoo`0n?of087ooOl0
;>KooP3hoo`0n?of087ohOon0?Soo03hooH0POoQooh0n?ol0?SomP21ooco02cW
ooh0n?ok0?Som`21on7ooP3hoo/0n?og087ohOon0?Son`3hooL0POoko`0/j?om
0?Won`3hooL0POoQood0nOok0?Som`21on7oo@3ioo/0n?og087on_l0;>Woo@3h
oo`0n?og087ohOom0?Soo03hooL0POoQood0n?ol0?Som`21ooWo02cYooh0n?ol
0?Som`21on3ooP3hoo`0n?og087oh?on0?Soo03hooL0POoho`0/j_on0?Soo03h
ooL0POoPooh0n?ol0?Som`21on3ooP3hoo`0n?og087omol0;>_ooP3hoo`0n?of
087ohOon0?Soo03hooH0POoQooh0n?ol0?SomP21ooOo02c/ooh0n?ol0?SomP21
on7ooP3hoo`0n?of087ohOon0?Soo03hooH0POofo`0/kOon0?Soo03gooL0POoQ
ooh0n?ol0?Oom`21on7ooP3hoo`0moog087omOl0;>koo@3ioo/0n?og087ohOom
0?Won`3hooL0POoQood0nOok0?Som`21ooCo02c_ood0n?ol0?Som`21on7oo@3h
oo`0n?og087ohOom0?Soo03hooL0POoco`0/koon0?Soo03hooL0POoPooh0n?ol
0?Som`21on3ooP3hoo`0n?og087ol_l0;?3ooP3hoo`0n?og087oh?on0?Soo03h
ooL0POoPooh0n?ol0?Som`21oo7o02caooh0n?ol0?SomP21on7ooP3hoo`0n?of
087ohOon0?Soo03hooH0POoao`0/l_on0?Soo03hooH0POoQooh0n?ol0?SomP21
on7ooP3hoo`0n?of087ol?l0;??ooP3hoo`0moog087ohOon0?Soo03gooL0POoQ
ooh0n?ol0?Oom`21onoo02cdood0nOok0?Som`21on7oo@3ioo/0n?og087ohOom
0?Won`3hooL0POo^o`0/mOom0?Soo03hooL0POoQood0n?ol0?Som`21on7oo@3h
oo`0n?og087okOl0;?GooP3hoo`0n?og087oh?on0?Soo03hooL0POoPooh0n?ol
0?Som`21onco02cfooh0n?ol0?Som`21on3ooP3hoo`0n?og087oh?on0?Soo03h
ooL0POo[o`0/moon0?Soo03hooH0POoQooh0n?ol0?SomP21on7ooP3hoo`0n?of
087ojol0;?SooP3hoo`0n?of087ohOon0?Soo03hooH0POoQooh0n?ol0?SomP21
on[o02ciooh0n?ol0?Oom`21on7ooP3hoo`0moog087ohOon0?Soo03gooL0POoY
o`0/n_om0?Won`3hooL0POoQood0nOok0?Som`21on7oo@3ioo/0n?og087oj?l0
;?_oo@3hoo`0n?og087ohOom0?Soo03hooL0POoQood0n?ol0?Som`21onOo02ck
ooh0n?ol0?Som`21on3ooP3hoo`0n?og087oh?on0?Soo03hooL0POoVo`0/o?on
0?Soo03hooL0POoPooh0n?ol0?Som`21on3ooP3hoo`0n?og087oiOl0;?gooP3h
oo`0n?of087ohOon0?Soo03hooH0POoQooh0n?ol0?SomP21onGo02cnooh0n?ol
0?SomP21on7ooP3hoo`0n?of087ohOon0?Soo03hooH0POoTo`0]0OoooP3hoo`0
moog087ohOon0?Soo03gooL0POoQooh0n?ol0?Oom`21on?o02`0ood0nOol0?Oo
m`21on7oo@3ioo`0moog087ohOom0?Woo03gooL0POoRo`0Zo@3hoo`0n?og087o
hOom0?Soo03hooL0POoQood0n?ol0?Som`21on7o02[n0?Soo03hooL0POoPooh0
n?ol0?Som`21on3ooP3hoo`0n?og087oh?l0;@400?Soo03hooL0POoOo`400?So
o03hooL0POoOo`400?Soo03hooL0POoOo`0Z003hoo`0n?of087ogol00?Soo03h
ooH0POoOo`00n?ol0?SomP21omoo023hoo`0n?of087oeOol0?SomP21omGoo03h
ooH0POoNo`0PnOol0?Oom`21omGoo03gooL0POoEoo`0moog087ogOl08?[oo03g
ooL0POoEoo`0moog087oeOol0?Oom`21omco023joo`0n?og087oe?ol0?Som`21
omCoo03hooL0POoKo`0Pnool0?Som`21omCoo03hooL0POoDoo`0n?og087of_l0
8?coo03hooL0POoDoo`0n?og087oe?ol0?Som`21omWo023moo`0n?of087oeOol
0?SomP21omGoo03hooH0POoIo`0Po_ol0?SomP21omGoo03hooH0POoEoo`0n?of
087of?l08@7ooo`0moog087oeOol0?Oom`21omGoo03gooL0POoGo`0P0?ol0?Oo
m`21omGoo03gooL0POoEoo`0moog087oe_l0803oo03hooL0POoDoo`0n?og087o
e?ol0?Som`21omGo01kl0?Som`21omCoo03hooL0POoDoo`0n?og087oe?l07_d0
n?og087odoom0?Som`21om?oo@3hooL0POoCo`0NoP3hooH0POoCooh0n?of087o
doon0?SomP21om?o0241003hooH0POoBo`400?SomP21om;o0@00n?of087od_l0
7P00n?of087odOl00?SomP21om7o003hooH0POoAo`0Dmoog087oa_og087oa_og
087od?l05?Som`21olKom`21olKom`21oloo01CiooL0POo6ooL0POo6ooL0POo>
o`0Dn_og087oa_og087oa_og087ocOl05?_om`21olKom`21olKom`21olco01Cl
ooH0POo7ooH0POo7ooH0POo<o`0DoOof087oaoof087oaoof087obol05?gom`21
olKom`21olKom`21ol[o01CnooL0POo6ooL0POo6ooL0POo9o`0E0Ooom`21olKo
m`21olKom`21olSo01@0ooL0POo6ooL0POo6ooL0POo7o`0Bm`21olKom`21olKo
m`21olKo01;g087oa_og087oa_og087oa_l04_P0POo5ooP0POo5ooP0POo5o`0B
n@21olCon@21olCon@21olCo01;j087o`ooj087o`ooj087o`ol04_/0POo2oo/0
POo2oo/0POo2o`0Bo021ol7oo021ol7oo021ol7o01;m087o`?om087o`?om087o
`?l04_d0POo0ood0POo0ood0POo0o`0BoP21okoooP21okoooP21okoo01D10021
okko0@00POnno`40087o__l04P00POnmo`00POnmo`00POnmo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnbo`0:POn1oh7oPOnb
o`0:POn1oh7oPOnbo`0B0021okgo0021okgo0021okgo01D10021okko0@00POnn
o`40087o__l05@40087o__l10021okko0@00POnno`0BoP21okoooP21okoooP21
okoo01;n087o_oon087o_oon087o_ol04_h0POnoooh0POnoooh0POnoo`0BoP21
okoooP21okoooP21okoo01;n087o_oon087o_oon087o_ol04_h0POnoooh0POno
ooh0POnoo`0BoP21okoooP21okoooP21okoo01D10021okko0@00POnno`40087o
__l05@40087o__l10021okko0@00POnno`0B0021okgo0021okgo0021okgo00Z1
oh7oPOn1ok;o0180087o_Ol0087o_Ol0087o_Ol04_h0POnoooh0POnoooh0POno
o`0Bo@21ol3oo@21ol3oo@21ol3o01;m087o`?om087o`?om087o`?l04_`0POo1
oo`0POo1oo`0POo1o`0Bo021ol7oo021ol7oo021ol7o01@0ood0POo0ood0POo0
ood0POo1o`0D0?om087o`?om087o`?om087o`Ol0503oo@21ol3oo@21ol3oo@21
ol7o01@0ood0POo0ood0POo0ood0POo1o`0D0?om087o`?om087o`?om087o`Ol0
4_d0POo0ood0POo0ood0POo0o`0Bo@21ol3oo@21ol3oo@21ol3o01;m087o`?om
087o`?om087o`?l04_h0POnoooh0POnoooh0POnoo`0E0@00POnno`40087o__l1
0021okko0180087o_Ol0087o_Ol0087o_Ol02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o/_l02X7oPOn1oh7o
/_l02X7oPOn1oh7o/_l0X02o0?l\>"], "NumberedFigure",
  ImageSize->{432, 394.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Figure 8.  Upper part: Most general capacitive network consisting \
of 5 nodes (0-4). 
Lower part: Successive reduction to two nodes\
\>", "Caption"],

Cell["\<\
Equation (45) shows how the new box impedance connecting nodes \
\[Mu] and \[Nu] is expressed by all the star legs:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(Z\_\(\[Mu], \[Nu]\) = \(Z\_\(\[Mu], r\)\) \(Z\_\(\[Nu], 
              r\)\) \(\[Sum]\+\(\[Lambda] = 1\)\%n 1\/Z\_\(\[Lambda], \
r\)\)\)]],
  ","
}], "NumberedEquation"],

Cell["\<\
where n is the number of legs of the star-type node r to be \
replaced. 
\tThe cell below contains an auxiliary function to calculate parallel \
impedances.\
\>", "Text"],

Cell[BoxData[
    \(par[z1_, z2_] := \(z1\ z2\)\/\(z1 + z2\)\)], "Input",
  CellLabel->"In[81]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell["\<\
We get 6, 3 and at last 1 expression corresponding to the thin \
lines in the lower part of Fig. 8.\
\>", "Text"],

Cell["Replace node 4 :", "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(zz10 = 
      par[z10, z14\ z40\ \((1\/z40 + 1\/z14 + 1\/z24 + 1\/z34)\)] // 
        Simplify\)], "Input",
  CellLabel->"In[82]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(z10\ \((z24\ z34\ z40 + z14\ \((z34\ z40 + z24\ \((z34 + z40)\))\))\)\
\)\/\(z10\ z24\ z34 + z24\ z34\ z40 + z14\ \((z24\ z34 + z24\ z40 + z34\ z40)\
\)\)\)], "Output",
  CellLabel->"Out[82]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(zz20 = 
      par[z20, z24\ z40\ \((1\/z40 + 1\/z14 + 1\/z24 + 1\/z34)\)] // 
        Simplify\)], "Input",
  CellLabel->"In[83]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(z20\ \((z24\ z34\ z40 + z14\ \((z34\ z40 + z24\ \((z34 + z40)\))\))\)\
\)\/\(z24\ z34\ z40 + z14\ \((z20\ z34 + z34\ z40 + z24\ \((z34 + z40)\))\)\)\
\)], "Output",
  CellLabel->"Out[83]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(zz30 = 
      par[z30, z34\ z40\ \((1\/z40 + 1\/z14 + 1\/z24 + 1\/z34)\)] // 
        Simplify\)], "Input",
  CellLabel->"In[84]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(z30\ \((z24\ z34\ z40 + z14\ \((z34\ z40 + z24\ \((z34 + z40)\))\))\)\
\)\/\(z24\ z34\ z40 + z14\ \((z34\ z40 + z24\ \((z30 + z34 + z40)\))\)\)\)], \
"Output",
  CellLabel->"Out[84]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(zz12 = 
      par[z12, z14\ z24\ \((1\/z40 + 1\/z14 + 1\/z24 + 1\/z34)\)] // 
        Simplify\)], "Input",
  CellLabel->"In[85]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(z12\ \((z24\ z34\ z40 + z14\ \((z34\ z40 + z24\ \((z34 + z40)\))\))\)\
\)\/\(\((z12 + z24)\)\ z34\ z40 + z14\ \((z34\ z40 + z24\ \((z34 + \
z40)\))\)\)\)], "Output",
  CellLabel->"Out[85]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(zz13 = 
      par[z13, z14\ z34 \((1\/z40 + 1\/z14 + 1\/z24 + 1\/z34)\)] // 
        Simplify\)], "Input",
  CellLabel->"In[86]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(z13\ \((z24\ z34\ z40 + z14\ \((z34\ z40 + z24\ \((z34 + z40)\))\))\)\
\)\/\(z24\ \((z13 + z34)\)\ z40 + z14\ \((z34\ z40 + z24\ \((z34 + \
z40)\))\)\)\)], "Output",
  CellLabel->"Out[86]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(zz23 = 
      par[z23, z24\ z34 \((1\/z40 + 1\/z14 + 1\/z24 + 1\/z34)\)] // 
        Simplify\)], "Input",
  CellLabel->"In[87]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(z23\ \((z24\ z34\ z40 + z14\ \((z34\ z40 + z24\ \((z34 + z40)\))\))\)\
\)\/\(z24\ z34\ z40 + z14\ \((\((z23 + z34)\)\ z40 + z24\ \((z34 + \
z40)\))\)\)\)], "Output",
  CellLabel->"Out[87]="]
}, Open  ]],

Cell["Replace node 0:", "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(zzz12 = 
      par[zz12, zz10\ zz20 \((1\/zz10 + 1\/zz20 + 1\/zz30)\)] // 
        Simplify\)], "Input",
  CellLabel->"In[88]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(zzz12\)\" is similar to \
existing symbol \"\!\(zz12\)\"."\)], "Message",
  CellLabel->"From In[88]:="],

Cell[BoxData[
    \(\((z12\ \((z20\ z30\ \((z24\ z34\ z40 + 
                    z14\ \((z34\ z40 + z24\ \((z34 + z40)\))\))\) + 
              z10\ \((z24\ z34\ \((z30\ z40 + z20\ \((z30 + z40)\))\) + 
                    z14\ \((z30\ \((z34\ z40 + z24\ \((z34 + z40)\))\) + 
                          z20\ \((z34\ \((z30 + z40)\) + 
                                z24\ \((z30 + z34 + 
                                      z40)\))\))\))\))\))\)/\((z30\ \((z20\ \
\((z24\ z34\ z40 + z14\ \((z34\ z40 + z24\ \((z34 + z40)\))\))\) + 
                z12\ \((\((z20 + z24)\)\ z34\ z40 + 
                      z14\ \((z20\ z34 + z34\ z40 + 
                            z24\ \((z34 + z40)\))\))\))\) + 
          z10\ \((z34\ \((z24\ \((z30\ z40 + z20\ \((z30 + z40)\))\) + 
                      z12\ \((z30\ \((z24 + z40)\) + 
                            z20\ \((z30 + z40)\))\))\) + 
                z14\ \((z30\ \((z34\ z40 + z24\ \((z34 + z40)\))\) + 
                      z20\ \((z34\ \((z30 + z40)\) + 
                            z24\ \((z30 + z34 + 
                                  z40)\))\))\))\))\)\)], "Output",
  CellLabel->"Out[88]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(zzz13 = 
      par[zz13, zz10\ zz30 \((1\/zz10 + 1\/zz20 + 1\/zz30)\)] // 
        Simplify\)], "Input",
  CellLabel->"In[89]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(zzz13\)\" is similar to \
existing symbol \"\!\(zz13\)\"."\)], "Message",
  CellLabel->"From In[89]:="],

Cell[BoxData[
    \(\((z13\ \((z20\ z30\ \((z24\ z34\ z40 + 
                    z14\ \((z34\ z40 + z24\ \((z34 + z40)\))\))\) + 
              z10\ \((z24\ z34\ \((z30\ z40 + z20\ \((z30 + z40)\))\) + 
                    z14\ \((z30\ \((z34\ z40 + z24\ \((z34 + z40)\))\) + 
                          z20\ \((z34\ \((z30 + z40)\) + 
                                z24\ \((z30 + z34 + 
                                      z40)\))\))\))\))\))\)/\((z20\ \((z30\ \
\((z24\ z34\ z40 + z14\ \((z34\ z40 + z24\ \((z34 + z40)\))\))\) + 
                z13\ \((z24\ \((z30 + z34)\)\ z40 + 
                      z14\ \((z34\ z40 + 
                            z24\ \((z30 + z34 + z40)\))\))\))\) + 
          z10\ \((z24\ z34\ \((z30\ z40 + z20\ \((z30 + z40)\))\) + 
                z13\ z24\ \((z30\ z40 + z20\ \((z30 + z34 + z40)\))\) + 
                z14\ \((z30\ \((z34\ z40 + z24\ \((z34 + z40)\))\) + 
                      z20\ \((z34\ \((z30 + z40)\) + 
                            z24\ \((z30 + z34 + 
                                  z40)\))\))\))\))\)\)], "Output",
  CellLabel->"Out[89]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(zzz23 = 
      par[zz23, zz20\ zz30 \((1\/zz10 + 1\/zz20 + 1\/zz30)\)] // 
        Simplify\)], "Input",
  CellLabel->"In[90]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(zzz23\)\" is similar to \
existing symbol \"\!\(zz23\)\"."\)], "Message",
  CellLabel->"From In[90]:="],

Cell[BoxData[
    \(\((z23\ \((z20\ z30\ \((z24\ z34\ z40 + 
                    z14\ \((z34\ z40 + z24\ \((z34 + z40)\))\))\) + 
              z10\ \((z24\ z34\ \((z30\ z40 + z20\ \((z30 + z40)\))\) + 
                    z14\ \((z30\ \((z34\ z40 + z24\ \((z34 + z40)\))\) + 
                          z20\ \((z34\ \((z30 + z40)\) + 
                                z24\ \((z30 + z34 + 
                                      z40)\))\))\))\))\))\)/\((z20\ z30\ \
\((z24\ z34\ z40 + 
                z14\ \((\((z23 + z34)\)\ z40 + z24\ \((z34 + z40)\))\))\) + 
          z10\ \((z24\ z34\ \((\((z23 + z30)\)\ z40 + 
                      z20\ \((z30 + z40)\))\) + 
                z14\ \((z30\ \((z34\ z40 + z24\ \((z34 + z40)\))\) + 
                      z23\ \((\((z30 + z34)\)\ z40 + 
                            z24\ \((z30 + z34 + z40)\))\) + 
                      z20\ \((z34\ \((z30 + z40)\) + 
                            z23\ \((z30 + z34 + z40)\) + 
                            z24\ \((z30 + z34 + 
                                  z40)\))\))\))\))\)\)], "Output",
  CellLabel->"Out[90]="]
}, Open  ]],

Cell["Replace node 3:", "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(zzzz12 = 
      par[zzz12, zzz13\ zzz23 \((1\/zzz13 + 1\/zzz23)\)] // 
        Simplify\)], "Input",
  CellLabel->"In[91]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(zzzz12\)\" is similar \
to existing symbol \"\!\(zzz12\)\"."\)], "Message",
  CellLabel->"From In[91]:="],

Cell[BoxData[
    \(\((z12\ \((z20\ \((z23\ z30\ \((z24\ z34\ z40 + 
                          z14\ \((z34\ z40 + z24\ \((z34 + z40)\))\))\) + 
                    z13\ \((z24\ \((z30\ z34 + z23\ \((z30 + z34)\))\)\ z40 + 
                          z14\ \((z30\ \((z34\ z40 + 
                                      z24\ \((z34 + z40)\))\) + 
                                z23\ \((\((z30 + z34)\)\ z40 + 
                                      z24\ \((z30 + z34 + 
                                        z40)\))\))\))\))\) + 
              z10\ \((z23\ \((z24\ z34\ \((z30\ z40 + 
                                z20\ \((z30 + z40)\))\) + 
                          z14\ \((z30\ \((z34\ z40 + 
                                      z24\ \((z34 + z40)\))\) + 
                                z20\ \((z34\ \((z30 + z40)\) + 
                                      z24\ \((z30 + z34 + z40)\))\))\))\) + 
                    z13\ \((z24\ \((\((z30\ z34 + 
                                      z23\ \((z30 + z34)\))\)\ z40 + 
                                z20\ \((z34\ \((z30 + z40)\) + 
                                      z23\ \((z30 + z34 + z40)\))\))\) + 
                          z14\ \((z30\ \((z34\ z40 + 
                                      z24\ \((z34 + z40)\))\) + 
                                z23\ \((\((z30 + z34)\)\ z40 + 
                                      z24\ \((z30 + z34 + z40)\))\) + 
                                z20\ \((z34\ \((z30 + z40)\) + 
                                      z23\ \((z30 + z34 + z40)\) + 
                                      z24\ \((z30 + z34 + 
                                        z40)\))\))\))\))\))\))\)/\((z20\ \
\((z23\ z30\ \((z24\ z34\ z40 + 
                      z14\ \((z34\ z40 + z24\ \((z34 + z40)\))\))\) + 
                z13\ \((z24\ \((z30\ z34 + z23\ \((z30 + z34)\))\)\ z40 + 
                      z14\ \((z30\ \((z34\ z40 + z24\ \((z34 + z40)\))\) + 
                            z23\ \((\((z30 + z34)\)\ z40 + 
                                  z24\ \((z30 + z34 + z40)\))\))\))\))\) + 
          z12\ \((z30\ \((\((z23\ z24 + z20\ \((z23 + z24)\))\)\ z34\ z40 + 
                      z14\ \((z23\ \((z34\ z40 + z24\ \((z34 + z40)\))\) + 
                            z20\ \((z34\ z40 + z23\ \((z34 + z40)\) + 
                                  z24\ \((z34 + z40)\))\))\))\) + 
                z13\ \((\((z24\ \((z30\ z34 + z23\ \((z30 + z34)\))\) + 
                            z20\ \((z30\ z34 + z23\ \((z30 + z34)\) + 
                                  z24\ \((z30 + z34)\))\))\)\ z40 + 
                      z14\ \((z30\ \((z34\ z40 + z24\ \((z34 + z40)\))\) + 
                            z23\ \((\((z30 + z34)\)\ z40 + 
                                  z24\ \((z30 + z34 + z40)\))\) + 
                            z20\ \((z34\ \((z30 + z40)\) + 
                                  z23\ \((z30 + z34 + z40)\) + 
                                  z24\ \((z30 + z34 + z40)\))\))\))\))\) + 
          z10\ \((z23\ \((z24\ z34\ \((z30\ z40 + z20\ \((z30 + z40)\))\) + 
                      z14\ \((z30\ \((z34\ z40 + z24\ \((z34 + z40)\))\) + 
                            z20\ \((z34\ \((z30 + z40)\) + 
                                  z24\ \((z30 + z34 + z40)\))\))\))\) + 
                z13\ \((z24\ \((\((z30\ z34 + z23\ \((z30 + z34)\))\)\ z40 + 
                            z20\ \((z34\ \((z30 + z40)\) + 
                                  z23\ \((z30 + z34 + z40)\))\))\) + 
                      z14\ \((z30\ \((z34\ z40 + z24\ \((z34 + z40)\))\) + 
                            z23\ \((\((z30 + z34)\)\ z40 + 
                                  z24\ \((z30 + z34 + z40)\))\) + 
                            z20\ \((z34\ \((z30 + z40)\) + 
                                  z23\ \((z30 + z34 + z40)\) + 
                                  z24\ \((z30 + z34 + z40)\))\))\))\) + 
                z12\ \((z34\ \((z24\ z30\ z40 + 
                            z20\ \((z23 + z24)\)\ \((z30 + z40)\) + 
                            z23\ \((z30\ z40 + z24\ \((z30 + z40)\))\))\) + 
                      z13\ \((z30\ \((z34\ z40 + z24\ \((z34 + z40)\))\) + 
                            z23\ \((\((z30 + z34)\)\ z40 + 
                                  z24\ \((z30 + z34 + z40)\))\) + 
                            z20\ \((z34\ \((z30 + z40)\) + 
                                  z23\ \((z30 + z34 + z40)\) + 
                                  z24\ \((z30 + z34 + z40)\))\))\) + 
                      z14\ \((z30\ \((z34\ z40 + z24\ \((z34 + z40)\))\) + 
                            z23\ \((\((z30 + z34)\)\ z40 + 
                                  z24\ \((z30 + z34 + z40)\))\) + 
                            z20\ \((z34\ \((z30 + z40)\) + 
                                  z23\ \((z30 + z34 + z40)\) + 
                                  z24\ \((z30 + z34 + 
                                        z40)\))\))\))\))\))\)\)], "Output",
  CellLabel->"Out[91]="]
}, Open  ]],

Cell[TextData[{
  "After entering the capacity values for the impedances, we get ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_12\)\&^\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`C\_1'\)]],
  " from (3) for the first differential line!"
}], "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(z10 = 1/129.28; z12 = 1/0.242; z13 = 1/0.0035; 
    z14 = 1/0.0001;\), "\[IndentingNewLine]", 
    \(z20 = 1/129.04; z23 = 1/0.242; z24 = 1/0.0035; 
    z30 = 1/129.04;\), "\[IndentingNewLine]", 
    \(z34 = 1/0.242; z40 = 1/129.28; 1/zzzz12\)}], "Input",
  CellLabel->"In[92]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(64.88416518144994`\)], "Output",
  CellLabel->"Out[102]="]
}, Open  ]],

Cell[TextData[{
  "To get ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \ \)\(\(C\_23\)\&^\ between\ nodes\ 2\ and\ \
3\)\)\)]],
  " the numbers 1 and 3 in the capacitors indices  swap places (cf. Fig. 8):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(z10 = 1/129.04; z12 = 1/0.242; z13 = 1/0.0035; 
    z14 = 1/0.242;\), "\[IndentingNewLine]", 
    \(z20 = 1/129.04; z23 = 1/0.242; z24 = 1/0.0035; 
    z30 = 1/129.28;\), "\[IndentingNewLine]", 
    \(z34 = 1/0.0001; z40 = 1/129.28; 1/zzzz12\)}], "Input",
  CellLabel->"In[103]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(64.88453042098982`\)], "Output",
  CellLabel->"Out[113]="]
}, Open  ]],

Cell[TextData[{
  "Both the capacities ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_24\)\&^\)]],
  " between nodes 2 and 4 (swap numbers 1 and 4) and  ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_13\)\&^\)]],
  " between nodes 1 and 3 (swap numbers 2 and 3) are identical :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(z10 = 1/129.28; z12 = 1/0.0035; z13 = 1/0.242; 
    z14 = 1/0.0001;\), "\[IndentingNewLine]", 
    \(z20 = 1/129.04; z23 = 1/0.242; z24 = 1/0.242; 
    z30 = 1/129.04;\), "\[IndentingNewLine]", 
    \(z34 = 1/0.0035; z40 = 1/129.28; 1/zzzz12\)}], "Input",
  CellLabel->"In[114]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(64.76491205580561`\)], "Output",
  CellLabel->"Out[124]="]
}, Open  ]],

Cell[TextData[{
  "The capacity ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(C\_14\)\&^\)\)]],
  " between nodes 1 and 4 is (swap numbers 2 and 4):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(z10 = 1/129.28; z12 = 1/0.0001; z13 = 1/0.0035; 
    z14 = 1/0.242;\), "\[IndentingNewLine]", 
    \(z20 = 1/129.28; z23 = 1/0.242; z24 = 1/0.0035; 
    z30 = 1/129.04;\), "\[IndentingNewLine]", 
    \(z34 = 1/0.242; z40 = 1/129.04; 1/zzzz12\)}], "Input",
  CellLabel->"In[136]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(64.76263083351635`\)], "Output",
  CellLabel->"Out[146]="]
}, Open  ]],

Cell[TextData[{
  " Last is ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2'\)]],
  ", the capacity of the second differential line,  where 1 is swapped for 4 \
and 2 for 3 (identical to ",
  Cell[BoxData[
      \(TraditionalForm\`C\_1'\)]],
  ") : "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(z10 = 1/129.28; z12 = 1/0.242; z13 = 1/0.0035; 
    z14 = 1/0.0001;\), "\[IndentingNewLine]", 
    \(z20 = 1/129.04; z23 = 1/0.242; z24 = 1/0.0035; 
    z30 = 1/129.04;\), "\[IndentingNewLine]", 
    \(z34 = 1/0.242; z40 = 1/129.28; 1/zzzz12\)}], "Input",
  CellLabel->"In[147]:=",
  CellFrame->True,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(64.88416518144994`\)], "Output",
  CellLabel->"Out[157]=",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[TextData[{
  "The remaining effective coupling ",
  StyleBox["that determines the crosstalk",
    FontSlant->"Italic"],
  ", evaluates then \nwith (45) to ",
  Cell[BoxData[
      \(TraditionalForm\`C\_12'\)]],
  " = 0.1173 [pF/m].\n"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Code  (Coefficients of ",
  "inductance",
  " of the pigtail)"
}], "Subsection",
  PageBreakAbove->Automatic],

Cell["RAM requirements: Front End 20 MB, Kernel 30 MB", "Text"],

Cell["\<\
Set v1 - v4 such that the resulting current in the loop integral \
below has the correct value (-1 or  0 or +1).\
\>", "Text"],

Cell["\<\
v1=0.196581;v2=-0.1947736;v3=0.1947728;v4=-0.196612;
nz=80; (* # of rows of the grid, divisible by 2 *)
ns=446; (* # of columns of the grid, divisible by 2 *)
{xr,yr}={91,12.5};(* center point for contour integral *)
u=.;m=.;m=Array[u,{nz,ns}];a=Array[u,{nz,ns}];
mb=Table[0,{nz},{ns}];
Do[Do[a[[i,j]]=u[[i,j]],{j,1,ns}],{i,1,nz}]
Do[Do[m[[i,j]]:=Evaluate[0.25(a[[i-1,j]]+a[[i,j-1]]+
a[[i+1,j]]+a[[i,j+1]])],
{j,2,ns-1}],{i,2,nz-1}]
Do[m[[1,j]]:=0.,{j,1,ns}]
Do[m[[nz,j]]:=0.,{j,1,ns}]
Do[m[[i,1]]:=0.,{i,1,nz}]
Do[m[[i,ns]]:=0.,{i,1,nz}]
xl1=80;xr1=102;yd1=11;yu1=14;
xl2=168;xr2=190;yd2=11;yu2=14;
xl3=256;xr3=278;yd3=11;yu3=14;
xl4=344;xr4=366;yd4=11;yu4=14;
Do[Do[{m[[i,j]]:=v1;mb[[i,j]]=1;},{j,xl1,xr1}],{i,yd1,yu1}]
Do[Do[{m[[i,j]]:=v2;mb[[i,j]]=1;},{j,xl2,xr2}],{i,yd2,yu2}]
Do[Do[{m[[i,j]]:=v3;mb[[i,j]]=1;},{j,xl3,xr3}],{i,yd3,yu3}]
Do[Do[{m[[i,j]]:=v4;mb[[i,j]]=1;},{j,xl4,xr4}],{i,yd4,yu4}]\
\>", "Input",
  CellLabel->"In[2]:=",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}},
  Background->GrayLevel[0.849989]],

Cell[CellGroupData[{

Cell["\<\
nz1=nz/2;ns1=ns/2;u1=.;m1=.;
m1=Array[u1,{nz1,ns1}];a1=Array[u1,{nz1,ns1}];
Do[Do[a1[[i,j]]=u1[[i,j]],{j,1,ns1}],{i,1,nz1}]
Do[Do[
m1[[i,j]]:=Evaluate[0.25(a1[[i-1,j]]+a1[[i+1,j]]+a1[[i,j-1]]+a1[[i,j+1]])],
{j,2,ns1-1}],{i,2,nz1-1}];
Do[m1[[1,j]]:=0.,{j,1,ns1}];
Do[m1[[nz1,j]]:=0.,{j,1,ns1}];
Do[m1[[i,1]]:=0.,{i,1,nz1}];
Do[m1[[i,ns1]]:=0.,{i,1,nz1}];
(* guess for coordinates:old/2;mb is used to identify location of conductors \
*)
Do[Do[If[mb[[2i,2j]]==1,m1[[i,j]]=m[[2i,2j]]],{i,nz1}],
{j,ns1}]
u1=Table[0.,{i,1,nz1},{j,1,ns1}];
Timing[Do[{u1=m1;
If[Mod[i,500]==0,
Print[i,\" residual error:\",Max[Flatten[Abs[u1-m1]]]]]},
{i,1,2000}]]\
\>", "Input",
  CellLabel->"In[23]:=",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}},
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(Part::"partd" \(\(:\)\(\ \)\) 
      "Part specification \!\(u1 \[LeftDoubleBracket] \(\(1, 1\)\) \
\[RightDoubleBracket]\) is longer than depth of object."\)], "Message",
  CellLabel->"From In[23]:="],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Part :: \"partd\"\) will be suppressed during \
this calculation."\)], "Message",
  CellLabel->"From In[23]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p = 
        ListInterpolation[Transpose[u1], 
          InterpolationOrder \[Rule] 1];\)\), "\n", 
    \(Plot3D[p[x, y], {x, 1, ns1}, {y, 1, nz1}, 
      PlotRange \[Rule] All]\)}], "Input",
  CellLabel->"In[35]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P00022A000`40O003h00OogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomoolmoo`L000Yoo`@007ioo`00ogooogoocgoo1`0027oo2000O7oo003oOoooOooBOol2000:Ool2
0004Ool2001lOol00?mooomoom9oo`8000Uoo`8000Ioo`8007]oo`00ogooogoodWoo0P002Goo0P00
1Woo0P00Ngoo003oOoooOoo:Ool<0006Ool20008Ool2001jOol00?mooomoolYoo``000Ioo`8000Qo
o`8007Yoo`00ogooogoobWoo0P001Woo0P0000=oo`00Ool01Goo0P0027oo0P00NWoo003oOoooOoo;
Ool20005Ool20008Ool20008Ool2001jOol00?mooomool]oo`<000Aoo`8000Qoo`8000Qoo`8007Yo
o`00ogooogooc7oo0P0017oo0P0027oo0P0027oo0P00NWoo003oOoooOoo=Ool20003Ool20008Ool2
0008Ool2001jOol00?mooomooleoo`<0009oo`8000Qoo`8000Qoo`8007Yoo`00ogooogoocWoo0P00
0Woo0P002Goo0P001Woo0P00Ngoo003oOoooOoo?Ool200000goo00000009Ool20006Ool2001kOol0
0?mooomoom1oo`@000Yoo`8000Aoo`8007aoo`00ogooogood7oo10002Woo2000O7oo003oOoooOooA
Ool3000<Ool4001nOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
7Woo1@003Woo1000ogoo;Woo003oOoooOolLOol9000:Ool8003oOol/Ool00?mooomooa]oo`@000Ao
o`<000Uoo`8000Aoo`800?moobaoo`00ogooogoo6goo0P001goo0`001goo0P001Woo0P00ogoo:goo
003oOoooOolUOol20007Ool20006Ool2003oOol[Ool00?mooomoobEoo`8000Ioo`8000Qoo`800?mo
obYoo`00ogooogoo9Goo0P001Woo0P0027oo0P00ogoo:Woo003oOoooOolTOol30006Ool20008Ool2
003oOolZOol00?mooomoob=oo`<000Moo`8000Qoo`8009eoo`D008Moo`00ogooogoo87oo1@0027oo
0P0027oo0P00UWoo1`0017oo00<007ooOol0QGoo003oOoooOolPOol40009Ool20008Ool2002?Ool7
000;Ool20026Ool00?mooomoob=oo`8000Qoo`8000Qoo`8008Qoo`L0019oo`8008Ioo`00ogooogoo
97oo0P001goo0P0027oo0P00PGoo1`006Goo00<007oo0000QGoo003oOoooOolTOol20008Ool20006
Ool2001jOol8000POol00`00Ool00025Ool00?mooomooaaoo`8000Ioo`8000Qoo`8000Ioo`8007=o
o`L000Aoo`03001oogoo025oo`04001oogoo0024Ool00?mooomooaaoo`<000Aoo`<000Uoo`8000Ao
o`8006eoo`L000]oo`03001oogoo025oo`04001oogoo0024Ool00?mooomooaeoo`P000Yoo`P006Io
o`L0019oo`03001oogoo025oo`05001oogooOol00023Ool00?mooomooaioo`D000ioo`@0065oo`L0
03eoo`05001oogooOol00023Ool00?mooomoohioo`P004Aoo`03001oogoo009oo`03001oogoo081o
o`00ogooogooQgoo1`001Goo00<007ooOol0A7oo00<007ooOol00Woo00<007ooOol0P7oo003oOooo
Oon0Ool7000<Ool00`00Oomoo`14Ool00`00Oomoo`03Ool00`00Oomoo`1oOol00?mooomoogUoo`L0
01=oo`03001oogoo04Aoo`03001oogoo00Aoo`03001oogoo07ioo`00ogooogooLWoo1`00HGoo00<0
07ooOol017oo00<007ooOol0OWoo003oOomdOol<000;Ool4003JOol8001YOol00`00Oomoo`04Ool0
0`00Oomoo`1mOol00?moogAoo``000Uoo`P00=5oo`L000Ioo`03001oogoo06Qoo`03001oogoo00Ao
o`03001oogoo07eoo`00ogooMGoo0`001Woo0P002Goo0P0017oo0P00bWoo1`003Goo00<007ooOol0
J7oo00<007ooOol01Goo00<007ooOol0O7oo003oOomfOol3000?Ool20006Ool20032Ool7000DOol0
0`00Oomoo`1XOol00`00Oomoo`05Ool00`00Oomoo`1lOol00?moogMoo`<000ioo`8000Ioo`800;]o
o`L008Ioo`03001oogoo00Ioo`03001oogoo07]oo`00ogooN7oo0`0037oo0P0027oo0P00/Woo2000
SGoo00<007ooOol01Woo00<007ooOol0Ngoo003oOomiOol3000;Ool20008Ool2002[Ool70007Ool0
0`00Oomoo`2;Ool00`00Oomoo`07Ool00`00Oomoo`1jOol00?moogYoo`<000Yoo`8000Qoo`800:Ao
o`L000ioo`03001oogoo08]oo`03001oogoo00Moo`03001oogoo07Yoo`00ogooNgoo0`002Goo0P00
27oo0P00WGoo1`005Goo00<007ooOol0Rgoo00<007ooOol027oo00<007ooOol0NGoo003oOomlOol3
0008Ool20008Ool2002EOol8002ZOol00`00Oomoo`08Ool00`00Oomoo`1iOol00?moogeoo`8000Qo
o`8000Qoo`8008ioo`L0009oo`03001oogoo0:eoo`03001oogoo00Uoo`03001oogoo07Qoo`00ogoo
OWoo0P001goo0P0027oo0P00Qgoo1`002Goo00<007ooOol0[Goo00<007ooOol02Goo00<007ooOol0
N7oo003oOomnOol20007Ool20008Ool20020Ool7000@Ool00`00Oomoo`2]Ool00`00Oomoo`0:Ool0
0`00Oomoo`1gOol00?moogEoo`8000Moo`8000Qoo`8000Ioo`8007Yoo`L001Moo`03001oogoo0:eo
o`03001oogoo00Yoo`03001oogoo07Moo`00ogooMGoo0`001Woo0P0027oo0P001Woo0P00LWoo2000
7Woo00<007ooOol0[Goo00<007ooOol02goo00<007ooOol0MWoo003oOomeOol40004Ool2000:Ool2
0004Ool2001/Ool70004Ool00`00Oomoo`0OOol00`00Oomoo`2]Ool00`00Oomoo`0;Ool00`00Oomo
o`1fOol00?moogIoo`P000]oo`P006Eoo`L000]oo`03001oogoo0<moo`03001oogoo00aoo`03001o
ogoo07Eoo`00ogooN7oo1@003Woo1000H7oo1`004Woo00<007ooOol0cgoo00<007ooOol037oo00<0
07ooOol0MGoo003oOooXOol7003[Ool00`00Oomoo`0=Ool00`00Oomoo`1dOol00?moon1oo`P00?9o
o`03001oogoo00eoo`03001oogoo07Aoo`00ogoofGoo1`001Woo00<007ooOol0lGoo00<007ooOol0
3Woo00<007ooOol0Lgoo003oOooBOol7000=Ool00`00Oomoo`3aOol00`00Oomoo`0>Ool00`00Oomo
o`1cOol00=Uoo`X000]oo`@00=Qoo`L001Aoo`03001oogoo0?5oo`03001oogoo00moo`03001oogoo
079oo`00fGoo2P002Goo2000cgoo1`00ogoo47oo00<007ooOol047oo00<007ooOol0LGoo003MOol2
000=Ool20004Ool20037Ool800000goo001oo`3oOolDOol00`00Oomoo`0@Ool00`00Oomoo`1aOol0
0=eoo`8000aoo`8000Ioo`800;moo`L000Uoo`03001oogoo0?mooa=oo`03001oogoo015oo`03001o
ogoo071oo`00gGoo0P0037oo0P001Woo0P00^7oo1`0047oo00<007ooOol0ogoo4goo00<007ooOol0
4Goo00<007ooOol0L7oo003MOol2000;Ool20008Ool2002`Ool7000GOol00`00Oomoo`3oOolDOol0
0`00Oomoo`0AOol00`00Oomoo`1_Ool00=eoo`8000]oo`8000Qoo`800:Uoo`L00?moocEoo`03001o
ogoo015oo`03001oogoo06moo`00gGoo0P002goo0P0027oo0P00XGoo200017oo00<007ooOol0ogoo
=Goo00<007ooOol04Woo00<007ooOol0KWoo003MOol2000;Ool20008Ool2002JOol7000<Ool00`00
Oomoo`3oOoleOol00`00Oomoo`0BOol00`00Oomoo`1^Ool00=eoo`8000]oo`8000Qoo`8009=oo`L0
01=oo`03001oogoo0?moocEoo`03001oogoo01=oo`03001oogoo06eoo`00gGoo0P002goo0P0027oo
0P00S7oo1`00ogooDWoo00<007ooOol04goo00<007ooOol0KGoo003MOol2000;Ool20008Ool20025
Ool700000goo001oo`3oOomFOol00`00Oomoo`0DOol00`00Oomoo`1/Ool00=eoo`8000]oo`8000Qo
o`8007eoo`P000Qoo`03001oogoo0?mooeEoo`03001oogoo01Aoo`03001oogoo06aoo`00gGoo0P00
37oo0P001Woo0P00Mgoo1`0047oo00<007ooOol0ogooEGoo00<007ooOol05Goo00<007ooOol0Jgoo
003MOol2000<Ool20006Ool2001`Ool7000GOol00`00Oomoo`3oOomEOol00`00Oomoo`0EOol00`00
Oomoo`1[Ool00=Uoo`<00003Ool0000000eoo`8000Aoo`8006Yoo`L001ioo`03001oogoo0?mooeEo
o`03001oogoo01Ioo`03001oogoo06Yoo`00fGoo1P003Goo2000Hgoo1`001Goo00<007ooOol07Goo
00<007ooOol0ogooEGoo00<007ooOol05Woo00<007ooOol0JWoo003LOol3000?Ool4001MOol8000<
Ool00`00Oomoo`3oOomeOol00`00Oomoo`0GOol00`00Oomoo`1YOol00?moodUoo`L001Aoo`03001o
ogoo0?moogEoo`03001oogoo01Moo`03001oogoo06Uoo`00ogoo@Woo1`00ogooTgoo00<007ooOol0
67oo00<007ooOol0J7oo003oOolkOol70002Ool00`00Oomoo`3oOonEOol00`00Oomoo`0HOol00`00
Oomoo`1XOol00?moocAoo`L000Uoo`03001oogoo0?mooiEoo`03001oogoo01Uoo`03001oogoo06Mo
o`00ogoo;7oo200047oo00<007ooOol0ogooUGoo00<007ooOol06Goo00<007ooOol0Igoo003oOolU
Ool7000HOol00`00Oomoo`3oOonEOol00`00Oomoo`0JOol00`00Oomoo`1VOol00?mooaioo`L00?mo
okMoo`03001oogoo01Yoo`03001oogoo06Ioo`00ogoo5goo1`001Woo00<007ooOol0ogoo]Goo00<0
07ooOol06goo00<007ooOol0IGoo003oOol@Ool7000=Ool00`00Oomoo`3oOoneOol00`00Oomoo`0L
Ool00`00Oomoo`1TOol00?moo`Qoo`P001Aoo`03001oogoo0?mookEoo`03001oogoo01aoo`03001o
ogoo06Aoo`00ogoo0Goo1`00ogooe7oo00<007ooOol07Goo00<007ooOol0Hgoo003iOol70004Ool0
0`00Oomoo`3oOooDOol00`00Oomoo`0MOol00`00Oomoo`1SOol00?9oo`L000]oo`03001oogoo0?mo
omAoo`03001oogoo01ioo`03001oogoo069oo`00jWoo20004Woo00<007ooOol0ogooe7oo00<007oo
Ool07Woo00<007ooOol0HWoo003SOol7003oOoobOol00`00Oomoo`0NOol00`00Oomoo`1QOol00=ao
o`L0009oo`03001oogoo0?moooAoo`03001oogoo01ioo`03001oogoo065oo`00eGoo1`002Goo00<0
07ooOol0ogoom7oo00<007ooOol07goo00<007ooOol0H7oo003>Ool7000@Ool00`00Oomoo`3oOood
Ool00`00Oomoo`0OOol00`00Oomoo`1POol00<Ioo`P001Moo`03001oogoo0?moooAoo`03001oogoo
021oo`03001oogoo05moo`00_goo1`0000=oo`00Ool077oo00<007ooOol0ogoom7oo00<007ooOol0
87oo00<007ooOol0Ggoo002hOol70008Ool00`00Oomoo`0KOol00`00Oomoo`3oOoodOol00`00Oomo
o`0QOol00`00Oomoo`1NOol00;5oo`L000moo`03001oogoo0?mooomooa=oo`03001oogoo025oo`03
001oogoo05ioo`00ZWoo1`005Woo00<007ooOol0ogooogoo4goo00<007ooOol08Woo00<007ooOol0
GGoo002ROol8003oOoooOolcOol00`00Oomoo`0ROol00`00Oomoo`1MOol009]oo`L000Moo`03001o
ogoo0?mooomooc5oo`03001oogoo02=oo`03001oogoo05aoo`00U7oo1`003Goo00<007ooOol0ogoo
ogoo<Woo00<007ooOol08goo00<007ooOol0G7oo002=Ool7000DOol00`00Oomoo`3oOoooOolbOol0
0`00Oomoo`0TOol00`00Oomoo`1KOol008Ioo`L00?mooomooe1oo`03001oogoo02Aoo`03001oogoo
05]oo`00OWoo20001Goo00<007ooOol0ogooogooCgoo00<007ooOol09Goo00<007ooOol0FWoo001g
Ool7000<Ool00`00Oomoo`3oOoooOom@Ool00`00Oomoo`0UOol00`00Oomoo`1JOol0071oo`L001=o
o`03001oogoo0?mooomooe1oo`03001oogoo02Ioo`03001oogoo05Uoo`00JGoo1`00ogooogooKGoo
00<007ooOol09Woo00<007ooOol0FGoo001ROol70004Ool00`00Oomoo`3oOoooOom]Ool00`00Oomo
o`0WOol00`00Oomoo`1HOol005ioo`@000]oo`03001oogoo0?mooomoofeoo`03001oogoo02Qoo`03
001oogoo05Moo`009Goo10003Woo0`002Woo30003Woo00<007oo000037oo00<007ooOol0ogooogoo
KGoo00<007ooOol0:7oo00<007ooOol0Egoo000SOol8000;Ool50009Ool<000>Ool01000Oomoo`00
ogooogooNgoo00<007ooOol0:Goo00<007ooOol0EWoo000SOol20004Ool2000;Ool5000:Ool30006
Ool2000>Ool00`00Oomoo`03003oOoooOomiOol00`00Oomoo`0YOol00`00Oomoo`1FOol0029oo`80
00Ioo`8000Yoo`D000]oo`<001Eoo`<000=oo`03001oogoo0?mooomoogIoo`03001oogoo02Yoo`03
001oogoo05Eoo`008Woo0P001Woo0P002goo0`003Goo0`0057oo00<007ooOol017oo00<007ooOol0
ogooogooMGoo00<007ooOol0:Woo00<007ooOol0EGoo000>Ool=0006Ool20008Ool2000KOol3000C
Ool00`00Oomoo`05Ool2003oOoooOomeOol00`00Oomoo`0[Ool00`00Oomoo`1DOol000ioo`d000Io
o`8000Qoo`8001aoo`<0019oo`03001oogoo00Moo`03001oogoo0?mooomoog9oo`03001oogoo02]o
o`03001oogoo05Aoo`003Woo3@001Woo0P0027oo0P007Goo0`004Goo00<007ooOol027oo00<007oo
Ool0ogooogooLGoo00<007ooOol0;7oo00<007ooOol0Dgoo000QOol20008Ool2000NOol3000?Ool0
0`00Oomoo`0:Ool2003oOoooOombOol00`00Oomoo`0[Ool00`00Oomoo`1COol0025oo`8000Qoo`80
01moo`<000ioo`03001oogoo00aoo`03001oogoo0?mooomoofmoo`03001oogoo02aoo`03001oogoo
059oo`008Goo0P0027oo0P0087oo0P003Woo00<007ooOol03Goo0P00ogooogooKgoo00<007ooOol0
;7oo00<007ooOol0DWoo000QOol20008Ool2000QOol2000=Ool00`00Oomoo`0?Ool00`00Oomoo`3o
OoooOom/Ool00`00Oomoo`0]Ool00`00Oomoo`1AOol0025oo`8000Qoo`80025oo`8000eoo`03001o
ogoo011oo`03001oogoo0?mooomoof]oo`03001oogoo02eoo`03001oogoo055oo`008Woo0P001Woo
0P006Goo0P001goo0P003Goo00<007ooOol04Goo0P00ogooogooJgoo00<007ooOol0;Woo00<007oo
Ool0D7oo000ROol20006Ool2000IOol30006Ool2000=Ool00`00Ool00002000AOol00`00Oomoo`3o
OoooOomXOol00`00Oomoo`0^Ool00`00Oomoo`1@Ool002=oo`8000Aoo`8001Yoo`@000Aoo`8000io
o`8001Eoo`03001oogoo0?mooomoofMoo`03001oogoo02moo`03001oogoo04moo`008goo20006goo
20003goo00<007ooOol05Goo0P00ogooogooIgoo00<007ooOol0;goo00<007ooOol0Cgoo000UOol4
000OOol5000@Ool00`00Oomoo`0GOol00`00Oomoo`3oOoooOomTOol00`00Oomoo`0`Ool00`00Oomo
o`1>Ool005eoo`03001oogoo01Qoo`03001oogoo0?mooomoof=oo`03001oogoo031oo`03001oogoo
04ioo`00GGoo00<007ooOol06Goo0P00ogooogooHgoo00<007ooOol0<Goo00<007ooOol0CGoo001M
Ool00`00Oomoo`0KOol00`00Oomoo`3oOoooOomPOol00`00Oomoo`0aOol00`00Oomoo`1=Ool005eo
o`03001oogoo01aoo`03001oogoo0?mooomooemoo`03001oogoo039oo`03001oogoo04aoo`00GGoo
00<007ooOol07Goo0P00ogooogooGgoo00<007ooOol0<goo00<007ooOol0Bgoo001LOol00`00Oomo
o`0POol00`00Oomoo`3oOoooOomLOol00`00Oomoo`0cOol00`00Oomoo`1;Ool005aoo`03001oogoo
025oo`03001oogoo0?mooomooe]oo`03001oogoo03Aoo`03001oogoo04Yoo`00G7oo00<007ooOol0
8Woo0P00ogooogooFgoo00<007ooOol0=7oo00<007ooOol0BWoo001LOol5000ROol00`00Oomoo`3o
OoooOomHOol00`00Oomoo`0eOol00`00Oomoo`19Ool005aoo`03001oogoo02Eoo`800?mooomooeQo
o`03001oogoo03Eoo`03001oogoo04Uoo`00G7oo00<007ooOol09goo00<007ooOol0ogooogooEGoo
00<007ooOol0=Woo00<007ooOol0B7oo001LOol00`00Oomoo`0XOol00`00Oomoo`3oOoooOomDOol0
0`00Oomoo`0fOol00`00Oomoo`18Ool005aoo`03001oogoo02Uoo`800?mooomooeAoo`03001oogoo
03Moo`03001oogoo04Moo`00G7oo00<007ooOol0:goo00<007ooOol0ogooogooDGoo00<007ooOol0
=goo00<007ooOol0Agoo001LOol00`00Oomoo`0/Ool00`00Oomoo`3oOoooOom@Ool00`00Oomoo`0h
Ool00`00Oomoo`16Ool005aoo`03001oogoo02eoo`800?mooomooe1oo`03001oogoo03Qoo`03001o
ogoo04Ioo`00G7oo00<007ooOol0;goo00<007ooOol0ogooogooCGoo00<007ooOol0>Goo00<007oo
Ool0AGoo001LOol00`00Oomoo`0`Ool00`00Oomoo`3oOoooOom=Ool00`00Oomoo`0hOol00`00Oomo
o`15Ool005aoo`03001oogoo035oo`800?mooomoodeoo`03001oogoo03Uoo`03001oogoo04Aoo`00
G7oo00@007oo0000039oo`03001oogoo0?mooomoodYoo`03001oogoo03Uoo`03001oogoo04Aoo`00
G7oo0P00=Goo00<007ooOol0ogooogooBGoo00<007ooOol0>Woo00<007ooOol0@goo001KOol00`00
Oomoo`0fOol2003oOoooOom9Ool00`00Oomoo`0jOol00`00Oomoo`13Ool005]oo`03001oogoo03Qo
o`03001oogoo0?mooomoodIoo`03001oogoo03]oo`03001oogoo049oo`00Fgoo00<007ooOol0>Goo
00<007ooOol0Cgoo0`00ogoolWoo00<007ooOol0>goo00<007ooOol0@Woo001KOol00`00Oomoo`0j
Ool2001?Ool00`00CDi=CP05003oOoo]Ool00`00Oomoo`0lOol00`00Oomoo`11Ool005]oo`03001o
ogoo03aoo`03001oogoo04]oo`8000M=CPD00?moonQoo`03001oogoo03aoo`03001oogoo045oo`00
Fgoo00<007ooOol0?Goo00<007ooOol0BGoo0P003De>1@00ogooggoo1@00?goo00<007ooOol0@7oo
001KOol00`00Oomoo`0nOol20018Ool00`000080000BCDh3003oOooCOol90004?el00`00Oomoo`0m
Ool00`00Oomoo`10Ool005]oo`03001oogoo041oo`03001oogoo04Aoo`0400000P02000CCDh01000
EFd00000ogoobGoo20003CmO0P00?goo00<007ooOol0?goo001KOol00`00Oomoo`11Ool20013Ool0
100000800P004de>00<005E]EFd00UE]0P00ogoo_goo20005CmO0P00@7oo00<007ooOol0?Woo001K
Ool00`00Oomoo`13Ool00`00Oomoo`10Ool0100000800P004de>00<005E]EFd015E]0P00ogoo]Goo
200013mO00<003mO?el05SmO00<003mO0000?goo00<007ooOol0?Woo001KOol01000Ool00000@goo
00<007ooOol0?Woo00D0000200800P0001==CP03001EKEE]00IEK@<00?moojYoo`P000doG`03000o
GcmO01DoG`04000oGcmO000oOol00`00Oomoo`0mOol005]oo`8004Ioo`8003eoo`0500000P020080
000CCDh00`00EFeEK@0:EFd2003oOonPOol8000F?el00`00?eloG`0D?el01000?eloG`00?goo00<0
07ooOol0?Goo001KOol00`00Oomoo`17Ool00`00Oomoo`0iOol00`0000800P0200800`00CDi=CP0A
CDh00`00EFeEK@0<EFd2003oOonEOol90004?el00`00?eloG`0G?el00`00?eloG`0D?el01@00?elo
GcmO0000?goo00<007ooOol0?7oo001KOol00`00Oomoo`18Ool00`00Oomoo`0gOol00`0000800P03
00800`00CDi=CP0ACDh00`00EFeEK@0>EFd2003oOon;Ool8000>?el00`00?eloG`0G?el00`00?elo
G`0C?el01@00?eloGcmO0000?goo00<007ooOol0?7oo001KOol00`00Oomoo`19Ool2000fOol00`00
00800P0300800`00CDi=CP0ACDh00`00EFeEK@0AEFd2003oOon1Ool8000G?el00`00?eloG`0G?el0
0`00?eloG`0B?el6000oOol00`00Oomoo`0kOol005Yoo`03001oogoo04aoo`03001oogoo03=oo`03
00000P0200<00P03001=CTe>015=CP03001EKEE]01=EK@800?moogMoo`P000@oG`03000oGcmO01To
G`03000oGcmO01HoG`03000oGcmO00/oG`P000@o?`03001oogoo03eoo`03001oogoo03]oo`00FWoo
00<007ooOol0CGoo00<007ooOol0<Goo00<000020080100200<004e>CDh044e>00<005E]EFd055E]
00<005D[00000P00ogooK7oo20003CmO00<003mO?el063mO00<003mO?el05cmO00<003mO?el00SmO
20001clo00<003lo?cl00clo00<007ooOol0?Goo00<007ooOol0>Woo001JOol00`00Oomoo`1>Ool2
000`Ool00`0000800P0400800`00CDi=CP0ACDh00`00EFeEK@0CEFd00`00EB]E:`03EB/2003oOomR
Ool8000F?el00`00?eloG`0H?el00`00?eloG`0A?el:000??cl00`00?clo?`04?cl00`00Oomoo`0l
Ool00`00Oomoo`0jOol005Yoo`03001oogoo051oo`03001oogoo02aoo`0300000P0200D00P03001=
CTe>015=CP03001EKEE]01=EK@03001E:eD[00EE:`<00?mooeMoo`P000DoG`03000oGcmO01LoG`03
000oGcmO01PoG`03000oGcmO00@oG``000Ho?`03000o?clo010o?`03000o?clo00@o?`03001oogoo
03eoo`03001oogoo03Uoo`008Goo10003Woo0`0037oo2P003Woo00<007ooOol0DGoo00<007ooOol0
:Woo00<0000200801P0200<004e>CDh044e>00<005E]EFd04eE]00<005D[EB/02ED[0P00ogooCGoo
20003SmO00<003mO?el05SmO00<003mO?el05CmO2P004clo00<003lo?cl03clo00<003lo?cl01Clo
00<007ooOol0?7oo00<007ooOol0>Goo000OOol8000;Ool5000;Ool:000>Ool00`00Oomoo`1BOol2
000YOol00`0000800P0600800`00CDi=CP0ACDh00`00EFeEK@0CEFd00`00EB]E:`0;EB/3003oOom0
Ool:000G?el00`00?eloG`0F?el00`00?eloG`0;?el90004?cl00`00?clo?`0G?cl00`00?clo?`0>
?cl00`00?clo?`05?cl00`00Oomoo`0mOol00`00Oomoo`0hOol001moo`8000Aoo`8000]oo`D000mo
o`80019oo`03001oogoo05Aoo`03001oogoo02Ioo`0300000P0200H00P03001=CTe>015=CP03001E
KEE]019EK@03001E:eD[00mE:`800?mooc=oo`/000LkG`03000oGcmO01PoG`03000oGcmO01HoG`03
000oGcmO008oG`P000ho?`03000o?clo01Ho?`03000o?clo00ho?`03000o?clo00Ho?`03001oogoo
03aoo`03001oogoo03Qoo`007Woo0P001Woo0P002Woo1@003goo0P004Woo1P00DWoo00<007ooOol0
97oo00<0000200801`0200<004e>CDh044e>00<005E]EFd04eE]00<005D[EB/04ED[0`00ogoo9Woo
2P004c]O00<003mO?el063mO00<003mO?el043mO2P005clo00<003lo?cl05Slo00<003lo?cl03Clo
00<003lo?cl00clo1@00?Woo00<007ooOol0=goo000NOol20006Ool2000;Ool3000@Ool2000BOol0
0`00Oomoo`1FOol2000SOol00`0000800P0700800`00CDi=CP0ACDh00`00EFeEK@0BEFd00`00EB]E
:`0EEB/2003oOolLOol80004>el00`00>elkG`0G>el00`00?eloG`0H?el00`00?eloG`04?el;0006
>cl00`00?clo?`0H?cl00`00?clo?`0F?cl00`00?clo?`0;?cl80004?cl00`00Oomoo`0lOol00`00
Oomoo`0gOol000Yoo`d000Ioo`8000Qoo`8001eoo`80019oo`03001oogoo05Qoo`03001oogoo01mo
o`0300000P0200P00P03001=CTe>015=CP03001EKEE]019EK@03001E:eD[01EE:`03001@j0000080
0?mooa5oo`P000dkG`03000kGc]O01LkG`03000oGcmO01@oG`X0018k?`03000o?clo01Po?`03000o
?clo01Ho?`03000o?clo008o?`P000<o?`03000o?clo00Lo?`03001oogoo03aoo`03001oogoo03Io
o`002Woo3@001Woo0P0027oo0P007Goo0P004Woo00<007ooOol0FGoo0P007Woo00<0000200802@02
00<004e>CDh044e>00<005E]EFd04UE]00<005D[EB/05ED[00<0053XD>P00e3X0`00ogoo1Woo2000
5S]O00<003]O>el05c]O00<003mO?el02cmO200013/o00<003/o>cl05S/o00<003lo?cl05clo00<0
03lo?cl04Clo2P002clo00<003lo?cl01clo00<007ooOol0?7oo00<007ooOol0=Woo000:Ool=0006
Ool20008Ool2000MOol2000BOol00`00Oomoo`1KOol00`00Oomoo`0JOol00`0000800P0900800`00
CDi=CP0ACDh00`00EFeEK@0BEFd00`00EB]E:`0DEB/00`00D>Q@j007D>P3003jOol80005>el00`00
>elkG`0G>el00`00>elkG`0G>el00`00?eloG`02?el8000=>cl00`00>clk?`0F>cl00`00?clo?`0G
?cl00`00?clo?`04?cl<0006>cl00`00?clo?`0<?cl00`00?clo?`08?cl00`00Oomoo`0lOol00`00
Oomoo`0eOol001eoo`8000Qoo`8001eoo`80019oo`03001oogoo05aoo`03001oogoo01Uoo`030000
0P0200T00P03001=CTe>011=CP03001EKEE]019EK@03001E:eD[01EE:`03001@j53X00Y@j0800?5o
o`L000hkG`03000kGc]O01LkG`03000kGc]O014kG`X001Hk?`03000k?c/o01Hk?`03000o?clo014o
?``001<k?`03000o?clo00/o?`03000o?clo00To?`03001oogoo03]oo`03001oogoo03Eoo`007Goo
0P0027oo0P007Goo0P004Woo00<007ooOol0GGoo0P0067oo00<0000200802P0200<004e>CDh044e>
00<005E]EFd04UE]00<005D[EB/055D[00<0053XD>P03E3X0`00iWoo20005S]O00<003]O>el05c]O
00<003]O>el013]O30001c]O00<003/o>cl05c/o00<003/o>cl05S/o00<003lo?cl013lo30001S/o
00<003/o>cl05c/o00<003lo?cl02Slo00<003lo?cl02Clo00<007ooOol0?7oo00<007ooOol0=7oo
000MOol20008Ool2000MOol2000BOol00`00Oomoo`1OOol00`00Oomoo`0DOol2000;00800`00CDi=
CP0ACDh00`00EFeEK@0AEFd00`00EB]E:`0DEB/00`00D>Q@j00AD>P3003KOol80006>el00`00>elk
G`0F>el00`00>elkG`0C>el:000D>el00`00>clk?`0G>cl00`00>clk?`0@>cl<000C>cl00`00>clk
?`0F>cl00`00?clo?`0:?cl00`00?clo?`0:?cl00`00Oomoo`0kOol00`00Oomoo`0dOol001eoo`80
00Qoo`8001eoo`80019oo`03001oogoo061oo`03001oogoo01=oo`0300000P0200X00P03001=CTe>
011=CP03001EKEE]019EK@03001E:eD[01AE:`03001@j53X01A@j0<00=1oo`P000lkG`03000kGc]O
01HkG`03000kGc]O00XkG`P000DgG`03000kGc]O01LkG`03000k?c/o01Lk?`03000k?c/o00@k?`/0
00Hg?`03000k?c/o01Lk?`03000k?c/o01Hk?`03000o?clo00To?`03000o?clo00Xo?`03001oogoo
03aoo`03001oogoo03=oo`007Goo0P0027oo0P007Goo0P004Goo00<007ooOol0HWoo0P004Woo0P00
300200<004e>CDh044e>00<005E]EFd04EE]00<005D[EB/055D[00<0053XD>P05E3X00<004bUC:D0
0`00aGoo200063]O00<003]O>el05S]O00<003]O>el00S]O1`003SMO00<003]O>el05c]O00<003/o
>cl04C/o30004SLo00<003/o>cl05c/o00<003/o>cl05C/o00<003lo?cl02Clo00<003lo?cl01Clo
1`00?Goo00<007ooOol0<goo000NOol20006Ool2000NOol2000AOol00`00Oomoo`1TOol00`00Oomo
o`0>Ool00`00Gk40000;00800`00CDi=CP0ACDh00`00EFeEK@0AEFd00`00EB]E:`0CEB/00`00D>Q@
j00ED>P00`00C:E<Y@04C:D3002jOol80006>el00`00>elkG`0H>el00`00>elkG`0@>el:000F=el0
0`00>elkG`0G>el00`00>clk?`04>cl<0006=cl00`00=clg?`0F=cl00`00>clk?`0G>cl00`00>clk
?`0E>cl00`00?clo?`04?cl<0006>cl00`00Oomoo`0lOol00`00Oomoo`0bOol001ioo`8000Ioo`80
01ioo`80015oo`03001oogoo06Eoo`03001oogoo00eoo`8000`00P03001=CTe>00e=CPT000iEK@03
001E:eD[01AE:`03001@j53X01A@j003001<YDbU00Q<Y@@00:moo`L000lkG`03000kGc]O01PkG`03
000kGc]O00@kG`/000Pg?`03000gGcMO01HgG`03000kGc]O01<kG`X001<g?`03000g?cLo01Hg?`03
000k?c/o01Lk?`03000k?c/o00Xk?a4000@k?`03000k?c/o00`k?`03001oogoo03aoo`03001oogoo
035oo`007goo0P0017oo0P006goo0`0000=oo`0000004Goo1@00I7oo0P0037oo00<005na00003002
00<004e>CDh01Te>1`000dT_00<004e?CDl00de?2@001EE]00<005D[EB/04eD[00<0053XD>P0553X
00<004bUC:D03DbU0`00XWoo2P005c]O0P005C]O2P0053Lo00<003MO=el05SMO00<003]O>el02S]O
20001C<o00<003Lo=cl05SLo00<003Lo=cl05SLo00<003/o>cl04C/o4P002cLo00<003/o>cl01c/o
00<003/o>cl03C/o00<007ooOol0>goo00<007ooOol0<Goo000OOol8000KOol6000AOol00`00Oomo
o`1XOol00`00Oomoo`09Ool2000<00800`00CDi=CP07000:BBl00`00CDm=C`0<CDl8000BEB/00`00
D>Q@j00DD>P00`00C:E<Y@0AC:D3002DOol;0008=el00`00>elkG`0H>el00`00>elkG`0:>el80006
=cl00`00=clg?`0F=cl00`00=elgG`0F=el00`00>elkG`02>el7000><cl00`00=clg?`0F=cl00`00
=clg?`0F=cl00`00>clk?`04>cl<0006=cl00`00=clg?`0E=cl00`00>clk?`06>cl00`00>clk?`0=
>cl00`00Oomoo`0lOol00`00Oomoo`0`Ool0025oo`@0021oo`<0015oo`03001oogoo06Uoo`03001o
ogoo00Moo`03001O/@0000/00P@00119;`03001=Cde?015=C`04001=CTe>CDh7000;EB/00`00D>Q@
j00CD>P00`00C:E<Y@0EC:D40026Ool:000D=el2000I>el00`00>elkG`02>el7000?=cl00`00=clg
?`0F=cl00`00=elgG`0@=el:000F<cl00`00=clg?`0F=cl00`00=clg?`0@=cl<000C=cl00`00=clg
?`0E=cl00`00>clk?`05>cl00`00>clk?`0>>cl00`00Oomoo`0kOol00`00Oomoo`0`Ool005Uoo`03
001oogoo06Yoo`8000Ioo`03001O/@0000/00P03000dJ`000199;`03001=Cde?015=C`03001=CTe>
00Q=CPL000=E:`03001@j53X01A@j003001<YDbU01A<Y@03001484@P009480@007]oo`L000HgG`03
000gGcMO01LgG`80018kG`X001Lg?`03000g?cLo01Hg?`03000gGcMO00@gG`/000Pc?`03000c?c<o
01Hc?`03000g?cLo01Hg?`03000g?cLo00@g?`/000Lc?`03000g?cLo01Hg?`03000g?cLo01Dg?`03
000k?c/o00@k?`03000k?c/o00hk?`03001oogoo03aoo`03001oogoo02moo`00FGoo00<007ooOol0
K7oo00<007ooOol00goo00<005na00002P0200@003A[=6/00199;`03001=Cde?011=C`03001=CTe>
011=CPH001=@j003001<YDbU01A<Y@03001484@P00M480@0071oo`L000hgG`03000gGcMO01PgG`03
000kGc]O00@kG`/000Pc?`03000g?cLo01Lg?`03000g?cLo010g?``001@c?`03000c?c<o01Hc?`03
000g?cLo00Xg?a8001<c?`03000g?cLo01Hg?`03000g?cLo01Dg?`03000k?c/o00<k?`03000k?c/o
00lk?`03001oogoo03]oo`03001oogoo02moo`00FGoo00<007ooOol0KGoo00L007ooOomoo`00Gk40
000900820002=6/00`00BBm9;`0@BBl00`00CDm=C`0ACDl00`00CDi=CP0BCDh01000CBe=;Dd]1`00
2e3X00<004bUC:D04dbU0P003T@P1000I7oo20005SMO0P005CMO2P0053<o0P0063Lo00<003Lo=cl0
13Lo2`0022ln00<003<o<cl05S<o00<003<o<cl043<o4P003Blo00<003<o<cl05S<o00<003Lo=cl0
5CLo00<003Lo=cl05SLo00<003/o>cl00S/o00<003/o>cl01C/o3000?Goo00<007ooOol0;Woo001I
Ool00`00Oomoo`1^Ool30002Gk400`0000800P0600800`00=6/dJ`02=6/00`00BBm9;`0@BBl00`00
CDm=C`0ACDl00`00CDi=CP0ACDh00`00CBe=;@09CBd70003D>P00`00C:E<Y@0CC:D00`00A214800B
A204001HOol80006=el00`00=elgG`0G=el00`00=elgG`0:=el80006<cl00`00<clc?`0G<cl00`00
=clg?`0@=cl<000D;ch00`00<clc?`0F<cl00`00<clc?`04<cl;0007;ah00`00;cl_?`0F;cl00`00
<clc?`0F<cl00`00=clg?`0E=cl00`00=clg?`0:=clH000;>cl00`00Oomoo`0kOol00`00Oomoo`0^
Ool005Uoo`03001oogoo071oo`04001O/Ena000700800`00=6/dJ`03=6/00`00BBm9;`0@BBl00`00
CDm=C`0@CDl00`00CDi=CP0BCDh00`00CBe=;@0@CBd8000@C:D00`00A214800GA205001<Ool7000?
=el2000H=el00`00=elgG`02=el7000?<cl2000H<cl00`00=clg?`04=cl;0008:ch2000G;ch00`00
<clc?`0@<cl<000C;ah00`00;cl_?`0F;cl00`00<clc?`0F<cl00`00=clg?`0:=clG000<=cl01@00
>clk?c/o00004c/o00<007ooOol0>goo00<007ooOol0;Goo001IOol00`00Oomoo`1_Ool01000Gk5O
/@001P020P001SA[00<004T_BBl044T_00<004e?CDl044e?00<004e>CDh04Te>00<004d]CBd04Td]
00<004d;C@/00dd;2P001DbU00<004@PA2005T@P0P001CP01@00?Woo2@0063MO0P004SMO2@0063<o
00<003<o<cl043<o30005B/n00<002ln;ch05Bln00<003<o<cl013<o2`0022/N00<002lN;ah05BlN
00<002lo;cl05Rlo00<003<o<cl02S<o60002cLo00<003Lo=cl05SLo00@003/o>cl001@k?`03001o
ogoo03Yoo`03001oogoo02eoo`00FGoo00<007ooOol0KWoo00D005naGk5O/@0000D00P03000dJcA[
00DdJ`030019;dT_0119;`03001=Cde?015=C`03001=CTe>015=CP03001=;Dd]019=;@03001=2dd;
00i=2`X0015480<000`h00D002ioo`/000LgG`03000gGcMO01TgG`03000gGcMO00@gG`/000Lc?`03
000c?c<o01Pc?`03000c?c<o00@c?`/000P[7P8001P[?P8000/_?Q4001@[7P8001H_7P03000_?blo
010_?a8000`c7`03000g?cLo01Dg?`03000g?cLo01Hg?`03000k?`0001@k?`03001oogoo03]oo`03
001oogoo02aoo`00FGoo00<007ooOol0KWoo00@005naGk4000D00P03000dJcA[00HdJ`030019;dT_
0119;`03001=Cde?011=C`03001=CTe>019=CP03001=;Dd]019=;@03001=2dd;019=2`030018bDS9
00=8b@X000E4808001@h00D001moo`X001<gG`8001HgG`X001<c?`8001Dc?`X001D[7P03000[?R/n
014[?Q4000dS7@8001P[7P03000_7RlN01@_7P03000_?blo00@_?`/000H_7`03000c7c<O01Hc7`03
000g?cLo01Dg?`03000g?cLo01Dg?`03000k?`0001Dk?`03001oogoo03Yoo`03001oogoo02aoo`00
FGoo00<007ooOol0KGoo00D005naGk5O/@0000<00P8000TdJ`030019;dT_0119;`03001=Cde?011=
C`03001=CTe>019=CP03001=;Dd]019=;@03001=2dd;015=2`030018bDS900i8b@X001Dh00H0019o
o`P000HgG`03000gGcMO01HgG`8000`gG`P000Hc?P03000c?c<o01Hc?`8000`c?`L000HW7@8001P[
7P8000H[?P/000PNo003000S7B<M01DS7@03000[7R/N01H[7P03000_7RlN00T_7Q40018_7`03000c
7c<O01Hc7`03000g?cLo01Dg?`03000g?cLo01Dg?`8001Dk?`03001oogoo03]oo`03001oogoo02]o
o`00F7oo1@00K7oo00@005naGk4000<00P03000dJcA[00PdJ`030019;dT_0159;`03001=Cde?011=
C`03001=CTe>015=CP03001=;Dd]019=;@03001=2dd;019=2`030018bDS90198b@030014QdB700=4
Q`/000Hh00@000HX00L000Aoo`L000lgG`8001PgG`03000gGcMO008gG`L000lc?P8001Pc?`03000c
?c<o008c?`L000lW7@8001<[7P/001@No08001HS7@8000`[7QH000d_7`03000_7blO01@_7`03000c
7c<O01Hc7`03000g?cLo01@g?`03000g?cLo01Dg?`8001Hk?`03001oogoo03Yoo`03001oogoo02]o
o`00F7oo00<007ooOol0KGoo00D005naGk5O/@0000800P03000dJcA[00TdJ`030019;dT_0119;`03
001=Cde?011=C`03001=CTe>019=CP03001=;Dd]019=;@03001=2dd;015=2`030018bDS90198b@03
0014QdB700m4Q`l000@X00P001PgG`80018gG`T001Pc?P80018c?`T001PW7@8000H[7P/000LJf`<0
01LNo003000S7B<M00XS7AL000dW7P03000_7blO01@_7`03000_7blO01@_7`03000c7c<O01Dc7`03
000g?cLo01Dg?`03000g?cLo01Dg?`03000k?c/o00Xk?``003aoo`03001oogoo02Yoo`00F7oo00<0
07ooOol0K7oo00<005naGk400Una0`0033A[00<004T_BBl044T_00<004e?CDl044e?00<004e>CDh0
4Te>00<004d]CBd04Dd]00<004d;C@/04Td;00<004S9B<T04DS900<004B7A8L054B700<00413@4<0
1D131`001SMO0P006SMO00<003MO=el013MO2`001bln0P006S<n00<003<o<cl013<o2`001b<M0`00
52LM2`005A[K0P002akl5`003B;m00<002LN9ah05BLN00<002lO;al052lO00<002lO;al052lO00<0
03<O<al05C<O00<003Lo=cl02SLo;`002c/O00<007ooOol0>Woo00<007ooOol0:Woo001HOol00`00
Oomoo`1/Ool01000Gk5O/Ena0P003SA[00<004T_BBl044T_00<004e?CDl044e?00<004e>CDh04De>
00<004d]CBd04Td]00<004d;C@/04Dd;00<004S9B<T04TS900<004B7A8L04dB700<0041300001P00
3cMO0P005CMO2P0052ln0`004c<n2`005B<M0`001RLM2`0021:j0`0031[K5P003Akl0`005B;m0P00
5RLN00<002lO;al052lO00<002lO;al052lO00<003<O<al02S<O5`002c/O00<003/O>al053/O0P00
5c/O00<007ooOol0>Woo00<007ooOol0:Goo001HOol00`00Oomoo`1[Ool00`00Gk5O/@02Gk400`00
=6/dJ`0<=6/00`00BBm9;`0@BBl00`00CDm=C`0ACDl00`00CDi=CP0ACDh00`00CBe=;@0ACBd00`00
C@]=2`0BC@/00`00B<U8b@0AB<T00`00A8M4Q`0=A8L9000H=el00`00=elgG`0;=el70006;ch2000I
;ch20006<ch;00087a`4000<8adA000<4[XF000=5]/3000F7_`2000E8_d00`009ahW7P0D9ah00`00
;al_7`09;al^000;>al00`00>alk7`0E>al00`00>alk7`0D>al2000G>al00`00Oomoo`0iOol00`00
Oomoo`0YOol005Qoo`03001oogoo06Yoo`03001O/Ena009O/@03000dJcA[00ddJ`030019;dT_0119
;`03001=Cde?011=C`03001=CTe>015=CP03001=;Dd]019=;@03001=2dd;015=2`030018bDS90198
b@030014QdB70094Q`/000LgG`8001TgG`8000@gG`L000l_?P<001<_?P/001<O710000L:V1H000h:
V@<001DFf`8000/No4<000/g7`03000g7cLO01@g7`03000k7c/O01Dk7`03000k7c/O01Dk7`03000k
7c/O01<k7`8001Lk7`03001oogoo03Yoo`03001oogoo02Qoo`00F7oo00<007ooOol0JWoo00<005na
Gk400Una00<003A[=6/03CA[00<004T_BBl044T_00<004e?CDl044e?00<004e>CDh04De>00<004d]
CBd04Td]00<004d;C@/04Dd;00<004S9B<T03TS92@0053MO0P005CMO20006Bln0P001Rln2`0021kk
10001alLJ`002c<O00<003<O<al04c<O00<003LO=al053LO00<003LO=al053LO00<003LO=al053LO
00<003/O>al05C/O00<003/O>al053/O00<003/O>al04c/O00<003/O00005c/O00<007ooOol0>Goo
00<007ooOol0:7oo001HOol00`00Oomoo`1YOol00`00Gk5O/@02Gk400`00=6/dJ`0>=6/00`00BBm9
;`0@BBl00`00CDm=C`0@CDl00`00CDi=CP0ACDh00`00CBe=;@0ACBd00`00C@]=2`0AC@/00`00B<U8
b@08B<T70005=el2000H=el00`00=elgG`0;=el70006;ch2000G;ch:000C7_/I000C8]h00`009_hV
oP0B9_h00`00:al[7`0C:al00`00;al_7`0C;al00`00<alc7`0B<al00`00<alc7`0C<al00`00=alg
7`0D=al00`00=alg7`0D=al00`00=alg7`0D=al00`00>alk7`0E>al00`00>alk7`0D>al00`00>alk
7`0B>al01000>alk7`005S/O00<007ooOol0>Woo00<007ooOol09goo001HOol00`00Oomoo`1XOol0
0`00Gk5O/@02Gk42000?=6/00`00BBm9;`0@BBl00`00CDm=C`0@CDl00`00CDi=CP0ACDh00`00CBe=
;@0BCBd00`00C@]=2`0@C@/00`00B<U8b@02B<T7000>=el2000G=el20004=el7000?;ch3000=;ch7
00076_/400077_/>00023Y/2000B5[d2000B8]h2000C9_h2000D:al00`00;al_7`0C;al00`00<alc
7`0B<al00`00<alc7`0C<al00`00=alg7`0D=al00`00=alg7`0D=al00`00=alg7`0D=al00`00>alk
7`0D>al00`00>alk7`0D>al00`00>alk7`0B>al01000>alk7`005c/O00<007ooOol0>Goo00<007oo
Ool09goo001HOol00`00Oomoo`1XOol01`00Gk5O/Ena00000@0000ldJ`030019;dT_0119;`03001=
Cde?011=C`03001=CTe>015=CP03001=;Dd]015=;@03001=2dd;00e=2`T001LgG`80018gG`T001T_
?P8000@_?PL000hJn`/000i:_A0000PF_@03000RgR;N014RgP03000VoRKn018VoP03000[7b/O018[
7`03000_7blO01<_7`03000c7c<O018c7`03000c7c<O01<c7`03000g7cLO01@g7`03000g7cLO01@g
7`03000g7cLO01@g7`03000k7c/O01@k7`03000k7c/O01@k7`03000k7c/O00Xk7b@003]oo`03001o
ogoo02Ioo`00F7oo00<007ooOol0Igoo00L005naGk5O/@000040000@=6/00`00BBm9;`0@BBl00`00
CDm=C`0@CDl00`00CDi=CP0ACDh00`00CBe=;@0ACBd00`00C@]=2`02C@/;0007>el2000I=el20005
=el;0008<ch3000D;ch:00096_/;0009B[`00`00B[e:_@0AB[d00`00B]e:g@09B]dE00088]h00`00
9_hVoP0B9_h00`00:al[7`0B:al00`00;al_7`0C;al00`00<alc7`0B<al00`00<alc7`0C<al00`00
=alg7`0D=al00`00=alg7`0D=al00`00=alg7`0D=al00`00>alk7`09>al^0007?cl01@00?clo?clo
00005clo00<007ooOol0>Goo00<007ooOol09Woo001HOol00`00Oomoo`1WOol01000Gk5O/@000P01
00<003A[=6/03SA[00<004T_BBl03dT_00<004e?CDl044e?00<004e>CDh04De>00<004d]CBd03Td]
2@0053]O0P005CMO2@005S<n0`001Rln2`0021[j2`0000=:W000B[`04TZl00<004ZmB[d04DZm00<0
04[MB]d04D[M00<004KNA]h02DKN:P002B/O00<002lO;al04blO00<003<O<al04S<O00<003<O<al0
4c<O00<003LO=al053LO00<003LO=al02CLO;@002d<O00<003lO?al053lO00<003lo?cl043lo00<0
03lo?cl00Slo00<003lo?cl05Clo00<007ooOol0>Goo00<007ooOol09Goo001HOol4001UOol01000
Gk5O/@000`0100<003A[=6/03CA[00<004T_BBl044T_00<004e?CDl044e?00<004e>CDh04De>00<0
04d]CBd01dd]1`001C]O0P0063]O00<003MO=el02cMO1`001S=N0P005c<n2@0021[j2`0034ZL00<0
04ZlB[`04DZl00<004ZmB[d04DZm00<004[MB]d04T[M00<004KNA]h04DKN00<004KNA]h04TKN00<0
04KnA_h02DKnK@002d<O00<004<O@al054<O00<004<O@al054<O00<003lO?al053lO00<003lo?cl0
3clo00<003lo?cl00clo00<003lo?cl053lo00<007ooOol0>Woo00<007ooOol097oo001HOol00`00
Oomoo`1UOol01000Gk5O/@000`0100<003A[=6/03SA[00<004T_BBl044T_00<004e?CDl044e?00<0
04e>CDh044e>00@004d]CBe=;@L000hkG`8001LkG`8000@gG`L000lcGP<000dc?PL000TJnPP000=:
V`03001:W4ZL019:W003001:_4Zl011:_003001:_DZm019:_@03001:gD[M015:g@030016gTKN0196
gP030016gTKN0196gP030016oTKn0196oP030016oTKn01=6oP030016odKo0196o`0300177dLO01=7
7`0300137d<O01A37`0300137d<O01A37`0300137d<O01A37`0300137d<O01A37`03000o7clO01@o
7`03000o?clo00ho?`03000o?clo00<o?`03000o?clo01Do?`03001oogoo03Uoo`03001oogoo02Ao
o`00F7oo00<007ooOol0IGoo00<005na0000100100<003A[=6/03SA[00<004T_BBl044T_00<004e?
CDl044e?00<004e>CDh02de>2@005c]O0P004S]O2@006C=N0P0013<n1`002A[j1`0034ZK00<004ZL
BY`04DZL00<004ZlB[`04DZl00<004ZmB[d04DZm00<004[MB]d04T[M00<004KNA]h04DKN00<004KN
A]h04TKN00<004KnA_h04dKn00<004KnA_h04dKn00<004KoA_l04TKo00<004LOAal04dLO00<004<O
@al054<O00<004<O@al054<O00<004<O@al04d<O00<004<O@al054<O00<003lO?al053lO00<003lo
?cl03Slo00<003lo?cl013lo00<003lo?cl05Clo00<007ooOol0>Goo00<007ooOol08goo001HOol0
0`00Oomoo`1TOol00`00Gk40000500400`00=6/dJ`0==6/00`00BBm9;`0@BBl00`00CDm=C`0@CDl0
1000CDi=CTe>2`001c]O0P006C]O0P001C]O2`0023=N0`0053=N2`001a[j20004TZK00<004ZLBY`0
4DZL00<004ZlB[`04DZl00<004ZmB[d04TZm00<004[MB]d04D[M00<004KNA]h04TKN00<004KNA]h0
4TKN00<004KnA_h04TKn00<004KnA_h04dKn00<004KoA_l04dKo00<004LOAal04dLO00<004<O@al0
54<O00<004<O@al04d<O00<004<O@al054<O00<004<O@al054<O00<003lO?al053lO00<003lo?cl0
3Clo00<003lo?cl013lo00<003lo?cl05Clo00<007ooOol0>Goo00<007ooOol08goo001GOol00`00
Oomoo`1TOol00`00Gk40000500400`00=6/dJ`0>=6/00`00BBm9;`0@BBl00`00CDm=C`0;CDl9000D
>el2000E>el9000F<eh30006<eh;00096_X90007BW/00`00BY]:V`0ABY/00`00BYa:W00ABY`00`00
B[a:_00AB[`00`00B[e:_@0AB[d00`00B]e:g@0BB]d00`00A]i6gP0AA]h00`00A]i6gP0BA]h00`00
A_i6oP0CA_h00`00A_i6oP0CA_h00`00A_m6o`0BA_l00`00Aam77`0CAal00`00@am37`0D@al00`00
@am37`0D@al00`00@am37`0D@al00`00@am37`0D@al00`00?alo7`0C?al00`00?clo?`0=?cl00`00
?clo?`05?cl00`00?clo?`0:?cl<000kOol00`00Oomoo`0ROol005Moo`03001oogoo06=oo`03001O
/@0000H00@03000dJcA[00hdJ`030019;dT_0119;`03001=Cde?00A=C`L000DkG`8001PkG`03000k
Gc]O00/kG`L000HcG`8001LcGPT000TJnP/0015:N`03001:VdZK011:V`03001:W4ZL015:W003001:
_4Zl015:_003001:_DZm019:_@03001:gD[M015:g@030016gTKN0196gP030016gTKN0196gP030016
oTKn01=6oP030016oTKn0196oP030016odKo01=6o`0300177dLO01=77`0300137d<O01A37`030013
7d<O01=37`0300137d<O01A37`0300137d<O01A37`03000o7clO01@o7`03000o?clo00Xo?aL000]3
?`03001oogoo03Uoo`03001oogoo029oo`00Egoo00<007ooOol0Hgoo0P001`0100<003A[=6/03SA[
00<004T_BBl03dT_20003S]O00<003]O>el05S]O0P0013]O1`003c=O0`003C=N1`002A[j3P0014Yj
00<004YkBW/044Yk00<004ZKBY/04DZK00<004ZLBY`04DZL00<004ZlB[`04DZl00<004ZmB[d04DZm
00<004[MB]d04T[M00<004KNA]h04TKN00<004KNA]h04TKN00<004KnA_h04TKn00<004KnA_h04dKn
00<004KoA_l04dKo00<004LOAal04dLO00<004<O@al04d<O00<004<O@al054<O00<004<O@al054<O
00<004<O@al054<O00<003lO?al02ClO5`000T<o00<004<o@cl01T<o00<004<o@cl05D<o00<007oo
Ool0>Goo00<007ooOol08Goo001GOol00`00Oomoo`1ROol2000700400`00=6/dJ`0>=6/00`00BBm9
;`08BBl9000F>el2000E>el7000I<el20004<eh7000:6_X7000=DUP?0008BW/00`00BY]:V`0ABY/0
0`00BYa:W00ABY`00`00B[a:_00AB[`00`00B[e:_@0BB[d00`00B]e:g@0AB]d00`00A]i6gP0BA]h0
0`00A]i6gP0BA]h00`00A_i6oP0CA_h00`00A_i6oP0CA_h00`00A_m6o`0BA_l00`00Aam77`0DAal0
0`00@am37`0C@al00`00@am37`0D@al00`00@am37`0C@al00`00@am37`0:@alF000;Aal00`00@cm3
?`0;@cl00`00@cm3?`07@cl00`00@cm3?`0E@cl00`00Oomoo`0hOol00`00Oomoo`0QOol005Moo`03
001oogoo065oo`8000P00@03000dJcA[00hdJ`/000LoG`8001PkG`8000`kG`L000DgG`<001LcG`T0
00PJnPL000EBF003001BF59H011BF003001BFE9I00QBFA@000Q:V`03001:W4ZL019:W003001:_4Zl
011:_003001:_DZm019:_@03001:gD[M019:g@030016gTKN0196gP030016gTKN0196gP030016oTKn
0196oP030016oTKn01=6oP030016odKo01=6o`0300177dLO01=77`0300137d<O01A37`0300137d<O
01=37`0300137d<O00U37aL000]77`0300177dLO01A77`030013?d<o00Y3?`030013?d<o00Q3?`03
0013?d<o01A3?`03001oogoo03Uoo`03001oogoo021oo`00Egoo00<007ooOol0H7oo0P002@0100<0
03A[=6/01SA[200053mO0P0063]O00<003]O>el00S]O1`003cMO0P003S=O1`0021[j2@00359H00<0
059HDUP0459H00<0059IDUT04E9I00<0059iDWT0259i5@0024ZL00<004ZlB[`04DZl00<004ZmB[d0
4TZm00<004[MB]d04D[M00<004KNA]h04TKN00<004KNA]h04TKN00<004KnA_h04dKn00<004KnA_h0
4dKn00<004KoA_l04TKo00<004LOAal054LO00<004<O@al04d<O00<004<O@al02D<O5P002d/O00<0
04LOAal05DLO00<004LOAal04dLO00<004<o@cl02T<o00<004<o@cl024<o00<004<o@cl05D<o00<0
07ooOol0>7oo00<007ooOol087oo001GOol00`00Oomoo`1OOol2000900400`00=6/dJ`070005?el2
000G?el2000B>el9000H=el30004<el700046_X;00000e8h001BF00BDUP00`00DUQBF00ADUP00`00
DUUBF@0@DUT00`00DWUBN@0ADWT00`00DWYBNP09DWXD0008B[`00`00B[e:_@0BB[d00`00B]e:g@0B
B]d00`00A]i6gP0BA]h00`00A]i6gP0BA]h00`00A_i6oP0CA_h00`00A_i6oP0BA_h00`00A_m6o`0C
A_l00`00Aam77`09Aal/000;Bah00`00Bam;7`0DBal00`00Aam77`0DAal00`00Aam77`0DAal00`00
@cm3?`09@cl00`00@cm3?`09@cl00`00@cm3?`0D@cl00`00Oomoo`0iOol00`00Oomoo`0OOol005Mo
o`04001oo`00001NOol00`0000400@040047000>?el2000G?el20005>el;0007=el3000G=elB000=
DSP00`00DUQBF00@DUP00`00DUQBF00ADUP00`00DUUBF@0ADUT00`00DWUBN@0@DWT00`00DWYBNP0B
DWX00`00CYY>VP08CYXZ0008B]d00`00A]i6gP0BA]h00`00A]i6gP0BA]h00`00A_i6oP0CA_h00`00
A_i6oP09A_h[000;B_h00`00B_i:oP0CB_h00`00Bai;7P0DBah00`00Bam;7`0DBal00`00Aam77`0D
Aal00`00Aam77`0DAal00`00@cm3?`08@cl00`00@cm3?`09@cl00`00@cm3?`0E@cl00`00Oomoo`0h
Ool00`00Oomoo`0OOol005Moo`8005ioo`T001LoG`03000oGcmO01<oG`P001DgG`8000hgG`L000<O
6`L0009B=`03001B>58h011B>003001BF59H011BF003001BF59H015BF003001BFE9I015BF@03001B
NE9i015BN@03001BNU9j015BNP03001>VTjJ015>VP03001>VdjK019>V`03001>VdjK00U>Ve@000Y>
g@03001>gDkM01=>g@03001:oT[n01A:oP03001:oT[n01=:oP03001;7T/N01=;7P03001;7d/O01A;
7`0300177dLO01A77`0300177dLO01A77`030013?d<o00Q3?`030013?d<o00Y3?`030013?d<o00Y3
?``003Yoo`03001oogoo01ioo`00Egoo00<007ooOol0Dgoo2P001cmO0P0063mO0P0033mO1`001C]O
0`005cMO0`0013MO1`000alK1`002E8g00<0058hDSP0458h00<0059HDUP04E9H00<0059HDUP0459H
00<0059IDUT04E9I00<0059iDWT04E9i00<0059jDWX04U9j00<004jJCYX04DjJ00<004jKCY/04TjK
00<004jKCY/04DjK00<004jlC[`04Tjl00<004jlC[`04Tjl00<004kLC]`04dkL00<004kMC]d04dkM
00<004kMC]d04dkM00<004[nB_h04d[n00<004[nB_h04d[n00<004/NBah054/N00<004/OBal054/O
00<004LOAal054LO00<004LOAal054LO00<004<o@cl01d<o00<004<o@cl01D<o4P002dLo00<007oo
Ool0>7oo00<007ooOol07Woo001GOol00`00Oomoo`1;Ool8000C?el2000H?el20003?el7000?>el2
000C=elC000@DSL00`00DSQB>00@DSP00`00DUQBF00ADUP00`00DUQBF00ADUP00`00DUUBF@0ADUT0
0`00DWUBN@0@DWT00`00DWYBNP0BDWX00`00CYY>VP0ACYX00`00CY]>V`0BCY/00`00CY]>V`0BCY/0
0`00C[a>_00BC[`00`00C[a>_00BC[`00`00C]a>g00CC]`00`00C]e>g@0BC]d00`00C]e>g@0CC]d0
0`00B_i:oP0DB_h00`00B_i:oP0CB_h00`00Bai;7P0CBah00`00Bam;7`0DBal00`00Aam77`0DAal0
0`00Aam77`0DAal00`00@cm3?`04@cl;0006Acl00`00Acm7?`0EAcl00`00Oomoo`0hOol00`00Oomo
o`0MOol005Moo`03001oogoo04Aoo`L000DoG`8001HoG`03000oGcmO01@oG`H001PkG`<000DgG`/0
00DS6`L000=B=`03001B=e8g015B=`03001B>58h011B>003001BF59H015BF003001BF59H015BF003
001BFE9I015BF@03001BNE9i015BN@03001BNU9j015BNP03001>VTjJ015>VP03001>VdjK019>V`03
001>VdjK019>V`03001>_4jl019>_003001>_4jl019>_003001>g4kL01=>g003001>gDkM01=>g@03
001>gDkM01=>g@03001:oT[n01=:oP03001:oT[n01=:oP03001;7T/N01A;7P03001;7d/O01A;7`03
00177dLO01A77`0300177dLO00m77`/000=7?`030017?dLo00a7?`030017?dLo01A7?`03001oogoo
03Qoo`03001oogoo01eoo`00Egoo00<007ooOol0?Goo1`003SmO00<003mO?el053mO0P003CmO1`00
1C]O0`005S]O2@0022<K1`002e8g00<0058gDSL0458g00<0058hDSP04E8h00<0059HDUP0459H00<0
059HDUP04E9H00<0059IDUT04E9I00<0059iDWT04E9i00<0059jDWX04U9j00<004jJCYX04DjJ00<0
04jKCY/04TjK00<004jKCY/04DjK00<004jlC[`04Tjl00<004jlC[`04Tjl00<004kLC]`04dkL00<0
04kMC]d04dkM00<004kMC]d04dkM00<004[nB_h054[n00<004[nB_h04d[n00<004/NBah054/N00<0
04/OBal054/O00<004LOAal04dLO00<004LOAal014LO2`001D/o00<004LoAcl01TLo00<004LoAcl0
34Lo00<004LoAcl05DLo00<007ooOol0>7oo00<007ooOol077oo001GOol00`00Oomoo`0dOol9000F
?el2000F?el20004?el7000?>el2000=>el70009:c`8000BDSL00`00DSMB=`0@DSL00`00DSQB>00A
DSP00`00DUQBF00ADUP00`00DUQBF00@DUP00`00DUUBF@0ADUT00`00DWUBN@0ADWT00`00DWYBNP0B
DWX00`00CYY>VP0ACYX00`00CY]>V`0BCY/00`00CY]>V`0BCY/00`00C[a>_00BC[`00`00C[a>_00B
C[`00`00C]a>g00CC]`00`00C]e>g@0CC]d00`00C]e>g@0CC]d00`00B_i:oP0CB_h00`00B_i:oP0D
B_h00`00Bai;7P0CBah00`00Bam;7`0DBal00`00Aam77`09AalA000ABcl00`00Acm7?`05Acl00`00
Acm7?`0=Acl00`00Acm7?`0EAcl00`00Oomoo`0gOol00`00Oomoo`0LOol005Moo`03001oogoo02Yo
o`X000M3G`8001PoG`80014oG`T001PkG`<000<kG`L000d[?0D000AB=`03001B=e8g015B=`03001B
=e8g015B=`03001B>58h011B>003001BF59H015BF003001BF59H015BF003001BFE9I015BF@03001B
NE9i015BN@03001BNU9j015BNP03001>VTjJ015>VP03001>VdjK019>V`03001>VdjK019>V`03001>
_4jl019>_003001>_4jl019>_003001>g4kL01=>g003001>gDkM01=>g@03001>gDkM01=>g@03001:
oT[n01=:oP03001:oT[n01A:oP03001;7T/N01A;7P03001;7d/O00m;7a0000];7`03001;?d/o01A;
?`030017?dLo00E7?`030017?dLo00i7?`030017?dLo01A7?`03001oogoo03Qoo`03001oogoo01]o
o`00EWoo00<007ooOol08Goo2P004d=O0P0063mO00<003mO?el00cmO2`001cmO0`005c]O1`003R/l
1@002U8g00<0058gDSL0458g00<0058gDSL04E8g00<0058hDSP0458h00<0059HDUP04E9H00<0059H
DUP04E9H00<0059IDUT04E9I00<0059iDWT04E9i00<0059jDWX04E9j00<004jJCYX04TjJ00<004jK
CY/04TjK00<004jKCY/04DjK00<004jlC[`04djl00<004jlC[`04Tjl00<004kLC]`04dkL00<004kM
C]d04dkM00<004kMC]d04TkM00<004[nB_h054[n00<004[nB_h054[n00<004/NBah04d/N00<004/O
Bal014/O2`001DlN00<004/OBal054/O00<004/oBcl054/o00<004LoAcl014Lo00<004LoAcl03TLo
00<004LoAcl04DLo1@00>Goo00<007ooOol06goo0011Ool4000AOol00`00Oomoo`0FOol;0007@el0
0`00@em3G`0E@el00`00?eloG`0C?el8000E?el2000>>el70007<ed50004:c`5000?DSL00`00DSMB
=`0@DSL00`00DSMB=`0ADSL00`00DSQB>00@DSP00`00DUQBF00ADUP00`00DUQBF00ADUP00`00DUUB
F@0ADUT00`00DWUBN@0ADWT00`00DWYBNP0BDWX00`00CYY>VP0ACYX00`00CY]>V`0BCY/00`00CY]>
V`0BCY/00`00C[a>_00BC[`00`00C[a>_00BC[`00`00C]a>g00CC]`00`00C]e>g@0CC]d00`00C]e>
g@0CC]d00`00B_i:oP0CB_h00`00B_i:oP0DB_h00`00Bai;7P09BahA000ACah00`00Bam;7`0CBal0
0`00Bcm;?`0EBcl00`00Acm7?`04Acl00`00Acm7?`0>Acl00`00Acm7?`09Acl70004Ael00`00Oomo
o`0hOol00`00Oomoo`0JOol003moo`P000moo`03001oogoo00ioo`P001=3G`8001I3G`8000`oG`L0
00E3G`8001PoG`<000@kG`L0014cG@H001AB=`03001B=e8g011B=`03001B=e8g015B=`03001B>58h
015B>003001BF59H011BF003001BF59H015BF003001BFE9I015BF@03001BNE9i015BN@03001BNU9j
019BNP03001>VTjJ015>VP03001>VdjK019>V`03001>VdjK019>V`03001>_4jl019>_003001>_4jl
01=>_003001>g4kL019>g003001>gDkM01=>g@03001>gDkM01=>g@03001:oT[n01A:oP03001:oT[n
00m:oQ0000]?7P03001?7TlN01A?7P03001;7d/O01A;7`03001;?d/o01A;?`030017?dLo00A7?`03
0017?dLo00i7?`030017?dLo0097?`L000a7G`03001oogoo03Moo`03001oogoo01Yoo`00?goo0P00
17oo0P003goo00<007ooOol01goo1`001D=O0P005T=O0P005T=O0P000cmO1`003T=O0`005CmO1`00
4C=M1`001U9H00<0058gDSL04E8g00<0058gDSL04E8g00<0058gDSL0458g00<0058hDSP04E8h00<0
059HDUP04E9H00<0059HDUP04E9H00<0059IDUT04E9I00<0059iDWT04E9i00<0059jDWX04E9j00<0
04jJCYX04TjJ00<004jKCY/04TjK00<004jKCY/04TjK00<004jlC[`04Tjl00<004jlC[`04Tjl00<0
04kLC]`04dkL00<004kMC]d04dkM00<004kMC]d04dkM00<004[nB_h04d[n00<004[nB_h014[n2`00
1Dkm00<004lNCah054lN00<004lNCah054lN00<004/OBal04d/O00<004/oBcl05D/o00<004LoAcl0
0dLo00<004LoAcl02DLo2P0054MO00<007ooOol0=goo00<007ooOol06Goo000nOol20006Ool2000>
Ool00`00Oomoo`07000>@el00`00@em3G`0E@el00`00@em3G`0B@el6000H@el2000<?el70007=gh5
0005<ed7000=DUP00`00DSMB=`0ADSL00`00DSMB=`0ADSL00`00DSMB=`0@DSL00`00DSQB>00ADSP0
0`00DUQBF00ADUP00`00DUQBF00ADUP00`00DUUBF@0ADUT00`00DWUBN@0ADWT00`00DWYBNP0BDWX0
0`00CYY>VP0ACYX00`00CY]>V`0BCY/00`00CY]>V`0BCY/00`00C[a>_00BC[`00`00C[a>_00BC[`0
0`00C]a>g00CC]`00`00C]e>g@0CC]d00`00C]e>g@0CC]d00`00B_i:oP09B_hA000AC_d00`00Cai?
7P0CCah00`00Cai?7P0DCah00`00Bam;7`0DBal00`00Bcm;?`0DBcl00`00Acm7?`03Acl<0006Bel0
0`00Aem7G`0FAel00`00Oomoo`0fOol00`00Oomoo`0IOol003ioo`8000Ioo`8000ioo`<001I3G`80
01I3G`8000]3G`L000E3G`8001U3G`8000<oG`L0018gOPH001ABF003001B=e8g015B=`03001B=e8g
015B=`03001B=e8g015B=`03001B>58h011B>003001BF59H015BF003001BF59H015BF003001BFE9I
015BF@03001BNE9i015BN@03001BNU9j019BNP03001>VTjJ015>VP03001>VdjK019>V`03001>VdjK
019>V`03001>_4jl019>_003001>_4jl01=>_003001>g4kL01=>g003001>gDkM01=>g@03001>gDkM
00i>gA0000]>o@03001>oDkm01A>o@03001?7TlN01=?7P03001?7TlN01E?7P03001;7d/O01=;7`03
001;?d/o015;?`X0019;G`030017GdMO01E7G`03001oogoo03Moo`03001oogoo01Qoo`00?Goo0P00
27oo0P003Goo00@007oo000001M3G`8001I3G`040013Gd=O@el7000>@el3000E@el6000D=gh50005
EWT00`00DUQBF00BDUP00`00DSMB=`0ADSL00`00DSMB=`0ADSL00`00DSMB=`0ADSL00`00DSQB>00@
DSP00`00DUQBF00ADUP00`00DUQBF00ADUP00`00DUUBF@0BDUT00`00DWUBN@0ADWT00`00DWYBNP0A
DWX00`00CYY>VP0BCYX00`00CY]>V`0BCY/00`00CY]>V`0BCY/00`00C[a>_00BC[`00`00C[a>_00B
C[`00`00C]a>g00CC]`00`00C]e>g@0CC]d00`00C]e>g@03C]d;0005C]d00`00C_e>o@0DC_d00`00
C_e>o@0CC_d00`00Cai?7P0DCah00`00Cai?7P0DCah00`00Bam;7`0DBal00`00Bcm;?`09Bcl70004
Bcl00`00Bem;G`02Bel00`00Bem;G`0@Bel00`00Aem7G`0FAel00`00Oomoo`0gOol00`00Oomoo`0G
Ool003eoo`8000Qoo`8000eoo`05001oogooOol0000H@el00`00@em3G`0?@el8000H@el2000<@el7
0006?gl3000<=gh5000:EWT00`00DUQBF00BDUP00`00DSMB=`0BDSL00`00DSMB=`0@DSL00`00DSMB
=`0ADSL00`00DSQB>00ADSP00`00DUQBF00ADUP00`00DUQBF00ADUP00`00DUUBF@0ADUT00`00DWUB
N@0ADWT00`00DWYBNP0ADWX00`00CYY>VP0BCYX00`00CY]>V`0BCY/00`00CY]>V`0BCY/00`00C[a>
_00BC[`00`00C[a>_00CC[`00`00C]a>g00BC]`00`00C]e>g@09C]d@000AC]d00`00C_e>o@0CC_d0
0`00C_e>o@0DC_d00`00Cai?7P0CCah00`00Cai?7P0DCah00`00Bam;7`0DBal00`00Bcm;?`02Bcl7
000<Bcl01@00Bem;Gd]O00004d]O00<004MOAel04dMO1000>7oo00<007ooOol05goo000mOol20008
Ool2000=Ool00`00Oomoo`02Ool2000G@el20005@el:0007Ael2000I@el20003@el7000@?gl30004
=gh50002GYP00`00EWUFN@0;EWT00`00DUQBF00ADUP00`00DSMB=`0BDSL00`00DSMB=`0@DSL00`00
DSMB=`0ADSL00`00DSQB>00ADSP00`00DUQBF00ADUP00`00DUQBF00ADUP00`00DUUBF@0ADUT00`00
DWUBN@0ADWT00`00DWYBNP0BDWX00`00CYY>VP0ACYX00`00CY]>V`0BCY/00`00CY]>V`0BCY/00`00
C[a>_00CC[`00`00C[a>_00BC[`00`00C]a>g00>C]`@000;D]`00`00C]e>g@0CC]d00`00C_e>o@0D
C_d00`00C_e>o@0CC_d00`00Cai?7P0DCah00`00Cai?7P0DCah00`00Bam;7`0?Bal9000CBcl01@00
Bem;Gd]O00004d]O00<004MOAel03DMO1P000d]O00<007ooOol0=goo00<007ooOol05Woo000mOol2
0008Ool2000=Ool00`00Oomoo`04Ool2000D@el8000CAel2000G@el5000I?gl50005GYP2000>EWT0
0`00DUQBF00BDUP00`00DSMB=`0ADSL00`00DSMB=`0ADSL00`00DSMB=`0@DSL00`00DSQB>00ADSP0
0`00DUQBF00ADUP00`00DUQBF00ADUP00`00DUUBF@0ADUT00`00DWUBN@0ADWT00`00DWYBNP0BDWX0
0`00CYY>VP0BCYX00`00CY]>V`0BCY/00`00CY]>V`0BCY/00`00C[a>_00BC[`00`00C[a>_00BC[`0
0`00C]a>g003C]`;0005D]`00`00D]aBg00DD]`00`00C]e>g@0BC]d00`00C_e>o@0DC_d00`00C_e>
o@0DC_d00`00Cai?7P0CCah00`00Cai?7P0DCah00`00Bam;7`04Bal;0005Ccl00`00Bcm;?`0EBcl0
1000Bem;G`0054]O00<004MOAel01dMO1@002T]O00<007ooOol0=Woo00<007ooOol05Woo000mOol2
0008Ool2000=Ool00`00Oomoo`06Ool00`00@em3G`0:@el70005Ael00`00Aem7G`0EAel00`00@em3
G`0?@el50004@gl3000B?gl50003I_T00`00GYQNV003GYP00`00EWUFN@0>EWT00`00DUQBF00BDUP0
0`00DSMB=`0ADSL00`00DSMB=`0ADSL00`00DSMB=`0@DSL00`00DSQB>00ADSP00`00DUQBF00ADUP0
0`00DUQBF00ADUP00`00DUUBF@0BDUT00`00DWUBN@0ADWT00`00DWYBNP0ADWX00`00CYY>VP0BCYX0
0`00CY]>V`0BCY/00`00CY]>V`0BCY/00`00C[a>_00BC[`00`00C[a>_009C[`?000AD]`00`00D]aB
g00CD]`00`00C]e>g@0CC]d00`00C_e>o@0CC_d00`00C_e>o@0DC_d00`00Cai?7P0DCah00`00Cai?
7P0@Cah:000ACcl00`00Bcm;?`0EBcl00`00Bel0000DBel01000Aem7GdMO1P003d]O00<007ooOol0
=goo00<007ooOol05Goo000mOol20008Ool2000=Ool00`00Oomoo`07Ool20003@el7000=Ael2000F
Ael2000:@el5000<@gl2000;?gl50008I_T00`00GYQNV002GYP00`00EWUFN@0?EWT00`00DUQBF00B
DUP00`00DSMB=`0ADSL00`00DSMB=`0ADSL00`00DSMB=`0ADSL00`00DSQB>00@DSP00`00DUQBF00A
DUP00`00DUQBF00BDUP00`00DUUBF@0ADUT00`00DWUBN@0ADWT00`00DWYBNP0ADWX00`00CYY>VP0B
CYX00`00CY]>V`0BCY/00`00CY]>V`0BCY/00`00C[a>_009C[`E000:D[`00`00D]aBg00CD]`00`00
D]aBg00CD]`00`00C]e>g@0CC]d00`00C_e>o@0DC_d00`00C_e>o@0CC_d00`00Cai?7P0DCah00`00
Cai?7P09Cah70004Cah00`00Ccm??`0DCcl00`00Bcm;?`0EBcl00`00Bel0000ABel7000FBel00`00
Oomoo`0fOol00`00Oomoo`0EOol003eoo`8000Qoo`8000eoo`03001oogoo00Uoo`<001I7G`8001I7
G`8000=3G`D001=3O`<000<oO`D000eVn@05001NV5jHGYP0000BEWT00`00DUQBF00BDUP00`00DSMB
=`0ADSL00`00DSMB=`0ADSL00`00DSMB=`0ADSL00`00DSQB>00ADSP00`00DUQBF00ADUP00`00DUQB
F00ADUP00`00DUUBF@0ADUT00`00DWUBN@0ADWT00`00DWYBNP0BDWX00`00CYY>VP0BCYX00`00CY]>
V`0BCY/00`00CY]>V`08CY/E000:D[/00`00D[aB_00CD[`00`00D]aBg00BD]`00`00D]aBg00DD]`0
0`00C]e>g@0CC]d00`00C_e>o@0CC_d00`00C_e>o@0DC_d00`00Cai?7P0CCah00`00Cai?7P02Cah7
000<Cah00`00Ccm??`0DCcl00`00Bcm;?`0EBcl2000:Bel70004Bel00`00Bem;G`0GBel00`00Oomo
o`0fOol00`00Oomoo`0DOol003eoo`8000Qoo`8000eoo`03001oogoo00]oo`030017GdMO01I7G`03
0017GdMO0197G`H001U3O`H0015Vn@04001NV5jH000CEWT00`00DUQBF00BDUP00`00DSMB=`0ADSL0
0`00DSMB=`0ADSL00`00DSMB=`0ADSL00`00DSQB>00ADSP00`00DUQBF00ADUP00`00DUQBF00ADUP0
0`00DUUBF@0ADUT00`00DWUBN@0BDWT00`00DWYBNP0ADWX00`00CYY>VP0BCYX00`00CY]>V`0=CY/@
000:D[/00`00D[]B^`0CD[/00`00D[aB_00BD[`00`00D]aBg00CD]`00`00D]aBg00CD]`00`00C]e>
g@0CC]d00`00C_e>o@0DC_d00`00C_e>o@0CC_d00`00Cai?7P0?Cah9000CCah00`00Ccm??`0ECcl0
0`00Bcm;?`0DBcl20003Bel7000<Bel00`00Bem;G`0FBel00`00Oomoo`0fOol00`00Oomoo`0DOol0
03ioo`8000Ioo`8000ioo`03001oogoo00aoo`8001M7G`8000]7G`L000E7O`<00193O`P001EVn@80
01EFN@03001BF59H015BF003001B=e8g015B=`03001B=e8g015B=`03001B=e8g015B=`03001B>58h
015B>003001BF59H015BF003001BF59H015BF003001BFE9I019BF@03001BNE9i015BN@03001BNU9j
015BNP03001>VTjJ019>VP03001>VdjK00=>V`X000EBV`03001B^e:k01=B^`03001B^e:k019B^`03
001B_5:l019B_003001Bg5;L01=Bg003001Bg5;L01ABg003001>gDkM019>g@03001>oDkm01A>o@03
001>oDkm01=>o@03001?7TlN00A?7P/000E?7P03001?7TlN01E?7P03001??dlo01A??`03001;?d/o
015;?`P001A;G`03001;Gd]O01=;G`@003Qoo`03001oogoo01=oo`00?Woo0P001Woo0P003Woo00<0
07ooOol03Woo0P005dMO00@004MOAem7G`L000m7O`8000]3O`D0008oW0<001MVn@8001IFN@03001B
F59H019BF003001B=e8g015B=`03001B=e8g015B=`03001B=e8g011B=`03001B>58h015B>003001B
F59H015BF003001BF59H019BF003001BFE9I015BF@03001BNE9i015BN@03001BNU9j019BNP03001>
VTjJ00Q>VPl000mBV`03001B^e:k01=B^`03001B^e:k019B^`03001B_5:l01=B_003001Bg5;L01=B
g003001Bg5;L01=Bg003001>gDkM01=>g@03001>oDkm01A>o@03001>oDkm011>o@T0015?7P03001?
7TlN01A?7P03001??dlo01E??`03001;?d/o00U;?`L000A;G`03001;Gd]O01I;G`03001;Gd]O00e;
G`D000=7O`03001oogoo03Ioo`03001oogoo01=oo`00?goo0P0017oo0P003Woo00<007ooOol04Goo
00<004MOAel04TMO1P0064Mo0`000d=o1@0013nL0`006FKi00<005KK00005UIi00<0059HDUP04U9H
00<0058gDSL04E8g00<0058gDSL04E8g00<0058gDSL0458g00<0058hDSP04E8h00<0059HDUP04U9H
00<0059HDUP04E9H00<0059IDUT04E9I00<0059iDWT04U9i00<0059jDWX01e9j5@002U:J00<005:K
DY/04U:K00<005:kD[/04U:k00<005:kD[/04e:k00<005:lD[`04U:l00<005;LD]`04e;L00<005;L
D]`04e;L00<004kMC]d04dkM00<004kmC_d054km00<004kmC_d02Dkm1`000e<N00<004lNCah054lN
00<004lNCah05DlN00<004loCcl054lo00<004/oBcl00T/o1`002d]O0P005d]O00<004]OBel01d]O
1P002DMo00<007ooOol0<Goo1P0057oo000oOol8000>Ool5000@Ool2000;Ael70005Bgl2000HAgl>
0003Ki/00`00I_UVn@0EI_T01000E]]Ff`005UIi00<0059HDUP04U9H00<0058gDSL04E8g00<0058g
DSL04E8g00<0058gDSL0458g00<0058hDSP04U8h00<0059HDUP04E9H00<0059HDUP04E9H00<0059I
DUT04U9I00<0059iDWT01e9i50002U:J00<005:JDYX04U:J00<005:KDY/04U:K00<005:kD[/04e:k
00<005:kD[/04U:k00<005:lD[`04e:l00<005;LD]`04e;L00<005;LD]`04e;L00<004kMC]d04dkM
00<004kmC_d04dkm00<004kmC_d00Tkm1`002e<N00<004lNCah054lN00<004lNCah054lN00<004lo
Ccl04Tlo1`004T]O00<004]O00005d]O00@004]OBem;G`D000m7O`03001oogoo02Qoo`T000Eoo`03
001oogoo019oo`00@Goo100047oo00<007ooOol057oo00@004MOAem7G`L000i;O`800157O`D000U?
_`@000A_V`03001VnFKi01AVn@03001FfeKK009Ff`03001FNEIi01=FN@03001BF59H019BF003001B
=e8g015B=`03001B=e8g015B=`03001B=e8g015B=`03001B>58h015B>003001BF59H015BF003001B
F59H015BF003001BFE9I00eBF@l000YBVP03001BVU:J019BVP03001BVU:J019BVP03001BVe:K015B
V`03001B^e:k01=B^`03001B^e:k019B^`03001B_5:l01=B_003001Bg5;L01=Bg003001Bg5;L01=B
g003001>gDkM01=>g@03001>oDkm00m>o@T0019C7P03001?7TlN01A?7P03001?7TlN01A?7P03001?
?dlo00e??`D000=?G`03001;Gd]O01=;G`03001;G`0001E;G`H001E7O`03001oogoo01eoo`X000io
o`03001oogoo019oo`00EGoo00<007ooOol05Goo0`005d]o0P002TMo1@0034no0P000W=i00<006nK
Ki/00fnK00<006KiI_T04fKi00<005KKE]/00eKK00<005IiEWT04eIi00<0059HDUP04U9H00<0058g
DSL04E8g00<0058gDSL04E8g00<0058gDSL04E8g00<0058hDSP04E8h00<0059HDUP04E9H00<0059H
DUP04U9H00<0059IDUT00U9I2P001E9j00<005:JDYX04E:J00<005:JDYX04U:J00<005:JDYX04U:J
00<005:KDY/04U:K00<005:kD[/04U:k00<005:kD[/04e:k00<005:lD[`04e:l00<005;LD]`04U;L
00<005;LD]`055;L00<004kMC]d04TkM00<004kmC_d014km2`001E;m00<005<NDah055<N00<004lN
Cah054lN00<004lNCah054lN00<004loCcl01Tlo1P002DmO00<004]OBel04T]O00@004]OBel000m;
G`D000=;G`030017OdMo01I7O`03001oogoo019oo`X001Qoo`03001oogoo019oo`00EGoo00<007oo
Ool05goo00<004]oBgl05d]o0P000dMo1@003Tno0`0017=i00<006nKKi/016nK00<006KiI_T04FKi
00<005KKE]/015KK00<005IiEWT055Ii00<0059HDUP04E9H00<0058gDSL04E8g00<0058gDSL04E8g
00<0058gDSL04E8g00<0058hDSP04E8h00<0059HDUP04E9H00<0059HDUP03E9H2P003e9j00<005:J
DYX04U:J00<005:JDYX04E:J00<005:JDYX04U:J00<005:KDY/04U:K00<005:kD[/04e:k00<005:k
D[/04U:k00<005:lD[`04e:l00<005;LD]`04e;L00<005;LD]`04e;L00<004kMC]d03TkM2`004E;m
00<005<NDah04e<N00<004lNCah05DlN00<004lNCah04dlN00@004loCcm??`D000m?G`03001;Gd]O
019;G`04001;Gd]O0009Bel60009Bel00`00Agm7O`0EAgl00`00Oomoo`09Ool9000ROol00`00Oomo
o`0BOol005Eoo`03001oogoo01Qoo`8001M;O`D0015?_`8000IcN@03001_VfnK00E_V`03001VnFKi
011Vn@03001FfeKK00EFf`03001FNEIi01AFN@03001BF59H019BF003001B=e8g011B=`03001B=e8g
019B=`03001B=e8g011B=`03001B>58h015B>003001BF59H019BF003001BF59H009BF0X000EBNP03
001BNU9j019BNP03001BVU:J015BVP03001BVU:J019BVP03001BVU:J019BVP03001BVe:K015BV`03
001B^e:k01=B^`03001B^e:k01=B^`03001B_5:l019B_003001Bg5;L01=Bg003001Bg5;L01=Bg003
001>gDkM00=>g@/000EBo@03001BoE;m01ABo@03001C7U<N01AC7P03001?7TlN01A?7P03001?7TlN
015?7PH001E?G`03001;Gd]O015;G`05001;Gd]OBel00003Bel5000?Bel00`00Agm7O`0CAgl>000[
Ool00`00Oomoo`0BOol005Eoo`03001oogoo01Yoo`80015;O`@000AGW`<000a?_`<000McN@03001_
VfnK00M_V`03001VnFKi00iVn@03001FfeKK00MFf`03001FNEIi01=FN@03001BF59H019BF003001B
=e8g015B=`03001B=e8g015B=`03001B=e8g011B=`03001B>58h019B>003001BF59H00aBF0X000mB
NP03001BNU9j019BNP03001BVU:J015BVP03001BVU:J019BVP03001BVU:J019BVP03001BVe:K019B
V`03001B^e:k019B^`03001B^e:k01=B^`03001B_5:l01=B_003001Bg5;L01=Bg003001Bg5;L011B
g0P0015Bo@03001BoE;m01ABo@03001C7U<N01=C7P03001?7TlN01E?7P03001?7TlN00U?7PL000=?
?`03001?GdmO01I?G`03001;Gd]O011;G`03001;G`0000D001E;G`030017OdMo00e7O`D000=7G`03
001oogoo03=oo`03001oogoo019oo`00EGoo00<007ooOol077oo00<004]oBgl02T]o10002eNO0`00
1dno0`002G=i00<006nKKi/01fnK00<006KiI_T03FKi00<005KKE]/025KK00<005IiEWT04eIi00<0
059HDUP04U9H00<0058gDSL04E8g00<0058gDSL04E8g00<0058gDSL0458g00<0058hDSP04U8h00<0
059HDUP00U9H2P001E9j00<0059jDWX04U9j00<0059jDWX04E9j00<005:JDYX04U:J00<005:JDYX0
4E:J00<005:JDYX04U:J00<005:KDY/04U:K00<005:kD[/04e:k00<005:kD[/04U:k00<005:lD[`0
4e:l00<005;LD]`04e;L00<005;LD]`02E;L1`000e;L00<005;mD_d04e;m00<005;mD_d055;m00<0
05<NDah055<N00<004lNCah054lN00<004lNCah00TlN1`002dlo00<004mOCel05DmO00<004]OBel0
3D]O1@000d]O00<004]OBel05T]O00<004MoAgl01TMo1P002DMO00<007ooOol0<Woo00<007ooOol0
4Woo001EOol00`00Oomoo`0MOol20007Bgl3000BEil300001Tno00000000Ki/000UcN@03001_VfnK
00U_V`03001VnFKi00YVn@8000]Ff`03001FNEIi01=FN@03001BF59H019BF003001B=e8g015B=`03
001B=e8g015B=`03001B=e8g015B=`03001B>58h00aB>0X000mBNP03001BNU9j019BNP03001BNU9j
015BNP03001BVU:J019BVP03001BVU:J019BVP03001BVU:J019BVP03001BVe:K015BV`03001B^e:k
01=B^`03001B^e:k01=B^`03001B_5:l01=B_003001Bg5;L019Bg003001Bg5;L009Bg0L000]Bg003
001BoE;m01=Bo@03001BoE;m01ABo@03001C7U<N01=C7P03001?7TlN015?7PP0019??`03001?GdmO
01I?G`03001;Gd]O00I;G`H000=;G`03001;Gd]O00=;G`03001;Gd]O01E;G`040017OdMoAgl5000?
Ael00`00Oomoo`0bOol00`00Oomoo`0BOol005Eoo`03001oogoo01moo`03001;Od]o00@001MGW`80
00=_V`03001cNG=i00McN@03001_VfnK00Y_V`03001VnFKi00UVn@03001FfeKK00]Ff`03001FNEIi
01=FN@03001BF59H019BF003001B=e8g015B=`03001B=e8g015B=`03001B=e8g015B=`03001B>58h
009B>0X000EBNP03001BNU9j019BNP03001BNU9j015BNP03001BNU9j019BNP03001BVU:J015BVP03
001BVU:J019BVP03001BVU:J019BVP03001BVe:K019BV`03001B^e:k019B^`03001B^e:k01=B^`03
001B_5:l01=B_003001Bg5;L00iBg0T0019Bg003001BoE;m01=Bo@03001BoE;m01ABo@03001C7U<N
01AC7P03001?7TlN00U?7PL000A??P03001??dlo01A??`03001?GdmO01E?G`04001;Gd]OBel50009
Bel00`00Bem;G`03Bel00`00Bem;G`0CBel6000EAel00`00Oomoo`0aOol00`00Oomoo`0BOol005Eo
o`03001oogoo021oo`8001QGW`<000A_V`03001cNG=i00QcN@03001_VfnK00]_V`03001VnFKi00MV
n@03001FfeKK00eFf`03001FNEIi019FN@03001BF59H019BF003001B=e8g015B=`03001B=e8g015B
=`03001B=e8g00iB=`P000mBNP03001BNU9j019BNP03001BNU9j015BNP03001BNU9j019BNP03001B
VU:J015BVP03001BVU:J019BVP03001BVU:J019BVP03001BVe:K019BV`03001B^e:k01=B^`03001B
^e:k019B^`03001B_5:l01=B_003001Bg5;L00=Bg0/000EBg003001Bg5;L01=Bg003001BoE;m01=B
o@03001BoE;m01ABo@03001C7U<N01AC7P03001?7TlN009?7PL000a??P03001??dlo01A??`03001?
GdmO019?G`H000i;G`03001;Gd]O00A;G`03001;Gd]O00e;G`D000=3O`030017GdMO01I7G`03001o
ogoo031oo`03001oogoo019oo`00EGoo00<007ooOol08Woo0P004eNO0`001VnK00<007=iLgT027=i
00<006nKKi/036nK00<006KiI_T01VKi00<005KKE]/03UKK00<005IiEWT04eIi00<0059HDUP04E9H
00<0058gDSL04E8g00<0058gDSL04U8g00<0058gDSL01U8g1`000e9j00<0059jDWX04U9j00<0059j
DWX04E9j00<0059jDWX04U9j00<0059jDWX04E9j00<005:JDYX04U:J00<005:JDYX04U:J00<005:J
DYX04U:J00<005:KDY/04E:K00<005:kD[/04e:k00<005:kD[/04e:k00<005:lD[`045:l20004E;L
00<005;LD]`04e;L00<005;mD_d04e;m00<005;mD_d055;m00<005<NDah04E<N1`004dln00<004lo
Ccl054lo00<004mOCel03DmO1@000d]O00<004]OBel03T]O00<004]OBel01D]O00<004]OBel01T]O
1P002D=o00<004MOAel05DMO00<007ooOol0<Goo00<007ooOol04Goo001EOol00`00Oomoo`0TOol0
0`00EimGW`0=Eil30008Ki/00`00LgUcN@08LgT00`00Ki]_V`0>Ki/00`00I_UVn@04I_T00`00E]]F
f`0?E]/00`00EWUFN@0CEWT00`00DUQBF00BDUP00`00DSMB=`0@DSL00`00DSMB=`0BDSL00`00DSMB
=`06000:DWX00`00DWYBNP0BDWX00`00DWYBNP0ADWX00`00DWYBNP0BDWX00`00DWYBNP0BDWX00`00
DYYBVP0ADYX00`00DYYBVP0BDYX00`00DYYBVP0BDYX00`00DY]BV`0BDY/00`00D[]B^`0BD[/00`00
D[]B^`0CD[/00`00D[aB_009D[`70003D]`00`00D]aBg00CD]`00`00D]aBg00CD]`00`00D_eBo@0C
D_d00`00D_eBo@0DD_d00`00DaiC7P0<Dah50003Dch00`00Cci??P0ECch00`00Ccm??`0DCcl00`00
Cem?G`06Cel60009Bel00`00Bem;G`0>Bel00`00Bem;G`04Bel01000Bem;Gd]O1@0044=o00<004MO
Ael04DMO1@00<Woo00<007ooOol04Goo001EOol4000TOol2000:Eil3000;Ki/00`00LgUcN@08LgT0
0`00Ki]_V`0>Ki/00`00I_UVn@03I_T00`00E]]Ff`0@E]/00`00EWUFN@0CEWT00`00DUQBF00BDUP0
0`00DSMB=`0ADSL00`00DSMB=`0>DSL6000ADWX00`00DWYBNP0ADWX00`00DWYBNP0BDWX00`00DWYB
NP0ADWX00`00DWYBNP0BDWX00`00DYYBVP0ADYX00`00DYYBVP0BDYX00`00DYYBVP0BDYX00`00DY]B
V`0BDY/00`00D[]B^`0CD[/00`00D[]B^`0BD[/00`00D[aB_002D[`7000;D]`00`00D]aBg00BD]`0
0`00D]aBg00DD]`00`00D_eBo@0CD_d00`00D_eBo@0DD_d00`00DaiC7P06Dah50009Dch00`00Cci?
?P0DCch00`00Ccm??`0DCcl01000Cem?GdmO1@0044]O00<004]OBel03D]O00<004]OBel00T]O1P00
5D=o00<004MOAel02TMO1`0014=O00<007ooOol0<7oo00<007ooOol04Goo001EOol00`00Oomoo`0W
Ool20005Eil3000=Ki/00`00LgUcN@08LgT00`00Ki]_V`0?Ki/00`00I_UVn@02I_T00`00E]]Ff`0B
E]/00`00EWUFN@0BEWT00`00DUQBF00BDUP00`00DSMB=`0ADSL00`00DSMB=`07DSL70003DYX00`00
DWYBNP0ADWX00`00DWYBNP0BDWX00`00DWYBNP0ADWX00`00DWYBNP0BDWX00`00DWYBNP0ADWX00`00
DYYBVP0BDYX00`00DYYBVP0BDYX00`00DYYBVP0BDYX00`00DY]BV`0ADY/00`00D[]B^`0CD[/00`00
D[]B^`0>D[/9000BD]`00`00D]aBg00CD]`00`00D]aBg00CD]`00`00D_eBo@0CD_d00`00D_eBo@0D
D_d01000DaiC7U<N1@003U<n00<004lnCch05Dln00<004loCcl04Dlo1P005T]O00<004]OBel034]O
1@000d=o00<004=o@gl05T=o00<004MOAel00TMO1`0034=O00<007ooOol0;goo00<007ooOol04Goo
001DOol00`00Oomoo`0ZOol00`00Eil00002000?Ki/00`00LgUcN@09LgT00`00Ki]_V`0@Ki/01000
I_UVn@005EKK00<005IiEWT04UIi00<0059HDUP04U9H00<0058gDSL04E8g00<0058gDSL01`002U:J
00<0059jDWX04E9j00<0059jDWX04U9j00<0059jDWX04E9j00<0059jDWX04U9j00<0059jDWX04E9j
00<005:JDYX04U:J00<005:JDYX04U:J00<005:JDYX04U:J00<005:KDY/04U:K00<005:kD[/04U:k
00<005:kD[/00e:k2`001E:k00<005;LD]`04e;L00<005;LD]`04e;L00<005;LD]`04e;L00<005;m
D_d055;m00<005;mD_d045;m1`0055<n00<004lnCch054ln00<004loCcl034lo1@000d]O00<004]O
Bel05T]O00<004]OBel01d]O1P0024=o00<004=o@gl04d=o1`0054=O00<007ooOol0;Woo00<007oo
Ool04Goo001DOol00`00Oomoo`0[Ool2000@Ki/00`00LgUcN@09LgT00`00Ki]_V`0AKi/00`00I_T0
000FE]/00`00EWUFN@0BEWT00`00DUQBF00BDUP00`00DSMB=`0?DSL5000BDYX00`00DWYBNP0ADWX0
0`00DWYBNP0ADWX00`00DWYBNP0BDWX00`00DWYBNP0ADWX00`00DWYBNP0BDWX00`00DYYBVP0ADYX0
0`00DYYBVP0BDYX00`00DYYBVP0BDYX00`00DY]BV`0BDY/00`00D[]B^`0@D[/8000AD[/00`00D]aB
g00CD]`00`00D]aBg00BD]`00`00D]aBg00DD]`00`00D_eBo@0CD_d00`00D_eBo@09D_d70004Dah0
0`00DciC?P0DDch00`00Cci??P0ECch00`00Ccm??`06Ccl50009Bel00`00Bem;G`0FBel01000Bem;
Gd]O1@001D=o00<004=o@gl01d=o00<004=o@gl03D=o1@000cmO00<004=O@el05D=O00<007ooOol0
;Woo00<007ooOol04Goo001DOol00`00Oomoo`0]Ool00`00Ki]_V`0<Ki/00`00LgUcN@09LgT00`00
Ki]_V`0BKi/2000HE]/00`00EWUFN@0BEWT00`00DUQBF00ADUP00`00DSMB=`0:DSL50002DY/00`00
DYYBVP0BDYX00`00DWYBNP0ADWX00`00DWYBNP0BDWX00`00DWYBNP0ADWX00`00DWYBNP0ADWX00`00
DWYBNP0BDWX00`00DYYBVP0ADYX00`00DYYBVP0CDYX00`00DYYBVP0BDYX00`00DY]BV`0ADY/00`00
D[]B^`09D[/70003D[/00`00D[]B^`0CD[/00`00D]aBg00CD]`00`00D]aBg00CD]`00`00D]aBg00C
D]`00`00D_eBo@0CD_d00`00D_eBo@02D_d7000<Dah00`00DciC?P0DDch00`00Cci??P0DCch01000
Ccm??dlo1@003d]O00<004]OBel04d]O1P002T=o00<004=o@gl024=o00<004=o@gl01d=o1@002CmO
00<004=O@el05D=O00<007ooOol0;Goo00<007ooOol04Goo001DOol00`00Oomoo`0^Ool2000;Ki/0
0`00LgUcN@0:LgT00`00Ki]_V`0AKi/00`00Dgl0000HE]/00`00EWUFN@0BEWT00`00DUQBF00BDUP0
0`00DSMB=`04DSL50008DY/00`00DYYBVP0ADYX00`00DWYBNP0ADWX00`00DWYBNP0BDWX00`00DWYB
NP0ADWX00`00DWYBNP0BDWX00`00DWYBNP0ADWX00`00DYYBVP0BDYX00`00DYYBVP0BDYX00`00DYYB
VP0BDYX00`00DY]BV`0BDY/01000D[]B^e:k1`002e:k00<005:kD[/04U:k00<005;LD]`04e;L00<0
05;LD]`04e;L00<005;LD]`055;L00<005;mD_d045;m1`004e<N00<005<nDch05E<n00<004lnCch0
4Dln1P005D]O00<004]OBel03D]O1@0013mo00<004=o@gl02D=o00<004=o@gl02D=o00@004=o@gm3
O`D000loG`030013Gd=O0193G`@002ioo`03001oogoo015oo`00E7oo00<007ooOol0<7oo0P0026nK
00<007=iLgT02W=i00<006nKKi/04FnK00D005=oDgmCO`0001MFf`03001FNEIi019FN@03001BF59H
019BF003001B=`0000@000eBV`03001BVU:J019BVP03001BNU9j015BNP03001BNU9j015BNP03001B
NU9j015BNP03001BNU9j019BNP03001BNU9j015BNP03001BVU:J019BVP03001BVU:J019BVP03001B
VU:J019BVP03001BVe:K00eBV`T0019B^`03001B^e:k01=B^`03001Bg5;L01=Bg003001Bg5;L01=B
g003001Bg5;L01=Bg003001BoE;m00UBo@L000=C7@03001C7U<N01EC7P03001C?U<n01AC?P03001?
?Tln00a??PD000=;G`03001;Gd]O01E;G`03001;Gd]O00M;G`H000XoO`030013Od=o00Q3O`030013
Od=o00M3O`H001DoG`030013Gd=O00Y3G`L000<oG`03001oogoo02aoo`03001oogoo015oo`00E7oo
00<007ooOol0<Woo00<006nKKi/016nK00<007=iLgT02W=i00<006nKKi/04FnK00<005=oDgl00U=o
00<005KKE]/05EKK00<005IiEWT04UIi00<0059HDUP0459H10004U:K00<005:JDYX04U:J00<0059j
DWX04E9j00<0059jDWX04U9j00<0059jDWX04E9j00<0059jDWX04E9j00<0059jDWX04U9j00<005:J
DYX04E:J00<005:JDYX04e:J00<005:JDYX04U:J00<005:KDY/00U:K2P001E:k00<005:kD[/04e:k
00<005:kD[/04e:k00<005;LD]`04e;L00<005;LD]`04e;L00<005;LD]`04e;L00<005;mD_d00U;m
1`002e<M00<005<NDah055<N00<005<nDch05E<n00<004lnCch01Tln1@002D]O00<004]OBel05D]O
00@004]OBem;G`D0014oO`030013Od=o00M3O`030013Od=o00L000<kG`03000oGcmO01HoG`030013
Gd=O0093G`L000/oG`03001oogoo02]oo`03001oogoo015oo`00E7oo00<007ooOol0<goo0P000fnK
00<007=iLgT02g=i00<006nKKi/046nK00<005=oDgl015=o00<005KKE]/05EKK00<005IiEWT04EIi
00<0059HDUP0359H10000Tjk00<005:KDY/04U:K00<005:JDYX04E:J00<0059jDWX04E9j00<0059j
DWX04U9j00<0059jDWX04E9j00<0059jDWX04E9j00<0059jDWX04U9j00<005:JDYX04E:J00<005:J
DYX04e:J00<005:JDYX03E:J2P0045:k00<005:kD[/04e:k00<005:kD[/04e:k00<005;LD]`04U;L
00<005;LD]`04e;L00<005;LD]`04E;L1`004U<M00<005<NDah05E<N00<005<nDch055<n00@004ln
Cci??PD000m;G`03001;Gd]O019;G`H001LoO`030013Od=o0093O`L000/kG`03000oGcmO018oG`P0
018oG`03001oogoo02]oo`03001oogoo015oo`00E7oo00<007ooOol0=Goo00<006nK00003G=i00<0
06nKKi/046nK00<005=oDgl01E=o00<005KKE]/05EKK00<005IiEWT04EIi00<0059HDUP0259H1000
1djk00<005:KDY/04E:K00<005:JDYX04U:J00<0059jDWX04E9j00<0059jDWX04E9j00<0059jDWX0
4E9j00<0059jDWX04U9j00<0059jDWX04E9j00<005:JDYX04U:J00<005:JDYX04U:J00<005:JDYX0
0e:J2P001E:J00<005:kD[/04U:k00<005:kD[/04e:k00<005:kD[/04e:k00<005;LD]`04e;L00<0
05;LD]`04e;L00<005;LD]`02e;L1@000e<M00<005<MDad055<M00<005<NDah055<N00<005<nDch0
4U<n1P005D]O00<004]OBel034]O1@0013mo00<003mo?gl053mo1`0013]O00<003]O>el033]O00<0
03mO?el02SmO1`0013MO00<003mO?el053mO00<007ooOol0:Woo00<007ooOol04Goo001DOol00`00
Oomoo`0fOol2000<LgT00`00Ki]_V`0@Ki/00`00DgmCO`07Dgl00`00E]]Ff`0DE]/00`00EWUFN@0B
EWT00`00DUQBF003DUP4000;C[/00`00DY]BV`0ADY/00`00DYYBVP0BDYX00`00DWYBNP0ADWX00`00
DWYBNP0ADWX00`00DWYBNP0ADWX00`00DWYBNP0BDWX00`00DWYBNP0BDWX00`00DYYBVP0ADYX00`00
DYYBVP0@DYX8000?DYX00`00D[]B^`0BD[/00`00D[]B^`0CD[/00`00D[]B^`0CD[/00`00D]aBg00C
D]`00`00D]aBg00CD]`00`00D]aBg006D]`50009Dad00`00DaeC7@0CDad00`00DaiC7P0DDah00`00
DciC?P0=Dch50003Bel00`00Bem;G`0EBel00`00Bem;G`07Bel5000:?gl00`00?gloO`0>?gl50004
<eh00`00>elkG`04>el00`00>elkG`0=>el00`00?eloG`02?el7000<=el00`00?eloG`0D?el00`00
Oomoo`0YOol00`00Oomoo`0AOol005Aoo`03001oogoo03Qoo`8000YcN@03001_VfnK00m_V`03001C
Oe=o00QCO`03001FfeKK01AFf`03001FNEIi019FN@03001BF00000<000m>^`03001BVe:K019BV`03
001BVU:J015BVP03001BNU9j015BNP03001BNU9j019BNP03001BNU9j015BNP03001BNU9j015BNP03
001BNU9j019BNP03001BVU:J015BVP03001BVU:J00UBVPL000=BVP03001BVU:J019BVP03001B^e:k
019B^`03001B^e:k01=B^`03001B^e:k01=B^`03001Bg5;L019Bg003001Bg5;L01=Bg004001Bg5;L
D]`5000>Dad00`00DaeC7@0DDad00`00DaiC7P0DDah00`00DciC?P06Dch60009Bel00`00Bem;G`0E
Bel01000Bem;Gd]O1@0043mo00<003mo?gl01cmo1P002S=N00<003]O>el00c]O00<003]O>el02C]O
2@0053MO00<003mO?el04cmO00<007ooOol0:Goo00<007ooOol04Goo001DOol4000iOol00`00LgUc
N@06LgT00`00Ki]_V`0?Ki/00`00DgmCO`0:Dgl00`00E]]Ff`0DE]/00`00EWUFN@0?EWT4000DC[/0
0`00DY]BV`0ADY/00`00DYYBVP0BDYX00`00DWYBNP0@DWX00`00DWYBNP0BDWX00`00DWYBNP0ADWX0
0`00DWYBNP0BDWX00`00DWYBNP0ADWX00`00DYYBVP0BDYX01000DYYBVU:J1`002U:J00<005:JDYX0
4U:J00<005:kD[/04U:k00<005:kD[/04e:k00<005:kD[/04e:k00<005;LD]`04e;L00<005;LD]`0
45;L1P0055<M00<005<MDad04e<M00<005<NDah055<N00@005<nDciC?PD0011;G`03001;Gd]O019;
G`H001HoO`04000oOcmo?gl5000A<eh00`00>elkG`02>el<0006<cl00`00=elgG`0D=el00`00?elo
G`0??el6000ZOol00`00Oomoo`0AOol005Aoo`03001oogoo03]oo`8000EcN@03001_VfnK00i_V`80
00eCO`03001FfeKK01AFf`03001FNEIi00]FN@@0009>g@03001>^djk01=>^`03001BVe:K015BV`03
001BVU:J019BVP03001BNU9j015BNP03001BNU9j015BNP03001BNU9j015BNP03001BNU9j019BNP03
001BNU9j015BNP03001BVU:J00eBVPT0019BVP03001BVU:J015BVP03001B^e:k019B^`03001B^e:k
01=B^`03001B^e:k01=B^`03001Bg5;L01=Bg003001Bg5;L00UBg0L000=Fo@03001C7E<M01AC7@03
001C7E<M01AC7@03001C7U<N015C7PH001I;G`03001;Gd]O00a;G`D000DkO`03000oOcmo018oO`H0
01@cGPP0018c?`03000gGcMO01@gG`03000oGcmO00<oG`/000Dk?`03001oogoo02Qoo`03001oogoo
015oo`00E7oo00<007ooOol0?Goo0P000g=i00<006nKKi/03FnK00<005=oDgl03U=o00<005KKE]/0
4eKK00<005IiEWT01eIi10001dkM00<004jkC[/04Tjk00<005:KDY/04U:K00<005:JDYX04E:J00<0
059jDWX04E9j00<0059jDWX04U9j00<0059jDWX04E9j00<0059jDWX04E9j00<0059jDWX04U9j00<0
05:JDYX00U:J2P001E:J00<005:JDYX04e:J00<005:JDYX04U:J00<005:kD[/04U:k00<005:kD[/0
4e:k00<005:kD[/04e:k00<005;LD]`04U;L00<005;LD]`00U;L1`002eKm00<005<MDad055<M00<0
05<MDad04e<M00<005<NDah035<N1@000dmO00<004]OBel05T]O00<004]OBel01d]O1@002c]o00<0
03mo?gl02Smo1`001Blm0P0033=N1`0012/n00@003<o<cl001<c?`03000gGcMO00TgGa00014k?`03
001oogoo02Moo`03001oogoo015oo`00E7oo00<007ooOol0?goo00<007=i00003fnK00<005=oDgl0
3e=o00<005KKE]/04eKK00<005IiEWT015Ii0`002dkM00<004jkC[/04djk00<005:KDY/04E:K00<0
05:JDYX04U:J00<0059jDWX0459j00<0059jDWX04U9j00<0059jDWX04E9j00<0059jDWX04E9j00<0
059jDWX03E9j2P003e:J00<005:JDYX04e:J00<005:JDYX04U:J00<005:kD[/04U:k00<005:kD[/0
4e:k00<005:kD[/04e:k00<005;LD]`04E;L1P004UKm00<005<MDad055<M00<005<MDad055<M00<0
05<NDah01U<N1@002DmO00<004]OBel05T]O00@004]OBem;G`D0014kO`03000oOcmo008oO`L000h_
?@03000cGS=N008cGPL000`[?P03000c?`0000lc?a0000/g?`03000k?c/o01@k?`03001oogoo02Io
o`03001oogoo015oo`00E7oo00<007ooOol0@7oo0P003VnK00<005=oDgl045=o00<005KKE]/055KK
00<005Ii00000`003dkM00<004jkC[/04Tjk00<005:KDY/04E:K00<005:JDYX04U:J00<0059jDWX0
4E9j00<0059jDWX04E9j00<0059jDWX04E9j00<0059jDWX04U9j00<0059jDWX00U9j2P001E9i00<0
05:JDYX04U:J00<005:JDYX04e:J00<005:JDYX04E:J00<005:kD[/04U:k00<005:kD[/04e:k00<0
05:kD[/055:k00<005;LD]`02e;L1@000UKl00<005KmE_d055Km00<005<MDad04e<M00<005<MDad0
55<M00@005<NDaiC7PD000m?G`03001;Gd]O01=;G`H001@kO`L001<_?@L001@[?P8000@c?`/000H_
?`03000g?cLo01<g?`03000k?c/o01<k?`03001oogoo02Ioo`03001oogoo015oo`00E7oo00<007oo
Ool0@Woo0P002fnK00<005=oDgl04U=o00<005KKE]/04EKK10004dkM00<004jkC[/04Tjk00<005:K
DY/04U:K00<005:JDYX04E:J00<0059jDWX04E9j00<0059jDWX04U9j00<0059jDWX0459j00<0059j
DWX03E9j2P003e9i00<005:JDYX04U:J00<005:JDYX04e:J00<005:JDYX04U:J00<005:kD[/04U:k
00<005:kD[/04e:k00<005:kD[/04e:k00<005;LD]`01U;L1@0025Kl00<005KmE_d04eKm00<005<M
Dad055<M00<005<MDad04E<M1P005DmO00<004]OBel03D]O1@001CMn00<003]o>gl03C]o1@001BLL
0P0032lm1`001B<L0P0042/n2P004Rlo00<003Lo=cl04cLo00<003/o>cl04c/o00<007ooOol09Woo
00<007ooOol047oo001COol00`00Oomoo`15Ool00`00Ki]_V`07Ki/00`00DgmCO`0CDgl00`00E]]F
f`0>E]/30002Bah00`00C]e>g@0CC]d00`00C[]>^`0BC[/00`00DY]BV`0ADY/00`00DYYBVP0BDYX0
0`00DWYBNP0@DWX00`00DWYBNP0BDWX00`00DWYBNP0ADWX00`00DWYBNP02DWX:0005DWT00`00DWUB
N@0BDWT00`00DYYBVP0ADYX00`00DYYBVP0CDYX00`00DYYBVP0BDYX00`00D[]B^`0BD[/00`00D[]B
^`0CD[/00`00D[]B^`0CD[/01000D]aBg5;L1@003EKl00<005KmE_d055Km00<005<MDad04e<M00<0
05<MDad035<M1@000dmO00<004mOCel05TmO00<004]OBel01d]O1@002cMn00<003]o>gl01c]o1@00
32LL00<002lm;cd00Rlm1`003R<L00<002/n:ch00b/n2P001B/N00<002/N00005Blo00<003Lo=cl0
4cLo00<003/o>cl02C/o2`009goo00<007ooOol047oo001COol00`00Oomoo`16Ool20006Ki/00`00
DgmCO`0EDgl00`00E]]Ff`0:E]/30006Bah00`00C]e>g@0BC]d00`00C[]>^`0BC[/00`00DY]BV`0A
DY/00`00DYYBVP0BDYX00`00DWYBNP0ADWX00`00DWYBNP0ADWX00`00DWYBNP0<DWX:000?DWT00`00
DWUBN@0BDWT00`00DYYBVP0BDYX00`00DYYBVP0BDYX00`00DYYBVP0BDYX00`00D[]B^`0BD[/00`00
D[]B^`0CD[/00`00D[]B^`0AD[/6000CE_`00`00E_eFo@0DE_d00`00DaeC7@0CDad00`00DaeC7@06
Dad50009Cel00`00Cem?G`0FCel01000Bem;Gd]O1@004CMn00@003]o>glkO`D000dW70T0014S70X0
00l[7P04000[7R/N000E;cl00`00=clg?`09=clE000:>cl00`00Oomoo`0UOol00`00Oomoo`0@Ool0
05=oo`03001oogoo04Qoo`8000=_V`03001COe=o01ICO`03001FfeKK00MFf`<000Y;7P03001>gDkM
019>g@03001>^djk019>^`03001BVe:K015BV`03001BVU:J015BVP03001BNU9j015BNP03001BNU9j
019BNP03001BNU9j009BNPT000EBN@03001BNE9i019BN@03001BNE9i015BN@03001BVU:J019BVP03
001BVU:J01=BVP03001BVU:J019BVP03001B^e:k019B^`03001B^e:k01=B^`03001B^e:k00]B^`D0
00=Fg003001Fo5Kl01=Fo003001FoEKm01AFo@03001C7E<M01=C7@04001C7E<MDad5000?Cel00`00
Cem?G`0CCel6000D=gh700069a`;00075]X300058a`;00078_d00`00:ah[7P0?:ah01@00:ah[7R/N
00002blo5@002SLo00<003/o>cl04c/o00<007ooOol097oo00<007ooOol047oo001COol00`00Oomo
o`1:Ool00`00Ki/0000JDgl00`00E]]Ff`03E]/3000=Bah00`00C]e>g@0BC]d00`00C[]>^`0BC[/0
0`00DY]BV`0ADY/00`00DYYBVP0BDYX00`00DWYBNP0@DWX00`00DWYBNP0=DWX:000>DWT00`00DWUB
N@0BDWT00`00DWUBN@0BDWT00`00DYYBVP0ADYX00`00DYYBVP0CDYX00`00DYYBVP0BDYX00`00D[]B
^`0BD[/00`00D[]B^`0CD[/00`00D[]B^`06D[/50009E]`00`00E_aFo00CE_`00`00E_eFo@0DE_d0
0`00DaeC7@0ADad5000ECel00`00Cem?G`0=Cel50005<eh2000<=gh700056_X8000;5]X?000C8_d0
0`00:ah[7P09:ahE000:<cl00`00=clg?`0C=cl00`00>clk?`0B>cl00`00Oomoo`0TOol00`00Oomo
o`0@Ool005=oo`03001oogoo04]oo`8001YCO`03001FfeKK00<0015;7P03001>gDkM019>g@03001>
^djk015>^`03001BVe:K015BV`03001BVU:J019BVP03001BNU9j015BNP03001BNU9j009BNPX000EB
N@03001BNE9i015BN@03001BNE9i015BN@03001BNE9i019BN@03001BVU:J019BVP03001BVU:J019B
VP03001BVU:J019BVP03001B^e:k019B^`03001B^e:k01=B^`04001B^e:kD[/5000>E]`00`00E_aF
o00CE_`00`00E_eFo@0DE_d00`00DaeC7@0<Dad50002Cel00`00Cem?G`0FCel00`00Cem?G`07Cel5
000<<eh00`00=ghgOP02=gh700056_X700033YL@000<5]/2000;8_dE0005;al00`00;al_7`02;al0
0`00<clc?`0C<cl00`00=clg?`0B=cl00`00>clk?`0C>cl00`00Oomoo`0SOol00`00Oomoo`0@Ool0
05=oo`03001oogoo04eoo`03001COe=o01ICO`@001A;7P03001>gDkM019>g@03001>^djk019>^`03
001BVe:K015BV`03001BVU:J015BVP03001BNU9j00aBNPX000mBN@03001BNE9i015BN@03001BNE9i
019BN@03001BNE9i015BN@03001BVU:J019BVP03001BVU:J01=BVP03001BVU:J019BVP03001B^e:k
019B^`03001B^e:k011B^`H001=Fg003001Fo5Kl01AFo003001FoEKm01AFo@03001C7E<M00IC7@D0
00Q?G`03001?GdmO01I?G`04001?GdmOCel5000@<eh600056_XA00073YP3000:5]/E000;:al00`00
;al_7`0<;al00`00;al_7`03;al00`00<clc?`0C<cl00`00=clg?`0B=cl00`00>clk?`0B>cl00`00
Oomoo`0SOol00`00Oomoo`0@Ool005=oo`@004eoo`8001=CO`<0008o?`03001;7T/N01A;7P03001>
gDkM019>g@03001>^djk015>^`03001BVe:K015BV`03001BVU:J019BVP03001BNU9j009BNPT000EB
N@03001BNE9i019BN@03001BNE9i011BN@03001BNE9i019BN@03001BNE9i019BN@03001BVU:J015B
VP03001BVU:J01=BVP03001BVU:J019BVP03001B^e:k019B^`03001B^e:k00UB^`L000=Ff`03001F
g5KL01AFg003001Fo5Kl01=Fo003001FoEKm01AFo@04001C7E<MDad5000>Cel00`00Cem?G`0CCel6
000@<eh500034[L]000<9ah00`00:al[7`0B:al00`00;al_7`0;;al00`00;al_7`04;al00`00<clc
?`0C<cl00`00=clg?`0A=cl00`00>clk?`09>cl;000TOol00`00Oomoo`0@Ool005=oo`03001oogoo
051oo`03001COe=o00eCO`<000Ho?`03001;7T/N01A;7P03001>gDkM015>g@03001>^djk015>^`03
001BVe:K015BV`03001BVU:J00eBVPX000iBN@03001BNE9i019BN@03001BNE9i015BN@03001BNE9i
015BN@03001BNE9i019BN@03001BVU:J019BVP03001BVU:J019BVP03001BVU:J019BVP03001B^e:k
019B^`03001B^e:k009B^`L000]Ff`03001Fg5KL01=Fg003001Fo5Kl01=Fo003001FoEKm01=Fo@D0
01A?G`03001?GdmO00e?G`D000D_G@8000XcGQ8000`Jg080018No@8001<W7P03000[7b/O018[7`03
000_7blO00X_7`03000_7blO00D_7`03000c?c<o00Tc?bT000Xk?`03001oogoo029oo`03001oogoo
011oo`00Dgoo00<007ooOol0DGoo00<005=oDgl02E=o0`002Slo00<004/NBah04d/N00<004kMC]d0
4TkM00<004jkC[/04Djk00<005:KDY/04E:K00<005:JDYX00U:J2P001Dii00<0059iDWT04E9i00<0
059iDWT04E9i00<0059iDWT04E9i00<0059iDWT04E9i00<0059iDWT04U9i00<005:JDYX04U:J00<0
05:JDYX04e:J00<005:JDYX04U:J00<005:kD[/045:k1P004UKK00<005KLE]`055KL00<005KlE_`0
4eKl00<005KmE_d03UKm10000TmO00<004mOCel05DmO00<004mOCel01dmO1@0032mM0P000c=N1`00
20jj0`004a[L00<001km7_d04Akm00<002LN9ah04BLN00<002/O:al022/O:P002S/o00<003/o>cl0
4C/o00<003/o>cl04c/o00<007ooOol08Goo00<007ooOol047oo001COol00`00Oomoo`1BOol20006
Dgl3000>?cl00`00Bai;7P0CBah00`00C]e>g@0AC]d00`00C[]>^`0AC[/00`00DY]BV`0<DY/:000?
CWT00`00DWUBN@0ADWT00`00DWUBN@0ADWT00`00DWUBN@0ADWT00`00DWUBN@0BDWT00`00DWUBN@0B
DWT00`00DYYBVP0ADYX00`00DYYBVP0CDYX00`00DYYBVP0BDYX00`00D[]B^`0;D[/50002E]/00`00
E]]Ff`0DE]/00`00E]aFg00CE]`00`00E_aFo00CE_`00`00E_eFo@09E_d50007Cel00`00Cem?G`0E
Cel01000Cem?GdmO1@0042mMGP002S/O00<003/o>cl02S/o00<003/o>cl01C/o00<003/o>cl04c/o
00<003/o>cl04C/o00<003/o>cl04S/o00<007ooOol08Goo00<007ooOol047oo001COol00`00Oomo
o`1DOol00`00DgmCO`03000B?cl00`00Bai;7P0BBah00`00C]e>g@0BC]d00`00C[]>^`0@C[/00`00
DY]BV`03DY/90005CWX00`00CWU>N@0BCWT00`00DWUBN@0@DWT00`00DWUBN@0BDWT00`00DWUBN@0@
DWT00`00DWUBN@0BDWT00`00DWUBN@0BDWT00`00DYYBVP0BDYX00`00DYYBVP0BDYX00`00DYYBVP0B
DYX00`00D[]B^`06D[/50008E]/00`00E]]Ff`0CE]/00`00E]aFg00CE]`00`00E_aFo00DE_`00`00
E_eFo@04E_d4000=Cel00`00Cem?G`0CCel5000>;ed70004>al00`00>alk7`0A>al00`00>alk7`0A
>al00`00>alk7`0A>al00`00>alk7`0A>al00`00>alk7`0B>al00`00>clk?`09>cl00`00>clk?`06
>cl00`00>clk?`0B>cl00`00>clk?`0B>cl00`00>clk?`0B>cl00`00Oomoo`0POol00`00Oomoo`0@
Ool005=oo`03001oogoo05Eoo`8001Ho?`03001;7T/N019;7P03001>gDkM015>g@03001>^djk00Q>
^`h000i>NP03001>NDii019>N@03001BNE9i011BN@03001BNE9i019BN@03001BNE9i015BN@03001B
NE9i015BN@03001BNE9i019BN@03001BVU:J019BVP03001BVU:J019BVP03001BVU:J01=BVP03001B
^e:k00D000eFf`03001FfeKK01=Ff`03001Fg5KL01AFg003001Fo5Kl01=Fo003001FoEKm00@0019?
G`03001?GdmO00i?G`@000D[?0<000@_G@L000`k7`03000k7c/O014k7`03000k7c/O014k7`03000k
7c/O014k7`03000k7c/O014k7`03000k7c/O018k7`03000k?c/o00Pk?`03000k?c/o00Lk?`03000k
?c/o018k?`03000k?c/o014k?`03000k?c/o01<k?`03001oogoo01moo`03001oogoo011oo`00Dgoo
00<007ooOol0Egoo0P005Clo00<004/NBah04T/N00<004kMC]d034kM3`002DYk00<004ijCWX04Dij
00<004iiCWT04Dii00<0059iDWT04E9i00<0059iDWT04E9i00<0059iDWT04E9i00<0059iDWT04U9i
00<0059iDWT04E9i00<005:JDYX04U:J00<005:JDYX04e:J00<005:JDYX045:J1@004UKK00<005KK
E]/055KK00<005KLE]`04eKL00<005KlE_`04EKl1@005TmO00<004mOCel02TmO10002R/l1`004c/O
00<003/O>al04C/O00<003/O>al04C/O00<003/O>al04C/O00<003/O>al04C/O00<003/O>al04S/O
00<003/o>cl01c/o00<003/o>cl01c/o00<003/o>cl04c/o00<003/o>cl04C/o00<003/o>cl04S/o
00<007ooOol07goo00<007ooOol047oo001COol00`00Oomoo`1IOol00`00?clo?`0C?cl00`00Bai;
7P0ABah00`00C]e>g@03C]d90005@Y`00`00BW]:N`0@BW/00`00CWY>NP0ACWX00`00CWU>N@0BCWT0
0`00DWUBN@0@DWT00`00DWUBN@0ADWT00`00DWUBN@0ADWT00`00DWUBN@0BDWT00`00DWUBN@0BDWT0
0`00DYYBVP0BDYX00`00DYYBVP0BDYX00`00DYYBVP0;DYX50002E[X00`00E]]Ff`0CE]/00`00E]]F
f`0CE]/00`00E]aFg00DE]`00`00E_aFo00;E_`50003Del00`00Cem?G`0FCel00`00Cem?G`05Cel4
0009:c`50007>al00`00>alk7`0A>al00`00>alk7`0A>al00`00>alk7`0A>al00`00>alk7`0@>al0
0`00>alk7`0B>al00`00>alk7`0B>al00`00>clk?`06>cl00`00>clk?`08>cl00`00>clk?`0B>cl0
0`00>clk?`08>clP000POol00`00Oomoo`0@Ool001Uoo`@000ioo`<000aoo`X000moo`03001oogoo
05Yoo`8001@o?`03001;7T/N00Q;7Ph000m2W003001:NdYk011:N`03001>NTij011>NP03001>NDii
019>N@03001BNE9i011BN@03001BNE9i015BN@03001BNE9i015BN@03001BNE9i019BN@03001BNE9i
019BN@03001BVU:J019BVP03001BVU:J019BVP03001BVU:J00IBVPD000QF^P03001FfeKK019Ff`03
001FfeKK01AFf`03001Fg5KL01=Fg003001Fo5Kl00IFo0D000UCG`03001?GdmO01I?G`03001?GdmO
00@000P[?0D000dk7`03000k7c/O014k7`03000k7c/O014k7`03000k7c/O014k7`03000k7c/O010k
7`03000k7c/O018k7`03000k7c/O00Pk7cd000Y3?`03000o?clo018o?`03001oogoo01ioo`03001o
ogoo011oo`005goo20002goo1@002goo2P003Woo00<007ooOol0GGoo0P003clo3P002CJN00<004:L
@Y`04D:L00<004YkBW/044Yk00<004ijCWX04Dij00<004iiCWT04Dii00<0059iDWT04E9i00<0059i
DWT04E9i00<0059iDWT04E9i00<0059iDWT04E9i00<0059iDWT04U9i00<005:JDYX04U:J00<005:J
DYX04e:J00<005:JDYX01@003EJj00<005KKE]/04eKK00<005KKE]/04eKK00<005KLE]`04eKL00@0
05KlE_aFo0D000mCG`03001?GdmO01=?G`L000D[?8H000Y77`0300177dLO00E77`0300177dLO00U7
7`030013?d<o0193?`030013?d<o0193?`03000o?clo018o?`03001oogoo01eoo`03001oogoo011o
o`005goo0P0017oo0P002goo1@003goo0P004Woo00<007ooOol0Ggoo00<003lo?cl00clo2@00119m
00<003JN=Yh04CJN00<004:L@Y`044:L00<004YkBW/044Yk00<004ijCWX04Dij00<004iiCWT04Dii
00<0059iDWT04E9i00<0059iDWT04E9i00<0059iDWT04E9i00<0059iDWT04U9i00<0059iDWT04U9i
00<005:JDYX04U:J00<005:JDYX045:J1@004UJj00<005KKE]/04eKK00<005KKE]/055KK00<005KL
E]`04EKL1@005E=O00<004mOCel03DmO1@001R<J1P001DkM00<004kMC]d044kM00<004[MB]d04D[M
00<004[nB_h04D[n00<004[nB_h04D[n00<004[nB_h044[n00<004LOAal04TLO00<004LOAal04TLO
00<004LOAal014LO00<004LOAal02TLO00<004<o@cl04T<o00<004<o@cl04D<o00<003lo?cl04clo
00<007ooOol077oo00<007ooOol047oo000FOol20006Ool2000:Ool5000?Ool2000BOol00`00Oomo
o`1POol5000>4Wd00`00=YhfWP0@=Yh00`00@Ya2W00A@Y`00`00BW]:N`0@BW/00`00CWY>NP0@CWX0
0`00CWU>N@0BCWT00`00DWUBN@0@DWT00`00DWUBN@0ADWT00`00DWUBN@0ADWT00`00DWUBN@0BDWT0
0`00DWUBN@0BDWT00`00DYYBVP0BDYX00`00DYYBVP0;DYX50002E[X00`00E[YF^P0CE[X00`00E]]F
f`0BE]/00`00E]]Ff`0DE]/00`00E]aFg00=E]`40002Del00`00DemCG`0FDel00`00Cem?G`07Cel5
00068aX5000<C]d00`00C]e>g@0@C]d00`00B]e:g@0AB]d00`00B_i:oP0AB_h00`00B_i:oP0AB_h0
0`00B_i:oP0@B_h00`00Aam77`0BAal00`00Aam77`0AAal00`00Aam77`04Aal00`00Aam77`0:Aal0
0`00@cm3?`0B@cl00`00@cm3?`0B@cl00`00?clo?`0B?cl00`00Oomoo`0LOol00`00Oomoo`0@Ool0
01Ioo`8000Ioo`8000]oo`<0011oo`80019oo`03001oogoo00<005moo`03000BOA9m00lBO@03000f
WSJN010fWP030012W4:L0112W003001:NdYk011:N`03001>NTij011>NP03001>NDii019>N@03001B
NE9i011BN@03001BNE9i015BN@03001BNE9i019BN@03001BNE9i015BN@03001BNE9i019BN@03001B
VU:J019BVP03001BVU:J00IBVPD000MF^P03001F^UJj01=F^P03001FfeKK01=Ff`03001FfeKK01=F
f`03001Fg5KL00UFg0@000MCG`03001CGe=O01ICG`04001?GdmOCel500068aX5000AC]d00`00C]e>
g@0@C]d00`00B]e:g@0AB]d00`00B_i:oP0AB_h00`00B_i:oP0AB_h00`00B_i:oP0@B_h00`00Aam7
7`0BAal00`00Aam77`0BAal00`00Aam77`03Aal00`00Aam77`0;Aal00`00@cm3?`0B@cl00`00@cm3
?`0B@cl00`00?clo?`0B?cl00`00Oomoo`0LOol00`00Oomoo`0?Ool001Eoo`8000Qoo`8001eoo`80
019oo`<006=oo`80010BO@03000fWSJN00lfWP030012W4:L0152W003001:NdYk00m:N`03001>NTij
015>NP03001>NDii015>N@03001BNE9i015BN@03001BNE9i015BN@03001BNE9i015BN@03001BNE9i
019BN@03001BNE9i019BN@03001BVU:J019BVP03001BVU:J00D000eF^P03001F^UJj019F^P03001F
feKK01=Ff`03001FfeKK01AFf`03001Fg5KL00AFg0@000aCG`03001CGe=O01ACG`H000DS6PD000A>
_003001>gDkM011>g@03001>gDkM011>g@03001:gD[M015:g@03001:oT[n015:oP03001:oT[n011:
oP03001:oT[n015:oP0300177dLO01977`0300177dLO01577`0300177dLO00=77`0300177dLO00a7
7`030013?d<o0193?`030013?d<o0153?`03000o?clo00To?`/001eoo`03001oogoo00moo`005Goo
0P0027oo0P007Goo0P004Woo00<007ooOol0IGoo00<0019m4Wd03A9m00<003JN=Yh043JN00<004:L
@Y`044:L00<004YkBW/044Yk00<004ijCWX044ij00<004iiCWT04Dii00<0059iDWT04E9i00<0059i
DWT04E9i00<0059iDWT04E9i00<0059iDWT04U9i00<0059iDWT04U9i00<005:JDYX03e:J1P004UJj
00<005JjE[X04eJj00<005KKE]/04UKK00<005KKE]/055KK00<005KLE]`010004E=O00<005=ODel0
3e=O10001Q[h1@002Djl00<004kMC]d044kM00<004kMC]d044kM00<004[MB]d04D[M00<004[nB_h0
4D[n00<004[nB_h04D[n00<004[nB_h04D[n00<004LOAal04DLO00<004LOAal04TLO00<004LOAal0
0TLO00<004LOAal034LO00<004<o@cl04T<o00<004<o@cl024<o5@002T<o00<007ooOol06goo00<0
07ooOol03goo000EOol20008Ool2000MOol2000BOol00`00Oomoo`1VOol2000>4Wd00`00=YhfWP0?
=Yh00`00@Ya2W00@@Y`00`00BW]:N`0@BW/00`00CWY>NP0@CWX00`00CWU>N@0BCWT00`00DWUBN@0@
DWT00`00DWUBN@0ADWT00`00DWUBN@0ADWT00`00DWUBN@0BDWT00`00DWUBN@0BDWT00`00DYYBVP08
DYX70003EYT00`00E[YF^P0BE[X00`00E[YF^P0CE[X00`00E]]Ff`0CE]/00`00E]]Ff`0BE]/4000F
Del00`00DemCG`0:Del400056_P5000>C[`00`00C]e>g@0AC]d00`00C]e>g@0@C]d00`00B]e:g@0A
B]d00`00B_i:oP0AB_h00`00B_i:oP0@B_h00`00B_i:oP0AB_h00`00Aam77`0BAal00`00Aam77`0A
Aal60005AalY000:Acl00`00@cm3?`0C@cl00`00Oomoo`0JOol00`00Oomoo`0?Ool001Eoo`8000Qo
o`8001eoo`80019oo`03001oogoo06Qoo`03000BOA9m00`BO@03000fWSJN00lfWP030012W4:L0112
W003001:NdYk00m:N`03001>NTij015>NP03001>NDii015>N@03001BNE9i011BN@03001BNE9i015B
N@03001BNE9i019BN@03001BNE9i015BN@03001BNE9i01=BN@03001BVU:J00L000YFV@03001F^UJj
01=F^P03001F^UJj019F^P03001FfeKK01=Ff`03001FfeKK00iFf`@0009CG`03001CGe=O01ICG`03
001CGe=O00ECG`@000@Jn0H001=>_003001>gDkM011>g@03001>gDkM011>g@03001:gD[M015:g@03
001:oT[n015:oP03001:oT[n015:oP03001:oT[n015:oP0300177dLO01577`0300177dLO00I77aH0
00Y;7`03001;?d/o019;?`030017?dLo0197?`030013?d<o01=3?`03001oogoo01Uoo`03001oogoo
00moo`005Goo0P0027oo0P007Goo0P004Woo00<007ooOol0JGoo0`00319m00<003JN=Yh03cJN00<0
04:L@Y`03d:L00<004YkBW/044Yk00<004ijCWX044ij00<004iiCWT04Dii00<0059iDWT04E9i00<0
059iDWT04E9i00<0059iDWT04E9i00<0059iDWT04U9i00<0059iDWT0459i1@004UJI00<005JjE[X0
4UJj00<005JjE[X04eJj00<005KKE]/04eKK00<005KKE]/025KK1@001e=O00<005=ODel05U=O00<0
05=ODel010000a[h1@001Tjl00<004jlC[`044jl00<004kMC]d04DkM00<004kMC]d044kM00<004[M
B]d044[M00<004[nB_h04D[n00<004[nB_h04D[n00<004[nB_h04D[n00<004LOAal024LO50002T/N
00<004/OBal00T/O00<004/OBal03D/O00<004/oBcl04T/o00<004LoAcl04TLo00<004<o@cl04T<o
00<007ooOol06Goo00<007ooOol03goo000EOol20008Ool2000MOol2000BOol00`00Oomoo`1[Ool6
00074Wd00`00=YhfWP0?=Yh00`00@Ya2W00@@Y`00`00BW]:N`0?BW/00`00CWY>NP0@CWX00`00CWU>
N@0BCWT00`00DWUBN@0@DWT00`00DWUBN@0ADWT00`00DWUBN@0ADWT00`00DWUBN@0BDWT00`00DWUB
N@0;DWT50002EWT00`00EYUFV@0BEYT00`00E[YF^P0BE[X00`00E[YF^P0CE[X00`00E]]Ff`0CE]/0
0`00E]]Ff`04E]/4000=Del00`00DemCG`0DDel;000;C[`00`00C[a>_00@C[`00`00C]e>g@0AC]d0
0`00C]e>g@0@C]d00`00B]e:g@0AB]d00`00B_i:oP0AB_h00`00B_i:oP0@B_h00`00B_i:oP08B_hL
0002C_h00`00Bai;7P0BBah00`00Bam;7`02Bal00`00Bam;7`0<Bal00`00Bcm;?`0BBcl00`00Acm7
?`0BAcl00`00@cm3?`0>@cl6000JOol00`00Oomoo`0?Ool001Eoo`8000Qoo`8001eoo`80019oo`03
001oogoo06eoo`80009U80@000@BO@03000fWSJN00lfWP030012W4:L00m2W003001:NdYk00m:N`03
001>NTij011>NP03001>NDii019>N@03001BNE9i011BN@03001BNE9i015BN@03001BNE9i015BN@03
001BNE9i019BN@03001BNE9i00IBN@D000MFN@03001FVEJI019FV@03001F^UJj01=F^P03001F^UJj
019F^P03001FfeKK01=Ff`03001FfeKK00@0019CG`03001CGe=O00mCG`X0015>_003001>_4jl011>
_003001>gDkM015>g@03001>gDkM011>g@03001:gD[M011:g@03001:oT[n015:oP03001:oT[n00Q:
oQ<000M>o@X000i>oP03001;7T/N015;7P03001;7d/O00=;7`03001;7d/O00a;7`03001;?d/o019;
?`030017?dLo0197?`030013?d<o00=3?`X000E7G`03001oogoo01Qoo`03001oogoo00moo`005Goo
0P0027oo0P007Goo0P004Woo00<007ooOol0Kgoo00<006DPIB000fDP1P0043JN00<004:L@Y`044:L
00<004YkBW/03dYk00<004ijCWX044ij00<004iiCWT04Dii00<0059iDWT0459i00<0059iDWT04E9i
00<0059iDWT04U9i00<0059iDWT04U9i00<0059iDWT01@003EIi00<005JIEYT04UJI00<005JjE[X0
4UJj00<005JjE[X04eJj00<005KKE]/04EKK10005U=O00<005=ODel02U=O2P000djK00<004jlC[`0
44jl00<004jlC[`044jl00<004kMC]d04DkM00<004kMC]d044kM00<004[MB]d024[M9`002Dkm00<0
04kmC_d00dkm2`0014km00<004knC_h04Dkn00<004/NBah04T/N00<004/OBal00T/O00<004/OBal0
3D/O00<004/oBcl04T/o00<004LoAcl03DLo2P0044MO00<007ooOol05goo00<007ooOol03goo000F
Ool20006Ool2000NOol2000BOol00`00Oomoo`1`Ool20008IB04000>=Yh00`00@Ya2W00?@Y`00`00
BW]:N`0?BW/00`00CWY>NP0@CWX00`00CWU>N@0ACWT00`00DWUBN@0ADWT00`00DWUBN@0@DWT00`00
DWUBN@0BDWT00`00DWUBN@0?DWT6000BEWT00`00EYUFV@0BEYT00`00E[YF^P0BE[X00`00E[YF^P0C
E[X00`00E]]Ff`0>E]/30002Eeh00`00DemCG`0FDel00`00DemCG`05Del90008CY/00`00C[a>_00@
C[`00`00C[a>_00@C[`00`00C]e>g@08C]dW0009C]`00`00C]e>g@0AC]d00`00C_e>o@0<C_d:000?
C_d00`00C_i>oP0BC_h00`00Bai;7P0BBah00`00Bam;7`02Bal00`00Bam;7`0<Bal00`00Bcm;?`0B
Bcl00`00Acm7?`03Acl:0005Bcl00`00Aem7G`0CAel00`00Oomoo`0FOol00`00Oomoo`0?Ool001Io
o`8000Ioo`8001ioo`80019oo`03001oogoo079oo`03001U86DP00IU80030004m`Cg00D000TfWP03
0012W4:L00m2W003001:NdYk00m:N`03001>NTij011>NP03001>NDii019>N@03001BNE9i011BN@03
001BNE9i015BN@03001BNE9i015BN@03001BNE9i00QBN@L000=FN003001FNEIi019FN@03001FVEJI
019FV@03001F^UJj01=F^P03001F^UJj019F^P03001FfeKK00]Ff`<000IGGP03001CGe=O01ICG`03
001CGe=O04H000YB^`03001B_5:l011B_003001>g4kL015>g003001>gDkM015>g@03001>oDkm00/0
00E>o@03001>oDkm019>o@03001>oTkn015>oP03001;7T/N019;7P03001;7d/O00=;7`03001;7d/O
00a;7`03001;?d/o00e;?`X0011;?`030017GdMO0197G`03001oogoo01Ioo`03001oogoo00moo`00
5goo0P0017oo0P006goo0`0000=oo`0000004Woo00<007ooOol0LWoo00<006DPIB001fDP00<000Cg
1?L010Cg1@001CJN00<004:L@Y`03d:L00<004YkBW/03dYk00<004ijCWX044ij00<004iiCWT04Dii
00<0059iDWT0459i00<0059iDWT04E9i00<0059iDWT04U9i00<0059iDWT01`002UIh00<005IiEWT0
4UIi00<005JIEYT04UJI00<005JjE[X04eJj00<005JjE[X04eJj00<005KKE]/01UKK10002UMN00<0
05=ODel055=O1`0000=BVP00DYX045:J00<005:KDY/045:K00<005:kD[/045:k00<005:kD[/04U:k
00<005:lD[`045:l00<004kLC]`044kL00<004kMC]d02TkM2P004Dkm00<004kmC_d04Dkm00<004kn
C_h04Tkn00<004/NBah04T/N00<004/OBal00T/O00<004/OBal034/O00<004/oBcl00d/o2P001D/o
00<004/oBcl04T/o00<004MOAel04dMO00<007ooOol05Goo00<007ooOol03goo000GOol8000KOol6
000BOol00`00Oomoo`1cOol00`00IB1U8006IB000`001?L4m`091?L6000A@Y`00`00BW]:N`0?BW/0
0`00CWY>NP0@CWX00`00CWU>N@0ACWT00`00DWUBN@0ADWT00`00DWUBN@0@DWT00`00DWUBN@0?DWT6
000BEWP00`00EWUFN@0BEWT00`00EYUFV@0BEYT00`00E[YF^P0BE[X00`00E[YF^P0CE[X00`00E]]F
f`03E]/3000?Eeh00`00DemCG`0@Del50006DYX00`00DYYBVP0?DYX00`00DY]BV`0ADY/00`00D[]B
^`0@D[/00`00D[]B^`0AD[/00`00D[aB_00@D[`00`00C]a>g00AC]`<0007C]d00`00C_e>o@0AC_d0
0`00C_e>o@0BC_d00`00C_i>oP0AC_h00`00Bai;7P0BBah00`00Bam;7`03Bal00`00Bam;7`02Bal?
000@Bcl00`00Bcm;?`0BBcl00`00Aem7G`0@Ael4000FOol00`00Oomoo`0?Ool001Uoo`@0021oo`<0
015oo`D007=oo`03001U86DP00EU80030004m`Cg00h4m`D000i2W003001:NdYk00i:N`03001>NTij
011>NP03001>NDii015>N@03001BNE9i015BN@03001BNE9i011BN@03001BNE9i00QBN@L000=FF003
001FN5Ih019FN003001FNEIi019FN@03001FVEJI019FV@03001F^UJj01=F^P03001F^UJj019F^P03
001FfeKK00<001=GGP03001CGe=O00aCG`<000aBVP03001BVU:J00mBVP03001BVe:K011BV`03001B
^e:k011B^`03001B^e:k015B^`03001B_5:l011B_003001>g4kL00Q>g0X001=>g@03001>oDkm015>
o@03001>oDkm015>o@03001>oTkn019>oP03001;7T/N00e;7Pl000Y?7P03001;?d/o019;?`03001;
?d/o01=;?`030017GdMO00Q7G`L000=;G`03001oogoo01Aoo`03001oogoo00moo`00DGoo00<007oo
Ool0MWoo00<006DPIB001FDP00<000Cg1?L03PCg00@002UF:EHYEPL000M2W003001:NdYk00m:N`03
001>NTij00m>NP03001>NDii019>N@03001BNE9i011BN@03001BNE9i015BN@03001BNE9i00L000YF
F003001FN5Ih019FN003001FNEIi019FN@03001FVEJI019FV@03001F^UJj01=F^P03001F^UJj015F
^P@001IGGP03001CGe=O00QCG`@000mBVP03001BVU:J00mBVP03001BVe:K011BV`03001B^e:k011B
^`03001B^e:k019B^`03001B_5:l011B_0X000Y>g003001>gDkM011>g@03001>oDkm015>o@03001>
oDkm019>o@03001>oTkn015>oP03001;7T/N00=;7PX000E?7P03001?7TlN00A?7P03001?7TlN00]?
7P03001;?d/o019;?`03001;?d/o019;?`040017GdMOAel7000;Bel00`00Oomoo`0COol00`00Oomo
o`0?Ool0055oo`03001oogoo07Moo`03001U86DP00AU80030004m`Cg00h4m`03000YERUF00PYEPH0
0003@Y`004Yk011:N`03001>NTij011>NP03001>NDii015>N@03001BNE9i011BN@03001BNE9i00aB
N@P0019FF003001FN5Ih015FN003001FNEIi019FN@03001FVEJI01=FV@03001F^UJj019F^P03001F
^UJj00iF^P<0009GGP03001GGUMN01IGGP03001CGe=O00ACG`@0019BVP03001BVU:J00mBVP03001B
Ve:K015BV`03001B^e:k011B^`03001B^e:k015B^`03001B_5:l00EB_0`001=>g003001>gDkM015>
g@03001>oDkm011>o@03001>oDkm019>o@03001>oTkn00Q>oPl0011?7P03001?7TlN00=?7P03001?
7TlN00]?7P03001;?d/o01=;?`03001;?d/o00e;?`P0019;G`03001oogoo01=oo`03001oogoo00mo
o`00DGoo00<007ooOol0N7oo00<006DPIB0016DP00<000Cg1?L03@Cg00<002UF:EH03RUF20002dYk
00<004ijCWX044ij00<004iiCWT04Dii00<0059iDWT04E9i00<0059iDWT00U9i2@001EIG00<005IH
EUP04UIH00<005IhEWP04EIh00<005IiEWT04eIi00<005JIEYT04UJI00<005JjE[X04eJj00<005Jj
E[X02UJj0`001UMN00<005MNEeh05UMN00<005=ODel00`00159j00<005:JDYX045:J00<005:JDYX0
3e:J00<005:KDY/045:K00<005:kD[/045:k00<005:kD[/03e:k2P002e:l00<004kLC]`04DkL00<0
04kMC]d04DkM00<004kmC_d04Dkm00<004kmC_d03Dkm3`002TlN00<004lNCah04TlN00<004lNCah0
14lN00<004lNCah02dlN00<004/oBcl04T/o00<004/oBcl00d/o2P001D]O00<004]OBel04d]O00<0
07ooOol04Woo00<007ooOol03goo001AOol00`00Oomoo`1hOol00`00IB1U8004IB000`001?L4m`0>
1?L00`00:EHYEP0?:EH00`00?IHmUP03?IH90003BW/00`00CWY>NP0?CWX00`00CWU>N@0BCWT00`00
DWUBN@07DWT>000>EUL00`00EUQFF00BEUP00`00EWQFN00BEWP00`00EWUFN@0BEWT00`00EYUFV@0B
EYT00`00E[YF^P0CE[X00`00E[YF^P06E[X4000:Eeh00`00EeiGGP0DEeh40007DWX00`00DYYBVP0@
DYX00`00DYYBVP0?DYX00`00DY]BV`0@DY/00`00D[]B^`0@D[/00`00D[]B^`04D[/;0003D[/00`00
D[aB_00@D[`00`00C]a>g00AC]`00`00C]e>g@0AC]d00`00C_e>o@0@C_d00`00C_e>o@03C_d:0005
D_d00`00Cai?7P0BCah00`00Cai?7P0BCah00`00Cai?7P04Cah00`00Cai?7P0:Cah00`00Bcm;?`0@
Bcl8000@Bel00`00Bem;G`0BBel00`00Oomoo`0BOol00`00Oomoo`0?Ool0055oo`03001oogoo07Uo
o`03001U86DP00=U80030004m`Cg00h4m`03000YERUF00lYEP03000mUSfF00`mUPh000Q>NP03001>
NDii00M>NA@000UFEP03001FEeIG011FE`03001FF5IH019FF003001FN5Ih019FN003001FNEIi019F
N@03001FVEJI01=FV@03001F^UJj019F^P03001F^UJj00=F^P<000mGGP03001GGUMN011GGP<000]B
NP03001BVU:J011BVP03001BVU:J00mBVP03001BVe:K015BV`03001B^e:k00aB^`X000iB^`03001B
_5:l011B_003001>g4kL015>g003001>gDkM015>g@03001>oDkm00a>o@X0011Bo@03001?7TlN015?
7P03001?7TlN019?7P03001?7TlN00E?7P03001?7TlN00Y?7P03001;?d/o00Q;?`L000=??`03001;
Gd]O019;G`03001;Gd]O011;G`@001=oo`03001oogoo00moo`00DGoo00<007ooOol0NWoo00<006DP
IB000fDP00<000Cg1?L03@Cg00<002UF:EH03bUF00<003fF?IH03cfF00<005HFEQH025HF4P002UHf
00<005IFEUH045IF00<005IGEUL04EIG00<005IHEUP04EIH00<005IhEWP04UIh00<005IiEWT04eIi
00<005JIEYT04UJI00<005JjE[X04eJj00<005Jj00000P004eMN00<005MNEeh035MN0`003U9j00<0
05:JDYX04E:J00<005:JDYX03e:J00<005:KDY/045:K00@005:kD[]B^`/000AB^`03001B^e:k015B
^`03001B_5:l011B_003001>g4kL019>g003001>gDkM011>g@03001>oDkm00=>o@T000EBo@03001B
oE;m019Bo@03001?7TlN015?7P03001?7TlN019?7P03001?7TlN00E?7P03001?7TlN00Y?7P04001;
?d/oBcl7000;Ccl00`00Bem;G`0BBel00`00Bem;G`08Bel70003Bel00`00Oomoo`0BOol00`00Oomo
o`0>Ool0055oo`03001oogoo07]oo`03001U86DP009U80030004m`Cg00d4m`03000YERUF00lYEP03
000mUSfF00lmUP03001F5UHF011F5P03001F=UHf015F=P03001FEUIF011FEP03001FEeIG015FE`03
001FF5IH019FF003001FN5Ih015FN003001FNEIi01=FN@03001FVEJI019FV@03001F^UJj015F^P@0
01IGGP03001GGUMN00QGGP@0019BNP03001BVU:J011BVP03001BVU:J00mBVP03001BVe:K00YBV`X0
011B^`03001B^e:k015B^`03001B_5:l011B_003001>g4kL015>g003001>gDkM00Q>g@h000mBo@03
001BoE;m019Bo@03001?7TlN015?7P03001?7TlN019?7P03001?7TlN00E?7P03001?7TlN00E?7PP0
019??`03001;Gd]O019;G`04001;Gd]OBel7000;Bel00`00Oomoo`0AOol00`00Oomoo`0>Ool0055o
o`03001oogoo07aoo`03001U86DP009U80030004m`Cg00`4m`03000YERUF00lYEP03000mUSfF00lm
UP03001F5UHF011F5P03001F=UHf015F=P03001FEUIF015FEP03001FEeIG011FE`03001FF5IH019F
F003001FN5Ih019FN003001FNEIi019FN@03001FVEJI019FV@03001F^UJj00iF^P<0009KGP03001G
GUMN01IGGP03001GGUMN00AGGP<000=BN@03001BNU9j011BNP03001BVU:J011BVP03001BVU:J00mB
VP03001BV`0000X000MBV`03001B^e:k011B^`03001B^e:k015B^`03001B_5:l011B_003001>g4kL
00e>g0l000UBg003001BoE;m015Bo@03001BoE;m019Bo@03001?7TlN015?7P03001?7TlN019?7P03
001?7TlN00=?7PX000E??`03001??dlo01=??`03001;Gd]O00m;G`H001=;G`03001oogoo011oo`03
001oogoo00ioo`00DGoo00<007ooOol0O7oo00<006DPIB000VDP00<000Cg1?L030Cg00<002UF:EH0
3bUF00<003fF?IH03cfF00<005HFEQH045HF00<005HfESH04EHf00<005IFEUH04EIF00<005IGEUL0
45IG00<005IHEUP04UIH00<005IhEWP04UIh00<005IiEWT04UIi00<005JIEYT04eJI00<005JjE[X0
2UJj0`001U]N00<005MNEeh05UMN00<005MNEeh00`001e9i00<0059jDWX03e9j00<005:JDYX045:J
00<005:JDYX01e:J2P004U:K00<005:kD[/045:k00<005:kD[/04E:k00<005:lD[`045:l00<004kL
C]`00dkL2P001E;L00<005;LD]`04E;L00<005;mD_d045;m00<005;mD_d04e;m00<004lNCah04DlN
00<004lNCah03dlN20000dlo00<004loCcl02Tlo00<004loCcl04Tlo00<004]OBel024]O1`000d]O
00<004]OBel054]O00<007ooOol03goo00<007ooOol03Woo001AOol00`00Oomoo`1mOol01@00IB1U
86DP00003`Cg00<002UF:EH03bUF00<003fF?IH03SfF00<005HFEQH045HF00<005HfESH04EHf00<0
05IFEUH04EIF00<005IGEUL045IG00<005IHEUP04UIH00<005IhEWP04UIh00<005IiEWT04eIi00<0
05JIEYT04UJI00<005JjE[X01UJj10002U]N00<005MNEeh055MN10002U9i00<0059jDWX03e9j00<0
05:JDYX03e:J2`002E:J00<005:KDY/045:K00<005:kD[/04E:k00<005:kD[/04E:k00<005:lD[`0
1e:l3P0045;L00<005;LD]`045;L00<005;mD_d04E;m00<005;mD_d04U;m00<004lNCah04DlN00<0
04lNCah024lN1`000e<n00<004loCcl01Tlo00<004loCcl02Dlo00<004loCcl04Tlo00@004]OBem;
G`L000];G`03001;Gd]O019;G`<0011oo`03001oogoo00ioo`00DGoo00<007ooOol0OWoo00D006DP
IB1U800000h4m`03000YERUF00lYEP03000mUSfF00hmUP03001F5UHF011F5P03001F=UHf019F=P03
001FEUIF011FEP03001FEeIG015FE`03001FF5IH015FF003001FN5Ih019FN003001FNEIi01=FN@03
001FVEJI019FV@03001F^UJj00=F^P<000mKGP03001GGUMN011GGP<000iBN@03001BNU9j011BNP03
001BVU:J00ABVPX0009BVP03001BVU:J00mBVP03001BVe:K015BV`03001B^e:k011B^`03001B^e:k
00aB^`l000UBg003001Bg5;L019Bg003001Bg5;L011Bg003001BoE;m015Bo@03001BoE;m019Bo@03
001?7TlN015?7P04001?7TlNCah7000;Dch00`00Ccm??`06Ccl00`00Ccm??`09Ccl00`00Ccm??`0?
Ccl6000CBel00`00Bem;G`0<Bel50002Bgl00`00Oomoo`0>Ool00`00Oomoo`0>Ool0055oo`@007io
o`04001U86DP000>1?L00`00:EHYEP0?:EH00`00?IHmUP0>?IH00`00EQIF5P0@EQH00`00ESIF=P0B
ESH00`00EUIFEP0@EUH00`00EUMFE`0AEUL00`00EUQFF00BEUP00`00EWQFN00BEWP00`00EWUFN@0B
EWT00`00EYUFV@0CEYT00`00E[X00002000CFeh00`00EeiGGP0<Eeh3000ADWT00`00DWYBNP0<DWX;
000<DYX00`00DYYBVP0@DYX00`00DY]BV`0@DY/00`00D[]B^`0@D[/00`00D[]B^`03D[/90005D[/0
0`00D]aBg00AD]`00`00D]aBg00AD]`00`00D]aBg00AD]`00`00D_eBo@0AD_d00`00D_eBo@0BD_d0
0`00Cai?7P0<Cah8000BDch00`00Ccm??`07Ccl00`00Ccm??`09Ccl00`00Ccm??`07Ccl70003Cel0
0`00Bem;G`0CBel00`00Bem;G`07Bel50008Bgl00`00Oomoo`0=Ool00`00Oomoo`0>Ool0055oo`03
001oogoo081oo`03001U800000h4m`03000YERUF00lYEP03000mUSfF00hmUP03001F5UHF015F5P03
001F=UHf015F=P03001FEUIF011FEP03001FEeIG015FE`03001FF5IH019FF003001FN5Ih019FN003
001FNEIi019FN@03001FVEJI015FV@@001IKGP03001GGUMN00QGGP@0009BN@03001BNE9i011BN@04
001BNU9jDWX:0004DWX00`00DYYBVP0ADYX00`00DYYBVP0?DYX00`00DY]BV`0@DY/00`00D[]B^`08
D[/>000?D[/00`00D]aBg00@D]`00`00D]aBg00BD]`00`00D]aBg00@D]`00`00D_eBo@0AD_d00`00
D_eBo@0BD_d00`00Cai?7P03Cah90005Dah00`00DciC?P0CDch00`00Ccm??`06Ccl00`00Ccm??`09
Ccl01000Ccm??dlo1P002dmO00<004]OBel04d]O00@004]OBem;G`D000e;O`03001oogoo00eoo`03
001oogoo00ioo`00DGoo00<007ooOol0PGoo00<006DP00003@Cg00<002UF:EH03bUF00<003fF?IH0
3cfF00<005HFEQH045HF00<005HfESH04EHf00<005IFEUH045IF00<005IGEUL04EIG00<005IHEUP0
4UIH00<005IhEWP04UIh00<005IiEWT04eIi00<005JIEYT03EJI0`000U/m00<005]NFeh05U]N00<0
05MNEeh015MN0`001U9i00<0059iDWT02E9i2`003e9j00<005:JDYX045:J00<005:JDYX03e:J00<0
05:KDY/035:K3`002E:k00<005:kD[/04E:k00<005;LD]`04E;L00<005;LD]`04E;L00<005;LD]`0
4E;L00<005;mD_d04E;m00<005;mD_d03e;m20003e<N00<005<nDch04U<n00<004loCcl01dlo00<0
04loCcl01Tlo1P004TmO00<004]OBel044]O1P004d]o00<007ooOol037oo00<007ooOol03Woo001@
Ool00`00Oomoo`22Ool00`00IB00000=1?L00`00:EHYEP0?:EH00`00?IHmUP0??IH00`00EQIF5P0@
EQH00`00ESIF=P0AESH00`00EUIFEP0AEUH00`00EUMFE`0@EUL00`00EUQFF00BEUP00`00EWQFN00B
EWP00`00EWUFN@0CEWT00`00EYUFV@0:EYT30006Fcd00`00FeiKGP0FFeh00`00EeiGGP030009DWT0
0`00DWT000090007DWT00`00DWYBNP0@DWX00`00DYYBVP0@DYX00`00DYYBVP0@DYX00`00DY]BV`02
DY/90005D[/00`00D[]B^`0AD[/00`00D[]B^`0@D[/00`00D]aBg00AD]`00`00D]aBg00AD]`00`00
D]aBg00AD]`00`00D_eBo@0AD_d00`00D_eBo@08D_d70003Dad00`00DaiC7P0ADah00`00DciC?P0C
Dch00`00Ccm??`07Ccl80003Cel00`00Cem?G`0BCel00`00Bem;G`09Bel70003Bgl00`00Bgm;O`0C
Bgl00`00Oomoo`0<Ool00`00Oomoo`0>Ool0051oo`03001oogoo08=oo`03001U800000d4m`03000Y
ERUF00hYEP03000mUSfF00lmUP03001F5UHF011F5P03001F=UHf015F=P03001FEUIF015FEP03001F
EeIG015FE`03001FF5IH015FF003001FN5Ih019FN003001FNEIi01=FN@03001FVEJI00IFV@@000YK
?@03001KGU]N01EKGP<000=BN@/0019BN@03001BNU9j00mBNP03001BVU:J015BVP03001BVU:J00IB
VPh000mB^`03001B^e:k011B^`03001B^e:k015B^`03001Bg5;L011Bg003001Bg5;L019Bg003001B
g5;L015Bg003001BoE;m011Bo@04001BoE;mD_d7000;Dad00`00DaiC7P0ADah00`00DciC?P0BDch0
1000Ccm??dlo20002TmO00<004mOCel04TmO00@004]OBem;G`L000];O`03001;Od]o011;O`@000eo
o`03001oogoo00ioo`00D7oo00<007ooOol0Q7oo0P003@Cg00<002UF:EH03RUF00<003fF?IH03cfF
00<005HFEQH045HF00<005HfESH04EHf00<005IFEUH04EIF00<005IGEUL04EIG00<005IHEUP04UIH
00<005IhEWP04UIh00<005IiEWT04UIi00<005JIEYT00eJI0`003U/m00<005]NFeh04E]N2P002U9i
00<0059iDWT0459i00<0059jDWX03e9j00<005:JDYX035:J3P002E:J00<005:kD[/04E:k00<005:k
D[/045:k00<005:kD[/04E:k00<005;LD]`04E;L00<005;LD]`04E;L00<005;LD]`04E;L00<005;m
D_d035;m20004U<M00<005<NDah04U<N00<005<nDch045<n1@001dmO00<004mOCel024mO00<004mO
Cel04DmO1@004d]o00<004]oBgl024]o1`000dMo00<007ooOol02goo00<007ooOol03Woo001@Ool0
0`00Oomoo`25Ool00`001?L4m`0;1?L00`00:EHYEP0>:EH00`00?IHmUP0??IH00`00EQIF5P0@EQH0
0`00ESIF=P0AESH00`00EUIFEP0AEUH00`00EUMFE`0AEUL00`00EUQFF00BEUP00`00EWQFN00BEWP0
0`00EWUFN@0CEWT00`00EYT00002000BFcd00`00FeiKGP05Feh<00000e9i001BN@0@DWT00`00DWUB
N@0@DWT00`00DWYBNP0@DWX00`00DYYBVP02DYX90005DYX00`00DYYBVP0@DYX00`00D[]B^`0@D[/0
0`00D[]B^`0AD[/00`00D[]B^`0@D[/00`00D]aBg00AD]`00`00D]aBg00AD]`00`00D]aBg00AD]`0
0`00D_eBo@03D_d90005D_d00`00DaeC7@0BDad00`00DaiC7P0BDah00`00DciC?P0;Dch50002Cel0
0`00Cem?G`08Cel00`00Cem?G`08Cel00`00Cem?G`0;Cel50002Bgl00`00Bgm;O`0CBgl01000Bgm;
Od]o1`002dMo00<007ooOol02Woo00<007ooOol03Woo001@Ool00`00Oomoo`26Ool00`001?L4m`0:
1?L00`00:EHYEP0>:EH00`00?IHmUP0??IH00`00EQIF5P0@EQH00`00ESIF=P0AESH00`00EUIFEP0A
EUH00`00EUMFE`0AEUL00`00EUQFF00BEUP00`00EWQFN00BEWP00`00EWUFN@0BEWT3000CFcd:0006
Feh30004DWT00`00DWUBN@0?DWT00`00DWUBN@0ADWT00`00DWYBNP06DWX>000>DYX00`00DYYBVP0@
DYX00`00D[]B^`0AD[/00`00D[]B^`0@D[/00`00D[]B^`0AD[/00`00D]aBg00AD]`00`00D]aBg00A
D]`00`00D]aBg00>D]`8000?D_d00`00DaeC7@0BDad00`00DaiC7P0BDah00`00DciC?P05Dch50008
Cel00`00Cem?G`08Cel00`00Cem?G`08Cel00`00Cem?G`05Cel50008Bgl00`00Bgm;O`0ABgl5000C
Agl00`00Oomoo`09Ool00`00Oomoo`0>Ool0051oo`03001oogoo08Ioo`030004m`Cg00X4m`03000Y
ERUF00hYEP03000mUSfF00lmUP03001F5UHF011F5P03001F=UHf015F=P03001FEUIF015FEP03001F
EeIG015FE`03001FF5IH019FF003001FN5Ih019FN003001FNEIi00mFN@<00003Fcd005/m00QK?@/0
00AK?@03001KGU]N00IKGP<000MBN@03001BNE9i00mBN@03001BNE9i00aBN@h000UBVP03001BVU:J
015BVP03001BVU:J00mBVP03001B^e:k015B^`03001B^e:k011B^`03001B^e:k015B^`03001Bg5;L
015Bg003001Bg5;L015Bg003001Bg5;L00MBg0L000=Bo@03001BoE;m015Bo@03001C7E<M019C7@03
001C7U<N019C7P03001C?U<n00D000e?G`03001?GdmO00U?G`03001?GdmO00M?G`03001?GdmO00D0
00i;O`03001;Od]o00];O`D00093O`030017OdMo01=7O`03001oogoo00Uoo`03001oogoo00ioo`00
D7oo00<007ooOol0Qgoo00<000Cg1?L02@Cg00<002UF:EH03bUF00<003fF?IH03SfF00<005HFEQH0
45HF00<005HfESH04UHf00<005IFEUH045IF00<005IGEUL04UIG00<005IHEUP04EIH00<005IhEWP0
4eIh00<005IiEWT035Ii0P0015/m2P003e/m00<005]NFeh00e]N0`002U9i00<0059iDWT0459i00<0
059iDWT00U9i2@001E:J00<005:JDYX03e:J00<005:JDYX04E:J00<005:JDYX045:J00<005:kD[/0
45:k00<005:kD[/04E:k00<005:kD[/04E:k00<005;LD]`04E;L00<005;LD]`045;L00@005;LD]aB
g0H000]Bo@03001BoE;m015Bo@03001C7E<M019C7@03001C7U<N00mC7PD001=?G`03001?GdmO00Q?
G`03001?GdmO00E?G`D001=;O`03001;Od]o00I;O`D000Q3O`030017OdMo0117O`@000Yoo`03001o
ogoo00ioo`00D7oo00<007ooOol0R7oo00<000Cg1?L02@Cg00<002UF:EH03RUF00<003fF?IH03SfF
00<005HFEQH045HF00<005HfESH04UHf00<005IFEUH04EIF00<005IGEUL04EIG00<005IHEUP04UIH
00<005IhEWP04UIh00<005IiEWT025Ii2P000U/m00<005/mFcd05E/m00<005]N00000P003U9i00<0
059iDWT01U9i3P003U:J00<005:JDYX045:J00<005:JDYX045:J00<005:JDYX045:J00<005:kD[/0
4E:k00<005:kD[/045:k00<005:kD[/04E:k00<005;LD]`04E;L00<005;LD]`035;L20004E;m00<0
05;mD_d04E;m00<005<MDad04U<M00<005<NDah025<N1`000dlo00<004mOCel04dmO00<004mOCel0
24mO1`000d]o00<004]oBgl04d]o00<004]oBgl01@003T=o00<004MoAgl024Mo1`000d=O00<007oo
Ool027oo00<007ooOol03Woo001@Ool00`00Oomoo`28Ool00`001?L4m`091?L00`00:EHYEP0>:EH0
0`00?IHmUP0>?IH00`00EQIF5P0@EQH00`00ESIF=P0BESH00`00EUIFEP0AEUH00`00EUMFE`0AEUL0
0`00EUQFF00BEUP00`00EWQFN00BEWP<000<Fcd00`00FceK?@0DFcd2000=DWT=0009DWT00`00DYYB
VP0ADYX00`00DYYBVP0?DYX00`00DYYBVP0ADYX00`00DYYBVP0?DYX00`00D[]B^`0AD[/00`00D[]B
^`0AD[/00`00D[]B^`0@D[/00`00D]aBg00AD]`00`00D]aBg003D]`90005E_`00`00D_eBo@0BD_d0
0`00D_eBo@0AD_d00`00DaeC7@0ADad01000DaiC7U<N1`002dlo00<004mOCel04TmO00@004mOCem?
G`L00003Bgl004]o00Q;O`03001;Od]o011;O`D001A3O`040017OdMoAgl6000;@el00`00Oomoo`07
Ool00`00Oomoo`0>Ool0051oo`04001oo`000028Ool00`001?L4m`081?L00`00:EHYEP0>:EH00`00
?IHmUP0>?IH00`00EQIF5P0AEQH00`00ESIF=P0AESH00`00EUIFEP0AEUH00`00EUMFE`0AEUL00`00
EUQFF00BEUP00`00EWQFN008EWP;0006EWT3000>Fcd00`00FceK?@0AFcd300000e9i001BN@03DWT9
0004DWT00`00DWUBN@0?DWT00`00DYYBVP0ADYX00`00DYYBVP0?DYX00`00DYYBVP0ADYX00`00DYYB
VP0@DYX00`00D[]B^`0@D[/00`00D[]B^`0AD[/00`00D[]B^`0AD[/00`00D]aBg00>D]`8000?E_`0
0`00D_eBo@0AD_d00`00D_eBo@0AD_d00`00DaeC7@0?Dad6000BCcl00`00Cem?G`0ACel50008Bgl0
0`00Bgm;O`08Bgl00`00Bgm;O`08Bgl70003@gl00`00@gm3O`0A@gl6000A@el00`00Oomoo`07Ool0
0`00Oomoo`0>Ool0051oo`8008]oo`030004m`Cg00L4m`03000YERUF00hYEP03000mUSfF00hmUP03
001F5UHF015F5P03001F=UHf015F=P03001FEUIF015FEP03001FEeIG015FE`03001FF5IH019FF0/0
00YFN003001FNEIi009FN@80019K?@03001K?E/m00eK?@`000eBN@03001BNE9i011BN@03001BVU:J
011BVP03001BVU:J011BVP03001BVU:J011BVP03001BVU:J011BVP03001B^e:k015B^`03001B^e:k
011B^`03001B^e:k015B^`03001Bg5;L00MBg0L000=Fg003001Fo5Kl015Fo003001BoE;m019Bo@03
001BoE;m015Bo@03001C7E<M00MC7@L000=C?P03001??dlo01=??`03001?GdmO00]?G`D0009;O`03
001;Od]o00U;O`03001;Od]o00M;O`04001;Od]oBgl7000;@gl00`00@gm3O`09@gl70003@el00`00
@em3G`0B@el00`00Oomoo`07Ool00`00Oomoo`0=Ool0051oo`03001oogoo08]oo`030004m`Cg00H4
m`03000YERUF00hYEP03000mUSfF00hmUP03001F5UHF015F5P03001F=UHf015F=P03001FEUIF015F
EP03001FEeIG019FE`03001FF5IH00MFF0/001EFN0@001EK?@03001K?E/m00UK?@<000MBN@03001B
NE9i011BN@03001BNE9i00mBN@03001BVU:J015BVP03001BVU:J00mBVP03001BVU:J015BVP03001B
VU:J00mBVP03001B^e:k015B^`03001B^e:k015B^`03001B^e:k011B^`04001Bg5;LD]`6000;E]`0
0`00E_aFo00@E_`00`00D_eBo@0BD_d00`00D_eBo@0AD_d01000DaeC7E<M1P002e<n00<004loCcl0
4dlo00<004mOCel01DmO1@0024]o00<004]oBgl02D]o00<004]oBgl01D]o1@004d=o00@004=o@gm3
O`L000]3G`030013Gd=O0153G`03001oogoo00Moo`03001oogoo00eoo`00D7oo00<007ooOol0Rgoo
00<000Cg1?L01PCg00<002UF:EH03RUF00<003fF?IH03SfF00<005HFEQH04EHF00<005HfESH04EHf
00<005IFEUH04EIF00<005IGEUL04EIG2`002eIH00<005IhEWP04EIh0P0065/m00<005/mFcd01e/m
0P002U9i00<0059iDWT0459i00<0059iDWT03e9i00<005:JDYX04E:J00<005:JDYX03e:J00<005:J
DYX04E:J00<005:JDYX045:J00<005:kD[/045:k00<005:kD[/04E:k00<005:kD[/035:k20004EKL
00<005KlE_`04EKl00<005;mD_d04E;m00<005;mD_d03e;m1P004U<n00<004loCcl04Tlo00<004mO
Cel01@003T]o00<004]oBgl02D]o00<004]o000010000cmo00<004=o@gl044=o1P004d=O00<004=O
@el034=O1P0027oo00<007ooOol03Goo001@Ool00`00Oomoo`2<Ool00`001?L4m`051?L00`00:EHY
EP0>:EH00`00?IHmUP0>?IH00`00EQIF5P0AEQH00`00ESIF=P0AESH00`00EUIFEP0AEUH00`00EUMF
E`07EUL:00000eIG001FF00CEUP00`00EWQFN00>EWP300000ell001K?@0HFcd00`00FceK?@03Fcd3
000=DWT00`00DWUBN@0?DWT00`00DWUBN@0@DWT00`00DYYBVP0@DYX00`00DYYBVP0@DYX00`00DYYB
VP0@DYX00`00DYYBVP0@DYX00`00D[]B^`0AD[/00`00D[]B^`0@D[/00`00D[]B^`03D[/90005E]/0
0`00E]aFg00AE]`00`00E_aFo00AE_`00`00D_eBo@0BD_d00`00D_eBo@07D_d70003Dch00`00DciC
?P0BDch00`00Ccm??`0ACcl4000CBgl00`00Bgm;O`06Bgl50009?gl00`00@gm3O`08@gl70003?el0
0`00@em3G`0C@el00`00@em3G`03@el90005@el00`00Oomoo`06Ool00`00Oomoo`0=Ool0051oo`03
001oogoo08eoo`030004m`Cg00D4m`03000YERUF00dYEP03000mUSfF00lmUP03001F5UHF011F5P03
001F=UHf015F=P03001FEUIF011FEP/000]FE`03001FF5IH019FF003001FN5Ih00]FN0<000EO?003
001K?E/m01MK?@03001K?@000080011BN@03001BNE9i00mBN@03001BNE9i011BN@03001BVU:J011B
VP03001BVU:J011BVP03001BVU:J011BVP03001BVU:J011BVP03001B^e:k015B^`03001B^e:k00iB
^`P000mFf`03001Fg5KL015Fg003001Fo5Kl015Fo003001BoE;m015Bo@04001BoE;mD_d6000;Dch0
0`00DciC?P0BDch00`00Ccm??`0;Ccl50002Bgl00`00Bgm;O`0CBgl00`00Bgm;O`050004?gl00`00
?gloO`08?gl01000@gm3Od=o1P002cmO00<004=O@el044=O20003d=O00<007ooOol01Goo00<007oo
Ool03Goo001@Ool00`00Oomoo`2=Ool00`001?L4m`051?L00`00:EHYEP0=:EH00`00?IHmUP0??IH0
0`00EQIF5P0@EQH00`00ESIF=P0AESH00`00EUIFEP06EUH:0002EUH00`00EUMFE`0AEUL00`00EUQF
F00BEUP00`00EWQFN008EWP30009Gc`00`00FceK?@0FFcd200000e9i001BN@0@DWT00`00DWUBN@0@
DWT00`00DWUBN@0?DWT00`00DYYBVP0ADYX00`00DYYBVP0?DYX00`00DYYBVP0ADYX00`00DYYBVP0@
DYX00`00D[]B^`0@D[/00`00D[]B^`07D[/70003E[/00`00E]]Ff`0AE]/00`00E]aFg00AE]`00`00
E_aFo00AE_`00`00D_eBo@0@D_d5000BDch00`00DciC?P0ADch00`00Ccm??`06Ccl50008Bgl00`00
Bgm;O`0@Bgl5000:?gl00`00?gloO`06?gl5000B?el00`00@em3G`08@el70003?el00`00@em3G`0B
@el00`00Oomoo`04Ool00`00Oomoo`0=Ool004moo`03001oogoo08moo`030004m`Cg00@4m`03000Y
ERUF00dYEP03000mUSfF00lmUP03001F5UHF011F5P03001F=UHf00mF=P/000aFEP03001FEeIG019F
E`03001FF5IH015FF003001FN5Ih00EFN0<000eO?003001K?E/m019K?@<000=BN@03001BNE9i00mB
N@03001BNE9i011BN@03001BNE9i011BN@03001BVU:J011BVP03001BVU:J00mBVP03001BVU:J015B
VP03001BVU:J011BVP03001B^e:k015B^`03001B^e:k00H000]F^`03001FfeKK011Ff`03001Fg5KL
019Fg003001Fo5Kl015Fo003001BoE;m00YBo@D0009C?P03001C?U<n019C?P03001C?U<n019C?P03
001??dlo00D000i;O`03001;Od]o00Q;O`L000@oO`03000oOcmo00ToO`03000oOcmo00D000<kG`03
000oGcmO018oG`040013Gd=O@el6000;?el00`00@em3G`0A@el00`00Oomoo`04Ool00`00Oomoo`0=
Ool004moo`03001oogoo091oo`030004m`Cg00<4m`03000YERUF00hYEP03000mUSfF00hmUP03001F
5UHF011F5P03001F=UHf00EF=PX000=F=P03001FEUIF015FEP03001FEeIG019FE`03001FF5IH019F
F004001FN5IhEWP3000@Gc`00`00FceK?@0@Fcd20006DWT00`00DWUBN@0@DWT00`00DWUBN@0?DWT0
0`00DWUBN@0@DWT00`00DYYBVP0@DYX00`00DYYBVP0@DYX00`00DYYBVP0@DYX00`00DYYBVP0@DYX0
0`00D[]B^`0<D[/8000AE[/00`00E]]Ff`0AE]/00`00E]aFg00AE]`00`00E_aFo00AE_`00`00D_eB
o@05D_d50008Dch00`00DciC?P0BDch00`00DciC?P0?Dch5000DBgl01000Bgm;Od]o1P0033mo00<0
03mo?gl01Smo1@002C]O00<003mO?el03CmO20004SmO00<004=O@el034=O1P001Goo00<007ooOol0
3Goo001?Ool00`00Oomoo`2AOol00`001?L4m`021?L00`00:EHYEP0>:EH00`00?IHmUP0>?IH00`00
EQIF5P0=EQH;000=ESH00`00EUIFEP0AEUH00`00EUMFE`0BEUL00`00EUQFF00BEUP4000DGc`00`00
FceK?@0<Fcd30009DWT00`00DWUBN@0?DWT00`00DWUBN@0?DWT00`00DWUBN@0@DWT00`00DYYBVP0A
DYX00`00DYYBVP0?DYX00`00DYYBVP0ADYX00`00DYYBVP0@DYX00`00D[]B^`02D[/90005E[/00`00
E[]F^`0AE[/00`00E]]Ff`0AE]/00`00E]aFg00AE]`00`00E_aFo00AE_`00`00D_eBo@05000=Dch0
0`00DciC?P0BDch00`00DciC?P08Dch70003Bgl00`00Bgm;O`0BBgl5000C?gl00`00?gloO`050003
>el00`00>elkG`09>el00`00?eloG`03?el90005?el00`00?eloG`0B?el00`00@em3G`03@el90005
@el00`00Oomoo`03Ool00`00Oomoo`0=Ool004moo`03001oogoo095oo`030004m`Cg0084m`03000Y
ERUF00hYEP03000mUSfF00hmUP03001F5UHF00=F5PX000=F5P03001F=UHf019F=P03001FEUIF015F
EP03001FEeIG019FE`03001FF5IH015FF08001QO?003001K?E/m00UK?@8000aBN@03001BNE9i00mB
N@03001BNE9i011BN@03001BNE9i011BN@03001BVU:J011BVP03001BVU:J00mBVP03001BVU:J015B
VP03001BVU:J00eBVPP000mF^`03001F^eJk015F^`03001FfeKK011Ff`03001Fg5KL019Fg003001F
o5Kl00iFo0D001=C?P03001C?U<n019C?P04001C?U<nDch6000;Bgl00`00Bgm;O`0<Bgl50003>gl0
0`00?gloO`0@?gl50009>el00`00>elkG`06>el8000??el00`00?eloG`0=?el:000?@el00`00Oomo
o`02Ool00`00Oomoo`0=Ool004moo`03001oogoo099oo`030004m`Cg0084m`03000YERUF00dYEP03
000mUSfF00TmUP/000iF5P03001F=UHf015F=P03001FEUIF015FEP03001FEeIG019FE`03001FF5IH
00mFF0800003Ga`005ll01MO?003001K?E/m00IK?@<000iBN@03001BNE9i00mBN@03001BNE9i011B
N@03001BNE9i011BN@03001BVU:J011BVP03001BVU:J011BVP03001BVU:J011BVP03001BVU:J00MB
VPH000=F^P03001F^eJk015F^`03001F^eJk015F^`03001FfeKK015Ff`03001Fg5KL015Fg003001F
o5Kl00MFo0L000=C7P03001C?U<n01=C?P03001C?U<n011C?PD0019;O`03001;Od]o00I;O`D000Tk
O`03000oOcmo00PoO`L000DgG`03000kGc]O00HkG`03000kG`0000H000<kG`03000oGcmO018oG`03
000oGcmO00<oG`T000DoG`030013Gd=O0193G`05001oogooOol0000?Ool004moo`03001oogoo09=o
o`050004m`Cg1?L0000?:EH00`00?IH000090005?IH00`00EQIF5P0AEQH00`00ESIF=P0AESH00`00
EUIFEP0BEUH00`00EUMFE`0BEUL00`00EUQFF00<EUP20004Ga`00`00GcaO?00FGc`00`00FceK?@03
Fcd2000ADWT00`00DWUBN@0@DWT00`00DWUBN@0?DWT00`00DWUBN@0@DWT00`00DYYBVP0@DYX00`00
DYYBVP0@DYX00`00DYYBVP0ADYX00`00DYYBVP06000:E[X00`00E[]F^`0@E[/00`00E[]F^`0AE[/0
0`00E]]Ff`0AE]/00`00E]aFg00AE]`01000E_aFo5Kl1P002e<N00<005<nDch04U<n00<005<nDch0
2e<n1@000TMo00<004]oBgl04d]o00<004]oBgl01@003c]o00@003mo?gloO`H000dgG`04000kGc]O
>el6000;>el00`00?eloG`0=?el:000??el00`00@em3G`0A@el01@00Oomoogoo00003goo001?Ool4
002BOol01@001?L4m`Cg00001RUF2`003cfF00<005HFEQH04EHF00<005HfESH04EHf00<005IFEUH0
4UIF00<005IGEUL04UIG00<005IHEUP02UIH0P001elL00<005llGc`05Ull00<005/m00000P000U9j
00<0059iDWT03e9i00<0059iDWT03e9i00<0059iDWT0459i00<0059iDWT0459i00<005:JDYX045:J
00<005:JDYX03e:J00<005:JDYX035:J200045Jj00<005JkE[/04EJk00<005JkE[/04EJk00<005KK
E]/045KK00<005KLE]`045KL1@004E<N00<005<nDch04e<n00<005<nDch01E<n1@0024Mo00<004]o
Bgl044]o1@004S]o1P003cMO20001S]O00<003]O>el02C]O00<003mO?el00cmO2@001CmO00<003mO
?el04SmO00<004=O@el034=O1P000Woo00<007ooOol03Goo001?Ool00`00Oomoo`2DOol:0009:EH0
0`00?IHmUP0>?IH00`00EQIF5P0AEQH00`00ESIF=P0AESH00`00EUIFEP0BEUH00`00EUMFE`0BEUL0
0`00EUQFF007EUP30009Ga`00`00GcaO?00FGc`20005DWX00`00DWUBN@0?DWT00`00DWUBN@0?DWT0
0`00DWUBN@0@DWT00`00DWUBN@0@DWT00`00DYYBVP0@DYX00`00DYYBVP0@DYX00`00DYYBVP02DYX9
0005EYX00`00E[YF^P0@E[X00`00E[]F^`0AE[/00`00E[]F^`0AE[/00`00E]]Ff`0AE]/00`00E]aF
g00:E]`50002Ead00`00DaiC7P0BDah00`00DciC?P0BDch00`00DciC?P05000>Agl00`00Bgm;O`08
Bgl70005=eh00`00>glkO`08>gl70005<eh20005=el90006=el00`00>elkG`06>el00`00>elkG`04
>el:000??el00`00?eloG`0A?el00`00@em3G`03@el90005@el01000Oomoo`003goo001?Ool00`00
Oomoo`29Ool;000017oo0004m`003bUF00<003fF?IH03SfF00<005HFEQH04EHF00<005HfESH04EHf
00<005IFEUH04UIF00<005IGEUL04UIG00<005IHEUP01EIH0P003ElL00<005llGc`04ell0P001e9j
00<0059iDWT03e9i00<0059iDWT0459i00<0059iDWT03e9i00<0059iDWT0459i00<005:JDYX045:J
00<005:JDYX035:J2@003UJJ00<005JjE[X04EJj00<005JkE[/045Jk00<005JkE[/04EJk00<005KK
E]/04EKK00<005KLE]`01EKL1@0025LM00<005<NDah04U<N00<005<nDch045<n100054Mo00@004]o
Bgm;O`H000dgGP04000kOc]o>gl6000;<eh8000@=el00`00>elkG`03>el90006>el00`00?eloG`0A
?el00`00?eloG`0=?el9000?@el00`00Ool0000?Ool004moo`03001oogoo07moo`X000eoo`8000lY
EP03000mUSfF00hmUP03001F5UHF015F5P03001F=UHf015F=P03001FEUIF019FEP03001FEeIG019F
E`03001FF5IH00=FF08000mO7003001O?5ll011O?0<000YBNP03001BNE9i00iBN@03001BNE9i011B
N@03001BNE9i00mBN@03001BNE9i015BN@03001BVU:J011BVP03001BVU:J009BVPT000AFV@03001F
VUJJ015FVP03001F^UJj011F^P03001F^eJk015F^`03001F^eJk015F^`03001FfeKK011Ff`03001F
g5KL00D000eG7@03001C7U<N019C7P03001C?U<n00]C?PD00097O`030017OdMo0197O`D0014gGPH0
00XcGPL000@cG`03000gGcMO00lgG`P000<kG`03000kGc]O00XkG`03000oGcmO014oG`03000oGcmO
00<oG`T000DoG`030013Gd=O0153G`8000moo`00Cgoo00<007ooOol0M7oo2`005goo00<000Cg0000
3RUF00<003fF?IH03SfF00<005HFEQH04EHF00<005HfESH04EHf00<005IFEUH04UIF00<005IGEUL0
4eIG00<005IHEUP00P004UlL00<005llGc`03Ell0P003E9j00<0059iDWT03e9i00<0059iDWT03e9i
00<0059iDWT0459i00<0059iDWT0459i00<005:JDYX03E:J20003EJI00<005JJEYX04EJJ00<005Jj
E[X045Jj00<005JkE[/04EJk00<005JkE[/04EJk00<005KKE]/03UKK1@004eLM00<005<NDah04U<N
00<005<nDch01E<n1@0024Mo00<004MoAgl034Mo1@0013=M00<003MN=eh023MN1`001Blm0P000c=N
1P0033=O00<003MO=el023MO1P0013]O00<003]O>el01C]O00<003]O>el02S]O00<003mO?el023mO
3P003cmO00<004=O@el044=O0P003goo001?Ool00`00Oomoo`1ZOol:000SOol2000>:EH00`00?IHm
UP0>?IH00`00EQIF5P0AEQH00`00ESIF=P0BESH00`00EUIFEP0AEUH00`00EUMFE`0CEUL3000EGa`0
0`00GcaO?00:Gc`2000?DWX00`00DWUBN@0?DWT00`00DWUBN@0?DWT00`00DWUBN@0@DWT00`00DWUB
N@0@DWT00`00DYYBVP07DYX60003EWT00`00EYUFV@0@EYT00`00EYYFVP0@EYX00`00E[YF^P0AE[X0
0`00E[]F^`0AE[/00`00E[]F^`0@E[/00`00E]]Ff`07E]/70003Ead00`00EaeG7@0BEad00`00DaiC
7P0BDah00`00DciC?P05000>Agl00`00Agm7O`06Agl5000:<ed01000=ehgGSMN1P002Blm20004c=O
00@003MO=elgG`H000/kG`03000kGc]O00DkG`03000kGc]O00DkG`l000ToG`03000oGcmO018oG`03
0013Gd=O00M3G`X000moo`00Cgoo00<007ooOol0H7oo2P00;Woo00<002UF:EH032UF00<003fF?IH0
3SfF00<005HFEQH04EHF00<005HfESH04UHf00<005IFEUH04UIF00<005IGEUL04EIG0P005elL00<0
05llGc`025ll0P004E9j00<0059iDWT03e9i00<0059iDWT0459i00<0059iDWT03e9i00<0059iDWT0
4E9i00<005:JDYX01P002EIi00<005JIEYT045JI00<005JJEYX04EJJ00<005JjE[X045Jj00<005Jk
E[/04EJk00<005JkE[/04EJk00<005KKE]/01P002eLM00<005LMEad04ULM00<005<NDah045<N1000
54Mo00<004MoAgl01@003C=M1P001Rlm2@001bmN00<003=O<el03C=O20004S]O00<003]O>el00c]O
2@001CmO00<003mO?el04CmO00<003mO?el03CmO3P002Goo00<007ooOol03Goo001?Ool00`00Oomo
o`1EOol;000hOol00`00:EHYEP0=:EH00`00?IHmUP0=?IH00`00EQIF5P0AEQH00`00ESIF=P0BESH0
0`00EUIFEP0BEUH00`00EUMFE`0?EUL200000f<K001O700GGa`00`00GcaO?005Gc`200000e:J001B
NP0ADWX00`00DWUBN@0>DWT00`00DWUBN@0@DWT00`00DWUBN@0?DWT00`00DWUBN@0<DWT8000@EWT0
0`00EYUFV@0?EYT00`00EYYFVP0AEYX00`00E[YF^P0@E[X00`00E[]F^`0AE[/00`00E[]F^`0?E[/5
000AEad00`00EaeG7@0BEad00`00DaiC7P0;Dah50003Agl00`00Agm7O`0@Agl5000<<ed600049c`8
000A;eh00`00<elcG`03<el90006=el00`00>elkG`0=>el:0002?el00`00?eloG`0:?el00`00?elo
G`0A?el00`00?eloG`03?el9000HOol00`00Oomoo`0<Ool001Aoo`@000ioo`<000Yoo``0011oo`03
001oogoo04]oo`X004Aoo`03000YERUF00`YEP03000mUSfF00hmUP03001F5UHF011F5P03001F=UHf
019F=P03001FEUIF019FEP03001FEeIG00eFE`8000AS6`03001O75lL01EO7003001O?5ll009O?0<0
00ABVP03001BNU9j00mBNP03001BNE9i00mBN@03001BNE9i00mBN@03001BNE9i011BN@03001BNE9i
009BN@T000EFN@03001FNEIi011FN@03001FVEJI011FV@03001FVUJJ011FVP03001F^UJj015F^P03
001F^eJk015F^`03001F^eJk00UF^`D0009Fo003001G7ELM019G7@03001G7ELM019G7@03001C7U<N
00EC7PD000U7O`030017OdMo00Q7O`L000D[?0<000<cG@H000@W?0H000D[?@8000l_GPT0010gG`03
000kGc]O00<kG`T000HkG`03000oGcmO00@oG`03000oGcmO00XoG`03000oGcmO00`oG`X0025oo`03
001oogoo00aoo`004Woo20002goo1@002Goo30003goo00<007ooOol0@Goo2`00Cgoo00<002UF:EH0
2bUF00<003fF?IH03SfF00<005HFEQH04EHF00<005HfESH04EHf00<005IFEUH04UIF00<005IGEUL0
2eIG0P001V<K00<005lLGa`05UlL00@005ll000000MBVP03001BNU9j00mBNP03001BNE9i00mBN@03
001BNE9i00mBN@03001BNE9i00aBN@T000iFN@03001FNEIi011FN@03001FVEJI011FV@03001FVUJJ
015FVP03001F^UJj011F^P03001F^eJk015F^`03001F^eJk00EF^`@000QFo003001G7ELM015G7@03
001G7ELM019G7@03001C7U<N00D000m7O`040017OdMoAgl6000<:c`600049c`6000=:cd00`00;eh_
GP03;eh90006=el00`00=elgG`0==el9000@>el00`00?eloG`03?el00`00?eloG`0:?el00`00?elo
G`03?el9000[Ool00`00Oomoo`0<Ool0019oo`8000Aoo`8000]oo`D000Yoo`<000Ioo`8000moo`03
001oogoo03Moo`X005Yoo`03000YERUF00/YEP03000mUSfF00hmUP03001F5UHF015F5P03001F=UHf
015F=P03001FEUIF019FEP03001FEeIG00UFE`8000US6`03001O75lL01EO708000UBVP03001BNU9j
011BNP03001BNE9i00iBN@03001BNE9i011BN@03001BNE9i009BN@T000AFN003001FNEIi015FN@03
001FNEIi00mFN@03001FVEJI011FV@03001FVUJJ015FVP03001F^UJj011F^P03001F^eJk015F^`03
001F^eJk00D000aFo003001G7ELM019G7@03001G7ELM011G7@@001=7O`D000/[?0L0008NnPP000l[
?@X0010gG`03000gGcMO00<gG`T000DkG`03000kGc]O018kG`03000oGcmO00<oG`04000oGcmO?el>
000dOol00`00Oomoo`0<Ool0015oo`8000Ioo`8000Yoo`D000]oo`<001Ioo`03001oogoo02aoo`/0
06Eoo`03000YERUF00XYEP03000mUSfF00hmUP03001F5UHF015F5P03001F=UHf015F=P03001FEUIF
019FEP03001FEeIG00MFE`8000aS6`03001O75lL019O708000aBVP03001BNU9j00mBNP03001BNE9i
00iBN@03001BNE9i00aBN@T000eFN003001FNEIi015FN@03001FNEIi011FN@03001FVEJI00mFV@03
001FVUJJ015FVP03001F^UJj015F^P03001F^eJk00mF^`@0019Fo003001G7ELM015G7@03001G7ELM
00]G7@D000A7O`030017OdMo00]7O`D000@S6P<000<[?0l000LW?@8000D[?@T000LcG`03000gGcMO
00dgG`T000lkG`03000kGc]O00dkG`h0049oo`03001oogoo00aoo`004Goo0P001Woo0P002goo0`00
3Goo0`005Goo1P007goo2P00LGoo00<002UF:EH02BUF00<003fF?IH03SfF00<005HFEQH04EHF00<0
05HfESH04EHf00<005IFEUH04UIF00<005IGEUL01EIG0P003V<K00<005lLGa`045lL0P003U:J00<0
059jDWX03e9j00<0059iDWT03e9i00<0059iDWT00U9i2@0015IH00<005IhEWP045Ih00<005IiEWT0
45Ii00<005IiEWT045Ii00<005JIEYT045JI00<005JJEYX04EJJ00<005JjE[X045Jj00<005JkE[/0
2UJk1@000UKl00<005KlE_`04EKl00<005LMEad04ULM00<005LMEad01ELM1@002TMo00<004MoAgl0
1TMo10002B<J30003RLm2@004C=O00<003MO=el00cMO2@001CMO00<003]O>el04C]O00<003]O>el0
0c]O2@0037oo00<007ooOol0@Goo00<007ooOol037oo000@Ool20008Ool2000KOol3000DOol00`00
Oomoo`0GOol;001kOol00`00:EHYEP09:EH00`00?IHmUP0>?IH00`00EQIF5P0AEQH00`00ESIF=P0A
ESH00`00EUIFEP0CEUH00`00EUMFE`02EUL2000AHa/00`00GaaO700=Ga`2000@DYX00`00DWYBNP0@
DWX00`00DWUBN@06DWT=000=EUP00`00EWQFN00@EWP00`00EWUFN@0@EWT00`00EWUFN@0@EWT00`00
EYUFV@0@EYT00`00EYYFVP0AEYX00`00E[YF^P0@E[X00`00E[]F^`05E[/50008E_`00`00E_aFo00A
E_`00`00EaeG7@0AEad00`00EaeG7@05000@Agl00`00Agm7O`0500068aX;00058a`300059cd90006
;ch00`00<elcG`0=<el:000?=el00`00>elkG`0=>el9000EOol00`00Oomoo`11Ool00`00Oomoo`0<
Ool0011oo`8000Qoo`8001aoo`<001=oo`03001oogoo00eoo`X008Moo`03000YERUF00PYEP03000m
USfF00hmUP03001F5UHF015F5P03001F=UHf015F=P03001FEUIF01=FEP03001FEeIG008001=S6`03
001O75lL00]O70<0019BVP03001BNU9j00IBNQ8000QFF003001FF5IH011FF003001FN5Ih00mFN003
001FNEIi015FN@03001FNEIi00mFN@03001FVEJI011FV@03001FVUJJ015FVP03001F^UJj015F^P03
001F^`0000@000eFo003001Fo5Kl019Fo003001G7ELM00mG7@@001A7O`D000@S6P/000XS70T0010_
?P03000cGc=O00<cG`T000LgG`03000gGcMO010gG`03000kGc]O00<kG`T001moo`03001oogoo041o
o`03001oogoo00aoo`0047oo0P0027oo0P007Goo0`004Woo00<007ooOol00Woo2`00TGoo00<002UF
:EH022UF00<003fF?IH03SfF00<005HFEQH04EHF00<005HfESH04UHf00<005IFEUH04UIF0`005V<K
00<005lLGa`02ElL00D004jKCY]>V`0000QBVQ8000UBE`03001FF5IH00iFF003001FF5IH011FF003
001FN5Ih00mFN003001FNEIi015FN@03001FNEIi011FN@03001FVEJI011FV@03001FVUJJ015FVP03
001F^UJj00iF^P@0019Fo003001Fo5Kl019Fo003001G7ELM00YG7@D000A7O`030017OdMo00a7O`D0
00<Ff0`000HS70T000H_?P8000T_?Ph0014gG`03000gGcMO00LgG`h002Uoo`03001oogoo03moo`03
001oogoo00aoo`0047oo0P0027oo0P007Woo0`004Goo1P00W7oo00<002UF:EH01bUF00<003fF?IH0
3SfF00<005HFEQH04EHF00<005HfESH04UHf00<005IFEUH04EIF0P0066<K00<005lLGa`01elL3`00
2E8g00<0059GDUL03e9G00<005IHEUP03eIH00<005IHEUP03eIH00<005IhEWP045Ih00<005IiEWT0
45Ii00<005IiEWT045Ii00<005JIEYT045JI00<005JJEYX04EJJ00<005JjE[X02EJj1@000UKk00<0
05KlE_`04UKl00<005KlE_`04UKl00<005LMEad01ELM10002TMo00<004MoAgl01TMo1@000QKH2P00
1A[j2@003Bln3@002cMO0P003cMO3@00>7oo00<007ooOol0?Woo00<007ooOol037oo000@Ool20008
Ool2000OOol3000BOol200000goo001oo`2LOol00`00:EHYEP06:EH00`00?IHmUP0>?IH00`00EQIF
5P0AEQH00`00ESIF=P0BESH00`00EUIFEP0@EUH00`00Ha/0000IHa/00`00GaaO7004Ga`20006CSP0
0`00DSMB=`0?DSL00`00DUMBE`0?DUL00`00EUQFF00?EUP00`00EUQFF00?EUP00`00EWQFN00@EWP0
0`00EWUFN@0@EWT00`00EWUFN@0@EWT00`00EYUFV@0@EYT00`00EYYFVP0AEYX00`00E[YF^P05E[X4
0008E_/00`00E_aFo00AE_`00`00E_aFo00BE_`00`00EaeG7@05000?Agl00`00Agm7O`0500000aKH
0000000500056_X90006:ch20005;ch90006<el00`00=elgG`0A=el00`00=elgG`03=el90015Ool0
0`00Oomoo`0nOol00`00Oomoo`0<Ool0011oo`8000Qoo`80021oo`8001Aoo`8009eoo`03000YERUF
00LYEP03000mUSfF00dmUP03001F5UHF015F5P03001F=UHf019F=P03001FEUIF00iFEP8000=S6`03
001S6f<K01MS6`04001O75lLGa`20008CSP00`00DSMB=`0?DSL00`00DUMBE`0@DUL00`00EUQFF00>
EUP00`00EUQFF00@EUP00`00EWQFN00?EWP00`00EWUFN@0AEWT00`00EWUFN@0@EWT00`00EYUFV@0?
EYT00`00EYYFVP0BEYX00`00E[X00004000<E_/00`00E_aFo00BE_`00`00E_aFo00@E_`4000CAgl:
00035]T9000=:ch9000@<el00`00=elgG`08=el>001?Ool00`00Oomoo`0mOol00`00Oomoo`0<Ool0
011oo`8000Qoo`80025oo`8001=oo`04001oo`00002LOol00`00:EHYEP06:EH00`00?IHmUP0=?IH0
0`00EQIF5P0AEQH00`00ESIF=P0BESH00`00EUIFEP0=EUH00`00Ha]S6`03Ha/00`00Ha]S6`0GHa/0
1000Ga`000002Thh00<0058gDSL0458g00<0059GDUL03e9G00<005IHEUP03UIH00<005IHEUP045IH
00<005IhEWP03eIh00<005IiEWT04EIi00<005IiEWT045Ii00<005JIEYT045JI00<005JJEYX03eJJ
10004UKk00<005KlE_`04EKl00<005KlE_`035Kl100014NO00<004MoAgl02dMo4P001R/m0P001B/n
2@001S<o0P003S=O3P00GWoo00<007ooOol0?7oo00<007ooOol037oo000@Ool20008Ool2000QOol2
000GOol2002KOol00`00:EHYEP05:EH00`00?IHmUP0=?IH00`00EQIF5P0BEQH00`00ESIF=P0AESH0
0`00EUIFEP0;EUH20007Ha/00`00Ha]S6`0FHa/2000=CSP00`00DSMB=`0?DSL00`00DUMBE`0?DUL0
0`00EUQFF00>EUP00`00EUQFF00@EUP00`00EWQFN00@EWP00`00EWUFN@0@EWT00`00EWUFN@0@EWT0
0`00EYUFV@0@EYT00`00EYYFVP0:EYX50002F]/00`00E_]Fn`0AE_/00`00E_aFo00BE_`00`00E_aF
o007E_`40009Ail00`00Agm7O`06Agl=0008:cd>000A<cl00`00<elcG`02<el9001]Ool00`00Oomo
o`0kOol00`00Oomoo`0<Ool0015oo`8000Ioo`8001Uoo`8000Moo`8001Uoo`8009Uoo`03000YERUF
00DYEP03000mUSfF00dmUP03001F5UHF019F5P03001F=UHf015F=P03001FEUIF00YFEP03001S6f<K
00MS6`03001S6f<K01AS6`8000m>>003001B=e8g00mB=`03001BEe9G00mBE`03001FF5IH00mFF003
001FF5IH00mFF003001FN5Ih011FN003001FNEIi011FN@03001FNEIi011FN@03001FVEJI011FV@03
001FVUJJ00EFVPD000QJf`03001FneKk015Fn`03001Fo5Kl015Fo003001Fo5Kl00AFo0<000i7W`03
0017OdMo00H000LW7@d000/c?P<000Tc?`d007Ioo`03001oogoo03]oo`03001oogoo00aoo`004Goo
0P001Woo0P006Goo0`001Woo0P006goo0P00V7oo00<002UF:EH012UF00<003fF?IH03CfF00<005HF
EQH04UHF00<005HfESH04EHf00<005IFEUH025IF0P002f<K00<006<KHa/04F<K0`0044hh00<0058g
DSL03e8g00<0059GDUL03e9G00<005IHEUP03eIH00<005IHEUP03eIH00<005IhEWP045Ih00<005Ii
EWT045Ii00<005IiEWT04EIi00<005JIEYT045JI00<005JJ000010003E[K00<005KkE_/04EKk00<0
05KlE_`04EKl00<005KlE_`0100044NO1@000bLM2@001Rln0P003c<n3@00Q7oo00<007ooOol0>Woo
00<007ooOol037oo000BOol20004Ool2000JOol40004Ool2000NOol20004Ool00`00Oomoo`2@Ool0
0`00:EHYEP03:EH00`00?IHmUP0=?IH00`00EQIF5P0BEQH00`00ESIF=P0AESH00`00EUIFEP06EUH2
000=Ha/00`00Ha]S6`0@Ha/01000BSQ:>00044hh00<0058gDSL03e8g00<0059GDUL03e9G00<005IH
EUP03eIH00<005IHEUP045IH00<005IhEWP045Ih00<005IiEWT045Ii00<005IiEWT045Ii00<005JI
EYT03UJI10004U[K00<005KkE_/04EKk00<005KlE_`045Kl10003dNO3@004Bln00<003<n<ch00c<n
2@00TWoo00<007ooOol0>Goo00<007ooOol037oo000BOol8000KOol8000QOol20002Ool00`00Oomo
o`2@Ool00`00:EHYEP03:EH00`00?IHmUP0>?IH00`00EQIF5P0AEQH00`00ESIF=P0AESH00`00EUIF
EP05EUH00`00Ha]S6`0>Ha/00`00Ha]S6`0=Ha/20003BSP00`00CSQ>>00>CSP00`00DSMB=`0?DSL0
0`00DUMBE`0@DUL00`00EUQFF00>EUP00`00EUQFF00@EUP00`00EWQFN00@EWP00`00EWUFN@0@EWT0
0`00EWUFN@0@EWT00`00EYUFV@09EYT50002F]X00`00F]]Jf`0BF]/00`00E_]Fn`0AE_/00`00E_aF
o00<E_`30004@il20008Ail:0006;ch20009;ch>002KOol00`00Oomoo`0iOol00`00Oomoo`0<Ool0
01Aoo`@001moo`D002Aoo`8009Aoo`03000YERUF008YEP03000mUSfF00hmUP03001F5UHF015F5P03
001F=UHf019F=P03001FEUIF009FEP80019S6`03001S6f<K00YS6`8000E:>003001>>4hh00m>>003
001B=e8g00mB=`03001BEe9G00mBE`03001FF5IH00mFF003001FF5IH00mFF003001FN5Ih011FN003
001FNEIi011FN@03001FNEIi011FN@03001FVEJI00EFV@@000QJfP03001Jfe[K015Jf`03001FneKk
015Fn`03001Fo5Kl00QFo0@000U3W`030017WdNO00H000d_?Pd00:Yoo`03001oogoo03Qoo`03001o
ogoo00aoo`00HGoo0`00Tgoo00D002UF:EHYEP00010mUP03001F5UHF015F5P03001F=UHf019F=P05
001FEUIFEUH0000DHa/00`00Ha]S6`08Ha/20008BSP00`00CSQ>>00>CSP00`00DSMB=`0?DSL00`00
DUMBE`0?DUL00`00EUQFF00?EUP00`00EUQFF00?EUP00`00EWQFN00@EWP00`00EWUFN@0@EWT00`00
EWUFN@0AEWT00`00EYT00004000<F]X00`00F]]Jf`0AF]/00`00E_]Fn`0BE_/00`00E_aFo003E_`4
000<@il40003;ch30004;ch9002hOol00`00Oomoo`0gOol00`00Oomoo`0<Ool006Aoo`80095oo`05
000YERUF:EH0000@?IH00`00EQIF5P0AEQH00`00ESIF=P0BESH01000EUH000005V<K00<006<KHa/0
1F<K0P002TXh00<004hhCSP03Thh00<0058gDSL03e8g00<0059GDUL03e9G00<005IHEUP03eIH00<0
05IHEUP045IH00<005IhEWP045Ih00<005IiEWT045Ii00<005IiEWT03UIi10004E[J00<005[KF]/0
4U[K00<005KkE_/04EKk00<005KlE_`00`003D>O0`001Rln2000`Woo00<007ooOol0=goo00<007oo
Ool02goo001VOol2002@Ool01000:EHYEP0043fF00<005HFEQH04EHF00<005HfESH04UHf0P0066<K
00<006<KHa/016<K00<004XhBSP02TXh00<004hhCSP03Thh00<0058gDSL03e8g00<0059GDUL03e9G
00<005IHEUP03eIH00<005IHEUP045IH00<005IhEWP045Ih00<005IiEWT045Ii00<005IiEWT02eIi
0`000UZj00<005[JF]X04E[J00<005[KF]/04E[K00<005KkE_/045Kk100034>O3@00bWoo00<007oo
Ool0=goo00<007ooOol02goo001XOol20006Ool00`00Oomoo`25Ool01@00:EHYERUF00003cfF00<0
05HFEQH04EHF00<005HfESH04EHf0P006V<K00@006<KHa]S6`8000e:>003001>>4hh00i>>003001B
=e8g00mB=`03001BEe9G00mBE`03001FF5IH00mFF003001FF5IH011FF003001FN5Ih011FN003001F
NEIi011FN@03001FNEIi00MFN@@000IJ^P03001JfU[J011JfP03001Jfe[K015Jf`03001FneKk00aF
n`@000@oWP8000I3W`P00=Aoo`03001oogoo03Ioo`03001oogoo00]oo`00JWoo0P0017oo00<007oo
Ool0QWoo00@002UF:EH000lmUP03001F5UHF015F5P03001F=UHf011F=P03001WF`0001YS6`04001S
6`00000?BSP00`00CSQ>>00>CSP00`00DSMB=`0?DSL00`00DUMBE`0@DUL00`00EUQFF00?EUP00`00
EUQFF00?EUP00`00EWQFN00@EWP00`00EWUFN@0@EWT00`00EWUFN@03EWT4000:F[X00`00F]YJfP0@
F]X00`00F]]Jf`0BF]/00`00E_]Fn`07E_/4000:?ih00`00@im3W`03003MOol00`00Oomoo`0eOol0
0`00Oomoo`0;Ool006aoo`80009oo`03001oogoo08Moo`03000YEP0000lmUP03001F5UHF019F5P03
001F=UHf00iF=P05001WFfMKIe/0000IHa/3000@BSP00`00CSQ>>00?CSP00`00DSMB=`0>DSL00`00
DUMBE`0@DUL00`00EUQFF00?EUP00`00EUQFF00@EUP00`00EWQFN00@EWP00`00EWUFN@0@EWT00`00
EWT00002000>F[X00`00F]YJfP0AF]X00`00F]]Jf`0AF]/00`00E_]Fn`04E_/3000=?ih4003QOol0
0`00Oomoo`0dOol00`00Oomoo`0;Ool006ioo`<008Uoo`03000YEP0000lmUP03001F5UHF019F5P03
001F=UHf00eF=P03001WFfMK009WF`03001S6f<K01IS6`0500126D8I@QT0000@BSP00`00CSQ>>00>
CSP00`00DSMB=`0?DSL00`00DUMBE`0?DUL00`00EUQFF00?EUP00`00EUQFF00@EUP00`00EWQFN00@
EWP00`00EWUFN@0>EWT4000BF[X00`00F]YJfP0@F]X00`00F]]Jf`0AF]/00`00E_]Fn`04000;?ih5
003UOol00`00Oomoo`0dOol00`00Oomoo`0;Ool0071oo`8008Uoo`8000lmUP03001F5UHF019F5P03
001F=UHf00aF=P03001WFfMK00AWF`03001S6f<K01=S6`8000A26@03001:>4Xh00i:>003001>>4hh
00i>>003001B=e8g00mB=`03001BEe9G00mBE`03001FF5IH00mFF003001FF5IH011FF003001FN5Ih
011FN003001FNEIi00UFN@D0009JV@03001J^UZj015J^P03001JfU[J015JfP03001Jfe[K011Jf`@0
00XoWP@00>]oo`03001oogoo03=oo`03001oogoo00]oo`00L7oo00@007oo000008Qoo`03000mUSfF
00dmUP03001F5UHF019F5P03001F=UHf00]F=P03001WFfMK00EWF`03001S6f<K019S6`0300126D8I
00A26@03001:>4Xh00i:>003001>>4hh00i>>003001B=e8g00mB=`03001BEe9G00mBE`03001FF5IH
00mFF003001FF5IH011FF003001FN5Ih011FN003001FNEIi00EFN@@000MJV@03001J^UZj015J^P03
001JfU[J015JfP03001Jfe[K00eJf`<000@kO@<0008oWPD00?1oo`03001oogoo039oo`03001oogoo
00]oo`00M7oo0P00QWoo00<003fF?IH03CfF00<005HFEQH04UHF00<005HfESH02UHf00<006MKIe/0
1fMK00<006<KHa/03f<K0P001d8I00<004XhBSP03TXh00<004hhCSP03Thh00<0058gDSL03e8g00<0
059GDUL0459G00<005IHEUP03eIH00<005IHEUP03eIH00<005IhEWP04EIh00<005Ii0000100035ZI
00<005ZjF[X04EZj00<005[JF]X045[J00<005[KF]/02U[K0`0023]m1000mGoo00<007ooOol0<Woo
00<007ooOol02goo001fOol20025Ool00`00?IHmUP0<?IH00`00EQIF5P0BEQH00`00ESIF=P09ESH0
0`00Ie]WF`08Ie/00`00Ha]S6`0>Ha/00`00@QU26@07@QT00`00BSQ:>00>BSP00`00CSQ>>00?CSP0
0`00DSMB=`0>DSL00`00DUMBE`0@DUL00`00EUQFF00?EUP00`00EUQFF00@EUP00`00EWQFN00>EWP4
000AFYT00`00F[YJ^P0AF[X00`00F]YJfP0AF]X00`00F]]Jf`06F]/30008>gd3003jOol00`00Oomo
o`0aOol00`00Oomoo`0;Ool007Qoo`8008Aoo`03000mUSfF00/mUP03001F5UHF019F5P03001F=UHf
00QF=P03001WFfMK00YWF`03001S6f<K00]S6`8000]26@03001:>4Xh00e:>003001>>4hh00m>>003
001B=e8g00iB=`03001BEe9G011BE`03001FF5IH00mFF003001FF5IH011FF003001FN5Ih00]FN0<0
009JV@03001JVEZI011JV@03001J^UZj015J^P03001JfU[J015JfP03001Jfe[K00=Jf`<000LkO@@0
0?ioo`03001oogoo031oo`03001oogoo00]oo`00NWoo0P000goo00<007ooOol0O7oo00<003fF?IH0
2cfF00<005HFEQH04UHF00<005HfESH01eHf00<006MKIe/036MK00<006<KHa/026<K0P003D8I00<0
04XhBSP03DXh00<004hhCSP03dhh00<0058gDSL03e8g00<0059GDUL03e9G00<005IHEUP03eIH00<0
05IHEUP045IH00<005IhEWP01eIh10001EZI00<005ZIFYT04EZI00<005ZjF[X04EZj00<005[JF]X0
45[J00<005[KF]/00`001S]m1000ogoo17oo00<007ooOol0;goo00<007ooOol02goo001lOol20000
0goo001oo`1nOol00`00?IHmUP0;?IH00`00EQIF5P0AEQH00`00ESIF=P06ESH00`00Ie]WF`0=Ie/0
0`00Ha]S6`07Ha/200000bUg0000000;@QT00`00BSQ:>00>BSP00`00CSQ>>00>CSP00`00DSMB=`0?
DSL00`00DUMBE`0?DUL00`00EUQFF00@EUP00`00EUQFF00?EUP00`00EWQFN003EWP4000:FYT00`00
FYUJV@0@FYT00`00F[YJ^P0AF[X00`00F]YJfP0@F]X50004>gd3003oOol8Ool00`00Oomoo`0_Ool0
0`00Oomoo`0;Ool007ioo`80081oo`03000mUSfF00XmUP03001F5UHF015F5P03001F=UHf00EF=P03
001WFfMK00mWF`03001S6f<K00AS6`80000309D002Ug008YM`8000U26@03001:>4Xh00i:>003001>
>4hh00i>>003001B=e8g00mB=`03001BEe9G00mBE`03001FF5IH011FF003001FF5IH011FF003001F
N000008000iJV@03001JVEZI011JV@03001J^UZj015J^P03001JfU[J00eJfP<000DcN`@00?moo`ao
o`03001oogoo02ioo`03001oogoo00]oo`00OWoo00@007oo000007ioo`03000mUSfF00XmUP03001F
5UHF015F5P03001F=UHf00AF=P03001WFfMK011WF`03001S6f<K00=S6`030000U@2E0080U@03000Y
MbUg008YM`8000Q26@03001:>4Xh00e:>003001>>4hh00m>>003001B=e8g00iB=`03001BEe9G011B
E`03001FF5IH00mFF003001FF5IH00iFF0@0015JV@03001JVEZI015JV@03001J^UZj015J^P03001J
fU[J00UJfP<000DcN`<00?mooa5oo`03001oogoo02eoo`03001oogoo00]oo`00PWoo0P00OGoo00<0
03fF?IH02CfF00<005HFEQH04UHF00<005HfESH00UHf00<006MKIe/04VMK00<006<KHa/00P001@2E
00<002Ug:GL012Ug0P001T8I00<004XhBSP03DXh00<004hhCSP03dhh00<0058gDSL03U8g00<0059G
DUL0459G00<005IHEUP03eIH00<005IHEUP02EIH1@000UYh00<005ZIFYT04EZI00<005ZIFYT045ZI
00<005ZjF[X04EZj00<005[JF]X01U[J0`0013=k1000ogoo5Goo00<007ooOol0;7oo00<007ooOol0
2goo0024Ool2001kOol00`00?IHmUP09?IH00`00EQIF5P0BEQH01@00ESIF=UHf00005FMK00<006<K
00001`2E00<002Ug:GL01RUg00<0048I@QT00d8I00<004XhBSP03DXh00<004hhCSP03dhh00<0058g
DSL03U8g00<0059GDUL0459G00<005IHEUP03eIH00<005IHEUP01EIH10001eYh00<005ZIFYT04EZI
00<005ZIFYT045ZI00<005ZjF[X04EZj00<005[JF]X00e[J0`000c=k1000ogoo6Goo00<007ooOol0
;7oo00<007ooOol02goo0026Ool2001jOol00`00?IHmUP08?IH00`00EQIF5P0BEQH01000ESIF=P00
5VMK0P00202E00<002Ug:GL01bUg0P000d8I00<004XhBSP03DXh00<004hhCSP03dhh00<0058gDSL0
3e8g00<0059GDUL03e9G00<005IHEUP045IH00<005IH0000100035Yh00<005ZIFYT045ZI00<005ZI
FYT04EZI00<005ZjF[X04EZj00<005[J00000P000c=k0`00ogoo7Woo00<007ooOol0:goo00<007oo
Ool02goo0028Ool20002Ool00`00Oomoo`1dOol00`00?IHmUP07?IH00`00EQIF5P0BEQH00`00ESH0
000FIe/00`0009D0U@0809D00`00:GLYM`09:GL200000d8I001:>00?BSP00`00CSQ>>00>CSP00`00
DSMB=`0?DSL00`00DUMBE`0?DUL00`00EUQFF00>EUP4000AFWP00`00FYUJV@0@FYT00`00FYUJV@0A
FYT00`00F[YJ^P0@F[X9003oOolROol00`00Oomoo`0ZOol00`00Oomoo`0;Ool008Yoo`<007Ioo`03
000mUSfF00LmUP03001F5UHF019F5P8001IWF`030000U@2E00X0U@03000YMbUg00XYM`<000m:>003
001>>4hh00i>>003001B=e8g00mB=`03001BEe9G00mBE`03001FF5IH00UFF0D0009JM`03001JN5Yh
011JN003001JVEZI015JV@03001JVEZI011JV@03001J^UZj00eJ^P<0008W>0<00?moobIoo`03001o
ogoo02]oo`03001oogoo00Yoo`00S7oo0P00MWoo00<003fF?IH01SfF00<005HFEQH04EHF0P005FMK
0P0000=oo`0009D02P2E00<002Ug:GL032Ug0P003TXh00<004hhCSP03dhh00<0058gDSL03U8g00<0
059GDUL0459G00<005IHEUP015IH10001eYg00<005YhFWP045Yh00<005ZIFYT04EZI00<005ZIFYT0
4EZI00<005ZjF[X02EZj0`0000<W>00000000P00ogoo:Woo00<007ooOol0:Woo00<007ooOol02Woo
002<Ool01000Ool00000MGoo00<003fF?IH01CfF00<005HFEQH045HF00<005^n000056MK00D007oo
Oomoo`0000/0U@03000YMbUg00`YM`030011eP00008000]:>003001>>4hh00m>>003001B=e8g00iB
=`03001BEe9G011BE`03001FF00000@000aJM`03001JN5Yh011JN003001JVEZI011JV@03001JVEZI
015JV@03001J^UZj00IJ^PL00?moobmoo`03001oogoo02Uoo`03001oogoo00Yoo`00T7oo00<007oo
Ool0LWoo00<003fF?IH01CfF00<005HFEQH03eHF00D005^nFkiK_P00019WF`03001oogoo00=oo`03
0000U@2E00P0U@03000YMbUg00`YM`030011eT7F0091eP<000Q:>003001>>4hh00m>>003001B=e8g
00iB=`03001BEe9G00iBE`@0015JM`03001JN5Yh011JN003001JVEZI011JV@03001JVEZI015JV@03
001J^UZj00=J^PH00?moocAoo`03001oogoo02Qoo`03001oogoo00Yoo`00TGoo0P00Lgoo00<003fF
?IH013fF00<005HFEQH03EHF0P001E^n00<006MKIe/03FMK0P001goo00<0002E09D01`2E00<002Ug
:GL032Ug00<0047F@MH01D7F0`001DXh00<004hhCSP03dhh00<0058gDSL03U8g00<0059GDUL02E9G
1@000UYG00<005YgFWL045Yg00<005YhFWP045Yh00<005ZIFYT04EZI00<005ZIFYT04EZI00<005Zj
00001@00ogoo=goo00<007ooOol0:7oo00<007ooOol02Woo002COol2001bOol00`00?IHmUP03?IH0
0`00EQIF5P0<EQH00`00FkiK_P06Fkh00`00Ie]WF`0;Ie/00`00Oomoo`07Ool00`0009D0U@0809D0
0`00:GLYM`0;:GL00`00@MI1eP08@MH30003BSP00`00CSQ>>00>CSP00`00DSMB=`0?DSL00`00DUMB
E`04DUL40007FUL00`00FWMJM`0@FWL00`00FWQJN00@FWP00`00FYUJV@0AFYT00`00FYUJV@0@FYT6
003oOolkOol00`00Oomoo`0WOol00`00Oomoo`0:Ool005Eoo``000]oo`@000ioo`@001=oo`8000=o
o`03001oogoo06Yoo`03000mUSfF00<mUP03001F5UHF00]F5P03001K_U^n00MK_P03001WFfMK00UW
F`8000]oo`030000U@2E00L0U@03000YMbUg00`YM`030011eT7F00Y1eP@0015>>003001B=e8g00iB
=`03001BE`0000@000]JE`03001JMeYg011JM`03001JN5Yh015JN003001JVEZI011JV@03001JVEZI
00eJV@H00?moocmoo`03001oogoo02Ioo`03001oogoo00Yoo`00EGoo30002Goo20002Woo20004goo
0P0000=oo`00Ool0K7oo00<003fF?IH00SfF00<005HFEQH02EHF0P002e^n00<006MKIe/01fMK00<0
07ooOol037oo00<0002E09D01P2E00<002Ug:GL032Ug00<0047F@MH03D7F2P0024hh00<0058gDSL0
1U8g2P004EYG00<005YgFWL045Yg00<005YhFWP045Yh00<005ZIFYT04EZI00<005ZIFYT02UZI1@00
ogoo@goo00<007ooOol09Goo00<007ooOol02Woo001FOol30006Ool20009Ool20004Ool2000:Ool2
0004Ool2000EOol2001^Ool01@00?IHmUSfF00002UHF00<005^nFkh035^n00<006MKIe/01FMK00<0
07ooOol03Goo00<0002E09D01P2E00<002Ug:GL032Ug00<0047F@MH03D7F00<005HfESH01eHf4@00
25IF00<005YGFUL045YG00<005YgFWL045Yg00<005YhFWP045Yh00<005ZIFYT04EZI00<005ZIFYT0
1eZI1@00ogooAWoo00<007ooOol09Goo00<007ooOol02Woo001GOol3000?Ool20006Ool20008Ool2
0006Ool2000EOol3001/Ool00`00?IHmUP02?IH00`00EQIF5P06EQH00`00FkiK_P0=Fkh00`00Ie]W
F`03Ie/2000AOol00`0009D0U@0509D00`00:GLYM`0<:GL00`00@MI1eP0=@MH00`00ESIF=P0?ESH0
0`00EUIFEP0>EUH00`00FUMJE`0@FUL00`00FWMJM`0@FWL00`00FWQJN00@FWP00`00FYUJV@0AFYT0
0`00FYUJV@04FYT5003oOom:Ool00`00Oomoo`0TOol00`00Oomoo`0:Ool005Qoo`<000ioo`8000Io
o`8000Qoo`8000Ioo`8001Qoo`8006]oo`05000mUSfF?IH00006EQH2000AFkh01@00Ie]WFfMK0000
57oo00<0002E09D01@2E00<002Ug:GL02bUg00<0047F@MH03D7F00<005HfESH03eHf00<005IFEUH0
3UIF00<005YGFUL045YG00<005YgFWL045Yg00<005YhFWP045Yh00<005ZIFYT04EZI00<005ZIFYT0
0UZI1000ogooCWoo00<007ooOol08goo00<007ooOol02Woo001IOol3000<Ool20008Ool20006Ool2
0008Ool2000IOol2001YOol01@00?IHmUSfF00001EHF00<005^nFkh04U^n00<006MK00005Goo00<0
002E09D01@2E00<002Ug:GL02bUg00<0047F@MH03D7F00<005HfESH03eHf00<005IFEUH03eIF00<0
05YGFUL03eYG00<005YgFWL045Yg00<005YhFWP04EYh00<005ZIFYT04EZI1@00ogooDWoo00<007oo
Ool08Woo00<007ooOol02Woo001JOol3000;Ool20008Ool20006Ool20008Ool2000KOol20004Ool0
0`00Oomoo`1QOol01000?IHmUP0015HF00<005^nFkh04e^n0P005goo00<0002E09D0102E00<002Ug
:GL02bUg00<0047F@MH03D7F00<005HfESH03eHf00<005IFEUH03eIF00<005YGFUL03eYG00<005Yg
FWL04EYg00<005YhFWP045Yh00<005ZIFYT045ZI0`00ogooEGoo00<007ooOol08Woo00<007ooOol0
2Woo001KOol3000:Ool20008Ool20006Ool20008Ool2000MOol20002Ool00`00Oomoo`1ROol00`00
?IH00002EQH2000DFkh2000JOol00`0009D0U@0309D00`00:GLYM`0;:GL00`00@MI1eP0>@MH00`00
ESIF=P0>ESH00`00EUIFEP0?EUH00`00FUMJE`0@FUL00`00FWMJM`0@FWL00`00FWQJN00@FWP00`00
FYUJV@0>FYT2003oOomIOol00`00Oomoo`0QOol00`00Oomoo`0:Ool005aoo`<000Uoo`8000Qoo`80
00Ioo`8000Qoo`8001moo`<006Aoo`05000mUP00EQH0000DFkh2000MOol00`0009D0U@0209D00`00
:GLYM`0<:GL00`00@MI1eP0=@MH00`00ESIF=P0?ESH00`00EUIFEP0>EUH00`00FUMJE`0@FUL00`00
FWMJM`0@FWL00`00FWQJN00@FWP00`00FYUJV@0;FYT3003oOomLOol00`00Oomoo`0POol00`00Oomo
o`0:Ool005eoo`<000Qoo`8000Qoo`8000Ioo`8000Qoo`80025oo`8006Aoo`<001=K_P8001moo`03
0000U@2E00<0U@03000YMbUg00/YM`030011eT7F00e1eP03001F=UHf00mF=P03001FEUIF00iFEP03
001JEeYG011JE`03001JMeYg011JM`03001JN5Yh015JN003001JVEZI00QJV@800?mooemoo`03001o
ogoo021oo`03001oogoo00Yoo`00GWoo0P0027oo0P0027oo0P001Woo0P0027oo0P008goo0P00Hgoo
0P0045^n0`008Woo00<0002E09D00P2E00<002Ug:GL02bUg00<0047F@MH03D7F00<005HfESH03eHf
00<005IFEUH03UIF00<005YGFUL045YG00<005YgFWL045Yg00<005YhFWP04EYh00<005ZIFYT01UZI
0P00ogooHWoo00<007ooOol07goo00<007ooOol02Woo001OOol20007Ool20008Ool20006Ool20008
Ool2000UOol20007Ool00`00Oomoo`1IOol2000<Fkh2000VOol01@0009D0U@2E00003BUg00<0047F
@MH03D7F00<005HfESH03eHf00<005IFEUH03eIF00<005YGFUL03eYG00<005YgFWL04EYg00<005Yh
FWP045Yh00<005ZIFYT015ZI0P00ogooIGoo00<007ooOol07Woo00<007ooOol02Woo001OOol20007
Ool20008Ool20006Ool20008Ool2000WOol20005Ool00`00Oomoo`1KOol20008Fkh2000XOol01@00
09D0U@2E00003BUg00<0047F@MH03D7F00<005HfESH03eHf00<005IFEUH03eIF00<005YGFUL03eYG
00<005YgFWL04EYg00<005YhFWP045Yh00@005ZIFYUJV@<00?moofQoo`03001oogoo01eoo`03001o
ogoo00Yoo`00EWoo0P001goo0P0027oo0P001Woo0P0027oo0P001Woo0P00:Woo0P000goo00<007oo
Ool0GGoo00<005^nFkh00e^n0P00:goo00@0002E09D000dYM`030011eT7F00e1eP03001F=UHf00mF
=P03001FEUIF00mFEP03001JEeYG011JE`03001JMeYg011JM`03001JN5Yh015JN0<00?moof]oo`03
001oogoo01ioo`03001oogoo00Uoo`00EWoo0`001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P00
;7oo0P0000=oo`00Ool0Ggoo0P0000=K_P000000;Woo00@0002E09D000`YM`030011eT7F00e1eP03
001F=UHf00mF=P03001FEUIF00mFEP03001JEeYG011JE`03001JMeYg011JM`03001JN5Yh011JN080
0?moofioo`03001oogoo01eoo`03001oogoo00Uoo`00EWoo100017oo0P002Woo0P0017oo0P002Woo
0P0017oo0P00;goo0P00HWoo00<007ooOol0;Woo00@0002E09D000`YM`030011eT7F00e1eP03001F
=UHf00mF=P03001FEUIF00mFEP03001JEeYG011JE`03001JMeYg011JM`03001JN5Yh00iJN0800?mo
og5oo`03001oogoo01aoo`03001oogoo00Uoo`00Egoo20002goo20002Woo2000<7oo0`00TWoo00<0
002E000032Ug00<0047F@MH03D7F00<005HfESH03eHf00<005IFEUH03eIF00<005YGFUL045YG00<0
05YgFWL04EYg00<005YhFWP02eYh0P00ogooM7oo00<007ooOol06goo00<007ooOol02Goo001IOol5
000>Ool4000>Ool4000eOol2002AOol2000=:GL00`00@MI1eP0<@MH00`00ESIF=P0@ESH00`00EUIF
EP0>EUH00`00FUMJE`0@FUL00`00FWMJM`0AFWL00`00FWQJN009FWP2003oOomfOol00`00Oomoo`0K
Ool00`00Oomoo`09Ool00;Uoo`8008moo`8000dYM`030011eT7F00e1eP03001F=UHf00mF=P03001F
EUIF00mFEP03001JEeYG00mJE`03001JMeYg015JM`03001JN5Yh00MJN0800?moogUoo`03001oogoo
01Yoo`03001oogoo00Uoo`00^goo0P0017oo00<007ooOol0Qgoo0P0032Ug00<0047F@MH03D7F00<0
05HfESH03eHf00<005IFEUH03eIF00<005YGFUL045YG00<005YgFWL045Yg00<005YhFWP01EYh0P00
ogooO7oo00<007ooOol06Goo00<007ooOol02Goo002mOol20002Ool00`00Oomoo`28Ool00`00:GLY
M`0::GL00`00@MI1eP0=@MH00`00ESIF=P0?ESH00`00EUIFEP0?EUH00`00FUMJE`0@FUL00`00FWMJ
M`0@FWL00`00FWQJN003FWP2003oOomnOol00`00Oomoo`0IOol00`00Oomoo`09Ool00;moo`8008]o
o`03000YMbUg00XYM`030011eT7F00e1eP03001F=UHf00mF=P03001FEUIF00mFEP03001JEeYG011J
E`03001JMeYg015JM`03001JN5Yh00800?mooh5oo`03001oogoo01Qoo`03001oogoo00Uoo`00`7oo
0`00RWoo00<002Ug:GL02BUg00<0047F@MH03D7F00<005HfESH03eHf00<005IFEUH03eIF00<005YG
FUL045YG00<005YgFWL04EYg0`00ogooQ7oo00<007ooOol05goo00<007ooOol02Goo0033Ool20029
Ool00`00:GLYM`08:GL00`00@MI1eP0=@MH00`00ESIF=P0?ESH00`00EUIFEP0?EUH00`00FUMJE`0@
FUL00`00FWMJM`0@FWL2003oOon7Ool00`00Oomoo`0FOol00`00Oomoo`09Ool00<Eoo`8008Moo`03
000YMbUg00PYM`030011eT7F00e1eP03001F=UHf00mF=P03001FEUIF011FEP03001JEeYG00mJE`03
001JMeYg00iJM`800?moohUoo`03001oogoo01Ioo`03001oogoo00Uoo`00agoo0P0017oo00<007oo
Ool0Ogoo00<002Ug:GL022Ug00<0047F@MH0347F00<005HfESH03eHf00<005IFEUH045IF00<005YG
FUL045YG00<005YgFWL02eYg0P00ogooS7oo00<007ooOol05Goo00<007ooOol02Goo0039Ool20002
Ool00`00Oomoo`20Ool00`00:GLYM`07:GL00`00@MI1eP0<@MH00`00ESIF=P0@ESH00`00EUIFEP0?
EUH00`00FUMJE`0@FUL00`00FWMJM`0:FWL00`00Oomoo`3oOon=Ool00`00Oomoo`0DOol00`00Oomo
o`09Ool00<]oo`<0089oo`03000YMbUg00LYM`030011eT7F00a1eP03001F=UHf011F=P03001FEUIF
00mFEP03001JEeYG011JE`03001JMeYg00QJM`800?mooi5oo`03001oogoo01=oo`03001oogoo00Uo
o`00cGoo0P00PWoo00<002Ug:GL01RUg00<0047F@MH03D7F00<005HfESH03eHf00<005IFEUH03eIF
00<005YGFUL045YG00<005YgFWL01UYg0P00ogooTgoo00<007ooOol04goo00<007ooOol02Goo003?
Ool20020Ool00`00:GLYM`06:GL00`00@MI1eP0=@MH00`00ESIF=P0?ESH00`00EUIFEP0?EUH00`00
FUMJE`0@FUL00`00FWMJM`04FWL2003oOonFOol00`00Oomoo`0BOol00`00Oomoo`09Ool00=5oo`80
07moo`03000YMbUg00DYM`030011eT7F00e1eP03001F=UHf00mF=P03001FEUIF011FEP03001JEeYG
00mJE`03001JMeYg009JM`800?mooiUoo`03001oogoo015oo`03001oogoo00Uoo`00dgoo0P0017oo
00<007ooOol0Mgoo00<002Ug:GL012Ug00<0047F@MH03D7F00<005HfESH03eHf00<005IFEUH045IF
00<005YGFUL045YG00@005YgFWL00?mooi]oo`03001oogoo015oo`03001oogoo00Uoo`00eGoo0P00
0Woo00<007ooOol0Mgoo00<002Ug:GL012Ug00<0047F@MH03D7F00<005HfESH03eHf00<005IFEUH0
45IF00<005YGFUL045YG0`00ogooWGoo00<007ooOol04Goo00<007ooOol027oo003GOol3001jOol0
0`00:GLYM`04:GL00`00@MI1eP0<@MH00`00ESIF=P0?ESH00`00EUIFEP0@EUH00`00FUMJE`0?FUL2
003oOonPOol00`00Oomoo`0@Ool00`00Oomoo`08Ool00=Uoo`8007Yoo`03000YMbUg00<YM`030011
eT7F00a1eP03001F=UHf00mF=P03001FEUIF011FEP03001JEeYG00iJE`03001oogoo0?mooj5oo`03
001oogoo00moo`03001oogoo00Qoo`00Vgoo2P002Goo1P003Woo10005Goo0P00N7oo00<002Ug:GL0
0bUg00<0047F@MH0347F00<005HfESH045Hf00<005IFEUH03eIF00<005YGFUL035YG0P00ogooY7oo
00<007ooOol03goo00<007ooOol027oo002KOol:0007Ool:000:Ool8000EOol2001fOol20004:GL0
0`00@MI1eP0<@MH00`00ESIF=P0@ESH00`00EUIFEP0?EUH00`00FUMJE`0;FUL00`00Oomoo`3oOonU
Ool00`00Oomoo`0>Ool00`00Oomoo`08Ool009moo`8000]oo`<000Eoo`<000Uoo`8000Aoo`8001Mo
o`8000=oo`03001oogoo06ioo`03001oo`0000<YM`030011eT7F00a1eP03001F=UHf011F=P03001F
EUIF011FEP03001JEeYG00UJE`03001oogoo0?moojMoo`03001oogoo00eoo`03001oogoo00Qoo`00
Wgoo0P0057oo0P0027oo0P001Woo0P0067oo0P0000=oo`00Ool0Kgoo00<007oo00000bUg00<0047F
@MH0347F00<005HfESH045Hf00<005IFEUH045IF00<005YGFUL01eYG0P00ogooZgoo00<007ooOol0
37oo00<007ooOol027oo002OOol2000EOol20007Ool20006Ool2000JOol2001`Ool01000Oomoo`00
0RUg00<0047F@MH03D7F00<005HfESH03eHf00<005IFEUH045IF00<005YGFUL01UYG00<007ooOol0
ogooZgoo00<007ooOol037oo00<007ooOol027oo002OOol2000EOol20006Ool20008Ool2000JOol3
001^Ool01000Oomoo`000RUg00<0047F@MH03D7F00<005HfESH03eHf00<005IFEUH045IF00<005YG
FUL015YG0P00ogoo[goo00<007ooOol02goo00<007ooOol027oo002OOol2000EOol20006Ool20008
Ool2000MOol20007Ool00`00Oomoo`1ROol01`00Oomoogoo000YM`0000m1eP03001F=UHf00mF=P03
001FEUIF011FEP03001JEeYG00=JE`03001oogoo0?mook1oo`03001oogoo00Yoo`03001oogoo00Qo
o`00Wgoo0P005Goo0P001Woo0P0027oo0P007goo0P001Goo00<007ooOol0HWoo00<007ooOol00Woo
00<002Ug00003T7F00<005HfESH03eHf00<005IFEUH045IF00<005YGFUL00UYG00<007ooOol0ogoo
/Woo00<007ooOol02Goo00<007ooOol027oo002OOol2000EOol20006Ool20008Ool2000QOol20003
Ool00`00Oomoo`1ROol00`00Oomoo`02Ool00`00:GL0000>@MH00`00ESIF=P0?ESH00`00EUIFEP0A
EUH01000FUL00000ogoo]Goo00<007ooOol02Goo00<007ooOol027oo002OOol2000DOol20007Ool2
0008Ool2000SOol200000goo001oo`1SOol00`00Oomoo`03Ool2000>@MH00`00ESIF=P0@ESH00`00
EUIFEP0@EUH2003oOonhOol00`00Oomoo`08Ool00`00Oomoo`08Ool009moo`8000aoo`8000Eoo`<0
00Moo`8000Qoo`8002Eoo`8006Aoo`03001oogoo00Aoo`030011eT7F00a1eP03001F=UHf011F=P03
001FEUIF00mFEP800?mookYoo`03001oogoo00Moo`03001oogoo00Qoo`00Wgoo0P0037oo2@0027oo
0P0027oo0P009Woo0`00HWoo00<007ooOol017oo00<0047F@MH0347F00<005HfESH045Hf00<005IF
EUH03UIF00<007ooOol0ogoo^Woo00<007ooOol01goo00<007ooOol027oo002OOol2000<Ool20000
0goo000000030009Ool20008Ool2000YOol2001POol00`00Oomoo`05Ool00`00@MI1eP0;@MH00`00
ESIF=P0@ESH00`00EUIFEP0<EUH2003oOonnOol00`00Oomoo`06Ool00`00Oomoo`08Ool009moo`80
00aoo`80011oo`8000Ioo`8002aoo`8005ioo`03001oogoo00Ioo`030011eT7F00Y1eP03001F=UHf
011F=P03001FEUIF00]FEP03001oogoo0?mookmoo`03001oogoo00Eoo`03001oogoo00Qoo`00Wgoo
0P0037oo0P0047oo0P001Woo0P00;Woo0P000Woo00<007ooOol0Egoo00<007ooOol01goo00<0047F
@MH02T7F00<005HfESH03eHf00<005IFEUH02EIF0P00ogoo`goo00<007ooOol017oo00<007ooOol0
27oo002KOol300000goo0000000<Ool2000AOol20004Ool2000aOol3001IOol00`00Oomoo`08Ool0
0`00@MI1eP09@MH00`00ESIF=P0?ESH00`00EUIFEP08EUH00`00Oomoo`3oOoo3Ool00`00Oomoo`04
Ool00`00Oomoo`08Ool009]oo`H000aoo`X000Uoo`P003=oo`8005Qoo`03001oogoo00Uoo`030011
eT7F00Q1eP03001F=UHf00mF=P03001FEUIF00IFEP800?moolMoo`03001oogoo00Aoo`03001oogoo
00Moo`00WWoo0`0037oo2P002goo1000=Goo00@007oo000005Ioo`03001oogoo00Yoo`030011eT7F
00M1eP03001F=UHf00mF=P03001FEUIF00EFEP03001oogoo0?moolQoo`03001oogoo00=oo`03001o
ogoo00Moo`00ogoo0P00E7oo00<007ooOol02goo00<0047F@MH01T7F00<005HfESH045Hf00<005IF
EUH00UIF0P00ogooc7oo00<007ooOol00Woo00<007ooOol01goo003oOol2Ool20003Ool00`00Oomo
o`1<Ool00`00Oomoo`0<Ool00`00@MI1eP05@MH00`00ESIF=P0@ESH01@00EUIFEUIF0000ogoocWoo
00<007ooOol00Woo00<007ooOol01goo003oOol4Ool200000goo001oo`1=Ool00`00Oomoo`0=Ool0
0`00@MI1eP04@MH00`00ESIF=P0@ESH01000EUH00000ogood7oo00D007ooOomoo`0000Uoo`00ogoo
1Woo0P00CWoo00<007ooOol03Goo00<0047F@MH0147F00<005HfESH045Hf0P00ogoodgoo00@007oo
Ool000Uoo`00ogoo1goo0`00C7oo00<007ooOol03Woo00<0047F@MH00d7F00<005HfESH03eHf0P00
ogooe7oo00@007ooOol000Uoo`00ogoo2Woo0P00BWoo00<007ooOol03goo00<0047F@MH00T7F00<0
05HfESH035Hf0`00ogooegoo00<007oo00002Goo003oOol<Ool20003Ool00`00Oomoo`12Ool00`00
Oomoo`0@Ool01@00@MI1eT7F000035Hf0P00ogoofgoo0P002Goo003oOol>Ool200000goo001oo`13
Ool00`00Oomoo`0AOol01@00@MI1eT7F000025Hf0`00ogooegoo20002Goo003oOol@Ool20014Ool0
0`00Oomoo`0BOol01000@MI1eP001EHf0`00ogooc7oo3P004Goo003oOolAOol30012Ool00`00Oomo
o`0COol00`00@MH00003ESH2003oOoo0Ool?000OOol00?mooa5oo`04001oogoo0011Ool00`00Oomo
o`0DOol5003oOondOol>000^Ool00?mooaEoo`8003moo`03001oogoo01Eoo`03001oogoo0?moojMo
o`h003aoo`00egoo2P002goo10003Woo100057oo0P000goo00<007ooOol0=goo00<007ooOol0ogoo
/7oo3`00BWoo003GOol:0009Ool8000:Ool8000DOol200000goo001oo`0hOol00`00Oomoo`3oOonR
Ool>001IOol00=]oo`8000eoo`8000Aoo`8000Yoo`8000Aoo`8001Ioo`8003Uoo`03001oogoo0?mo
oiAoo`h006Moo`00fgoo0P0037oo0P001Woo0P0027oo0P001Woo0P005Woo0`001goo00<007ooOol0
;Goo00<007ooOol0ogooQWoo3P00MGoo003KOol2000<Ool20006Ool20008Ool20006Ool2000IOol2
0005Ool00`00Oomoo`0]Ool00`00Oomoo`3oOomgOol?0023Ool00=]oo`8000]oo`8000Qoo`8000Io
o`8000Qoo`8001Yoo`8000=oo`03001oogoo02eoo`03001oogoo0?moofUoo`h0099oo`00fgoo0P00
2goo0P0027oo0P001Woo0P0027oo0P0077oo0P0000=oo`00Ool0;Woo00<007ooOol0ogooFgoo3P00
X7oo003KOol2000;Ool20008Ool20006Ool20008Ool2000NOol2000_Ool00`00Oomoo`3oOom=Ool>
002^Ool00=]oo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8001moo`<002aoo`03001oogoo0?moocmo
o`l00;aoo`00fgoo0P002goo0P0027oo0P001Woo0P0027oo0P008Woo0P00:Woo00<007ooOol0ogoo
<Goo3P00bgoo003KOol2000;Ool20008Ool20006Ool20008Ool2000TOol20003Ool00`00Oomoo`0R
Ool00`00Oomoo`3oOolSOol>003IOol00=]oo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8002Ioo`80
0003Ool007oo02=oo`03001oogoo0?mooaAoo`l00>Moo`00fgoo0P002goo0P0027oo0P001Woo0P00
27oo0P00:7oo0P0097oo00<007ooOol0ogoo1Woo3P00mWoo003KOol2000<Ool20006Ool20008Ool2
0006Ool2000ZOol3000ROol00`00Oomoo`3gOol>003oOol5Ool00=]oo`8000aoo`8000Ioo`8000Qo
o`8000Ioo`8002eoo`80021oo`03001oogoo0>Uoo`h00?mooa=oo`00egoo0`0000=oo`0000003Goo
0P0017oo0P002Woo0P0017oo0P00<7oo0P000goo00<007ooOol067oo00<007ooOol0fWoo3`00ogoo
8Goo003GOol6000=Ool8000:Ool8000bOol200000goo001oo`0IOol00`00Oomoo`3<Ool>003oOol`
Ool00=Yoo`<000moo`@000ioo`@003Ioo`8001Yoo`03001oogoo0;ioo`h00?moocioo`00ogoo>Woo
0`0067oo00<007ooOol0[goo3`00ogooC7oo003oOolmOol20004Ool00`00Oomoo`0?Ool00`00Oomo
o`2QOol>003oOomKOol00?moocmoo`80009oo`03001oogoo00moo`03001oogoo09=oo`h00?moofUo
o`00ogoo@Goo0`004Goo00<007ooOol0QGoo3P00ogooMgoo003oOom3Ool2000@Ool00`00Oomoo`1f
Ool?003oOon5Ool00?mood=oo`04001oo`00000>Ool00`00Oomoo`1XOol>003oOonDOol00?moodMo
o`8000=oo`03001oogoo00Ioo`03001oogoo05Yoo`h00?mooj9oo`00ogooBGoo0P0000=oo`00Ool0
1goo00<007ooOol0C7oo3P00ogoo/7oo003oOolHOol6000>Ool4000KOol20008Ool00`00Oomoo`0m
Ool?003oOonnOol00?mooaIoo`X000Yoo`P001Yoo`<000Ioo`03001oogoo02moo`h00?mooleoo`00
ogoo5Woo0`001Goo0`002Goo0P0017oo0P007Goo0P0017oo00<007ooOol08Goo3P00ogoofgoo003o
OolOOol20008Ool20006Ool2000NOol20002Ool00`00Oomoo`0BOol?003oOooYOol00?moob1oo`80
00Moo`8000Ioo`80021oo`<000Ioo`h00?moooQoo`00ogoo87oo0P001Woo0P0027oo0P008Goo1`00
ogooogoo1goo003oOolPOol20006Ool20008Ool2003oOoooOol_Ool00?moob1oo`8000Ioo`8000Qo
o`800?mooomoobmoo`00ogoo87oo0P001Woo0P0027oo0P00ogooogoo;goo003oOolOOol20007Ool2
0008Ool2003oOoooOol_Ool00?mooaMoo`8000Eoo`<000Moo`8000Qoo`800?mooomoobmoo`00ogoo
5goo2@0027oo0P0027oo0P00ogooogoo;goo003oOolGOol200000goo000000030009Ool20008Ool2
003oOoooOol_Ool00?mooaMoo`80011oo`8000Ioo`800?mooomooc1oo`00ogoo5goo0P0047oo0P00
1Woo0P00ogooogoo<7oo003oOolGOol2000AOol20004Ool2003oOoooOolaOol00?mooaMoo`X000Uo
o`P00?mooomooc5oo`00ogoo5goo2P002goo1000ogooogoo<goo003oOoooOoooOomSOol00?mooomo
oomoof=oo`00\
\>"], "Graphics",
  CellLabel->"From In[35]:=",
  Evaluatable->False,
  ImageSize->{288, 173.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["Control plot of interpolated vector potential.", "Text"],

Cell[CellGroupData[{

Cell["\<\
u=Table[p[j/2,i/2],{i,1,nz},{j,1,ns}];Timing[Do[{u=m;
If[Mod[i,100]==0,{err=Max[Abs[Flatten[u-m]]];Print[i,\" residual error: \
\",err];If[err<10^-6,Break[]]}]},{i,1,7000}]]
ListPlot3D[u,ImageSize->400,ViewPoint->{1,-4.000,3}];\
\>", "Input",
  CellLabel->"In[107]:=",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}},
  Background->GrayLevel[0.849989]],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000B`0003k1000`40O003h00Oogooogooogooogoo
]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOooo
OoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOond
Ool00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomo
oomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAo
o`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogoo
ogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo
003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOooo
OoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol0
0?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomo
oomookAoo`00ogooogooogooM7oo1`002Woo10003Woo1000ogoo6Goo003oOoooOoooOomdOol70008
Ool8000:Ool8003oOolGOol00?mooomooomoogMoo`8000Yoo`8000Aoo`8000Yoo`8000Aoo`800?mo
oaMoo`00ogooogooogooMgoo0P002Goo0P001Woo0P0027oo0P001Woo0P00ogoo5Woo003oOoooOooo
OomgOol20009Ool20006Ool20008Ool20006Ool2003oOolFOol00?mooomooomoofmoo``000Ioo`80
00Qoo`8000Ioo`8000Qoo`800?mooaEoo`00ogooogooogooKgoo30001Woo0P0027oo0P001Woo0P00
27oo0P00ogoo5Goo003oOoooOoooOom_Ool20006Ool200000goo001oo`05Ool20008Ool20006Ool2
0008Ool2003oOolEOol00?mooomooomoog1oo`8000Eoo`8000Qoo`8000Qoo`8000Ioo`8000Qoo`80
0?mooaEoo`00ogooogooogooL7oo0`0017oo0P0027oo0P0027oo0P001Woo0P0027oo0P00ogoo5Goo
003oOoooOoooOomaOol20004Ool20008Ool20008Ool20006Ool20008Ool2003oOolEOol00?mooomo
oomoog9oo`8000=oo`8000Qoo`8000Qoo`8000Ioo`8000Qoo`800?mooaEoo`00ogooogooogooLWoo
0`000Woo0P0027oo0P0027oo0P001Woo0P0027oo0P00ogoo5Goo003oOoooOoooOomcOol20002Ool2
0009Ool20006Ool20008Ool20006Ool2003oOolFOol00?mooomooomoogAoo`800003Ool0000000Uo
o`8000Ioo`8000Qoo`8000Ioo`800?mooaIoo`00ogooogooogooMGoo10002Woo0P0017oo0P002Woo
0P0017oo0P00ogoo5goo003oOoooOoooOomeOol4000:Ool8000:Ool8003oOolGOol00?mooomooomo
ogIoo`<000aoo`@000ioo`@00?mooaUoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol0
0?mooomooomoonMoo`@00<Qoo`00ogooogooogoohGoo1P000goo00<007ooOol0aWoo003oOoooOooo
OooKOol60009Ool00`00Oomoo`36Ool00?mooomooomoomEoo`H0009oo`03001oogoo00Yoo`800<Mo
o`00ogooogooogoocgoo1P0027oo00<007ooOol02Woo0P00agoo003oOoooOoooOoo9Ool6000>Ool0
0`00Oomoo`0:Ool20037Ool00?mooomooomool=oo`H001Aoo`03001oogoo00Yoo`03001oo`000<Io
o`00ogooogooogoo_Goo1P006Woo00<007ooOol02Woo00<007oo0000aWoo003oOoooOoooOongOol6
000]Ool00`00Ool00036Ool00?mooomooomook5oo`H003Aoo`800<Ioo`00ogooogooogooZgoo1P00
0Woo00<007ooOol0=Goo00<007oo0000aGoo003oOoooOoooOonUOol60008Ool00`00Oomoo`0eOol0
0`00Ool00035Ool00?mooomooomooimoo`H000ioo`03001oogoo03Eoo`03001oo`000<Eoo`00ogoo
ogooogooVGoo1P0057oo00<007ooOol0=Goo00<007oo0000aGoo003oOoooOonSOol5000>Ool4000>
Ool40036Ool6000JOol00`00Oomoo`0eOol01000Oomoo`00a7oo003oOoooOonQOol9000:Ool8000:
Ool8002nOol6001HOol01000Oomoo`00a7oo003oOoooOonPOol40004Ool30009Ool20004Ool2000:
Ool20004Ool2002hOol6001NOol01000Oomoo`00a7oo003oOoooOonPOol20007Ool30007Ool20006
Ool20008Ool20006Ool2002aOol60002Ool00`00Oomoo`1OOol01@00Oomoogoo0000`goo003oOooo
OonZOol20007Ool20006Ool20008Ool20006Ool2002[Ool60008Ool00`00Oomoo`1OOol01@00Oomo
ogoo0000`goo003oOoooOonZOol20006Ool20008Ool20006Ool20008Ool2002TOol6000>Ool00`00
Oomoo`1OOol01@00Oomoogoo0000`goo003oOoooOonZOol20006Ool20008Ool20006Ool20008Ool2
002NOol6000DOol00`00Oomoo`1OOol01@00Oomoogoo0000`goo003oOoooOonYOol30006Ool20008
Ool20006Ool20008Ool2002HOol6000JOol00`00Oomoo`1OOol00`00Oomoo`02Ool00`00Oomoo`30
Ool00?mooomoojQoo`<000Moo`8000Qoo`8000Ioo`8000Qoo`80099oo`H0021oo`03001oogoo05mo
o`03001oogoo009oo`03001oogoo0<1oo`00ogooogooYGoo1@0027oo0P0027oo0P001Woo0P0027oo
0P00S7oo1P009Woo00<007ooOol0Ggoo00<007ooOol00Woo00<007ooOol0`7oo003oOoooOonUOol4
0009Ool20008Ool20006Ool20008Ool20026Ool60002Ool00`00Oomoo`0WOol00`00Oomoo`1OOol0
0`00Oomoo`03Ool00`00Oomoo`2oOol00?mooomoojQoo`8000Qoo`8000Qoo`8000Ioo`8000Qoo`80
081oo`H000Qoo`03001oogoo08Uoo`03001oogoo00=oo`03001oogoo0;moo`00ogooogooZGoo0P00
1goo0P0027oo0P001Woo0P0027oo0P00NWoo1P003Woo00<007ooOol0RWoo00<007ooOol00Woo00<0
07ooOol0_goo003oOoooOonYOol20008Ool20006Ool20008Ool20006Ool2001eOol6000DOol00`00
Oomoo`2:Ool00`00Oomoo`02Ool00`00Oomoo`2oOol00?mooomooj5oo`8000Ioo`8000Qoo`8000Io
o`8000Qoo`8000Ioo`8006moo`H001Yoo`03001oogoo08Yoo`03001oogoo00=oo`03001oogoo0;io
o`00ogooogooXGoo0`0017oo0`002Goo0P0017oo0P002Woo0P0017oo0P00JWoo1P00[Goo00<007oo
Ool00goo00<007ooOol0_Woo003oOoooOonROol8000:Ool8000:Ool8001TOol6002cOol00`00Oomo
o`03Ool00`00Oomoo`2nOol00?mooomooj=oo`D000ioo`@000ioo`@0061oo`H0009oo`03001oogoo
0;Aoo`03001oogoo00=oo`03001oogoo0;ioo`00ogooogooogoo9goo1P0027oo00<007ooOol0]7oo
00<007oo00001@00_goo003oOoooOoooOolQOol6000?Ool00`00Oomoo`2cOol00`00Oomoo`04Ool0
0`00Oomoo`2mOol00?mooomooomooa]oo`H001Eoo`03001oogoo0;=oo`03001oogoo00Aoo`03001o
ogoo0;eoo`00ogooogooogoo5Goo1P006goo00<007ooOol0/goo00<007ooOol01Goo00<007ooOol0
_7oo003oOoooOoooOol?Ool6003GOol00`00Oomoo`05Ool00`00Oomoo`2lOol00?mooomooomoo`Uo
o`H00=eoo`03001oogoo00Eoo`03001oogoo0;aoo`00ogooogooogoo17oo1@000goo00<007ooOol0
gGoo00<007ooOol01Goo00<007ooOol0_7oo003oOoooOoomOol60008Ool00`00Oomoo`3MOol00`00
Oomoo`06Ool00`00Oomoo`2kOol00?mooomoooMoo`H000ioo`03001oogoo0=eoo`03001oogoo00Io
o`03001oogoo0;]oo`00ogooogoolGoo1P0057oo00<007ooOol0gGoo00<007ooOol01Woo00<007oo
Ool0^goo003oOoooOoo[Ool6000JOol00`00Oomoo`3MOol00`00Oomoo`06Ool00`00Oomoo`2kOol0
0?mooomoonEoo`H00?moo`9oo`03001oogoo00Ioo`03001oogoo0;Yoo`00ogooogooggoo1P00ogoo
27oo00<007ooOol01Woo00<007ooOol0^Woo003oOoooOooIOol60003Ool00`00Oomoo`3oOol8Ool0
0`00Oomoo`06Ool00`00Oomoo`2jOol00?mooomoom=oo`H000Uoo`03001oogoo0?moo`Qoo`03001o
ogoo00Moo`03001oogoo0;Uoo`00ogooogoocGoo1P003goo00<007ooOol0ogoo27oo00<007ooOol0
1goo00<007ooOol0^Goo003oOooDOol<000;Ool4000>Ool40035Ool6000EOol00`00Oomoo`3oOol8
Ool00`00Oomoo`07Ool00`00Oomoo`2iOol00?moomAoo``000Uoo`P000Yoo`P00;eoo`H00?moobIo
o`03001oogoo00Moo`03001oogoo0;Uoo`00ogooeGoo0`001Woo0P002Goo0P0017oo0P002Woo0P00
17oo0P00]goo1P00ogoo;7oo00<007ooOol027oo00<007ooOol0^7oo003oOooFOol3000?Ool20006
Ool20008Ool20006Ool2002`Ool6003oOolbOol00`00Oomoo`08Ool00`00Oomoo`2hOol00?moomMo
o`<000ioo`8000Ioo`8000Qoo`8000Ioo`800:Yoo`H000=oo`03001oogoo0?mooc9oo`03001oogoo
00Qoo`03001oogoo0;Qoo`00ogoof7oo0`0037oo0P0027oo0P001Woo0P0027oo0P00Xgoo1P002Goo
00<007ooOol0ogoo<Woo00<007ooOol02Goo00<007ooOol0]goo003oOooIOol3000;Ool20008Ool2
0006Ool20008Ool2002MOol6000?Ool00`00Oomoo`3oOolbOol00`00Oomoo`09Ool00`00Oomoo`2g
Ool00?moomYoo`<000Yoo`8000Qoo`8000Ioo`8000Qoo`8009Moo`H001Eoo`03001oogoo0?mooc9o
o`03001oogoo00Uoo`03001oogoo0;Moo`00ogoofgoo0`002Goo0P0027oo0P001Woo0P0027oo0P00
TGoo1P006goo00<007ooOol0ogoo<Woo00<007ooOol02Goo00<007ooOol0]goo003oOooLOol30008
Ool20008Ool20006Ool20008Ool2002;Ool6000QOol00`00Oomoo`3oOolbOol00`00Oomoo`0:Ool0
0`00Oomoo`2fOol00?moomeoo`8000Qoo`8000Qoo`8000Ioo`8000Qoo`8008Eoo`H002Moo`03001o
ogoo0?mooc9oo`03001oogoo00Yoo`03001oogoo0;Ioo`00ogoogWoo0P001goo0P0027oo0P001Woo
0P0027oo0P00Ogoo1P0017oo00<007ooOol0ogooG7oo00<007ooOol02Goo00<007ooOol0]Woo003o
OooNOol20007Ool20008Ool20006Ool20008Ool2001iOol6000:Ool00`00Oomoo`3oOomLOol00`00
Oomoo`09Ool00`00Oomoo`2fOol00?moomEoo`8000Moo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`80
07Aoo`H0011oo`03001oogoo0?mooeaoo`03001oogoo00Yoo`03001oogoo0;Eoo`00ogooeGoo0`00
1Woo0P0027oo0P001Woo0P0027oo0P001Woo0P00KWoo1P005Woo00<007ooOol0ogooG7oo00<007oo
Ool02Woo00<007ooOol0]Goo003oOooEOol40004Ool2000:Ool20004Ool2000:Ool20004Ool2001Y
Ool6003oOomkOol00`00Oomoo`0:Ool00`00Oomoo`2eOol00?moomIoo`P000]oo`P000Yoo`P006=o
o`H00?mooh5oo`03001oogoo00]oo`03001oogoo0;Aoo`00ogoof7oo1@003Woo10003Woo1000Ggoo
1P00ogooQgoo00<007ooOol02goo00<007ooOol0]7oo003oOoooOomKOol60005Ool00`00Oomoo`3o
Oon5Ool00`00Oomoo`0;Ool00`00Oomoo`2dOol00?mooomooeEoo`H000]oo`03001oogoo0?moohEo
o`03001oogoo00]oo`03001oogoo0;Aoo`00ogooogooCgoo1P004Goo00<007ooOol0ogooQGoo00<0
07ooOol037oo00<007ooOol0/goo003oOoooOom9Ool6000GOol00`00Oomoo`3oOon5Ool00`00Oomo
o`0<Ool00`00Oomoo`2cOol00?mooomood=oo`H00?moojEoo`03001oogoo00Yoo`<00;Eoo`00ogoo
ogoo?Goo1P00ogooZgoo00<007ooOol027oo0P000goo00<007ooOol0/Woo003oOoooOolgOol7003o
Oon`Ool00`00Oomoo`0=Ool00`00Oomoo`2bOol00?mooomooc5oo`H000Ioo`03001oogoo0?moojio
o`03001oogoo00eoo`03001oogoo0;9oo`00ogooogoo:goo1P0037oo00<007ooOol0ogoo[Woo00<0
07ooOol03Goo00<007ooOol0/Woo003oOoooOolUOol6000BOol00`00Oomoo`3oOon^Ool00`00Oomo
o`0>Ool00`00Oomoo`2aOol00?mooomooamoo`H001Qoo`03001oogoo0?moojmoo`03001oogoo00eo
o`03001oogoo0;5oo`00ogooogoo6Goo1P00ogood7oo00<007ooOol03Goo00<007ooOol0/Goo003o
OoooOolCOol6003oOooFOol00`00Oomoo`0=Ool00`00Oomoo`2aOol00?mooomoo`eoo`H0009oo`03
001oogoo0?moomMoo`03001oogoo00ioo`03001oogoo0;1oo`00ogooogoo1goo1P0027oo00<007oo
Ool0ogooegoo00<007ooOol03Woo00<007ooOol0/7oo003oOoooOol1Ool6000>Ool00`00Oomoo`3o
OooGOol00`00Oomoo`0>Ool00`00Oomoo`2`Ool00?moo`moo`X000]oo`@000ioo`@00<1oo`H001Ao
o`03001oogoo0?moomMoo`03001oogoo00moo`03001oogoo0:moo`00ogoo3goo2P002Goo20002Woo
2000^7oo1P006Woo00<007ooOol0ogooegoo00<007ooOol03goo00<007ooOol0[goo003oOolCOol2
000=Ool20004Ool2000:Ool20004Ool2002bOol6003oOoojOol00`00Oomoo`0?Ool00`00Oomoo`2_
Ool00?mooa=oo`8000aoo`8000Ioo`8000Qoo`8000Ioo`800:]oo`H00?mooomoo`5oo`03001oogoo
00moo`03001oogoo0:moo`00ogoo4goo0P0037oo0P001Woo0P0027oo0P001Woo0P00YGoo1P000goo
00<007ooOol0ogooogoo0Goo00<007ooOol047oo00<007ooOol0[Woo003oOolCOol2000;Ool20008
Ool20006Ool20008Ool2002NOol60009Ool00`00Oomoo`3oOoooOol1Ool00`00Oomoo`0@Ool00`00
Oomoo`2^Ool00?mooa=oo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8009Qoo`H000moo`03001oogoo
0?mooomoo`5oo`03001oogoo011oo`03001oogoo0:ioo`00ogoo4goo0P002goo0P0027oo0P001Woo
0P0027oo0P00TWoo1P005Goo00<007ooOol0ogooogoo0Goo00<007ooOol04Goo00<007ooOol0[Goo
003oOolCOol2000;Ool20008Ool20006Ool20008Ool2002<Ool6000KOol00`00Oomoo`3oOoooOol1
Ool00`00Oomoo`0AOol00`00Oomoo`2]Ool00?mooa=oo`8000]oo`8000Qoo`8000Ioo`8000Qoo`80
08Ioo`H0025oo`03001oogoo0?mooomoo`5oo`03001oogoo015oo`03001oogoo0:eoo`00ogoo4goo
0P002goo0P0027oo0P001Woo0P0027oo0P00P7oo1P009goo00<007ooOol0ogooogoo0Woo00<007oo
Ool047oo00<007ooOol0[Goo003oOolCOol2000;Ool20008Ool20006Ool20008Ool2001jOol60005
Ool00`00Oomoo`3oOoooOolZOol00`00Oomoo`0AOol00`00Oomoo`2/Ool00?mooa=oo`8000]oo`80
00Qoo`8000Ioo`8000Qoo`8007Aoo`H000]oo`03001oogoo0?mooomoobYoo`03001oogoo015oo`03
001oogoo0:aoo`00ogoo4goo0P0037oo0P001Woo0P0027oo0P001Woo0P00Kgoo1P004Goo00<007oo
Ool0ogooogoo:Woo00<007ooOol04Goo00<007ooOol0[7oo003oOolCOol2000<Ool20006Ool20008
Ool20006Ool2001YOol6000GOol00`00Oomoo`3oOoooOolZOol00`00Oomoo`0AOol00`00Oomoo`2/
Ool00?moo`moo`<00003Ool0000000eoo`8000Aoo`8000Yoo`8000Aoo`8006Aoo`H00?mooomoodYo
o`03001oogoo019oo`03001oogoo0:]oo`00ogoo3goo1P003Goo20002Woo2000GWoo1P00ogooogoo
D7oo00<007ooOol04Woo00<007ooOol0Zgoo003oOolBOol3000?Ool4000>Ool4001JOol600000goo
001oo`3oOoooOomCOol00`00Oomoo`0BOol00`00Oomoo`2[Ool00?moohioo`H000Moo`03001oogoo
0?mooomooe9oo`03001oogoo01=oo`03001oogoo0:Yoo`00ogooR7oo1P003Goo00<007ooOol0ogoo
ogooDWoo00<007ooOol04goo00<007ooOol0ZWoo003oOon2Ool6000COol00`00Oomoo`3oOoooOomB
Ool00`00Oomoo`0COol00`00Oomoo`2ZOol00?moogaoo`H001Uoo`03001oogoo0?mooomooe9oo`03
001oogoo01=oo`03001oogoo0:Yoo`00ogooMWoo1P00ogooogooM7oo00<007ooOol057oo00<007oo
Ool0ZGoo003oOom`Ool6003oOoooOomjOol00`00Oomoo`0DOol00`00Oomoo`2YOol00?moofYoo`H0
00=oo`03001oogoo0?mooomoogYoo`03001oogoo01Aoo`03001oogoo0:Uoo`00ogooI7oo1P002Goo
00<007ooOol0ogooogooNWoo00<007ooOol057oo00<007ooOol0ZGoo003oOomNOol6000?Ool00`00
Oomoo`3oOoooOomjOol00`00Oomoo`0COol3002ZOol00?mooeQoo`H001Eoo`03001oogoo0?mooomo
og]oo`03001oogoo00moo`<0009oo`03001oogoo0:Qoo`00ogooDWoo1P00ogooogooVGoo00<007oo
Ool057oo00<007ooOol0Z7oo003oOom<Ool6003oOoooOonOOol00`00Oomoo`0EOol00`00Oomoo`2W
Ool00?moodIoo`H00?mooomoo`Qoo`P009Eoo`03001oogoo01Eoo`03001oogoo0:Moo`00ogoo@Goo
1@001Goo00<007ooOol0ogooogoo1P0000Q<b000EBT0066;001^3000UGoo00<007ooOol05Goo00<0
07ooOol0Ygoo003oOolkOol6000:Ool00`00Oomoo`3oOooiOol600003T1V0014QP00B:L004c8001E
:@00HH/006h<002EOol00`00Oomoo`0EOol00`00Oomoo`2WOol00?moocEoo`H0011oo`03001oogoo
0?mooo9oo`L0000;?4D003a50010A@00@6H004B60018Y`0200001UDY001QRf6;001^308009Aoo`03
001oogoo01Ioo`03001oogoo0:Ioo`00ogoo;goo1P005Woo00<007ooOol0ogook7oo1P0000Xl9@00
?2Dl9@00?4D003a5000lA@80000<@6H004B60018Y`00C<P005DY001QR`000Vh<0P00U7oo00<007oo
Ool05Woo00<007ooOol0YWoo003oOolYOol6003oOoooOol6Ool600008SPU000h9@00?2D003`U000l
9@00?4D003a5000lA@00@4D0041V0014QP00B:L004c8001E:@00HH/006h<001fK@00U7oo00<007oo
Ool05Woo00<007ooOol0YWoo003oOolSOol6003oOoooOol6Ool600002C@W000d9P00>2H003PU000h
9@02000073`U000l9C`U000lA@00?4D003a50010A@00@6H004B60018Y`00C<P005DY001QR`00KP`0
07I]0P00Tgoo00<007ooOol05goo00<007ooOol0YGoo003oOolMOol7003oOoooOol:Ool0300030T0
0208000/1`00=2L003@V000h9P800008>2D003`U000l9@00?2D0008lA@04000lA@00?4D200001T1V
0014QP00B:L0009<b008001E:@00HH/006h<001fK@8009=oo`03001oogoo01Moo`03001oogoo0:Eo
o`00ogoo5goo1P001Woo00<007ooOol0ogooogoo27oo00H000`9000P2000;0L200004c@V000h9P00
>2D003PU000l9@00?2D003`U000lA@00?4D003a500/00008EBT0066;HH/006h<001fK@8009=oo`03
001oogoo01Moo`03001oogoo0:Eoo`00ogoo4Goo1P0037oo00<007ooOol0ogooogoo27oo00l000`9
000002`7000d9`00=2H003PV000h9@00>2D00P0000<l9@000000200000U0I@00A8H004RV001<a`00
E@P00`0000IQR`00KPa^3000MVd3002BOol00`00Oomoo`0GOol00`00Oomoo`2UOol00?moo`]oo`H0
019oo`03001oogoo0?mooomoo`Qoo`80000980P002`7000d9`00=2H003PV00800003>2D0000000<0
000D?2D003a5?4D003a50010A@00@6D004B60018YP00C<L005D8001MB@<0009^3003001fK@000080
099oo`03001oogoo01Qoo`03001oogoo0:Aoo`00ogoo1Goo1P0067oo00<007ooOol0ogooogoo27oo
0P0000DP2000;0L003@W00800003>2H0000000<0000D>2D003PU000l9@00?4D003a50010A@00@6D0
04B60018YP00C<L0009E2005001MB@00IJX00002KP`01000MVd007J50P00TGoo00<007ooOol067oo
00<007ooOol0Y7oo003nOol6000NOol00`00Oomoo`3oOoooOol7Ool01P0030T00208000/1`H00003
=0D003P500800004>2D003`U0002?4D04@00?4D004150010I@00A8H004RV001<a`00E@P005e90000
0VFZ00@006h<KP`0009fK@<0095oo`03001oogoo01Qoo`03001oogoo0:Aoo`00n7oo1P0097oo00<0
07ooOol0ogooogoo1goo00@000`9000P20@00005;0D00305000d1@02000023PU000h9@00?2D003a5
0002?4D03`00@4D0041U0014QP00B:H004c7001E2000GDT00002IJX30003MVd3002AOol00`00Oomo
o`0HOol00`00Oomoo`2TOol00?9oo`H0009oo`03001oogoo02Eoo`03001oogoo0?mooomoo`Moo`03
000<2@0000<0000390D002`50080000H=0D003P5000h9@00>2D003`U000lA@00?4D004150010I@00
A8H004RV001<a`000UD800H005e9001UZP00KP/20003MVd200000g9S001oo`2@Ool00`00Oomoo`0H
Ool00`00Oomoo`2SOol00>aoo`H000Qoo`03001oogoo0?mooomoobmoo`07000<2@00000D1@0090D0
0P0000D`1@00=0D003P500800003>2D003`U0180009MB@04001UZP00KP/20003MVd200000g9S001o
o`2@Ool00`00Oomoo`0HOol00`00Oomoo`2SOol00>Ioo`H000ioo`03001oogoo0?mooomoobmoo`80
000380P001@500800005;0D00305000d1@0800004Ca50010AD150010I@00A6D004R6001<YP00D>L0
05TX00000Ue900<006FZ00000Vh;00@007I]MVefK@800003LV<007oo091oo`03001oogoo01Qoo`03
001oogoo0:=oo`00h7oo1P0057oo00<007ooOol0ogooogoo;goo1@0000<T1@00;0D00P0001@d1@00
000003P4000h9000?2D003a50010A@00@6D004AU0018QP000TbV00@0053W001I:0<0009UZP04001^
2fh;0003MVd00`00MXD00002002@Ool00`00Oomoo`0IOol00`00Oomoo`2ROol00=Yoo`H00?mooomo
odaoo`<0000350D002@500H00003=0@003P400800004?2D003a50002@4D02`00@6D004AU0018QP00
C:H0053W00000UTX00<0065X00000VFZ00@006h;KP/000=fK@05001fQ@00LV<0002@Ool00`00Oomo
o`0IOol00`00Oomoo`2ROol00==oo`L00?mooomooe9oo`<0000350D0000000800003;0@003040080
000:>0@003PT000l9@00?4D004150002@6D02`00A6D004R6001<YP00D>L005TX00000V5X0`000fh;
0P000gI]0P0000=bH`00Ool0Sgoo00<007ooOol06Goo00<007ooOol0XWoo003>Ool6003oOoooOomG
Ool400001Q@5000002@4000/1080000B=0@003P4000h9000?2D003a50010A@00@6D004AU0018QP00
0TbV00D0053W001I:000009QJ003001YZ@0000=^2`8000=fK@800003LV<007oo08moo`03001oogoo
01Uoo`03001oogoo0:9oo`00b7oo1P001Goo00<007ooOol0ogooogooEGoo0P0000<00`0000000P00
00PT1000000`1000=0@003P40P0000<l9@00?4D0300000M@i`00FBQI:000HFP00002JJT01P00KP]^
2`00MT/000=fK@800003LV<0000008moo`03001oogoo01Yoo`03001oogoo0:5oo`00`Woo1P002goo
00<007ooOol0ogooogooEGoo0P0000@00`00000H0`800003;0@0030400800003>0@0000000D0000:
@4D0041U@6D004AU0018QP00C:H50002HFP00`00JJUYZ@0200001Fh;001fBgI;00000WI]0P0000=b
H`000000Sgoo00<007ooOol06Woo00<007ooOol047oo30002goo1000MWoo002lOol6000AOol00`00
Oomoo`3oOoooOomEOol600000b@4000/100600002SP4000l9000?2D004150010I@000TAU00T004R6
001<YP00D>L005T700000V5X00<006VY00000VgZ0P000WI;00P007I]MVd007J5001bH`00Sgoo00<0
07ooOol06Woo00<007ooOol047oo30002Goo2000M7oo002fOol6000GOol00`00Oomoo`3oOoooOomE
Ool3000010@2000002@4100000D`1000=0@003P400800004?2D004150002@6D01`00A6D004R6001<
YP00009@i`03001I1`000080009YZ@03001]jVgZ0080009fB`03001fK@0000<00003LV<007oo08io
o`03001oogoo01]oo`03001oogoo011oo`<000Ioo`8000Uoo`8000Aoo`8007Aoo`00/7oo1P00ogoo
ogooMGoo100000<H0`0000000P0000</1000<0@00P0000Xh1000?2@003`U0010A@00@6D00094I@07
0018QP00C:H0053W00000UT700<005e800000VVY00D006gZKNY]jP00009fB`08001fK@00001fQ@00
LV<008moo`03001oogoo01]oo`03001oogoo015oo`<000moo`8000Ioo`8007=oo`00ZWoo1P00ogoo
ogooNWoo2000014X0`00000`1000=0@003P4000l9000?2D004150010I@000094I@090018QP00C:H0
053W001I1`00009MB004001YZFVY0003KNX01000MT]fBgI;0P0000AjR@00001bH`8008ioo`03001o
ogoo01]oo`03001oogoo019oo`<000ioo`8000Ioo`8007=oo`00Y7oo1P000Woo00<007ooOol0ogoo
ogooNgoo0`0000@40P00000L0P800007;0@00304000d1000>0@00P0000@l9@00@4D00090I@070014
I@00B8H004bV00000U3W00<005T700000Ue80`0016gZ00D007I;MT]fB`00009jR@D008ioo`03001o
ogoo01]oo`03001oogoo01=oo`<000aoo`8000Qoo`80079oo`00WWoo1P0027oo00<007ooOol0ogoo
ogooNgoo1`0000DX0`00;0@0030400800003>0@000000100009I1`03001MB000009UR007001]jVgZ
KNX0078900000WI;00D007Z9NXT007J500<008ioo`03001oogoo01aoo`03001oogoo01=oo`<000]o
o`8000Qoo`80079oo`00V7oo1P003Goo00<007ooOol0ogooogooO7oo100000@@0@00000X0`800003
<0@0000000<00008>2@003`T0010A@00@4D00094I@060018Q@00C:H005360`000Ue800@006F8IHP0
00=]jP04001b2@00MT/20002NXT00`00MXD00002002>Ool00`00Oomoo`0LOol00`00Oomoo`0DOol3
000:Ool20008Ool2001bOol0099oo`H001=oo`03001oogoo0?mooomoogaoo`D000037080000000@0
0003=0@003P400800006?2@004150010A@000TAU00D004R5001<YP00009@aP03001E1`00009MB005
001UR000KLP00002KNX02P00LPT007I;001jB@00NXT007J50`00Sgoo00<007ooOol06goo00<007oo
Ool05Goo0`002Goo0P0027oo0P00LWoo002<Ool6003oOoooOonGOol400000a010000000200000b`3
000`100200002SP4000h9000?2@004150010A@000TAU00L004R5001<YP00D<H00002E@L30002IHP0
0`00KLQ]b0020003LPT2000027Y9001jR@00MXD0079S002?Ool00`00Oomoo`0KOol00`00Oomoo`0F
Ool30008Ool20008Ool2001bOol008Ioo`H00?mooomooieoo`@000064040000090<002`30P0000hd
1000>0@003PT000l9000@4D004150014I@000TR500L004bV001@aP00E@L00002GBL01000IHQUR000
0fg800D00789LPUb2@00009jB@06001jR@00MXD0079S0P00SWoo00<007ooOol077oo00<007ooOol0
5Woo0P0027oo0P0027oo0P00LWoo0020Ool6003oOoooOonSOol800001b`3000`1000=0@003P40080
0006?2@004150010A@000TAU00D004R5001<YP00009@aP03001E1`00009M9`<000A]b005001b2G89
LPT00002NTT01@00NXUjR@00MXD00`00SWoo00<007ooOol06Goo10006Goo0P001goo0P0027oo0P00
LWoo001jOol60004Ool00`00Oomoo`3oOoooOonROol600001B@3000/0`00<0@00P0000<h10000000
40000UD700<005dW00000V5W00P006g8KLQ]b000LNP007890P000WY900D007Z9NXT007J500<008]o
o`@001Moo`@000=oo`03001oogoo01Moo`8000Moo`8000Qoo`80079oo`00M7oo1P002Woo00<007oo
Ool0ogooogooXGoo100000H<0000000T0`00;0<600002SPT000l9000?4@004150014I@000TAU00@0
04R5001<Y@<0009M9`04001QIf5W0002KLP02000LNQaj000LPT007HX0002NTT01`00NXT007J5001b
H`0008Aoo`L00004E]/005KK000OOol00`00Oomoo`0=Ool20007Ool20008Ool20006Ool2001cOol0
06ioo`H0011oo`03001oogoo0?mooomooj5oo`D0000470800000;0<300001C@4000h1000>2@00P00
00HlA000@4D004AU0002A6D00`00B8D00002C:D03000E<H00000GBL0065W001YQ`00KLP0009aj005
001b2@00MRP00002NTT3000017J5001bH`00OWoo1P0000IFf`00E]/005KK0002E]/00`00E]/0000O
Ool00`00Oomoo`0=Ool30006Ool20008Ool20006Ool2001cOol006Qoo`H001Ioo`03001oogoo0?mo
oomooj5oo`<000033000000000@0000?<0<00000>0@003PT000l9000?4@004150014I@000094I@05
0018Q@00C:D00002E<H00`00F@H00002HFL01000JHMYQ`00177X00@007HXMRP0009jB@03001jIP00
00800003LV<007oo07Ioo`L0000:E]/005KK001Ff`00E]/005KK0002E]/00`00E]]Ff`03000NOol0
0`00Oomoo`0=Ool40004Ool2000:Ool20004Ool2001dOol0069oo`H00?mooomookmoo`@000063000
0000908002`30P00010d1000>0@003PT000l9000?4@004150014I@00A6D00098Q@05001<Y@00E<H0
0002F@H200001F5W001YQfV70000177X00@007HXMRP0009jB@04001jIP00MV@4001`Ool600001UKK
001Ff`00E]/0009Ff`05001Ff`00E]/00002E]/01@00E]/005KK00000UKK0`007Woo00<007ooOol0
3Woo20002goo2000M7oo001OOol3003oOoooOoo5Ool300000``00000000200002B`3000`0`00=0@0
03P4000h900200001Sa40010A@00A6D00094I@030018Q@00009<Y@05001DaP00F@H00002GBH01P00
JHMYQ`00KJL0009aj003001ai`00009f:0<0009jIP03001fI000008006Uoo`L0000:E]/005KK001F
f`00E]/005KK0002E]/03000E]]Ff`00E]/005KK001Ff`00E]/0009Ff`03001Ff`00008001moo`03
001oogoo00moo`D000ioo`@007Ioo`00Ggoo00<007ooOol0ogooogooaGoo1P0000DT0P00;0<00303
00800003>0@003PT0100009DaP03001I1P00009M9P04001YQfV70002KJL01@00LNP0077W00000WHX
00L007Y6NTH007YV001fI003001UOol400001UKK001Ff`00E]/0009Ff`05001Ff`00E]/00002E]/0
1@00E]/005KK00000UKK00T005KK001Ff`00E]/005KK00000UKK00<005KK00000P007goo00<007oo
Ool0W7oo000ROol4000>Ool3000:Ool<000BOol2003oOoooOoo5Ool400001100000000000R`32000
00Xl9000?2@004140010A000A6D00098I@030018Q@000080009I1P07001M9P00HDH006V700000ffW
00@0077WLNL0009f:007001jAWY6001jIP00MV@00`00GWoo1`0000IFf`00E]/005KK0002E]/00`00
E]/00002E]/02@00E]/005KK001Ff`00E]/00002E]/02`00E]/005KK001Ff`00E]/005KK00000UKK
00H005KKE]/005KK000NOol00`00Oomoo`2LOol0021oo`P000]oo`D000Uoo``0019oo`80009oo`@0
0?mooomookmoo`<0000640000000908002`30`0000Dd0`00>0@003PT00800008?2@004140010A000
A6D00098I@050018QDR5001<Y@030002GBH01000HDIQAP0016fW00@0077WLNMai`800007MRH007Y6
001jIP00MV@00`00F7oo1P0000AFf`00E]/0009Ff`05001Ff`00E]/00002E]/01@00E]/005KK0000
0UKK00T005KK001Ff`00E]/005KK00000UKK00D005KK001Ff`00009Ff`06001Ff`00E]/005KK1P00
7goo00<007ooOol0Vgoo000POol20004Ool2000;Ool5000:Ool30006Ool2000BOol4003oOoooOoo3
Ool300000a000000000400004C03000003P4000h9000?2@003`T0010A000@4@004AU00000TQU00<0
04R500000TbU00H00535000005dV0002HDH20002KJL00`00KJD00002LNL01000MRIf9P000WY600@0
07YV001fI0<0051oo`L00006E]/005KK001Ff`000UKK00D005KK001Ff`00009Ff`07001Ff`00E]/0
05KK00000UKK00/005KK001Ff`00E]/005KK001Ff`00009Ff`05001FfeKK001Ff`0800001UKK001F
f`00E]/001moo`03001oogoo09]oo`007goo0P001Woo0P002Woo1@002goo0`006Goo00<007oo0000
ogooogoo`goo0`0000D@0000000X0P00008/0`80000B=0<003P4000h9000?2@003`T0010A000@4@0
04AU0018I@000TR500<004bU00000U3500<005CU00000V5600T006EUIFD006fW001]Y@00LNL00P00
0gHV00H007Y6001jIP00MV@3001:Ool6000015KK001Ff`000UKK00L005KK001Ff`00E]/00002E]/0
0`00E]/00002E]/01`00E]/005KK001Ff`00009Ff`07001Ff`00E]/005KK00000UKK00H005KK001F
f`00E]/600001UKK001Ff`00E]/0009Ff`05001Ff`00E]/0000OOol00`00Oomoo`2KOol001moo`80
00Ioo`8000]oo`<000eoo`<001Moo`05001oogooOol0003oOoooOoo2Ool300001100000000000R`3
00@003030000008h100<000h9000000l9000@4@004140014I@000TQU00P004R5B8D004bU001@a@00
0UCU0P0000=QAP00IFD00VEU00D006fUKJE]Y@00009ai@09001f9WHV001jAP00NVH007IT00<004=o
o`L00006E]`005KL001Fg0000UKK00D005KK001Ff`00009Ff`07001Ff`00E]/005KK00000UKK00T0
05KK001Ff`00E]/005KK00000UKK00<005KK00000UKK00<005KK00001`0000QFf`00E]/005KK001F
f`000UKK00<005KK00000UKK0`0000=Ff`00Ool07Goo00<007ooOol0Vgoo000;Ool=0006Ool20008
Ool2000KOol3000FOol00`00Oomoo`02Ool00`00Oomoo`3oOoooOonnOol6000012P2000/0b`30P00
00Dd0`00>0@003PT0100009<Y@05001@a@00E>D00002F>@01000IFEUIFEU0P000ffU00@0077ULND0
009f9P03001jAWY600800004MV@00000000mOol600003EKl001Fo5Kl001Fg000E]`005KL001Fg000
009Ff`03001Ff`00009Ff`07001Ff`00E]/005KK00000UKK00L005KK001Ff`00E]/00002E]/01P00
E]/005KK001Ff`H00006E]/005KK001Ff`000UKK00D005KK001Ff`00009Ff`05001Ff`00E]/00002
E]/300000eKK001oo`0NOol00`00Oomoo`2JOol000]oo`d000Ioo`8000Qoo`8001aoo`<001Eoo`03
001oogoo009oo`03001oogoo0?mooomookioo`<0000:60000000:08002`3000`0`00=0<5000033`T
000l9000?2@004140010A000@4@00094I0@00004D<D005CU0002F>@200002fEU001YI6UT001]Y@00
KJ@0077U00000WHV1`0000=b@@000000=Goo1`0000IFo000E_`005Kl0002E_`01@00E_`005KL0000
0UKL00L005KL001Fg000E]/00002E]/02@00E]/005KK001Ff`00E]/00002E]/00`00E]/00002E]/0
0`00E]/00007000025KK001Ff`00E]/005KK0002E]/00`00E]/00002E]/02`00E]/005KK001Ff`00
E]/005KK00000UKK00D005KK001Ff`0001moo`03001oogoo09Yoo`002goo3@001Woo0P0027oo0P00
7Goo0`0057oo00<007ooOol00goo00<007ooOol0ogooogoo_7oo1@0000<P0@0000000R`31@0000Dh
1000>2@003`T00800008?2@004140010A000@4@000=4I0040018I000B8@2000015CU001Hi0000Ud3
00<006UTJF@00VUT00@006fTKJ@0009ai@800005MP@007HT001f@`0200000g910000000_Ool60000
2eKl001Fo5Kl001Fo000E_`005Kl00000UKl00<005Kl00000UKl00T005KL001Fg000E]`005KL0000
0UKK00L005KK001Ff`00E]/00002E]/01P00E]/005KK001Ff`H00004E]/005KK0002E]/01`00E]/0
05KK001Ff`00009Ff`05001Ff`00E]/00002E]/01`00E]/005KK001Ff`00009Ff`09001Ff`00E]/0
05KK001Ff`0001moo`03001oogoo09Yoo`007Woo0P0027oo0P007Woo0`004goo00<007ooOol00goo
00<007ooOol0ogooogoo_7oo0`0000<H00000000100001@d0`00=0<003P4000h9000?2@003`T000l
9000@4@004140010A0000TAT00<004QT00000TR400H004b3000005ST0002G@<20003JF@01@00KJA]
Y000LND00P000WH400H007HT001f@`00MV@3000YOol600001UKl001Fo000E_`0009Fo005001Fo000
E_`00002E_`01`00E_`005Kl001Fo000009Fo009001Fg000E]`005KL001Fg000009Ff`03001Ff`00
009Ff`03001Ff`0000L00008E]/005KK001Ff`00E]/0009Ff`03001Ff`00009Ff`09001Ff`00E]/0
05KK001Ff`00009Ff`09001Ff`00E]/005KK001Ff`00009Ff`03001Ff`00009Ff`<00003E]/007oo
01eoo`03001oogoo09Yoo`007Woo0P0027oo0P007goo0`004Woo00<007ooOol017oo00<007ooOol0
ogooogoo^Woo100000HH0000000/0P00<0<200005c@3000h13P4000h9000?2@003`T000l9000@4@0
04140010A000A6@004QT00000TR400H004b3C8<005220002G@<02000G@9M0P00JF@006UR0002KJ@0
1000LL=a``000WH400<007HT00001@0097oo1@0000YFo000E_`005Kl001Fo000E_`0009Fo003001F
o000009Fo007001Fo000E_`005Kl00000UKl00T005Kl001Fo000E]`005KL00000UKL00H005KL001F
f`00E]/6000015KK001Ff`000UKK00L005KK001Ff`00E]/00002E]/00`00E]/00002E]/02@00E]/0
05KK001Ff`00E]/00002E]/01`00E]/005KK001Ff`00009Ff`08001Ff`00E]/005KK001Ff`H001mo
o`03001oogoo09Uoo`007Woo0P0027oo0P0087oo0P004Woo00<007ooOol017oo00<007ooOol0ogoo
ogoo^Woo0P0000@80000000X0@80000:<0<003@3000d0`00>0@003PT0002?2@2000023`T0010A000
@4@004140002A6@00`00B6@00002B8@00`00C8<00002D882000015d3001M0Ud20P000VUR00@006fT
0000009a``07001f17H4001f9000MT<00P0000=b@@00Ool07Goo1P0000AFo000E_`0009Fo005001F
o000E_`00002E_`01`00E_`005Kl001Fo000009Fo007001Fo000E_`005Kl00000UKl00<005Kl0000
0UKl00@005KL001Fg0P00006E]/005KK001Ff`000UKK00D005KK001Ff`00009Ff`09001Ff`00E]/0
05KK001Ff`00009Ff`09001Ff`00E]/005KK001Ff`00009Ff`03001Ff`00009Ff`03001Ff`0000T0
0006E]/00000001Ff`007goo00<007ooOol0VGoo000NOol20008Ool2000QOol2000AOol00`00Oomo
o`05Ool00`00Oomoo`3oOoooOonhOol700003B`2000`0`00=0<003@3000h1000>2@003`T01400006
B8@004b3001@PP000U210P0000IM0P00G>1Lh000JF820002KH802@00LL=a``00MP@007HT001f@`02
00000g910000000FOol700001UKl001Fo000E_`0009Fo003001Fo000009Fo009001Fo000E_`005Kl
001Fo000009Fo009001Fo000E_`005Kl001Fo000009Fo006001Fo000E_`005Kl1P0000AFg000E]`0
009Fg007001Ff`00E]/005KK00000UKK00<005KK00000UKK00T005KK001Ff`00E]/005KK00000UKK
00L005KK001Ff`00E]/00002E]/01P00E]/005KK001Ff`H00004E]/005KK0002E]/01000E]/005KK
0`0000=Ff`00Ool07Woo00<007ooOol0VGoo000NOol20008Ool2000QOol2000AOol00`00Oomoo`05
Ool00`00Oomoo`3oOoooOongOol600001BP1000/0P00<0<00P0000<d0`0000001P0000hl9000?2@0
03`T000l9000?2@003`S00108`000T0R100000I@PP00D85@P@00D8020003G>000`00ID000002KH80
1000LL=a``000WH40P0000=f@`00LR800`0047oo1P0000AG7@00E_`0009Fo005001Fo000E_`00002
E_`01@00E_`005Kl00000UKl00T005Kl001Fo000E_`005Kl00000UKl00<005Kl00000UKl00@005Kl
001Fo0P00006E]`005KL001Fg0000UKL00D005KL001Fg000009Ff`09001Ff`00E]/005KK001Ff`00
009Ff`09001Ff`00E]/005KK001Ff`00009Ff`07001FfeKK001Ff`00E]/0200000QFf`00E]/005KK
001Ff`000UKK00D005KK001Ff`00009Ff`05001Ff`00E]/0000OOol00`00Oomoo`2HOol001moo`80
00Ioo`8001Uoo`8000Moo`80015oo`03001oogoo00Ioo`03001oogoo0?mooomookIoo`<000045000
0000:04200000c0300000003000013P4000h10000S`T0P0000`l9000?2@003`T000l9000?2<0040S
0003@2801000@28004000P0000Q@P@00D81@P000D60005cP0P000VE000<006f200002@0000Ab8P00
000000Uoo`L00006Ead005LM001G7@000ULM00<005Kl00000UKl00L005Kl001Fo000E_`00002E_`0
2@00E_`005Kl001Fo000E_`00002E_`02000E_`005Kl001Fo000E_`600002eKl001Fg5KL001Fg000
E]`005KL00000UKL00D005KL001Fg000009Fg007001Ff`00E]/005KK00000UKK00T005KK001Ff`00
E]/005KK00000UKK00H005KK001Ff`00E]/6000015KK001Ff`000UKK00L005KK001Ff`00E]/00002
E]/00`00E]/00002E]/02@00E]/005KK001Ff`00E]/0000OOol00`00Oomoo`2HOol001moo`8000Io
o`8001Uoo`<000Ioo`80015oo`03001oogoo00Ioo`03001oogoo0?mooomookEoo`D0000380000000
00@00003=0<003P30080000C>0@003`T?2@003`T000l9000?2@003`T000l9000?2<0040S00000T0R
00<0040R00000T0000H00400000005200002D6020002G<001P00ID000000JF00009]X@04001ah@00
LP420000178R000000000goo1P0000MG7@00EaeG7@00Ead00002Ead02@00Ead005LM001G7@00E_`0
0002E_`01`00E_`005Kl001Fo000009Fo003001Fo000009Fo004001Fo000E_`:00001UKl001Fo000
E_`0009Fo005001Fg000E]`00002E]`01`00E]`005KL001Fg000009Fg009001Fg000E]/005KK001F
f`00009Ff`03001Ff`00009Ff`04001Ff`00E]/800001UKK001Ff`00E]/0009Ff`05001Ff`00E]/0
0002E]/02@00E]/005KK001Ff`00E]/00002E]/02@00E]/005KK001Ff`00E]/0000OOol00`00Oomo
o`2HOol0021oo`8000Aoo`8001Yoo`@000Aoo`80015oo`03001oogoo00<000Eoo`03001oogoo0?mo
oomookAoo`<000035000000000800003<08003@300800006>0<003P4000h10000S`T014003`T000l
9000?2@003`T000l9000?2<0040S00108P0000908P030010000000900006000l0000001@H0000T`P
00H005c0000006400002JF001@00KJ5]X@00LN402P0000IC?P00Ech005Ln0002Ead03000EaeG7@00
Ead005LM001G7@00Ead0009G7@09001Fo000E_`005Kl001Fo000009Fo006001Fo000E_`005Kl1P00
00AFo000E_`0009Fo007001Fo000E_`005Kl00000UKl00<005Kl00000UKL00L005KL001Fg000E]`0
0002E]`02`00E]`005KL001Fg000E]/005KK00000UKK00H005KK001Ff`00E]/6000015KK001Ff`00
0UKK00L005KK001Ff`00E]/00002E]/00`00E]/00002E]/02@00E]/005KK001Ff`00E]/00002E]/0
2@00E]/005KK001Ff`00E]/00002E]/00`00Oomoo`0LOol00`00Oomoo`2HOol0021oo`P001]oo`P0
019oo`<000Qoo`03001oogoo0?mooomook=oo`@0000450000000<04200005C@3000d0`00>0<003P4
000h1000?2@003`T000l9000?2@003`T000l900600002d0R00108T0R00100000@00003`000000SP0
0`0000=<800000000UR000<0064000000VUP200000ICG`00Deh005<n0002Dch01`00Ech005Ln001G
7@00009G7@07001G7@00Ead005LM00000ULM00D005LM001Fo000009Fo004001Fo000E_`800001UKl
001Fo000E_`0009Fo007001Fo000E_`005Kl00000UKl00L005Kl001Fo000E_`00002E]`01`00E]`0
05KL001Fg000009Fg005001Fg000E]`00002E]`01000E]/005KK200000IFf`00E]/005KK0002E]/0
1@00E]/005KK00000UKK00T005KK001Ff`00E]/005KK00000UKK00T005KK001Ff`00E]/005KK0000
0UKK00<005KK00000UKK0`0000AFf`00000001moo`03001oogoo09Moo`008Woo10007goo1@004goo
00<007ooOol02Goo00<007ooOol0ogooRWoo0P00ogoo9Woo0P0000@80000000X00800007<08003@3
000d0`00>0<00P0000@h1000?2@l90/00005>0<003@2000d0@0;000013P0000d03@00`0000=40000
F8001P0000I;O`00Cgl004mO0003Del01`00Deh005<n001C?P00009G?P09001G?P00Ead005LM001G
7@00009G7@08001G7@00Ead005LM001Fo0P0000;E_`005KlE_`005Kl001Fo000E_`00002E_`01@00
E_`005Kl00000UKl00L005Kl001Fo000E_`00002E_`02@00E_`005KL001Fg000E]`00002E]`01P00
E]`005KL001Fg0P0000=E]/005KKE]/005KK001Ff`00E]/005KK00000UKK00<005KK00000UKK00L0
05KK001Ff`00E]/00002E]/02@00E]/005KK001Ff`00E]/00002E]/01@00E]/005KK00000UKK1`00
00=Ff`00Ool07Woo00<007ooOol0Ugoo001MOol00`00Oomoo`0:Ool00`00Oomoo`3oOon3Ool60000
0fX>001oo`3oOolTOol4000022@000000301000`0P00=0<200000cP30000000600002CPT000h1000
>0<003P3000h0`0200001C@2000d0C@100000S0000H00300000X0000900=00001CMn000004Mo0000
0T]o00D004mo001?G`00009CG`07001CGP00Dch005<n00000ULn00D005Ln001G7@00009G7@`00008
E_d005Kl001Fo000E_`0009Fo003001Fo000009Fo007001Fo000E_`005Kl00000UKl00/005Kl001F
o000E_`005Kl001Fo000009Fo003001Fo000009Fg004001Fg000E]`8000025KL001Fg000E]`005KK
0002E]/01@00E]/005KK00000UKK00T005KK001Ff`00E]/005KK00000UKK00L005KK001Ff`00E]/0
0002E]/00`00E]/00002E]/01000E]/005KK2P0000IFf`00000005KK0002E]/00`00Oomoo`0LOol0
0`00Oomoo`2GOol005eoo`03001oogoo00Yoo`03001oogoo0?moogeoo`H00007C>P005DZ001QS000
JPh00P00ogoo8goo0`0000@L00000000008`0@800003=0<0000000<0000F>0@003PT000h9000>2@0
03P4000h0`00>0<003P3000h0`00=08003@10002<0001P00<00002P0000T00H00003FWP005Ih00T0
000>Agl004]oBgl004mo001?G`00Del005=N001C?Pd00006Dad005;m001Bo@000U;m00D005;m001F
o@00009Fo007001Fo000E_`005Kl00000UKl00L005Kl001Fo000E_`00002E_`02@00E_`005Kl001F
o000E_`00002E_`02000E_`005Kl001Fo000E]`600003EKL001Fg5KL001Fg000E]`005KL001Fg000
009Ff`03001Ff`00009Ff`09001Ff`00E]/005KK001Ff`00009Ff`09001Ff`00E]/005KK001Ff`00
009Ff`06001Ff`00E]/005KK1P0000AFf`00E]/0009Ff`04001Ff`00E]/300001EKK001FfeKK0000
7Woo00<007ooOol0Ugoo001MOol00`00Oomoo`0;Ool00`00Oomoo`3oOomfOol600001D1V0014QP00
B:L00P0000EE:P00HH`006X>00<00?moob9oo`<0000670000000:00003011@0000Dh0`00>0<003P4
0080000F>2@003PT>2@003P4000h0`00>0<003P3000h0`00=08003@1000`0000<00500003EZH001J
N000FWP005Yh001FN000EWP005Ih00<000035[d0000000d00004Bah004lN0002Cah01`00Cah005<N
001C7@00009C7@05001Bo@00D_d00002D_d02`00D_d005Km001Fo000E_`005Kl00000UKl00T005Kl
001Fo000E_`005Kl00000UKl00D005Kl001Fo000009Fo003001Fo00000T00006E]`005KL001Fg000
0UKL00D005KL001Fg000009Fg009001Fg000E]`005KK001Ff`00009Ff`09001Ff`00E]/005KK001F
f`00009Ff`03001Ff`00009Ff`04001Ff`00E]/800001UKK001Ff`00E]/0009Ff`07001Ff`00E]/0
05KK00000UKK00L005KK001Ff`00E]/0000OOol00`00Oomoo`2FOol005eoo`03001oogoo00]oo`03
001oogoo0?moog1oo`H00005?4D003a50010A@0200002dB60018Y`00C>P005DZ001QS000JPh00`00
ogoo8Goo0`0000<L000090001@0000<h0`00>0<00P0000`h0`00>0@003PT000h9000>2@003P40002
>0<01000>0<003P30P0000<d0P0000001P0000YNU`00GYP005ZH001JN000FWP0009JN008001FN000
EWP005Ih001BF0H0000:=al003lO00137`00Aal004/O0002Bah00`00Cah00002Cah03@00Cah005<N
001C7@00Dad005;m001Bo@00009Bo@07001Bo@00E_d005Kl00000UKl00L005Kl001Fo000E_`00002
E_`02000E_`005Kl001Fo000E_`8000015KL001Fg0000UKL00L005KL001Fg000E]`00002E]`00`00
E]`00002E]`02@00E]`005KL001Fg000E]`00002E]/02`00E]/005KK001Ff`00E]/005KK00000UKK
00H005KK001Ff`00E]/600003EKK001FfeKK001Ff`00E]/005KK001Ff`00009Ff`03001Ff`00009F
f`09001Ff`00E]/005KK001Ff`00009Ff`03001oogoo01aoo`03001oogoo09Ioo`00GGoo00<007oo
Ool037oo00<007ooOol0ogooJGoo1P0000Dl9@00?2D003`U00800009?4D004150010IP00A8H004RW
00800006EBX0066<HH`006X>0P0000=nb`00Ool0ogoo7Woo00D000@0000001`000800004=04003@2
=08200004cP3000h0`00>0<003P4000h9000>2@003PT000h1000>0<003P300L00004I[L006:G0002
HYL01`00GYL005jH001JV000009JN003001JN0000100000:=al003lO00137`00Aal004/O0002Bah0
2`00Cah004lN001?7P00Dah005<M00000U<M00/005;m001Bo@00D_d005;m001Fo@00009Fo007001F
o000E_`005Kl00000UKl2P0000QFo000E_`005Kl001Fg0000UKL00L005KL001Fg000E]`00002E]`0
1`00E]`005KL001Fg000009Fg009001Fg000E]`005KL001Fg000009Ff`03001Ff`00009Ff`06001F
f`00E]/005KK200000IFf`00E]/005KK0002E]/01@00E]/005KK00000UKK00T005KK001Ff`00E]/0
05KK00000UKK00@005KK001Ff`<00005E]/005KKE]/0000NOol00`00Oomoo`2FOol005eoo`03001o
ogoo00aoo`03001oogoo0?moof=oo`H00005>2D003PU000h9@0200001C`U000l9@00?4D00P0000i0
A@00@6H004B60018Y`00C>P005DZ001QS0000VX>0P0000=nb`00Ool0ogoo7Goo1P0000<`00000000
0S@200X003P3000h0`00>0<003P3000h10800004>2@003PT>2@70002K]D01P00J]IZeP00I[L0009R
U`07001RU`00GYL005jH00000UZH1@0000eJN000EWP005Ih001FN000DUP0059H001>>00200000aIn
0000000400004DLO001;7d/O001;7P00Cah004lN001?7P00Dah005<M00000U<M00D005;m001Bo@00
009Bo@04001Bo@00E_d<00001UKl001Fo000E_`0009Fo007001Fo000E_`005Kl00000UKL00D005KL
001Fg000009Fg007001Fg000E]`005KL00000UKL00/005KL001Fg000E]`005KL001Fg000009Fg006
001Ff`00E]/005KK200000eFf`00E]]Ff`00E]/005KK001Ff`00E]/00002E]/03000E]]Ff`00E]/0
05KK001Ff`00E]/0009Ff`08001Ff`00E]/005KK001Ff`<0009Ff`03001Ff`0001moo`03001oogoo
09Eoo`00GGoo00<007ooOol03Goo00<007ooOol0ogooG7oo1P0000D`1P00=0D003@500800005>2D0
03PU000l9@0200001c`U000lA@00?4D0041500800004A8H004RW0002C>P02`00EBX0066<001Z3P00
MVl007k;0000ogoo7Goo0`0000<X0000;0000P0000dd0@00=08003P3000h0`00>0<003P3000h1007
0002Oc020003Na830002J]H00`00I[L00002HYL01@00HYL005jG00000UjH0`00015JV000FWP005Yh
001FN000EWP005Ih001BF000DUP004hh00<000065Wh00000;]l003KO7`0000]Bo@00D_aBo000D_`0
05;l001Fo000009Fo007001Fo000E_`005Kl00000UKl00T005Kl001Fo000E]`005KL00000UKL00T0
05KL001Fg000E]`005KL00000UKL00<005KL00000UKL00H005KL001Fg000E]`8000025KK001Ff`00
E]/005KK0002E]/01@00E]/005KK00000UKK00L005KK001Ff`00E]/00002E]/02@00E]/005KK001F
f`00E]/00002E]/01@00E]/005KK00000UKK00@005KK001Ff`H001ioo`03001oogoo09Eoo`00G7oo
00<007ooOol03Woo00<007ooOol0ogooFgoo00H00005000H1P00:0H200001C@5000d1@00>2D00P00
00Lh9@00?2D003`U000l9@0200003Sa50010A@00@6H004B60018Y`00C>P005DZ0002HH`01@00JPh0
07I_00000Wk;00<007ooOol0ogoo6Goo0P0000hT0000000/0000<00003@1000d0P00>0<003P32000
0gl`0P000Wl`00<007lB00000W/B0P0000Abm@00J]H0009V]`05001RU`00HYL00002GYL3000045jH
001JV000FWP005Yh001FN000EWP005Ih001BF0000U9H0P0000=:600000000`0000D^g`00000jo`00
008no`0=0012o`00A_h004[n001:oP00C_h004km00000Tkm00/004km001Bo@00D_d005;m001Bo@00
009Bo@07001Bo000D_`005;l00000UKl00L005Kl001Fo000E_`00002E_`01`00E_`005Kl001Fo000
009Fg00;001Fg000E]`005KL001Fg000E]`00002E]`01P00E]`005KL001Fg0P0000=E]`005KKE]/0
05KK001Ff`00E]/005KK00000UKK00<005KK00000UKK00T005KK001Ff`00E]/005KK00000UKK00T0
05KK001Ff`00E]/005KK00000UKK00D005KK001Ff`00009Ff`L00005E]/005KKE]/0000NOol00`00
Oomoo`2EOol005aoo`03001oogoo00moo`03001oogoo0?mooeYoo`80000760H002P6000`1P00=0D0
0P0000Dh9@00>2D003PU00800005?2D003`U000lA@0;00001TcX001E:P00HH`0009Z3P03001fK`00
009nb`03001oogoo0?mooaMoo`<00007900002P0000/0000<0002P000Wm@00@007m@Oe0000=o<080
009o<003001o4P00009k4P800004L_D006[F0002I[L00`00HYL00002HYL3000025jH001NV000FYP0
05Yh0002FWP03000EWP005Ih001FN000DUP0059H001>>0D000073Sd00000=]l003[o00000Sko00d0
04;o0016oP00B_h004[n001>oP00C_d00002C_d03@00C_d005;m001Bo@00D_d005;m001Bo@00009B
o007001Bo000D_`005Kl00000UKl00d005Kl001Fo000E_`005Kl001Fo000E_`00002E]`01@00E]`0
05KL00000UKL00@005KL001Fg0P00008E]`005KL001Fg000E]`0009Fg005001Ff`00E]/00002E]/0
2@00E]/005KK001Ff`00E]/00002E]/02@00E]/005KK001Ff`00E]/00002E]/00`00E]/00002E]/0
1000E]/005KK2P0000IFf`00E]/005KK0002E]/00`00E]/0000NOol00`00Oomoo`2EOol005aoo`03
001oogoo00moo`03001oogoo0?mooeYoo`80000360H002P600800003=0D003@500800005>2D003PU
000l9@0600002d150014IP00A8H004RW001@j000EBT00`000V6<00H006X>JPh007I_0002O//2003o
OolFOol4000290000`00:000000500001GnB001oLGma00000Wma00@007m@Oe00009oD0800009Oc00
07laOc4007l`001o4P00009k4P04001bmG;e0002J]H01@00I[L006:G00000V:G00L006:G001NV000
GYP00002FYP04P00FWP005Yh001FN000EWP005Ih001BF000DUP004hh001:60D0000D7Uh00000000j
o`00?_l004;o0016oP00B_h004[n001>oP00C_d0009>o@0;001>o@00D_d005;m001Bo@00D_d00002
D_d02@00D_`005;l001Bo000E_`00002E_`01`00E_`005Kl001Fo000009Fo00:001Fo000E_`005KL
001Fg000E]`800003EKL001Fg5KL001Fg000E]`005KL001Fg000009Fg003001Fg000009Ff`09001F
f`00E]/005KK001Ff`00009Ff`0;001Ff`00E]/005KK001Ff`00E]/00002E]/00`00E]/00002E]/7
00003eKK001FfeKK001Ff`00E]/005KK001Ff`00E]/00002E]/01000E]]Ff`007Woo00<007ooOol0
U7oo001LOol00`00Oomoo`0@Ool00`00Oomoo`3oOomHOol01`0000D00000:0H0030600800003=0D0
03PU00H00005?2@003`U000lA@02000024AV0014QP00B:L0053X0002EBT01P00GFX00000HH`0009Z
3P03001fK`00009nb`800?mooaAoo`8000033000000000D0009ke003001o/`00009oTP03001oL@00
00=oL@<0009oD005001o<@00Oc000002Oc401@00Oc0007lB00000W/B00@007;eL_D0009ZeP03001V
]`00009RU`<00004HYL005jH0002GYP05P00FYP005Yh001JN000EWP005Ih001FN000DUP0059H001>
>000BQP0047h0P0000<>?@0000000RJN100000Q2o`00A_h004[n001:oP000Tkn00/004km001>o@00
C_d005;m001Bo@00009Bo@0;001Bo@00D_d005;l001Bo000D_`00002E_`01`00E_`005Kl001Fo000
009Fo0`00008E]`005KL001Fg000E]`0009Fg005001Fg000E]`00002E]`02@00E]`005KL001Fg000
E]`00002E]/02@00E]/005KK001Ff`00E]/00002E]/00`00E]/00002E]/01P00E]/005KK001Ff`P0
0006E]/005KK001Ff`000UKK00L005KK001Ff`00E]/00002E]/3000015KK001Ff`000UKK00<007oo
Ool077oo00<007ooOol0U7oo001LOol6000=Ool00`00Oomoo`3oOomHOol200000aP6000X1P020000
0c@50000000200001C@4000h1000>2@00P00018l9@00?4D004150014IP00A8H004RW001@j000EBT0
05eZ0002IL`01000JPiZ3P000gI_00D007k;001nbP000?mooa1ooa@0009oL@05001oLGma001oD@02
0002Oe000`00Oc5o<@020002Oc420002Oa801000Na9k4P000W;e00H006[FJ]H006Jg0002HYL01@00
H[L006:G00000UjH014005jH001JV000FWP005Yh001FN000EWP005Ih001BF000009BF0800003BQP0
047h00H000059Yh002jN000f_P0700001T[n001>oP00C_d0009>o@0=001>o@00D_d005;m001Bo@00
D_d005;m00000U;l00@005;l001Bo0`00006E]`005KL001Fg0000UKL00T005KL001Fg000E]`005KL
00000UKL00<005KL00000UKL00T005KL001Fg000E]`005KL00000UKL00/005KL001Ff`00E]/005KK
001Ff`00009Ff`06001Ff`00E]/005KK200000eFf`00E]]Ff`00E]/005KK001Ff`00E]/00002E]/0
2@00E]]Ff`00E]/005KK001Ff`0300001eKK001FfeKK001Ff`0001Yoo`D009Ioo`00G7oo00<007oo
Ool04Goo00<007ooOol0ogooEgoo0P0000@H1P00000`1P800003;0@0030400800009>0@003PT000l
9000?2D003a500800008A6H004B60018Y`00D>P0009E:@03001MJP00009Uc004001Z3VX>0003MVl0
1@00O//007k:0000ogoo2Woo200000A;f`00HoX000=_n003001gmP00009ke@03001o]000009oT`04
001oLGma0002Og401000Oe5oD@000Wm@00<007laOc400P000gla00P007lBOa8007/B001k50000W;e
00<006[F00000VJg0`0001MR]`00HYMRU`00GYP005jH001JV000FWP005Yh001FN000EWP005Ih001B
F000009BF007001>>0000011n000>MP00P0000H1^`00000VWP00;Yh200001CZn000ngP00@]h07@00
00eBg000D]aBg000D]`005;L001Fg000E]`00002E]`01`00E]`005KL001Fg000009Fg007001Fg000
E]`005KL00000UKL00/005KL001Fg000E]`005KL001Fg000009Fg003001Fg000009Ff`06001Ff`00
E]/005KK200000QFf`00E]/005KK001Ff`000UKK00D005KK001Ff`00009Ff`07001Ff`00E]/005KK
00000UKK00H005KK001Ff`00E]/300001eKK001FfeKK001Ff`0001moo`03001oogoo09=oo`00G7oo
00<007ooOol04Woo00<007ooOol0ogooEWoo0`0000@X1P00000X0`800007<0@003@4000h1000>2@0
0P00010l9@00?4D004150014IP00A8H004RW001@j000EBT0009MJP07001Uc000KPd006X>00000gI_
00D007k;001nbP000?moo`=oo`P00003>gh0000000800003Dmd0000000@00004KoP007Of0002NmD0
0`00Ok@00003Oi<30003Og401000Oe5oD@000Wm@00<007laOc400P000gla00P007lBOa8007/B001k
50000W;e00<006[F00000VJg00<006Jg00000V:g01D006:G001NV000GYP005ZH001JN000FWP005Ih
001FN000EWP0059H00000U9H00@004hh001:60800003>MP000000080000:3O`00000;Yh003Jn000j
_P00?]h200003dKN0016gTKN001:gP00B]d004kM001>g@00C]d00002C]d02`00D]d005;M001Bg@00
D]`005;L00000U;L00T005;L001Bg000D]`005KL00000UKL00D005KL001Fg000009Fg009001Fg000
E]`005KL001Fg000009Fg009001Fg000E]`005KL001Fg000009Fg008001Fg000E]`005KL001Ff`P0
000=E]/005KKE]/005KK001Ff`00E]/005KK00000UKK00<005KK00000UKK00T005KK001Ff`00E]/0
05KK00000UKK00P005KK001Ff`00E]/005KK0`000UKK00<005KK00000UKK00<007ooOol077oo00<0
07ooOol0Tgoo001LOol00`00Oomoo`0BOol00`00Oomoo`3oOomEOol2000011P6000001`30P0000</
1000<0@00P0001Ph1000>2@003`T000l9@00?4D004150014IP00A8H004RW001@j000EBT005eZ0002
IL`01@00KPd006X>00000gI_00<007k;00000Wk:00<007ooOol0nGoo1P000T]o00D004MoAgl004=o
00<000=GgP800003Io/007?i009cn@D00004NmD007nd0003Oi<00`00Oi800003Og400`00Oe5oD@02
00000gm@001o<@02Oc401@00Oc5o<Gla00000glB0P0000Ek5000L_Ebm@00009ZeP<0000AI[L006:g
H[L006:G001NV000GYP005ZH001JN000FWP00002EWP03P00EWP005Ih001BF000DUP004hh001:6000
@OP700001aXm000003Jn000j_P00008ngP80000?A]h004KNA]h004[N001:g@00C]d004kM001>g@00
009>g@0=001Bg@00D]d005;M001Bg000D]`005;L00000U;L00T005;L001Bg000E]`005KL00000UKL
00d005KL001Fg000E]`005KL001Fg000E]`00002E]`00`00E]`00002E]`01000E]`005KL2P0000QF
g000E]/005KK001Ff`000UKK00D005KK001Ff`00009Ff`09001Ff`00E]/005KK001Ff`00009Ff`09
001Ff`00E]/005KK001Ff`00009Ff`03001Ff`00009Ff`06001Ff`00E]/005KK20007Woo00<007oo
Ool0Tgoo001LOol00`00Oomoo`0COol00`00Oomoo`3oOomDOol3000010P1000002P30P0000T`1000
=0@003P4000h9000?2@03`0000IE:@00GFX006G<0002KPd20004MVl00`00O//00002O/X00`00Oomo
o`3cOol6000015=N001CG`000TmO00D004]oBgl004Mo00<0009KgP03001GgP00009Wo08000=cn@03
001gm`00009keP04001o]7nd0002Oi<00`00Oi9oTP020002Og401000Oe4007mA0P0017la00D007la
Oc5o<@0000=o4P04001k57/D0002L_D01P00J]IZeP00J]H0009V]`0;001R]`00HYL005jH001NV000
FYP00002FWP04P00FWP005Ih001FN000EWP0059H001BF000CSP004XH0011n0800004:GL000000CP3
00000b9N000000020002?]h04@00@]h004KN0016gP00B]h004[M001>g@00C]d004kM00000TkM00/0
05;M001Bg@00D]d005;L001Bg000009Bg00;001Bg000D]`005;L001Fg000E]`00002E]`01`00E]`0
05KL001Fg000009Fg008001Fg000E]`005KL001Fg0P00004E]`005KL0002E]`02@00E]`005KL001F
f`00E]/00002E]/00`00E]/00002E]/02@00E]/005KK001Ff`00E]/00002E]/02`00E]/005KK001F
f`00E]/005KK00000UKK00<005KK00000UKK2@0000MFf`00E]]Ff`00E]/0000NOol00`00Oomoo`2C
Ool005aoo`03001oogoo01=oo`03001oogoo0?mooeAoo`@0000870<00000;0@00304000d10H0000@
?2D004150010I@00A6H004RV001<a`00D>P005TY0002GFX00`00IL`00003KPd00`00MVmfK`02MVl0
1@00O/]nb`00O/X00P00kGoo1`0000IG?P00Dch005<n0002Deh00`00Del00002Cel01000Bgl00000
0e^n00@005_N000000=Wo007001cnP00LoT007Og00000g_F0`000gnC00D007nBOi8007mb0080009o
D@04001oD@000004Oc401P00Oc5o<@00Oc80009o4P04001k57/D0002L_D01P00J]IZeP00J]H0009V
]`07001R]`00HYL005jH00000UjH00H005ZH001JN000FWP=00001DXH0011n000>MP01P0000HJ?@00
000ZOP00<Yh500002TKN0016gP00B]h004[M001>g@000TkM00d004kM001>g@00D]d005;M001Bg@00
D]`00002D]`02`00D]`005;L001Bg000D]`005KL00000UKL00D005KL001Fg000009Fg003001Fg000
00T00008E]`005KL001Fg000E]`0009Fg007001Fg000E]`005KL00000UKL00T005KK001Ff`00E]/0
05KK00000UKK00T005KK001Ff`00E]/005KK00000UKK00<005KK00000UKK00H005KK001Ff`00E]/8
000025KK001Ff`00E]/005KK0002E]/01@00E]/005KK00007goo00<007ooOol0TWoo001LOol00`00
Oomoo`0DOol00`00Oomoo`3oOomCOol200001PP1000002P3000/10@00005=0@003P4000h90020000
34150010I@00A6H004RV001<a`00D>P0009I:@<0009Uc005001^3Fh=KPd00004MVl01@00O/]nb`00
O/X00P00jGoo100000IG7@00Ead005LM0003Ech01@00Dch005<n00000U=N00@005=O001?G`80009K
WP05001K_U^nFkh00002Im`00`00Io`00003LoX200001GOg001keW_F00000Wne0P000WnC00<007nB
00000gmb00@007mAOe40009oD@0;001o<GlaOc4007lb001o<@00Oc800002Oa801@00NaAk57/D0000
0W;e0`000V[F00L006Jg001R]`00HYL00002GYP01000GYP005ZH1@0000QFN000EWP0059H001BF000
0TiH100000=1n000>MP00P0000<DmP0000000`0000<RGP00:Wh00P000SJN00<003jn00001P0000Q:
g@00C]d004kM001>g@000TkM00d005;M001Bg@00D]d005;L001Bg000D]`00002D]`01P00D]`005;L
001Fg0`00006E]`005KL001Fg0000UKL00T005KL001Fg000E]`005KL00000UKL00<005KL00000UKL
00T005KL001Fg000E]/005KK00000UKK00/005KK001Ff`00E]/005KK001Ff`00009Ff`06001Ff`00
E]/005KK200000eFf`00E]]Ff`00E]/005KK001Ff`00E]/00002E]/00`00E]/00002E]/00`00E]/0
000NOol00`00Oomoo`2BOol005]oo`03001oogoo01Eoo`03001oogoo0?mooe9oo`@0000370<002P3
00800003;0<0030300800005>0@003PT000l9@0200001T1U0014IP00B:H0009<a`05001@j000FBT0
0002HHX00`00IL`00003KPd20004MVl02000O/]nb`00O/X007k9003ROol6000015LM001G7@000ULM
00D005LM001G7@00009G?P03001C?P00009C?P03001CGP0000<00003Fih005^N009KWP06001K_P00
Imd006OL100000AcnP00MmQgf080009keP05001o]Gne001oU0020002Oi801@00Og9oLWmb00000WmA
00@007mAOe4000=o<@07001o<P00Oc4007lb00000WlB00D007/DNaAk5000009bm@<0009ZeP05001V
]`00H[L00002HYL00`00GYP00004000035ZH001JN000EWP005Ih001BF000DUP0009>F003001:>000
00<00004>MP000005?H400000`gL00000002:Wh20002=Yh200001Cjn0012_P00A]d08@0000eBg000
D]aBg000D]`005KL001Fg000E]`00002E]`01@00E]`005KL00000UKL00/005KL001Fg000E]`005KL
001Fg000009Fg009001Fg000E]`005KK001Ff`00009Ff`03001Ff`00009Ff`06001Ff`00E]/005KK
200000QFf`00E]/005KK001Ff`000UKK00D005KK001Ff`00009Ff`03001Ff`0000800004E]/005KK
0002E]/00`00E]/0000NOol00`00Oomoo`2BOol005]oo`03001oogoo01Ioo`03001oogoo0?mooe5o
o`@0000470<00000:0<200000c03000d1002000043PT000l9@00@4D0041U0014IP00B:H004c7001@
j0000UTY00H0066:HHX006G<0003KPd20004MVl02000O/]nb`00O/X007k9003KOol700001UKl001F
o000E_`0009G7@05001G7@00Ead00002Ead01`00Ead005Ln001C?P00009C?P800004Fgh005]n0002
Fih00`00FiiKWP020003Imd00`00Lm]cf`02Lm/02`00MmQgf7OH001ke`00NmH007ne00000gnD00@0
07nBOi8000=oLP800004Oe4007mAOe420002Oc401@00Oc8007la00000Wlb00@007lB0000009k5004
001bmG;e0002K]H01`00J]H006Jg001R]`00009RU`<00008GYP005jH001JV000FWP0009FN00<001F
N000DUP0059H001>F000BSP004HH100000<YM`005?H01@0000dJ7@00000003:N000fWP00?[h003jn
0012_P02000014KM001:g@000T[M00d004[M001>g@00C]d004kM001>g@00D]`00002D]`02`00D]`0
05;L001Bg000D]`005;L00000U;L00T005;L001Bg000E]`005KL00000UKL00D005KL001Fg000009F
g009001Fg000E]`005KL001Fg000009Fg00;001Fg000E]`005KL001Fg000E]/00002E]/01P00E]/0
05KK001Ff`P0000=E]/005KKE]/005KK001Ff`00E]/005KK00000UKK00<005KK00000UKK00H005KK
001Ff`00E]/30002E]/01`00E]/005KK001Ff`0001ioo`03001oogoo099oo`00Fgoo00<007ooOol0
5Woo00<007ooOol0ogooDGoo0P0000@80@00000L0P800008;0<00000=0@003P4000h9080000<@4D0
041U0014IP00B:H004c7001@j0000UTY00H0066:HHX006W;0003KPd01000MVefK@000gI_00P007k;
O//007k:001nb@00eGoo1P0000AFo000E_`0009Fo003001Fo000009Fo007001Fo000Ead005LM0000
0ULM00H005LM001G7@00Ech5000025]N001KOU]n001KOP00Fih30002Ikd01@00Imd006oK00000g?K
0P0000=gf000NmL00W_G00@007neOkD000=oU0<000=oLP04001oLP000003Oe420002Oc401@00Oc80
07la00000Wlb00@007lB0000009k5004001bmG;e0002K]H01@00J]H006Jg00000V:g00T006:G001N
V000GYP005jH00000UZH018005Yh001FN000EWP0059H001BF000CUP004Xh00166000?OP200000bUg
000DmP0400000`gL000000028Sd200003SJN000n_P00?[h004:n0016g@00A]d004[M0002B]d01P00
B]d00000C]d0009>g@0=001>g@00D]`005;L001Bg000D]`005;L00000U;L00D005;L001Bg000009B
g009001Bg000E]`005KL001Fg000009Fg00=001Fg000E]`005KL001Fg000E]`005KL00000UKL00<0
05KL00000UKL00H005KL001Fg000E]/8000025KK001Ff`00E]/005KK0002E]/01@00E]/005KK0000
0UKK00T005KK001Ff`00E]/005KK00000UKK00H005KK001Ff`00E]/30002E]/01@00E]/005KK0000
0UKK00<007ooOol077oo00<007ooOol0TGoo001KOol00`00Oomoo`0GOol00`00Oomoo`3oOom@Ool3
000010`0000002P30P0000P`0`00000h1000>2@003`U2@0000I<a`00D>P005TY0003HHX00`00JL/0
0003KPd01000MVefK@000gI_00H007k;O//007k:0002O/T00`00Oomoo`3<Ool600001UKK001Fg000
E_`0009Fo003001Fo000009Fo007001Fo000E_`005Kl00000ULM00H005LM001G7@00Ead4000015/m
001KG@000e]N00@005]n001KOP80009W_@05001W_FNmIkd00003Km/00`00Lm/00002MmT00`00NmMk
e`02NmL200001Gne001oU7nD00000WnC00D007mbOg9oLP00009oLP0:001oDGmAOe4007mB001o<@00
Oc820003Oc8200001W/C001k57/D001bm@80009^eP05001ZeP00I[L00002H[L300004ejH001NV5jH
001NV000FYP005Yh001FN000EWP0059H001BF000009>F0800003AQP003gh00@000035?H0000000H0
00038Sd002YN00@00004?[h004:n0002A]d200004D[M001:gD[M001:g@00C]d004kM001>g@00C]d0
05;L00000U;L00/005;L001Bg000D]`005;L001Bg000009Bg00;001Bg000D]`005KL001Fg000E]`0
0002E]`01`00E]`005KL001Fg000009Fg00:001Fg000E]`005KL001Fg000E]`800003EKK001FfeKK
001Ff`00E]/005KK001Ff`00009Ff`03001Ff`00009Ff`09001Ff`00E]/005KK001Ff`00009Ff`0<
001Ff`00E]/005KK001Ff`00E]/005KK0P0000AFf`00E]/0009Ff`<001ioo`03001oogoo095oo`00
Fgoo00<007ooOol05goo00<007ooOol0ogooCgoo1@0000LL0P0000000303000d100600002D150010
I@00A8H004RV001<a`0400002ETY001QRV6:001Yb`00KP`00002KPd01000MVefK@000gI_0P0000An
b`00O/X0009nb@03001oogoo0<Eoo`L00006E]/005KK001Ff`000UKK00T005KL001Fo000E_`005Kl
00000UKl00<005Kl00000UKl00P005Kl001G7@00Ead005LM0P0000AK?@00Fcd0009K?@03001KG@00
009KGP06001KOP00001WW@000fNm00D006Nm001_^`0000=_f`04001gfGOIMmT20002NmL00`00OkIo
]P020002Oi@00`00Oi=oT`020002Og801000Og9oLP000WmA00<007mBOe800P000glb00@007lbOc9o
<P800003Na<007/D009k50800006L_D006kF001ZeP000VJg00D006:g001R]`00009NV00A001NV000
GYP005ZH001JN000EWP005Ih001BF000DUP00002CUP01`00BSP00000?OP003Fh008000065?H00000
0000U@000P6K0P0000HR?@00000bOP00=Yh3000044:n0016g@00A]d004[M001:g@00B]d004kM001>
g@000TkM00d004kM001Bg000D]`005;L001Bg000D]`00002D]`03@00D]`005;L001Bg000D]`005KL
001Fg000009Fg005001Fg000E]`00002E]`00`00E]`0000;000025KL001Fg000E]`005KL0002E]/0
1@00E]/005KK00000UKK00T005KK001Ff`00E]/005KK00000UKK00T005KK001Ff`00E]/005KK0000
0UKK00D005KK001Ff`00009Ff`04001Ff`00E]/:00000eKK001oo`0MOol00`00Oomoo`2AOol005]o
o`03001oogoo01Qoo`03001oogoo0?moodioo`<0000530000000000/0`0400001CP4000h9000?2@0
0P0000I0I@00A8H004RV0002C<L01@00E>P005TY00000V6:00P006W;JL/006h<001^3@000gI]00H0
07I_MVmfK`00O//20002O/X00`00O/T00031Ool600001UKK001Ff`00E]/0009Ff`0<001FfeKK001F
f`00E]/005KL001Fo0000UKl00L005Kl001Fo000E_`00002E_`01000E_`005LM100000MK7@00FceK
?@00Fcd00002Fcd01000Fed005]N0P0000ESO@00IieWW@0000=W_@0;001_^fnkKk/006oK001gfP00
MmT00002NkP00`00NmL00002OkH01`00OiD007nD001oT`00009oL`8000=oLP800004Oe4007mBOe82
0003Oc800`00Oc9o<P02Oc801000Na=k4`000W/D00P007;eL_D006kF001ZeP000VJg0`000V:g00/0
05jH001NV000GYP005ZH001JN000009FN00<001FN000DUP0059H001>F000BSP004HH0P0000@e^000
000DmP@0000309D0006K008000058Sd002YN000bOP0200000cZN0000000500001T[M001:gD[M001:
g@80000AC]d004kMC]d004kM001Bg000D]`005;L001Bg000D]`00002D]`01@00D]`005;L00000U;L
00H005;L001Fg000E]`<00001UKL001Fg000E]`0009Fg009001Fg000E]`005KL001Fg000009Fg003
001Ff`00009Ff`09001Ff`00E]/005KK001Ff`00009Ff`0;001Ff`00E]/005KK001Ff`00E]/00002
E]/01@00E]/005KK00000UKK2@000UKK00L005KK001Ff`00E]/0000OOol00`00Oomoo`2@Ool005]o
o`03001oo`00008001Ioo`03001oogoo0?moodioo`D00006:0<00000<0<003@30P00010h9000?2@0
04150010I@00A8H004RV001<a`00E>P0009I:@800009HHX006W;JL/006h<001^3@0000=fK@03001f
KgI_0080009nb`06001nbWk:001nb@00^goo1P0000IF^`00E]/005KK0002E]/01@00E]/005KK0000
0UKK00D005KK001Ff`00009Ff`09001Fg000E_`005Kl001Fo000009Fo004001Fo000E_`4000015/L
001K70000U/M00<005/m00000U/m00@005/m001KG@800005Hgd006=mHgd00002Iid01@00Ikd006nl
00000fnk00D007OJMmYgfP0000Ak^004001o]Wnf0003OiD01000Oi=oT`000gmc00@007mbOg80009o
DP8000=oDP05001o<WlbOc800004Oc801000Na=k4`000W/D00H007;eL_D006kF0002J]H01@00I[L0
06Jg00000V:g00L005jH001NV000GYP00002FYP04P00FWP005Ih001FN000DUP0059H001>F000BSP0
04HH000mn0D0000305<0000000<000090I/00000000ZGP00<Wh003JN00800006?[h004:m@[d004:m
2@0000Q>g@00C]d004kM001Bg0000U;L00X005;L001Bg000D]`005;L001Bg0`0000=D]`005KLE]`0
05KL001Fg000E]`005KL00000UKL00L005KL001Fg000E]`00002E]`02@00E]`005KL001Fg000E]/0
0002E]/02@00E]/005KK001Ff`00E]/00002E]/01@00E]/005KK00000UKK00@005KK001Ff`X00005
E]/005KK001Ff`02000025KK001Ff`00E]/005KK0002E]/00`00Oomoo`0LOol00`00Oomoo`2@Ool0
05]oo`8001Yoo`03001oogoo0?moodaoo`@0000470800000:08200004C@3000003PT000l9000@4D0
041U0014QP00B:H004c700000UCX00<005TY00000V5Y00@006W;JL/000=^3003001fKGI]00=fK@80
0005NXd007k;O//00002O/X00`00O/T0002dOol700001UJj001F^P00E[X0009F^`0;001Ff`00E]/0
05KK001Ff`00E]/00002E]/04@00E]]Ff`00E]/005KK001Fg000E_`005Kl001Fo000E_`01@0000AK
7000Fa`0009K7005001K7000Fad00002Fcd01000Fcd005/m0P0000ESG@00HgeSO@00009SO@04001W
W@000003Kk`01000Kk/000000gOJ0P000g^h0P0000=o]P00OiD00WnE00@007nCOi<000=oL`04001o
LWmb0002Oe820003Oe801000Oc9o<Wlb0P000glb00D007/CNa<007/D0080009bm@03001^eP00009Z
eP<0009V]`05001R]`00GYP00002GYP05P00GYP005ZH001JN000EWP005Ih001BF000DUP004iH001:
>000AQP003gh0P0000@YM`000000D`P0000;6O`00000<Wh003JN000jWP00?[h00002@[d200001dJm
0016_@00B]d004[M01D0000<D]`005;L001Bg000D]`005;L001Bg0000U;L00T005KL001Fg000E]`0
05KL00000UKL00D005KL001Fg000009Fg009001Fg000E]`005KL001Fg000009Fg00;001Ff`00E]/0
05KK001Ff`00E]/00002E]/01@00E]/005KK00000UKK1`0000iFf`00E]]Ff`00E]/005KK001Ff`00
E]/005KK0P0000]Ff`00E]]Ff`00E]/005KK001Ff`0001ioo`03001oogoo091oo`00Fgoo00<007oo
Ool06Woo00<007ooOol0ogooBgoo1@0000@P0@00000`0`800005>0@003PT000l900200001T1U0014
QP00B:H0009<a`03001Dj000009I:@04001QJF5Y0002JL/01@00KPa^36h<00001GI]0P000WZ=00L0
07k;000007k:001nb@02002]Ool600001UJj001F^P00E[X0009F^P0@001F^UJj001F^P00E[/005KK
001Ff`00E]/005KK0002E]/00`00E]/00002E]/02P00E]/005KK001Fg000E_`005Kl100000AJo000
F_`000=K7005001K7000Fa`00002Fa`01P00Fad005/m001K?@800005Hed006=MHed00002Hgd01000
Hgd000000V^L00D006nlKka__000009c^P03001gfP00009g^003001k^000009k]`06001oUGnEOiD0
07nD0P0017mc0P0000=oLP00Oe800WmB00D007mBOe9oDP00009o<P03001o<P0000=o<P08001k4g/C
001k5000Ma@0009bm@07001^eP00J]H006Jg00000VJg00<006:g00000UjH01X005jH001NV000FYP0
05Yh001FN000EWP0059H001BF000CUP004Xh00166000?OP003Fh0P0000<DmP0000001P0000@=g000
000R?@@0008jWP800092_@060012_@00A[d004Jm0P0000A:g@00B]d0009>g@0=001>g@00C]`004kL
001Bg000D]`005;L00000U;L00T005;L001Bg000D]`005;L00000U;L00D005;L001Bg000009Fg009
001Fg000E]`005KL001Fg000009Fg00=001Fg000E]`005KL001Fg000E]`005KL00000UKL00<005KK
00000UKK00H005KK001Ff`00E]/:00001UKK001Ff`00E]/0009Ff`07001Ff`00E]/005KK00000UKK
00L005KK001Ff`00E]/00002E]/01`00E]/005KK001Ff`0001ioo`03001oogoo091oo`00Fgoo00<0
07ooOol06Woo00<007ooOol0ogooBWoo100000LD000000000303000d0`02000043PT000l9000@4D0
041U0014QP00B:H004c7001Dj0000UTY00P0065YHFT006FZ001Yb`000Vh<0P001GI]00H007Z=NXej
S@00O//200000gk:001nb@02002WOol6000025JJ001F^P00E[X005Jj0002E[X00`00E[X00002E[X0
2`00E[X005Jj001F^`00E]/005KK00000UKK00L005KK001Ff`00E]/00002E]/01000E]/005KK1P00
00AJo000F_`0009Jo003001Jo000009K7005001K7000Fa`00002Fa`01000Fad005/m0P0000EOG000
HeeSG@00009SG@06001SOF=m001[W0000f^L00@006nl000000=c^P03001g^7Nh009g^004001k]g^g
NkL20002OiD01000OiAoU0000gmc00@007mc000000AoDP0:001oDWmB001oDP00Oc8007lb0002Oc82
0002Na<01@00Na@007LD00000W;e00D006kF001ZeP00009V]`03001V]`00009R]`0;001NV000GYP0
05jH001JV000FWP00002EWP01000EWP0059H0P000TiH0P0000E66000?OP003Fh00d000046O`00000
:Ud5000043jn0012_@00@[d004Jm0016_@00B]d004[M001:g@000TkM00d004kM001>g000C]`005;L
001Bg000D]`00002D]`03`00D]`005;L001Bg000D]`005;L001Bg000D]`00002E]`02@00E]`005KL
001Fg000E]`00002E]`02@00E]`005KL001Fg000E]`00002E]`02000E]`005KL001Ff`00E]/80000
3eKK001FfeKK001Ff`00E]/005KK001Ff`00E]/00002E]/03P00E]]Ff`00E]/005KK001Ff`00E]/0
05KK0002E]/02@00E]/005KK001Ff`00E]/0000OOol00`00Oomoo`2?Ool005Yoo`03001oogoo01ao
o`03001oogoo0?moodUoo`H00004:0800000=0<A000015CX001I:@000f5Y00@006FZIJX000=^3003
001b;00000AfK@08001jSGZ=NXd007k;001nb@800003O/T000000:1oo`L0000:EYT005JI001FV@00
EYX005Jj0002E[X01`00E[X005Jj001F^P00009F^P05001F^P00E[X00002E[/02`00E]/005KK001F
f`00E]/005KK00000UKK00<005KK00000`0000IJn`00F_/005[k0002F_`01`00F_`005[l001Jo000
009K7003001K7000009K7003001K700000<00005Gc`005mLGe`00002Hed01000Hed006=m0P000V^L
00D006^LJia[W000009c^P03001c^W>j008000=g^004001k]g^g0002OiH00`00OiD00002Oi@01@00
Og=oLgmc00000Wmc00<007mBOe800WmB0P0000IoDP00Oe8007lb0002Oc801@00Oc8007/c00000W/C
00@007LDMa@0009bm@03001^eP000080009V]`03001V]`00009R]`07001NV000GYP005jH00000UZH
00<005Yh0000200000=>F000BSP00P0000Dmn000=KP002Ug00X000041I/000008Sd20000139m000f
OCIm0P000T:m0P0000Y6_@00A[d004[M001:g@00B]d0009>g@0=001>g@00C]`004kL001Bg000D]`0
05;L00000U;L00T005;L001Bg000D]`005;L00000U;L00l005;L001Bg000E]`005KL001Fg000E]`0
05KL00000UKL00<005KL00000UKL00@005KL001Fg0X00008E]/005KK001Ff`00E]/0009Ff`07001F
f`00E]/005KK00000UKK00L005KK001Ff`00E]/00002E]/02`00E]/005KK001Ff`00E]/005KK0000
0UKK00<005KK00000UKK00D005KK001Ff`0001ioo`03001oogoo08moo`00FWoo00<007ooOol077oo
00<007ooOol0ogooBGoo100000@P0@00000`0`80000A>0@003PT000l9000@4D0041U0014I@00B8H0
04c7001@i`0200001ETY001QJF5Y00000fFZ00@006h<KP`0009b;004001fKGI]MVd20003NXd00`00
O/]nb`0300000gk90000002JOol600001UIi001FV@00EYT0009FV@05001FV@00EYT00002EYX02`00
E[X005Jj001F^P00E[X005Jj00000UJj014005JjE[X005Jj001F^`00E]/005KK001Ff`00E]/005KK
00D00004F]/005[k0002F_/02@00F_/005[k001Jo000F_`00002F_`00`00F_`00002Fa`00`00Fa`0
0003000015ll001O?0000Ull00L005mLGe`006=M001SG@020002Ig`01@00Jia[W000Ji`00P000W>j
00<007>j00000WNi00L007Nh001k]`00NkL00003OiH01P00OiAoU000Og@0009oL`04001oLgmc0003
Oe802@00Oe8007mB001oDP00Oc800002Oc801@00Oc8007/c00000W/C00@007LDMa@0009bm@03001^
eP00009ZeP03001V]`00009V]`07001R]`00GYP005jH00000UjH1@0000MFN000EWP0059H001BF005
00001THH000003Fh000YM`<000030140000000L000098Sd002YM000bO@00=Wd003ZM00D00003A[d0
04Jm0080009:g@0=001:g@00C]d004kM001>g000C]`005;L00000U;L00d005;L001Bg000D]`005;L
001Bg000D]`00002D]`01@00D]`005;L00000UKL00X005KL001Fg000E]`005KL001Fg0X00004E]`0
05KL0002E]`02@00E]/005KK001Ff`00E]/00002E]/00`00E]/00002E]/02`00E]/005KK001Ff`00
E]/005KK00000UKK00`005KK001Ff`00E]/005KK001Ff`00E]/2000015KK001FfeKK1`007Woo00<0
07ooOol0Sgoo001JOol00`00Oomoo`0MOol00`00Oomoo`3oOom7Ool300000a@00000000300004C@3
000003PT000l9000@4D0041U0014I@00B8H004c700000U3W00<005TX00000V5Y00T006FZIJYUZP00
KN/006h<00000W8/00H007I]MVd007Y/0003NXd01`00O/]nb`00O/T007k9008009Aoo`H0000<EWP0
05Ih001FN000EWT005JI001FV@000eJI00d005JI001FV@00EYX005Jj001F^P00E[X00002E[X01@00
E[X005Jj00000UJj00X005Jj001F^`00E]/005KK001Ff`@00004F]/005[K0002F]/00`00F_/00002
F_/01@00F_/005[k00000U[l00P005[l001Jo000F_`005/L100000=O7000Gc`00Ull00D005ll001O
?000009OG006001SG@00001WO0000VMl00<006^LJi`00P000VnK00@007>jLkX000Ag^@05001k]g^g
NkL00004OiH01000OiAoU0000Wmd0P000gmc0P000WmB00D007mB001oDP00009oDP09001o<WlbOc80
07lb001k<`00009k4`09001g57LDMa@007;e001^eP00009ZeP03001V]`00009V]`05001R]`00GYP0
0002GYP300003eZH001JN000EWP005Ih001BF000DUP004hh001:>00400000cFh000YM`0;000010FK
000000000RYM0P000SIm0P0000<nW@00@Yd01`0000A:g@00B]d0009>g@0=001>g@00C]`004kL001B
g000D]`005;L00000U;L010005;L001Bg000D]`005;L001Bg000D]`005;L001Fg0/0000:E]`005KL
001Fg000E]`005KL0002E]`01`00E]`005KL001Ff`00009Ff`09001Ff`00E]/005KK001Ff`00009F
f`0;001Ff`00E]/005KK001Ff`00E]/00002E]/00`00E]/00002E]/01P00E]/005KK001Ff`P00006
E]/005KK001Ff`007goo00<007ooOol0SWoo001JOol00`00Oomoo`0MOol00`00Oomoo`3oOom7Ool5
00000bP2000`0`0200004SP4000h9000?2@004150010I@00A6D004R6001<a`00D>L0009I:0800005
HFT006FZIJX00002KN/00`00KP`00003LR`20002NV`01@00NXejSGZ=00000Wk;00<007k900000Wk9
00<007ooOol0Rgoo1`0000aFE`00EWP005Ih001FN000EWP005Ih0002EWT01@00EYT005JI00000UJI
00T005JI001FV@00EYX005Jj00000UJj00T005Jj001F^P00E[X005Jj00000UJj00<005Jj00000UJk
1@0000AJf`00F]/0009Jf`03001Jf`00009Jf`05001Jn`00F_/00002F_/02P00F_/005[l001Jo000
F_`005[l0P0000AO7000Ga`0009O7008001O?5ll001O?000Gc`0009OG080000;Ie`006MlIg`006Ml
001[W000Ki/00002Ki/01@00LkX007NI00000gNi00@007^gNkMk]`80009oUP05001oU@00Oi@00003
Og@01000Og=oL`000WmC00<007mB00000WmB00D007mBOe9oDP0000Ao<P04001k<g/c0002Na<01@00
MaAg57LD00000W;e0P000V[F00P006JgI[L006Jg001R]`000UjH0`0000INV000FYP005Yh0002EWP0
1000EWP0059H0P0000M>>000BSP004HH000mn00200000bUg000I5P0700000`2f0000000200002agl
00000000<Wd003Im000jW@00?Yd00P0000E2_@00A[d004Jm02H0000:D]`005;L001Fg000E]`005KL
0002E]`02@00E]`005KL001Fg000E]`00002E]`00`00E]`00002E]`02@00E]/005KK001Ff`00E]/0
0002E]/02`00E]/005KK001Ff`00E]/005KK00000UKK00D005KK001Ff`00009Ff`/0009Ff`09001F
f`00E]/005KK001Ff`0001moo`03001oogoo08ioo`00FWoo00<007ooOol07Woo00<007ooOol0ogoo
AGoo100000HP0@00000`0`00=0<200003SPT000l9000@4D0041U0014I@00B8H004c70002D>L00`00
FBP00002GDT01@00IJYUZVFZ00000fg[00<0078/LR`00W8/00D007Y/NVajK00000=jS@05001nbgk;
001nb@0200000gk9001oo`26Ool6000015IG001FE`000UIG00L005IG001FN000EWP00002EWP02`00
EWP005Ih001FN@00EYT005JI00000UJI00D005JI001FV@00009FVP0;001F^P00E[X005Jj001F^P00
E[X00002E[X00`00E[YF^P05000015[K001Jf`000U[K00L005[K001Jf`00F]/00002F]/00`00F_/0
0002F_/02000F_/005[k001Jo000F_`400002ElL001O75lL001O7000Ga`00002Gc`01000Gc`005ll
0`0000QWG000IeaWG000Ig`006Ml0P000fnK00@006nKKi/000=gV@07001g^@00NiP007^g00000W^G
00<007nF00000WnE00<007mdOg@00Wmd00@007mcOg<0009oD`8000=oDP05001oDWmBOe800004Oc80
2000Nc=k<`00Na<007/D0002Ma@02000L_Ebm@00K_H006[F0002I[L00`00I[L00002H[L300001UjH
001NV000FYP0009JN00:001FN000EWP0059H001BF000CSP200000dHH000000020002:GL300000`0A
0000000600000a7L000000029Sd200002cIm000jW@00?Yd004:M0012_@00A[d00P000TZm00d004Zm
001:g@00C]d004kL001>g000C]`00002C]`03@00D]`005;L001Bg000D]`005;L001Bg000009Bg009
001Bg000D]`005;L001Bg000009Fg005001Fg000E]`00002E]`02`00E]`005KL001Fg000E]`005KL
00000UKL00/005KL001Ff`00E]/005KK001Ff`00009Ff`05001Ff`00E]/00002E]/01000E]/005KK
2P0000MFf`00E]/005KK001Ff`0200001UKK001Ff`00E]/0009Ff`05001Ff`00E]/0000NOol00`00
Oomoo`2>Ool005Yoo`03001oogoo01ioo`03001oogoo0?moodEoo`80000650000000:08003030P00
018h1000>2@003`T0010A@00@6D004AU0018QP00C<L0053W0002FBP00`00GDUMB@0200000fFZ001]
j`03KN/00`00LRab;002LR`00`00NVajK002NV`02000NXejSGZ=001nb`00O/T200000gk900000020
Ool600002UHf001FE`00EUL005IG001FE`000UIG01@005IGEUL005Ih001FN000EWP005Ih001FN000
EWT005JI001FV@000eJI00d005JI001FV@00EYX005Jj001F^P00E[X00002E[X00`00E[X000050000
15[J001JfP000U[K00T005[K001Jf`00F]/005[K00000U[K00D005[K001Jn`00009Jn`06001Jn`00
F_/005[l0P0000ANn`00Ga`0009O7005001O7000Ga`00002Ga`00`00GcaO?00300000f=L001WG002
Ie`00`00Ie`00002Ig`00`00Jg/00003Ki/01000Ki/0000017NI00H007^HNiP007^g0003NiL01@00
OiEoUGnE00000gmd00D007md001oL`0000=oD`05001oDWmBOe800003Oe820003Oc802000Nc=k<`00
Na<007/D0002Ma@01P00L_Ebm@00K_H0009ZeP03001V]`00009V]`<00006H[P005jH001NV0000UZH
00h005Yh001FN000EWP0059H001BF000CSP004Xh0P0000Dmn000=KP002Ug00<000030140000000@0
00030AP0000000<000039Sd002YM00@0000:?Yd004:M0012_@00A[d004Jm0002B[d01P00B[d00000
C]d0009>g00?001>g000C]`004kL001Bg000D]`005;L001Bg000009Bg009001Bg000D]`005;L001B
g000009Bg009001Bg000E]`005KL001Fg000009Fg009001Fg000E]`005KL001Fg000009Fg00;001F
g000E]`005KK001Ff`00E]/00002E]/01@00E]/005KK00000UKK1`0000AFf`00E]/0009Ff`0:001F
f`00E]/005KK001Ff`00E]/200003EKK001FfeKK001Ff`00E]/005KK001Ff`0001ioo`03001oogoo
08ioo`00FWoo00<007ooOol07goo00<007ooOol0ogoo@goo100000PP0@00000`0`00=0<003P43`00
00A@i`00FBP0009MB@04001URFF90004KN/00`00LP/00002LR`20004NV`01`00NXejSGZ=001nb`00
009nb@04001nb@00001iOol7000045Hf001F=P00ESH005Hf001FE`00EUL005IG001FE`000UIG0100
05IGEUL005Ih001FN000EWP005Ih001FN000EWT0009FV@03001FV@00009FV@09001FV@00EYT005JJ
001F^P00009F^P03001F^P0000@00005F]X005[JF]X00002F]X02`00F]X005[K001Jf`00F]/005[K
00000U[K00D005[K001Jf`00009Jn`04001Jn`00F_/400002Ekk001Nnekk001O7000Ga`00002Ga`0
1P00Ga`005lL001O?0800005Hc`006=LHe`00002Ie`01000Ie`006Ml0P000V]k00D006nKKi]_V`00
009cVP05001gVGNIMiT00003NiP00`00NiMkU`02NiL01P00OiEoU@00OgD0009oM004001oM0000004
Oe<01000Oe9oDWmB0P000WmB0P000glb00@007/cNc=k<`800006Na@007LDMa@007;e0P0000M^mP00
J]IZeP00I[L00002I[L01`00H[L006:h001NV000009NV00B001JV000FWP005Ih001FN000DUP0059H
001>>000BSP004HH100000<YM`0000002`0000D=V`007O`002Hm00800003<Ud0000000@00092_@04
0016_@000002B[d03@00B[d004[M001>g@00C]`004kL001>g000009>g00=001Bg000D]`005;L001B
g000D]`005;L00000U;L00T005;L001Bg000D]`005;L00000UKL00l005KL001Fg000E]`005KL001F
g000E]`005KL00000UKL00<005KL00000UKL00H005KK001Ff`00E]/:00001UKK001Ff`00E]/0009F
f`07001Ff`00E]/005KK00000UKK00T005KK001Ff`00E]/005KK00000UKK00T005KK001Ff`00E]/0
05KK00007goo00<007ooOol0SGoo001JOol00`00Oomoo`0OOol00`00Oomoo`3oOom3Ool200001Q@0
000002P2000`0`@0000?>0@003`T000lA000@4D004AU0018Q@00C:H0053600800005FBP005e9GDT0
0002IHT01@00KN]]jfg[00000W8;00<0078/00000WI;00D007Y/NVajK00000=jS@03001nb`00009n
b@@007=oo`H0000CESH005HfESH005Hf001F=P00ESH005Hf001F=P00EUL005IG00000UIG00D005IG
001FE`00009FE`0;001FN000EWP005Ih001FN000EWP00002EWT01@00EYT005JI00000UJI00D005JI
001FV@00009FVP03001F^P0000@00004F[X005Zj0002F]X00`00F]X00002F]X01`00F]X005[K001J
f`00009Jf`07001Jf`00F]/005[K00000U[K1P0000AJn`00F_/0009Nn`05001Nn`00Ga`00002Ga`0
1P00Ga`005lL001O70800005Hc`006<lHc`00002He`01000Ie`006ML0P000V]k00D006]kJg/006nK
008000=cVP05001gV@00MiP00002NiP20002NiL01@00NiH007nE00000Wme00<007md00000Wmd00<0
07mCOe<00WmC0P0000AoDP00Oe<0009oDP80009o<P03001o<`00009k<`04001k57/D0003Ma@30000
1Fkf001ZeV[F00000VJg0`0000AR]`00H[P0009NV007001NV000FYP005Yh00000UIh00@005Ih001B
F0800005CSP004Xh0016600200001CFh000000006AH02@0000@0m`00000=V`8000039Sd002YM0080
0003=Wd003Ym00<0000>@[d004Jm0016_@00B[d004Zm001:g@00C]d0009>g00?001>g000C]`004kL
001Bg000D]`005;L001Bg000009Bg00=001Bg000D]`005;L001Bg000D]`005;L00000UKL00L005KL
001Fg000E]`00002E]`02P00E]`005KL001Fg000E]`005KL2P0000mFf`00E]]Ff`00E]/005KK001F
f`00E]/005KK00000UKK00<005KK00000UKK00/005KK001Ff`00E]/005KK001Ff`00009Ff`0;001F
f`00E]/005KK001Ff`00E]/0000OOol00`00Oomoo`2=Ool005Yoo`03001oogoo021oo`03001oogoo
0?mood5oo`@000038040000000800003=0<003P30080000<?2@003a40010A@00A6D004R5001<YP00
0U3600<005CW00000Ue900P006F9IHT006VY001]j`000g8;00<0078/00000WI;00H007Y/NVajK000
NXd30002O//00`00O/T00003001]Ool6000025Hf001F=P00ESH005Hf0002ESH02@00ESH005Hf001F
=P00ESH00002ESH02@00EUL005IG001FE`00EUL00002EUL01`00EUL005Ih001FN000009FN00;001F
N000EWP005Ii001FV@00EYT00002EYT01@00EYUFV@00EYT01@0000AJ^P00F[X0009J^P05001J^P00
F]X00002F]X01@00F]X005[J00000U[K00X005[K001Jf`00F]/005[K001Jf`@00007F_/005[kF_/0
05[k00000U[k00<005kk00000Ukk00P005lL001O7000Ga`005lL0P0000MS?000HcaS?000Hc`00002
He`01P00Ie`00000Jg/000=[N`04001[Nf]k0002LiX01@00LiYcVW>J00000WNH00<007^H00000W^G
00L007^G001kUP00OiD00003OgD01@00OgAoM7md00000gmC00D007mC001oDP00009oD`80009o<`05
001o<P00Oc<00002Nc<01@00NaAk57/D00000WLD00P007;eL_D006kf001ZeP000VJg00<006Jg0000
0V:g00T006:h001NV000GYP005ZH00000UYh00X005Ih001FN000DUP0059H001>>0800003AQP003gh
00800003:GP0000000X000050?L00000000Eg00200001BYM000bG@00=Wd00P0000<nW@0000001@00
0TZm00H004Zm000004kM0002C]`03`00C]`004kL001>g000D]`005;L001Bg000D]`00002D]`02@00
D]`005;L001Bg000D]`00002D]`02@00D]`005KL001Fg000E]`00002E]`<00002UKL001Fg000E]`0
05KK001Ff`000UKK00L005KK001Ff`00E]/00002E]/02@00E]/005KK001Ff`00E]/00002E]/02`00
E]/005KK001Ff`00E]/005KK00000UKK00<005KK00000UKK00L005KK001Ff`00E]/0000NOol00`00
Oomoo`2=Ool005Yoo`03001oogoo021oo`03001oogoo0?mood5oo`80000650000000:08003020P00
00<h0`00>0@00P0000XlA000@4D004AU0018Q@00C:H0009@aP03001DieCW00800005GDT006F9IHT0
0002JJT00`00LP]b2`03LP/01@00MT]fBgI;00000gY/0P000WZ;0P0000=nb`00O/T01000Igoo1P00
00iF=P00ESH005Hf001F=P00ESH005Hf001F=P000UHf00<005Hf00000UHf00l005Hf001F=P00ESH0
05IG001FE`00EUL005IG00000UIG00D005IG001FN000009FN00=001FN000EWP005Ih001FN@00EYT0
05JI00000eJI1@0000AJ^@00F[X0009J^P09001J^P00F[X005Zj001JfP00009JfP0?001JfU[J001J
fP00F]/005[K001Jf`00F]/005[K00800004F_/005[k0002F_/00`00F_/00002F_/00`00F_/00002
G_/01P00G_/005lL001O70@00007Hc`006<lHc`006<l00000V<l00H006=LHe`006MK0002Jg/01@00
Jg][N`00Jg/00P000g>J00@007>J000000=gV003001kUg^G009kU`05001kUW^FNiH00004OgD01P00
OgAoM000Og@0009oD`05001oD`00Oe800002Oe<20002Oc<01@00Oc8007lc00000W/c00D007/DNaAk
5000009g5008001bmG;e001^mP00J]H0009V]`0>001V]fJg001R]`00H[P005jH001NV000FYP0009J
N00<001FN000EWP0059H001BF000CSP004Xh0P0000<mn00000000RUh0`0000<0D`000000200000@=
V`00000Mo0800005<Ud003Im000jO@020002?Yd01000@Yd004Jm1`0000Q>g@00C]`004kL001>g000
0TkL00d005;L001Bg000D]`005;L001Bg000D]`00002D]`01000D]`005;L3P0000QFg000E]`005KL
001Fg0000UKL00/005KL001Fg000E]`005KK001Ff`00009Ff`0>001FfeKK001Ff`00E]/005KK001F
f`00E]/0009Ff`0;001Ff`00E]/005KK001Ff`00E]/00002E]/3000015KK001FfeKK2@007Woo00<0
07ooOol0SGoo001JOol00`00Ool00002000OOol00`00Oomoo`3oOoloOol400001200000003020P00
018h0`00>0@003`T000lA000@4D004AU0018Q@00C:H005360002E>L01000FBMI9`000VF900D006VY
JJUYZ@0000Ab2`8000=fB`03001jK7Y/008000=jR`07001nZP00001nb@00NZP00P00H7oo1`00019F
=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf0002ESH00`00ESH00002ESH04@00ESH005Hf
001F=P00ESH005IG001FE`00EUL005IG00000UIG010005IGEUL005Ih001FN000EWP005Ih001FN000
EWT0009FV@04001FV@00EYT200001UZi001J^@00F[T0009J^P09001J^P00F[X005Zj001J^P00009J
fP03001JfP00009JfP08001JfP00F]/005[K001Jf`@00009F_/005[kF_/005[k001Jn`00009Jn`05
001Jn`00F_/00002G_/01000G_/005lL0P0000AO6`00Ga`0009S?003001S?000009S?004001S?000
He`20002Ie/01000Jg][N`000V]k00@006mjKgX000=cVP04001gVGNI0002MiP00`00NiMkU`02NiL0
1@00NiIkUW^F00000gme00D007md001oM000009oM003001oD`00009oD`04001oDgmCOe<20002Oc<0
1P00Oc8007lc001k<`8000=k5004001g50000002L_D00`00K_H00002J]H30002I[L02`00H[L006:h
001NV000GYP005ZH00000UYh00h005Ih001FN000DUP0059H001>>000BSP004HH0P0000<e^000:GP0
0`0000<0D`0000001P0000D0m`00000001GL008000099Sd00000=Wd003Ym000nW@00008nW@800007
A[d004Jm001:_@00B[d07`0000ABg000D]`0009Bg00;001Bg000D]`005KL001Fg000E]`00002E]`0
1@00E]`005KL00000UKL00/005KL001Fg000E]/005KK001Ff`00009Ff`0;001Ff`00E]/005KK001F
f`00E]/00002E]/00`00E]/00002E]/01P00E]/005KK001Ff`X00008E]/005KK001Ff`00E]/001mo
o`03001oogoo08aoo`00FGoo0`008goo00<007ooOol0ogoo?Goo1P0000HX0P00000d0`00>0<20000
33`T000lA000@4D004AU0018Q@00C:H0009@aP03001Di`0000=I9`800007IHT006VYJJT006g90000
0W8;00@0078ZLRX000=fB`800003NV/007Z;009jR`07001nZWjZ001nb@00NZP00P00FWoo1P0000IF
=P00ESH005Hf0002ESH03@00ESH005Hf001F=P00ESH005Hf001F=P00009F=P07001F=P00ESH005Hf
00000UHf014005Hf001F=P00ESH005Hf001FE`00EUL005IG001FE`00009FE`0>001FEeIG001FN000
EWP005Ih001FN000EWP0009FN@H00006F[T005Zi001J^@000UZi00L005Zj001J^P00F[X00002F[X0
1`00F[X005[J001JfP00009JfP04001JfP00F]/4000015[K001Jf`000U[k00L005[k001Jn`00F_/0
0002F_/00`00F_/00002F_/01000G_/005kk0P0000UO6`00Ga]O6`00Ga`006<l00000V<l00@006<l
001S?080009WF`07001WFfMK001[N`00Jg/00P000fmj00@007>JLiX0009gV@05001gV000MiP00002
NiL01`00NiL007^F001oM@00009oM@05001oM000Og@00002Og@20003Oe<00`00Oe=oD`02Oe<01@00
Oc=o<glc00000Wlc00D007/c001k=000009k5004001g50000002L_D00`00K_H00002J]H03P00J]MZ
e`00I[L006:g001R^000GYP005jH0002FYP00`00FWP00002EWP01000EWP0059H0P0000E>>000BSP0
04HH00800003=KP002Uh010000035M`001gl0080000?;Sd00000000jO@00?Yd003jM0012W@00A[d0
04Jm00800004B[d004Zm0002B[`03`00C[`004kL001>g000C]`004kL001Bg000D]`00002D]`02@00
D]`005;L001Bg000D]`00002D]`02`00D]`005;L001Bg000D]`005KL00000UKL00L005KL001Fg000
E]`00002E]`02`00E]`005KL001Fg000E]/005KK00000UKK00T005KK001Ff`00E]/005KK00000UKK
00P005KK001Ff`00E]/005KK200000AFf`00E]/0009Ff`0;001Ff`00E]/005KK001Ff`00E]/0000O
Ool00`00Oomoo`2<Ool005Uoo`03001oogoo02=oo`03001oogoo0?mooceoo`D00003:08003020080
0003>0<003P400d00005D<H005CWE>L00002FBL01000GDQMB0000VVY00H006g9KLT0078;0003LRX0
1@00MT]fBgI;00000gY[00@007Z;NX/0009nZP07001nb@00NZP006j20000Dgoo1P0000aFE`00ESH0
05Hf001F=P00ESH005Hf0002ESH01`00ESH005Hf001F=P00009F=P0;001F=P00ESH005Hf001F=P00
ESH00002ESH03`00ESH005Hf001F=P00ESH005Hf001FE`00EUL00002EUL01@00EUL005IG00000UIG
00T005Ih001FN000EWP005Ih00000UIh0`0000ANV000FYT0009J^@0:001J^EZi001J^@00F[T005Zj
0002F[X02@00F[X005Zj001J^P00F]X00002F]X00`00F]YJfP03000015[J001Jf`000U[K00L005[K
001Jn`00F_/00002F_/01@00F_/005[k00000U[k1P0000UO6`00Ga]O6`00Ga/005lL00000V<l00@0
06<l001S?0800005Ie/006MKIe/00002Ie/01000Jg/000000Vmk00P006mjKgX007>J001cV@000WNI
00/007NHMiQgV000NiL007^G001kUP00009oM@04001oM@00Og@20004Og@01@00Oe=oDgmC000017mC
00D007lcOc=o<`0000=o<`800003Nc@007/D009k50800004MaD007;e0002K_H30002J]L00`00I[L0
0002H[L200001ejH001NV5jH001JV000009JN0T00006CSP00000AQP003gh0P0000<YN0007CL03000
00L1>@00000001gl000V?@020000539M00000000?Yd003jM0012W@00A[d004Jm001:_@00B[d004Zm
0002B[`200001TkL001>g000C]`0009>g00?001Bg000D]`005;L001Bg000D]`005;L001Bg000009B
g003001Bg000009Bg00;001Bg000D]`005KL001Fg000E]`00002E]`03`00E]`005KL001Fg000E]`0
05KL001Ff`00E]/00002E]/02@00E]]Ff`00E]/005KK001Ff`0:000025KK001Ff`00E]/005KK0002
E]/3000015KK001Ff`000UKK00L005KK001Ff`00E]/0000NOol00`00Oomoo`2<Ool005Uoo`03001o
ogoo02Aoo`03001oogoo0?mooc]oo`8000031000020000800003<080000000@0000=?2@003`T0010
A000@4D004AU0018Q@00C:H00P0000EDi`00FBMI9`00009MB005001UJ000JJT00003KLT00`00LRYb
:P02LRX00`00MT]fB`020003NV/01000NX]jR`000WjZ0P0000Enb@00001^PP0004aoo`L0000BEUL0
05IG001FE`00EUL005Hf001F=P00ESH005Hf001F=P000UHf01@005HfESH005Hf001F=P00ESH005Hf
001F=P00ESH005Hf001F=P000UHf00d005Hf001F=P00ESH005Hf001F=P00EUL00002EUL01`00EUL0
05IG001FE`00009FE`05001FN000EWP00002EWP00`00EWP0000200001UjH001NV000FYT0009J^@08
001J^EZi001J^@00F[T0009J^P09001J^P00F[X005Zj001J^P00009JfPH0000=F]X005[JF]X005[K
001Jf`00F]/005[k00000U[k00D005[k001Jn`00009Jn`<00007G_/005lKGa/005lK00000UlK00T0
05lKGa/005lL001S?000Hc`00P0000EW>`00Ie]WF`00009WF`06001WFfMK001[N`000fmk00@006mj
KgX0009cV@04001gVGNI0004MiP01@00NiMkUg^G000017me00D007mdOgAoM00000AoM004001oDgmC
Oe<20003Oe<01@00Oc=o<glc00000glc00@007/dNc@000=k5006001g5GLE001bm@000Vkf00<006[G
00000V[G00D006JgI[L006:g0080009NV003001NV00000D00007EWP005Ih001BF000CUT01P0000<m
n00000000RUh0`0000<0D`0000002P0000HA^`00000V?@00;Sd20002=Wd600002TJm0016_@00B[d0
04Zm001:_@000TZl00l004jl001>g000C]`004kL001>g000D]`005;L00000U;L00/005;L001Bg000
D]`005;L001Bg000009Bg00=001Bg000D]`005;L001Fg000E]`005KL00000UKL00T005KL001Fg000
E]`005KL00000UKL00P005KK001Ff`00E]/005KK200000AFf`00E]/0009Ff`0;001Ff`00E]/005KK
001Ff`00E]/00002E]/30002E]/02`00E]/005KK001Ff`00E]/005KK00007goo00<007ooOol0Rgoo
001IOol00`00Oomoo`0TOol00`00Oomoo`3oOoljOol200001@@000000000:0800P0000Dd0`00>0<0
03P40080000:?2@004140010A@00A6D004R50002C:H01P00D<H00000FBL0009MB005001UJ6EXIFP0
0004KLT00`00LRYb:P03LRX200000gI:001jJ`02NV/01000NX]jR`000WjZ00<007jX00001000AWoo
1P0001=FN000EUMFE`00EUL005IG001FE`00EUL005IG001F=P00ESH00002ESH01@00ESH005Hf0000
0UHf01<005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH00002ESH02@00ESH005Hf001F
=P00ESH00002ESH02`00EUL005IG001FE`00EUL005IG00000UIG00<005Ih00000UIh1@0000ANV000
GYP0009NV003001JV@00009J^@05001J^@00F[T00002F[T01`00F[X005Zj001J^P00009J^PD00007
G]X005kJG]X005[J00000U[J00D005[K001Jf`00009Jf`0:001Jn`00F_/005[k001Jn`00F_/20000
1ekk001Nnekk001O6`00009O6`09001O6elK001O6`00Ga`006<l00800005Hc/006LkIc/00002Ie/0
1000Ie/006MK0P000V]k00D006mkKg/006mj0080009cV@05001gV@00MiP00003MiP01@00NiMkUg^G
000017me00D007mdOgAoM00000=oM007001oE000Oe<007mC00000WmC00<007mC00000Wlc0P000Wlc
00D007/dNcAk=000009k5006001g5GLE001bm@000Vkf00H006[GJ]L006[G0002I[L01P00H[L006:h
001NV0<0000@FYP005ZHFYP005Ih001FN000DUP004iI001>>@00BST400000cFh000YN00300000`1C
0000000900000`Uj0000000300002Bhm000bG@00=Wd003Ym000nW@0300000dJm0016_@020002B[d0
3@00B[d004Zl001>_000C]`004kL001>g000009>g00?001Bg000D]`005;L001Bg000D]`005;L001B
g000009Bg00?001Bg000D]`005;L001Bg000E]`005KL001Fg000009Fg003001Fg000009Fg004001F
g000E]`:000025KK001Ff`00E]/005KK0002E]/01`00E]/005KK001Ff`00009Ff`08001Ff`00E]/0
05KK001Ff`<0009Ff`0;001Ff`00E]/005KK001Ff`00E]/0000OOol00`00Oomoo`2;Ool005Uoo`03
001oogoo02Eoo`03001oogoo0?moocQoo`8000031000000000<00008<0800000>0<003P4000l9080
0006@4@004150014I@000TR500<004bV00000U3600H005CV000005e80003IFP20003KLT00`00KNT0
0003LRX20003MTX01000NV]jJ`000gZ;00<007jZOZX00`0000=jZ0000000@7oo1P0000QFN000EWP0
05Ih001FN0000UIG00T005IG001FE`00EUL005IG00000UIG00/005Hf001F=P00ESH005Hf001F=P00
009F=P0C001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf00000UHf00L005Hf001F=P00
ESH00002ESH02`00ESH005IG001FE`00EUL005IG00000UIG00D005IGEUL005Ih00<00006GYP005jH
001NV0000UjH00D005jH001JV@00009J^@0:001J^EZi001J^@00F[T005Zj0002F[X00`00F[X00002
000015kJ001NfP000UkJ00<005kJ00000U[J00D005[J001Jf`00009Jf`08001Jf`00F_/005[k001J
n`@00007G_/005kkG_/005kk00000UlK00<005lK00000UlK00@005lK001O70800007Hc/006<kHc/0
06Lk00000VMK00@006MK0000009[F`04001[Nf]k0002Kg/01000LgYcNP000W>I00d007NHMiQgV000
MiP007^G001kU`00NgH00002OgD00`00OgD00002Og@20002Og@01@00Oe@007mC00000WmC00T007mC
001oD`00Oc<007lc00000Wlc00H007/dNcAk=000Na@20002MaD00`00L_Ebm@030002J]L02@00J]MZ
e`00I[L006:g001R^003000015jH001JV0000UZH00h005Ih001FN000DUP004iI001>>@00BST0048I
0P0000<e^000:GP03@0000D0e`000000016k00@00003;Sd00000008fO@05000jO@00000nW@070000
14Zm001:_@000TZl0P0000I>g000C]`004kL0002C]`03`00D]`005;L001Bg000D]`005;L001Bg000
D]`00002D]`00`00D]`00002D]`03000D]`005;L001Fg000E]`005KL001Fg0X00006E]`005KK001F
f`000UKK00T005KK001Ff`00E]/005KK00000UKK00<005KK00000UKK00/005KK001Ff`00E]/005KK
001Ff`00009Ff`0;001Ff`00E]/005KK001Ff`00E]/00002E]/00`00E]/0000NOol00`00Oomoo`2;
Ool005Uoo`03001oogoo02Eoo`03001oogoo0?moocQoo`800005100002@0000/0P0200004C@30000
03P4000l9000?2@004140010A@00A6D004R500000TbV00<0053600000UCV00<005T600000fEX00H0
06F8IHP006g90002KNT01P00LRYb:P00MRT000=fBP04001jJgY[0003NX/01`00OZYnZP00OZP007ZX
008003Yoo`H0000>EYT005Ii001FN000EWP005Ih001FN000EWP0009FE`03001FE`00009FE`0A001F
E`00EUL005IG001F=P00ESH005Hf001F=P00ESH00002ESH04`00ESH005Hf001F=P00ESH005Hf001F
=P00ESH005Hf001F=P00009F=P03001F=P00009F=P0?001F=P00ESH005Hf001FE`00EUL005IG001F
E`00009FE`03001FEeIG00<00006GYL005jH001NV0000UjH00L005jH001NV000FYT00002F[T02000
F[UJ^@00F[T005Zi0002F[X500002EkJ001NfUkJ001NfP00G]X00002G]X00`00F]X00002F]X02P00
F]/005[K001Jf`00F_/005[k0P0000ANn`00G_/0009Nn`03001Nn`00009Nn`05001O6`00Ga/00002
Ga/01P00Ga/00000Hc/0009S>`03001S>`00009W>`06001WFfMK001[F`000V]K00D006]kJg/006mk
0080009cNP04001cV@000004MiP01P00NiMkU`00NiL0009kMP03001oM@00009oM@80009oM007001o
M000Oe@007mC00000WmC00T007mC001oD`00Oc<007lc00000Wlc00H007/dNcAk=000Na@20002MaD0
0`00L_Ebm@02000016kf001Ze`000V[G00<006Jg00000V:g0P0000AN^000GYP0009JV003001JV000
009FN004001FN000DUP200001Dhi001:>@00@QT0100000<YN0007CL03`0000@A^`00000R70<00007
<Ud003Im000jO@00?Yd00P0000E2W@00AYd004Jm00X0000<C]`004kL001>g000C]`005;L001Bg000
0U;L00`005;L001Bg000D]`005;L001Bg000D]`?000035KL001Fg000E]`005KL001Fg000E]`0009F
f`05001Ff`00E]/00002E]/02`00E]/005KK001Ff`00E]/005KK00000UKK00/005KK001Ff`00E]/0
05KK001Ff`00009Ff`03001Ff`00009Ff`06001Ff`00E]/005KK1@007Woo00<007ooOol0Rgoo001I
Ool00`00Oomoo`0VOol00`00Oomoo`3oOolfOol200001@@000000000;0800P0000Dd0`00>0<003P4
00800008?2@004140010A@00A6D00098Q@05001<YP00D<H00002E>H00`00F@II1P0200000fEX001U
R003IHP01`00KNU]jFgY001b:P00009f:@05001fBWI:MTX00003NV/01000NX]jR`000WjZ00@007jX
001jZ08003=oo`L0000<EYT005JI001FV@00EYT005Ii001FN0000UIh00L005Ih001FN000EWP00002
EUL05@00EUL005IG001FE`00EUL005IG001F=P00ESH005Hf001F=P00ESH00002ESH04@00ESH005Hf
001F=P00ESH005Hf001F=P00ESH005Hf00000UHf00<005Hf00000UHf00l005Hf001F=P00ESH005Hf
001FE`00EUL005IG00000UIG00@005IG001FE`800004GWL005jG0002GYP02@00GYP005jH001NV000
GYP00002FYT00`00F[T00002F[T00`00F[T00002F[T3000015kI001NfP000UkJ00L005kJ001NfP00
G]X00002G]X00`00F]X00002F]X01P00F]/005[K001Jf`@00009G_/005kkG_/005kk001Nn`00009N
n`05001Nn`00Ga/00002Ga/01P00Ga/00000Ha/0009S>`03001S>`00009S>`04001W>`00Ie/20002
Je/01000Je][F`000V]k00@006mjKgX0009cNP04001gNGMi0003MiP01@00NiMkUg^G00000g]f00<0
07me00000Wme0P000Wmd0P000gmD00@007mCOe=oD`80009oD`03001o<`00009o<`04001o<`000002
Nc@01`00Na@007LE001g5@00009bm@06001^mVkf001Ze`000V[G00<006Jg00000V:g0P0000MN^000
GYQNV000FYP00002FYP02P00EWP005Ih001BF000CUT004hi0P0000=26@00?OP00P0000<YN0007CL0
0`0000<04P0000001`0000D16@00000001gl0080008Z?080000;=Wd003Ym000nW@00?Yd004:M0016
W@020002A[d01P00B[d004Zl001:_1/0000>D]`005;L001Bg000D]`005;L001Bg000E]`0009Fg009
001Fg000E]`005KL001Fg000009Fg005001Ff`00E]/00002E]/02@00E]/005KK001Ff`00E]/00002
E]/02`00E]/005KK001Ff`00E]/005KK00000UKK00P005KK001Ff`00E]/005KK200000AFf`00E]/0
01moo`03001oogoo08Yoo`00FGoo00<007ooOol09Woo00<007ooOol0ogoo=Goo1P0000</0P00<080
0P0000Dh0`00>0@003`T00`00006C:H00536001DiP000UT600@005dVGBH000AUR08000=]j@8000=f
:@03001fBWI:009fBP04001jJgY[0002NX/01@00OZYnZP00OZP01000;Goo1P0000AF^P00EYX0009F
V@07001FV@00EYT005JI00000UJI00d005Ii001FN000EWP005Ih001FN000EWP00002EUL05@00EUL0
05IG001FE`00EUL005IG001F=P00ESH005Hf001F=P00ESH00002ESH03@00ESH005Hf001F=P00ESH0
05Hf001F=P00009F=P07001F=P00ESH005Hf00000UHf00d005Hf001F=P00ESH005Hf001FE`00EUL0
0002EUL00`00EUL00003000015ig001NM`000UjG00T005jH001NV000GYP005jH00000UjH00D005ZI
001J^@00009J^@03001J^EZi00<00004G[T005kI0002G]X01`00G]X005kJ001NfP00009NfP05001N
fP00F]X00002F]X01000F]/005[K0P0000ANn`00G_/0009Nn`05001Nn`00G_/00002G_/01@00G_/0
05kk00000UlK100000US6`00Ha]S6`00Hc/006<k00000V<k00@006Lk0000009WF`03001[F`00009[
F`04001[N`000002KgX01000LgYcNP000gMi00D007NH001gN000009kU`03001kMW]f009kMP03001o
MGme009oM@05001oM7mdOg@00003Oe@00`00Oe=oD`02Oe<01@00Oe=oDgmC00000glc0P0000=k=000
Nc@00W/d00H007LEMaD007LE0002L_D01000K_I^mP000V[G00<006[G00000VJg10000Ujh00D005jH
001JV000009JV00<001FN000EWP0059H001>F@00CST004Xi0P0000<mn00000000P0000<M=`000000
400000HMo000000Z?000;Sd300002cYm000003jM0012W@00AYd004Jm00000TJm0P0000Y:_000B[`0
04jl001>_000C]`0009>g00?001>g000C]`005;L001Bg000D]`005;L001Bg000009Bg00;001Bg000
D]`005;L001Bg000D]`00002D]`00`00E]`00002E]`02`00E]`005KL001Fg000E]`005KL00000UKK
00d005KK001Ff`00E]/005KK001Ff`00E]/00002E]/00`00E]/00002E]/01P00E]/005KK001Ff`X0
0008E]/005KK001Ff`00E]/0009Ff`03001Ff`0001aoo`<008aoo`00FGoo00<007ooOol09goo00<0
07ooOol0ogoo=7oo0P0000D@0000900002`200800003=0<0000000@00008?2@003`T0010A000@4@0
0094I0030014I@0000<00004E>H005T60003GBH01@00IHQUR6F800000VVW00D006gY001aj00000Af
:@03001fBWI:00P0009nZP03001nZ00000@002Ioo`H00008E[X005Jj001F^P00E[X0009FVP03001F
V@00009FV@0C001FV@00EYT005JI001FN@00EWP005Ih001FN000EWP005Ih00000UIG01D005IG001F
E`00EUL005IG001FE`00ESH005Hf001F=P00ESH005Hf00000UHf00L005Hf001F=P00ESH00002ESH0
3@00ESH005Hf001F=P00ESH005Hf001F=P00009F=P0;001F=P00ESH005Hf001F=P00EUL00002EUL0
0`00EUL0000200001Eig001NMeig00000Uig00T005jG001NV000GYP005jH00000UjH00D005jH001J
V@00009J^@03001J^EZi00<00004G[T005ji0002G]T01@00G]X005kJ00000UkJ00L005kJ001NfP00
G]X00002F]X00`00F]X0000300002ekj001Nnekk001Nn`00G_/005kk00000Ukk00H005kk001Nn`00
G_/400000f<K001S6`02Ha/01@00Ha/006<k00000V<k00H006<k000006Lk0002Ie/00`00Je/00002
Je/20002KgX01`00KgX007=j001cN@0000=gN@08001gN7Mh001kU`00NgL000=kMP03001oMGme009o
M@05001oM7mdOg@00003Oe@00`00Oe=oD`02Oe<01@00Oe=oDgmC00000glc0P0000=k=000Nc@00W/d
00@007LEMaD0009g5@<0009^mP06001Zef[G001Ze`000VJg00/006:g001R^000G[P005jH001JV000
009JV00>001FN000EWP0059H001>F@00CST004Xi00126@800003=KP002Uh010000031GX0000000<0
008Z?0800003<Ud0000000@00004@Yd004JMAYd20002A[d06@00B[d004Zl001:_000C[`004jl001>
g000C]`004kL001>g000D]`005;L001Bg000009Bg005001Bg000D]`00002D]`03@00D]`005;L001B
g000D]`005;L001Fg000009Fg00;001Fg000E]`005KL001Fg000E]`00002E]/02@00E]/005KK001F
f`00E]/00002E]/02000E]/005KK001Ff`00E]/800001EKK001Ff`00E]/00P0000YFf`00E]/005KK
001Ff`00E]/0009Ff`03001Ff`0001Yoo`80009oo`03001oogoo08Yoo`00FGoo00<007ooOol09goo
00<007ooOol0ogoo<goo1P0000</0P0000000P0000Dh0`00>0<003`T00800006?2@004140010A000
0TAT00L004AUA6D004R5001<Q@0200002ET6001M9UdV001Q9P00IHP00003JJL20003LNP01000MRUf
:GHY0`0000EfB@00NVUjJ@00009jR@800004OZX007jXOZP4000POol6000035Jj001F^P00E[X005Jj
001F^P00E[X0009F^P03001FVP00009FV@0E001FV@00EYT005JI001FV@00EWT005Ih001FN000EWP0
05Ih001FN000009FE`0E001FE`00EUL005IG001FE`00EUL005Hf001F=P00ESH005Hf001F=P00009F
=P0F001F=UHf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf0002ESH02@00ESH005Hf
001F=P00ESH00002EUL00`00EUL00002000015ig001NM`000eig00T005ig001NU`00GYP005jH0000
0UjH00L005jH001NV000FYT00002F[T02000F[T00000G[T005ji0002G[T01@00G]T005kJ00000UkJ
00L005kJ001NfP00G]X00002G]X4000015kJ001NnP000Ukj00D005kk001Nn`00009Nn`08001Nn`00
G_/005kk001Nn`800004Ga/006<K0002Ha/01P00Ha]S6`00Ha/0009S>`@00007Ic/006LkIc/006MK
00000V]K0P0000E_FP00KgY_NP00009_NP05001cNG=iLgT00002MgT01P00MgQgN000NiL0009kM`05
001kMP00NgH00002OgD02`00NgD007md001oE000Oe@007mD00000WmC0P000gmC00<007lcOc<00Wlc
00@007/dNc@0009k=004001g5GLE0002MaD200001g;f001^mVkf001Ze`00009Ze`<00008H[L006:h
001N^000GYP0009JV00@001JV000EWP005Ih001BF000CUT004hi001:>@00@QT200000cFh00000002
00000a3f0000000>00026M/200000bXl000^?@0200000cIm000jO@03000054:M0016W@00A[d004Jm
001:_@00B[`004Zl001>_000C[`004kL0002C]`03`00C]`004kL001Bg000D]`005;L001Bg000D]`0
0002D]`02`00D]`005;L001Bg000D]`005;L00000U;L00l005KL001Fg000E]`005KL001Fg000E]`0
05KL00000UKK00<005KK00000UKK00@005KK001Ff`X0000:E]/005KK001Ff`00E]/005KK0002E]/3
00003eKK001FfeKK001Ff`00E]/005KK001Ff`00E]/0000OOol00`00Oomoo`29Ool005Qoo`03001o
ogoo02Uoo`03001oogoo0?mooc5oo`P00003=08003@30080000>>0<003`T000l9000?2@004140010
A000A6@00094I@030018Q@00009<Q@06001<Y000001M9P000f4V00L006VWJJMYY`00JJH00003LNP0
0`00MRUf:@020003MTT01000NVUjJ@000WZ900H007Z8001nZP00OZP4000IOol700001UKK001F^`00
E[X0009F^P0?001F^P00E[X005Jj001F^P00E[X005Jj001FVP00009FV@0E001FV@00EYT005JI001F
V@00EWT005Ih001FN000EWP005Ih001FN000009FE`0?001FE`00EUL005IG001FE`00EUL005Hf001F
=P00009F=P05001F=P00ESH00002ESH05@00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F
=P00ESH00002ESH01`00ESH005Hf001F=P00009F=P03001FE`0000800006GWL005ig001NM`000eig
00D005ig001NU`00009NV009001NV000GYP005jH001NV000009JV@@00004G[T005ji0002G[T01@00
G[T005kI00000UkJ00L005kJ001NfP00G]X00002G]X300001ekJ001NfUkJ001NnP00009NnP03001N
n`00009Nn`08001Nn`00G_/005kk001Nn`800009Ga/005lKGa/006<K001S6`00009S6`03001S6f<K
00<00003Ic/006Lk009W>`03001W>`00009WF`<000=_FP04001_NP00KgX20003LgT01@00MgT007Mh
00000WMh00L007]gNgMkM`00NgH00002NgH03@00OgD007]e001oM000Oe@007mD001oE000009oD`07
001oE000Oe<007ld00000glc00D007/dNc@007/d0080009g5@04001g5GLE0002L_H01P00K_I^mP00
J]L0009Ze`03001Ve`00009R]`80009N^00F001NV000FYP005ZH001FN000EWP0059H001>F@00CST0
04Xi00126@00?OP2000012fH0000013f0`0000<04@0000002`0000PIf`00000Z?000;Sd0039M0P00
00<jO@00?Yd01@0000A6_@00A[e6_@800006B[`004Zl001>_0000Tjl00l004kL001>g000C]`004kL
001Bg000D]`005;L00000U;L00l005;L001Bg000D]`005;L001Bg000D]`005;L00000U;L00D005KL
001Fg000009Fg00:001Fg000E]`005KL001Fg000E]/:000015KK001Ff`000UKK00/005KK001Ff`00
E]/005KK001Ff`00009Ff`0@001Ff`00001Ff`00E]/005KK001Ff`00E]/005KK0002E]/00`00E]/0
000NOol00`00Oomoo`29Ool005Qoo`03001oogoo02Uoo`03001oogoo0?mooc5oo`@00003:0400302
00800007=0<003P3000h0`00?2@00P0000Hl9000@4@004140002A6@01@00A6D004R500000Tb500H0
04bTC:@0052T0003HBH01@00HDD006VW00000VVV00@0077XLNQaj0<00003MPP007I900=fB@06001j
JGYY001jR@000WZ80P0000=nZ00000000P004goo1P0000AFf`00E]/0009Ff`0F001FfeKK001F^`00
E[X005Jj001F^P00E[X005Jj001F^P00E[X005Jj0002EYX00`00EYT00002EYT04`00EYT005JI001F
V@00EWT005Ih001FN000EWP005Ih001FN000009FE`0E001FE`00EUL005IG001FE`00EUL005Hf001F
=P00ESH005Hf001F=P00009F=P0E001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F
=P00009F=P05001F=P00ESH00002ESH00`00ESH0000200001UYf001NM`00GWL0009NM`08001NMeig
001NM`00GYL0009NV007001NV000GYP005jH00000UjH0`0000EN^@00G[UN^@00009N^@05001N^@00
G[T00002G]T01@00G]X005kJ00000UkJ1@0000ENfP00G]YNfP00009NfP05001NnP00G_X00002G_/0
2000G_/005kk001Nn`00G_/200002Ekk001O6elK001O6`00Ha/00002Ha/00`00Ha]S6`0300001FLk
001W>fLk00000VLk00@006Lk001WF`80009[FP04001_FVmJ0002KgX01000LgUcN@000g=i00@007Mh
MgP0009gN003001kMg]g009kM`0?001kMW]fNgH007me001kM@00Og@007mD001oE000009oE009001o
D`00Oe@007mC001o=00000=o<`05001k=7/d001k=0020002MaD01000MaEg5@000W;f00@006kfK_H0
009Ze`<00004I]L006:gH[L20002G[P01@00GYP005ZH00000UZH00H005Ih001FN000DUP200002Dhi
001:>@00@QT003gh000e^00200000adg0000000400000`0?0000000600001@EI000AV`006M/01@00
00DbG@00=Wd003Ym00800004@Yd004:M@Yd700005TZl001:_000C[`004jl001>g000C]`004kL001>
g000D]`005;L001Bg0000U;L00D005;L001Bg000009Bg00=001Bg000D]`005;L001Bg000D]`005KL
00000UKL300000aFg000E]/005KK001Ff`00E]/005KK0002E]/01@00E]/005KK00000UKK00X005KK
001Ff`00E]/005KK001Ff`80000<E]/005KK001Ff`00E]/005KK001Ff`000UKK00<005KK00007Woo
00<007ooOol0RGoo000KOol4000>Ool3000<Ool:000BOol00`00Oomoo`0ZOol00`00Oomoo`3oOol_
Ool3000012@0000003020P0001@d0`00>0<003P3000l9000?2@003`T0010A000@4@004AT0014I@00
0TR500<004b500000TbT00L0052T001D``00HBH00003HDD00`00JJIYYP02JJH300000g7W001f2002
MPP01@00MTUfBGI900000WYY00@007Z9NXT0009jR003001nZ00000<000eoo`H00006E]/005KK001F
f`000UKK00<005KK00000UKK01<005KK001F^`00E[X005Jj001F^P00E[X005Jj001F^P00E[X00002
E[X00`00EYX00002EYT05@00EYT005JI001FV@00EYT005Ii001FN000EWP005Ih001FN000EWP00002
EUL05@00EUL005IG001FE`00EUL005IG001F=P00ESH005Hf001F=P00ESH00002ESH04`00ESH005Hf
001F=P00ESH005Hf001F=P00ESH005Hf001F=P00009F=P03001F=P00009F=P04001F=P00ESH30000
1UYF001JMP00GWL0009NM`03001NM`00009NM`03001NM`00009NU`07001NV000GYP005jH00000UjH
0`0000AN^000G[T000=N^@05001N^@00G[T00002G[T01@00G]T005kJ00000UkJ0`0000ANfP00G]X0
009NfP03001NfP00009NfP03001NnP00009NnP06001Nn`00G_/005kk100000MNn`00G_]Nn`00Ga/0
0002Ga/01P00Ha/006<K001S6`800007Hc/006LkIc/006Lk00000VLk00H006LkIc/006]K0002JeX0
1@00KeY_FP00KgX00P000g=i00@007=iLgT0009gN005001gN000MgL00003NgL00`00NgIkMP02NgH0
1@00NgEkMG]e00000gmD00@007mDOeAoE080009oE005001oD`00Oc@00002Oc<20002Nc@01@00Nc@0
07/D00000WLE0`000W;f00@006kfK_H0009Ze`03001Ze`00009Ve`0;001R]`00H[P005jh001NV000
FYP00002FYP02P00EWP005Ih001BF000CUT004hi0P0000E26@00?OP003Fh00D000031;D0000000P0
00040=L000001ET2000011WK000002HL100000lfO@00>Wd003jM0012W@00@Yd004JM0016_@00A[`0
2@0001=>g000C]a>g000C]`004kL001Bg000D]`005;L001Bg000D]`00002D]`B00002UKL001Fg000
E]`005KL001Fg0000UKL00T005KK001Ff`00E]/005KK00000UKK00<005KK00000UKK00d005KK001F
f`00E]/005KK001Ff`00E]/00002E]/02@00E]/005KK001Ff`00E]/00002E]/01`00E]/005KK001F
f`0001ioo`03001oogoo08Uoo`006Goo20002goo1@002goo2P004Woo00@007ooOomoo`D002Eoo`03
001oogoo0?moobeoo`H0000;<08003@2000d0`00>0<003P3000l900=000014R5001<Q@000TbT00<0
052T00000UC30P000f550P000fVV0P00177W00@007H8MPP000=fB@04001jJGYY0002NXT01`00NXQj
R000OZP007Z600<000Ioo`H00006E]`005KK001Ff`000UKK00T005KK001Ff`00E]/005KK00000UKK
00L005KK001F^`00E[X00002E[X03@00E[X005Jj001F^P00E[X005Jj001F^P00009FVP0G001FV@00
EYT005JI001FV@00EYT005Ii001FN000EWP005Ih001FN000EWP00002EUL05@00EUL005IG001FE`00
EUL005IG001F=P00ESH005Hf001F=P00ESH00002ESH04@00ESH005Hf001F=P00ESH005Hf001F=P00
ESH005Hf00000UHf00<005Hf00000UHf00@005Hf001F=P<00006FUH005YF001JMP000Uig00D005ig
001NM`00009NM`0:001NMeig001NU`00GYP005jH0002GYP3000015jh001N^0000Uji00H005jiG[T0
05ji0002G[T01@00G[T005kI00000UkJ0`0000]NfP00G]YNfP00G]X005kJ001NfP00009NfP03001N
nP00009NnP04001Nn`00G_/2000015kk001Nn`000Ukk00<005kk00000UlK00H005lK001S6`00Ha/2
00001f<K001S>f<k001W>`00009W>`03001W>fLk00<0009[F`04001[FV]J0002KeX01000KgY_NP00
0W=i00D007=i001gN@00009gN009001gMgMgMgL007]g001kMP0000=kMP05001kMG]eNgD00003Oe@0
0`00OeAoE002Oe@01@00OeAoE7mD00000gld00D007lc001k=000009k=004001k57/D0002MaD20000
1g<E001bmW;f001^mP00009Ze`03001Ze`00009Ve`09001R]`00H[P005jh001NV000009JV0/00003
CST004Xi00800005?OP003Fh000]V003000010Be0000000A200000D0e`00000000fJ008000048O`0
0000;S`40002>Wd2000014:M0012WD:M0P0000Y6_@00A[`004Zl001:_000B[`0009>_1H0000:D]`0
05;L001Bg000D]`005;L0002D]`02`00D]`005;L001Fg000E]`005KL00000UKL00<005KL00000UKL
00/005KK001Ff`00E]/005KK001Ff`00009Ff`0?001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00
009Ff`09001FfeKK001Ff`00E]/005KK00X001ioo`03001oogoo08Qoo`006Goo0P0017oo0P002goo
1@003goo0P005Woo1000:Woo00<007ooOol0ogoo;7oo1@0000<X0@00<0800P0000<d0`0000001@00
00dl9000?2@003`T000l9000?2@0040S00108`04000014bT001@Y0000UC300H005BRE:8006550002
HB@01@00JJH006V50000177W00@007H8MPP000AfB@03001jJ@00009jR@03001jR7Z800<00003NXH0
000000L00006E_`005Kl001Fo0000UKL00/005KK001Ff`00E]/005KK001Ff`00009Ff`05001Ff`00
E]/00002E]/04`00E[/005Jj001F^P00E[X005Jj001F^P00E[X005Jj001F^P00009FVP0G001FV@00
EYT005JI001FV@00EYT005Ii001FN000EWP005Ih001FN000EWP00002EUL05@00EUL005IG001FE`00
EUL005IG001F=P00ESH005Hf001F=P00ESH00002ESH03@00ESH005Hf001F=P00ESH005Hf001F=P00
009F=P07001F=P00ESH005Hf00000UHf00<005Hf00000P0000IJEP00FUH005YF0002FWH01`00GWL0
05ig001NM`0000=NM`07001NM`00GYL005jH00000UjH0`0000AR^000G[P0009N^003001N^@00009N
^@03001N^@00009N^@03001N^@00009Nf@<0000;G]X005kJG]X005kJ001NfP00G]X00002G]X01@00
G]X005kj00000Ukj00H005kk000005kk0002G_/01@00G_/005kk00000Ukk00H005lK001O6`00Ha/2
00001f<K001S6f<K001S>`00009W>`04001W>`00Ic/20002Je/00`00Je/00002JeX01000KeX00000
0fmj00@007=iLgT0009gN@04001gN7Mh0003MgL00`00NgL00002NgH02@00NgH007]f001kM@00NgD0
0002Oe@00`00OeAoE002Oe@01@00OeAoE7mD00000gld00D007lc001k=000009k=004001k57/D0002
MaD01000LaEc5@000W;f00<006kfK_H00`000V[G00L006KG001R]`00H[P00002G[P00`00GYP00002
00002EZH001FN000EWP0059I001>F@0500000d8I00000002=KP300001a3f000000000140000?00T0
00031ET0000000<000049Q`00000<Ud300003CYm000nW@00@Yd004:M0016W@00A[d004Jl0080009:
_00C001:_000C[`004jl001>_000C[`004kL001>g000D]`005;L00000U;L00/005;L001Bg000D]`0
05;L001Bg000009Bg009001Bg000D]`005;L001Bg000009Fg009001Fg000E]`005KL001Fg000009F
g00;001Ff`00E]/005KK001Ff`00E]/00002E]/01`00E]/005KK001Ff`00009Ff`0:001Ff`00E]/0
05KK001Ff`00E]/8000015KK001Ff`000UKK00<005KK00007Woo00<007ooOol0R7oo000HOol20006
Ool2000:Ool5000?Ool2000FOol00`00Oomoo`0/Ool00`00Oomoo`3oOolZOol200000``0000T0002
00000c020000000300001CP3000h0`00>0@00P0000Xl9000?2@003`T000l9000@2<000908`040010
8`00@28400000eC3001DXP02E:830002HB@20003JHD01@00LNMaig7W00000WH82@0000AjR@00NXQj
R0H00007E_`005KlE_`005Kl00000UKl014005Kl001Fo000E]`005KK001Ff`00E]/005KK001Ff`00
009Ff`03001Ff`00009Ff`0E001Ff`00E[/005Jj001F^P00E[X005Jj001F^P00E[X005Jj001F^P00
009FVP09001FVEJI001FV@00EYT005JI0080000<EWT005Ih001FN000EWP005Ih001FN0000UIG01D0
05IG001FE`00EUL005IG001FE`00ESH005Hf001F=P00ESH005Hf00000UHf00L005Hf001F=P00ESH0
0002ESH03P00ESH005Hf001F=P00ESH005Hf001F=P00ESH400001UYF001JEP00FUH0009JEP09001J
MP00GWL005ig001NM`0000=NM`05001NM`00GYL00002GYP3000016:h001R^0000Ujh00D005jh001N
^@00009N^@03001N^@00009N^@03001N^Eji00<0000;G]T005kJG]X005kJ001NfP00G]X00002G]X0
1@00G]X005kJ00000Ukj00P005kj000005kj001Nn`000Ukk00<005kk00000Ukk00H005kk001O6`00
Ga/200001f<K001S6f<K001S6`00009S>`04001W>`00Ic/200001FLk001[Ff]K00000V]K00@006]J
JeX0009_FP05001_NVmj001cN@020002MgT01@00MgP007Mh00000gMg00d007]fNgIkMP00NgH007]f
001kM@00NgD00002Oe@20002Oe@20003Oe@01000OcAo=7ld0P000W/d00@007/dNc@0009k5004001g
5GLE0002LaD01000L_IbmP000Vkf00<006[G00000V[G00L006KG001R]`00H[P00002G[P300003eZH
001JV000EWP005Ih001BF@00CUT004Xi0016>@040002=KP500000`Be0000000300000`0?00000003
00001@3G000000003IX00`0000<V7000;S`00P0000<fG@0000000`000112W@00@Yd004JM0016_@00
A[`004Zl001:_000B[`0009>_00:001>_000001>_000C]`004kL0002D]`02@00D]`005;L001Bg000
D]`00002D]`02@00D]`005;L001Bg000D]`00002D]`02`00D]`005;L001Fg000E]`005KL00000UKL
00l005KL001Fg000E]/005KK001Ff`00E]/005KK00000UKK00L005KKE]/005KK001Ff`0<00002UKK
001Ff`00E]/005KK001Ff`000UKK00D005KK001Ff`0001ioo`03001oogoo08Qoo`0067oo0P001Woo
0P002goo0`0047oo0P005Woo00<007ooOol0;7oo00<007ooOol0ogoo:Goo2@0000/d0`00>0<003P3
000h0`00>0@003`T00800008?2@003`T000l9000@2<000908`0800108`00@280040Q001000<00003
E:800000009DX0<0009Q8P03001YQFV500L00003MPH007HW009f9`03001jA`0000D00006Ead005Km
001Fo0000UKl010005KlE_`005Kl001Fo000E_`005Kl001Fg000E]/0009Ff`07001Ff`00E]/005KK
00000UKK00/005KK001Ff`00E]/005Jk001F^P00009F^P0>001F^P00E[X005Jj001F^P00E[X005Jj
001FVP`0000<EWT005Ih001FN000EWP005Ih001FN0000UIG0P00019FE`00EUL005IG001FE`00ESH0
05Hf001F=P00ESH005Hf0002ESH04@00ESIF=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH01P00
00QJ=P00FUH005YF001JEP000UYF00T005YF001JMP00GWL005ig00000Uig00P005igGWL005ig001N
U`000UjH00D006:h001R^000009R^005001N^000G[P00002G[T00`00G[T00002G[T00`00G[UN^@03
00002EkI001NfEkI001NfP00G]X00002G]X01`00G]X005kJ001NfP00009NfP@00004G_X005kj0002
G_/00`00G_/00002G_/01P00G_/005kk001O6`800007Ha/006<KHa/006<K00000V<K00<006<k0000
0VLk00<006Lk00000VLk00L006]KJe/006]K001[FP020003KeX01000KgY_NP000W=i00@007MiMgT0
00=gN004001gMgMg0004NgH01P00NgIkMP00NgD0009kM@80000;Oe@007mDOe@007mD001oE000Ne@0
0003Oc@01@00NcAk=000Nc@00P000W/D00@007LE000000=c5@03001bmP00009^mP08001Zef[G001Z
e`00I]L0009R]`03001R^00000800004GYP005ZH0002FYP01P00EWP005Ih001BF@80000;BST004Hi
00126@00?OP003Fh000]V00300000`Be0000000600000`0B0000U@04000010fJ000001gK0P0000<^
?000<Ud00P000SYm00@003im00000092W@800006A[d004Jl001:_0000TZl01<004Zl001>_000C[`0
04jl001>_000C]`004kL001Bg000D]`00002D]`02`00D]`005;L001Bg000D]`005;L00000U;L00l0
05;L001Bg000D]`005;L001Fg000E]`005KL00000UKL00D005KL001Fg000009Ff`0:001Ff`00E]/0
05KK001Ff`00E]/8000025KK001Ff`00E]/005KK0002E]/02@00E]/005KK001Ff`00E]/00002E]/0
0`00E]/00002E]/00`00E]/0000MOol00`00Oomoo`28Ool000Aoo`d000Ioo`8000Qoo`8001eoo`80
01Ioo`03001oogoo02eoo`03001oogoo0?moobMoo`H00003<04003@200800004>0<003P3>0<20000
63P4000l9000?2@003`T000l9000?2@0040S00108`00@2<0040R00108@00@000009000<00005E:00
0000D6000002HB8400000fUS001aa@02LLD00`00MPIf1P0600001ULM001G7@00Ead0009G7@07001F
o@00E_`005Kl00000UKl00<005Kl00000UKl014005Kl001Fo000E]`005KK001Ff`00E]/005KK001F
f`00009Ff`05001Ff`00E]/00002E]/00`00E[/0000A00002e:J001BVP00DWT0059i001BN@00DWT0
2`0000YFN000EUMFE`00EUL005IG001FE`800006EUL005Hf001F=P000UHf00D005Hf001F=P00009F
=P0<001F=P00ESH005Hf001F=P00ESH005Hf1@0000AF=P00ESH0009J=P05001JEP00FUH00002FUH0
2@00FUH005YF001JMP00GWL00002GWL00`00GWL00002GWL00`00GWL00002GYL300002F:h001R^6:h
001R^000G[P00002G[P00`00G[T00002G[T01000G[T005ji0P0000URf@00G]UNf@00G]T005kJ0000
0UkJ00P005kJ001NfP00G]X005kJ100000ENnP00G_YNnP00009NnP03001Nn`00009Nn`06001Nn`00
G_/005kk0P0000MS6`00Ha]S6`00Ha/00002Ha/01P00Ha/006<k001W>`80009W>`03001W>`00009[
F`04001[F`000002KeX01@00KeY_FP00KgX00P000W=i00@007MiMgT000=gN005001gM`00NgL00003
NgH01@00NgIkMW]f00000g]e0P000WmD00T007mD001oE000Oe@007]D00000gld00P007/dNc@007/d
001k=0000W/D0P0000Eg5@00LaEc5@00009bmP<0009Ze`05001Ze`00I]L00002H[L3000015jh001N
V0000UZH00`005ZH001FN000EWP0059I001>F@00BST200001d8I00000000=KP002fH00H0000305<0
000A00P000050AP00000000E^`050000139M000fG@000SYm0P0000<nO@0000000`0000=6_@00A[`0
0P000TZl00l004Zl001>_000C[`004jl001>_000C]`004kL00000U;L00l005;L001Bg000D]`005;L
001Bg000D]`005;L00000U;L00/005;L001Bg000D]`005;L001Fg000009Fg007001Fg000E]`005KL
00000UKL300000aFf`00E]/005KK001Ff`00E]/005KK0002E]/01@00E]/005KK00000UKK00/005KK
001Ff`00E]/005KK001Ff`00009Ff`03001Ff`0001ioo`03001oogoo08Moo`0017oo3@001Woo0P00
27oo0P007Goo0P005Woo00<007ooOol0;Goo00<007ooOol0ogoo9goo100000h/0000000d0P00=0<0
03P3000h0`00>0<003P40P0001@l9000?2@003`T000l9000@2<0040S00108`00@280040Q00100000
0T0000<003`0?0000`000U1P0`000V3P00@006USJF=YH`H00006Dch005<n001G?P000ULM00L005LM
001G7@00Ead00002E_d01@00E_`005Kl00000UKl01D005Kl001Fo000E_`005Kl001Fg000E]/005KK
001Ff`00E]/005KK00000UKK2P00011F^`00E[/005Jj001F^P00E[X005JJ001FVP00EYX0009BVP0D
001BVP00DWT0059i001BN@00DWT0059i001BF@00DUP0059H001BF0P0000BEUL005IG001FE`00EUL0
05Hf001F=P00ESH005Hf001F=P000UHf00H005Hf001F=P00ESH7000025Hf001F=P00ESH005Hf0002
FSH00`00FUH00002FUH02@00FUH005YF001JEP00FWH00002GWL01@00GWL005ig00000Uig00<005ig
GWL00`0000UR]`00H[QR^000H[P006:h00000Ujh00D005jh001N^@00009N^@@00009H]T006;IH]T0
05kI001Nf@00009NfP08001NfP00G]X005kJ001NfP800004G_X005kj0002G_X02000G_YNnP00G_X0
05kk0002G_/01000G_/005kk0P0000MS6`00Ha]S6`00Ha/00002Ha/01P00Ha/006<K001S>`80009W
>`03001W>`00009W>`06001[Ff]K001[FP000fmJ00@006mJKeX0009cN@07001cN@00MgT007Mh0000
0gMh00T007]gNgMkM`00NgH007]f00000W]f00<007]eNgD00W]e00<007mDOe@00P000WmD00D007mD
001kE000009o=08000=k=0800004Nc@007/DNa@200001GLE001c5G<E00000W;f00<006kf00000V[G
00<006[G00000VKG00D006:g001R^000009N^00B001NV000FYP005ZH001FN000EWP0059I001>F@00
BST004Hi0P0000<mn@0000001@0000@<mP000000D`<00006014000000180002E1`0000<Mf`000000
0P0000<bG@0000000SYm00L003im000004:M0012W@07000014Zl001:_0000Tjl00X004jl000004jl
001>g000C]`0009Bg00;001Bg000D]`005;L001Bg000D]`00002D]`01`00D]`005;L001Bg000009B
g006001Bg000D]`005KL300000YFf`00E]/005KK001Ff`00E]/0009Ff`07001Ff`00E]/005KK0000
0UKK00P005KK001Ff`00E]/005KK0P0000YFf`00E]/005KK001Ff`00E]/0009Ff`05001Ff`00E]/0
000NOol00`00Oomoo`27Ool000Aoo`d000Ioo`8000Qoo`8001eoo`8001Ioo`03001oogoo02ioo`03
001oogoo0?moobEoo`<00004:00000000002=08200002CP3000h0`00>0<003P4000l900E00000d00
000l000200000cP0000000020002C20700001TmO001CG`00Deh0009C?P0;001C?P00Ech005LM001G
7@00Ead00002Ead01@00E_d005Kl00000UKl010005Kl001Fo000E_`005Kl001Fo000E]`005KK001F
f`T0000:E]/005Jk001F^`00E[/005Jk0002E[/03`00E[/005Jj001F^P00E[X005JJ001FVP00EYX0
0002DYX02000DYX0059i001BN@00DWT20000359i001BF@00DUP0059H001BF000DSP0009>=`03001B
=`0000H0000<EUL005Hf001F=P00ESH005Hf001F=P000UHf1`0000iF=P00ESH005Hf001F=P00ESH0
05Hf001F=P000eXf00d005YF001JEP00FUH005YF001JEP00FWH00002GWL01@00GWL005ig00000eig
00D005ig001RU`00009R]`05001R^000H[P00002H[P01@00G[P005jh00000Uji0`0000ERf@00H]UR
f@00009Rf@03001Nf@00009Nf@05001NfP00G]X00002G]X300002Ekj001NnUkj001NnP00G_X00002
G_X01@00G_X005kk00000Ukk00H005kk000006<K0002Ha/00`00Ha/00002Ha/01P00Ha/006<K001S
6`800005Ic/006LkIc/00002Ic/01000Ic/006]K0P000V]J00D006mJKeX006mJ0080009cN@04001c
NG=i0003MgP01000MgQgN0000g]g00T007]f001kMP00NgH007]f00000g]e00D007mDOeAoE00000=o
E009001kE7]DNe@007ld001k=000009k=004001k=7/d0002Na@01000MaEg5@000W<E00@007;fL_H0
009^mP03001Ze`00009Ze`03001Ve`000080000HH[P005jhG[P005jH001JV000FYP005Ih001FN000
DUT004iI001:>@00AST0048I0P000SGH0P0000@QE`00000<mPh000051ET00000000Mf`0200003BXL
00000000=Ud003Ym000nO@00?Wd004:M00800005AY`004JL0016_00<00002Tjl001>g000C]`005;L
001Bg0000U;L00H005;L001Bg000D]`B000015;L001Fg0000UKL00/005KL001Fg000E]/005KK001F
f`00009Ff`03001Ff`00009Ff`0;001Ff`00E]/005KK001Ff`00E]/00002E]/00`00E]/000020000
2UKK001Ff`00E]/005KK001Ff`000UKK00H005KKE]/005KK000MOol00`00Oomoo`27Ool001Moo`80
00Qoo`8001eoo`8001Ioo`03001oogoo02ioo`03001oogoo0?moobAoo`80000=80000000000`0@00
=08003@3000h0`00>0<01P00014h0`00>0<003P3000h0`00>08003@2000d0@00<00002`000800003
8000000000`00093O`0;0017O`00Bgl004mO001CG`00Deh00002Dch03@00Dch005Ln001G7@00Ead0
05LM001G7@00009Fo@0:001Fo000E_`005Kl001Fo000E_`:000025KK001Ff`00E]/005KK0003E]/0
6@00E[/005Jk001F^`00E[/005Jk001F^`00E[X005Jj001F^P00EYX005JJ001FVP00009BVP0B001B
VP00DWT0059i001BN@00DWT0059i001BF@00DUP0059H0P0000aB>000CSM>=`00DSL0058g001B=`00
DSL@000045Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P000UHf00<005Hf00000UXf00/005YF
001JEP00FUH005YF001JEP00009JMP07001NM`00GWL005ig00000eig0`0000URU`00H[MR]`00H[P0
06:h00000V:h00<005jh00000Ujh0`0000ARf@00H]T000=Rf@03001Rf@00009Nf@05001Nf@00G]X0
0002G]X300002f;j001NnUkj001NnP00G_X005kj00000Ukj00<005kj00000Ukk00P005kk000006;k
001S6`000V<K00T006<KHa/006<K001S6`00Ha/00P0000EW>`00Ic]W>`00009W>`04001W>`00Ic/2
0002JeX01000JeY[FP000VmJ00H006mIKeT007=i0002LgT02@00MgQgN7Mh001gN000MgL00003NgL0
2000NgIkMP00NgH007]f0002NgD00`00NeD00002Oe@01@00OeAoE7mD00000g]D00D007ld001k=000
009k=007001k=7/dNc@007/D00000gLE00<007<ELaD00`000Vkf00<006[G00000V[G0`0000UV^000
H[QR^000G[P005jH00000UZH00X005ZH001FN000EWP0059I001>F@800003AST0048I0080008ef0D0
00063?H0000005<0000A3`0000<Uo00000000Rhl0P000SYm0P0000TnO@00@Yd004:M0016W000AY`0
0P000TZl00P004Zl001:_000C[`004jl500000ABg000D]`0009Bg00;001Bg000D]`005;L001Bg000
D]`00002D]`02@00E]`005KL001Fg000E]`00002E]/02@00E]/005KK001Ff`00E]/00002E]/02`00
E]/005KK001Ff`00E]/005KK00000UKK00<005KK00000P0000iFf`00E]]Ff`00E]/005KK001Ff`00
E]/005KK10007Woo00<007ooOol0QWoo000GOol20008Ool2000MOol2000EOol00`00Oomoo`0`Ool0
0`00Oomoo`3oOolQOol200001AP000000000;0000P000S@21P0000Dh0`00>0<003P30080000?>0<0
03P3000h0`00>08003@2000d0@00<00002`000800003800001P000l0000I@gl004Mo001;O`00Cel0
05=O001CGP00Dch005<n001G?P00Ead005LM001G7@00Ead03@0000YFg000E]`005KL001Fg000E]`0
009Ff`07001Ff`00E]/005KK00000UKK01L005Jk001F^`00E[/005Jk001F^`00E[/005Jj001F^P00
E[X005JJ001FVP00009FVP0_001BVP00DYX0059i001BN@00DWT0059i001BN@00DUT0059H001BF000
DUP0058h001>=`00DSL0058g001B=`00DSL0058g001B=P00DSH005Hf001F=P00ESH00002ESH03`00
ESH005Hf001F=P00ESH005Hf001F=P00ESH00002ESH01@00ESH005Hf00000UXf00T005YF001JEP00
FUH005YF00000UYF00L005Yf001NM`00GWL00002GWL01P00GWL00000HYL0009RU`05001R]`00H[P0
0002H[P01@00H[P005jh00000Ujh00D006;H001Rf@00009Rf@04001RfF;I0002H]T01@00G]T005kI
00000UkJ0`0000]RfP00H_YRnP00G_X005kj001NnP00009NnP03001NnP00009NnP@00004H_X006;k
0002Ha/02@00Ha]S6`00Ha/006<K001S6`0200001fLK001W>fLk001W>`00009W>`06001W>fLk001[
>P000V]J00D006]JJeX006mJ0080009_F@03001cNG=i00800003LgT007Mh009gN004001gMgMg0003
NgL01000NgIkMW]f0P000W]f00T007]e001kE@00Oe@007]E00000WmD00@007]DNeAkE080009k=004
001k=0000003Nc@00`00Na@00003MaD01P00LaEc5@00L_H0009^mP03001Ze`00009Ze`03001Ve`00
009V^005001R^000G[P00002GYP04000FYP005ZH001FN000EWP0059I001>F@00BST004Hi0P0000Dm
n@00=MP002fh00<000043?H0000005<300000`0A0000000700000`ej0000000300001BXL000^?000
<U`01P0000Y2W@00@Yd004JL0016W000A[`0009:_080000<B[`004jl001>_000C[`004jl001>_000
0Tjl00/005;L001Bg000D]`005;L001Bg000009Bg00?001Bg000D]`005;L001Bg000D]`005;L001B
g000009Bg003001Fg000009Fg00;001Fg000E]`005KK001Ff`00E]/00002E]/03`00E]/005KK001F
f`00E]/005KK001Ff`00E]/00002E]/01`00E]/00000E]/005KK00`00004E]/005KK000NOol00`00
Oomoo`26Ool001Moo`8000Qoo`8001eoo`8001Eoo`03001oogoo031oo`03001oogoo0?moob1oo`80
000560000000000/000500001CP3000h0`00>0<00P0000<h0`00>0<00P0000lh0`00>0<003P3000h
0P00=08003@1000`0000;0001P000Vje0P0000IZ]P00I[H006:G0002GYLL00003E;m001BoE;m001B
o@00D_`005;l001Bo000009Fg00A001Fg000E]`005KL001Fg000E]/005KK001Ff`00E]/00002E]/0
2@00E[/005Jk001F^`00E[/00002E[/03`00E[/005Jj001F^P00E[X005JJ001FVP00EYX00002DYX0
1000DYX0059i0P00011BN@00DWT0059i001BF@00DUP0059H001BF000DSP0009>=`80000BDSL0058g
001B=`00DSL0058f001B=P00ESH005Hf001F=P000UHf00T005Hf001F=P00ESH005Hf00000UHf00/0
05Hf001F=P00ESH005Hf001F=P00009J=P07001JEP00FUH005YF00000UYF00L005YF001JMP00GWL0
0002GWL01P00GWL00000HYL0009RU`05001RU`00H[L00002H[P01@00H[P006:h00000Ujh0`0000MR
f000H]URf@00H]T00002H]T01P00H]URf@00G]T0009Nf@<00009H]X006;JH]X006;j001NnP00009N
nP05001NnP00G_X00002G_X300001F;j001RnV;j00000V;k00<006<K00000V<K00@006<K001S6`80
0007Ha/006LKIa/006Lk00000VLk00@006Lk001W>`80009[>P04001[FV]J0002JeX01P00KeY_FP00
KeT0009cN@05001cNG=iLgT00002MgP02@00MgMgMgMg001kM`00NgL00002NgH03@00NgIkMW]f001k
M@00NeD007mD001kE@00009oE08000=kE008001k=7/d001k=000Nc@0009k=0800005MaD007LEMaD0
0002LaD01P00L_IbmP00K_H0009Ze`05001Ze`00I]L00002I[P00`00H[P00002G[P04P00GYP005ZH
001JV000EWP005Ih001BF@00CUT004Xi0016>@800005?OT003GH000]^00200000aTG0000000B0000
0agK000000020002;S`200000cIL000jO@0300000d:M00000002AY`01000AY`000000TZl01T004Zl
001:_000C[`004jl001>_000C[`004jl001>_000D]`005;L001Bg000D]`00002D]`01@00D]`005;L
00000U;L00d005;L001Bg000D]`005;L001Bg000D]`00002E]`03@00E]`005KL001Fg000E]/005KK
001Ff`00009Ff`07001Ff`00E]/005KK00000UKK00P005KK001Ff`00E]/005KK200000QFf`00E]/0
05KK001Ff`000UKK00D005KK001Ff`0001ioo`03001oogoo08Ioo`005goo0P0027oo0P007Goo0P00
5Goo00<007ooOol0<Goo00<007ooOol0ogoo7Woo0P0000<H000000000`0000@h0P00>0<h0`800003
>0<003P300800009>0<003P3000h0`00>0<003P300800003>08003@200L00003Na8007Kc009fl`04
001^]Fje0002J[H00`00I[H00002HYL01P00GYL005jG001NV080000F8]h00000000o7`00@al004LO
001;7`00Bah004lN001?7P00C_d005;m0002D_d06P00D_eBo@00D_d005;l001Bo000D_`005KL001F
g000E]`005KL001Fg000E]/005KK0002E]/00`00E]/00002E]/06@00E[/005Jk001F^`00E[/005Jk
001F^`00E[X005Jj001F^P00EYX005JJ001FVP00009BVP0:001BVP00DWT0059i001BN@00DWT20000
2U9I001BF000DUP0059H001B>0000Thg00H0058g001B=`00DSL20000358g001B=P00DSH005Hf001F
=P00ESH0009F=P0F001F=UHf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf0002FSH0
1@00FUH005YF00000UYF00T005YF001JEP00FWH005ig00000Uig0`000V:G00H006:GHYL006:G0002
H[L01@00H[P006:h00000V:h0`0000URf000H]QRf000H]T006;I00000V;I00@006;IH]T0009Nf@<0
0009H]T006;JH]X006;J001RnP00009NnP08001NnP00G_X005kj001NnP800005H_X006;jH_X00002
H_X01@00H_/006<K00000V<K00H006<K000006<K0002Ha/00`00Ia/00002Ic/01000Ic/006Lk0P00
0V/j00<006/j00000V]J00@006]J0000009_FP03001_FFmI00<000=cN@05001gN000MgP00002MgL0
1@00NgL007]g00000W]f00<007]fNgH00W]f00@007]ENeEkE@80009kE@04001oE0000003Ne@02000
NcAk=000Nc@007/d0003Nc@00`00MaD00002MaD01000LaD000000W;f00<006kf00000V[G0`000VKG
00<006Jh00000V:h01H005jh001NV000FYP005ZH001FN000EWP0059I001>F@00BST004Hi00126@80
008ef0D000033?H0000000/000050AP00000000E^`0200001b7l000Z7000;S`0039L00800003>Wd0
03im00D0000FAY`004JL0016_000B[`004Zl001:_000C[`004jl001>_000C[`004jl0002C[`03@00
D]`005;L001Bg000D]`005;L001Bg000009Bg00=001Bg000D]`005;L001Bg000D]`005;L00000U;L
00d005KL001Fg000E]`005KL001Ff`00E]/00002E]/01@00E]/005KK00000UKK00<005KK00002@00
00iFf`00E]/005KK001Ff`00E]/005KK001Ff`000UKK00<005KK00000UKK00<005KK00007Goo00<0
07ooOol0QWoo000GOol20008Ool2000MOol2000EOol00`00Oomoo`0aOol00`00Oomoo`3oOolLOol3
00001QP0000003@1000d0P80008h0`800009>0<003P3000h0`00>0<003P300800003>0<003P300L0
0004Oc8007/C0002Na800`00Na<00002M_<01000K[E^]@000VZf00<006Jf00000V:G00D005jG001N
U`00009NV0H0000B?al004<O00177`00Bal004/N001?7P00Cah004km001Bo@000U;m00/005;m001B
o@00D_`005;l001Bo000009Fg00?001Fg000E]`005KL001Fg000E]/005KK001Ff`00009Ff`0I001F
f`00E[/005Jk001F^`00E[/005Jk001F^`00E[X005Jj001F^P00EYX005JJ00000UJJ018005:J001B
VP00DWT0059i001BN@00DWT0059i001BF@00DUP20000159H001B>0000Thg01L0058g001B=`00DSL0
058g001B=`00DSH0058f001F=P00ESH005Hf001F=P00009F=P0C001F=P00ESH005Hf001F=P00ESH0
05Hf001F=P00ESH005Hf00000UXf00D005YF001JEP00009JEP07001JEP00FUH005Yf00000Uig00D0
05ig001RU`00009RU`06001RUf:G001RU`000V:g00D006:h001R^000009R^003001Rf000009Rf005
001Rf000H]T00002H]T00`00H]T00003H]T300002F;I001RfF;I001RfP00H]X00002H_X02000G_X0
05kj001NnP00G_X200001f;j001RnV;j001RnP00009RnP03001Rn`00009S6`08001S6`00001S6`00
Ha/0009S6`07001W6fLK001W>`00Ic/00P0000EW>P00JcY[>P00009[>P04001[FV]J0002KeX00`00
KeX00002KeT01000LgUcN@000g=i00@007MhMgP000=gM`08001kMg]g001kMP00NgH000=kMP05001k
EG]ENeD00003NeD2000017]D001kE7]D0P000g/d00@007/dNc@000=k=003001g5@0000=g5@<0009b
mP06001^mVkf001Ze`000V[G00<006KG00000VJh00L006:h001N^000GYP00002FYP02P00FYP005Ih
001FN000DUT004iI0P0000M6>@00@QT003gi000ef002000012Eh000000cf2`0000<0UP0000001@00
00<Mf`008O`00P0000L^?000<U`003IL000jO@0200000cil0012W005000014Jl001:_4Zl0P0000I:
_000C[`004jl0002C[`03`00C[`004jl001>_000D]`005;L001Bg000D]`00002D]`04@00D]`005;L
001Bg000D]`005;L001Bg000D]`005;L00000U;L00<005KL00000UKL00P005KL001Fg000E]/005KK
300000QFf`00E]/005KK001Ff`000UKK00L005KK001Ff`00E]/00002E]/01`00E]/005KK001Ff`00
009Ff`05001Ff`00E]/0000NOol00`00Oomoo`25Ool001Qoo`8000Ioo`8001ioo`8001Eoo`03001o
ogoo039oo`03001oogoo0?mooaYoo`D0000><0000000=08003P2000h0`00>0<003P3000h0`800003
>0<003P300H000=o<`03001o<Wlb009o<P03001k4`00009k4P03001k4`0000=fl`<0009Z]P08001V
]VJf001RU`00GYL0009NU`<00004GYP000000OX2000053lO00137`00Aal004/O001;7P00Cah004lN
001>o@00D_d005;m0002D_d05`00D_d005;l001Bo000D_`005KL001Fg000E]`005KL001Fg000E]/0
05KK00000UKK00d005KK001Ff`00E[/005Jk001F^`00E[/00002E[/08P00E[/005Jj001F^P00E[X0
05JJ001FVP00EYX005:J001BVP00DWT0059i001BN@00DWT0059i001BF@00DUP0059H0P0001]B>000
CSM>=`00DSL0058g001B=`00DSL0058g001B=P00DSH005Hf001F=P00ESH005Hf00000UHf01<005Hf
001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH00002FSH00`00FUH00002FUH02@00FUH005YF
001JEP00FWH00002GWL300001F:G001RUf:G00000V:G00P006:GHYL006:g001R^0000V:h0`0000MR
f000H]QRf000H]P00002H]T00`00H]T00002H]T01P00H]T00000H]T0009Rf@05001Rf@00H]X00002
H]X01@00H_X005kj00000Ukj0`0000MRnP00H_YRnP00H_X00002H_X00`00H_X00002H_/4000016<J
001S6`000V<K00H006<KHa/006LK0002Ic/00`00IcX00002IcX01`00JcY[>P00JcX006]J0080009_
FP03001_FVmJ00<000=cN@04001cNG=i0003MgP01000MgMgM`000g]g0P000W]f00D007]f001kEP00
009kE@04001kEG]ENeD20002Ne@01@00Ne@007/d00000W/d00D007/dNcAk=000009k=004001g5GLE
0002MaD01P00LaIc5P00L_H0009^mP<0009Ze`03001Ve`00009V^005001R^000G[P00002GYP?0000
24Hi000003gi000ef000;KP300000`cf0000000=00000`Di0000000300000b7l000Z700400001cIL
000jO@00?Wd003il00800092W0030016W00000H0000FB[`004jl001>_000C[`004jl001>_000C[`0
05;L001Bg000D]`005;L0002D]`01@00D]`005;L00000U;L00h005;L001Bg000D]`005;L001Bg000
D]`005KL3000015Ff`00E]]Ff`00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`03001FfeKK00<0
000:E]/005KK001Ff`00E]/005KK0002E]/01`00E]/005KK001Ff`0001ioo`03001oogoo08Eoo`00
67oo0P001Woo0P007Woo0P005Goo00<007ooOol0<goo00<007ooOol0ogoo67oo0P0000@X0000000`
00800004=08003P20002>0<200000cP3000h0`070004Oe801@00Oc=o<glc000017lb00<007/C0000
0W/B00<007/C00000gKc0P0000A^e@00J[H0009V]P03001RU`00009NU`<00005GYP005jH001JV009
00001T/O001;7P00Cah0009?7P0O001>o@00D_d005;m001Bo@00D_d005;l001Bo000D_`005KL001F
g000E]`005KL001Fg000E]/005KK00000UKK00<005KK00007P0000=BVP00DWT00P0002IBN@00DWT0
059i001BF@00DUP0059H001BF000DSP004hg001B=`00DSL0058g001B=`00DSL0058f001B=P00ESH0
05Hf001F=P000UHf01D005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf00000eXf
00/005YF001JEP00FUH005YF001JEP00009JMP05001NM`00HYH00002HYL01P00HYMRU`00HYL0009R
U`03001R]`00009R^0<00007H[P006;HH]P006;H00000V;H00D006;I001Rf@00009Rf@800004H]T0
06;I0002H]T00`00H]T00002H]X01@00H]X006;j00000Ukj0`0000MRnP00H_YRnP00H_X00002H_X0
0`00H_X00002H_X300001F<J001S6V<J00000V<K00<006<K00000V<K00@006LK001W>`80009W>P03
001W>P00009[>P04001[>P000002JeX00`00KeX00002KeX01000LeUcF@000W=i00D007=i001gN000
009gN005001gM`00MgL00002NgL03@00NgIkMW]f001kMP00NeH007]E001kE@0000=kE@08001kE7]D
001kE000Nc@0009k=006001k=7/dNc@007/d0P000WLE00@007LEMaD0009c5P03001bmP00009^mP03
001Ze`00009Ze`08001VefKG001V^000H[P0009N^0<0000=FYP005ZH001FN000EWT0059i001>F@00
BUT0100000Dmn@00=MP002fh00D000031;D0000000h000055I/001gK000Qo00200000bhl00000002
00004CYm000nO@00?W`004:L0012W000AY`004JL001:_000B[`02`00019>_000C[a>_000D]`005;L
001Bg000D]`005;L001Bg000D]`A000035;L001Fg000E]`005KL001Ff`00E]/0009Ff`09001Ff`00
E]/005KK001Ff`00009Ff`07001Ff`00E]/005KK00000UKK0`0000YFf`00E]/005KK001Ff`00E]/0
009Ff`07001Ff`00E]/005KK00007Woo00<007ooOol0QGoo000IOol20004Ool2000KOol300000goo
0000000EOol00`00Ool00002000aOol00`00Oomoo`3oOolFOol3000032P000000300000d0@00=080
03P2000h0`H000=oM004001oDgmC0004Oe801000Oc=o<glc0P000Wlb00T007/CNa=k4`00Na8007/C
00000gKc00@006kEK]D0009Z]P05001V]P00HYL00002GYL01@00HYL005jH00000UjH00<005ZH0000
1@0000<bg`000000:P0001YB^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:K001BVP00DYX0
05:J001BVP000Tij00<004ij00001P0000=BN@00DWT00P0000YBF@00DUP0059H001BF000DSP0009>
=`80000BDSL0058g001B=`00DSL0058f001B=P00ESH005Hf001F=P000UHf014005Hf001F=P00ESH0
05Hf001F=P00ESH005Hf001F=P00009F=P03001F=P00009J=P09001JEP00FUH005YF001JEP00009J
EP03001JMP0000800005HYH006:GHYL00002HYL02000HYMRU`00HYL006:g0002H[P00`00I[P00002
H[P00`00H]P00002H]P01@00H]P006;I00000V;I0`000V;I00H006;IH]T006;I0002H]T01@00H]X0
06;J00000V;j0`0000MRnP00H_YRnP00H_X00002H_X01P00H_X006;j001RnP800005HaX006<JHaX0
0002HaX01@00Ha/006<K00000V<K00H006LK000006Lj0002IcX00`00IcX00002JcX200001F]J001[
FV]J00000VmJ0`000W=I00D007=iLgUcN@00009gN005001gN7MhMgP00002MgL01000NgMkM`0017]f
00P007]FNeH007]E001kE@000g]E00<007]DNe@00P000W/d00D007/d001k=@00009k=008001k=000
McD007LE001g5@80009c5P06001bmW;f001^mP000V[G00<006[G00000VKG00<006Jh00000V:h0`00
015NV000FYP005ZH001FN000EWT0059i001>F@00BUT004Hi00@00003=MP002fh008000047EL00000
1;DA00001QFK0000027l000Z70800005<S`00000000jO@020002?W`20002@Y`03P00AY`00000B[`0
04Zl001:_000B[`004jl0002C[`00`00C[`0000A00003U;L001Bg000D]`005;L001Bg000D]`005;L
0002D]`02`00D]`005KL001Fg000E]`005KK00000UKK00<005KK00000UKK00d005KK001Ff`00E]/0
05KK001Ff`00E]/00002E]/00`00E]/00002000025KK001Ff`00E]/005KK0002E]/00`00E]/00002
E]/01@00E]/005KK00007Woo00<007ooOol0Q7oo000IOol8000KOol6000EOol2000eOol00`00Oomo
o`3oOolCOol200000b00000X000200000c00000d0@0700001GnE001oU7nD000017md00<007mCOe<0
0P000gmB00@007lcOc=o<`80009o<P09001k4g/CNa<007/B001k4`0000=fl`04001^eFkE0002J[H0
0`00I[H00002HYL300002V:G001NV5jH001NV000FYP005Yh1@0000Pbg`00000004;n0016oP000TKn
01l004[n001:o@00C]d004kM001>g@00C]d005;L001Bg000D]`005;L001Bg000D]`005;L001Bg000
D]/00002D[/05`00D[]B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:K001BVP00DYX00P00
0U:J00X004ij001>NP00CWX004ij001>F@P00008DUP0059H001BF000DSP0009>=`04001B=`00DSL2
00003U8g001B=`00DSH0058f001F=P00ESH005Hf0002ESH03`00ESH005Hf001F=P00ESH005Hf001F
=P00ESH00002ESH01@00ESH005Hf00000UXf00T005YF001JEP00FUH005YF00000UYF0`0000MRMP00
HYIRUP00HYL00002HYL01P00HYMRU`00HYL0009R]`<00007I[P006:hH[P006;H00000V;H00<006;H
00000V;I0`0000=Rf@00H]T00V;I00<006;I00000V;I00D006;I001RfP00009RfP<00007H_X006;j
H_X006;j00000V;j00H006;j001RnP00H_X200001f;j001S6V<J001S6P00009S6P03001S6`00009S
6`06001S6`00001W6P000VLj00<006Lj00000VLj0P0000M[>P00JeY[FP00JeX00002KeX01000KeU_
F@000W=I00@007=iLgT000=gN004001gN7Mh0002MgL01@00NgL007]g00000g]f00@007]FNeIkEP80
009kE@04001kE@000003Ne@02000NcAk=000Nc@007/e0003Nc@2000017Le001g5GLE0`000W<F00<0
07;fL_H00`000V[G00H006[GJ]L006KG0002I[P300005F:h001NV000FYP005ZH001FN000EWT0059i
001>F@00BUT004Hi00126@0400000bfh000UN00200000`cf0000000=00001PUI000001FK000Mf`80
0003:Q`002hl00800003=U`0000000<0000=?W`004:L0012W000AY`004JL001:_000B[`00P000TZl
01<004jl001>_000C[`004jl001>_000C[`005:l001Bg000D]`00002D]`03@00D]`005;L001Bg000
D]`005;L001Bg000009Bg005001Bg000D]`00002D]`03@00E]`005KL001Fg000E]/005KK001Ff`00
009Ff`0=001Ff`00E]/005KK001Ff`00E]/005KK00000UKK00<005KK00000P000UKK00H005KK001F
f`00E]/<000NOol00`00Oomoo`24Ool001]oo`@0021oo`<001Eoo`03001oogoo03Aoo`03001oogoo
0?mooa5oo`<00003800002P000L000=k]P05001oUGnEOiD00002Oi@01@00OgAoM7md00000gmC00D0
07mC001oDP0000=o<`06001o<glc001o<P000g/C0P000g/C00@007KcM_<0009^e@06001Z]VZf001V
]P000V:G00<006:G00000V:G00X005jH001NV000FYP005Yh001JN0@00008<]l000000012oP00A_h0
0096oP0O001:oP00B_d004kM001>g@00C]d004kM001Bg000D]`005;L001Bg000D]`005;L001Bg000
D]`005;K00000U:k01/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00DY/005:J001BVP00
DYX005:J00000Tij0P0000]>NP00CWX004iI001>F@00BUT004Xi00<00007DUP00000DUP0058h0000
0Thg00H0058g001B=`00DSL20000358g001B=P00DSH005Hf001F=P00ESH0009F=P09001F=P00ESH0
05Hf001F=P00009F=P0;001F=P00ESH005Hf001F=P00ESH00002FSH01`00FUH005YF001JEP00009J
EP07001JEP00HWH0069f00000V:F00<006:G00000V:G00H006:GHYL006:G0002H[L00`00I[L00002
I[P00`00H[P00002H]P01@00H]P006;H00000V;I00<006;I00000V;I00H006;IH]T006;I0002H]T0
0`00H]T00002H]X300002F;j001RnV;j001RnP00H_X00002H_X01000H_X006;j0P0000URnP00H_YR
nP00HaX006<J00000V<J00<006<KHa/0100000MW6P00IaYW6P00IcX00002IcX30002JcX01000JeY[
FP000V]J0`000VmI00P007=ILeT007=i001cF@000WMh00D007Mh001gN000009gM`09001kMg]gNgL0
07]f001kEP00009kEP09001kEG]ENeD007]E001kE@00009kE004001k=7/dNc@200000g/e001k=002
Nc@01000McEg=@000WLE00H007LFMaH007<F0002L_H01P00K_M^m`00J]L0009Ze`03001Ve`00009V
^007001R^000H[P005jH00000UZH00X005ZH001FN000EWT0059i001>F@800007AST0048I000mn@00
=MP00P0000<UN00000001@0000<0D`0000002@0000@9F@00000EV`D00003;S`0038l00800003>U`0
03Yl00<0000B@Y`004:L0016W000AY`004Zl001:_000B[`004Zl001>_0000Tjl00@004jl001>_080
0004C[`005:l0002D]`01`00D]`005;L001Bg000009Bg00=001Bg000D]`005;L001Bg000D]`005;L
00000U;L00/005;L001Fg000E]`005KL001Ff`00009Ff`0=001Ff`00E]/005KK001Ff`00E]/005KK
00000UKK00D005KK001Ff`00009Ff`03001Ff`0000P0000;E]/005KKE]/005KK001Ff`00E]/0000N
Ool00`00Oomoo`24Ool005Moo`03001oogoo03Eoo`03001oogoo0?moo`eooaD00003OiD007nD009o
U005001oM7mdOg@00002Oe<01000Oe=oDgmC0P000glc00H007lcOc<007lb0004Na<02`00Na=k4g/C
001fl`00M_@006kE00000VZf00<006JfI[H00`000V:G00T006:G001NV000GYP005ZH00000UYh00<0
05Yh00001`0002A2oP00A_h004Kn001:oP00B_d004kM001>g@00C]d004kM001Bg000D]`005;L001B
g000D]`005;L001Bg000D]`005;K0002D[/06`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001BV`00DYX005:J001BVP00DYX00002CWX01P00CWX004ij001>NP800007CUT004YI001:>@00BST0
1P0000iB>000CSM>=`00DSL0058g001B=`00DSL0058g0P0000QB=P00ESH005Hf001F=P000UHf01H0
05HfESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH0009J=P05001JEP00FUH00002
FUH00`00FUH0000200002F9f001RMV9f001RUP00HYL00002HYL01000HYMRU`000V:G0`000VJg00D0
06Jh001R^000009Rf003001Rf000009Rf0<0009Rf@03001Rf@00009Rf@03001Rf@00009Rf@03001R
fF;I00<00009H_X006;jH_X006;j001RnP00009RnP04001RnP00H_X200002F;j001RnV;j001RnP00
HaX00002HaX00`00HaYS6P0300001FLJ001W6VLJ00000VLJ00<006Lj00000VLj00<006/j00000f/j
00<006]J00000V]J00@006mIKeT0009_F@04001cFG=I0002LeT01@00MgQgN7Mh00000WMh00@007Mg
MgL000=kM`05001kMP00NeH00002NeH02P00NeEkEG]E001kE@00NeD007]D0P000g/d00D007/eNcEk
=@00009k=004001g=GLe0002MaD01000MaIg5P000W<F00<007;f00000Vkg00H006[GJ]L006[G0002
I]L3000016:h001R^0000UjH010005ZH001JV000EWP005Ii001BN@00CUT004YI0016>@800005?OT0
0000000]^00200001AeG0000000009D02@0000D0]P00000000UI008000035I/001gK00D00005<S`0
03IL000jG0020002?W`500002DJL000004Zl001:_000B[`00002B[`04`00C[`004jl001>_000C[`0
04jl001>_000D[`005;L001Bg000009Bg00=001Bg000D]`005;L001Bg000D]`005;L00000U;L00l0
05;L001Bg000D]`005KL001Fg000E]`005KK00000UKK00<005KK00000UKK00P005KK001Ff`00E]/0
05KK300000QFf`00E]/005KK001Ff`000UKK00T005KK001Ff`00E]/005KK00007Woo00<007ooOol0
Q7oo001FOol00`00Oomoo`0fOol00`00Oomoo`3oOol:Ool80002Io/01@00LoUcnG?i00000W_H00D0
07^gNkMk]`00009oUPD000AoM004001oDgmC0004Oe<01@00Oc=o<glc00000Wlc0P001G/C00T007/C
Na=k4`00M_<007Kd00000VkE00<006Zf00000VJf00<006Jg00000V:G00D006:G001NV000009NV006
001JV000FWP005Yh100000<NOP00:Yh00P0002A2oP00A_h004Kn001:oP00B_d004kM001>g@00C]d0
04kM001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`005;K0002D[/05P00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001BV`00DYX005:J0P000U:J00h004ij001>NP00CWX004ij001>F@00
CUT004YI0P0000E:>@00BSP004XH00<0000JDSP004hg001B=`00DSL0058g001B=`00DSL0058f001B
=P00ESH005Hf001F=P00ESH0009F=P0C001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf
00000UXf00D005YF001JEP00009JEP<00004GWH0069f0002HWH00`00HYH00002HYL00`00HYL00002
HYL01P00HYMRU`00I[L0009V]`03001V^000009R^003001Rf000009Rf0<00007I]P006;IH]T006;I
00000V;I00<006;I00000f;I0`0000URn@00H_YRnP00H_X006;j00000V;j00<006;j00000V;j00<0
06;j00000V;j00D006;j001RnP00009S6P03001S6P00009S6P03001W6P00009W6P06001W6VLJ001W
6P000VLj0`000V/j00@006/jJcX0009[FP<0009_F@05001_FFmI001cF@020003LeT01000MgQgN000
0WMh00D007Mg001gE`0000=kM`08001kEW]F001kEP00NeH000=kE@08001kEG]E001kE000NeD0009k
=006001k=G/eNcD007/d0P000WLe00@007LE0000009g5P03001c5W<F00<0009^m`06001Zef[G001Z
e`000VKG00D006Jh001R^000009R^00B001NV000FYP005ZH001FN000EWT0059i001>F@00BUT004Hi
0P0000<mn@00>MT0100000@ME`000004]@H0000303<0001d00<000040?L000002ET3000011gK0000
02XL100000/fG000>U`003Yl000nO000@W`004:L00D00003B[`004Zl0080009:_00?001>_000C[`0
04jl001>_000C[`004jl001B_000009Bg00A001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`0
0002D]`01`00D]`005;L001Bg000009Fg00<001Fg000E]`005KK001Ff`00E]/005KK2P0000AFf`00
E]/0009Ff`0=001Ff`00E]/005KK001Ff`00E]/005KK00000UKK00X005KKE]/005KK001Ff`00E]/0
01ioo`03001oogoo08=oo`00EWoo00<007ooOol0=goo00<007ooOol0ogoo0goo3@000VOk00D007?i
LoUcn@00009kf005001k]g^gNkL00004OiH00`00OgEoM@0300000gmd001oD`02Oe<00`00Oe=oD`02
Oe<01@00Oc=o<glc00000glc00<007/CNa<00g/C00T007/CNa=k4`00M_<007Kd00000VkE00<006Zf
J[H00`000VJg00D006:G001RU`00009NV00:001NV000FYP005Yh001JN000EWP3000011in000003:N
1P0001Q:oP00B_d004kM001>g@00C]d004kM001Bg000D]`005;L001Bg000D]`005;L0002D]`08@00
D]`005;K001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001BV`00DYX005:J001BVP00
DYX00002CWX200002dij001>NP00CUT004iI001:F@00BST00P0000E:>000BQP004HH00<0009>=`80
000DDSL0058g001B=`00DSL0058f001B=P00ESH005Hf001F=P00ESH0009F=P0C001F=P00ESH005Hf
001F=P00ESH005Hf001F=P00ESH005Hf00000UXf00<005YF00000UYF00L005YF001NMP00GWH00002
HWH01@00HWH006:F00000V:G00<006:G00000f:G0`000VJg00D006Jg001V^000009R^003001Rf000
009Rf003001Vf000009Vf003001Rf@00009Rf@03001Rf@00009Rf@06001Rf@00001Rn@000V;i00D0
06;j001RnP00009RnP06001RnP00H_X006;j0P000V;j00D006;j001RnP00009RnP06001S6P00HaX0
06<J0P000VLJ00<006LJ00000VLJ00<006LJIaX00`000V/j00<006/j00000V/j00@006]JJeX0009_
FP04001_FFmI0002KeT01000LeUcF@000W=I00D007Mh001gF000009gN0800003MeL007]g009kM`04
001kEW]FNeH200000g]F001kE@02NeD01000NeEkEG]E0P0000IkE@00Nc@007/e0002NcD01@00Nc@0
07/e00000WLe0P0000Ag5@00MaH0009c5P04001^mVkf0002K_L00`00J]L00002J]L300006VJh001R
^6:h001R^000GYP005ZH001JV000EWP005Ii001BN@00CUT004YI0016>@00@QT200000cWI000a^002
00000aeG0000000500000`1D0000000400001@2f000000002ET01@0000@Qn`00000^70@0008jG080
008nO0800005@Y`004JL0016W007000014Zl001>_0000Tjl00@004jl001>_0800004C[`005:l0002
D]`02@00D]`005;L001Bg000D]`00002D]`02`00D]`005;L001Bg000D]`005;L00000U;L00<005;L
00003@0000YFf`00E]/005KK001Ff`00E]/0009Ff`06001Ff`00E]/005KK0`000UKK00T005KK001F
f`00E]/005KK00000UKK00L005KK001Ff`00E]/0000NOol00`00Oomoo`23Ool005Ioo`03001oogoo
03Moo`03001oogoo0?aoo`P0008kO`@00003Emh006_l009[o0P00003NmP007^g009k]`05001oUWnF
OiH00003OgD00`00OgAoM0020003Oe<01`00Oe=oDgmC001o<`00009o<`05001o<glcOc<00005Na<0
2@00Na=k4g/C001fl`00M_@00002K]D01P00J[IZ]P00J[H0009V]`03001RU`00009RU`0<001NV000
GYP005ZH001JN000FWP005Ih100000TNOP00000003Jn000j_P00?[h02000011>g@00C]d005;L001B
g000D]`005;L001Bg000D]`0009Bg00O001Bg000D]/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:K001BVP00DYX005:J00000U:J00P004ij001>NP00CWX004ij0P0000U>F@00BUT0
04Xi001:>@00BSP00P0000=66000AQP0100001EB=`00001B=`00DSL0058g001B=P00DSH005Hf001F
=P00ESH005Hf00000UHf01<005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH00003FSH0
1000FUH005YF0`0000UNMP00GWINMP00HWH0069f00000V:F00<006:G00000V:G00H006:GHYL006Jg
0002I[L00`00I[L00002I[P00`00H[P00002H]P300001FKH001Vf6KH00000V;I00<006;I00000V;I
00P006;I000006;i001Rn@000V;i00<006;j00000V;j00H006;j001RnP00H_X20002H_X01@00H_X0
06;j00000V;j00H006;j001S6P00HaX20002HaX00`00IaX00002IaX00`00IaX00002IaX00`00IcX0
0002JcX01000JcY[>P000V/j0`000VmJ00D006mIKeT006mI008000=cF@04001cFG=I0002MeP01000
MgQgN0000gMG00D007]g001kEP00009kEP06001kEW]FNeH007]E0P000g]E00P007]ENeD007/d001k
=@000g/e0P0000Ak=@00McEg=@800004MaD007LF0002LaH01000K_I^mP000Vkg00<006[G00000V[G
00<006KG00000VJh01X006:h001R^000GYP005ZH001JV000EWP005Ii001BN@00CUT004YI0016>@00
@QT003gi0P0000<a^0009GP00P0000DE5`000000002E00H0000507@000000000m`0300000`ej0000
0003000012XL0000038l0`0000TjG000>W`003il0012O000@Y`00P0000M6W000AY`004Zl001:_00>
000024jl001B_000D]`005;L0002D]`01000D]`005;L4P0000QBg000D]`005KL001Fg0000UKK00d0
05KK001Ff`00E]/005KK001Ff`00E]/00002E]/00`00E]/00002E]/03@00E]/005KK001Ff`00E]/0
05KK001Ff`00009Ff`09001Ff`00E]/005KK001Ff`0001ioo`03001oogoo08=oo`00EWoo00<007oo
Ool0>7oo00<007ooOol0mGoo1P000T]o00D004MoAgl004=o00<000AKgP<0009[o003001cfW?J009c
fP03001gf7OH00<0009k]`04001oUWnF0003OgD00`00OgAoM002Og@20002Oe<01@00Oe=oDgmC0000
0Wlc0P0017lc0P000g/C00<007/C00000g/C00@007KdM_@0009^e@04001Z]VZf0002J[H00`00I[L0
0002HYL02@00HYL005jH001NV000FYP00002FWP01000FWP005Ih1@0000HZWP00000f_P00>[h20000
1d;N0016g@00A]d004[M02H00009D[/005:k001BV`00DYX005:J0080009BVP0<001>NP00CWX004ij
001>NP00CUT004iI0P0000M:>@00BST004Xh001:6002000014HH001664HH0`0001=B=`00001B=`00
DSL0058f001B=P00ESH005Hf001F=P00ESH00002ESH03`00ESH005Hf001F=P00ESH005Hf001F=P00
ESH00002ESH00`00ESH00002FSH00`00FUH00002000015iF001NMP000Uif00D0069f001RMP00009R
UP03001RU`00009RU`04001RU`000002I[L00`00I[L00002I[L01@00I[P006:h00000V;H00<006KH
00000VKH00<006KH00000V;I00<006;I00000V;I0`000V;i00H006;iH_T006;i0002H_X01P00H_X0
06;j001RnP800007H_X006;jH_X006;j00000V;j00H006;j001RnP00HaX200001F<J001S6V<J0000
0VLJ00<006LJ00000VLJ0`000VLj00L006/jJcX006/j001[>P020002JeX01000KeY_FP000VmI00@0
07=ILeT0009cF@04001cF@000002MeP01000MgQgN0000gMG00D007]g001kEP00009kEP09001kEW]F
NeH007]E001kE@00009kE@08001kEG]E001k=000NcD000=k=@04001k=G/e0002McD01000MaEg5@00
0WLF0`000Vkf00@006kgK_L0009Ze`<0000=I]L006JhI[P006:h001R^000GYP005ZH00000UZH00P0
05Ih001FN@00DWT004iI0P0000M6>@00@QT003gi000if@0500001ADG0000000009D0100000<0<`00
00000`0000<0m`000000100000HM^`00000Z7000;Q`200003cIL00000000>W`003il0012O000@Y`0
04JL0016W0020002B[`20002B[`02P00B[`004jl001>_000C[`004jl400000QBg000D]`005;L001B
g0000U;L00d005;L001Bg000D]`005;L001Bg000E]`00002E]`01@00E]/005KK00000UKK00d005KK
001Ff`00E]/005KK001Ff`00E]/00002E]/03@00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`03
001Ff`00009Ff`05001Ff`00E]/0000MOol00`00Oomoo`23Ool005Ioo`03001oogoo03Qoo`03001o
ogoo0>ioo`L00007Deh005=ODel004mO00000T]o00<004Mo00000P000U^n0P0000=KgP00Jm`00V_L
10000W?J00D007OHMmQgf000009k]`@00003OiH007me009oM@05001oM7mdOg@00002Oe@20004Oe<0
0`00Oc=o<`020003Oc<00`00Nc<00003Na<00`00Na<00003Na<02000M_Afm7Kd001^e@00J[H20002
J[H00`00I[L00002HYL01`00HYL005jH001NV000009JV0X000032O`000000080000:=[h00000?[h0
04;N0016g@00A]d2000044[M001:g@00C]d004kL001>g000C]`004jl001>_0000Tjl018004jl001B
_000D[`005:k001B^`00D[/005:k001>^`00CY/=000015:J001>NTij0P0000U>NP00CWX004iI001>
F@00BUT00P0000M:>@00BSP004XH001660020002AQP00`00AOL0000200004E8g0000058g001B=P00
DSH005Hf001F=P00ESH005Hf00000UHf00d005Hf001F=P00ESH005Hf001F=P00ESH00002ESH01@00
ESH005Hf00000UXf0`0000AJEP00GUH0009NMP05001NMP00HWH00002HWH01@00HYH006:G00000V:G
0P0000MV]`00I[MV]`00I[L00002I[L00`00I[P00002H[P30002I]P00`00I]P00002I]P00`00H]T0
0002H]T30002I_T01P00H_URn@00H_T0009Rn@06001RnP00H_X006;j0P0000MRnP00H_YRnP00H_X0
0002H_X01P00H_X006;j001RnP800005HaX006<JHaX00002HaX01P00IaX006LJ001W6P80009W>P03
001W>P00009[>P06001[>V/j001[>P000V]J00D006mJKeX006mI0080009cF@05001cFG=ILeT00002
LeP00`00MeQgF00200000gMG001gE`02MeL02000NeIkEP00NeH007]F0002NeH02@00NeD007]E001k
E@00NeD00002NeD01@00NcEk=G/e00000W/e00@007/eNcD0009g=@06001g5GLEMaD007LF0P0000Mb
mP00K_I^mP00K_L00002J]L00`00J]L00002I]L01`00I[P006:h001R^000009NV00>001JV000FYP0
05Ih001FN@00DWT004iI001:F@800007@QT003gi000if@00<KP00P0000<ME`0000001@0000<0E000
0000100000D0e`00000000UI008000035IX0000000<00003;Q`0038l0080008jG080008nO080000L
@Y`004JL0016W000AY`004Zl001:_000B[`004Zl001>_000C[`004jl001>_000C[`004jl0002D[`0
3@00D[`005;L001Bg000D]`005;L001Bg000009Bg00;001Bg000D]`005;L001Bg000D]`00002D]`0
1`00D]`005KL001Fg000009Ff`0=001Ff`00E]/005KK001Ff`00E]/005KK00000UKK00/005KK001F
f`00E]/005KK001Ff`00009Ff`07001Ff`00E]/005KK00000UKK1`007Woo00<007ooOol0PWoo001F
Ool00`00Oomoo`0iOol00`00Oomoo`3WOol600001eLn001C?U<n001C?P00009CGP07001CGe=O001?
G`00Bgl00`000U^n0P0000=K_P0000000P000V_L00@007?JLmYcfP@00003MmP007^g00=k]`03001k
UW^F008000=oM@05001oM7mdOg@00003Oe@01@00Oe=oDgmC000017lc00D007lcOc=o<`00009k<`06
001k4g/C001k4`000g/C00D007KdM_Afm000009^e@800004J]H006Zf0002I[L01`00HYL006:G001N
V000009NV0<00007FWP005Yh001FN000EWP0100000<J?@008Uh00P0000<j_P00?[h00P0001I6g@00
A]d004[M001:g@00B]d004kM001>g000C]`004kL001>_000C[`0009>_00@001>_000D[`005:l001B
^`00D[/005:k001B^`00C[/200002djK001>V`00CY/004jK001>V`00CWX0200000Y>NP00001>F@00
CUT004YI001:>@800005BSP004XH001660020002AQP01000AOL004Wg0`0000mB=`00001B=P00DSH0
05Hf001F=P00ESH005Hf00000UHf00L005Hf001F=P00ESH00002ESH03000ESH005Hf001F=P00ESH0
05Hf001J=P800004FUH005YF0002GUH01`00GWH005if001RMP00009RMP03001RUP00009RU`03001R
U`00009V]`04001V]fJg0002I[L01@00I[L006Jh00000V:h00<006KH00000VKH00<006KH00000VKH
00<006;IH]T00`0000EVn@00I_UVn@00009Rn@03001Rn@00009Rn@04001RnP00H_X200001f;j001R
nV;j001RnP00009RnP06001RnP00H_X006;j0P0000MS6P00HaYS6P00HaX00002HaX01000IaX006LJ
0P0000EW6P00IcYW>P00009W>P04001[>P00JcX20002JcX01000JeY[FP000VmJ00@006mIKeT0009c
F@04001cFG=I0002LeP01000MeQgF0000WMG00D007MGMeMgE`0000=kEP800003NeH007]F009kEP08
001kEG]E001kE@00NeD0009kE@06001k=G/eNcD007/e0P000W/e00@007Le000000=g5@03001g5P00
009bmP04001^mVkf0002K_L300002F[G001VefKG001V^000H[P00002H[P01000GYP005ZH3@0000Q6
>@00000mn@00>MT0036h100000DE5`000000002E00H0000309D0000000T000038M/0000000800007
<S`003IL000jG000>W`01@0000M2W0000016W000AY`00002B[`20002B[`06@00B[`004jl001>_000
C[`004jl001>_000C[`005:l001B_000D]`005;L001Bg000009Bg007001Bg000D]`005;L00000U;L
00d005;L001Bg000D]`005;L001Bg000E]`00002E]`03`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/00002E]/00`00E]/00002E]/300000eKK001Ff`0<00001UKK001Ff`00E]/001ioo`03001oogoo
089oo`00EWoo00<007ooOol0>Goo00<007ooOol0hGoo1P0000AG7@00Ead0009G7@03001G?P00009C
?P03001C?P00009CGP03001CG`0000@0009OWP800004Fkh000000003Jmd30003LmX01000MkUg^GNi
0P000g^g00H007^FNiIkUP00OgD30003Og@00`00OeAoE002Oe@20002Oe<00`00Oc=o<`02Oc<01@00
Oc=o<glc00000W/c00H007/CNa<007/C0003Na<01@00M_Afm7Kd00000VkE00H006[FJ]H006Zf0002
I[L01@00HYL006:G00000UjH0`0000]JV000FWP005Yh001FN000EWP0059H00<000046Sd00000:Wh2
00001cjn0012gP00A]d004KM0080000@B]d004[M001>g@00C]`004kL001>g000C[`004jl0002C[`0
6P00C[`005:l001B_000D[/005:k001B^`00D[/004jk001>V`00CY/004jK001>V`00CY/2000024ij
001>NTij001:NP00BWX600001diI001:F@00BST004Xi0080000=BQP004HH00166000AQP004Gg0019
m`00BOL00`0000]B=`00001B=P00ESH005Hf001F=P00009F=P0A001F=UHf001F=P00ESH005Hf001F
=P00ESH005Hf001F=P0600001UYF001JEP00FUH0009NEP05001NMP00GWH00002HWH01@00HWH006:F
00000V:G0`000fJg00<006Jg00000VJg00<006Jg00000VJh0`000VKH00<006KH00000VKH00<006KH
00000V;I00<006Ki00000VKi00<006Ki00000V;i00<006;i00000V;i00H006;j000006;j0002H_X0
0`00H_X00002H_X01P00H_X006;j001RnP800007HaX006<JHaX006<J00000V<J00@006<J001W6P80
0005IaX006LJIaX00002IcX00`00IcX00002JcX01P00JcY[>P00JcX0009[FP04001_FP000002KeT0
2P00LeUcF@00LeT007=I001cF0000WMH00T007MGMeMgE`00MeL007MG00000W]F00D007]FNeIkEP00
009kEP04001kEG]ENeD200001G]E001kEG]E00000g/e00D007/e001k=@00009k=@800007MaD007LE
MaD007LF00000W;f00@006kfK_H0009^m`03001Ze`00009Ze`05001Ve`00I[P00002H[P00`00H[P0
000400002eZH001FN@00EWT0059i001>F@00CUT00`0000=26@0000000SWI0`0000<UN0005AL00`00
00<0U@0000000P0000<0M@0000000P0000<0e`0000000P0000@ANP00000M^`8000059O`00000000b
?0020002>U`200000cil000nO00500000dJL00000002B[`04`00B[`004Zl001:_000C[`004jl001>
_000C[`004jl001>_000009B_00=001B_000D]`005;L001Bg000D]`005;L00000U;L014005;L001B
g000D]`005;L001Bg000D]`005;L001Fg000009Fg009001Ff`00E]/005KK001Ff`00009Ff`0:001F
f`00E]/005KK001Ff`00E]/800001UKK001Ff`00E]/0009Ff`09001Ff`00E]/005KK001Ff`0001io
o`03001oogoo089oo`00EWoo00<007ooOol0>Woo00<007ooOol0fWoo1P0000IFo000E_d005LM0002
Ead00`00Ead00002Ead00`00Ech00002Dch01000Dch005=N0P000Umn00<005mnGgh00P0000AOWP00
0000009W_@800007Jmd007>kLk/007?J000017Ni00H007^h000007^g0002NiH00`00OgEoM@02OgD2
0002Og@00`00OeAoE002Oe@01@00Oe@007mC000017lc0P000Wlc00@007/cNc<0009k4`08001k4g/C
001k4`00Ma@0009fm004001^eFkE0002J]H02000J[IZ]P00I[L006:G0002HYL3000015jH001JV000
0UYh00P005Yh001FN000EWP0059H0`0000DJ?@00000003:N00@0000FA]d004KM001:g@00B]d004[M
001>g@00C]`004kL001>g000C[`004jl0002C[`200009E:l001B_000D[/005:k001B^`00D[/004jk
001>V`00CY/004jK001>V`00CY/004jK001>NP00CWX004Yj001:NP00BUX004YJ00<00008CUT00000
BST004Xi001:>080000=AQP004HH00166000AOL004Wg0019m`00BQL00`0000aB=P00DSH005Hf001F
=P00ESH005Hf0002ESH03000ESH005Hf001F=P00ESH005Hf001F=P<00004FSH005YF0002FUH00`00
FUH00002FUH01`00GUH005if001NMP00009RMP03001RMP00009RUP05001RU`00I[H00003I[L00`00
I[L00002I[L00`00I[L00002I[P00`00I]P00002I]P01P00I]QVf000I]P0009Vf0<0009Vn@03001V
n@00009Vn@05001Rn@00H_T00002H_T2000016;i001RnP000V;j00<006;j00000V;j00@006;j001R
nP800007HaX006<JHaX006<J00000V<J00<006<J00000V<J00<006LJ00000VLJ00<006LJ00000VLj
00@006Lj001[>P80009[>P04001[>V/j0002JeX01000KeU_F@000VmI00@007=ILeT0009cF@03001c
F7=H00800009MeP007MGMeL007MG001gE`00009kEP09001kEW]FNeH007]F001kEP00009kE@06001k
EG]ENeD007]E0P000g/e0P0000Ak=@00NcEk=@800007MaD007LEMaD007LF00000g;f00<006kf0000
0Vkg00<006[G00000V[G00D006KG001V^000009R^0<0000AG[P005jH001JV000EWT005Ii001BN@00
CUT004iI001:>@0300001Cgi000if@00<KP02P0000<0U@000000100000D0e`00000000UI00D00004
8M/00000;Q`300001CIL000jG000>W`00P0000DnO000@Y`004:L00D0000@B[`004Zl001:_000B[`0
04jl001>_000C[`004jl0002C[`04@00C[`005:l001B_000D]`005;L001Bg000D]`005;L00000U;L
00l005;L001Bg000D]`005;L001Bg000D]`005;L00000UKL00<005KL00000UKK00H005KK001Ff`00
E]/<000035KK00000000E]/005KK001Ff`00E]/0009Ff`05001Ff`00E]/00002E]/01@00E]/005KK
00007Woo00<007ooOol0PGoo001FOol00`00Oomoo`0kOol00`00Oomoo`3COol600001UKl001Fo000
E_`0009Fo005001Fo@00Ead00002Ead00`00Ead00002Ead01000Ech005<n10000UmN00@005mnGgh0
00=OOP05001WWFNMIid00003Ikd20003Lk/20003MkT00`00NkQk^002NkP20002NiH00`00OgEoM@02
OgD01@00OgD007md00000gmD00D007mDOeAoE00000Ao<`03001o<`00009o<`04001k<g/cNc<20003
Na<01@00Na<007LD00000WKd00@006kE0000009ZeP06001Z]VZf001V]`000V:G0`0000ANV000GYP0
009JV00:001JN000FWP005Ih001FN000DUP20000105j0000029N0`0000<fWP00>Yh01P0000Y:g@00
B]d004kM001>g000C]`0009>g00F001>_000C[`004jl001>_000D[`005:l001B^`00D[/005:k001B
^`00C[/2000034jK001>V`00CY/004jK001>V`00CWX0009>NP09001:NP00001:FP00BUX004Hj00H0
0005BST004Xh001:600200001THH001664HH0015m`800005BOL004XG001>5`0300002U8f001F=P00
ESH005Hf001F=P000UHf00H005Hf001F=P00ESH700001UHf001J=P00FUH0009JEP0:001JEUYF001J
EP00GUH005if0002GWH01@00HWH0069f00000V:F0`000VJf00@006JgI[L0009V]`03001V]`00009V
]`<0009Vf003001Vf000009Vf003001Vf000009Vf003001Vn000009Vn@03001Vn@00009Vn@03001R
n@00009Rn@800004I_T006;i0002H_X00`00H_X00002H_X01000H_X006;j0P0000MRnP00HaYS6P00
HaX00002HaX01P00HaX006<J001S6P80009W6P03001W6P00009W6P04001W>P00IcX20002JcX01`00
JcY[>P00JcX006]J0080009_F@05001_FFmI001cF@020002LeT01000LeQcF0000WMH00D007MGMeMg
E`00009gE`05001kEP00MeH00002NeH01@00NeH007]F00000W]E00@007]ENeEkE@800003NcD007/e
009k=@04001k=G/e0002NcD01000MaEg5@000gLE00<007<F00000W;f00<006kfK_H00`000V[G00D0
06[G001Ve`00009V^009001R^000H[P005jh001NV000009JV008001FN@00EWT0059i001>F@800003
BST004HI00<00003>MT0036h00<000037EP0000000T0000309D0000000H000066IX000008M/002Gl
0P000S8l0P0000LjG000>W`003il000nO00200001D:L0016W000AY`0200001Q:_000C[`004jl001>
_000C[`004jl001>_000D[`005:l001Bg000D]`005;L0002D]`01`00D]`005;L001Bg000009Bg00:
001Bg000D]`005;L001Bg000D]`>00001UKK001Ff`00E]/0009Ff`04001Ff`00E]/3000015KK001F
f`000UKK00D005KK001Ff`00009Ff`09001Ff`00E]/005KK001Ff`0001ioo`03001oogoo085oo`00
EWoo00<007ooOol0>goo00<007ooOol0cGoo1P0000IFo000E_`005Kl0002E_`01@00E_`005Kl0000
0UKl00L005Km001G7@00Ead00002Ead00`00Ead0000300001E]M001KGE]M00000UmN00P005mnGgh0
05mn001WW@000fNM00<006Nm00000Vnk00<007>k00000WNi0P0000=g^@00NkP00g^h00D007^G001k
UP0000=oM@04001oMGmeOgD20003Oe@01@00OeAoE7mD000017lc00<007lcOc<00P0017/c0P000g/C
00D007/C001g500000=fm0800004K]D006[F0002J[H00`00I[L00002HYL01@00H[L005jH00000UjH
00h005ZH001JN000FWP005Ih001FN000DUP0059H0P0000@9f`00000ZOP800008=Yh00000?[d004:m
0012_@P0000TC]`004kLC]`004jl001>_000C[`004jl001B_000D[`005:k001B^`00D[/005:k001>
^`00CY/004jK001>V`00CY/004jK0P000Tij00P004ij001:NP00BWX004YJ0P0000E6>P00AST004Hi
00@00005BSP004XH001660020002AQP01000AOL004Wg0P0000E:5`00CQL004hF00L00005ESH005Hf
001F=P08000035Hf001F=P00ESH005Hf001J=P00FUH000=JEP09001JEP00FUH005iF001NMP00009N
MP05001RMP00HWH00002HYH00`00I[H00002I[H01000I[MV]`000VJg00<006Jg00000VJg00<006KG
00000VKH00H006KHI]P006KH0002I]P30002I_P00`00I_T00002I_T00`00I_T00002H_T30002I_T0
1P00H_URn@00H_X0009RnP03001RnP00009RnP03001RnP00009RnP03001S6P00009S6P06001S6P00
HaX006<J0P000VLJ00<006LJ00000VLJ00@006LJ001W>P800005JcX006/jJcX00002JcX01000JcY[
>P000VmJ00@006mIKeT0009_F@04001cFG=I0002LeT30003MeP01000MeMgE`000gMG0P0000=gEP00
NeH00W]F00P007]FNeH007]E001kE@000W]E0P0000=k=@00NcD00W/e00@007/eNcD0009k=@05001g
5GLEMaD00002MaD00`00LaH00002L_H01P00K_I^mP00K_L0009Ze`03001Ze`00009Ve`03001V^000
0080000BH[P005jhG[P005jH001JV000EWT005Ii001BN@00CUT004iI0P0000=66@00?QT01P0000<U
N0007EP00`0000<4eP0000000P0000<0M@0000001`0000<ANP0000000`0000LUo000;Q`0038l000f
?00400002Cil000nO000@Y`004:L0016W0020002AY`01000B[`004Zl3`000U:l00P005:l001Bg000
D]`005;L5P00015Bg000E]aFg000E]/005KK001Ff`00E]/005KK001Ff`00009Ff`05001Ff`00E]/0
0002E]/02`00E]/005KK001Ff`00E]/005KK00000UKK00/005KK001Ff`00E]/005KK001Ff`0001io
o`03001oogoo085oo`00EWoo00<007oo00000P00>Woo00<007ooOol0aWoo1P0000IFf`00E]/005KL
0002E_`01`00E_`005Kl001Fo000009Fo007001Fo000E_`005Km00000ULM00@005LM001G7@800004
Fcd005/m0002Fed01000FeeKG@000UmN00@005mn000000=WW@03001WWFNM00<000=_^`8000Ag^@80
00=k^004001kUg^GNiL20003OgD01`00OgEoMGme001oE@00009oE004001oE7mDOe@20003Oc<00`00
Oc=o<`020005Nc<02@00Na=k4g/C001k4`00Ma@00003M_@01000K]E^e@000V[F00<006Zf00000VJg
0`0001AR]`00GYQNV000GYP005ZH001JN000FWP005Ih001FN000DUP0059H100000@Eo@00000bWP80
0005>Yh003jm0012_@0200001dJm0016_@00B[d004Zm00d0000UD[`005:l001B^`00D[/005:k001B
^`00C[/004jK001>V`00CY/004jK001>V`00CY/004ij001>NP00BWX004Yj001:FP00BUX00P0000E6
>@00AST0048I00800005BSP004XH001660020002AQP01P00AOL004Wg0019m`800009CQL004hF001B
5P00DQH0058f00H0000@ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf0002FSH00`00FUH00002
FUH01`00FUH005YF001NEP00009NMP05001NMP00HWH00002HWH00`00HYH00002I[H00`00I[H00002
I[L01000I[MV]`000VJg0`000VKG00<006KH00000VKH00<006KH00000VKH00<006Kh00000VKh00H0
06KiI_T006Ki0002I_T300000fKi001Vn@02I_T01@00H_T006;j00000V;j00@006;j001RnP80009R
nP05001RnP00HaX00002HaX01000HaX006<J0P0000EW6P00IaYW6P00009W6P03001W6P00009W6P03
001[>P00009[>P07001[>V/j001[>P00JcX00P000VmJ00D006mIKeT006mI0080009cF@04001cFG=I
0002LeP02000MeQgF000MeL007MG0002MeL01@00MeIgEWMF00000W]F00@007]FNeIkEP800003NeD0
07]E009kE@05001k=G/e001k=@020002NcD01@00NcD007Le00000WLE00H007LEMaD007<F0002L_H0
1000K_I^mP000Vkg00D006[G001Ze`00009Ve`<0000FH[P006:hH[P005jh001NV000FYP005Ii001F
N@00DWT004iI001>F@00BST2000013hI000inCWi0P0000@YV000000MF0<000041=H0000009D60000
0`3g0000000400000aVJ00000002000022Gl0000038l000f?000=U`400006Sil0012W000@Y`004JL
0016W000AY`004Zl001:_000B[`004Zl001>_000C[`004jl0002C[`00`00C[`0000:000015;L001B
g0000U;L00l005;L001Bg000D]`005;L001Bg000D]`005;L00000U;L00/005KL001Ff`00E]/005KK
001Ff`00009Ff`05001Ff`00E]/00002E]/03`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00002
E]/02@00E]/005KK001Ff`00E]/00002E]/00`00Oomoo`0KOol00`00Oomoo`21Ool005Eoo`<003eo
o`03001oogoo0;moo`L00006E]/005KK001Ff`000UKK00/005KK001Fg000E_`005Kl001Fo000009F
o005001Fo000E_`00002E_`01000E_d005LM100000MK?@00FceK?@00Fcd00002Fed01@00FeeKG@00
Geh00P000VMm00@006NMIieWW@8000=_V`03001_^`00009cVP800004MkT007NHMiP200000g^h001k
U`02NiL01P00NgH00000OgD0009oM@04001oEGmEOeD20003Oe@01000OeAoE0000Wlc00D007lcOc=o
<`0000Ek<`03001k4g/C009k4`05001g57LDMa@00002M_@01000K]E^e@000V[F00<006Zf00000VJg
00<006:g00000V:g00L005jH001NV000FYP00002FWP02P00FWP005Ih001FN000DUP0059H1@0000HN
?@00000fWP00>Yh200002D:m0012_@00A[d004Jm001:_@02000034Zl001:_4Zl001>_000C[`004jl
001>_0d0000?C[/00000CY/004jK001>V`00CY/004jK001>NP00009>NP0;001:NP00001:FP00BUX0
04Hj0016>@0200000d8I0000000200003dXH00166000AQP004HH0015m`00BOL004Wg001:5`020000
34hF001B5P00DQH0058f001B=P00ESH0009F=P0=001F=P00ESH005Hf001F=P00ESH005Hf00000UHf
00D005Xf001JEP00009JEP07001JEP00FUH005iF00000Uif00D005if001RMP00009RMP<0009V]P03
001V]P00009V]`04001V]fJg0002I[L00`00J]L00002I]L01P00I]QVf000I]P0009Vf0<0009Vn003
001Vn000009Vn@03001Vn@00009Vn@03001Vn@00009Vn@08001VnFKi001Rn@00H_X0009RnP06001R
nP00001RnP000V;j00<006;j00000V<J00@006<J001S6P800007IaX006LJIaX006LJ00000VLJ00@0
06LJ001W6P80009[>P03001[>P00009[>P04001[>P000002JcX00`00KeX00002KeT20002KeT00`00
LeT00002LeT01000LeQcF0000gMH00@007MGMeL0009gE`06001gEWMFMeH007]F0P000g]F00D007]E
NeEkE@00009kE@08001k=G/e001k=@00NcD0009k=@800006McD007LEMaD007LE0P000W<F00<007;f
L_H00`000Vkg00<006[G00000V[G00D006KG001Vf000009R^007001R^000G[P005jH00000UZH00P0
05Ii001FN@00DWT004iI0P0000=:>@00AQT00P000SWi1@0000<MF00000003P0000D5>000000001VJ
008000078M/00000000^7000<S`00P0000<fG000>U`00`0000<nO00000000T:L00@004JL00000096
W004001:_000B[`2000014Zl001>_0000Tjl014004jl001>_000C[`004jl001B_000D[`005:l001B
g000009Bg00A001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`00002D]`00`00D]`00002E]`0
3@00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`0A001Ff`00E]/005KK001Ff`00E]/005KK001F
f`00E]/00002E]/02@00E]]Ff`00E]/005KK001Ff`03000LOol30022Ool005Eoo`03001oogoo03io
o`03001oogoo0;Ioo`P00006E]/005KK001Ff`000eKK00/005KK001Ff`00E]/005KK001Fg000009F
o007001Fo000E_`005Kl00000UKl00@005Kl001Fo0@00004Fa`005/L0002Fcd01P00FceK?@00Fcd0
009KG@04001KG@000002Hgd02000IgeWO@00Iid006^K0004Ki/20004LiX00`00MiQgV003MiP20002
NiL00`00NgIkMP02NgH01@00OgEoMGme000017mE00D007mDOeAoE00000=oE08000Ao<`03001k<g/c
009k<`03001k500000=k4`06001g57LDMa@007Kd0P000VkE00@006[FJ]H0009Z]P<0009R]`07001R
]`00GYP005jH00000UZH00`005Yh001JN000EWP005Ih001BF000DUP7000022IM000003ZN000n_@00
@[d200002TJm0016_@00B[d004Zm001:_0000TZl00H004jl001>_000C[`200002djl001>_000C[`0
04jK001>V`00CY/02`0000=>V`0000000Tij00P004ij001:NP00BWX004YJ0P0000E6>P00AST004Hi
00800003@QT000000080000?AQP004HH00166000AOL004Wg0019m`00BQL004hG0080000:DQH0058F
001B=P00DSH005Hf0002ESH02@00ESH005Hf001F=P00ESH00002ESH02@00ESH005Hf001J=P00FUH0
0002FUH01@00FUH005YF00000UiF00D005if001NMP00009RMP05001RMP00IYH00002I[H00`00I[H0
0002I[L01000I[MV]`000VJg00H006[GJ]L006KG0002I]P00`00I]P00002I]P00`00I_P00002I_P0
1P00I_QVn000I_T0009Vn@<0009Vn@03001Vn@00009Vn@03001Rn@00009RnP06001RnP00001VnP00
0V;j00<006;j00000V;j00<006<J00000V<J00<006LJ00000VLJ00<006LJ00000VLJ00@006LJ001W
6P80009W>P03001[>P00009[>P06001[>V/j001[>P000V/j00<006mJKeX00P0000E_F@00KeU_F@00
009cF@800005LeP007=HLeP00002MeP02000MeMgE`00MeL007MG0002MeH01@00NeH007]F00000W]F
00H007]ENeEkE@00NeD20002NcD01@00NcD007/e00000W/e00@007LeMcD000=g5@800004LaH007<F
0002L_H00`00K_L00002K_L00`00J]L00002J]L300001fKH001R^6:h001R^000009N^00>001NV000
FYP005Ii001FN@00DWT004iI001>F@800007AQT003hI000in@00=MT00P0000<UN0007EP00`0000<4
eP0000003`0000<M^`0000000RGk0P0000<b?000=S`00P0000<jG000?W`01@0001I2W000AY`004JL
0016W000B[`004Zl001:_000B[`004jl001>_000C[`0009>_00<001>_000001B_000D[`005:l001B
g0000U;L00<005;L00000U;L014005;L001Bg000D]`005;L001Bg000D]`005;L001Bg000009Fg00=
001Ff`00E]/005KK001Ff`00E]/005KK00000UKK00L005KK001Ff`00E]/00002E]/02P00E]/005KK
001Ff`00E]/005KK2P0000=Ff`00Ool067oo0`000Woo00<007ooOol0P7oo001EOol00`00Oomoo`0n
Ool00`00Oomoo`2`Ool6000025Jj001F^P00E[/005KK0002E]/01@00E]/005KK00000UKK00D005KK
001Ff`00009Ff`0=001Ff`00E]`005Kl001Fo000E_`005Kl00000UKl100000AK7000Fa`0009K7003
001K7000009K?@03001K?@00009K?@06001KG@00001SG0000f=m00<006Mm00000P000V^K00L006nK
Ki]_V`00LiX00003LiX20003MiP01P00NiMkU`00NiL000AkMP80009oM@03001oEGmE009oE@05001o
E7mDOe@00004Oe@00`00Oc=o<`02Oc<20003Nc<00`00Na@00003Na<02@00MaAg57LD001fm000L_D0
0002K]D00`00J]H00002J[H00`00I[L00002H[L01@00H[L005jH00000UjH010005ZH001JN000FWP0
05Ih001FN000DUP0059H001>>0<000055Od00000000^O@0400002d:m0012_@00A[d004Jm001:_@00
B[d00P000TZl018004jl001>_000C[`004jl001>_000C[`004jl001>V`00CY/200002DjK001>V`00
CY/004ZK001:N`0500002dij001>NP00BWX004Yj001:FP00BUX00P0000E6>@00AST0048I00800003
?OP0000000800004AQP004HH0002AOL200002dWg001:5`00CQL004hF001B5P00DQH00P0000AB=P00
ESH0009F=P03001F=P00009F=P0?001F=P00ESH005Hf001F=P00ESH005Xf001JEP00009JEP05001J
EP00FUH00002GUH01@00GWH005if00000V9f0`000VJF00<006Jf00000VJf00@006JgI[L0009V]`<0
009Ze`06001VefKG001Vf0000VKH0`000VKh00<006Kh00000VKh00<006KiI_T00`000VKi00D006Ki
001Vn@00009Vn@03001RnF;i00@00004I_X006Kj0002H_X02@00H_YRnP00H_X006<J001S6P020002
IaX00`00IaX00002IaX00`00IaX00002IaX00`00IaX00002IcX01`00JcY[>P00JcX006/j0080009[
>P03001[>P00009_FP04001_FFmI0002KeT01000LeUcF@000W=H00P007=HLeP007MH001gF0000WMG
0P0000=gE`00MeH00WMF00P007]FNeH007]F001kEP000W]E00D007]E001k=@00009k=@04001k=G/e
0002NcD01@00McEg=GLe00000WLE00H007<FLaH007<F0002L_H01P00K_M^m`00K_L0009Ze`05001Z
e`00I]P00002I]P00`00H[P00002H[P04P00G[P005jH001JV000EWT005Ii001BN@00CUT004iI001:
>@800005?QT003Wi000ef@0400001AeH000000001=H00`0000<0U@0000000`0000D0m`00000000eI
00D000038M/002Gk00800005<S`003Hl000fG00200001Cil000nO000@W`01@0000i6W000AY`004Zl
001:_000B[`004Zl001>_0000Tjl01<004jl001>_000C[`004jl001B_000D[`005:l001Bg000D]`0
0002D]`03`00D]`005;L001Bg000D]`005;L001Bg000D]`00002D]`03`00D]`005KL001Ff`00E]/0
05KK001Ff`00E]/00002E]/00`00E]/00002E]/00`00E]/0000=000035KK001Ff`00E]/005KK001F
f`00E]/001ioo`03001oogoo081oo`00EGoo00<007ooOol0?goo00<007ooOol0ZGoo1P0000IF^P00
E[X005Jj0002E[X03@00E[X005Jk001Ff`00E]/005KK001Ff`00009Ff`0A001FfeKK001Ff`00E]/0
05KK001Fg000E_`005Kl001Fo005000015[l001K70000U/L00D005/L001K7000009K7004001K?@00
Fcd500001F=L001SG6=L00000f=m00D006]lJga[O000009[V`03001_V`0000=cVP03001cVP00009g
V@03001gV00000AkU`8000=kMP03001kMG]e008000AoE@03001kE000009oE003001oE7mD009oE007
001o<glcOc<007/d00000g/c00<007/D00000g/C00T007LDMaAg5000M_@007;e00000VkE00<006[F
00000VZf00P006JgI[L006:g001R]`000UjH018005jH001JV000FWP005Yh001FN000EWP0059H001B
F000CSP500001ahm00000000<Wd003ZM00@00004A[d004Jm0002B[d2000024Zl001:_4Zl001>_000
C[`200005Djl001>_000C[`004jl001>V`00CY/004jK001>V`00CY/004jK001:V`0200000dYk001:
N`06000024Yj000004YJ001:FP00ASX200000dHi00126@0200001Cgh000mn000AQP00P0000A66000
AOM5m`80000BBOL004XG001>5`00CQH0058F001B5P00DSH0058f001F=P000UHf01<005Hf001F=P00
ESH005Hf001F=P00ESH005Hf001J=P00FUH00002FUH00`00FUH00002FUH01`00GUH005if001NMP00
009RMP03001VUP00009VUP03001V]P00009V]P05001V]fJg001V]`020002J]L00`00J]L00002I]L0
0`00I]P00002I]P00`00J]P00002I_P01P00I_QVn000I_P0009Vn@03001Vn@00009Vn@03001Vn@00
009Vn@03001Vn@00009Rn@03001Vn@00009VnP06001VnVKj001RnP000V;j00@006;j001S6P800005
IaX006LJIaX00002IaX01P00IaX006LJ001W6P80009W6P06001W>VLj001[>P000V/j00<006/j0000
0V/j00<006/jJcX00`000fmI00<006mIKeT00`000g=H00@007=HLeP0009gF004001gEgMG0003MeL0
1000MeIgEP000W]F00D007]F001kEP0000=kE@04001k=G/e0002NcD02000NcEk=@00NcD007Le0002
McD01000MaEg5@000W<F00@007<F001bmP80009^m`03001^m`00009Ze`<0009Vf003001Vf000009R
^00F001R^000G[P005jH001JV000EWT005Ii001BN@00CUT004iI001:>@00AQT20002>OT2000012fi
000001eH500000<IVP0000000P0000<Un`00;Q`0100000LfG000>U`003il000nO0020002@Y`00`00
AY`0000400000dZl001:_002000014Zl001>_0000Tjl014004jl001>_000C[`004jl001B_000D[`0
05:l001Bg000009Bg00A001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`00002D]`00`00D]`0
0002E]`02P00E]/005KK001Ff`00E]/005KK300000YFf`00E]/005KK001Ff`00E]/0009Ff`09001F
f`00E]/005KK001Ff`00009Ff`03001oogoo01]oo`03001oogoo081oo`00EGoo00<007ooOol0?goo
00<007ooOol0Xgoo1P0000IF^P00E[X005Jj0002E[X03@00E[X005Jj001F^P00E[X005Jk001Ff`00
009Ff`05001Ff`00E]/00002E]/02P00E]/005KK001Ff`00E]/005KL1P0000AJo000F_`000=Jo005
001K7000Fa`00002Fa`01P00Fa`005/L001K?@800005Gc`006=LHe`00002He`02000HeaSG000Hgd0
06]l0003Jg`00`00Ji/000020004LiX00`00MiUgV@02MiT20004NiL00`00NgL00002NgH01000NgEk
MG]e0P000gmE00<007]DNe@00P0017mD00<007/d00000Wlc00H007/dNc@007/c0003Na@01@00Na<0
07/D00000gLD00@007;eL_D0009^e@03001ZeV[F00<0009V]`03001R]`00009R]`07001NV000GYP0
05ZH00000UYh00X005Yh001FN000EWP0059H001BF0800004BSP000002K/2000012IM0000039m0P00
00<jW@00?Yd010000TZm018004Zm001:_000B[`004jl001>_000C[`004jl001>_000C[`200004DjK
001>V`00CY/004jK001>V`00CY/004ZK001:N`00BW/00P000TYk00<004IJ00001@0000E:FP00ASX0
04Hi00800003@QT0048I00800003?OP0000000800006AQP004GgAOL004Wg0P00011:5`00CQL004hF
001B5P00DQH0058f001B=P00ESH0009F=P0C001F=P00ESH005Hf001F=P00ESH005Hf001F=P00FSH0
05YF00000UYF00X005YFFUH005YF001NEP00GWH0009NMP05001RMP00IYH00002IYH01P00I[IV]P00
I[H0009V]`800007J]L006[GJ]L006[G00000VKG00<006KHI]P00`000V[H00<006Kh00000VKh00<0
06KhI_P00`000VKi00<006Ki00000VKi00<006Ki00000VKi0`000VKi00P006KjI_X006Kj001RnP00
0V;j00H006;j000006LJ0002IaX02@00IaYW6P00IaX006LJ001W6P0200001FLJ001W6VLJ00000VLj
00@006/j001[>P80009[>P03001[>P00009[>P04001_FFmI0002KeT01000KeU_F@000W=I00@007=H
LeP0009cF004001gF7MH0002MeL02@00MeMgEgMG001gEP00MeH00002NeH20002NeH01000NeEkE@00
0W/e00/007/e001k=@00NcD007/e001g=@00009g=@04001g5@000002LaH00`00LaIc5P030002K_L0
2000K_M^m`00J]L006[G0002I]P00`00I]P00002H[P01`00H[P005jh001NV000009JV008001FN@00
EWT0059i001>F@800007BST004HI000n6@00>OT00P0000<]^@0000000P0000DI=`00000000CF00X0
00042CT000004GX200001Afk000Qf`009O/00P0000<b?00000000P0000ljG000?W`003il0012O000
@Y`004JL0016W000AY`01`0000Q:_000C[`004jl001>_0000Tjl00`004jl000005:l001B_000D[`0
05;L0002D]`00`00D]`00002D]`04P00D]`005;L001Bg000D]`005;L001Bg000D]`005;L001Fg0`0
0008E]/005KKE]/005KK001Ff`<00008E]/005KK001Ff`00E]/0009Ff`0>001FfeKK001Ff`00E]/0
05KK001Ff`00E]/001ioo`03001oogoo07moo`00EGoo00<007ooOol0@7oo00<007ooOol0W7oo1P00
00QFV@00EYT005JJ001F^P000UJj00T005Jj001F^P00E[X005Jj00000UJj00/005Jj001F^`00E]/0
05KK001Ff`00009Ff`08001Ff`00E]/005KK001Ff`@00006F_/005[k001Jo0000U[l00<005[l0000
0U[l00<005/L00000U/L00H005/L001K7000Fa`200001Ell001O?5ll00000V=L00D006=LHe`006=L
008000=[O005001[O6]lJg`00003KiX01000LiYcVW>J0P000gNI00<007NH00000W^G00L007]gNgMk
M`00NgH00003NgD00`00NeD00002OeD01@00NeAkE7]D000017mD00<007/d00000Wlc00H007/dNc@0
07/c0003Na@01@00Na<007/D00000gLD00@007;eL_D0009^e@04001ZeV[F0002J]L00`00I[L00002
H[L01`00H[L005jH001NV000009JV1<000065O`00000;Wd0039m0P0000HjW@000012W@00@Yd70000
4dZl001>_000C[`004jl001>_000C[`004jl001>_000CY/004jK0080000>CY/004jK001>V`00BY/0
04Yk001:N`00BW/0009:N`800003AUX004IJ00@00005ASX004Hi0016>@0200000d8I000mn0020000
2cgH00166000AQP004Gg0019m`00BOL00P0000i>5`00CQH0058F001B5P00DSH0058f001F=P000UHf
01<005Hf001F=P00ESH005Hf001F=P00ESH005Hf001J=P00FUH00003FUH02@00FUH005YF001NEP00
GWH00002GWH30002IYH00`00IYH00002I[H00`00I[H00002I[L01000J]MZe`000V[G00H006[GJ]L0
06KG0002I]P00`00J]P00002J]P01P00I_QVn000I_P0009Vn003001Vn000009Vn@09001VnFKi001V
n@00I_T006Ki0080009Vn@03001Vn@00009VnP03001VnP00009RnP08001RnP00001W6P00IaX0009W
6P07001W6VLJ001W6P00IaX00P0000EW6P00IaYW6P00009W6P04001W>P00JcX200001F/j001[>V/j
00000V/j0`000VmI00@006mIKeT0009_F@04001cFG=I0002LeP01@00LeP007=H00000WMH0P0000Ug
E`00MeMgE`00MeH007MF00000W]F00H007]FNeIkEP00NeD20003NcD2000017/e001k=G/e0P0000=g
=@00McD00WLe0P0000Ag5P00LaH0009c5P06001bmW;f001^m`000Vkg0`000V[G00<006KH00000VKH
00D006:h001R^000009N^003001NV00000d00007AQT003hI000in@00=MT00P0000@YV000000I=`<0
00051=H000000000]P0;00000aVJ000M^`0200000bGk000^700200000c8l00000002000013il000n
O3il0P000T:L0P0000U6W000AY`004ZL001:_000B[`0400000]B_000D[`005:l001Bg000D]`005;L
01D0000<D]`005;K001Ff`00E]/005KK001Ff`000UKK00H005KK001Ff`00E]/30002E]/02@00E]/0
05KK001Ff`00E]/00002E]/02`00E]/005KK001Ff`00E]/005KK00007Woo00<007ooOol0Ogoo001E
Ool00`00Oomoo`10Ool00`00Oomoo`2FOol600002UJI001FV@00EYT005JI001FV@000UJJ00L005Jj
001F^P00E[X00002E[X02`00E[X005Jj001F^P00E[X005Jk00000UKK00X005KK001Ff`00E]/005KK
001Ff`@00004F_/005[k0002F_/01`00F_/005[l001Jo000009Jo009001Jo5[l001K7000Fa`005/L
00@00005Gc`005llGc`00002Gc`01@00HeaSG000He`00P000VMl00H006]lJga[O000Jg`20004KiX0
0`00LiX00002MiT00`00MiT00003MiP00`00NiL00004NgL01@00NgEkMG]e00000g]E0P0017]D00<0
07mDOe@00WmD00H007/dNc@007lc0002Nc@00`00Nc<00003Na@01@00Na<007/D00000gLD00L007;e
L_Ebm@00K]D00002J]H01P00J]MZe`00I[L0009R]`05001R]`00GYP00002GYP300003EZH001JN000
EWP005Ih001BF000CUP004Xh00L000087Qd00000<Wd003ZM000jW@800003@Yd000000096W@040016
_@00A[`800005Djl001>_000C[`004jl001>V`00CY/004jK001>V`00CY/004jK001:V`02000014Yk
001:N`000TYk00L004IJ000004IJ0012>P0400001DHi0016>@00@QT00P0000<mn000?OP0100000U6
6000AOL004Wg0019m`00BQL00P0000a>5P00DQH0058F001B=P00DSH005Hf0002ESH03`00ESH005Hf
001F=P00ESH005Hf001F=P00ESH00002FSH00`00FUH00002FUH01`00FUH005YF001NEP00009NMP05
001NMP00HYH00002IYH00`00IYH00002I[H00`00I[H00002I[L01000J]MZe`000V[G00@006[GJ]L0
009Ve`<0009Zf003001Zf000009Vn003001Vn6Kh00<0009Vn003001Vn@00009Vn@03001Vn@00009V
n@03001Vn@00009Vn@03001Vn@00009VnP03001VnP00009RnP800004IaX006LJ0002IaX00`00IaX0
0002IaX02000IaX00000IaX006LJ0002IaX01000IaYW6P000VLj00<006/j00000V/j00<006/j0000
0V/j00@006liKcT0009_F@03001_FFmI00800005LeT007=ILeT00002LeP01000LeQcF0000WMH00@0
07MGMeL000=gE`04001gEWMF0002NeH02@00NeIkEW]F001kE@00NeH00002NcD01000NcEk=@000W/e
00D007LeMcEg=@00009g=@04001g5WLF0002LaH00`00LaH00002L_H00`00K_L00002K_L00`00J_L0
0002J]L02000I]QVf000I]P006:h0002H[P500002eZI001FV@00EWT0059i001>F@00CUT0100000Ln
6@00>OT003GI000]^@0200000aeH0000000;000010DH000000Ti1@0000PM^`00000Un`00;Q`0038l
0P00014fG000000003il000nO000@W`004:L0016W000AY`004JL00800008B[`004Zl001:_000C[`0
009>_008001>_000C[`004jl001>_0`0000@D]`005;L001Bg000D]`005;L001Bg000D]`005;L0002
D]`03@00D]`005;L001Bf`00E]/005KK001Ff`00009Ff`03001Ff`00009Ff`04001Ff`00E]/30000
25KK001Ff`00E]/005KK0002E]/03@00E]/005KK001Ff`00E]/005KK001Ff`0001ioo`03001oogoo
07moo`00EGoo00<007ooOol0@Goo00<007ooOol0SWoo1`0000aFN000EWP005Ih001FV@00EYT005JI
0002EYT02@00EYT005JJ001F^P00E[X00002E[X02@00E[X005Jj001F^P00E[X00002E[X02P00E[/0
05KK001Ff`00E]/005KK100000AJf`00F]/0009Jn`07001Jn`00F_/005[k00000U[l00D005[l001J
o000009Jo004001K7000Fa`2000015lL001O70000Ull00@005llGc`0009O?004001SG0000002Ie`0
1000IgaWO0000f]l00@006mkKg/000=_VP8000AgV@03001gV7NH00=gV003001kMg]g00=kM`80009k
M@03001kEG]E009kE@07001kE7]DNe@007]D00000WmD00@007/dNcAk=08000Ak=003001k57/D00=k
5005001k57/DNa@00002Ma@01@00L_EbmG;e00000VkE0`000V[G00P006JgI[L006:g001R]`000UjH
0`00015NV000FYP005Yh001FN000EWP0059H001>F000BSP004HH00L000039Sd0000000800003>Yd0
03jM00800006@Yd004JMAYd004Jm0P0000M:_000B[`004Zl001:_00800006DjK001>V`00CY/004jK
001>V`00CY/004ZK001:N`00BW/004Yk001:N`00AUX004IJ00800003@SX0048j00@00003AST0048I
00800003?OP003gh0080000;?MP000000015m`00BOL004Wg001:5`02000034hF001B5P00DQH0058f
001B=P00ESH0009F=P0=001F=P00ESH005Hf001F=P00ESH005Hf00000UHf00D005Xf001JEP00009J
EP07001JEP00FUH005iF00000Uif0`000V:F00<006JF00000VJF00<006Jf00000VJf0`000f[G00H0
06[GJ]L006[G0002I]L00`00J]L00002J]P01P00J]QZf000I_P0009Vn003001Zn000009Vn006001V
nFKi001Vn@000VKi0`000VKi00<006Ki00000VKi00<006Kj00000VKj0`000VLJ00P006LJIaX006LJ
001W6P000VLJ0P0000AW6P00IaX0009W6P03001W6P00009W6P04001W>P000002JcX00`00JcX00002
JcX30002KcT01000KeU_F@000VmI00@007=ILeT0009cF@04001cF0000002LeP01000MeQgF0000gMG
00@007MGMeL000=gEP800003MeH007]F009kEP04001kEW]F0002NcD01`00NcEk=G/e001k=@0000=g
=@04001g=GLe0002MaH00`00LaIc5P030002L_H01P00K_M^m`00K_L0009Zm`03001Ze`00009Vf003
001Vf000009R^0<0000AG[P005jH001JV@00EYT005Ii001BN@00CUT004iI001:>@0400001CWi000e
f@00;KT01@0000DA5`000000003F00T000062CT000005IX001VJ0P0000<Qf`0000000P0000<b?000
<S`00P0000<jG00000000`0002I2O000@Y`004JL0016W000AY`004ZL001:_000B[`004Zl001>_000
C[`004jl001>_000C[`004jl001>_000D[`005:l001B_0000U;L00d005;L001Bg000D]`005;L001B
g000D]`00002D]`01`00D]`005;L001Bg000009Bg00=001Bf`00E]/005KK001Ff`00E]/005KK0000
0UKK00@005KK001Ff`<00008E]/005KK001Ff`00E]/0009Ff`05001Ff`00E]/00002E]/01`00E]/0
05KK001Ff`0001ioo`03001oogoo07ioo`00EGoo00<007ooOol0@Goo00<007ooOol0R7oo1P0000eF
M`00EWQFN000EWP005Ih001FN000EWP00002EYT03@00EYT005JI001FV@00EYT005JJ001F^P00009F
^P07001F^P00E[X005Jj00000UJj00P005Jj001F^P00E[/005KK1P0000AJf`00F]/0009Jf`07001J
f`00F_/005[k00000U[k00D005[k001Jo000009Jo004001Jo000F_`400001elL001O75lL001O7000
009O?005001O?5ll001O?00200000fML001WG002Ie`01@00IgaWO000Jg`00P000fmk00<006nJ0000
0W=i00@007NIMiUgV@8000AgV08000=kM`06001kMW]f001kM@0017]E00D007]DNeAkE000009kE003
001oE00000Ak=003001k=7/d009k=003001k57/D00=k5009001k57/DNa@007LD001g5@00009bm@04
001^eFkE0002K]H00`00J]L00002I[L00`00H[L00002H[L3000015jH001NV0000UZH00X005Yh001F
N000EWP0059H001>F0800003AQP0047h00L0008^G@80000B>Yd00000@Yd004:M0016W@00A[d004Jl
001:_000B[`004Zl0P0000M:W000BY`004ZL001:W00600003TjK001>V`00CY/004ZK001:N`00BW/0
04Yk0002BW/200000dIJ0016FP0200000d8j000n6P0400000d8I00126@0200000cgh000mf0020000
13gG000004Gg0P0000E9m`00BQL004hG0080000:DQH0058F001B=P00DSH005Hf0002ESH02@00ESH0
05Hf001F=P00ESH00002ESH02@00ESH005Hf001J=P00FUH00002FUH01@00FUH005YF00000UiF00D0
05if001RUP00009RUP03001VUP00009VUP03001V]P00009V]P04001ZeV[F0002J]L01P00J]MZe`00
J]L0009Ve`06001Zef[G001Zf0000V[H00<006KhI_P00`000V[h00<006Kh00000VKi00<006KiI_T0
0`000VKi00<006Ki00000VKi00<006Ki00000VKj0`000VLJ00P006LJIaX006LJ001W6P000VLJ0P00
00AW6P00IaX0009W6P03001W6P00009W6P06001W6P00001[>P000V/j00<006/j00000V/j00@006/j
JcX0009_>@04001_F@00KeT20003LeT01000LeUcF@000W=H00<007=HLeP00P0000UgE`00MeMgE`00
MeL007MG00000WMF00@007MFMeH000=kEP08001kEW]F001k=@00McH0009k=@04001k=@000002McD0
1000McD000000WLF00@007<FLaH0009c5P03001bmP00009^m`<0009Zm`08001Zef[G001Vf000I]P0
009R^00F001R^000G[P005jH001JV@00EYT005Ii001BN@00CUT004iI001:>@00AST300001SWi0000
02fi000YV0<000054AL000000000eP0300001@3F000000001AP00P0000@9>@00000EVP8000047K/0
0000:O/400000c8l000fG002000013Yl000nO3il0P000T:L0P0000i6W000AY`004ZL001:_000B[`0
04Zl001>_0000Tjl00P004jl001>_000C[`004jl0P0000UB_000D[aB_000D[`005;L00000U;L00l0
05;L001Bg000D]`005;L001Bg000D]`005;L00000U;L00d005;L001Bg000D]/005KK001Ff`00E]/0
0002E]/02000E]/005KK001Ff`00E]/3000015KK001Ff`000UKK00D005KK001Ff`00009Ff`03001F
f`0000P001ioo`03001oogoo07ioo`00EGoo00<007ooOol0@Woo00<007ooOol0PGoo1P0000QFE`00
EUL005IG001FM`000UIh00<005Ih00000UIh00l005Ih001FN000EYT005JI001FV@00EYT005JI0000
0UJJ00L005Jj001F^P00E[X00002E[X02000E[X005Jj001F^P00E[X400001U[K001Jf`00F]/0009J
f`07001Jf`00F]/005[K00000U[k00<005[k00000U[k00P005[k001Jo000F_`005[l0P0000AO7000
Ga`0009O7006001O75lL001O70000Ull00H005ll000006=L0002Ie`01P00IeaWG6ML001WO080009_
N`05001_NfmkKg/00004LgT00`00MiT00002MgP01000MiQgV0000W]g00<007]g000017]f00<007]E
NeD00W]E00<007]E00000W]D00H007]DNe@007mD0004Nc@00`00NcAk=002Nc@20004Na@02@00NaAk
57/D001g5000MaD00002L_D01000K]E^e@000VkF00H006[GJ]L006Jg0002H[L3000016:H001NV000
0UjH00h005ZH001JN000EWP005Ih001BF000CUP004Xh0P0000E1n0000000005j00@00003;Ud0039M
00@00003@Yd000000096W@0A0016_@00001:_000B[`004Zl001:_000BY`004ZL001:W00200001DZL
001:V`00BY/01`0000M:V`00001:N`00BW/00002BW/01`00AUX00000AUX0048j00800003?QX003hI
00@00003@QT003gh00800006?MP00000?ML003gG0`0000]9m`00BQL004hG001>5P00DQH0058F0080
0004DSH005Hf0002ESH00`00ESH00002ESH03`00ESH005Hf001F=P00ESH005Hf001J=P00FUH00002
FUH01@00FUH005YF00000UiF0`0000MRUP00HYIRUP00IYH00002IYH01P00I[IV]P00I[H0009ZeP04
001Zef[G0002J]L00`00J]MZe`030002J]L01P00J]QZf000J]P0009Vn003001Zn000009Zn006001V
n6Kh001Vn@000VKi00<006Ki00000VKi00<006Ki00000VKi00@006Ki001VnP800005I_X006LJIaX0
0002IaX00`00IaX00002IaX30002IaX02000IaYW6P00IaX006LJ0002IaX200001f/j001[>V/j001[
>P00009[>P<0009[>P04001_>Fli0002KeT01000KeU_F@000W=I00@007=ILeT0009cF004001cF7=H
0002MeL01@00MeMgEgMG00000WMG00@007MFMeH000=gEP04001kEP000002NeH01@00NcD007Lf0000
0W/e0P0000=g=P00McD00WLe0P0000Ag5P00MaH0009c5P06001c5W<F001bmP000Vkg00H006kgK_L0
06[g0002J]L00`00I]P00002I]P300001V:h001N^000GYP0009JV@08001FV@00EWT0059i001>F@80
0005BST004Hi00126@0400000bfi000YV00?00000`DH0000000300001QFJ000001fk000Qf`800003
;Q`0000000800009=U`003YL000jO000?W`0049l00D00003AY`004JL0080000KB[`004ZlB[`004Zl
001>_000C[`004jl001>_000C[`004jl001>_000D[`005:l001B_000009Bg00=001Bg000D]`005;L
001Bg000D]`005;L00000U;L014005;L001Bg000D]`005;L001Bf`00E]/005KK001Ff`00009Ff`03
001Ff`00009Ff`0:001Ff`00E]/005KK001Ff`00E]/<000025KK001Ff`00E]/005KK000NOol00`00
Oomoo`1nOol005Aoo`03001oogoo04Aoo`03001oogoo07Yoo`H0000<EUH005IG001FE`00EUL005IG
001FE`000UIg018005IhEWP005Ih001FN000EWP005Ih001FV@00EYT005JI0002EYT02@00EYT005JJ
001F^P00E[X00002E[X01P00E[X005Jj001F^P@00004F]X005[J0002F]/02@00F]/005[K001Jf`00
F]/00002F]/00`00F]/00002F_/02000F_/005[k001Jn`00F_`400001ekk001O75lL001O7000009O
7003001O7000009O7006001O?000001S?0000V=L00@006MLIe`000=WG003001[N`0000=_N`05001_
N`00LgX00004LgT00`00MgQgN002MgP00`00MiP00003NgL00`00NgIkMP03NgH00`00NeEkE@02NeD0
0`00NeEkE@020004Ne@00`00NcAk=003Nc@20002Nc@00`00Nc@00003Na@20003Na@01@00Ma@007LE
00000W;e00@006kE0000009^eP06001Zef[G001V]`000V:g00D006:g001RV000009NV00B001NV000
FYP005Yh001FN000EWP0059H001>F000BSP004HH1P0000D9^`009Sd002iM00800003=Wd003Ym0080
000;@Yd004JM0016_@00A[`004Zl001:_00200003DZl001:W000BY`004ZL001:W000BY`004ZK0080
0005BY/004ZK001:N`0500002DYk001:N`00BW/004IJ0016FP0200000d8j0012>P0200000chI000i
n@0200000d8I000mn00200000cgH000mf0020002?ML05000BOL00000BQL004hG001>5P00DQH0058F
001B=P00DSH005Hf0002ESH04`00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Xf001JEP00009J
EP03001JEP00009JEP05001NEP00HWH00002HYH00`00HYH00002IYH00`00IYH00002I[H30002J]H0
1000J]MZe`000V[G00@006[GJ]L0009Ze`03001Ze`00009Zf003001Zf6[H00<0009Zn003001Zn000
009Vn003001VnFKi00<0009Vn@03001Vn@00009Vn@03001Vn@00009Vn@03001Vn@00009VnP03001W
6P00009W6P03001W6VLJ00<00003IaX006LJ009W6P05001W6P00IaX00002IaX30002JcX01000JcY[
>P000V/j0`000V/j00L006/jJcX006li001_F@020002KeT02P00LeUcF@00LeT007=H001cF0000W=H
00D007MGMeMgE`00009gE`08001gEgMG001gEP00MeH0009gEP05001kEP00MeH00002NeH200000gLf
001k=@02NcD00`00McH00003McD01000MaIg5P000WLF0`000W<F00H007;fL_H006kg0002K_L01P00
J_MZm`00J]L0009Vf0<00004H[P006:h0002G[P04000GYP005ZI001FV@00EWT0059i001>F@00CUT0
04Xi0P0000E26@00?OT003GI00800004:IP000007EP200001@dG000000000=H00`0000P0m`000005
60003ET0015I0P0000HI^P00000Qf`00:O/200000c8L0000000200002cYL000jO000?W`0049l0012
O000@Y`01`0001I:_000B[`004Zl001>_000C[`004jl001>_000C[`004jl001>_000D[`0009B_00A
001B_000D]`005;L001Bg000D]`005;L001Bg000D]`00002D]`02@00D]`005;L001Bg000D]`00002
D]/03000E]/005KK001Ff`00E]/005KK001Ff``00004E]/005KK0002E]/03@00E]/005KK001Ff`00
E]/005KK001Ff`0001ioo`03001oogoo07ioo`00E7oo00<007ooOol0A7oo00<007ooOol0M7oo1P00
00aF=P00ESH005Hf001FEP00EUL005IG0002EUL01`00EUL005IG001FM`00009FN00;001FN000EWP0
05Ih001FN000EYT00002EYT02`00EYT005JI001FV@00EYX005Jj00000UJj00@005Jj001F^P@00004
F[X005[J0002F]X02@00F]X005[K001Jf`00F]/00002F]/01@00F]/005[K00000U[K00H005[k001J
n`00F_/4000015kk001Nn`000Ukk00<005lL00000UlL00<005lL00000UlL00H005lL000006<l0002
Hc`01000HeaSG0000VML00@006ML0000009[N`05001_NfmkKg/00003LgX01000LgUcNG=i0P0017Mh
00<007]gNgL00W]g0P000g]f00<007]F00000W]E00<007]ENeD00W]E00<007]DNe@00W]D00<007/d
Nc@00W/d00<007/d00000W/d00<007/d00000g/D00<007/D00000g/D00@007LEMaD000=bm@800004
K_H006kF0002J]L00`00I[MV]`0300006V:g001RV6:H001NV000GYP005ZH001JN000EWP005Ih001B
F000CUP004Xh00166000@OP800001BiM000bG@00=Wd00P0000<nW@0000000P0000e6_@00A[`004Zl
001:_000B[`004Zl001:W00200003DZL001:W000BY`004ZK001:V`00BY/004ZK00800003BW/004Ik
00D0009:N`800003AUX004IJ00800003@SX003hJ00800003>OT0000000800003?OP003gh00800003
?MP00000008me`@0000@BQL004hG001>5P00DQH0058F001B=P00DSH005Hf0002ESH04`00ESH005Hf
001F=P00ESH005Hf001F=P00ESH005Xf001JEP00009JEP05001JEUYF001JEP0300001f9f001RUV:F
001RUP00009VUP03001VUP00009V]P06001Z]VZf001ZeP000V[G00@006[GJ]MZe`<0009Ze`06001Z
ef[G001Zf0000V[H00<006[h00000V[h00H006[hJ_P006Kh0002I_T01P00I_UVn@00I_T0009Vn@03
001Vn@00009Vn@<0009Vn@03001VnP00009W6P03001W6P00009W6P03001W6P00009W6P06001W6VLJ
001W6P000VLJ0`000VLJ00H006/jJcX006/j0002JcX00`00JcX00002JcX01000JcY[>P000Vli00@0
06mIKeT0009_F@04001cFG=I0002LeP00`00LeQcF00200001W=H001gEgMG001gE`8000=gE`800003
MeH007MF009gEP04001gEWMF0002NeH01@00McIg=WLf00000W/e00@007LfMcH0009g=@04001g5WLF
0002MaH200001W<F001c5W<F001bmP<0009^m`06001Zmf[g001Ze`000VKH00D006KH001R^000009R
^00D001N^000GYP005ZI001FV@00EWT0059i001>F@00CUT004Xi0016>@800005?OT00000000]^@02
00001B5h000000003AL01`0000<0m`0000000`0000@=F@00000EVPD00006:O/00000<Q`0038l0`00
00LjG000>W`003il0012O00200001d:L0016W000AY`004JL00L0000<C[`004jlC[`004jl001>_000
C[`004jl0P0000]B_000D[aB_000D[`005;L001Bg000009Bg00=001Bg000D]`005;L001Bg000D]`0
05;L00000U;L00@005;L001Bg0h0000>E]/005KK001Ff`00E]/005KK001Ff`00E]/0009Ff`07001F
f`00E]/005KK00000UKK00L005KK001Ff`00E]/0000NOol00`00Oomoo`1mOol005Aoo`03001oogoo
04Eoo`03001oogoo06eoo`H0000BESH005Hf001F=P00ESH005Hf001F=P00EUH005IG001FE`000UIG
00L005IG001FE`00EWL00002EWP01`00EWP005Ih001FN000009FN00;001FV@00EYT005JI001FV@00
EYT00002EYX00`00E[X00005000015Zj001J^P000UZj00/005[J001JfP00F]X005[K001Jf`00009J
f`03001Jf`00009Jf`06001Jf`00F]/005[k100000AJn`00F_/0009Nn`03001Nn`00009Nn`05001O
7000Ga`00002Ga`01P00Ga`00000Hc`0009S?004001S?6<l0002He`01000Ie`000000V]K00P006]k
Jg/006mk001_NP000g=j00<007=i00000WMi00@007MhMgQgN080009kM`04001kMg]g0002NgH01P00
NeIkEP00NeD000AkE@07001kE7]DNe@007/d00000g/d00H007/dNc@007/d0002Nc@01P00NaAk5000
Na@000=k5005001g5GLEMaD00002L_D01000K_I^mP000VkF00<006[G00000VJg00<006Jg00000V:g
00L006:H001NV000GYP00002FYP02P00FWP005Ih001FN000DUP004iH0P0000=66000@OP00`0000<0
e`0000000`0000H^G@00000fO@00>Wd200000cjM0012W@0600003DZl001:_000B[`004ZL001:W000
BY`004ZL0080000;BY/004ZK001:V`00BY/004Yk001:N`02000014Ik0016FdIK1P0000=6FP00@SX0
0P0000<n6P00?QT00P0000<in@0000000P0000`mn000000mf000?ML003gG000me`00BOL200003ThG
001>5P00DQH0058F001B=P00DSH005Hf0002ESH04`00ESH005Hf001F=P00ESH005Hf001F=P00ESH0
05Xf001JEP0000=JEP03001JEP0000800009GWH0069fHWH006:F001RUP00009VUP06001VUVJF001V
]P000VZf00<006[F00000V[G00L006[GJ]MZe`00J]L00002J]L01000J]MZe`000V[H0`000V[h00<0
06[h00000V[h00<006KhI_P00`000VKi00<006Ki00000VKi00@006Ki001Vn@80009Vn@05001Vn@00
I_X00002IaX00`00IaYW6P030002IaX00`00IaX00002IaX00`00IaYW6P0300001FLJ001W6VLJ0000
0V/j00<006/jJcX00`000V/j00L006/jJcX006/j001_>@020002KeT01@00KeU_F@00LeT00P000W=H
00@007=HLeP0009cF005001gEgMGMeL00002MeL01000MeMgE`000gMF00@007MFMeH0009gEP04001k
EW]F0003McH01000NcD000000WLf00@007Le0000009g5P04001g5WLF0002LaH01P00LaIc5P00L_H0
009^m`06001^mfkg001Zm`000V[G0`0001aVf000H[QR^000H[P005jh001NV000FYT005JI001FN@00
DWT004iI001>F@00BST004Hi00126@800003=MT00000008000038GP0000000<000053AL000000004
m`04000010TH000000eI0P0000@EVP00000Q^`@00006;Q`00000<S`003IL0`0000TjO000?W`0049l
0012O000@Y`00P0000I6W000AY`004ZL0002B[`00`00B[`0000>00001U:l001B_000D[`0009Bg003
001Bg00001D00008D]/005;K001Ff`00E]/0009Ff`0?001Ff`00E]/005KK001Ff`00E]/005KK001F
f`00009Ff`03001Ff`00009Ff`0=001Ff`00E]/005KK001Ff`00E]/005KK00007Woo00<007ooOol0
OGoo001DOol00`00Oomoo`030012Ool00`00Oomoo`1WOol600004UHf001F=P00ESH005Hf001F=P00
ESH005Hf001F=P00ESH0009FEP0;001FE`00EUL005IG001FE`00EUL00002EWL01@00EWP005Ih0000
0UIh00d005Ih001FN000EYT005JI001FV@00EYT00002EYT500001EZj001J^UZj00000UZj00/005Zj
001J^P00F]X005[J001JfP00009Jf`05001Jf`00F]/00002F]/01P00F]/005[K001Jf`800004F_/0
05[k0002F_/01`00F_/005kk001Nn`00009Nn`07001O75lL001O7000Ga`00P0000MS6`00HcaS?000
Hc`00002Hc`00`00HeaSG00200000f]K001[F`02Je/01000Jg][N`000fmj00D007=jLgYcNP0000Ag
N@03001gN000009gN003001kM`0000=kM`03001kMP0000=kEP03001kEG]E009kE@03001kE@00009k
E004001k=7/d0002Nc@01P00NcAk=000Nc@0009k=003001k5000009k5005001k57/DNa@00003MaD0
1000L_Ebm@000Vkf00@006kFK]H0009Ze`<0009V]`07001R]`00HYP005jH00000UjH00h005ZH001J
N000EWP005Ih001BF000CUP004Xh0P0000=1n000>MP01P0000HN7000000bG@00=Wd200000cjM000n
W@0200001D:M0012W000AY`0100000e:_000BY`004ZL001:W000BY`004ZL001:V`0200004DZK001:
V`00BW/004Yk0016N`00AW/004IK0016F`00@UX0100000=2>P00@SX00P0000<n6@00>OT00P0000He
f@00000mn000?MP200001CgG000me`00?ML00`0000m:5`00001>5P00DQH0058F001B=P00DSH005Hf
00000UHf00l005Hf001F=P00ESH005Hf001F=P00ESH005Hf00000UXf00<005YF00000UYF00L005YF
001NMP00GWH00002HWH00`00HYH00002HYH00`00IYH00002IYH30002J[H01P00J]IZeP00J]L000=Z
e`04001Zef[G0002J]L00`00J]L00002J]P00`00J_P00002J_P01P00J_QZn000J_P0009Vn006001Z
n6[h001Vn@000VKi00<006Ki00000VKi00<006Ki00000VKi00<006Ki00000VKj00@006LJ001W6P80
009W6P03001W6P00009W6P03001W6P00009W6P03001W6P00009W6P06001W6VLJ001[>P000V/j00H0
06/jJcX006/j0002JcX01000JcY[>P000Vli00@006mIKeT0009_F@04001cFG=I0002LeP30003LeP0
1000MeMgE`000WMG00@007MGMeL000=gEP04001gEP000002MeH01@00NeH007Lf00000WLf00d007/e
001g=P00McH007Le001g=P00MaH00002MaH01000LaIc5P000W<F00<007;f00000Vkg00H006kgK_L0
06[g0002J]L00`00I]P00002I]P07000H[P006:h001N^000GYP005ZI001FV@00EWT0059i001>F@00
CUT004Xi0016>@00@QT003gi0P0000<af@00:IP00P0000DMF000000000dG00<000041?L000000?L2
00001@TH000000005GT00P0000@I^P00000Uf`@00003<Q`0038l0080008jG080000Q?W`0049l0012
O000@Y`004JL0016W000AY`004ZL001:_000B[`004Zl001>_000C[`004jl001>_000C[`004jl00`0
000:D]`005;L001Bg000D]`005;L0002D]`03`00D]`005;L001Bg000D]`005;K001Bf`00E]/00002
E]/01@00E]/005KK00000UKK00<005KK00000P0000QFf`00E]/005KK001Ff`000UKK00l005KK001F
f`00E]/005KK001Ff`00E]/005KK00007Woo00<007ooOol0OGoo001DOol30016Ool00`00Oomoo`1P
Ool600004UHf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH0009F=P0?001F=P00ESH005IF
001FE`00EUL005IG001FE`00009FE`03001FM`00009FN00=001FN000EWP005Ih001FN000EYT005JI
00000UJI00<005JI00000P0000AJ^@00F[T0009J^P0<001J^UZj001J^P00F[X005Zj001JfP000U[J
00T005[J001Jf`00F]/005[K00000U[K00<005[K00000`0000]Jn`00F_]Jn`00F_/005[k001Jn`00
009Nn`03001Nn`00009Nn`04001O7000Ga`200001elK001S6f<K001S?000009S?003001S?6<l0080
0005Ie/006]KJe/00002Je/01@00Jg/006mj00000fmj00@007=j000000EgN@03001gN7Mh009gN003
001kMg]g00=kM`03001kEW]F009kEP8000=kE@06001kEG]E001kE0000g/d0P000g/d0P000g/d00<0
07/D00000g/D00@007/D000000=g5@04001bm@000002K_H01000K]I^eP000V[G00<006Jg00000VJg
00D006:g001RV000009NV00B001NV000FYP005Yh001FN000EWP0059H001>F000BSP004HH0P0000<i
f00000001P0000HV?@00000fO@00>Wd200001cjM0012W@00@Yd004:L00800003AY`004JL00H0000=
BY`004ZL001:W000BY/004ZK001:V`00BY/00P0000I:N`00AW/004Ik0002AU/200000d9J0012>P04
00000d8j000n6P02000013Wi000003GI100000Dmf000000me`00008me`800003@ML000000080000<
CQH0058F001B5P00DSH0058f001F=P000UHf00d005Hf001F=P00ESH005Hf001F=P00ESH00002ESH0
1@00FSH005YF00000UYF0`0000UNMP00GWINMP00HWH006:F00000V:F00<006JF00000VJF00H006Zf
J[H006Zf0002J]H01@00J]MZe`00J]L00P000V[G00H006[GJ]L006[G0002J]P01P00J_QZn000J_P0
009Zn003001Zn6[h00<0009Zn006001VnFKi001Vn@000VKi0`000VKi00<006Ki00000VKi00<006Kj
00000VLJ00<006LJ00000VLJ00<006LJ00000VLJ00<006LJIaX00`000VLJ00<006LJ00000VLJ00<0
06/jJcX00`000V/j00L006/jJcX006/j001[>P020002KcT01@00KeU_F@00KeT00P000W=I00@007=H
LeP0009cF005001cF7=H001gE`020002MeL01@00MeL007MG00000WMF00D007MF001gEP00009gEP80
0003McH007Lf009g=P04001g=WLf0002McH01000McIg=P000WLF0P0000Ec5P00LaIc5P00009c5P80
009^m`04001^mfkg0002J_L300003FKH001Vf6KH001R^000H[P005jh001NV000009JV@08001FV@00
EWT0059i001>F@800007BST004Hi00126@00?OT00P0000<af@0000000P0000LMF000000000dG000=
5`07000010TH000000eI1@0000@Q^`00000Yn`800009<Q`0038l000fG000>U`003YL00<0000=@W`0
0000@Y`004JL0016W000AY`004ZL00000TZl00`004Zl000004jl001>_000C[`004jl0002C[`20000
4Djl001B_5:l001B_000D[`005:l001Bg000D]`005;L00000U;L00d005;L001Bg000D]`005;L001B
g000D]`00002D]/01`00D]/005KK001Ff`00009Ff`06001Ff`00E]/005KK0`0000QFf`00E]/005KK
001Ff`000UKK00T005KK001Ff`00E]/005KK00000UKK00D005KK001Ff`0001ioo`03001oogoo07ao
o`00E7oo00<007ooOol0AWoo00<007ooOol0FWoo1P00019F=P00ESH005Hf001F=P00ESH005Hf001F
=P00ESH005Hf0002ESH04@00ESH005Hf001F=P00ESH005Hf001FEP00EUL005IG00000UIG00L005IG
001FE`00EWL00002EWP02`00EWP005Ih001FN000EWP005JI00000UJI1@0000UJ^@00F[UJ^@00F[T0
05Zj00000UZj00D005Zj001J^P00009J^P0<001JfP00F]X005[J001Jf`00F]/005[K1@0000AJf`00
F_/0009Jn`05001Jn`00F_/00002F_/01`00F_/005kk001Nn`00009Nn`@00007Ga/005lKGa/006<K
00000V<l00@006<l001S?08000=WF`04001[Ff]K0002Je/01@00KgY_NVmj00000fmj00@007=iLgT0
00=gN@8000AgN08000AkM`05001kEW]FNeH00002NeD01000NeEkE@000W]E0P001G/d00<007/dNc@0
0W/d00<007/dNc@00W/d0P000g/D00D007/D001g5000009g5@05001bm@00L_D00002K_H00`00K]H0
0002J]L02000I[MV]`00I[L006:g0002HYP05P00GYP005jH001JV000FWP005Ih001FN000DUP004iH
001:>000AQP0047h1`0000DEg000000002Xm00@00003?Yd003jM00800007@Yd004:L0016W000AY`0
0P0000E6W000AY`004JL00H0000;BY/004ZK001:V`00BY/004Yk001:N`020002AW/01P00AU/004IK
0012FP800003?SX0000000800003?QX003hI00800004>OT00000<KP200000cgH000mf0020002?ML2
00001D7G0011e`00CQL00P0000YB5P00DQH0058f001B=P00ESH0009F=P09001F=P00ESH005Hf001F
=P00009F=P0:001F=P00ESH005Xf001JEP00FUH2000015iF001NMP000Uif00D0069f001RUP00009R
UP03001VUP00009VUP06001Z]VZf001Z]P000V[F00<006[GJ]L00P0000E^eP00J]MZe`00009Ze`03
001Zef[G00<0009Zn006001Zn6[h001Zn0000V[h00H006[hJ_P006[h0002I_T01000I_T006Ki0P00
0VKi00<006Ki00000VKi00H006Ki001VnP00IaX20002IaX00`00IaX00002IaX01000IaX006LJ0P00
0VLJ00<006LJ00000VLJ00@006LJ001[>P80009[>P07001[>V/j001[>P00JcX00P000Vli00@006li
KcT0009_F@06001_FFmI001cF@000W=H00@007=HLeP000=cF004001gEgMG0002MeL200000gMG001g
EP02MeH01000MeIgEP000WMF00D007LfMcIg=P00009g=P04001g=WLf0002McH01000McIg=P000WLF
00@007<FLaH0009c5P06001c5W<F001^m`000Vkg00<006kg00000V[g00<006KH00000VKH00L006KH
001R^000H[P00002G[P04000GYP005ZI001FV@00EWT0059i001>F@00CUT004Xi0P0000E26@00?OT0
03GI00800006;KT000007EP001UH0P0000D=5`00000000Cg00<000051AL00000000=F@02000011VJ
0000026k0P0000<Yn`0000000P000S8l0P0000DjG000>U`003il00D00005@Y`00000AY`00002AY`0
7`00BY`004Zl001:_000B[`004jl001>_000C[`004jl001>_000C[`004jl001B_000D[`005:l001B
_000009Bg009001Bg000D]`005;L001Bg000009Bg00?001Bg000D]`005;L001Bg000D]/005;K001F
f`00009Ff`08001Ff`00E]/005KK001Ff`<00008E]/005KK001Ff`00E]/0009Ff`09001FfeKK001F
f`00E]/005KK00L001ioo`03001oogoo07aoo`00E7oo00<007ooOol0Agoo00<007ooOol0DGoo2000
019F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf0002ESH05`00ESH005Hf001F=P00ESH0
05Hf001F=P00ESH005Hf001FEP00EUL005IG00000UIG00L005IG001FE`00EWL00002EWP01`00EWP0
05Ih001FN000009FN003001FV@0000800004F[T005Zi0002F[T01`00F[T005Zi001J^P00009J^P0?
001J^UZj001J^P00F[X005[J001JfP00F]X005[K00@00005F]/005[KF]/00002F]/01`00F_/005[k
001Jn`00009Jn`08001Jn`00F_/005kk001Nn`<00004Ga/005lK0002Ga/00`00Ga/00002Ha/01000
Hc`006<l0P000VLk00P006MKIe]WF`00Je/006]K0P0016mj00@006mj000000=cN@03001gN@00009g
N004001gN7Mh0002MgL01P00NgMkM`00NeH0009kEP04001kEG]ENeD20004NeD00`00NcAk=003Nc@0
0`00NcAk=002Nc@00`00NcAk=002Nc@00`00NaAk5002Na@01@00Na@007LD00000gLE0P0000Ebm@00
K_I^mP00009^eP<0009V]`03001V]`00009R]`07001RV000GYP005jH00000UZH00X005Yh001FN000
EWP0059H001>F0800005AQP0047h000if00700001ahL00000000<Ud003IM00800007?Yd004:M0012
W@00@Y`00P0000M6W000AY`004JL0016W00200001DZL001:W000AY`0100001=:V`00BY/004Yk001:
N`00AW/004Ik0016F`00AU/0049J0012>P0200000chJ0000000200001ShI000003Wi000ef@D00003
?MP00000008me`05000me`000011e`0300001DhF001B5P00DQH00P0000AB=P00ESH0009F=P03001F
=P00009F=P0:001F=P00ESH005Hf001F=P00ESH6000015YF001NEP000Uif00D005if001RMP00009R
UP03001RUP00009VUP<0009Z]P06001Z]VZf001ZeP000V[G00D006kFK]I^eP00009Ze`03001Ze`00
009Ze`06001Zmf[g001Zn0000V[h00<006[hJ_P00`000V[h00H006[hJ_P006Ki0002I_T00`00I_T0
0002I_T00`00I_T00002I_T01000I_T006Kj0P000VLJ00<006LJ00000VLJ00<006LJ00000VLJ00<0
06LJ00000VLJ00H006LJIaX006LJ0002IaX00`00JcX00002JcX01000JcY[>P000V/j00<006/i0000
0Vli00D006liKcT006mI0080009_F@03001cFG=I00800005LeP007=HLeP00002LeP01000MeMgE`00
0WMG00D007MGMeMgE`00009gEP04001gEWMF0002MeH01P00McIg=WLf001g=P80009g=P04001g=P00
0002McH01000MaIg5P000W<F00@007<FLaH0009c5P03001^m`00009^m`03001^mfkg00<00009I]P0
06KHI]P006KH001R^000009R^004001N^000GYP=00000dXi0016>@0200001Cgi000ef@00<MT00P00
00<QN0007EP02P0000@96000000960<000035GT0000000<000039M/002Wk00@00007<S`003IL000j
G000>U`00P0000<nO000@W`01@0001A6W000AY`004ZL001:_000B[`004Zl001>_000C[`004jl001>
_0000Tjl0P00015>_000D[aB_000D[`005:l001B_000D]`005;L001Bg000009Bg00C001Bg000D]`0
05;L001Bg000D]`005;L001Bf`00D]/005KK00000UKK00L005KK001Ff`00E]/00002E]/03000E]/0
05KK001Ff`00E]/005KK001Ff`X00006E]/005KK001Ff`007Woo00<007ooOol0O7oo001DOol00`00
Oomoo`17Ool00`00Oomoo`1;Ool6000055IF001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH0
05Hf0002ESH07@00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001FEP00
EUL005IG00000UIG00D005IG001FE`00009FM`07001FN000EWP005Ih00000UIh1@0000]JV@00F[UJ
^@00F[T005Zi001J^@00009J^@03001J^P00009J^P09001J^P00F[X005Zj001JfP00009JfP<00004
F]X005[J0002F]/02000F]]Jf`00F]/005[k0002F_/02P00F_/005[k001Jn`00F_/005kk0P0000=O
6`00Ga/00UlK00D005lK001O6`00009O6`04001S6`00Hc`200000fLk001W>`02Ic/01@00Ie]WF`00
Je/00P000VmJ00<006mjKgX00Vmj00@007=iLgT000=cN@03001gN7Mh009gN003001gN00000=gM`03
001kM`00009kEP03001kEP0000AkE@03001kEG]E009kE@03001k=7/d00=k=08000=k=08000=k=003
001k57/D00=k5004001g57LD0003MaD01000L_Ebm@000Vkf00@006kFK]H0009Ze`03001V]`00009V
]`07001R]`00HYP005jH00000UjH400000E1n000>MP001dg008000030CT000fk008000049Sd00000
<Ud200000cIm0000000200001d:M0012W000AY`004JL00800009AY`004JL0016W000BY`004ZL0080
0003AY/004Ik00H00006BW/004Ik0016N`000TIK0P0000=2FP00@SX00P0000<n6P00>QX0100000@i
n@00000ef@80000:<KP00000?MP003gG000me`00?ML200000d7G0015m`0300002U8F001B5P00DSH0
058f001F=P000UHf00`005Hf001F=P00ESH005Hf001F=P00ESH3000015YF001JEP000UYF00X005iF
GUH005if001NMP00HWH0009RUP03001RUP00009VUP<0009Z]P06001Z]VZf001ZeP000V[G00D006kF
K]I^eP00009Ze`03001Zef[G00<0009Zm`06001Zn6[h001Zn0000V[h00H006[hJ_P006[h0002J_P0
0`00I_UVn@030002I_T00`00I_T00002I_T01000I_T006Ki0P0000EW6@00IaYW6P00009W6P06001W
6P00IaX006LJ0P000VLJ00<006LJ00000VLJ00@006LJ001W6P80009[>P07001[>V/j001[>P00JcX0
0P000V/i00@006liKcT0009_>@03001_>@00009_F@04001cFG=I0002LeP01@00LeQcF000LeP00P00
0WMG00@007MGMeL000=gE`04001gEP000002MeH01@00MeH007Lf00000WLf00D007Lf001g=P00009g
=P800005McH007Lf001g5P020003LaH00`00LaIc5P0300001Fkg001^mfkg00000Vkg00<006[g0000
0VKH00D006KH001Vf000009R^003001R^00000@0000;FYT005JI001FN@00DWT004iI001>F@050000
1T8I000003GI000af@@000077EP00000000E>0003AL0100000@96000000960H000037KX000000080
0004:O/00000<Q`300001cIL000jG000>U`003il00800005@W`004:L0016W00500001TZL001:_4Zl
001:_0800008C[`004jl001>_000C[`0009>_00C001>_000C[`005:l001B_000D[`005:l001Bg000
D]`005;L00000U;L00l005;L001Bg000D]`005;L001Bg000D]`005;K00000U;K00D005KK001Ff`00
009Ff`04001Ff`00E]/>000045KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`007Woo00<007oo
Ool0O7oo001DOol00`00Oomoo`18Ool00`00Oomoo`13Ool7000055IG001FE`00EUL005IF001F=P00
ESH005Hf001F=P00ESH005Hf0002ESH07`00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F
=P00ESH005Hf001F=P00ESH005Hf001FEP00009FE`05001FE`00EUL00002EUL02@00EUL005Ig001F
N000EWP00002EWP3000015jH001NV0000UZI00L005Zi001J^@00F[T00002F[T01@00F[T005Zj0000
0UZj00D005Zj001J^P00009J^PD00009G]X005[JF]X005[J001Jf`00009Jf`03001Jf`00009Jn`08
001Jn`00F_/005[k001Jn`@00005G_/005lKGa/00002Ga/00`00Ga/00002Ga/01000Ga/006<K0P00
00ES>`00Ic]W>`00009W>`05001WFfMKIe/00002JeX01000KeY_FP000fmj00T007=iLgUcN@00LgT0
07=h000017Mh00<007MgMgL00gMg00<007]FNeH00W]F00<007]ENeD00g]E00L007]ENeEkE@00NcD0
0003Nc@00`00Nc@00002Nc@00`00Nc@00003Nc@20004Na@01@00MaAg57LD00000WLE00@007;eL_D0
009^mP04001^eVkF0002J]L00`00I[L00002I[L01@00H[L006:H00000UjH0`0000eJV000FWP005Ih
001FN000DUP004iI001:>@0400000cWH0000000600001aGL00000000<Ud003IM00800003>Wd003im
00800009@Y`004JL0016W000AY`004JL00800009AY`004ZL001:W000AY`004JK00800005AW/004Ik
0016N`040002AW/01P00AU/004IK0012FP800006?SX00000>QX003Wj0P0000Hin@00000ef@00<KP5
00001cgG000me`00?ML0047G00800003AOL004Wf00<00008DQH0058f001B=P00ESH0009F=P08001F
=P00ESH005Hf001F=PD00006FSH005YF001JEP000UYF00P005iFGUH005if001NMP000V9f00D006:F
001RUP00009VUP06001Z]VZf001Z]P000VZf00<006[FJ]H00`000fkF00@006[GJ]L0009Ze`03001^
m`00009Zm`04001Zn6[h0002J_P30002J_P01P00J_QZn000J_P0009Vn@06001ZnF[i001Vn@000VKi
00<006Ki00000VKi00<006LI00000VLI00<006LJ00000VLJ00@006LJ001W6P80009W6P03001W6P00
009W6P04001W6P00IaX20002JaX00`00JcX00002JcX01000JcY[>P000V/i00<006/i00000Vli00@0
06li0000009_>@03001_FFmI00<000=cF004001cF7=H0002LeP00`00MeMgE`0200002GMG001gEgMG
001gEP00MeL00002MeH200000gLf001g=P02McH01000McIg=P000WLf00@007LfMcH0009g=P800005
MaH007<FLaH00002LaH01P00LaMc5`00K_L0009^m`<0009Zm`05001Vf000I]P00002I]P00`00H[P0
000200004ejh001NV@00FYT005JI001FN@00DWT004iI001>F@00BST004Hi00<00003?OT003GI0080
0003;KT00000008000046EP000005CP300001@dG000000003CP00`0000@AF@00000IVP8000038M/0
0000008Yn`<0008b?0800009>U`003YL000nO000?W`0049l00800004AY`004JL0002AY`9000064jl
001>_000C[`004jl001>_000C[`004jl001B_000D[`005:l001B_000D]`0009Bg007001Bg000D]`0
05;L00000U;L00X005;L001Bg000D]`005;L001Bf`h0000<E]/005KK001Ff`00E]/005KK001Ff`00
0UKK00T005KK001Ff`00E]/005KK00000UKK00D005KK001Ff`0001ioo`03001oogoo07]oo`00E7oo
00<007ooOol0B7oo00<007ooOol0?Goo1P0001EFE`00EUMFE`00EUL005IG001FE`00EUL005IF001F
=P00ESH005Hf00000UHf02<005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F
=P00ESH005Hf001F=P00ESH005Hf001F=P00009FEP05001FE`00EUL00002EUL01`00EUL005IG001F
M`00009FN003001FN00000800004GYP005jH0002GYP01`00FYT005Zi001J^@00009J^@05001J^@00
F[T00002F[X00`00F[X00002F[X00`00F[X00002000015kJ001NfP000UkJ00D005[J001JfP00009J
f`0=001Jfe[K001Jf`00F_/005[k001Jn`00F_/00P0000ANn`00G_/0009Nn`03001O6`0000=O6`06
001O6`00Ga/005lK0P0000ES>`00Hc]S>`00009W>`05001W>fLk001WF`020003JeX02000KeY_FP00
KgX006mJ0003LgT01@00LgQcN7=h00000gMh0P0017Mg00<007]FNeH00W]F0P000g]E00<007]E0000
0W]E00@007/eNcD0009k=008001k=7/d001k=000Nc@0009k=003001k500000Ak5006001g57LDMa@0
07LE0P000g;e00<006kfK_H00`000V[G00P006JgI[L006Jg001R]`000V:H0`00015NV000FYP005Yh
001FN000EWP0059H001>F@00BST004HI00P000030?L00000008000047O`00000<Ud200000cIm000j
O@0200000cim0000000200002dJL0016W000AY`004JL0016W000BY`00P0000U6W000AY/004Ik0016
N`00AW/00P0000=6N`0000000`0000M6F`00AU/0049J0012>P02000013hJ000003Wj100000@in@00
000a^0800005;IP00000?ML00002?ML200000d7G0011e`0200000dWf001>5P050000158f001F=P00
0UHf00<005Hf00001P0000YF=P00ESH005Xf001JEP00FUH0009JEP08001NEUiF001NMP00GWH0009R
MP03001RUP00009RUP03001VUP00009Z]P06001Z]VZf001Z]P000V[F00@006kFK]H0009^eP04001Z
ef[G0002J]L01000K_M^m`000V[g00<006[h00000V[h00H006[hJ_P006[h0002J_P00`00J_QZn003
0002J_T00`00I_T00002I_T01000I_T006Ki0P000VLI00<006LI00000VLJ00@006LJ001W6P800005
IaX006LJIaX00002IaX00`00IaX00002IaX00`00JaX00002JaX01`00JcY[>P00JcX006/j0080009[
>@04001[>F/i0002KcT00`00KcT00002KcT01000KeU_F@000W=H00@007=HLeP0009cF004001cF7=H
0002MeL01000MeMgE`000gMG00@007MGMeL0009gEP05001g=WLfMcH00002McH01000McIg=P000WLf
00@007LfMcH0009g=P04001g5WLF0002LaH01000LaIc5P000W<G00<006kg00000Vkg00<006[g0000
0V[g00D006KH001Vf000009Vf0<00006H[P005jh001NV@000UZI00P005JI001FN@00DWT004iI0P00
00E:>@00AST0048I00<00003=MT0037I00<000039IP00000008000055CP00000000=5`0200000`TH
0000000700000afj00000002000022Wk0000038L000b?000=S`300005SYL000003il0012O000@Y`0
04JL0016W000AY`004ZL001:W000B[`004Zl3`000U:l00P005:l001B_000D[`005;L5P0000ABf`00
D]/0009Ff`0?001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`03001Ff`00009Ff`0?001F
f`00E]/005KK001Ff`00E]/005KK001Ff`0001ioo`03001oogoo07]oo`00E7oo00<007ooOol0BGoo
00<007ooOol0=Woo1P0000QFN000EWP005Ih001FE`000UIG00T005IG001FE`00EUL005IG00000UIF
02L005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00
ESH005Hf001F=P00ESH005Hf00000UHf00T005Hf001FEP00EUL005IG00000UIG00D005IG001FE`00
009FM`D00004GYP005jH0002GYP01@00GYP005ZI00000UZi00D005Zi001J^@00009J^@05001J^@00
F[X00002F[X500002EkJ001NfUkJ001NfP00G]X00002F]X01@00F]X005[K00000U[K00H005[K001J
n`00F_/400001ekk001Nnekk001Nn`00009Nn`03001O6`00009O6`04001O6`00Ga/200001F<K001S
>f<k00000V<k00D006LkIc/006Lk0080009[F`06001[FV]JJeX006mJ0P000fmJ00@007=iLgT000Ac
N003001gN000009gM`06001gMgMg001gE`000W]F00@007]FNeH0009kE@06001kEG]E001kE@000W/e
00@007/dNc@0009k=003001k=000009k=003001k=000009k5005001k57/DNa@00003Ma@01@00MaD0
07Ke00000W;e00@006kfK_H0009^eP03001Ze`00009V]`03001V]`00009R]`<00004GYP005jH0002
FYP02P00FWP005Ih001FN000DUP004iI0P0000=66@00?OT0100000<8eP0000000`0000LEg0000000
039M000fG@0200000cYm000nO@0200000d9l0012W00400002dJL0016W000AY`004ZL001:W000AY`0
0P0000M6N`00AW/004Ik0016N`020000149K0012Fd9K100000=2FP00@SX00P0000<n6P00>QX00P00
00Hef@00000in@00=MT20000136h000003gH0P000SgG0P0000=1e`00@ML00P0000M9mP00CQH004hF
001B5P0:00003UHf001F=P00ESH005Hf001F=P00FSH005YF0002FUH00`00FUH00002GUH01@00GWH0
05if00000V9f00<006:F00000V:F0`000VZf00H006ZfJ[H006Zf0002J]H01000K]I^eP000VkF00@0
06[GJ]MZe`<0009^m`04001Zmf[g0002J_P30002J_P01P00J_QZn000J_P0009Zn006001ZnF[i001Z
n@000VKi00<006Ki00000VKi00H006LIIaT006LI0002IaT00`00IaX00002IaX00`00IaX00002IaX0
0`00IaX00002IaX01000IaX006LJ0P000V/J00L006/JJaX006/j001[>P020002JcX01`00JcU[>@00
JcT006li0080009_>@03001_>@00009_F@04001cF7=H0002LeP01000LeP000000W=H00@007MGMeL0
00=gE`04001gEgMG0002MeL01000MeIgEP000gLf00@007Lf0000009g=P07001g=P00McH007Lf0000
0WLf00@007LFMaH000=c5P<0009c5`03001^m`00009^m`08001Zmf[g001Zm`00I]P0009Vf007001V
f000H[P006:h00000Ujh010005jI001JV@00EYT005Ii001BN@00CUT004iI001:>@800003@QT003hI
00<00006<MT00000:IT002FH0`0000<E>0000000100000@96000000=>0<000065GX000007KX0027K
100000<^6`0000000S8l0P0000<jG0000000100000Q2O000@Y`004JL0016W0000TJL0P0000i:W000
B[`004Zl001:_000C[`004jl001>_0000Tjl00@004jl001>_0/00004D[`005;L0002D]`03`00D]`0
05;L001Bg000D]`005;L001Bg000D]/00002D]/03000D]/005KK001Ff`00E]/005KK001Ff`80000:
E]/005KK001Ff`00E]/005KK0002E]/03`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0000NOol0
0`00Oomoo`1kOol005=oo`03001oogoo04Yoo`03001oogoo031oo`H0000<EYT005Ih001FN000EWP0
05Ih001FN0000UIG00D005IG001FE`00009FE`0[001FE`00EUL005IF001F=P00ESH005Hf001F=P00
ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf00000UHf
00/005Hf001F=P00EUH005IG001FE`00009FE`03001FE`00009FE`<00006GYL005jH001NV0000UjH
00D005jH001NV000009JV@05001J^@00F[T00002F[T02000F[T005Zi001J^P00F[X2000015kJ001N
fP000UkJ00D005kJ001NfP00009NfP05001JfP00F]X00002F]/01P00F]/005[K001Jn`800004G_/0
05kk0002G_/00`00G_/00002G_/00`00G_/00002Ga/01000Ga/005lK0P0000ES6`00Ha]S6`00009S
>`05001S>f<k001W>`0200000f/k001[F`02Je/01`00JeY[FV]J001_FP0000=_FP05001cN@00LgT0
0004LgP00`00MgMgM`02MgL00`00MgL00002MeL00`00NeH00003NeH00`00NeD00002NeD20004NcD2
0003Nc@20003Nc@00`00Nc@00002Na@01P00NaAk5000Ma@0009g5005001g5@00M_D00002L_D01000
K_I^mP000VkF00H006[GJ]L006Jg0002I[L3000016:h001NV0000UjH00h005ZH001JN000EWP005Ih
001BF000CUT004Xi0P0000Dmn@00000001dg00P000037O`0000000<00003=Wd003Ym00800003?Wd0
049l00800003@Y`004:L00@0000;AY`004ZL001:W000AY`004JK0016N`0200002dIk0016N`00AW/0
049K0012F`00@U/00`0000A2FP00000n>P800003>QX003Wj00D00004=MT00000<KP50002?ML20000
1D7G0011e`00AOL00P0000Y>5P00CQH0058F001B5P00DSH0009F=P0?001F=P00ESH005Hf001F=P00
ESH005Hf001J=P00009JEP03001JEP00009JEP05001NEP00GWH00002GWH01@00HWH006:F00000V:F
00<006Zf00000VZf00@006ZfJ[H0009Z]P<0009^eP04001^eVkF0003J]L00`00K_L00002K_L01000
J_MZm`000V[h00<006[h00000V[h00@006[hJ_P0009Zn0<0009Zn@06001ZnF[i001Vn@000VKi0`00
0VLI00<006LI00000VLI00@006LJ001W6P80009W6P03001W6P00009W6P04001W6P00IaX20002IaX0
0`00JaX00002JaX01P00JcY[>P00JcX0009[>P04001[>F/i0002JcT00`00KcT00002KcT00`00KcU_
>@0200001FmI001cF7=H00000W=H00@007=HLeP0009cF0800006MeL007MGMeL007MG0P000gMG0P00
00Ug=P00McIg=P00McH007Lf00000WLf0P0000Qg=P00McH007Lf001g=P000WLF00@007<FLaH0009c
5P03001c5`00009^m`<0009Zm`05001Zm`00I]P00002I]P3000066:h001R^6:h001N^000GYT005ZI
001FV@00EWT0059i001>F@00CUT004Xi0016>@800003?QT003Wi00<00004;KT000009IP400001ADh
000000003AL00`0000D=>0000000015I00D000038M/00000008Yn`800005<Q`0038l000f?0020000
0cYL000nO00300000d9l00000002AY`03000AY`004JL001:W000BY`004Zl001:_080000GC[`004jl
C[`004jl001>_000C[`004jl001>_000D[`005:l001B_000D[`00002D[`04`00D]`005;L001Bg000
D]`005;L001Bg000D]`005;L001Bf`00009Bf`03001Bf`00009Ff`06001Ff`00E]/005KK0`0000IF
f`00E]/005KK0002E]/04@00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK00000UKK00<007oo
Ool06goo00<007ooOol0Ngoo001COol00`00Oomoo`1;Ool00`00Oomoo`0YOol600001UJI001FV@00
EYT0009FV@80000;EWP005IhEWP005Ih001FN000EUL00002EUL0:@00EUL005IG001FE`00EUL005IF
001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf
00000UHf014005Hf001F=P00ESH005Hf001F=P00EUH005IG001FE`00009FE`03001FEeIG00<00006
GWL005jG001NV0000UjH00D005jH001NV000009NV005001JV@00F[T00002F[T01P00F[T005Zi001J
^@@00009G]X005kJG]X005kJ001NfP00009NfP05001NfP00G]X00002F]X01P00F]X005[K001Jf`@0
0009G_/005kkG_/005kk001Nn`00009Nn`03001Nn`00009Nn`04001O6`00Ga/200001F<K001S6f<K
00000V<K00<006<k00000f<k00<006Lk00000V/k00H006]KJe][F`00JeX20002KeX01@00KeY_FVmJ
00000g=i00D007=hLgQcN00000EgM`03001gEgMG009gE`03001kEW]F00=kEP03001kEG]E009kE@03
001k=G/e00=k=@03001k=7/d009k=004001k=7/dNc@20003Na@01P00NaAk5000Ma@000=g5004001f
mGKe0002L_D01000K_H000000VkF00H006[GJ]L006Jg0002I[L01@00H[L006:h00000UjH018005jH
001JV000FWP005Ih001FN000DUP004iI001:>@00AQT200000cGH0000000700001aGL00000000:Sd0
02iM00800003>Wd003im00800005@W`004:L0012W00200000dJL0016W00600002DJL0016V`00AW/0
04Ik0016N`02000014Ik0012F`000T9K0P0000<n>`000000100000@n6P00000inP800006<MT00000
=MT0036h0P0000P]V000000me`00?ML003gG0P0000E1e`00AOL004Wf00800008CQH0058F001B5P00
DSH0009F=P0;001F=P00ESH005Hf001F=P00ESH00002ESH01`00FSH005YF001JEP00009JEP05001N
EP00GWH00002GWH00`00HWH00002HYH00`00HYH00002J[H00`00J[H00002J[H01000J[IZ]P000VkF
00<006kF00000VkF00D006[GJ]MZe`00009^m`06001^mfkg001Zm`000V[h00@006[hJ_P0009Zn003
001Zn000009Zn006001Zn6[h001Zn@000V[i00@006Ki001Vn@80009W6@03001W6@00009W6@04001W
6@00IaX20002IaT00`00IaX00002IaX00`00IaX00002IaX00`00IaX00002IaX01`00JaY[6P00JaX0
06/j0080009[>P07001[>V/j001[>@00JcT00P000Vli00<006li00000Vli00@006mIKeT0009cF004
001cF0000002LeP01000LeQcF0000WMG00D007MGMeMgE`00009gE`04001gEgMG0002McH01@00McIg
=WLf00000WLf00@007LfMcH0009g=P03001g=WLf00800005McH007LFMaH00002LaH01P00LaIc5P00
LaL0009^m`03001^m`00009Zm`03001Zm`00009Vf005001Vf000H]P00002H[P01`00H[P005jh001N
V@00009JV@08001FV@00EWT0059i001>F@800005BST004Hi00126@020002>OT500000bFH000QN002
00001ADh000000003AL02P0000DIVP000000027K00800003:O/002hK00800005<S`003Hl000jG002
00000cil000nO00500005TJL0016W000AY`004ZL001:W000B[`004Zl001:_000C[`004jl001>_000
0Tjl00@004jl001>_0800008D[`005:l001B_000D[`0009B_003001Bg000009Bg00A001Bg000D]`0
05;L001Bg000D]`005;L001Bf`00D]/00002D]/02000E]/005KK001Ff`00E]/300001UKK001Ff`00
E]/0009Ff`05001Ff`00E]/00002E]/02P00E]/005KK001Ff`00E]/005KK0`007Woo00<007ooOol0
NWoo001COol00`00Oomoo`1<Ool00`00Oomoo`0ROol600001UJI001FV@00EYT0009FV@0C001FV@00
EYT005JI001FN000EWP005Ih001FN000EWP005IG00000UIG02<005IG001FE`00EUL005IG001FEP00
ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00009F=P0E001F=P00
ESH005Hf001F=P00ESH005Hf001F=P00ESH005IF001FE`00009FE`03001FEeIG00<00004GWL005ig
0002GYL02@00GYP005jH001NV000GYP00002GYP00`00FYT00002F[T01P00F[T005Zi001J^@800004
G[T005ji0002G]X01@00G]X005kJ00000UkJ00D005kJ001NfP00009NfP06001JfP00F]X005[K0P00
00ANnP00G_/0009Nn`05001Nn`00G_/00002G_/01`00G_]Nn`00G_/005kk00@00005Ha/006<KHa/0
0002Ha/00`00Ha/00002Hc/01000Hc/000000VLk00@006/kJc/0009[F`80009_FP05001_FVmJ001_
FP020004LgT01@00LgP007MH00000gMg0P0017MG00<007]FNeH00g]F00<007]ENeD00W]E00<007/e
NcD00g/e00<007/dNc@00W/d00<007/dNc@00W/d00<007/DNa@00W/D00D007/D001g500000=g5004
001fmGKe0003L_D2000016kf001^eP000V[G00<006JgI[L00`0000]R]`00H[QR^000GYP005jH001J
V000009JN006001FN000EWP0059H0P0000E:>@00AQT003gi00`000047O`00000:Sd20000239M0000
03im000nO@00@W`200001D:L0012W000AY`00P0000E6W000AW`004Il00@0000?AW/004Ik0016N`00
AW/004Ik0012F`00@U/0049K00800003?SX003XJ00800003?QX003XJ00800003=MT0000000<00004
<KP00000;IP400000cgG000me`0200002D7G0015m`00BOH004hF001>5P020000158F001B=P000UHf
00L005Hf001F=P00ESH00002ESH02`00ESH005Hf001J=P00FUH005YF00000UYF00<005iF00000Uif
00D005if001RMP00009RUP<0009Z]P06001Z]VZf001Z]P000VZf00@006kFK]H0009^eP05001^eVkF
001Ze`020002K_L01000K_M^m`000V[g0`000V[h00@006[hJ_P0009Zn0<0009Zn006001ZnF[i001Z
n@000VKi00<006/I00000VLI00H006LIIaT006LI0002IaT00`00IaT00002IaT00`00IaX00002IaX0
1000IaX006LJ0P000VLJ00H006LJIaX006/J0002JaX01P00JcY[>P00JcX0009[>P06001[>F/i001_
>@000Vli00<006liKcT00`000fmI00@007=HLeP0009cF003001cF000009cF005001gEgMGMeL00002
MeL01000MeMgE`000WMG00D007LfMcIg=P00009g=P04001g=WLf0002McH01`00McIg=WLf001g=P00
009g=P05001g5WLF001c5P020002LaH01P00LaMc5`00K_L0009^m`03001Zm`00009Zm`03001Vf000
0080009Rf005001R^000H[P00002G[P04000GYT005ZI001FV@00EWT0059i001>F@00CUT004Xi0P00
00M26@00?QT003Wi000ef@0200000bVI000UV003000011Dh0000014h0`0000@=>000000=>0<00004
5GX000007KX400001BWk000^6`00<Q`0100000<jG000>U`00P0000DnO000@W`0049l00D00096W080
000:BY`004Zl001:_000B[`004jl0002C[`05@00C[`004jl001>_000C[`004jl001B_000D[`005:l
001B_000D[`00002D]`04@00D]`005;L001Bg000D]`005;L001Bg000D]`005;K00000U;K00l005;K
001Ff`00E]/005KK001Ff`00E]/005KK00000UKK00L005KK001Ff`00E]/00002E]/=00000eKK001o
o`0MOol00`00Oomoo`0GOol7000:Ool4001>Ool005=oo`03001oogoo04aoo`03001oogoo01aoo`H0
0006E[X005Jj001FVP000UJI01T005JI001FV@00EYT005JI001FV@00EYT005Ih001FN000EWP005Ih
001FN000EUL00002EUL07@00EUL005IG001FE`00EUL005IF001F=P00ESH005Hf001F=P00ESH005Hf
001F=P00ESH005Hf00000UHf01T005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf
001F=P00EUH00002EUL01000EUL005IG0P0000ANM`00GWL0009NM`09001NU`00GYP005jH001NV000
009NV003001NV000009JV@06001J^@00F[T005Zi0P0000AN^@00G[T0009N^@03001NfP00009NfP07
001NfP00G]X005kJ00000UkJ00@005kJ001JfP@00009G_X005kjG_X005kk001Nn`00009Nn`03001N
n`00009Nn`04001Nn`00G_/2000015lK001S6`000V<K00H006<KHa/006<K0002Ha/01000Hc/00000
0VLk00X006LkIc/006/k001[F`00JeX000=_FP04001_FVmJ0002LeT00`00LgUcN@02LgT01`00MeQg
F7MH001gM`00009gE`06001gEgMG001gEP000g]F00<007]F00000W]E00<007]E00000g/e00<007/e
00000W/d00<007/e00000g/d00<007/DNa@00W/D0P000gLD00@007LDMa@000=fm@04001bmG;e0002
K_H01P00K]I^eP00J]L0009V]`03001V]`00009R]`05001R^000GYP00002GYP03P00FYP005Yh001F
N000EWP0059H001>F@00BST200000cgi0000000200000`SF0000000400001a6k00000000:Sd002iM
0080000:=Ud00000?Wd0049l0012W000@Y`200001dJL0016W000AY`004Il00800003AW`004Il00@0
000=AW/004Ik0016N`00@U/0049K0012F`00?S/00P0000<j6P0000000P0000<j6P00>OX00`0000@]
^@00000a^080000:;IP00000;GL003gG000me`00@ML2000044Gg0019mP00CQH004hF001B5P00DQH0
058f001F=P000UHf014005Hf001F=P00ESH005Hf001F=P00FSH005YF001JEP00009JEP0:001NEUiF
001NMP00GWH0069f0002HYH00`00IYH00002J[H01000J[IZ]P000VZf0`000VkF00@006kFK]H0009^
eP800005K_H006kgK_L00002K_L01000J_MZm`000Vkg00<006[h00000V[h00@006[hJ_P0009Zn003
001Zn000009Zn@03001ZnF[i00<0009[6@03001W6@00009W6@04001W6@00IaT20002IaT00`00IaT0
0002IaX01000IaX006LJ0P000VLJ00<006LJ00000VLJ00@006/J001[6P80009[>P07001[>V/j001[
>P00JcT00P000Vli00<006li00000Vli00@006liKcT0009_F@04001cF7=H0002LeP00`00LeQcF002
00001W=H001gEgMG001gE`80009gE`05001gE`00MeL00002McH01000McH000000WLf00D007Lf001g
=P00009g=P03001g=P0000=g=P03001g5WLF00800004LaH007<F0002LaL30002K_L00`00J_L00002
J_L300001fKH001Rf6;H001R^000009R^00D001N^000GYT005ZI001FV@00EWT0059i001>F@00CUT0
04Xi0016>@800005?QT003Wi000ef@0400000bFH0000000300001A4h000000003AP02@0000PIVP00
000Qf`009M/002Wk0P0000<b7000<S`0100000LjG000?W`003il0012O0020002AY`00`00AY`00004
00001DZL001:_000B[`00P0001M>_000C[a>_000C[`004jl001>_000C[`004jl001B_000D[`005:l
001B_000009B_00C001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`005;K00000U;K00<005;K
00000UKK00H005KK001Ff`00E]/300000eKK0000000:000035KK001Ff`00E]/005KK001Ff`00E]/0
009Ff`03001oogoo01]oo`03001oogoo01Moo`L000Qoo`P004aoo`00Dgoo00<007ooOol0CGoo00<0
07ooOol05Goo1P0000IF^P00E[X005Jj0002E[X04@00E[X005JJ001FV@00EYT005JI001FV@00EYT0
05JI00000UJI0P0002=FN000EWQFN000EWP005Ih001FE`00EUL005IG001FE`00EUL005IG001FEP00
ESH005Hf001F=P00ESH005Hf001F=P00009F=P0M001F=P00ESH005Hf001F=P00ESH005Hf001F=P00
ESH005Hf001F=P00ESH005Hf001F=P00ESH00002EUH00`00EUL00003000015ig001NM`000Uig00T0
05ig001NU`00GYP005jH00000UjH00<005jH00000UjH00H005ZI001J^@00F[T2000015ji001N^@00
0Uji00D005ji001NfP00009NfP03001NfP00009NfP06001NfP00G]X005kJ0P0000ANfP00G]X0009N
nP05001NnP00G_/00002G_/02@00G_]Nn`00G_/005kk001Nn`0200001ekk001O6elK001S6`00009S
6`03001S6`00009S6`06001S6`00001W>`000VLk00D006LkIc/006/k008000=[FP05001_FVmJ001_
FP020003LeT01@00LgUcNG=i000017MH00<007MGMeL00WMG00<007MG00000WMF00<007]F00000g]F
00D007]E001kE@0000=k=@03001k=@00009k=003001k=@00009k=003001k=@0000Ak5006001g57LD
Ma@007LD0P000gKe00@007;eL_D0009^mP04001^eVkF0002J]L30002I[L01@00H[L006:h00000UjH
018005jH001JV000FWP005Ih001FN000DUP004iI001:>@00AQT>000011WL000002Xm0P0000@bG@00
000jO@@00007@Y`004:L0012W000AY`00P0000M6W000AW`004Il0016O00200000dIk0012N`040002
AW/20002@U/200000chk000n>P0200000cXJ00000002000013Wj0000037I1@0000@a^000000]M`<0
0006?ML00000@ML0047G0P0000i9mP00CQH004hF001B5P00DQH0058f001F=P000UHf014005Hf001F
=P00ESH005Hf001F=P00FSH005YF001JEP00009JEP08001NEUiF001NMP00GWH0009RMP03001RUP00
009VUP03001Z]P00009Z]P03001Z]VZf00800004K]H006kF0002K]H01000K]I^eP000fkf00<006kg
00000Vkg00@006[gJ_L0009^m`04001Zn6[h0002J_P30002J_P01P00J_QZn000J_T0009Zn@06001[
6F/I001[6@000VLI00@006LI001W6@80009W6@03001W6@00009W6@03001W6P00009W6P03001W6P00
009W6P07001W6VLJ001W6P00JaX00P0000=[>P00JcX00V/j00<006/j00000V/j00<006/i00000Vli
00<006liKcT00`000Vli00D006mIKeT007=H0080009cF004001cF7=H0002LeP01@00MeMgEgMG0000
0WMG00<007MGMeL00P0000UgE`00McIg=P00McH007Lf00000WLf0P0000Ig=P00McIg=P00McH20002
McH01000MaIg5P000W<F00<007<F00000W<G00H006kgK_L006kg0002J_L01@00J_L006KH00000VKH
00<006;H00000V:h00/006:h001N^000GYT005ZI001FV@00009FN@0;001BN@00001>F@00BST004Hi
00126@020002>OT200001S7I000002FH000QN0<000034CP0000000@000054EP00000000EN@020000
1AVJ000M^P008M/00P0000<Yn`00;Q/00P0000<b?000=S`0100000lnO000?W`0049l0012O000AY`0
04JL0016W000AY`02@0000I>_000C[`004jl0002C[`01000C[`004jl0P0000QB_000D[`005:l001B
_0000U:l00<005;L00000U;L018005;L001Bg000D]`005;L001Bg000D]`005;K001Bf`00D]/>0000
15KK001Ff`000UKK014005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`03001oogoo
01aoo`03001oogoo01Uoo`8000Yoo`8000Aoo`8004aoo`00Dgoo00<007ooOol0CGoo00<007ooOol0
3goo1P0000IF^P00E[X005Jj0002E[X04@00E[X005Jj001F^P00E[X005JJ001FV@00EYT005JI0000
0UJI02D005JI001FV@00EYT005Ih001FN000EWP005Ih001FN000EUL005IG001FE`00EUL005IG001F
E`00EUH005Hf001F=P00ESH00002ESH08@00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F
=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH00002ESH00`00EUH0000200001eig001NMeig001N
M`00009NM`07001NM`00GYL005jH00000UjH00D005jH001NV000009NV004001JV@00F[T2000015ji
001N^@000Uji00D005ji001N^@00009NfP03001NfP00009NfP06001NfP00G]X005kJ0P0000]NfP00
G]YNfP00G]X005kj001NnP00009Nn`09001Nnekk001Nn`00G_/005kk00800009G_/005kkG_/005lK
001S6`00009S6`05001S6f<K001S6`0200001FLk001W>fLk00000VLk00H006LkIc/006/j0004JeX0
1000KeY_FP000VmI00T007=ILeUcF@00LgT007=H00000gMH00<007MGMeL00gMG00L007MFMeIgEP00
NeH00003NeH00`00NeD00002NeD00`00NcD00003NcD00`00Nc@00002NcD01@00Nc@007/e000017/D
00T007LDMaAg5000Ma@007LE00000WKe00@007;e0000009^mP04001^eVkF0002J]L00`00I]L00002
I[L00`00H[L00002H[P05000GYP005jH001JV000FWP005Ih001FN000DUP004iI001:>@00AQT20000
0cGH0000000700000`Ej0000000200000bXm000^G@0200001SIM000003Yl000nO0800009@Y`004:L
0016W000AY`004JL00800007AW`004Il0016O000AW/00P0000=2N`0000000`0000E2F`00@U/0049K
00800003?SX003XJ00800003=OX0000000800005=MT00000000YV0020000136h000002eg0P0000L]
M`000000047G0011e`02000034Wf001>5P00CQH0058F001B5P00DSH0009F=P0C001F=P00ESH005Hf
001F=P00ESH005Hf001J=P00FUH005YF00000UYF00P005iFGUH005if001NMP000V9f0`000VJF00<0
06Zf00000VZf00@006ZfJ[H0009^eP06001^eVkF001^eP000VkF00L006kfK_I^mP00K_L00003K_L3
0002K_L01000J_QZn0000V[h00H006[hJ_P006[h0002J_P00`00J_UZn@030002JaT00`00JaT00002
IaT01P00IaUW6@00IaT0009W6@03001W6@00009W6@04001W6P00IaX20002IaX01P00IaYW6P00IaX0
009W6P03001[6P00009[>P07001[>V/j001[>P00JcX00P000V/i00<006li00000Vli00@006liKcT0
009_>@04001_FFmI0002LeP00`00LeQcF0030003LeP01000MeMgE`000WMG00@007MGMeL0009gE`05
001g=WLfMcH00002McH01000McIg=P000WLf00L007LfMcIg=P00McH00002McH01000MaIg5P000W<F
00H007<FLaH007<G0002K_L00`00K_L00002J_L300001FKH001Vf6KH00000V;H00L006:h001R^000
G[P00002GYT01000FYT005JI1`0000a>F@000016>@00@QT003hI000in@00=MT500000b5h00000003
00001A4h000000003CP00`0000<AF@0000000P0000HIVP00000Qf`009O/200000bhK000b70020000
0cHl000jG004000013il0012O49l0P000TJL0P0000]6W000AY`004ZL001:W000B[`004Zl0100000;
D[`005:l001B_000D[`005:l001Bg00E00002E;K001Bf`00D]/005KK001Ff`03000015KK001Ff`00
0UKK00L005KK001Ff`00E]/00002E]/03@00E]/005KK001Ff`00E]/005KK001Ff`0001ioo`03001o
ogoo01Uoo`8000Uoo`8000Ioo`8004]oo`00Dgoo00<007oo00000P00C7oo00<007ooOol01Woo2000
00IF^P00E[X005Jj0002E[X04@00E[X005Jj001F^P00E[X005Jj001F^P00E[X005JJ00000UJI01T0
05JI001FV@00EYT005JI001FV@00EYT005Ih001FN000EWP005Ih001FN000EUL00002EUL0<@00EUL0
05IG001FE`00EUL005IF001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH0
05Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00009F=P03001F=P0000800004FUH005ig0002
GWL02P00GWMNM`00GWL005ig001NU`000UjH00L005jH001NV000GYP00002GYP02000FYT00000G[T0
05ji0002G[T01@00G[T005ji00000Uji00<005kJ00000UkJ00@005kJ001NfP@0000;G]X005kJG]X0
05kJ001NfP00G_X00002G_X01`00G_]Nn`00G_/005kk00@00007G_/005kkG_/005kk00000UlK00<0
06<K00000V<K00H006<K000006<K0002Ic/01`00Ic]W>`00Ic/006Lk0080009[>P06001[FV]JJeX0
06mJ0P000fmI00D007=ILeUcF@0000=cF005001gF000MeP00004MeL00`00MeIgEP02MeH00`00NeIk
EP03NeH01`00NeEkEG]E001k=@0000=k=@8000=k=@05001k=000NcD00003Na@00`00MaD00003Ma@2
00002GLE001fmGKe001bm@00L_H00002K_H00`00K]H00002J]L02000I]MVe`00I[L006:g0002H[P0
1`00GYP005jH001JV000009JN006001FN000EWP0059H0P0000E:>@00AQT003gi00D0000305@00000
00D000076M`00000000^G@00<Ud00P0000<jO@00>W`00P0000<nO00000000P0000M6W000AY`004JL
0016O00200001dIl0016O000AW/0049k00800004@U/0049K@U/200001D9K0012F`00?S/00P0000<j
6P00>QX00P0000@anP00000ef@800003;KT0000000<00004;IP000000002;GL200001D7G0011e`00
AOL00P0000Y>5P00CQH0058F001B5P00DSH0009F=P0A001F=P00ESH005Hf001F=P00ESH005Hf001J
=P00FUH00002FUH00`00FUH00002GUH01@00GWH005if00000V9f00<006JF00000VJF00H006ZfJ[H0
06Zf0002J[H01000K]I^eP000VkF00<006kFK]H00`000fkf00<006kg00000fkg00@006kgK_L0009^
m`03001Zn000009Zn004001Zn6[h0002J_P00`00J_P00002J_T01P00JaU[6@00JaT0009[6@04001W
6@00IaT20002IaT00`00IaT00002IaT01000IaT006LJ0P000VLJ00<006LJ00000VLJ00@006LJ001W
6P800005JaX006/jJcX00002JcX01P00JcX00000JcT0009[>@03001_>Fli00<0009_>@05001_>Fli
001_F@020002LeP01000LeQcF0000W=H00D007=HLeP007MG0080009gE`04001gEgMG0003MeL01000
McIg=P000WLf00@007LfMcH000=g=P06001g=WLf001g=P000gLf0`000W<F00<007<FLaH00`000Vkg
00<006kg00000V[g00<006[h00000VKH00<006KH00000V;H00D006:h001R^000009N^0L00005EWT0
059i001BN@05000024Hi000003hI000in@00=MT2000012fi0000025h0P0000@MF000000A>0T00003
5GT00000008000047KX000009O/400000c8L000b?00200000cYL000jG00300003Cil0012O000@W`0
04JL0016W000AY`004JL00800008BY`004Zl001:_000C[`0009>_00:001>_000C[`004jl001>_000
C[`<00004U:l001Bg000D]`005;L001Bg000D]`005;L001Bg000D]/0009Bf`0:001Bf`00D]/005;K
001Ff`00E]/300001eKK001FfeKK001Ff`00009Ff`0A001Ff`00E]/005KK001Ff`00E]/005KK001F
f`00E]/00002E]/00`00Oomoo`0KOol00`00Oomoo`0IOol20009Ool20006Ool2001;Ool005=oo`80
04moo`03001oogoo00H00008E[/005Jk001F^P00E[X0009F^P0;001F^P00E[X005Jj001F^P00E[X0
0002E[X05`00E[X005Jj001F^P00E[X005JJ001FV@00EYT005JI001FV@00EYT005JI00000UJI0P00
00YFN000EWP005Ih001FN000EUL0009FE`0_001FE`00EUL005IG001FE`00EUH005Hf001F=P00ESH0
05Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH0
0002ESH00`00ESH00002000015YF001JEP000Uig00X005igGWL005ig001NM`00GWL0009NU`07001N
V000GYP005jH00000UjH00P005jH000005jh001N^@000Uji00D005ji001N^@00009N^@05001N^@00
G]X00002G]X02000G]X00000G]X005kJ0002G]X01@00G]X005kJ00000UkJ00D005kj001NnP00009N
n`08001Nn`00001Nn`00G_/0009Nn`03001Nn`00009Nn`05001O6`00Ha/00002Ha/200001f<K001S
6f<K001W>`00009W>`04001W>`000002JcX01000JcY[>P000f]J00@006mIKeT000=_F@04001cF@00
0003LeP00`00MeP00002MeP01P00MeMgE`00MeL000=gEP03001kEW]F00=kEP03001kEG]E009kE@03
001k=G/e00=k=@04001k=G/eNcD20003NcD01P00NaAk5000MaD000=g5004001g5GLE0003M_D20000
1G;f001^mVkf00000VkF0`000VKG00<006Jg00000V:g00D006:h001NV000009NV003001JV00000X0
0004BST00000?OT;00000`5J0000000200001RHL0000039M000fG@800003>W`003il00800003?W`0
049l00@00007AY`004Il0016O000AW`00P0000]6N`00@W/0049k0012F`00@U/0049K00@00003?S/0
03hj00800004>QX00000<OX400001C7I000000009GP00P0000P]V000000]M`00;GL003gG0P0000=1
e`00AOL00P0000Y>5P00CQH0058F001B5P00DSH0009F=P0?001F=P00ESH005Hf001F=P00ESH005Hf
001J=P00009JEP05001JEP00FUH00002GUH00`00GWH00002GWH00`00HWH00002IYH00`00IYH00002
J[H00`00J[IZ]P030002K]H01000K]I^eP000VkF00@006kfK_H0009^mP05001^mfkg001^m`020002
K_L01000K_M^m`000V[h0`000V[h00@006[hJ_P0009Zn0<0009[6@06001[6F/I001[6@000VLI00H0
06/IJaT006LI0002IaT00`00IaT00002IaT00`00IaT00002IaX01`00IaYW6P00IaX006LJ00800007
JaX006/JJaX006/j00000V/j0P0000M[>@00JcU[>@00JcT00002KcT01000KcU_>@000Vli00@006li
KcT0009c>@03001cF000009cF004001cF7=H0002LeP01@00MeL007MG00000WMG0P0000IgE`00MeMg
E`00McH20002McH01@00McH007Lf00000WLf00@007LfMcH0009g=P04001g=WLf0002LaH00`00LaH0
0002LaH01000KaM_5`000Vkg00D006kg001Zm`00009Zn003001Vf000009Vf005001Rf000H[P00002
H[P300003ejI001JV@00EYT005Ii001BN@00DWT004iI001:F@0600001CWi000ef@00<MT01@0000<M
N0000000100000@EF000000AF0<000035GT00000008M^P8000048M/00000:O/400000c8l000f?002
00000cYL000nG0050000:49l0016W000AY`004JL0016W000BY`004ZL001:_000B[`004jl001>_000
C[`004jl001>_000C[`004jl001>_000D[`005:l001B_0000U:l014005:l001Bg000D]`005;L001B
g000D]`005;L001Bg000009Bf`03001Bf`00009Bf`0?001Bf`00D]/005KK001Ff`00E]/005KK001F
f`00009Ff`0C001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK00000UKK00<007ooOol0
6goo00<007ooOol04Goo30001Woo0P0027oo0P00BWoo001COol00`00Oomoo`1;Ool600001UKK001F
f`00E[/0009F^`0=001F^`00E[X005Jj001F^P00E[X005Jj00000UJj014005Jj001F^P00E[X005Jj
001F^P00E[X005Jj001FVP00009FV@13001FV@00EYT005JI001FV@00EYT005JI001FN000EWP005Ih
001FN000EWP005IG001FE`00EUL005IG001FE`00EUL005IF001F=P00ESH005Hf001F=P00ESH005Hf
001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf00000UHf00H005Hf001F=P00ESH30000
1UYF001JEP00FUH0009NM`08001NMeig001NM`00GWL0009NM`07001NU`00GYP005jH00000UjH1000
00AN^000G[P0009N^@05001N^@00G[T00002G[T01@00G[T005ji00000UkJ00H005kJ000005kJ0002
G]X01`00G]X005kJ001NfP00009NfP07001NfP00G_X005kj00000Ukk0P0000UNnP00G_]Nn`00G_/0
05kk00000Ukk00H005kk001O6`00Ha/300001f<K001S6f<K001S6`00009W>`06001W>fLk001W>P00
0f/j00D006/jJcX006]J008000=_F@05001_FFmIKeT00002LeT01@00LeQcF7=H000017MH00<007MG
00000WMG00D007MF001gEP0000=kEP03001kEP0000=kE@03001k=G/e00=k=@03001k=G/e009k=@07
001k=G/eNcD007/D00000WLE00D007LDMaAg500000=g5@04001fmGKe0002L_H01000K_I^mP000VkF
00H006[GJ]L006KG0002I[L01@00H[L006:h00000UjH1@0000UJV000EWP005Ii001BF@00CUT02000
00<QE`000000200000DIg000000002Xl00800005=Ud003Ym000jO00200000cil000nO00200000d9l
0012O00400001dIl0016O000AW`004Ik00800004@W/0049K0002@U/200000chk0000000200000chj
000j6P02000013Gj000002gI0P0000@af@00000YV0<00006;IP00000;GL002eg100000E1e`00AOL0
04Wf00800008CQH0058F001B5P00DSH0009F=P0;001F=P00ESH005Hf001F=P00ESH00002ESH02@00
FSH005YF001JEP00FUH00002GUH00`00GWH00002GWH30002IYH00`00IYH00002J[H00`00J[IZ]P02
000016kE001^eP000VkF00@006kFK]H0009^mP04001^mVkf0002K_L200001Fkg001^mfkg00000Vkg
00@006[hJ_P0009^n006001Zn6[h001Zn0000V[h00H006/HJaP006/I0002JaT01000JaT006LI0P00
0V/I00<006LI00000VLI00@006LI001W6@80009W6@06001W6VLJ001W6P000VLJ00<006/J00000V/J
00<006/J00000V/j0P0000A[>@00JcT0009[>@03001[>F/i00<0009_>@05001_>Fli001_>@020002
LcT00`00LeQcF00200001G=H001cF7=H00000W=H00@007MGMeL0009gE`04001gEgMG0002MeL01@00
McH007Lg00000WLf0P0000Ig=P00McIg=P00McH20002McH01000McIg=P000W<F00H007<FLaH007<F
0002KaL01@00K_M^m`00K_L00`000V[h00<006KH00000VKH00<006;H00000V:h0`0001EN^@00GYT0
05ZI001FV@00EWT0059i001BN@00CUT004YI0016>@00@ST00P0000Din@00=MT0037I00800004:KT0
00007GP2000011UH0000014h0`0000<AF00000000P0000@EN@00000M^P8000038M/002Gk00800003
;Q/0000000800005=S`003YL000jG002000013il0012O49l0P000TJL0P0000i6W000AY`004ZL001:
W000B[`004Zl001>_0000Tjl00X004jl001>_000C[`004jl001>_0800009D[`005:lD[`005:l001B
_000009B_00A001Bg000D]`005;L001Bg000D]`005;L001Bg000D]/00002D]/04@00D]/005;K001B
f`00E]/005KK001Ff`00E]/005KK00000UKK00/005KK001Ff`00E]/005KK001Ff`00009Ff`09001F
f`00E]/005KK001Ff`0001ioo`03001oogoo011oo``000Ioo`8000Qoo`8004Yoo`00Dgoo00<007oo
Ool0AGoo1P0000IFf`00E]/005KK0002E]/03@00E]/005Jk001F^`00E[/005Jj001F^P00009F^P0A
001F^P00E[X005Jj001F^P00E[X005Jj001F^P00E[X00002E[X0@`00E[X005JJ001FV@00EYT005JI
001FV@00EYT005JI001FV@00EWP005Ih001FN000EWP005Ih001FE`00EUL005IG001FE`00EUL005IG
001FEP00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00009F=P0:
001F=P00ESH005Hf001F=P00ESH300001UYF001JEP00FUH0009JEP03001NM`00009NM`03001NM`00
009NM`07001NM`00GYL005jH00000UjH0`0000ER^000G[QN^000009N^005001N^@00G[T00002G[T0
1@00G[T005ji00000Uji100000]Nf@00G]YNfP00G]X005kJ001NfP00009NfP08001NfP00G]X005kj
001NnP<00009G_X005kjG_X005kk001Nn`00009Nn`06001Nn`00G_/005lK0P0000=S6`00Ha/00V<K
00<006<K00000V<K00@006Lk001W>`80009W>P04001[>V/j0003JcX01000KeY_FP000VmI00D006mI
KeU_F@0000=cF@03001cF7=H008000AgF007001gEgMGMeL007MF00000WMF00H007]FNeH007]F0002
NeD00`00NcD00003NcD00`00NcD00003NcD01`00NcEk=G/e001k500000=g5@04001g50000003MaD0
1000M_Efm@000W;f00@006kfK_H0009^eP06001Zef[G001Ve`000VJg00<006:g00000V:h0`00015N
V000FYP005ZH001FN000EWT0059I001>F@00BST004HI00<00003;IP0000000`000049Q`00000;S`4
00000cYl000nO00200001Cil0012O000@W`00P0000=2O000@W`00P0000M6O000AW`004Ik0012N`02
0002@U/01000@U/0049K0P0000<n>`0000000P0000<j6P00>QX00P0000<anP0000000`0000<]^@00
0000100000P]M`00000]M`00<GL0047G0P0000M5m`00BOH004hF001>5P020000158F001B=P000UHf
00L005Hf001F=P00ESH00002ESH03@00ESH005Hf001J=P00FUH005YF001JEP00009NEP08001NMUif
001NMP00HYH0009VUP03001VUP00009Z]P04001Z]VZf0002K]D01`00K]I^eP00K]H006kF0080009^
mP04001^mVkf0002K_L01`00K_M^mfkg001^m`0000=^m`<0009^n004001Zn6[h0002J_P30002JaP0
1P00JaU[6@00JaT0009[6@03001[6@00009[6@07001W6FLI001W6@00IaT00P0000EW6@00IaUW6@00
009W6P04001W6P00IaX200001f/J001[6V/J001[6P00009[>P04001[>F/i0002JcT00`00JcT00002
JcT01000KcU_>@000Vli00H006liKcT006li0002LcT01000LeQcF0000W=H00D007=HLeP007=H0080
009gE`04001gEgMG0003MeL01000MeMgE`000WLg00@007LfMcH0009g=P04001g=WLfMcH200001GLf
001g=P00McH00P000W<F00<007<FLaH00`000VlG00H006kgK_L006kg0002J_L00`00J_P00002I]P0
0`00I]P00002H]P300001Ujh001N^@00GYT0009JV@0:001FV@00EWT0059i001BN@00CUT200000dHi
0012>@0300001SWi0000037I000]^@D000057EP00000000A>00500000aEI0000000300000afj000Q
^P0200000bGk000Yn`0200000c8K0000000200002cYL000jG000?U`003il0012O000@W`01@0000=6
W000AY`00P0000A:W000B[`0009:_00G001>_000C[`004jl001>_000C[`004jl001>_000C[`005:l
001B_000D[`00002D[`04@00D[`005;L001Bg000D]`005;L001Bg000D]`005;L00000U;K01<005;K
001Bf`00D]/005;K001Ff`00E]/005KK001Ff`00E]/00002E]/02`00E]]Ff`00E]/005KK001Ff`00
E]/030007Goo00<007ooOol047oo0P001Woo0P0000=oo`00Ool01Goo0P0027oo0P00BWoo001BOol0
0`00Oomoo`10Ool600001UKK001Ff`00E]/0009Ff`0;001Ff`00E]/005KK001Ff`00E[/00002E[/0
4`00E[/005Jj001F^P00E[X005Jj001F^P00E[X005Jj001F^P00009F^P0G001F^P00E[X005Jj001F
^P00EYX005JI001FV@00EYT005JI001FV@00EYT00002EYT20000:5Ih001FN000EWP005Ih001FE`00
EUL005IG001FE`00EUL005IG001FEP00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00
0UHf00`005Hf001F=P00ESH005Hf001F=P00ESH500001UYF001JEP00FUH0009JEP05001JEP00GWL0
0002GWL00`00GWL00002GWL01@00GWL005jG00000UjH0`0000ER^000H[QR^000009N^005001N^000
G[T00002G[T01@00G[T005ji00000Uji0`0000=Nf@00G]T00UkI00L005kJ001NfP00G]X00002G]X0
1P00G]X005kJ001NfP@00003G_X005kj009NnP05001NnP00G_/00002G_/01P00G_/005kk001Nn`80
0005Ha/006<KHa/00002Ha/01`00Ha]S6`00Ha/006Lk0080009W>P04001W>VLj0002JcX01000JcX0
00000VmJ00T006mIKeU_F@00KeT007=I00000W=I00<007=H00000W=H00D007MHMeQgF00000AgE`03
001gEWMF009gEP03001kEP00009kEP03001kE@00009k=@06001k=G/e001k=@000W/e00<007/e0000
0g/e00<007LEMaD00WLE00D007LD001g5@00009g5@04001fm@000003L_H00`00K_I^mP030002J]L0
2000I]MVe`00I[L006:g0002H[P01`00GYP005jH001JV000009JV006001FN000EWT0059I0P0000=:
>@00AQT0400000DE^`00000002Xl00800003<U`003IL00800005?W`003il000nO00200001D9l0012
O000@W`00P0000=2O00000000P0000e6N`00@W/0049k0012F`00@U/0049K000n>`0200000cXk0000
0002000013XJ0000037j0P0000@Y^@00000]^@8000059GP00000000]M`0200000beg000aM`040000
44Gg0019mP00CQH004hF001B5P00DQH0058f001F=P000UHf01<005Hf001F=P00ESH005Hf001F=P00
FSH005YF001JEP00FUH00003GUH00`00GWH000020002HYH00`00IYH00002IYH00`00J[H00002J[H0
1000K]E^e@000VkF00<006kFK]H00P0000A^mP00K_H000=^mP03001^m`0000=^m`03001^m`0000=^
m`03001^m`00009^n004001Zn6[h0002J_P00`00JaP00002JaP01000JaU[6@000V/I0`000V/I00H0
06/IJaT006LI0002IaT00`00JaT00002IaT01`00IaUW6@00IaX006LJ00800007JaX006/JJaX006/J
00000V/J0`000f/i00<006/i00000V/i0`000Vli00@006liKcT0009_>@04001_>Fli0002LcT30003
LeP01000LeQcF0000W=H00<007MGMeL00P0000EgE`00MeMgE`00009gE`04001g=gLg0002McH01@00
McIg=WLf00000WLf00@007LfMcH0009g=P800004LaH007<F0002LaH01000LaMc5`000VlG00<006kg
K_L00P000V[g00H006[hJ_P006KH0002I]P3000016:h001N^0000Uji010005jI001JV@00EYT005Ii
001BN@00DWT004iI001:F@800003@ST0048I00<00004=MT00000;KT2000012FI000001eH1@0000DE
F000000001EI008000056IX001VJ000M^P0500001RWk0000038K000f?0@0008jG0800009?W`0049l
0012O000@Y`004JL00L0000HBY`004Zl001:_000C[`004jl001>_000C[`004jl001>_000C[`004jl
001B_0000U:l01D005:l001B_000D[`005;L001Bg000D]`005;L001Bg000D]`005;L00000U;K00D0
05;K001Bf`00009Bf`04001Bf`00E]/300001eKK001Ff`00E]/005KK00`00008E]/005KK001Ff`00
E]/0009Ff`03001oogoo01]oo`03001oogoo015oo`8000Eoo`8000Qoo`8000Qoo`8004Yoo`00DWoo
00<007ooOol0>Woo1P0000IFf`00E]/005KK0002E]/02`00E]/005KK001Ff`00E]/005KK00000UKK
00l005KK001F^`00E[/005Jk001F^P00E[X005Jj00000UJj01H005Jj001F^P00E[X005Jj001F^P00
E[X005Jj001F^P00E[X005JJ001FVA000007EWP005Ih001FN000EWP00P000UIG01H005IG000005IG
001FE`00EUH005Hf001F=P00ESH005Hf001F=P00ESH0009F=P0>001F=P00ESH005Hf001F=P00ESH0
05Hf001F=PD00008FSH005YF001JEP00FUH0009JEP05001JEP00FUH00002GWL00`00GWL00002GWL0
1`00GWL005ig001NU`00009NV003001R^000009R^003001R^000009N^003001N^000009N^@05001N
^@00G[T00002G[T300001EkI001NfEkI00000UkI00<005kJ00000UkJ00P005kJ001NfP00G]X005kJ
0P0000ANnP00G_X0009NnP04001NnUkj0002G_X02000G_/005kk001Nn`00G_/200001F<K001S6f<K
00000V<K00L006<KHa/006<K001S6`0200000fLj001W>P02IcX00`00IcX00003JcX01000JcY[>P00
0VmJ00<006mIKeT00P000g=I00@007=ILeT000AcF005001gF000MeL00003MeL00`00MeIgEP03MeH0
1`00NeIkEW]F001kE@00009k=@04001k=G/e0002NcD01@00NcD007/e00000g/e00<007LEMaD00WLE
00D007LD001g5@0000=g5@800005L_D007;fL_H00002K_H01P00K]I^eP00J]L0009Ve`03001V]`00
009R]`<0000BGYP005jHGYP005ZH001JV000EWP005Ii001BF@00CUT004Xi0P0000Dmn@000000025G
00d000069Q`00000;S`0039L0P0000XfG000000nO000?W`0049l0012O0800003@W`0049l00800003
@W`0049l00@00004@W/0049K0002@U/200000chk000n>`0200000cXJ00000002000013Gj000002gI
1P0000@UN000000]V0<0008]M`800003=IH0047G0080000>BOH004hF001>5P00DQH0058F001B=P00
ESH0009F=P0A001F=P00ESH005Hf001F=P00ESH005Xf001JEP00FUH00002FUH02000GUINEP00GWH0
069f0002HYH00`00IYH00002IYH01000J[H006Zf0P000VkE00@006kFK]H0009^eP04001^mVkf0002
K_H00`00K_I^mP030003K_L01@00K_M^m`00K_L00P000Vkg00<006kh00000f[h0`000V/H00L006/H
JaP006/I001[6@0200001F/I001[6F/I00000V/I00@006LI001W6@800005JaT006LIIaT00002IaT0
1P00IaYW6P00JaT0009[6P03001[6P00009[6P<0009[>@06001[>F/i001[>@000V/i00@006liKcT0
009_>@04001_>@00KcT20002KcT01000LcUc>@000W<h00@007=HLeP0009cF004001cF7=H0002MeL0
1000MeMgE`000WMG00@007MG0000009g=`05001g=P00McL00002McH01000McIg=P000WLf00@007Lf
McH0009c5P03001c5P00009c5P04001c5g<G0002KaL00`00K_M^m`020002J_L01P00J_QZn000I]P0
009Vf005001Rf000H[P00002G[P05P00G[T005jI001JV@00EYT005Ii001BN@00DWT004iI001:F@00
AST0048i0P0000<mn@0000000P0000<]^@00:KT01@0000DIF000000001EH00@000045ET000006IX2
000011fj000002GK100000H^6`00000f?000=S`300002CYL000nG000?W`0049l0012O00200001dJL
0016W000AY`004ZL00L0000>C[`004jlC[`004jl001>_000C[`004jl001>_0800009D[`005:lD[`0
05:l001B_000009B_00A001Bg000D]`005;L001Bg000D]`005;L001Bg000D]/00002D]/00`00D]/0
000?000055KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0002E]/00`00Oomoo`0L
Ool00`00Oomoo`0@Ool30004Ool20008Ool20008Ool2001:Ool0059oo`03001oogoo03Aoo`H00006
E]/005KK001Ff`000UKK00/005KK001Ff`00E]/005KK001Ff`00009Ff`0=001Ff`00E]/005KK001F
f`00E[/005Jk00000UJk018005Jj001F^P00E[X005Jj001F^P00E[X005Jj001F^P00E[X<00003eJJ
001FVP00DYT0059i001BN@00DWT0059i001BN@0;00002EIG001FE`00EUL005IG001FE`0200001UHf
001F=P00ESH0009F=P0@001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH500002UHf001F=P00
FSH005YF001JEP000UYF00L005YF001JEP00FUH00002GWL02P00GWMNM`00GWL005ig001NM`000UjG
0`000V:h00D006:h001R^000009N^008001N^5jh001N^@00G[T0009N^@<00007H]T005kIG]T005kI
00000UkI00/005kJG]X005kJ001NfP00G]X005kJ00800009G_X005kjG_X005kj001NnP0000=NnP08
001NnP00G_/005kk001Nn`800007H_/006<KHa/006<K00000V<K00D006<KHa/006<K00800005IaX0
06LjIcX00002IcX01@00IcYW>P00JcX00P000V/j00P006mJKeX006mI001_F@000g=I00@007=I0000
00EcF009001gEgMGMeL007MG001gE`0000AgEP03001kEW]F009kEP03001k=G/e009k=@8000=k=@05
001k=@00NcD00002NcD00`00MaD00004MaD01000MaEg5@000gLE00@007;eL_D0009bmP04001^mVkf
0002K]H01P00J]MZe`00I]L0009V]`<0000FH[P005jHGYP005jH001JV000FYP005Ih001FN@00DUT0
04iI001:>@00AQT400000b5G0000000900001AFk00000000:S`00P0000<bG000=U`00P0000<jG000
00000P0000E2O000@W`0049l00800005@W`0049l0012O00200000d9k0012F`020002@U/01000@U/0
049K0P0000<n>`00>S/00P0000<f6P0000000P0000DanP00000002FI00800003:IP0000000@00003
;GL002eg00800003=IH000000080000>BOH004hF001>5P00DQH0058F001B=P00ESH0009F=P0A001F
=P00ESH005Hf001F=P00ESH005Xf001JEP00FUH00002FUH00`00GUINEP0300001f9f001RUV:F001V
UP00009VUP03001Z]VZf00<0009^e@04001^eVkF0002K]H01000K_I^mP000Vkf00@006kfK_H0009^
mP04001^mfkg0002K_L200001fkg001^mfkg001^n000009Zn0800005JaP006/HJaP00002JaP01P00
JaU[6@00JaT0009[6@03001[6@00009[6@06001W6@00001[6@000V/I00<006LI00000VLI00H006LJ
000006/I0002JaX00`00JaX00002JaX00`00JcT00002JcT01000JcU[>@000V/i0`000Vli00@006li
KcT0009_>@06001_>Fli001_>@000W<i00@007<hLcP0009cF005001cF000LeP00002LeP00`00MeL0
0003MeL01000MeMgE`000WLg00<007LgMcL00P0000Ig=`00McIg=P00McH20002McH01000McIg=P00
0W<F00<007<FLaH00P0000Ac5`00LaL0009_5`06001^mfkg001^m`000V[g00<006[h00000VKH0`00
01aRf000H[QR^000G[P005ji001NV@00FYT005JI001FN@00DWT0059i001>F@00BUT004Hi0012>@80
0005?OT003Wi000af@02000012Vi000002FI0P0000<IF00000000`0000<EF@0000000`0000HIVP00
000M^P008KX200000bWk0000000200001S8K000003Hl000jG0<0000;?U`003il0012O000@W`004:L
0016W002000024JL001:W000BY`004ZL0002B[`A00001U:l001B_000D[`0009B_1P00005D]/005;K
001Bf`0300001UKK001Ff`00E]/0009Ff`0;001Ff`00E]/005KK001Ff`00E]/00002E]/01`00E]/0
05KK001Ff`00009Ff`03001oogoo01]oo`03001oogoo015oo`8000Aoo`8000Qoo`8000Qoo`8004Yo
o`00DWoo00<007ooOol0;Woo1P0000IFf`00E]/005KK0002E]/02`00E]/005KK001Ff`00E]/005KK
00000UKK00/005KK001Ff`00E]/005KK001Ff`00009Ff`0@001Ff`00E[/005Jk001F^`00E[X005Jj
001F^P00E[X:00009EJj001F^P00EYX005JJ001FVP00EYX005JJ001FVP00DYT0059i001BN@00DWT0
059i001BN@00DUP0059H001BF000DUP004hh00L0000GEUL005IG001FEP00ESH005Hf001F=P00ESH0
05Hf001F=P00ESH005Hf001F=P07000035Hf001F=P00ESH005Hf001J=P00FUH0009JEP09001JEP00
FUH005YF001JEP00009NM`08001NMeig001NM`00GWL0009NM`<00007HYL006:hH[P006:h00000V:h
00P005jhG[P005jh001N^@000Uji0`0000MRf@00H]URf@00G]T00002G]T02`00G]UNf@00G]X005kJ
001NfP00G]X00P0000UNfP00G_YNnP00G_X005kj00000Ukj00T005kjG_X005kj001Nn`00G_/00P00
00MRnP00H_]Rn`00Ha/00002Ha/01@00Ha]S6`00Ha/00P0000EW6P00IaYW6P00009W>P05001W>VLj
001W>P020002JcX01000JcY[>P000VmJ00D006mIKeU_F@0000=cF@04001cF7=H0004LeP01`00MeMg
EgMG001gE`00009gE`06001gEWMF001gEP000g]F00<007/eNcD00g/e00@007/eNcEk=@8000=k=@05
001k=@00MaD00004MaD01@00MaEg5GLE00000WLE00@007;eL_D0009bmP04001^mP000002K]H01P00
J]MZe`00I]L0009V]`03001R^000009R^00;001NV000GYP005ZH001JV000EWP00002EWT200001DiI
001:>@00AQT04`0000HQo000000^?000<U`200001SIL000003Yl000nO0800007@W`0049l0012O000
@W`00P0000E2O000@W`0049k00800009?U/000000012F`00@U/003hk00800003>S/003XJ00800004
<OX00000<OX200000bVi0000000400002B5G00000000;GL002eg000aM`0200000cVf0015m`020000
34hF001>5P00DQH0058F001B=P00ESH0009F=P0?001F=P00ESH005Hf001F=P00ESH005Xf001JEP00
009JEP04001JEP00GUH200001eif001RMV9f001RUP00009VUP03001VUP00009Z]P800008K]D006kE
K]D006kF001^eP80009^mP04001^mVkf0002K_H01000K_I^mP000Vkg00@006kgK_L000=^m`03001^
m`00009^n0800007KaP006/HJaP006/H00000V/H00H006/I000006/I0002JaT00`00JaT00002JaT2
00002F/I001[6F/I001[6@00IaT00002IaT200001f/I001[6F/I001[6P00009[6P<0009[>@04001[
>F/i0002JcT30002JcT01`00KcU_>@00KcT006li0080009_>@03001_>Fli00800005LcP007<hLcP0
0002LeP01000LeQcF0000W=H0P0000EcE`00MeMgE`00009gE`04001g=gLg0002McL01000McMg=`00
0gLf00@007LfMcH0009g=P<0009c5P04001c5W<F0002LaL01000LaMc5`000VlG0`0000M^m`00J_MZ
m`00J_P00002I]P00`00I]P00002H]P07000H[P005jh001N^@00GYT005ZI001FV@00EWT0059i001B
N@00CUT004YI0016>@00@ST0048I0P0000<in@0000000P0000<Y^@009IT00`0000<IF0006EP00`00
00HEF@00000IN@006GT200000afJ00000002000012GK000002gk0P0000Db6`00=S`003Hl0080008j
G0@0000;@W`0049l0012W000AY`004JL0016W0020002BY`05000BY`004Zl001>_000C[`004jl001>
_000C[`004jl001>_000C[`:000045:l001B_000D]`005;L001Bg000D]`005;L001Bg0000U;K00X0
05;K001Bf`00D]/005;K001Bf`<00004E]/005KK0002E]/05P00E]]Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`000UKK00<007ooOol06Goo0`0057oo0P000goo0P0027oo0P0027oo
0P00BWoo001BOol00`00Oomoo`0XOol600001UKK001Ff`00E]/0009Ff`0;001Ff`00E]/005KK001F
f`00E]/00002E]/02`00E]/005KK001Ff`00E]/005KK00000UKK00h005KK001Ff`00E]/005KK001F
^`00E[/005Jk200000YF^P00E[X005Jj001F^P00E[X0009F^P08001F^P00EYX005JJ001FVP80009F
VP0<001FVP00DYT0059i001BN@00DWT0059i0P0000mBF000DUP0059H001BF000CSP004hg001>=`00
DSL01`0000UF=P00ESH005Hf001F=P00ESH02@0000iF=P00ESH005Hf001F=P00ESH005Hf001F=P00
0UXf00d005YF001JEP00FUH005YF001JEP00FUH00002GWL01P00GWMNM`00GWL0009NM`05001NM`00
HYL00002HYL00`00H[P00002H[P00`00H[P00002G[P00`00G[P00002G[T300001f;I001RfF;I001R
f@00009Nf@03001Nf@00009Nf@03001NfP00009NfP<00007G]X005kJG]X005kj00000Ukj00<005kj
00000Ukj00@005kj001NnP@00007H_X006;jH_X006;k00000V<K00@006<KHa/0009S6`03001W6P00
009W6P06001W6VLJ001W>P000fLj00<006/j00000V/j00D006/jJcX006mJ008000A_F@04001cFG=I
0003LeP01P00LeQcF000MeP000=gE`03001gEgMG009gE`05001gEP00MeH00002NeH00`00McH00004
NcD00`00NcEk=@02NcD01`00NcEk=G/e001k=@00009g5@05001g5GLEMaD00003MaD01000MaD00000
0g;e00<007;fL_H00P0000A^mP00K]H0009Ze`03001VefKG00<00009H[P006:hH[P005jH001NV000
009JV00:001JV000EWP005Ii001BF@00CUT200001DHI00000000;KP00P0000<@mP000000200000DE
^`00000002HL00800003<U`003IL00800003>U`003Yl00800003?W`0000000800005@W`0049l0012
O00200001D9l0012N`00@U/00P000SiK100000<n>`00?S/00P0000<j6P00=QX01@0000D]f@000000
025h008000059GP00000000]M`0200000beg000aM`0200000cVf00000002000034hF001>5P00DQH0
058F001B=P00ESH0009F=P0=001F=P00ESH005Hf001F=P00ESH005Xf00000UYF00@005YF001JEP80
0004GUH005if0002HWH00`00HYH00002IYH00`00IYH00002J[H01000K]E^e@000VkE00<006kFK]H0
0P0000Q^mP00K_I^mP00K_H006kf0P000Vkf00L006kgK_M^m`00K_L00003K_L00`00K_L00002K_P0
1000KaQ_60000V/H00<006/H00000V/H0P0000M[6000JaU[6@00JaT00002JaT2000016/I001[6@00
0V/I00<006/I00000VLI0P0000U[6@00JaU[6@00JaT006/J00000V/J00H006/IJaT006/i0002JcT0
1P00JcU[>@00JcT0009[>@04001_>Fli0002KcT01P00KcU_>@00KcT0009_>@04001c>7<h0002LcP0
1000LeQcF0000g=H00H007=HLeP007=G0002MeL01000MeL000000WLg00@007LgMcL000=g=`04001g
=WLf0002McH01000McIg=P000W<f00<007<F00000W<F00@007<GLaL0009c5`04001_5flG0002K_L2
0002J_L00`00J_QZn00300003FKH001Rf6;H001R^000G[P005ji001NV@00009JV@0:001FV@00EWT0
059i001BN@00CUT200001dHi0012>@00@QT003gi00800003=MT002fi008000039IT002FI00<00003
6EP00000008000045ET000006GT2000011VJ0000026j0P0000@Uf`00000]n`@0000;=S`003Hl000j
G000>U`003iL000nO00300003d9l000004JL0016W000AY`004ZL001:W000BY`00002B[`2000044jl
001>_000C[`004jl001>_000C[`004jl001B_0000U:l014005:l001B_000D[`005:l001Bg000D]`0
05;L001Bg000009Bg009001Bg000D]/005;K001Bf`00009Bf`0=001Bf`00D]/005KK001Ff`00E]/0
05KK00000UKK01<005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00002E]/00`00Oomo
o`0FOol30002Ool00`00Oomoo`0BOol30002Ool20008Ool20008Ool2001:Ool0059oo`03001oogoo
021oo`P00006E]/005KK001Ff`000UKK00/005KK001Ff`00E]/005KK001Ff`00009Ff`09001Ff`00
E]/005KK001Ff`00009Ff`0>001Ff`00E]/005KK001Ff`00E]/005KK001Ff`P00008E[/005Jk001F
^`00E[X0009F^P0/001F^P00E[X005Jj001F^P00E[X005Jj001FVP00EYX005JJ001FVP00EYX005JJ
001BV@00DWT0059i001BN@00DWT0059i001BF000DUP0059H001BF080000;CSL004hg001B=`00DSL0
058g001B=`0;00004UHf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH0009F=P0?001F=P00
FSH005YF001JEP00FUH005YF001JEP00009JEP03001NM`00009NM`03001NM`00009NM`<00005HYL0
06:GHYL00002H[P01@00H[P006:h00000Ujh00<005jhG[P00`0000MRf000H]URf@00H]T00002H]T0
1@00G]T005kI00000UkI00<005kJG]X00`0000MNfP00G]YNfP00G]X00002G_X00`00G_X00002G_X0
1000G_X005kj0P0000ARnP00H_X0009RnP03001RnP00009Rn`07001S6f<K001S6`00Ha/00P000VLJ
00H006LJIaX006LJ0002IcX01000IcX000000V/j00@006/jJcX0009[>P04001_FFmI0003KeT01@00
LeT007=H00000g=H00D007=H001gF00000=gE`03001gEgMG00=gE`09001gEWMFMeH007]F001g=P00
00=k=@03001k=@0000=k=@04001k=G/eNcD20003MaD01P00MaEg5@00MaD0009g5@05001g5@00LaD0
0002L_D01000L_IbmP000Vkf00H006kFK]H006[G0002I]L00`00I[L00002H[P01@00H[P005jH0000
0UjH00h005ZH001JV000EWP005Ii001BF@00CUT004Xi0P0000<mn@000000400000@Qo000000Z7080
0003=U`003IL00800003>W`003il00800003?W`003il00800007@W`0049l0012O000@W`00P0000U2
F`00?U/003iK000nF`00?S/00P0000<n>`00>S/00P0000@f6P00000]fPD000059IT00000000UN006
00001Beg000aM`00=IH00P0000=1]P00BOH00P0000Y>5P00DQH0058F001B=P00ESH0009F=P09001F
=P00ESH005Hf001F=P00009F=P06001J=P00FUH005YF0`000UiF00P005ifGWH0069f001RUP000VJF
00<006JF00000VZf00@006kEK]D0009^e@04001^eVkF0002K_H01000K_I^mP000Vkf0P0000EbmP00
K_I^mP00009^m`<000=^m`03001^m`00009^n007001_66lHKaP006/H00000V/H0P0000U[6000JaQ[
6000JaT006/I00000V/I00@006/IJaT0009[6@03001[6@00009[6@<0009[6@06001[6F/I001[6@00
0V/J0`000V/I00L006/iJcT006/i001[>@020002JcT01`00JcU[>@00KcT006li0080009_>@03001_
>Fli00<000=c>007001c>000LeP007<h00000W=H00@007=HLeP0009cE`04001gEgMG0002McL00`00
McMg=`0200001WLg001g=gLg001g=P80009g=P04001g=WLf0002LcH00`00LaIc5P0200001g<G001c
5g<G001c5`00009_5`08001^mfkg001^m`00J_L0009Zn003001Vf000009Vf007001Rf000H[P005jh
00000Uji010005jI001JV@00EYT005Ii001BN@00DWT004iI001:F@800007@ST0048I000mn@00>OT0
1@0000<UV@009IT00`0000<IF0006ET01@0000@IN@00000IVP8000038KX0000000800004:O/00000
;Q/40002=S`20002>U`200000cil0012O00500001dJL000004JL001:W000009:W00M001:W000B[`0
04jl001>_000C[`004jl001>_000C[`004jl001>_000D[`005:l001B_000D[`00002D[`03`00D[`0
05;L001Bg000D]`005;L001Bg000D]`00002D]/04@00D]/005;K001Bf`00D]/005;K001Ff`00E]/0
05KK00000UKK00l005KK001Ff`00E]/005KK001Ff`00E]/005KK00000UKK00D005KK001Ff`00009F
f`03001oogoo01=oo`8000Ioo`03001oogoo019oo`80009oo`8000Uoo`8000Ioo`8004]oo`00DWoo
00<007ooOol06Woo1P0000QFf`00E]/005KK001Ff`000UKK00/005KK001Ff`00E]/005KK001Ff`00
009Ff`09001Ff`00E]/005KK001Ff`00009Ff`0>001Ff`00E]/005KK001Ff`00E]/005KK001Ff`H0
0008E[/005Jk001F^`00E[/0009F^`0A001F^`00E[/005Jj001F^P00E[X005Jj001F^P00E[X00002
E[X200008EJJ001FVP00EYX005JJ001FVP00EYX005:I001BN@00DWT0059i001BN@00DWT0059H001B
F000DUP0059H001>>00200008Thg001B=`00DSL0058g001B=`00DSH0058f001F=P00ESH005Hf001F
=P00ESH005Hf001F=P00ESH005Hf001F=P000UHf014005Hf001F=P00ESH005Xf001JEP00FUH005YF
001JEP00009JEP03001JEP00009NM`03001NM`00009NM`05001NM`00HYL00002HYL00`00HYL00002
H[P00`00H[P00002H[P00`00G[P00002G[P00`00H[P00002H]P00`00H]T00002H]T01@00H]T005kI
00000UkI00<005kIG]T00`0000MRfP00G]YNfP00G]X00002G]X00`00G_X00002G_X01000G_X005kj
0P0000URnP00H_YRnP00H_X006;j00000V;j00L006;kH_/006<K001S6`020002HaX00`00IaX00002
IaX01@00IaYW6P00IcX00P000V/j00L006/jJcX006/j001[>P020003KeT01@00KeU_FFmI00000g=H
00<007=HLeP00P000gMH00D007MG001gE`0000AgE`07001gEWMFMeH007]F00000WLf00<007/e0000
0W/e00H007/eNcD007Le0003NcD01@00MaEg5GLE00000WLE00<007LE00000gLE0P0000Ec5@00L_Eb
m@00009bmP04001^mVkf0002K]H00`00J]MZe`030002I[L01@00H[P006:h00000UjH018005jH001J
V000FYP005Ih001FN@00DUT004iI001:>@00AQT400000bEh0000000:00001A6K000000009Q`00P00
00P^?000000fG000>U`003Yl0P0000<nO000?W`00P0000<nO00000000P0000E2O000@W`0049k0080
0006?U/003iK?U/003iK0P0000Hj>`00000j>`00>QX20000137j000002Vi0P0000<Y^@0000001@00
00TM=`00000002eg000aM`00=IH00P0000M1]P00000004hF001>5P020000158F001B=P000UHf00L0
05Hf001F=P00ESH00002ESH02000ESH005Hf001J=P00FUH300001EiF001NEUiF00000Uif00D0069f
001RUP00009VUP03001VUVJF00<0009^e@04001^eFkE0002K]H01000K_I^mP000Vkf00@006kfK_H0
009bmP04001^mVkf0002K_L01000KaM_5`000Vkg00<006kgK_L00`000flH00<006/H00000V/H00@0
06/HJaP0009[6003001[6@00009[6@<000=[6@05001[6@00JaT00002JaT00`00JaT00003JaT00`00
JaT00002JaT30002JaT01P00JaU[6@00JcT0009[>@06001[>F/i001[>@000V/i00@006li0000009_
>@03001_>@00009_>@04001_>Fli0002LcP01000LcQc>0000W<h00D007=HLeP007=H0080009cE`04
001gEgMG0002McL01000McMg=`000WLg010007LgMcL007Lf001g=`00McH007Lf001c=`00LcH0009c
5P04001c5g<G0002LaL00`00LaMc5`030002K_L00`00K_L00002J_L30002I]P01`00I]P006;H001R
^000009N^004001N^@00GYT?00000dHi0012>@0200001Cgi000in@00=MT01@0000<UV@0000000P00
00DIF000000001Ui008000036GT001fI008000047IX000009MX4000012gk0000038K0`0000Lf?000
>U`003YL000nG00200001D9l0012O000@W`01@0000=6W00000000TZL01L004ZL001:_000C[`004jl
001>_000C[`004jl001>_000C[`004jl001B_000009B_00A001B_000D[`005:l001B_000D]`005;L
001Bg000D]`00002D]`05@00D]`005;K001Bf`00D]/005;K001Bf`00D]/005KK001Ff`00E]/00002
E]/00`00E]/00002E]/02P00E]/005KK001Ff`00E]/005KK2P007Goo00<007ooOol04goo0P0000=o
o`0000002Goo0P001Woo0P00Bgoo001BOol00`00Oomoo`0DOol600001UKK001Ff`00E]/0009Ff`0=
001Ff`00E]/005KK001Ff`00E]/005KK00000UKK00T005KK001Ff`00E]/005KK00000UKK00`005KK
001Ff`00E]/005KK001Ff`00E]/800001UKK001Ff`00E[/0009F^`0?001F^`00E[/005Jk001F^`00
E[/005Jk001F^P00009F^P0B001F^P00E[X005Jj001F^P00E[X005Jj001FVP00EYX005JJ0P000UJJ
00H005JJ001BV@00DWT200004e9i001BN@00DWT0059H001BF000DUP0059H001>>000CSL004hg0080
000HDSL0058g001B=`00DSH0058f001F=P00ESH005Hf001F=P00ESH005Hf001F=P000UHf01D005Hf
001F=P00ESH005Hf001F=P00ESH005Xf001JEP00FUH005YF00000UYF00D005YF001JEP00009NM`05
001NMeig001NM`030002HYL01@00HYL006:G00000V:h00H006:hH[P006:h0002G[P300001F:h001R
f6;H00000V;I00D006;I001Rf@00009Nf@04001Nf@00G]T200001f;I001RfV;J001NfP00009NfP03
001NfP00009NnP04001NnP00G_X200002F;j001RnV;j001RnP00H_X00002H_X01`00H_YRnP00H_/0
06<K00800005HaX006<JHaX00002IaX01@00IaYW6P00IaX00P0000EW>P00JcY[>P00009[>P04001[
>P000002KcT01P00KeU_FFmI001_F@8000=cF005001cF000LeP00003MeP00`00MeL00002MeL01P00
MeMgE`00MeH000=gEP07001g=WLfMcH007/e00000g/e00D007/e001g=@0000=k=@03001g5GLE009g
5@05001g5@00MaD00003MaD01000LaEc5@000W;e00@007;f000000=^mP03001^eP00009Ze`03001V
e`00009V]`03001R^000009R^00;001NV000GYP005ZH001JV000EWP00002EWT200001DiI001:>@00
AQT00`0000D]^0000000002e00`000048O`00000:Q`20000238l000003YL000jO000?W`200000cil
000nO00200000cil000nO00200003D9l0012N`00@U/003iK000nF`00?U/003hk00800006>Q/00000
>QX003HJ0P0000<]fP000000100000DQN0000000025G00<00008;GL00000<GL003FF000i]P80000>
AMH00000001>5P00DQH0058F001B=P00ESH0009F=P0<001F=P00ESH005Hf001F=P00ESH005Xf0`00
00AJEP00GUH000=NEP05001NMP00HWH00002HYH00`00IYH00002IYH30002K]D01@00K]E^e@00K]H0
0P000Vkf00@006kfK_H0009^mP04001bmW;f0002K_H01000K_M^m`000VlG00@006kgK_L0009^m`04
001_66lH0002KaP00`00JaP00002JaP02@00JaQ[66/H001[6000JaT00002JaT01000JaU[6@000V/I
00<006/I00000V/I0`000V/I00H006/IJaT006/I0002JaT00`00JaT00002JaT01`00JaU[6@00JcT0
06/i0080009[>@04001[>F/i0002JcT00`00KcT00002KcT00`00KcU_>@030002KcT01@00LcQc>000
LcP00P000g<h00@007=HLeP0009c>004001cE`00MeL20002McL01000McMg=`000gLg00@007LgMcL0
009g=`03001g=WLf00800004LcL007<f0002LaH01000LaMc5`000W<G00@007<GLaL0009^m`05001^
m`00K_L00002J_L00`00J_P00002I]P01@00I]P006;H00000V:h00<005jh0000100000eJV@00EYT0
05JI001BN@00DWT004iI001:F@030000248i000003gi000in@00=MT200000bfi000000029IT60000
0aUi000IN@0200000aUi000000030000126j000002WK0P0000<]n`00;Q/00P0000/f?000000003YL
000jG000?U`003il00800007@W`0049l0016W000AY`01@0000A:W000BY`0009:_080000<C[`004jl
001>_000C[`004jl001>_0000Tjl01D005:l001B_000D[`005:l001B_000D[`005;L001Bg000D]`0
05;L00000U;L00/005;L001Bf`00D]/005;K001Bf`00009Bf`<00008E]/005KK001Ff`00E]/0009F
f`d00006E]/005KK001Ff`000UKK00<007ooOol06goo00<007ooOol057oo10002Woo0P0017oo0P00
C7oo001BOol00`00Oomoo`0>Ool600001UKK001Ff`00E]/0009Ff`0=001Ff`00E]/005KK001Ff`00
E]/005KK00000UKK00L005KK001Ff`00E]/00002E]/03P00E]/005KK001Ff`00E]/005KK001Ff`00
E]/6000025KK001Ff`00E]/005KK0002E]/03@00E]/005Jk001F^`00E[/005Jk001F^`00009F^`0Z
001F^`00E[/005Jj001F^P00E[X005Jj001F^P00E[X005Jj001F^P00EYX005JJ001FVP00EYX005JJ
001FVP00DYT0059i001BN@00DWT0059i0P0001=BF000DUP0059H001BF000CSP004hg001>=`00DSL0
058g001B=`020000458f001B=P00ESH005Hf001F=P00ESH005Hf001F=P000UHf01D005Hf001F=P00
ESH005Hf001F=P00ESH005Hf001J=P00FUH005YF00000UYF00L005YF001JEP00FUH00002GWL00`00
GWMNM`0300001f:G001RUf:G001RU`00009RU`09001R^6:h001R^000H[P005jh00800007H[P006:h
H[P006;H00000V;I00<006;I00000V;I00@005kI001Nf@800007H]T006;IH]T006;J00000UkJ00<0
05kJ00000UkJ00@005kj001NnP800007H_X006;jH_X006;j00000V;j00<006;j00000V;j00@006;j
001Rn`800005HaX006<JHaX00002HaX00`00IaX00002IaX200001FLj001W>VLj00000V/j00H006/j
JcX006/j0003KcT01@00KeU_FFmI00000W=I00D007=HLeQcF00000=cF005001gF7MHMeP00003MeL0
0`00MeL00002MeH01@00MeIgEWMF000017Lf00<007/eNcD00W/e00<007/e00000WLe00D007/e001g
=@0000=g5@8000=g5@04001g5GLE0003LaD00`00L_Ebm@0200001g;f001^mVkf001^eP00009Ze`06
001VefKG001V]`000V:h00L006:h001NV000GYP00002FYP01000FYP005Ih1@0000A>F@0000166@80
0003>MT0000000d000054I/00000000V7002000012hl000003IL0P0000DjO000?W`003il00800005
?W`003il000nO00200000ciL0000000200002d9K000nF`00?U/003iK000n>`00>S/00P0000@f6`00
000f6P800004;MX000009IT200000bFI0000000200000b5G000000040002<GL200001SVf000004GF
0019mP<00008DQH0058F001B=P00ESH0009F=P08001F=P00ESH005Hf001F=PD00006FUH005YF001N
EP000eiF00D005if001RMP00009RUP03001VUP00009VUP04001^]Fje0002K]D00`00K]E^e@020000
27;E001^mVkf001^mP00K_H20003L_H00`00K_I^mP030002KaL01`00K_M^mfkg001^m`00009_6004
001_66lH0002JaP200001flH001[66/H001[6000009[6@<0009[6@06001[6F/I001[6@000V/I00H0
06/IJaT006/I0002JaT00`00JaU[6@030002JaT01`00JaU[6@00JaT006/i0080009[>@07001[>F/i
001[>@00JcT00P000Vli00<006li00000Vli00@006liKcT0009_>@04001c>7<h0002LcP01000LcQc
>0000W=H00@007<hLcP0009cE`04001c=g<g0002McL200001GLg001g=gLg00000WLg00@007LgMcL0
009g=P0:001c=g<g001c=P00LaH007<G0002LaL00`00LaMc5`030002K_L00`00K_L00002K_L30002
J_P01@00I]P006KH00000V;H00<006:h00000P0001=N^@00G[T005ZI001FV@00EYT0059i001BN@00
CUT004YI001:>@0600001CWi000ef@00<MT0100000LUV@00000001ei000IF@02000011Ui000001Ui
0P0000@MVP00000Q^P800003:M/0000000800003;Q/0038K0080008f?080008jG0800005?W`0049l
0012O00200001dJL0016W000AY`004ZL00X0000FC[`004jl001>_000C[`004jl001>_000C[`005:l
001B_000D[`005:l0002D[`03`00D[`005;L001Bg000D]`005;L001Bg000D]`00002D]/01P00D]/0
05;K001Bfa00000@E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0002E]/00`00E]/0000MOol0
0`00Oomoo`0DOol4000:Ool8001<Ool003Qoo`@001Ioo`03001oogoo00Qoo`H00006E]/005KK001F
f`000UKK00/005KK001Ff`00E]/005KK001Ff`00009Ff`09001Ff`00E]/005KK001Ff`00009Ff`0>
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`H00006E]/005KK001Ff`000UKK00d005KK001Ff`00
E]/005KK001Ff`00E[/00002E[/06@00E[/005Jk001F^`00E[/005Jk001F^`00E[X005Jj001F^P00
E[X005Jj001F^P00009F^P80000KEYX005JJ001FVP00EYX005JJ001FVP00DYT0059i001BN@00DWT0
059i001BN@00DUP0059H0080000?DUP004hh001>=`00CSL0058g001B=`00DSL0058g0080000>DSH0
05Hf001F=P00ESH005Hf001F=P00ESH0009F=P0E001F=P00ESH005Hf001F=P00ESH005Hf001F=P00
FSH005YF001JEP00009JEP07001JEP00FUH005YF00000Uig00H005igGWL006:G0002HYL01@00HYL0
06:G00000V:G00H006:hH[P006:h0002H[P00`00H[P00002H[P00`00H[P00002H]P00`00H]T00002
H]T01000H]T005kI0P0000MRf@00H]URf@00H]T00002H]X00`00G]X00002G]X01000G]X005kj0P00
00URnP00H_YRnP00H_X006;j00000V;j00L006;jH_X006;j001RnP0200001f<J001S6V<J001S6P00
009S6P07001W6P00IaX006LJ00000VLj00<006Lj00000V/j00@006/j0000009[>P06001_>FliKcT0
06mI0P000g=I00@007=HLeP000AcF004001gF7MH0004MeL00`00MeIgEP02MeH01@00MeH007Lf0000
0gLf00<007/eNcD00g/e00T007LeMcEg=@00NcD007Le000017LE00H007LEMaEg5@00MaD20003LaD0
1000L_Ebm@000W;f00@006kfK_H0009^eP<0009Ve`0:001V]fJg001R^000H[P005jH0002GYP70000
0e9i001BF@07000013WI000002Eh3`0000@Mg000000Z70800004<S`00000=U`400001Cil000nO000
?W`00P0000<nO000?W`00P0000<nG000?U/00P000SiK00@003iK000nF`800003>S/003XK00D00004
<OX00000:KT300000bFI00000005000011TF000000000S5g0P0000<i]P00@KH00P0000=9mP00COH0
0`0000IB5P00DSH005Hf0002ESH01000ESH005Hf1@0000QF=P00FSH005YF001JEP000UiF00P005iF
GUH005if001RMP000V:F00<006JF00000VJF00@006jeK[D0009^e@03001^eFkE00800005L]D006kf
K_H00002K_H200001G;f001bmW;f00000Vkf00@007<GLaL0009_5`03001^mfkg00800004KaL006lH
0002KaP01000JaQ[60000VlH00H006/HJaP006/H0002JaT01P00JaU[6@00JaT0009[6@03001[6F/I
00<0009[6@04001[6F/I0002JaT30002JaT00`00JaT00002JaT01P00JaU[6@00JcT0009[>@04001[
>F/i0002JcT00`00KcT00002KcT00`00KcU_>@030002KcT01000KcU_>@000W<h00@007<hLcP0009c
>004001cF0000002LcP01000LeMcE`000W<g00@007LgMcL0009g=`05001g=gLg001g=`020002McL0
1000McIg=P000g<g00H007<f000007<G0002LaL01P00LaMc5`00KaL0009^m`08001^mfkg001^m`00
J_P0009Zn005001Vf000I]P00002H]P300001Ujh001N^@00G[T0009JV@0:001FV@00EYT0059i001B
N@00CUT200001dXi0016>@00@QT003gi0080008ef@<00003:KT00000008000038GT001ei00<00006
6GT000006GT001fI1@0000@UfP00000Yn`@00007<Q/003Hl000f?000>U`01P0000M2O000@W`0049l
0016W0020002AY`20002BY`01P00BY`004Zl001:_1@00003D[`005:l01X0000:D]/005;K001Bf`00
E]/005KK0002E]/03`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00002E]/01@00E]/005KK0000
0UKK00<007ooOol06goo00<007ooOol057oo0`0037oo1000CWoo000fOol8000DOol01000Oomoogoo
1`0000IFf`00E]/005KK0002E]/02`00E]/005KK001Ff`00E]/005KK00000UKK00T005KK001Ff`00
E]/005KK00000UKK00`005KK001Ff`00E]/005KK001Ff`00E]/800001UKK001Ff`00E]/0009Ff`0=
001Ff`00E]/005KK001Ff`00E]/005KK00000UKK00l005KK001F^`00E[/005Jk001F^`00E[/005Jk
00000UJk01P005Jk001F^P00E[X005Jj001F^P00E[X005Jj001F^P00E[X005JJ001FVP00EYX20000
5eJJ001FVP00DYT0059i001BN@00DWT0059i001BN@00DUP0059H001BF000DUP00P0000]>=`00CSL0
058g001B=`00DSL0058g00800008DSH005Hf001F=P00ESH0009F=P0I001F=P00ESH005Hf001F=P00
ESH005Hf001F=P00ESH005Hf001F=P00FSH005YF00000UYF00T005YF001JEP00FUH005YF00000eig
0`0000MRU`00HYMRU`00HYL00002HYL00`00HYL00002H[P00`00H[QR^00300001f:h001R^6:h001R
^000009Rf007001RfF;I001Rf@00H]T00P0000MRf@00H]URf@00H]T00002H]T00`00H]X00002G]X0
1000G]X005kJ0P0000URnP00H_YRnP00H_X006;j00000V;j00L006;jH_X006;j001RnP0200001f<J
001S6V<J001S6P00009S6P04001S6P00IaX20003IaX00`00IcX00002IcX01000JcY[>P000V/j00@0
06/jJcX000=_>@04001_FFmI0002LeT01@00LeP007=H00000g=H00D007MH001gE`0000=gE`03001g
EWMF009gEP05001gEP00McH00002McH00`00McH00004NcD02@00McEg=GLe001k=@00McD00004MaD0
2@00MaEg5GLE001g5@00MaD00002LaD01000L_Ebm@000W;f00@006kfK_H0009^eP06001Zef[G001V
e`000VJg00D006:h001R^000009NV0<0000=FYP005ZH001FN@00DWT0059I001>F@00BST01@0000<]
^0000000300000DAV`000000027l00800004;S`00000=U`200000cYL000jG00200001Cil000nO000
?W`00P0000DnO000?U`003iL00800009?U/00000000nF`00?U/003hk00800003>Q/003HK00D00003
;MX0000000D000036CL00000008000066AH00000;GL0035g0P0000<i]P00@KH00P0000E9mP00COH0
04hF00h0000:ESH005Hf001F=P00FSH005YF0002FUH00`00GUH00002GUH00`00GWH00002HWH00`00
HYH00002IYH30002K[D01000K]E^e@000VkE00@007;EL]D0009^mP04001^mVkf0002L_H01000L_Ib
mP000Vkf00@007<GLaL0009_5`04001^mfkg0002KaL01000KaQ_60000VlH0`000VlH00@006/HJaP0
009[60<0009[6@04001[6F/I0002JaT30002JaT00`00JaT00002JaT01P00JaU[6@00JaT0009[6@07
001[6F/I001[6@00JaT00P000V/i00L006/iJcT006/i001[>@020002KcT00`00KcT00002KcT01000
KcU_>@000Vli00L006li001c>000LcP00002LcP01000LcQc>0000W<h00<007<hLcP00P0000Ac=`00
LcL0009g=`05001g=gLgMcL00002McL01000McMg=`000WLg0P0000Mc=`00LcMc=`00LcH00002LaL0
1000LaMc5`000W<G00H006lGKaL006kg0002K_L30002J_P01@00J_P006KH00000VKH00L006;H001R
^000G[P00002G[T04000G[T005ZI001FV@00EYT0059i001BN@00CUT004YI0P0000=6>@00@QT00`00
00<in@00=MT00P0000@]^@00000Y^@@000067GT000006GT001Ui1P0000<Q^P0000000P0000@Yf`00
000]n`<00003<Q/00000008f?0800003>U`003iL00@0000P@W`0049l0016W000AY`004JL001:W000
BY`004ZL001:_000B[`004jl001>_000C[`004jl001>_000C[`0009>_004001>_000D[`5000035:l
001B_000D[`005:l001Bg000D]`0009Bg00C001Bg000D]/005;K001Bf`00D]/005;K001Bf`00D]/0
05KK00000UKK00D005KK001Ff`00009Ff`0?001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00009F
f`03001Ff`0001eoo`03001oogoo07Eoo`00=Woo0P0017oo0P004goo1P0000IFf`00E]/005KK0002
E]/02`00E]/005KK001Ff`00E]/005KK00000UKK00L005KK001Ff`00E]/00002E]/03P00E]/005KK
001Ff`00E]/005KK001Ff`00E]/6000025KK001Ff`00E]/005KK0002E]/02`00E]/005KK001Ff`00
E]/005KK00000UKK00l005KK001Ff`00E]/005KK001Ff`00E[/005Jk00000UJk01P005Jk001F^`00
E[/005Jk001F^`00E[X005Jj001F^P00E[X005Jj001F^P00E[X;00001eJJ001FVP00DYT0059i0080
000?DWT0059i001BN@00DUP0059H001BF000DUP004hh0080000ZCSL0058g001B=`00DSL0058g001B
=P00DSH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F
=P000UXf00/005YF001JEP00FUH005YF001JEP00009JEP06001NM`00001RUP000V:G00D006:G001R
U`00009RU`03001RU`0000=R^0<00007H[P006:hH[P006:h00000V:h00L006;HH]P006;I001Rf@02
00002F;I001RfF;I001Rf@00H]T00002H]T01`00H]YRfP00G]X005kJ00800009H_X006;jH_X006;j
001RnP00009RnP03001RnP00009RnP06001RnP00001RnP000V<J00<006<J00000V<J00@006<J001S
6P800003IaX006LJ009W6P07001W>VLj001W>P00JcX00P000f/j00D006/jJcX006li0080009_F@05
001cFG=ILeT00003LeP01@00LeQcF7=H00000gMG00D007MG001gE`0000AgEP07001g=WLfMcH007Lf
00000WLf00H007/eNcD007Le0003McD01@00McEg=GLe00000WLE00<007LE00000gLE0P0000Ig5@00
LaEc5@00L_D20003L_H00`00K_I^mP030002J]L02000I]MVe`00I[L006:h0002H[P3000025jH001J
V000FYP005Ii0002DWT200001DiI001:>@00AQT00`0000<]^00000003`0000@Mg000000V70800006
<S`00000=U`003YL0P0000PjG000000nO000?W`003il0P0000DnG000?U`003iK0080008nF`800005
?U/003hk000j>`02000013HK000002gj0P0000@]fP00000UV@<000038GP00000008000037CL00000
00<00003<GL003FF00800003@KH004GF0080000:COH004hF001B5P00DQH0058f0002ESH03@00ESH0
05Hf001F=P00ESH005Hf001J=P00009JEP05001JEP00GUH00002GUH00`00GWH00002HWH00`00HYH0
0002IYH30002K[D01000K]E^e@000VkE00@007;EL]D0009^mP04001^mVkf0002L_H01@00L_IbmP00
K_H00P000W<G00@006lGKaL0009^m`04001_5flG0002KaP01000KaQ_60000VlH00H006lHKaP006/H
0002JaP01P00JaU[6@00JaT0009[6@06001[6F/I001[6@000V/I00L006/IJaT006/I001[6@020002
JaT01P00JaU[6@00JaT0009[6@06001[>F/i001[>@000V/i00H006/iJcT006/i0002KcT00`00KcU_
>@030002KcT01000KcU_>@000Vli00@007<hLcP0009c>004001c>0000002LcP01000LcQc>0000W<g
00<007<gLcL00P0000Ec=`00McMg=`00009g=`04001g=gLg0002McL01000LcMc=`000W<g00<007<f
00000g<G00<007<GLaL00`000VlG00<006kg00000Vkg00<006[g00000V[h00<006[h00000VKH00<0
06KH00000P0001YR^000G[QN^000G[T005ji001JV@00EYT005JI001BN@00DWT004iI001:F@00BST0
04Hi0P0000Ln6@00000003GI000af@0200000bVi000Y^@0300000aei000MN@02000011Ui000001fI
0P0000@MVP00000UfP800006:M/00000;O/0038K0`0000Df?000=S`003YL00800003?U`003il00<0
0007@W`00000AY`004JL00000TJL0P000TZL00H004ZL001:_000B[`200001Tjl001>_000C[`0009>
_00G001>_000C[`004jl001B_000D[`005:l001B_000D[`005:l001B_000D]`00002D]`03@00D]`0
05;L001Bf`00D]/005;K001Bf`00009Bf`<00006D]/005KK001Ff`000UKK01<005KK001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/00002E]/00`00E]/0000MOol00`00Oomoo`1eOol003Eoo`80
00Ioo`80019oo`800004E]/005KK0002E]/02`00E]/005KK001Ff`00E]/005KK00000UKK00L005KK
001Ff`00E]/00002E]/03P00E]/005KK001Ff`00E]/005KK001Ff`00E]/600001UKK001Ff`00E]/0
009Ff`0=001Ff`00E]/005KK001Ff`00E]/005KK00000UKK00/005KK001Ff`00E]/005KK001Ff`00
009Ff`0B001Ff`00E]/005Jk001F^`00E[/005Jk001F^`00E[/005Jk400000YBVP00001BVP00DYX0
05:J001BVP/00003DWT0059i0080000=DUP0059H001BF000DUP004hh001>=`00CSL00P00029B=`00
DSL0058g001B=P00DSH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00
ESH0009F=P0=001F=P00FSH005YF001JEP00FUH005YF00000UYF00P005YF0000069f001RUP000V:G
00<006:G00000V:G00D006:G001RU`00009R^0800007I[L006:hH[P006:h00000V:h00<006:h0000
0V;H00H006;IH]T006;I0002H]T01@00H]T006;I00000V;I00L006;IH]T006;J001NfP0200002F;j
001RnV;j001RnP00H_X00002H_X01@00H_X006;j00000V;j0P0000MRnP00H_YRnP00HaX00002HaX0
1000HaX006<J0P0000EW6P00IaYW6P0000=W6P04001W>P00IcX20002JcX01000JcY[>P000f/j00@0
06liKcT0009_F@04001cFG=I0003LeP01@00LeQcF7=H00000gMG00<007MG00000WMG00D007MFMeIg
EP0000=g=P03001g=P00009g=P06001k=G/e001g=@000gLe00L007LeMcEg=@00MaD00002MaD01@00
MaEg5GLE00000WLE00@007<ELaEc5@800005L_H007;fL_H00002K_H00`00J]L00002J]L01P00I]MV
e`00I[L0009R^0<00004G[P005jH0002FYP02P00FYP005Ii001BN@00DUT004iI0P0000=66@000000
0`0000<UN00000002`0000D=VP000000027l00800004:Q`00000=U`200000cYL000jG00200000cYL
0000000200001Cil000nO000?U`00P0000LnF`00?U/003iK000j>`0400000cXk000j6`0200000c7j
0000000300000bVi0000000=00000c5g000eUP0200001D6f0015eP00BOH00P0000Q>5P00DQH0058F
001B=P000UHf00/005Hf001F=P00ESH005Hf001F=P00009J=P07001JEP00FUH005iF00000UiF00P0
05ifGWH0069f001RUP000VJF00H006ZeJ[D006je0002K]D01000K]D000000W;E00D006kfK_H006kf
008000=bmP03001bmW;f00800005LaH007<GLaL00002KaL200001flG001_5flG001_6000009_6004
001_66lH0002KaP00`00JaQ[60030002JaT01`00JaU[6@00JaT006/I0080009[6@06001[6F/I001[
6@000V/I00H006/IJaT006/I0002JaT01000JaT006/I0P000V/i00L006/iJcT006/i001[>@020002
JcT00`00KcT00002KcT01000KcU_>@000Vli00@006li001_>@8000=c>006001c>7<h001c>0000W<h
00@007<hLcP000=c=`03001c=`00009c=`05001g=gLg001g=`020002McL01000McMg=`000W<g00L0
07<gLcMc=`00LaL00002LaL01000LaMc5`000W<G00<006lG00000Vkg0`000V[g00D006[h001Zn000
009Vf0<0000;H]P006:hH[P005jh001N^@00G[T00002FYT02P00EYT005JI001BN@00DWT004iI0P00
00E:>@00AST0048I00800003>OT0000000@00003:KT002Vi008000038GT001ei00<000046GT00000
7IT500000bGJ0000000200000bWk000]n`020002<Q/200001CHl000jG000>U`00P0000<nO000@W`0
1@0000=6W00000000TJL01L004ZL001:W000BY`004Zl001:_000C[`004jl001>_000C[`004jl001>
_000009>_004001>_000D[`200003e:l001B_5:l001B_000D[`005:l001Bg000D]`00002D]`03000
D]`005;K001Bf`00D]/005;K001Bf`<00004D]/005KK0002E]/04`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`00009Ff`03001Ff`00009Ff`03001oogoo01]oo`03001oogoo07Aoo`00
=Goo0P001Woo0P004Woo00d007oo001Ff`00E]/005KK001Ff`00E]/00002E]/01`00E]/005KK001F
f`00009Ff`0<001Ff`00E]/005KK001Ff`00E]/005KK200000IFf`00E]/005KK0002E]/03@00E]/0
05KK001Ff`00E]/005KK001Ff`00009Ff`09001Ff`00E]/005KK001Ff`00009Ff`0B001Ff`00E]/0
05KK001Ff`00E]/005KK001F^`00E[/005Jk2000011F^`00E[/005Jk001F^`00E[X005Jj001F^P00
DYX0009BVP800005DYX005:J001BVP0200002E9j001BNP00CWX004ij001>F@0800003E9H001BF000
DUP004hh001>=`00CSL0058g0080000LDSL0058g001B=P00DSH005Hf001F=P00ESH005Hf001F=P00
ESH005Hf001F=P00ESH005Hf0002ESH04@00ESH005Hf001F=P00FSH005YF001JEP00FUH005YF0000
0UYF0`000V9f00P006:FHYH006:G001RU`000V:G00<006:G00000V:G0P0000AV]`00I[L0009R^003
001R^000009R^003001R^000009Rf004001Rf@000002H]T01@00H]T006;I00000V;I00<006;I0000
0V;I00H006;J000006;j0002H_X01@00H_X006;j00000V;j00H006;j001RnP00H_X300001f;j001R
nV;j001RnP00009S6P04001S6P00HaX200001FLJ001W6VLJ00000VLJ00@006LJIaX0009W>P03001[
>P0000=[>P05001[>V/j001[>P020002KcT02000KeU_F@00LeT007=H0003LeP01@00LeP007=H0000
0gMG00D007MGMeMgE`00009gEP03001g=P0000=g=P03001g=WLf009g=P03001k=@00009g=@05001g
=@00McD00002McD00`00MaD00002MaD01@00MaEg5GLE00000gLE00@007<ELaD0009bmP04001bmW;f
0002K_H01000J]MZe`000V[G00<006KG00000VJg0`0000AR^000G[P0009NV00>001JV000FYP005Ii
001BN@00DUT004iI001:>@<00004>MT000009GP@000011gL000002HL0P0000H^?000000fG000>U`2
00001SYL000003iL000nG0800005?W`003iL000nG002000013iK000nFciK0P0000<j>`0000000P00
00<j6`00=Q/00P0000<]nP0000001@0000DIF000000001DG00@000066AH00000<GL003FF0P0000M1
]P00AMH004Wf001=mP0200001U8F001B5P00DSH0009F=P07001F=P00ESH005Hf00000UHf00/005Hf
001J=P00FUH005YF001NEP00009NEP08001NMUif001RMP00HYH0009VUP04001Z]FZe0002K[D00`00
K]E^e@0200001G;E001beG;E00000Vkf0P0000Ebm@00L_IbmP00009bmP04001c5W<F0002LaL01000
KaM_5`000VlG00@006lGKaL0009_60800004KaP006lH0002KaP01000JaQ[60000V/H00<006/I0000
0V/I00@006/IJaT0009[6@03001[6@00009[6@04001[6@00JaT20002JaT01`00JaU[6@00JaT006/I
0080009[6@06001[>F/i001[>@000V/i00<006/i00000V/i00<006liKcT00`000Vli00@006liKcT0
009_>@04001_>Fli0002LcP01000LcQc>0000W<h00<007<hLcP00P0000Mc>000LcMc=`00LcL00002
LcL01@00McMg=gLg00000WLg00L007Lg001g=`00LcL00002LcL01P00LcMc=`00LaL0009c5`04001c
5g<G0002LaL00`00KaL00002K_L00`00K_L00002J_L00`00J_P00002J_P01@00I]P006KH00000V;H
00D006:h001N^000009N^@0@001N^@00FYT005JI001FV@00DWT0059i001>F@00BUT200001DHi0012
6@00?QT00P000SWi0P0000H]^@00000Y^@009IT2000011ei000001fI0P0000@MN@00000QVP800004
8KX000009M/400001Bgk000b6`00<Q/00P000SHl0P0000<jG000?U`00P0000E2O000@W`0049l00D0
000DAY`004ZL001:W000BY`004Zl001:_000C[`004jl001>_000C[`0009>_00G001>_000C[`004jl
001B_000D[`005:l001B_000D[`005:l001B_000D]`00002D]`03P00D]`005;L001Bf`00D]/005;K
001Bf`00D]/3000015;K001Ff`000UKK00L005KK001Ff`00E]/00002E]/02P00E]/005KK001Ff`00
E]/005KK20007Goo00<007ooOol0M7oo000dOol20008Ool2000AOol01`00Ool005KK001Ff`00009F
f`07001Ff`00E]/005KK00000UKK00`005KK001Ff`00E]/005KK001Ff`00E]/6000025KK001Ff`00
E]/005KK0002E]/02`00E]/005KK001Ff`00E]/005KK00000UKK00/005KK001Ff`00E]/005KK001F
f`00009Ff`0>001Ff`00E]/005KK001Ff`00E]/005KK001Ff`X00008E[/005Jk001F^`00E[/0009F
^`0@001F^`00E[/005Jk001F^P00E[X005Jj001BVP00DYX200003e:J001BVP00DYX005:J001BNP00
DWX004ij001>NP0200001DiI001:F@00BST00`00011BF000001BF000CSP004hg001>=`00DSL0058g
001B=`80000BDSH0058f001F=P00ESH005Hf001F=P00ESH005Hf001F=P000UHf01D005Hf001F=P00
ESH005Hf001F=P00ESH005Xf001JEP00FUH005YF00000UYF00D005YF001NMP00009RMP06001RUV:F
001RU`000V:G00D006:G001RU`00009RU`04001V]fJg0002I[L00`00H[P00002H[P00`00H[P00002
H[P01P00H]P00000H]P0009Rf@03001Rf@00009Rf@05001Rf@00H]T00002H]T200002F;i001RnV;j
001RnP00H_X00002H_X01P00H_X006;j001RnP800003H_X006;j009RnP03001RnP00009RnP03001S
6P00009S6P03001W6P00009W6P06001W6VLJ001W6P000VLJ00@006Lj0000009[>P04001[>V/j0003
JcX01000KcU_>@000Vli00@006mIKeT000=cF005001cF7=HLeP00003LeP01000MeMgE`0017MG00D0
07MF001g=P0000=g=P03001g=WLf00=g=P09001g=GLeMcD007Le001g=@0000=g=@03001g5GLE009g
5@04001g5@000003MaD01000LaEc5@000W;f00D007;fL_H006kf0080009Ze`06001Zef[G001Ve`00
0VJg00D006:h001R^000009N^00@001NV000FYP005ZH001FN@00DWT0059I001>F@00BST300000cWI
0000000?00001@fJ000000008O`00P0000@Z7000000b?0800003>U`003YL00800003>U`003iL0080
000>?U`00000?U`003iL000nF`00?U/003iK000j>`800003>S/0000000800004=Q/00000;OX20000
12Fj000002FI100000<I=`0000000P0000<I5P0000000P0000@aM`00000i]P800009AMH004Wf001=
mP00CQH0058F00800005DSH005HfESH00002ESH04@00ESH005Hf001F=P00ESH005Xf001JEP00FUH0
05iF00000eiF00D005if001RMP00009RUP<0009Z]@04001^]Fje0002K]D200001G;E001beG;E0000
0Vkf00@007;eL_D0009bmP04001bmW;f0002LaH01000LaMc5`000VlG00@006lGKaL0009_5`04001_
66lH0002KaP01000KaQ_60000VlH0`000V/H00L006/IJaT006/I001[6@020002JaT01`00JaU[6@00
JaT006/I0080009[6@03001[6@00009[6@06001[6F/I001[6@000V/I00L006/iJcT006/i001[>@02
0002JcT00`00JcT00002KcT01000KcU_>@000Vli00@006li001_>@80009_>@05001c>7<h001c>002
0002LcP01000LcQc>0000W<h00<007<gLcL00P0000Ec=`00LcMc=`00009g=`04001g=gLg0002McL2
00001G<g001c=g<g00000W<g00<007<G00000g<G0`000W<G00<006lG00000Vkg00P006kgK_L006[g
001Zn0000V[h0`0000MVf000H]QRf000H[P00002G[P05P00G[T005ji001JV@00EYT005JI001BN@00
DWT004iI001:F@00BST004Hi0P0000Dn6@00>OT003Wi00@00003:KT002Vi00<000037GT001ei00D0
00037IT0000000<000049MX00000:O/20002;O/200000c8K000f?00600001CiL000nO000@W`00P00
00E2O000AY`004JL00P00005BY`004Zl001:_00200001Tjl001>_000C[`0009>_00G001>_000C[`0
04jl001B_000D[`005:l001B_000D[`005:l001B_000D]`00002D]`03P00D]`005;L001Bf`00D]/0
05;K001Bf`00D]/2000025;K001Bf`00E]/005KK0002E]/01000E]/005KK3@0000MFf`00E]]Ff`00
E]/0000MOol00`00Oomoo`1dOol003Aoo`8000Qoo`80015oo`0:001oogoo001Ff`00E]/005KK0002
E]/03000E]/005KK001Ff`00E]/005KK001Ff`H00006E]/005KK001Ff`000UKK00d005KK001Ff`00
E]/005KK001Ff`00E]/00002E]/02@00E]/005KK001Ff`00E]/00002E]/03P00E]/005KK001Ff`00
E]/005KK001Ff`00E]/800002UKK001F^`00E[/005Jk001F^`000UJk01P005Jk001F^`00E[/005Jk
001F^`00E[/005Jk001F^P00E[X005Jj001BVP00DYX200005E:J001BVP00DYX005:J001BNP00DWX0
04ij001>NP00CUT004iI001:F@0200000dXi0000000300003U9H000004hg001>=`00DSL0058g001B
=`00DSL200003U8f001F=P00ESH005Hf001F=P00ESH005Hf0002ESH05@00ESH005Hf001F=P00ESH0
05Hf001F=P00ESH005Xf001JEP00FUH00002FUH00`00FUH0000200000eif001RMP02HWH01@00HYH0
06:G00000V:G00<006:G00000V:G0`000fJg00<006Jg00000V:h00D006:h001R^000009R^0800007
H]P006;HH]P006;I00000V;I00H006;I001Rf@00H]T300002F;I001RnF;i001RnP00H_X00002H_X0
1P00H_X006;j001RnP800005H_X006;jH_X00002H_X02@00H_YRnP00H_X006<J001S6P020002IaX0
0`00IaX00002IaX01@00IaYW6P00IaX00P000V/j00<006/j00000f/j00@006/j0000009_>@05001_
>Fli001_F@020003LeP01@00LeQcF7=H00000g=H00D007MG001gE`0000AgE`09001g=WLfMcH007Lf
001g=P0000Ag=P09001g=GLeMcD007Le001g=@0000=g=@03001g5GLE009g5@05001g5@00MaD00002
MaD01000LaD000000g;f00<007;fL_H00P0000A^mP00J]L0009Ze`03001VefKG00<00009H[P006:h
H[P005jh001NV000009JV00:001JV000EWT0059i001BF@00CUT200001DHI00000000<KT00P0000<I
=`0000003@0000@If`00000V70800004;S`00000<S`200000cYL000jG00200000ciL000nG0020000
0ciL0000000200002CiK000nF`00?U/003Xk000j>`0200000cHK000000020000137j000002gJ3@00
00DI5P00000001dF00<0000A>KH00000AMH004Wf001=mP00CQH0058F001B5P00DSH00002ESH04`00
ESH005Hf001F=P00ESH005Hf001J=P00FUH005YF001NEP0000=NEP05001NMP00HWH00002HYH30002
J[D01000K[E^]@000VkE00@007;EL]D0009be@04001^mVkf0002L_D01@00L_IbmP00L_H00P000g<F
00<007<GLaL00P0000Ec5`00KaM_5`00009_5`<0009_6004001_66lH0002KaP01P00KaQ_6000JaP0
009[6@04001[6F/I0002JaT00`00JaT00002JaT01P00JaU[6@00JaT0009[6@07001[6F/I001[6@00
JaT00P000V/I00L006/IJaT006/i001[>@0200001F/i001[>F/i00000V/i0`000Vli00@006liKcT0
009_>@04001_>Fli0002KcT01000LcQc>0000W<h00<007<h00000W<h00D007<hLcQc>000009c=`03
001c=`00009c=`04001g=`000002McL01000McMg=`000W<g00D007<gLcL007<g0080009c5`04001c
5g<G0002LaL00`00LaL00002KaL30002K_L00`00J_L00002J_P01@00J_P006KH00000VKH00<006;H
00000V:h00L005jh001N^@00G[T00002FYT02P00EYT005JI001BN@00DWT004iI0P0000E:>@00AST0
048I00800005>OT003Wi000en@0200000bVi000Y^@02000012FI000001ei0P0000@QV@00000MV@80
00068KX000009MX002GK100000D]n`00<Q/0038K00800003=S`003YL00@00009?W`0049l0012O000
@W`004JL00800096W004001:W000BY`900002Tjl001>_000C[`004jl001>_0000Tjl00@004jl001B
_080000?D[`005:lD[`005:l001B_000D[`005;L001Bg000009Bg00<001Bg000D]/005;K001Bf`00
D]/005;K400000aFf`00E]/005KK001Ff`00E]/005KK0002E]/01@00E]/005KK00007Goo00<007oo
Ool0M7oo000dOol20008Ool2000AOol04P00Oomoogoo001Ff`00E]/005KK001Ff`00E]/005KK001F
f`H00006E]/005KK001Ff`000UKK00d005KK001Ff`00E]/005KK001Ff`00E]/00002E]/02@00E]/0
05KK001Ff`00E]/00002E]/03P00E]/005KK001Ff`00E]/005KK001Ff`00E]/6000025KK001Ff`00
E]/005KK0002E]/08@00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F
^`00E[X005Jj001F^P00DYX00002DYX200001e:J001BVP00DYX005:J0080000=DWX004ij001>NP00
CUT004iI001:F@00BST00P0000=:>000AQP00`0000a>>000001>=`00DSL0058g001B=`00DSL20000
3U8f001F=P00ESH005Hf001F=P00ESH005Hf0002ESH05@00ESH005Hf001F=P00ESH005Hf001F=P00
ESH005Xf001JEP00FUH00002FUH3000015if001NMP000f9f00<006:F00000V:G00D006:G001RU`00
009RU`03001V]`0000=V]`03001V]`00009R^003001R^000009R^0<000=Rf003001Rf000009Rf@05
001Rf@00H]T00002H]T00`00H]T00003H]T01@00H_T006;j00000V;j00H006;j001RnP00H_X20000
1f;j001RnV;j001RnP0000=RnP06001RnP00H_X006<J0P000V<J00<006LJ00000VLJ00D006LJIaX0
06LJ00800005IaX006/jJcX00002JcX00`00JcY[>P020002JcT01000KcU_>@000Vli00@006liKcT0
00=cF005001cF000LeP00003LeP01@00MeMgEgMG00000gMG00L007LfMcIg=P00McH00002McH01P00
McIg=P00McH000=g=@09001g=GLeMcD007Le001g5@0000=g5@05001g5@00MaD00003MaD200001G<F
001bmW;f00000W;f00@006kfK_H0009Ze`03001Ze`00009Ve`03001Ve`00009R^005001R^000G[P0
0002GYP03P00FYP005ZH001FN@00DWT0059I001>F@00BST300000cWI0000000?00000`fJ00000002
00000bHL000Z70020000138l000003IL0P0000DjG000>U`003iL00800006?U`00000?U`003iL0P00
0SiK00L003iK000003Xk000j>`0200000c8K0000000200001Bgj000000008IT00`0000<IF0000000
0P0000<<mP0000000`000QdF0P0000<i]P00@KH00P0000a9mP00COH004hF001B5P00DQH0058f0002
ESH04@00ESH005Hf001F=P00ESH005Hf001J=P00FUH005YF00000UiF00P005iFGUH005if001RMP00
0V:F00H006ZEJYD006Ze0002K[D01000K]E^e@000W;E00D007;EL]D006kf0080009bm@04001bmW;f
L_H200001G<F001c5W<F00000W<G00@007<GLaL0009_5`04001_5flG0002KaL01`00KaQ_6000KaP0
06lH0080009_6007001[66/H001[6@00JaT00P000V/I00L006/IJaT006/I001[6@020002JaT01P00
JaU[6@00JaT0009[6@06001[6F/I001[6@000V/I00H006/iJcT006/i0002JcT00`00JcT00002JcT0
1000KcU_>@000Vli00@006li001_>@80009_>@05001_>Fli001c>0020002LcP00`00LcQc>0020000
1G<h001c>7<h00000W<g00<007<g00000W<g00L007Lg001c=`00McL00002McL01@00LcMc=g<g0000
0W<g00H007<gLcL007<G0002LaL01P00LaMc5`00LaL0009_5`08001^mfkg001^m`00J_L0009Zn0<0
009Vf003001Vf000009Rf007001R^000G[P005ji00000Uji400000E6>@00@QT003hI0080008in@D0
0003:KT002FI00D000037IT0000000<000038IX0000000<000039M/002Wk00@00005<Q/0038K000f
?00200000cYL000jG00400005d9l0012O000@W`004JL0016W000AY`004ZL001:W000BY`004ZL001:
_000C[`0500000=B_00000006P0000IBf`00D]/005;K0002D]/04`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`00009Ff`06001FfeKK001Ff`007Goo00<007ooOol0Lgoo000dOol20008
Ool2000AOol03000Oomoogoo001Ff`00E]/005KK001Ff`H00006E]/005KK001Ff`000UKK00/005KK
001Ff`00E]/005KK001Ff`00009Ff`09001Ff`00E]/005KK001Ff`00009Ff`0>001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`P00006E]/005KK001Ff`000UKK01T005KK001Ff`00E]/005KK001F^`00
E[/005Jk001F^`00E[/005Jk001F^`00E[/00002E[/04000E[/005Jk001F^`00E[X005Jj001F^P00
DYX005:J0P0000mBVP00DYX005:J001BVP00DWX0059j001>NP00CWX00P0000M>F@00BUT004Xi001:
>@0200000dHH0016600300002Thg0000058g001B=`00DSL0058g0P0000iB=P00ESH005Hf001F=P00
ESH005Hf001F=P000UHf01<005Hf001F=P00ESH005Hf001F=P00ESH005Hf001J=P00FUH00002FUH0
1`00FUH005if001NMP00009NMP06001RMV9f001RUP000V:G00<006:G00000V:G0`000VJg00@006Jg
I[L0009V]`03001R^000009R^0<0009Vf006001Rf6;H001Rf0000V;I00<006;I00000V;I0`000V;I
00H006;IH]T006;i0002H_X01P00H_X006;j001RnP800007H_X006;jH_X006;j00000V;j00L006;j
H_X006;j001RnP0200001F<J001S6V<J00000VLJ00@006LJIaX0009W6P03001W6P00009W6P0:001[
>V/j001[>P00JcX006/j0002JcT01@00KcU_>@00KcT00P000fli00D007=HLeQcF00000=cF004001c
F7=H0003MeL01P00MeMgE`00McL000=g=P05001g=WLfMcH00002McH00`00McH00003McD02@00McEg
=GLe001g=@00MaD00004MaD01000MaEg5@000gLE00@007<FLaH0009bmP04001bmW;f0002K_H01000
J]MZe`000V[G0`000VKG00D006:h001R^000009N^00@001NV000FYP005ZH001FN@00DWT0059I001>
F@00BST3000013WI000002VH4@0000LIf`00000002XL000^?0020000138l000003IL0P0000DjG000
?U`003iL00800003?U`003iL00800007>U/00000000nF`00>S/00P0000<j>`00=Q/00P0000@an`00
000]nP8000039KX0000000H000035AL0000000<000037AH001dF00800003>KH0046f0080000<BOH0
04gf001>5P00DQH0058F001B=P000UHf00l005Hf001F=P00ESH005Hf001F=P00FSH005YF00000UYF
00<005iF00000UiF00<005if00000V9f00<006:F00000VZE00<006Ze00000Vje00@006kE0000009b
e@08001beG;E001^mP00L_D0009bm@04001bmW;f0002LaH01000LaIc5P000W<G00@007<GLaL0009_
5`04001_5flG0002KaL01000KaQ_60000VlH00H006lHKaP006lH0002JaP01000JaU[6@000V/I00<0
06/I00000V/I00@006/IJaT0009[6@03001[6@00009[6@04001[6@00JaT20002JaT01`00JaU[6@00
JaT006/i00800005JcT006/iJcT00002JcT30002KcT01000KcU_>@000Vli00@006liKcT0009_>@06
001_>Fli001c>0000W<h00@007<hLcP0009c>005001c>7<h001c=`020002LcL01000LcMc=`000W<g
00<007LgMcL00P0000Ec=`00LcMc=`00009c=`07001c=g<g001c5`00LaL00P000W<G00H007<GLaL0
06lG0002K_L02P00K_M^m`00J_L006[h001Vf0000VKH00<006KH00000V;H00<006:h00000Ujh00<0
05ji00000P0000eJV@00FYT005JI001BN@00DWT004ii001>F@03000024Hi000003hI000in@00>OT2
00000c7I00000002000012FI000002FI0P0000@MV@00000QV@8000048IX000009KX3000012GK0000
00000RhK0P0000Db6`00=S`003Hl00800003>U`003iL00<00003@W`000000092O0040016W0000002
AY`04P00BY`00000BY`004ZL001:_000C[`004jl001>_000C[`0009>_00:001>_000C[`004jl001B
_000D[`300002U:l001B_000D[`005:l001B_0000U;L00@005;L001Bg0L00008D]/005;K001Bf`00
D]/0009Bf`09001Bf`00E]/005KK001Ff`00009Ff`0=001Ff`00E]/005KK001Ff`00E]/005KK0000
0UKK00<005KK00007Goo00<007ooOol0Lgoo000dOol20008Ool2000AOol00`00Oomoo`02Ool70000
1UKK001Ff`00E]/0009Ff`0;001Ff`00E]/005KK001Ff`00E]/00002E]/02@00E]/005KK001Ff`00
E]/00002E]/03P00E]/005KK001Ff`00E]/005KK001Ff`00E]/6000025KK001Ff`00E]/005KK0002
E]/05@00E]/005KK001Ff`00E]/005KK001Ff`00E]/005Jk001F^`00E[/00002E[/08P00E[/005Jk
001F^`00E[/005Jk001F^`00E[/005Jk001F^P00E[X005Jj001BVP00DYX005:J001BVP00DYX005:J
0P0000eBNP00DWX004ij001>NP00CUT004iI001:F@0200000dXi001:>00200000dHH001660030000
24hg0000058g001B=`00DSL200003U8f001F=P00ESH005Hf001F=P00ESH005Hf0002ESH03`00ESH0
05Hf001F=P00ESH005Hf001F=P00ESH00002FSH01000FUH005YF0`0000MNMP00GWINMP00GWH00002
HWH02000HYIRUP00HYL006:G0002HYL00`00I[L00002I[L01000I[MV]`000VJg00<006:h00000V:h
00<006KH00000VKH00@006;HH]P0009Rf003001Rf@00009Rf@<0009Rf@03001Rf@00009Rf@09001R
nF;i001RnP00H_X006;j00800007H_X006;jH_X006;j00000V;j00L006;jH_X006;j001RnP020000
1F<J001S6V<J00000V<J00L006LJIaX006LJ001W6P020002IaX00`00IaX00002JcX01000JcX00000
0f/j00@006/iJcT0009_>@04001_>Fli0003KcT01000LeP000000g=H00D007=H001cE`0000=gE`05
001gE`00McL00003McH00`00McIg=P02McH00`00McH00002McH01@00McD007Lf00000WLe00<007Le
00000WLE00D007LEMaEg5@0000=g5@04001g5GLE0002LaH01000L_IbmW;f0`000fkf00<006[G0000
0V[G00<006KG00000VKG00<006:h00000V:h018005jh001NV000FYP005ZH001FN@00DWT0059I001>
F@00BST2000013hI0000036i4@0000DE^`00000002Gl00800003;S`0038l00800004=U`00000=U`2
00001CiL000nG000?U`00P0000<nG000?U`00P000SXk0P0000<j>`00>S/00P0000<f6`00<Q/01@00
00D]fP00000001ei00X000046AH000007AH400000d6f0015eP0200002Tgf001>5P00DQH0058F001B
=P000UHf00d005Hf001F=P00ESH005Hf001F=P00FSH00002FUH01@00FUH005iF00000UiF00<005if
00000V9f0`000VZE00@006ZeJ[D0009^]@800005L]D007;EL]D00002L]D200001G;e001bmG;e0000
0W;f00@007<FLaH0009c5P04001c5`000003LaL00`00KaM_5`02000016lG001_5`000VlH00@006lH
KaP0009_6007001_66lH001[6000JaT00P000V/I00L006/IJaT006/I001[6@020002JaT01`00JaU[
6@00JaT006/I0080009[6@03001[6@00009[6@06001[6F/I001[>@000V/i00<006/i00000V/i00@0
06liKcT0009_>@04001_>@00KcT20002KcT01000KcU_>@000Vli00@007<hLcP0009c>0<000=c>004
001c>7<h0002LcL00`00LcL00002LcL01000LcMc=`000WLg00@007<gLcL0009c=`04001c=`000002
LcL01000LaMc5`000W<G00<007<G00000W<G0P0000A_5`00K_L0009^m`03001Zm`000080009Vf003
001Vf000009Vf003001Rf000009R^0D0000AG[T005ZI001JV@00EYT0059i001BN@00CWT004iI001:
F@0600001CWi000in@00=OT00P0000H]f@00000UV@009IT500000b6I000000030000126j000002GJ
0`0000HYn`00000^6`00<Q/400000cHl000jG00200000ciL000nO00500004D9l0016W000AY`004JL
001:W000BY`004ZL001:W000B[`00P0001]>_000C[a>_000C[`004jl001>_000C[`004jl001B_000
D[`005:l001B_000D[`005:l00000U:l00<005:l00001P0000YBf`00D]/005;K001Bf`00D]/0009B
f`05001Bf`00D]/00002D]/04`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00009F
f`05001Ff`00E]/0000MOol00`00Oomoo`1cOol003Aoo`8000Qoo`80015oo`03001oogoo009oo`07
001Ff`00E]/005KK00000UKK00/005KK001Ff`00E]/005KK001Ff`00009Ff`07001Ff`00E]/005KK
00000UKK00h005KK001Ff`00E]/005KK001Ff`00E]/005KK200000IFf`00E]/005KK0002E]/04`00
E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`0S001Ff`00E[/005Jk001F^`00
E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[X005Jj001F^P00DYX00002DYX20000
2e:J001BVP00DYX005:J001BNP00DWX00P0000U>NP00CUT004iI001:F@00BST00P0000=:>000AQP0
0P0000=66000AOP00`0000IB=`00001B=`00DSL200003U8f001F=P00ESH005Hf001F=P00ESH005Hf
0002ESH02`00ESH005Hf001F=P00ESH005Hf00000UHf00H005Hf001J=P00FUH3000015iF001NMP00
0Uif00<005if00000V9f00H006:FHYH006:G0002HYL30002I[L00`00I[L00003I[L00`00I[L00002
H[P30002I]P00`00I]P00003H]P00`00H]P00002H]T300001F;I001RfF;I00000V;I00T006;IH]T0
06;i001RnP00H_X00P0000MRnP00H_YRnP00H_X00002H_X01`00H_YRnP00H_X006;j00800005H_X0
06<JHaX00002HaX01`00HaYS6P00IaX006LJ0080009W6P03001W6P00009W6P06001[>V/j001[>P00
0f/j00D006/iJcT006li008000=_>@05001_>FliKcT00002LcP01@00LeQcF7=H00000g=G00D007MG
MeMgE`0000=g=`05001g=P00McH00004McH02@00McIg=WLf001g=@00McH00003McD01@00MaEg5GLE
00000WLE00<007LE00000WLE00@007LE000000=c5P04001bmW;f0002K_H01P00K_I^mP00J]L0009Z
e`06001VefKG001Ve`000V:h00L006:h001N^000GYP00002FYP02P00FYP005Ii001BN@00DUT004iI
0`0000<n6@00>MT00`0000<MF00000003P0000DIf`00000002XL00800003<S`0038l00800004=U`0
0000>U`400000ciL000nG00200001ciL000jF`00>S/003Xk00800003>S/003Xk00800003<Q/0037k
00H000058IT00000000IF00:00000adF0000000200001D6f0015eP00BOH00P0000Q>5P00DQH0058F
001B=P000UHf00/005Hf001F=P00ESH005Hf001F=P00009J=P07001JEP00FUH005iF00000UiF00P0
05ifGWH0069f001VU@000VZE00@006ZeJ[D0009^]@800005L]D007;EL]D00002L]D01000L_Ebm@00
0W;e00@007;f000000=c5P03001c5W<F00800005LaH007<GLaL00002KaL01000KaM_5`000VlG00<0
06lHKaP00P0000A_6000KaP0009_6004001[66/H0002JaP00`00JaT00002JaT01000JaU[6@000V/I
00<006/I00000V/I00H006/IJaT006/I0002JaT01`00JaU[6@00JaT006/I0080009[>@03001[>@00
009[>@<0009_>@04001_>Fli0002KcT01000KcU_>@000Vli00@006li001_>@80009c>004001c>7<h
0002LcP01000LcQc>0000W<h00L007<gLcL007<g001c=`020002LcL01000McMg=`000W<g00D007<g
LcMc=`00009c=`03001c=`00009c5`06001c5g<G001c5`000W<G00@006lGKaL0009^m`05001^m`00
J_L00002J_P00`00I]P00002I]P00`00I]P00002H]P300001Uji001N^@00G[T0009JV@0:001JV@00
EYT0059i001BN@00CWT200001DYI0016>@00@SX0100000<in@00=OT00P0000<]f@0000000P0000@U
V@00000UV@8000048IT000008KX200000b6j000U^P0200000bWK000Yn`0200001BhK000b6`00=S/0
100000<jG000>U`00P0000DnO000@W`0049l00D0000FAY`004JL001:W000BY`004ZL001:W000B[`0
04jl001>_000C[`004jl0002C[`03P00C[`004jl001>_000D[`005:l001B_000D[`90002D]`04`00
D]`005;L001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00009Bf`0E001Bf`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK001Ff`00009Ff`06001FfeKK001Ff`007Goo00<007ooOol0LWoo000d
Ool20008Ool2000AOol00`00Oomoo`03Ool03@00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`07
001Ff`00E]/005KK00000UKK00h005KK001Ff`00E]/005KK001Ff`00E]/005KK1P0000QFf`00E]/0
05KK001Ff`000UKK014005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`0K001Ff`00
E]/005KK001Ff`00E]/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00009F^`04001F^`00
E[/>00003e:J001BVP00DYX005:J001BNP00DWX004ij001>NP0200001diI001:F@00BST004Xi0080
0003AQP004HH00800003AOP004Gg00<00006DSL00000DSL0058f0P0000aF=P00ESH005Hf001F=P00
ESH005Hf0002ESH01`00ESH005Hf001F=P00009F=P08001F=P00ESH005Hf001J=P<00004FUH005iF
0002GWH01@00GWH005if00000f9f00D006:F001RU`00009RU`03001V]`00009V]`04001V]fJg0002
I[L00`00I[L00002H[P01P00I]QVf000I]P0009Vf006001Rf6;H001Rf0000V;I00<006KI00000V;I
00H006;IH]T006;I0002H]T01000H_T006;j0P0000MRnP00H_YRnP00H_X00002H_X01`00H_YRnP00
H_X006;j00800007H_X006;jH_X006<J00000V<J00D006<JHaX006LJ00800005IaX006LJIaX00002
IaX01000IaX006/j0P000V/j00D006/jJcY[>P00009[>@04001_>Fli0002KcT01@00KcU_>Fli0000
0g<h00@007=HLeP000=cE`05001gEgMGMeL00003McL01@00McH007Lf000017Lf00T007LfMcIg=P00
McD007Lf00000gLe00<007LEMaD00WLE00D007LE001g5@00009g5@05001g5@00LaH00002LaH01000
L_IbmP000Vkf00@006kfK_H0009Ze`<0009Ve`0:001VefKG001R^000H[P005jh0002GYPA000013WI
000002VH400000DAV`00000002Gl00800006;Q`00000<S`003IL0P0000HfG000000jG000>U`20000
0ciL000nG002000013YK000j>cXk0P0000Hj>`00000j>`00=Q/20000137k000002WJ0P0000<U^P00
00001`0000<<mP0000000`000QdF0`0000M1]P00AMH004Wf001=mP0200001U8F001B5P00DSH0009F
=P07001F=P00ESH005Hf00000UHf00/005Hf001J=P00FUH005YF001NEP00009NEP06001NMUif001R
MP000VJE00<006ZE00000VZe00@006jeK[D0009be@04001beG;E0002L]D01000L_Ebm@000W;e00D0
07;f001c5P00009c5P04001c5W<F0002LaH01000LaMc5`000VlG00@006lGKaL0009_5`04001_66lH
0002KaP01`00KaQ_6000KaP006/H0080009[6007001[6F/I001[6@00JaT00P000V/I00L006/IJaT0
06/I001[6@020002JaT01P00JaU[6@00JaT0009[6@03001[>@00009[>@03001[>@00009[>@04001[
>F/i0002KcT01000KcT006li0P000Vli00@006liKcT0009_>@06001_>6lh001c>0000W<h00@007<h
LcP0009c>004001c>0000002LcL01000LcMc=`000W<g00<007<gLcL00P0000Ec=`00LcMc=`00009c
=`04001c=g<g0002LcL30002LaL00`00LaMc5`030002KaL01000K_M^m`000Vkg0P000V[h00<006KH
00000VKH00<006KH00000V;H00L006:h001N^@00G[T00002G[T03P00FYT005ZI001FV@00DWT0059i
001>N@00CUT200001DHi0012>P00@QX0100000<en@00<MT00P0000H]f@00000UV@009IT500000b6I
0000000300001BFj000UfP00:M/00P0000<]n`00;Q/00P0000<f>`00=S/0100000LjG000?U`003il
0012O0020002@W`00`00AY`0000400003DZL000004ZL001:W000B[`004jl001>_000009>_00<001>
_000C[`004jl001>_000C[`005:l1`0000AB_000D[`0009B_00G001B_000D]`005;L001Bg000D]/0
05;K001Bf`00D]/005;K001Bf`00D]/00002D]/02`00D]/005KK001Ff`00E]/005KK00000UKK00`0
05KK001Ff`00E]/005KK001Ff`00E]/4000MOol00`00Oomoo`1bOol003Aoo`8000Qoo`80011oo`03
001oogoo00Aoo`07001Ff`00E]/005KK00000UKK00L005KK001Ff`00E]/00002E]/03000E]/005KK
001Ff`00E]/005KK001Ff`P00006E]/005KK001Ff`000UKK00d005KK001Ff`00E]/005KK001Ff`00
E]/00002E]/07P00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001F^`00
E[/005Jk001F^a00000=D[/005:k001BV`00DY/005:J001BVP00DYX02P0000]BNP00CWX004ij001>
F@00CUT004YI00800008BST00000AQP004HH001660800003AOL004Gg00<0000EDSL00000DSH0058f
001F=P00ESH005Hf001F=P00ESH005Hf001F=P00009F=P0:001F=P00ESH005Hf001F=P00ESH50000
15YF001JEP000UiF00L005if001NMP00GWH00003HWH00`00HYH00002HYL00`00HYL00002I[L00`00
I[L00002I[L01000I[MV]`000VJg0`000VKH00<006KH00000VKH00@006;HH]P0009Rf0<0009Vf@03
001Rf@00009Rf@03001Rf@00009Rf@06001RnF;i001Rn@000V;j00<006;j00000V;j00L006;jH_X0
06;j001RnP0200001f;j001RnV;j001RnP00009S6P05001S6V<J001S6P0200001FLJ001W6VLJ0000
0VLJ00@006LJ001W6P80009[>P04001[>V/j0002JcX01000JcT000000Vli00T006liKcU_>@00KcT0
06lh00000W<h00D007=H001c>00000=cE`05001gE`00McL00003McL01@00McIg=WLf00000WLf00<0
07Lf00000gLf00T007LfMcIg=P00McD007Lf00000gLE00D007LE001g5@0000=g5@800006LaH007<F
LaH007;f0P000Vkf00@006kfK_H0009Ze`06001Zef[G001Ve`000VKG00D006:h001R^000009N^0<0
000=FYP005ZH001FN@00DWT0059I001>F@00BST00`0000<if@00<KT0500000@Qn`00000Z70800006
;S`00000=U`003IL0P0000<jG000>U`00P0000`jG000000nG000?U`003YK000j>`00>S/200001SHk
000003HK000b6`800003;OX0000000@000037GT0000000X0008M5P80000<>KH00000AMH004Wf001=
mP00CQH0058F0P0000EB=P00ESIF=P00009F=P0A001F=P00ESH005Hf001F=P00FSH005YF001JEP00
GUH00003GUH00`00GWH000020002IYD00`00JYD00002J[D01000K[E^]@000W;E00D007;EL]D007;E
008000=bm@03001bmG;e00800005LaH007<FLaH00002LaH01000LaIc5P000g<G0P0000Qc5`00KaM_
5`00KaL006lH0P000VlH00@006lHKaP0009_6006001_66lH001[60000V/I00@006/IJaT0009[6@03
001[6@00009[6@04001[6F/I0002JaT00`00JaT00002JaT01000JaT006/I0P000V/i00<006/i0000
0V/i0`000V/i00@006liKcT0009_>@04001_>Fli0002KcT01000KcT006li0P000Vlh00<007<hLcP0
0P0000Ec>000LcQc>000009c>006001c>7<h001c=`000W<g00@007<gLcL0009c=`04001c=g<g0002
LcL01000LcL000000W<g00@007<gLcL0009c5`03001c5`00009c5`04001_5flG0002KaL00`00K_L0
0002K_L01@00J_P006[h00000VKH00<006KH00000VKH0`0001YR^000G[UN^@00G[T005ji001JV@00
FYT005JI001BN@00DWT004ii001>F@00BUT004Hi0P0000E26P00?QX003Wi00800003<MT002gI00D0
00049IT000009KT20000126I000002Fj0`0000HU^P00000Yf`00;O/200000bhK000b6`0200000cHk
000j?00400003ciL000nO000@W`0049l0012O000AY`004JL0016W00500001DZL001:W000B[`00P00
00Y>_000C[a>_000C[`004jl001>_0L0000:D[`005:l001B_000D[`005:l0002D[`04`00D[`005;L
001Bg000D]`005;K001Bf`00D]/005;K001Bf`00009Bf`05001Bf`00D]/00002D]/02000E]/005KK
001Ff`00E]/>000015KK001Ff`007Goo00<007ooOol0LWoo000eOol20006Ool2000AOol00`00Oomo
o`05Ool01`00E]/005KK001Ff`00009Ff`0>001Ff`00E]/005KK001Ff`00E]/005KK001Ff`H00008
E]/005KK001Ff`00E]/0009Ff`0=001Ff`00E]/005KK001Ff`00E]/005KK00000UKK01X005KK001F
f`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK2P00011F^`00E[/005Jk
001F^`00E[/005Jk001B^`00D[/0009B^`0:001B^`00DY/005:K001BVP00DYX200002DjJ001>VP00
CWX004ij001>NP0400002Dij001>F@00CUT004YI001:>@0300001DHH00166000AQP00P0000E5m`00
AOL004Wg00<0000ADSL00000DSH005Hf001F=P00ESH005Hf001F=P00ESH00002ESH02P00ESH005Hf
001F=P00ESH005Hf0`0000QJEP00FUH005YF001JEP000UiF00D005if001NMP00009NMP06001RMV9f
001RUP000V:G0`000VJg00H006JgI[L006Jg0002I[L01000I[MV]`000VKG00<006KH00000VKH00@0
06KHI]P0009Rf0<0009Vf003001Vf@00009Rf@03001Rf@00009Rf@03001RfF;I00<0009Rn@03001R
nP00009RnP03001RnP00009RnP06001RnP00001RnP000V;j00<006;j00000V;j00@006<JHaX0009S
6P03001W6P00009W6P03001W6P00009W6P06001W6VLJ001[>P000V/j00@006/jJcX000=[>P04001_
>Fli0002KcT00`00KcU_>@020002KcP01@00LcQc>7<h00000W<h00<007=GLeL00W=G00@007LgMcL0
00=g=`07001g=WLfMcH007Lf00000WLf00D007LfMcIg=P0000=g=P05001g=@00McH00004MaD01@00
MaEg5GLE00000WLE00@007<FLaH000=c5P800005L_H006kfK_H00002K_H30002J]L02000I]MVe`00
I]L006:h0002H[P300003ejH001JV000FYP005Ii001BN@00DUT004iI001:>@050000136i000001eH
4`0000@Uo000000^70800006<S`00000=U`003IL0P0000<jG000>U`00P0000`jG000000nG000>U/0
03Xk000j>`00>S/200001SHK0000038K000an`800005:MX00000000QV@0400000a4G000000050000
0adF000M5P0500003TGF0019mP00COH004hF001B5P00DQH0058f0002ESH04`00ESH005Hf001F=P00
ESH005Hf001J=P00FUH005YF001NEP0000=NEP05001NMP00HWD00002IYD01`00JYEZU@00J[D006je
0080009be@08001beG;E001be@00L_D0009bm@04001bmG;e0002LaH01@00LaIc5P00LaH00P000g<F
00@007<GLaL0009c5`04001_5flG0002KaL01000KaQ_60000VlH00@006lH001_6080009_6007001[
66/H001[6@00JaT00P000V/I00L006/IJaT006/I001[6@020002JaT01`00JaU[6@00JaT006/I0080
0007JaT006/iJcT006/i00000V/i00@006/iJcT0009[>@04001_>@00KcT20002KcT01000KcU_>@00
0Vli00H006liKcT006lh0002LcP01000LcQc>0000W<h00@007<hLcP0009c>003001c=g<g00800004
LcL007<g0002LcL01000LcMc=`000W<g00L007<g001c=`00LcL00002LcL01P00LaMc5`00LaL0009c
5`04001_5flG0002KaL00`00K_M^m`0300001f[h001Zn6[h001Vf000009Vf0<0000NH]P006:hH[P0
05ji001N^@00G[T005ZI001JV@00EYT0059i001BN@00CWT004iI001:F@00AST0048j0P0000<n6P00
00000P0000<af@00;MT00P0000HY^@00000UV@009IT50000126j000002Fj100000<Yf`00;O/00P00
00D^6`00<Q/003Hk00800003>S`003YL00@00004?W`0049l@W`20002@W`200001dJL0016W000BY`0
04ZL00T00003C[`004jl00H0000FC[`004jl001>_000D[`005:l001B_000D[`005:l001B_000D[`0
05:l0002D]`03P00D]`005;L001Bf`00D]/005;K001Bf`00D]/B00002UKK001Ff`00E]/005KK001F
f`000UKK00D005KK001Ff`0001eoo`03001oogoo079oo`00=Goo0P001Woo0P004Goo00<007ooOol0
1Goo014005KKE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK00H00006E]/005KK001Ff`000UKK
00d005KK001Ff`00E]/005KK001Ff`00E]/00002E]/02@00E]/005KK001Ff`00E]/00002E]/01P00
E]/005KK001Ff`800007E]/005KK001Ff`00E]/0200000YF^`00E[/005Jk001F^`00E[/0009F^`0T
001F^`00E[/005Jk001F^`00E[/005:k001B^`00D[/005:k001BV`00DY/005:J001BVP00DYX004jJ
001>VP00CWX004ij0P0000=:NP00BUX0100000M>F@00BUT004Xi001:>@0300001DHH00166000AOP0
0P0000E5m`00BOL004Wg00@0000>DSH005Hf001F=P00ESH005Hf001F=P00ESH0009F=P06001F=P00
ESH005Hf1@0000QJ=P00FUH005YF001JEP000UYF00L005iF001NMP00GWH00002GWH01000HWIRMP00
0V:F00<006:G00000VJf00<006Jg00000VJg00@006JgI[L0009V]`<0009Ve`06001Vf6KH001Vf000
0VKH00H006;HH]P006KH0002I]P01P00I]UVf@00H]T0009Rf@04001Rf@00H]T20002H_T00`00H_T0
0002H_X00`00H_X00002H_X01P00H_YRnP00H_X0009RnP03001RnP00009RnP03001RnP00009S6P04
001S6P000002IaX00`00IaX00002IaX01000IaX006LJ0P000V/j00@006/jJcX0009[>P04001[>P00
0002KcT02000KcU_>@00KcT006li0003KcP01000LcQc>0000g<h00<007=GLeL00P000gLg00D007Lg
001g=`0000=g=P03001g=WLf009g=P05001g=P00McH00002McH01@00McD007Lf000017LE00D007LE
MaEg5@00009g5@05001c5W<FLaH00002LaH01000L_IbmP000Vkf00H006kfK_H006[G0002J]L01P00
I]MVe`00I]L0009R^0<00004G[P005jH0002FYP02P00FYP005Ii001BN@00DUT004iI0`0000=26@00
00000P0000<YV00000002`0000<0e`0000000`0000@Mf`00000Z70800004;S`00000<S`200000cIL
000jG00200000cYL000jG00200000cYL00000002>U/01`00>S/00000>S/003Hk00800004<Q/00000
<O/200000bWJ0000000@00001QdF000002ef0011]P80000<BOH004gf001>5P00DQH0058F001B=P00
0UHf014005Hf001F=P00ESH005Hf001F=P00FSH005YF001JEP00009NEP03001NEUiF00<0009RM@03
001VU@00009ZU@04001Z]@00K[D20003L]D00`00L]Ebe@0200001G;e001bmG;e00000W;e00D007<F
LaIc5P00009c5P800005LaH007<FLaH00002LaL01000LaMc5`000VlG00@006lGKaL0009_6004001_
66lH0002KaP01P00KaQ_6000KaP0009[6004001[6F/I0002JaT00`00JaT00002JaT01000JaU[6@00
0V/I00<006/I00000V/I00H006/IJaT006/I0002JaT00`00JcT00002JcT30002JcT01000JcU[>@00
0Vli00@006liKcT0009_>@04001_>@00KcT20002KcT00`00KcQ_>0030003LcP01000LcP007<h0P00
0W<h00@007<gLcL0009c=`03001c=g<g00800005LcL007<gLcL00002LcL03000LcMc=`00LcL007<g
001c5`00LaL0009c5`800004KaL006lG0002KaL02000K_M^m`00J_P006[h0002J_P00`00I]P00002
I]P00`00I]P00002H]P07P00H[P005ji001N^@00G[T005ZI001JV@00EYT0059i001BN@00CWT004iI
001:F@00AST0048j00126P800003>QX0000000800003;MT002gI00D000049IT000009KX200000b6j
000U^P0200001BWJ000UfP00:M/00P0000<]n`0000000P0000<f>`00=S/00P0000<jG000?U`00`00
00/nO000@W`0049l0012O000AY`004JL00800007BY`004ZL001:W000BY`0=@0000ABf`00D]/0009B
f`0E001Bf`00D]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`06001FfeKK001F
f`007Goo00<007ooOol0LGoo000fOol20004Ool2000BOol00`00Oomoo`06Ool02000E]/005KK001F
f`00E]/800001UKK001Ff`00E]/0009Ff`0=001Ff`00E]/005KK001Ff`00E]/005KK00000UKK00L0
05KK001Ff`00E]/00002E]/04000E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK1`0000QFf`00
E]/005KK001Ff`000UJk01T005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001B
^`00D[/00002D[/02P00D[/005:K001BV`00DYX005:J0P0000]>VP00CYX004ij001>NP00CWX004Yj
00800003BUX004Hj00H00004BST00000AQP200001DHH0015n000AOL00P0000E9m`00BOL004hG00@0
000<ESH005Hf001F=P00ESH005Hf001F=P000UHf1`0000YF=P00ESH005Xf001JEP00FUH0009JEP07
001JEP00GUH005if00000Uif00<005if00000V9f00<006:FHYH00`000VJf00<006Jg00000VJg00@0
06JgI[L0009V]`03001Ve`00009Ve`04001Vf6KH0002I]P01000I]P006;H0P000VKH00<006KH0000
0VKI00<006;I00000V;I00H006;I000006;i0002H_T01P00H_URn@00H_X0009RnP04001RnP00H_X2
0002H_X00`00H_X00002H_X01@00H_X006;j00000V<J0P000VLJ00<006LJ00000VLJ00@006LJ001W
6P80009W6P04001[>V/j0002JcX01000JcY[>P000V/i00@006liKcT0009_>@05001_>FliKcT00002
KcP01@00LcP007<h00000W<h00<007=G00000W<g00P007LgMcL007Lg001g=`000gLf00<007LfMcH0
0WLf00D007Lf001g=P0000=g=P05001g=WLfMcH00002MaD00`00MaH00002MaD01@00MaD007<F0000
0W<F00@007<FLaH0009bmP04001^mVkf0002K_H01000J]MZe`000V[G00<006KG00000VKG0`0000AR
^000G[P0009NV00<001JV000FYP005Ii001BN@00DUT004iI0`0000=26@00>OT00P0000<YV0000000
4`0000@Qn`00000^70800004<S`00000=S`200000cYL000jG00200000cYL000jG00200001cXl0000
0000>S/003Xk00800003=S/003HK00800004;O/00000;OX200001BFj000000007GT01`0000<8e@00
00000P0000<M5P009CH00P0000m1]P000019mP00COH004hF001B5P00DQH0058f00000UHf00l005Hf
001F=P00ESH005Hf001F=P00FSH005YF00000UYF00@005iF001NEP800007HWH0069eHWD006JE0000
0VZE00<006ZeJ[D00P0000E^e@00L]Ebe@00009be@04001bmG;e0002L_D01000L_D000000g<F00@0
07<FLaH0009c5P05001c5W<F001c5`020003LaL00`00KaM_5`02000016lG001_60000VlH00@006lH
KaP0009_6007001_66lH001[6000JaT00P000V/I00L006/IJaT006/I001[6@020002JaT01`00JaU[
6@00JaT006/I00800005JaT006/IJaT00002JcT30002JcT01`00JcU[>@00JcT006li0080009_>@04
001_>Fli0002KcT00`00KcT00002KcT01000KcQ_>0000Vlh00@007<hLcP0009c>004001c>7<h0002
LcP30003LcL00`00LcL00002LcL01000LcMc=`000W<g00@007<gLcL0009c=`800004LaL007<G0002
LaL01000KaM_5`000VlG00<006lGKaL00`000V[h00D006[h001Zn000009Vf0<0000=I]P006;HH]P0
06:h001N^@00G[T005ji00000UZI00X005ZI001FV@00DWT0059i001>N@800009BUT004Hi0012>P00
@QX003hJ00800006>OX00000;MT002gI0P0000HY^@00000UV@009KT500001BFj000U^P00:MX00P00
00<Yf`00;O/00P0000<b6`0000000P0000<f>`00>S`00P0000<nG000?U`01@0000]2O000@W`004JL
0016W000AY`004ZL00H00006B[`004jl001>_0000Tjl01L004jl001>_000C[`004jl001>_000C[`0
05:l001B_000D[`005:l001B_000009B_00E001B_000D[`005;L001Bf`00D]/005;K001Bf`00D]/0
05;K001Bf`00009Bf`0=001Bf`00D]/005;K001Ff`00E]/005KK00000UKK00T005KK001Ff`00E]/0
05KK00000UKK00D005KK001Ff`0001eoo`03001oogoo075oo`00=Woo20004Woo00<007ooOol00`00
0goo00<005KK00001@0000QFf`00E]/005KK001Ff`000UKK00/005KK001Ff`00E]/005KK001Ff`00
009Ff`09001Ff`00E]/005KK001Ff`00009Ff`0>001Ff`00E]/005KK001Ff`00E]/005KK001Ff`T0
0006E]/005KK001Ff`000UKK014005KK001Ff`00E]/005Jk001F^`00E[/005Jk001F^`00009F^`0P
001F^`00E[/005Jk001F^`00E[/005:k001B^`00D[/005:k001BV`00DY/005:J001BVP00DYX004jJ
001>VP800005CWX004ij001:NP0200001dYJ0016>P00AST0048i00D00003AQP004HH00800005AOP0
04Gg0015m`0200000dWg001>5`0200000e8F0000000>000035Hf001F=P00ESH005Hf001F=P00FSH0
009JEP0;001JEP00FUH005YF001NEP00GWH00002GWH00`00GWH00002HWH01P00HYIRUP00IYH0009V
]P03001V]`0000=V]`03001V]`00009V]`04001VefKG0002I]L00`00I]P00002I]P01P00I]QVf000
I]P0009Vf006001Vf6KH001Vf@000V;I00H006;IH]T006Ki0002H_T00`00H_T00002H_T01`00H_YR
nP00H_X006;j0080009RnP05001RnP00H_X00002H_X01000H_X006;j0`0000EW6P00IaYW6P00009W
6P03001W6P00009W6P03001W6P00009W6P04001[>V/j0002JcX01000JcX000000V/i00D006liKcT0
06li008000=_>@05001_>6lhKcP00002LcP01@00LcQc>7<h00000g<g00D007LgMcMg=`0000=g=`05
001g=P00McH00003McH00`00McH00002McH01000McIg=P000gLf00<007LE00000WLF00@007LEMaEg
5@800006LaH007<FLaH007<F0P000g;f00<006kfK_H00`000V[G00H006[GJ]L006KG0002I]L01@00
H[P006:h00000Ujh010005jH001JV000FYP005Ii001BN@00DUT004iI001:>@<00003>OT000000080
00037EP0000000/000030AP00000008000077M/00000000^7000;S`00P0000@b?000000f?0800005
>U`003YL000jG00200000cYL00000002>S/200000cXk000j>`0200000cHK000b6`0500000bWJ0000
000700000`cf0000000500000adF000U=P0400003DGF000004gf001>5P00DQH0058F001B=P00009F
=P0=001F=P00ESH005Hf001F=P00ESH005Xf00000UYF00@005YF001NEP800004GWH0069f0002HWD0
0`00IYD00002JYD01000J[EZ]@000VkE00@007;EL]D0009be@04001bmG;e0002L_D01@00L_D007LE
00000W<F00@007<FLaH0009c5P04001c5W<FLaH200001G<G001c5g<G00000VlG00@006lGKaL0009_
6003001_66lH00800004KaP006lH0002KaP01000JaQ[60000V/I00<006/I00000V/I00H006/IJaT0
06/I0002JaT01000JaU[6@000V/I00<006/I00000V/I00<006/I00000V/i00<006/i00000V/i00@0
06/iJcT0009[>@04001_>Fli0002KcT01000KcT006li0P000Vli00<006liKcT00`000Vlh00D007<h
LcP007<h0080009c>004001c>7<h0002LcP01P00LcMc=`00LcL0009c=`05001c=g<g001c=`020002
LcL01000LcMc=`000W<G00<007<G00000W<G00@006lGKaL0009_5`06001_5flG001^m`000V[h00<0
06[h00000V[h0`0000eVf000I]QVf000H]P006:h001N^@00G[T00002G[T03P00FYT005ZI001FV@00
DWT0059i001>N@00CUT200001dHi0012>P00@QX003hJ00800003>OX0000000800003;MT002Vi00D0
00039KT002Fj00<0008U^P800006:MX00000:M/002gk0P0000<b6`00<Q/0100000<j?000>U`00P00
00@nG000?W`00092O0800092O0P0000PBY`004ZL001:W000B[`004jl001>_000C[`004jl001>_000
C[`004jl001>_000C[`005:l001B_000D[`0009B_00F001B_000D[`005:l001B_000D]`005;K001B
f`00D]/005;K001Bf`00D]/2000015;K001Bf`000U;K01D005;K001Bf`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK00000UKK00D005KK001Ff`0001eoo`03001oogoo075oo`00>7oo100057oo
0`001goo00L005KK001Ff`00E]/00002E]/03@00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`07
001Ff`00E]/005KK00000UKK00h005KK001Ff`00E]/005KK001Ff`00E]/005KK200001QFf`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0002E[/0;P00E[/005Jk001F^`00
E[/005Jk001F^`00E[/005Jk001F^`00E[/005:k001B^`00D[/005:k001BV`00DY/005:J001BVP00
DYX004jJ001>VP00CWX004ij0P0000E:NP00BUX004YJ00800005AST0048i00126@0300001DHH0016
6000AQP00P0000E5m`00AOL004Wg0080000ACQL00000DQH0058F001B5P00DSH005Hf001F=P00ESH0
0002ESH02`00ESH005Hf001F=P00ESH005Hf00000UXf00/005YF001JEP00FUH005YF001NEP00009N
MP05001NMP00GWH00003HWH00`00HYH00002IYH00`00I[H00002I[L01000I[MV]`000VJg0`000VKG
00@006KGI]L0009Vf004001Vf000I]P20002I]P00`00I]P00002I]P01`00I]UVf@00H]T006;I0080
009Vn@03001Rn@00009Rn@07001RnF;i001RnP00H_X00P0000MRnP00H_YRnP00H_X00002H_X01000
H_X006;j0P0000=W6P00IaX00VLJ00T006LJIaX006LJ001W6P00IaX00P000VLJ00@006LJIaX0009[
>P04001[>P000002JcT01000JcU[>@000Vli00@006liKcT000=_>@04001_>6lh0003LcP01000LcQc
>00017<g00@007LgMcL000=g=`05001g=P00McH00004McH02@00McIg=WLf001g=P00McH00002McH0
0`00MaD00002MaH01@00MaEg5GLE00000W<F00@007<FLaIc5P800005L_H007;fL_H00002K_H01P00
K_M^m`00J]L0009Ze`03001VefKG00<00009H[P006:hH[P005jh001NV000009JV00:001JV000EWT0
059i001BF@00CUT30000148I0000037I0P0000<MF00000003`0000@I^`00000Qn`<00003;S`0038l
00800004=S`00000=S`200001CYL000jG000>U`00P0000Dj?000>S/003Hk00800003>S/003Hk0080
0003<Q/002gk00<00004:MX000008IT>00027AH300001CVF0015eP00BOH00P0000Q>5P00DQH0058F
001B=P000UHf00/005Hf001F=P00ESH005Hf001F=P00009J=P04001JEP00FUH30002GWH02000HWIR
MP00HWD006JE0002JYD01000J[EZ]@000VkE00D007;EL]D007;E008000=bm@03001bmG;e00800006
MaD007<FLaH007<F0P000g<F00@007<FLaH0009c5`04001c5g<G0002KaL01000KaM_5`000VlH00@0
06lHKaP0009_6007001_66lH001_6000JaP00P000V/I00L006/IJaT006/I001[6@020002JaT01`00
JaU[6@00JaT006/I0080009[6@03001[6@00009[6@<0009[>@07001[>F/i001[>@00JcT00P000Vli
00@006liKcT0009_>@03001_>@00009_>@04001_>Fli0002KcP01000KcQ_>0000W<h00<007<h0000
0W<h00@007<hLcP0009c>003001c=g<g00800005LcL007<gLcL00002LcL01P00LcMc=`00LcL0009c
=`06001c5g<GLaL007<G0P0000Mc5`00KaM_5`00KaL00002KaL02000K_M^m`00J_P006[h0002J_P0
0`00I]P00002I]P01`00I]P006;H001R^000009N^@04001N^@00G[T?00000dYI0016>@0200001D8J
000n6P00>QX00P0000<enP0000000P0000@Y^@00000Y^@@000039KX00000008000069KX00000:MX0
02WK100000H]n`00000b6`00=S/400001cYL000nG000?U`003il00T0000AAY`00000BY`004ZL001:
W000BY`004Zl001>_000C[`00002C[`05`00C[`004jl001>_000C[`004jl001>_000D[`005:l001B
_000D[`005:l00000U:l01D005:l001B_000D]`005;K001Bf`00D]/005;K001Bf`00D]/005;K0000
0U;K01L005;K001Bf`00D]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`03001F
f`00009Ff`03001oogoo01Yoo`03001oogoo075oo`00D7oo00<007ooOol01goo010005KKE]/005KK
001Ff`00E]/005KK001Ff`00E]/0009Ff`07001Ff`00E]/005KK00000UKK00h005KK001Ff`00E]/0
05KK001Ff`00E]/005KK1P0000QFf`00E]/005KK001Ff`000UKK00H005KK001Ff`00E]/200001UKK
001Ff`00E]/0009Ff`0A001Ff`00E]/005KK001F^`00E[/005Jk001F^`00E[/00002E[/06P00E[/0
05Jk001F^`00E[/005Jk001B^`00D[/005:k001B^`00DY/005:K001BVP00DYX200002djJ001>VP00
CWX004ij001>NP00BWX00P0000E:FP00ASX004Hi00800009@QT003hI00166000AQP004HH00800007
AOL004Gg0019m`00BOL00`0000iB5P00DQH0058F001B=P00ESH005Hf001F=P000UHf00T005Hf001F
=P00ESH005Hf00000UHf00d005Xf001JEP00FUH005YF001JEP00GUH00002GWH01@00GWH005if0000
0f9f0`000VJF00<006Jf00000VJg00@006JgI[L0009V]`06001VefKG001Ve`000VKG00@006KHI]P0
009Vf003001Vf000009Vf004001Vf6KH0002I]P01000I]T006;I0P000VKi00D006Ki001Rn@00009R
n@05001RnF;i001RnP0200001f;i001RnV;j001RnP00009RnP03001RnP00009RnP03001VnP00009W
6P04001W6VLJ0002IaX01000IaX006LJ0P000VLJ00@006LJIaX0009W6P06001[>V/j001[>P000V/i
00D006/iJcT006li008000=_>@08001_>Fli001_>000LcP0009c>005001c>000LcP00003LcL01@00
McL007Lg00000gLg00D007LfMcIg=P0000=g=P09001g=WLfMcH007Lf001g=P0000=g=P03001g5WLF
009g5P04001g5GLE0003LaH01000LaIc5P000W;f00@007;fL_H0009^mP04001^mfkg0002J]L00`00
J]L00002I]L00`00I]P00002H[P01@00H[P005jh00000UjH00`005ZH001JV000EWT0059i001BF@00
CUT300000d8I000in@0C00001@4i000000007M/00`0000HZ7000000b?000<S`2000013Hl000003Hl
0P0000DjG000>U`003YL0080008j>`800006=S/00000=S/003HK0P0000@]n`00000YfP8000039KX0
000000h000047AH00000;GH400000dWf001=mP0200001U8F001B5P00DSH0009F=P07001F=P00ESH0
05Hf00000UHf00H005Hf001J=P00FUH300001EiF001NMUif00000V9f00<0069e00000VJE00<006ZE
00000VZe00@006kEK]D0009be@05001be@00L_D00002L_D01000L_Ebm@000WLE00@007<FLaIc5P80
0005LaH007<FLaH00002LaH01000LaMc5`000g<G0P0000Qc5`00KaM_5`00KaP006lH0P000VlH00@0
06lHKaP0009_6006001_66lH001[6@000V/I00H006/IJaT006/I0002JaT01000JaU[6@000V/I00<0
06/I00000V/I00<006/I00000V/I00H006/iJcT006/i0002JcT01000JcU[>@000Vli00L006liKcT0
06li001_>@020002KcT00`00KcT00002KcT01000KcQ_>0000Vlh00@007<hLcP0009c>003001c>7<h
00800005LcP007<hLcP00002LcL00`00LcL00002LcL01000LcMc=`000W<g00<007<gLcL00P0000Mc
=`00LaMc5`00LaL00002LaL01000KaM_5`000VlG0`000Vkg00<006[h00000V[h0`0000UVf000I]QV
f000I]P006;H00000V:h00@005ji001N^@<0000=FYT005ZI001FV@00DWT0059i001>N@00CUT01@00
00Q2>P00000n6P00>QX003Wj0P0000HanP00000Y^@00:KT200001RVj000002Fj000U^P@000039KX0
02WJ00800003;O/0000000800006<Q/00000=S/003Hk2P0000M2O000@W`0049l0016O00500000dZL
001:W002000014ZL001:_0000Tjl01L004jl001>_000C[`004jl001>_000C[`004jl001>_000D[`0
05:l001B_000009B_00I001B_000D[`005:l001B_000D]`005;K001Bf`00D]/005;K001Bf`00D]/0
05;K00000U;K00d005;K001Bf`00D]/005KK001Ff`00E]/00002E]/02@00E]/005KK001Ff`00E]/0
0002E]/00`00E]/00002000MOol00`00Oomoo`1`Ool0051oo`03001oogoo00Qoo`07001Ff`00E]/0
05KK00000UKK00L005KK001Ff`00E]/00002E]/03P00E]/005KK001Ff`00E]/005KK001Ff`00E]/8
00001UKK001Ff`00E]/0009Ff`0M001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/00002E]/0<000E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F
^`00E[/005Jk001B^`00D[/005:k001B^`00DY/005:K001BVP00DYX005:J001>VP00CYX004ij001>
NP80000:BWX00000BUX004Hj0016>@00@ST200002ChI00000000AQP004HH0015n00200001DGg0019
m`00BOL00P0000m>5P00001B5P00DQH0058f001F=P00ESH005Hf00000UHf00T005Hf001F=P00ESH0
05Hf00000UHf00/005Xf001JEP00FUH005YF001JEP00009NEP05001NMP00GWH00002GWH01P00HWH0
0000IYH0009VUP06001V]VJf001V]`000fJg0`000VKG00@006KGI]L0009Ve`04001Vf000I]P20002
I]P00`00I]P00002I]P01000I]QVf0000VKI00<006Ki00000VKi00<006Ki00000V;i00<006;i0000
0V;i0P0000MVn@00H_URn@00H_X00002H_X01P00H_X006;j001RnP80009VnP03001W6P0000=W6P04
001W6P00IaX200001FLJ001W6VLJ00000VLJ00D006LJIaX006/j0080009[>P04001[>F/i0002JcT0
1000KcU_>@000Vli00D006liKcU_>@00009c>005001c>7<hLcP00003LcP01@00LcMc=g<g00000WLg
00D007LgMcMg=`0000Ag=P05001g=P00McH00003McH01@00McIg=WLf00000WLf00<007LFMaH00WLF
00D007LE001g5P00009c5P04001c5W<F0002L_H01000L_IbmW;f0`000Vkg00@006[GJ]L0009Ze`<0
009Vf005001R^000H[P00002G[P03P00GYP005ZH001JV000EWT0059i001BF@00CUT2000014Hi0000
03Wi0P0000@YV@00000E5a0000045K/000008O/300001RhL0000038l000f?0800004=S`00000=S`4
00001cYL000j?000>S/003Hk00800006=Q/00000=Q/0038K0P0000<]fP000000100000<IN@000000
200000@0U000000M5P800004;GH00000@KH300001Dgf001>5P00DQH00P0000EB=P00ESIF=P00009F
=P0:001F=P00ESH005Hf001F=P00FSH3000015YF001NEP000Uif00H0069fHWH0069e0002IYD01000
JYD006Ze0P000VkE00@007;EL]Ebe@800005L_D007;eL_D00002L_D01@00MaEg5GLE00000W<F00@0
07<FLaH0009c5P05001c5P00LaH00002LaL01000LaMc5`000W<G00@006lGKaL0009_6004001_66lH
0002KaP01000KaP006lH0P000VlH00L006/IJaT006/I001[6@020002JaT00`00JaT00002JaT01000
JaT000000V/I00<006/I00000V/I0`000V/i00L006/iJcT006/i001[>@020002KcT01000KcU_>@00
0Vli00<006li00000Vli00<006liKcT00P0000Q_>@00KcQ_>000KcP007<h0P000W<h00@007<hLcP0
009c>004001c>7<h0002LcL00`00LcL00002LcL01000LcL000000W<g00@007<gLcL0009c=`06001c
5g<G001c5`000W<G00@006lGKaL0009_5`08001_5flG001^m`00J_P0009Zn003001Zn000009Vf005
001Vf000I]P00002H]P00`00H[P0000400004eZi001JV@00FYT005JI001BN@00DWT004ii001>F@00
BUX004IJ00<00006@QX00000>QX003Wj0P0000<anP0000000P0000<Y^@00:KT0100000@U^P000000
008YfP800006:MX00000;O/002gk0P0000<b6`0000002@000SiL00H003il0012O000@W`200001DIl
0016W000AY`01`0001a:W000B[`004jl001>_000C[`004jl001>_000C[`004jl001>_000C[`005:l
001B_000D[`0009B_00I001B_000D[`005:l001B_000D]`005;K001Bf`00D]/005;K001Bf`00D]/0
05;K00000U;K00d005;KD]/005;K001Bf`00E]/005KK001Ff`0@00000eKK001oo`0LOol00`00Oomo
o`1`Ool0051oo`03001oogoo00Qoo`0:001FfeKK001Ff`00E]/005KK0002E]/03P00E]/005KK001F
f`00E]/005KK001Ff`00E]/6000025KK001Ff`00E]/005KK0002E]/04@00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK00000UKK00H005KK000005KK0002E]/05P00E]/005KK001Ff`00E]/005KK
001F^`00E[/005Jk001F^`00E[/005Jk7@0000]>VP00CYX004ij001>NP00CWX004Yj00800008BUX0
0000AST0048i00126@H00005AQP004Gh0015m`0200000dWg0019m`02000064hF001B5P00DQH0058F
001B=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH0009F=P0;001F=P00FSH005YF001JEP00FUH0
0002FUH01`00GUH005if001NMP00009NMP800007IYH006JFIYH006JF00000VJf00<006Jg00000fJg
00<006Zg00000VKG00@006KGI]L0009Ve`06001Vf6KH001Vf0000VKH00H006KHI]P006KH0002I]P0
1000I]T000000VKi00<006Ki00000VKi00<006;i00000V;i0P0000MVn@00I_UVn@00H_T00002H_X0
1P00H_X006;j001RnP80009VnP03001VnP00009W6P04001W6VLJ0002IaX00`00IaX00002IaX01000
IaYW6P000VLJ00@006LJ0000009[>P03001[>P00009[>@04001[>@000003KcT01@00KcU_>@00KcT0
0P000g<h00@007<hLcP000=c>005001c=g<gLcL00003McL01@00McL007Lg00000gLf00D007Lf001g
=P0000=g=P09001g=WLfMcH007Lf001g5P0000=g5P05001g5@00MaH00002LaH01@00LaH007<F0000
0W;f00@007;fL_H0009^m`06001^mfkg001Ze`000V[G00<006KG00000VKH00<006:h00000V:h00/0
05jh001NV000FYP005ZH001FN@00009BN@800006CUT00000AST0048I0P0000<af@0000004@0000D9
NP000000027k00800004:Q`00000;Q`200000cHl000f?00200001SHl000003Hl000f?080008j?005
000j>`00000f>`0200001S8K0000038K000]n`800005:MX00000000QV@0>000011dF000002ef0P00
00=1]P00AMH00`0000Q>5P00DQH0058F001B=P000UHf00X005Hf001F=P00ESH005Hf001F=P<00006
FUH005YF001NEP000Uif00H0069fHWH0069e0002IYD00`00JYEZU@030003K]D01000L]Ebe@000W;e
00D007;eL_D007;e008000=g5@04001c5W<F0002LaH01000LaIc5W<F0P0000Ec5P00LaMc5`00009c
5`04001c5g<G0002KaL01000KaQ_60000VlH00@006lHKaP0009_6006001_66lH001_60000V/I00H0
06/IJaT006/I0002JaT01@00JaU[6@00JaT00P0000M[6@00JaU[6@00JaT00002JaT01000JcU[>@00
0V/i00<006/i00000V/i00@006/iJcT0009_>@04001_>@00KcT20002KcT00`00KcT00002KcT01000
KcU_>@000Vlh00@006lhKcP0009c>003001c>000009c>004001c>7<h0002LcP01000LcL000000W<g
00@007<gLcL0009c=`03001c=`00009c=`04001c=g<g0003LaL00`00LaL00002LaL00`00KaM_5`03
0002KaL00`00K_L00002J_P30002J_P01`00I]P006KH001Vf000009Rf0<00006G[T005ji001J^@00
0UZI00X005ZI001FV@00DWT0059i001>N@800005BUX004IJ0016>P03000023hJ000003Wj000enP00
<OX500000bVi000Y^P0500000bFj000YfP0200000bWJ000Yf`0700000c8K000f>`0200000cXl000j
G00300002CiL000nO000@W`0049l0012O00200002DJL0016W000BY`004ZL001:W0090002C[`05`00
C[`004jl001>_000C[`004jl001>_000D[`005:l001B_000D[`005:l00000U:l01H005:l001B_000
D]`005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`h0000:E]/005KK001Ff`00E]/005KK0002
E]/01@00E]/005KK00007Goo00<007ooOol0L7oo001@Ool00`00Oomoo`09Ool04@00E]]Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/0200000IFf`00E]/005KK0002E]/04@00E]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK00000UKK01X005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK300001eF^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:K001B
V`00DY/004jK001>V`00CY/004jK00H00005CWX004ij001:NP0200000dYJ0016>P0200002D8i0012
6@00?QT003gH0016600200000dGh0015m`0200001DWg0019m`00CQL00P00011B5P00DQH0058F001B
=P00ESH005Hf001F=P00ESH0009F=P0A001F=P00ESH005Hf001F=P00FSH005YF001JEP00FUH00002
FUH01@00GUH005if00000Uif00<005if00000VJF00H006JFIYH006JF0002I[H00`00I[L00002I[L2
0002J[L00`00I]L00002I]L01@00I]MVe`00I]P00P000VKH00<006KH00000VKH00D006KHI]P006KH
0080009Vn003001Vn@00009Vn@06001Vn@00H_T006;i0P000fKi00D006Ki001Rn@00009RnP04001R
nP00H_X200001FKj001VnVKj00000VKj00L006LJIaX006LJ001W6P020002IaX01000IaYW6P000VLJ
00H006LJIaX006/J0002JcX01000JcY[>P000V/i00@006liKcT0009_>@05001_>FliKcT00002KcP0
2000LcQc>000LcP007<h0003LcP01@00LcL007<g00000WLg00D007Lg001g=`0000Ag=P09001g=WLf
McH007Lf001g=P00009g=P05001g=P00MaH00004MaH200000gLF001c5P02LaH200001G<F001bmW;f
00000W;f00@006kgK_L0009^m`03001Zef[G00<0009Ve`03001Vf000009R^007001R^000G[P005jH
00000UZH00@005ZH001FN@D00007CUT0000000126@00>OT00`0000DQN0000000002f018000049O`0
0000;Q`200001S8l000003Hl000f?0800003=S`003Hl00800007=S`00000000j>`00=S/00P0000@f
6`00000b6`800004;O/00000:MXB00000adF000U=P0200001SVF000004GF0019mP<00006DQH0058F
001B=P000UHf00H005Hf001F=P00ESH500001UXf001JEP00FUH0009NEP06001NMUif001RMP000V9e
00<006JE00000VZE0P0000E^]@00K]E^e@00009be@04001bmG;e0002L_D01@00L_D007Ke00000WLE
00@007<F000000=c5P04001c5W<F0002LaH02000LaMc5`00LaL007<G0002LaL00`00KaM_5`020000
16lH001_60000VlH00@006lHKaP0009_6007001_66lH001[6@00JaT00P000V/I00<006/I00000V/I
0P0000M[6@00JaU[6@00JaT00002JaT30002JcT01`00JcU[>@00JcT006/i0080009[>@04001_>Fli
0002KcT00`00KcT00002KcT00`00KcU_>@030003KcT01000KcP006lh0P000W<h00<007<hLcP00P00
00Ec>000LcQc>000009c>006001c=g<g001c=`000W<g00@007<gLcL0009c=`800005LcL007<gLcL0
0002LaL00`00LaL00002LaL01P00KaM_5`00KaL0009_5`03001^m`00009Zn003001Zn000009Zn005
001Vf000I]P00002I]P02@00H]P006:i001N^@00G[T00002F[T04000FYT005ZI001FV@00DWT0059i
001>N@00CUT004YJ0P0000=6>P00@SX0100000DinP00=OX0037j00800006;MX00000:KT002Vj0P00
00<Y^P009KX02@0000@]n`00000b6`@00005=S/003Hk000j?00200004CiL00000000?W`0049l0012
O000@W`004Il0016W000AY`00P0000Q:W000BY`004ZL001:W0000TZl00<004jl0000<00001IBf`00
D]/005;K001Bf`00D]/005KK001Ff`00E]/005KK001Ff`00E]/0009Ff`05001Ff`00E]/00002E]/0
0`00Oomoo`0KOol00`00Oomoo`1_Ool0051oo`03001oogoo00Yoo`0:001Ff`00E]/005KK001Ff`00
E]/6000025KK001Ff`00E]/005KK0002E]/03@00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`0J
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`X0000<E[/0
05Jk001F^`00E[/005Jk001F^`000UJk01X005:k001B^`00D[/005:k001B^`00D[/005:k001BV`00
DY/005:K001>V`00CY/004jK0P0000E>NP00BWX004Yj00@00008BWX00000BUX004Hj0016>@800005
@QT003hI000mf00300001THH000004Gg0015m`800003BOL004hG0080000>DQH0058F001B5P00DSH0
05Hf001F=P00ESH0009F=P0A001F=P00ESH005Hf001F=P00ESH005Xf001JEP00FUH00002FUH01`00
FUH005iF001NMP00009NMP<0009VUP04001VUVJF0002IYH00`00I[H00002I[L200001FZg001Z]fZg
00000VKG00<006KG00000VKG0P0000EZe`00I]QVf000009Vf003001Vf000009Vf0800007I_P006Kh
I_P006Ki00000VKi00@006Ki001Rn@800003I_T006Ki009Vn@03001Vn@00009Rn@04001RnP00H_X2
00001FKj001VnVKj00000VKj00L006KjI_X006LJ001W6P020002IaX00`00IaX00002IaX01@00IaYW
6P00IaX00P000V/J00L006/jJcX006/j001[>@020003KcT01@00KcU_>@00KcT00P000Vlh00D007<h
LcQc>00000=c>005001c>7<hLcP00002LcL01@00McMg=gLg00000gLg00D007LfMcIg=P0000=g=P05
001g=P00McH00003McH01@00MaIg5WLF00000gLF00D007LFMaIg5P00009c5P04001c5W<F0002L_H0
1000L_H000000Vkg00@006kgK_L0009Ze`03001Ze`00009Ve`0:001Vf6KH001R^000H[P005jh0002
GYP700000e9i001BN@04000014Hi000003Wi0P0000<YV@000000400000D9FP000000027K00800004
:Q`00000;Q`200001S8l000003Hl000f?0800003=S`003Hl0080008f>`800003=S/003Hk00800004
<Q/00000;O/2000012gJ000002Fj0`0000<IN@000000300000@U=P00000iUP800005AMH004Wf001>
5P050000158f001F=UHf1`0000YF=P00FSH005Xf001JEP00FUH0009NEP06001NMUif001RMP000V9e
00<006JE00000VZE00@006jeK[D0009^e@04001beG;E0002L_D01000L_EbmG;e0P0000Ufm@00MaEg
5@00LaH007LE00000W<F00@007<FLaH000=c5P03001c5g<G00800005LaL007<GLaL00002KaL01000
KaQ_60000VlH00<006lHKaP00P0000A_6000KaP0009_6006001[6F/I001[6@000V/I00<006/IJaT0
0`000V/I00@006/IJaT0009[6@<0009[>@07001[>F/i001[>@00JcT00P000V/i00L006/iJcT006li
001_>@020002KcT00`00KcT00002KcT01000KcU_>@000Vli00H006lhKcP006lh0002LcP01000LcQc
>0000W<h00@007<hLcP0009c>007001c=g<g001c=`00LcL00P000W<g00@007<gLcL0009c=`04001c
=g<g0002LaL00`00LaL00002LaL01000KaM_5`000VlG00<006lG00000Vkg0`000V[h00D006[h001V
f000009Vf003001Vf0000080000LH[T005jiG[T005ji001J^@00FYT005ZI001FV@00DWT0059i001>
N@00CUT004YJ0016FP00ASX200000d8J0000000200001CGj000anP00<MX0100000<Y^@0000001`00
00@YfP00000YfP800003;O/002gk00800003<Q/0000000800005=S/003Xl000jG0020002?U`50000
:d9l000004Il0016W000AY`004ZL001:W000BY`004ZL001:W000B[`004jl001>_000C[`004jl001>
_000C[`004jl001>_000D[`005:l001B_000009B_00I001B_000D[`005:l001B_000D[`005;K001B
f`00D]/005;K001Bf`00D]/005;K00000U;K00d005;K001Bf`00D]/005;K001Ff`00E]/00002E]/0
2@00E]/005KK001Ff`00E]/00002E]/01@00E]/005KK00007Goo00<007ooOol0Kgoo001?Ool00`00
Oomoo`0;Ool00`00E]/0000700001UKK001Ff`00E]/0009Ff`0=001Ff`00E]/005KK001Ff`00E]/0
05KK00000UKK00T005KK001Ff`00E]/005KK00000UKK0P0000eFf`00E]/005KK001Ff`00E]/005KK
001Ff`0800002UKK001Ff`00E]/005KK001F^`000UJk02X005Jk001F^`00E[/005Jk001F^`00E[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001BV`00DY/005:K001>V`00CY/004jK001>V`00CWX2
00001DYj001:NP00AUX01@0000E6>P00AST0048i00800005?QT00000000if00400001DGg0015m`00
BOL00P00015>5`00001B5P00DQH0058F001B=P00ESH005Hf001F=P00009F=P0=001F=P00ESH005Hf
001F=P00ESH005Xf00000UYF00/005YF001JEP00FUH005iF001NMP00009NMP03001RUP0000=VUP03
001VUP00009VUP03001V]P00009V]`07001Z]fZgJ[L006Zg00000VKG00<006KGI]L00P0000MZe`00
J]MZe`00I]P00002I]P00`00I]QVf0030003I_P00`00I_P00002I_T00`00I_T00002I_T00`00I_T0
0002I_T01000I_UVn@000VKi00<006;i00000V;j00<006Kj00000VKj00<006Kj00000VKj00D006Kj
I_X006LJ00800005IaX006LJIaX00002IaX01@00IaYW6P00IaX00P000V/J00<006/J00000V/j00@0
06/jJcX0009[>@04001_>Fli0003KcT01000KcU_>@000Vlh00@007<hLcP000=c>005001c>7<hLcP0
0003LcL01000McMg=`0017Lg00D007Lf001g=P00009g=P05001g=P00McH00003McH01@00MaIg5WLF
00000gLF00D007LFMaIg5P00009c5P05001c5W<FLaH00002L_H200001fkf001^mfkg001^m`00009Z
e`06001Zef[G001Ve`000VKH00D006:h001R^000009N^0<0000;FYP005ZI001FN@00DWT0059i001>
F@0500000cWi000af@0300000aUH0000000C000012Gk000002hL0P0000@b?000000b?0800003=S`0
03Hl00800007=S`003Hl000f>`00=S/00P0000Hf>`00000b6`00<Q/500000bWJ0000000?00000`RD
0000000200000cVF0011]P0200001dWf001>5P00DQH0058F00H0000>ESH005Hf001F=P00ESH005Xf
001J=P00FUH0009JEP03001NEP00009NMP03001RMP00009RM@03001VU@00009ZU@04001^]Fje0002
K]D01000L]Ebe@000g;e00@007;eL_D0009fm@04001g5GLEMaD200002GLE001c5W<F001c5P00MaH0
0002LaH01000LaMc5`000W<G00@007<GLaL0009_5`04001_66lH0002KaP01000KaQ_60000VlH00L0
06lHKaP006lH001[6@020002JaT00`00JaT00002JaT01000JaU[6@000V/I00<006/I00000V/I00<0
06/I00000V/i00@006/iJcT0009[>@03001[>@00009[>@04001[>F/i0002KcT00`00KcT00002KcT0
0`00KcU_>@030002KcT01@00KcU_>@00KcP00P000Vlh00<007<hLcP00`000g<h00@007<h001c>080
009c=`04001c=g<g0002LcL00`00LcMc=`030002LcL01@00LcMc=`00LaL00P000W<G00<007<GLaL0
0`000VlG00<006lG00000Vkg00<006[h00000V[h00D006[h001Vf000009Vf0<0000PH]P006:iH[T0
05ji001N^@00F[T005ZI001JV@00EYT0059i001BN@00CWT004iI001:FP00AUX004Hj0012>P800003
?QX000000080008anPL00004:KX00000:KX200000bFj000YfP0200000bWJ0000000200001Rgk0000
038K000f6`@0008j?0800007?U`003iL000nO000@W`01P0000i6W000AY`004ZL001:W000BY`004ZL
001:W0000TZl018004jl000004jl001>_000C[`004jl001>_000C[`005:l0002D[`06@00D[`005:l
001B_000D[`005:l001B_000D[`005;K001Bf`00D]/005;K001Bf`00009Bf`03001Bf`00009Bf`0E
001Bf`00D]/005;K001Bf`00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`07001Ff`00E]/005KK
00007Goo00<007ooOol0Kgoo001?Ool00`00Oomoo`0<Ool02@00E]/005KK001Ff`00E]/00002E]/0
3@00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`07001Ff`00E]/005KK00000UKK00P005KK001F
f`00E]/005KK0P0000EFf`00E]/005KK00P00008E]/005KK001Ff`00E]/0009Ff`0E001Ff`00E]/0
05KK001F^`00E[/005Jk001F^`00E[/005Jk001F^`00009F^`0J001B^`00D[/005:k001B^`00D[/0
05:k001B^`00DY/005:K001BV`00CY/004jK001>V`800005CWX004Yj001:NP0200000dIJ0016FP05
00001DHi0012>@00@QT00`0000Hmf000000if000AOP200001DGg0019m`00BOL00`0000iB5P00DQH0
058F001B=P00ESH005Hf001F=P000UHf00/005Hf001F=P00ESH005Hf001F=P00009J=P0;001JEP00
FUH005YF001JEP00GUH00002GWH00`00GWH00002HYH01P00IYIVUP00IYH0009VUP06001V]VJf001V
]`000fZg00<006Zg00000VKG00@006KGI]L0009Ze`04001Zef[G0002I]P00`00I]P00002I]P01000
I_QVn0000VKh00H006KhI_P006Ki0002I_T30002I_T00`00I_T00003I_T01P00I_T006;i001RnP80
009VnP03001VnP00009VnP04001VnVKj0002I_X00`00IaX00002IaX01P00IaYW6P00IaX0009W6P80
0005IaX006/JJaX00002JaX01000JcX006/j0P000f/i00D006liKcT006li0080009_>@08001_>6lh
001c>000LcP000=c>005001c>000LcP00002LcL01@00McL007<g00000gLg00D007Lf001g=P0000=g
=P09001g=WLfMcH007Lf001g=P0000=g5P05001g5P00MaH00002MaH01@00LaH007<F00000W<F00@0
07;fL_H0009^mP04001^mfkg0002K_L30002J]L02000I]MVe`00I]P006:h0002H[P3000025jH001J
V000FYT005Ii0002DWT2000014iI000004Hi100000@af@00000QN0<000030;H0000000/000032EX0
000000@000049O`00000;Q`20000138l0000038l0P0000<f?000=S`00P0000@f?000=S/f>`800004
=S/00000=Q/200000c8K000]n`03000012WJ000001fI300000<0U0000000100000<iUP00@KH00P00
00Y9mP00CQH0058F001B5P00DSH0009F=P0=001F=P00ESH005Hf001F=P00FSH005Xf00000UYF00D0
05YF001NEP00009NMP09001RMV9f001RM@00IYD006ZE0080009^]@08001^eFkE001be@00L_@0009b
m@04001bmG;e0003M_D01000MaEg5@000WLE00@007<FLaIc5P800005MaH007<FLaH00002LaL01@00
LaMc5g<G00000W<G0P0000Qc5`00KaQ_6000KaP006lH0P000VlH00@006lHKaP0009_6003001_6@00
009[6@03001[6F/I00<0009[6@04001[6F/I0002JaT30002JaT01`00JcU[>@00JcT006/i0080009[
>@07001[>F/i001[>@00KcT00P000Vli00<006li00000Vli00@006liKcT0009_>@06001_>Fli001_
>0000Vlh00@007<hLcP0009c>004001c>7<h0002LcP01000LcQc>0000W<g0`000W<g00@007<gLcL0
009c=`04001c=g<g0002LcL01P00LaMc5`00LaL0009c5`06001_5flG001_5`000VlG00<006kg0000
0V[h00D006[h001Zn000009Vf0<0000KH]P006;HH]P006:i001N^@00G[T005Zi001JV@00FYT005JI
001BN@00DWT004ii001>F@00009:FP800005ASX0048j00126P0900001RgJ000002gJ000Y^P800003
:KX002WJ00800003:MX002WJ00800003;O/0000000800006<Q/00000=Q/003Hk0`0000<j?000>U`0
0P000SiL0P0000E2O000@W`0049l00<00003AY`004JL00800004BY`004ZL0002BY`06`00BY`004Zl
001>_000C[`004jl001>_000C[`004jl001>_000C[`005:l001B_000D[`00002D[`06@00D[`005:l
001B_000D[`005:l001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00009Bf`0E001Bf`00D]/005;K
001Bf`00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`05001Ff`00E]/00002E]/00`00Oomoo`0J
Ool00`00Oomoo`1_Ool004moo`03001oogoo00aoo`0@001FfeKK001Ff`00E]/005KK001Ff`00E]/0
05KK0002E]/01`00E]/005KK001Ff`00009Ff`0@001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/7000025KK001Ff`00E]/005KK0002E]/04@00E]/005KK001Ff`00E]/005KK001Ff`00E]/005Jk
00000UJk02H005Jk001F^`00E[/005Jk001F^`00E[/005:k001B^`00D[/005:k001B^`00D[/005:k
001BV`00DY/005:K001>V`00CY/004jK0P0000U>NP00BWX004Yj001:NP00AUX00`0000=2>P000000
0P0000M2>@00@QT003hI000mf00200000cWH0000000200001DGg0019m`00BOL00`0000iB5P00DQH0
058F001B=P00ESH005Hf001F=P000UHf00T005Hf001F=P00ESH005Hf00000UHf00d005Xf001JEP00
FUH005YF001JEP00GUH00002GWH30002HYH01000IYIVUP000VJF00<006JF00000VJf0`000fZg00H0
06ZgJ[L006KG0002I]L01`00J]MZef[G001Ze`00009Vf003001Vf6KH00<0009Vn004001Vn6Kh0002
I_P01000I_T006Ki0P000VKi00<006Ki00000VKi00L006KiI_T006Ki001Rn@020002I_T00`00I_X0
0002I_X01`00I_YVnP00I_X006Kj0080009W6P03001W6P00009W6P07001W6P00IaX006LJ00000VLJ
00L006/JJaX006/J001[>P020002JcT01000JcU[>@000fli00@006liKcT0009_>@04001_>6lh0003
LcP01@00LcQc>7<h00000W<h00D007<gLcMc=`00009c=`03001g=gLg009g=`05001g=WLfMcH00002
McH02@00McIg=WLf001g=P00McH00003MaH01@00MaH007LF00000gLF0P0000Ec5P00LaIc5P00009b
mP04001^mVkf0002K_L01000K_M^m`000V[G00<006[G00000VKG00<006KH00000V:h0`0000AN^000
GYP0009JV008001JV@00EWT0059i001BN@<00003AST0048I00@00003:IT0000001H000079O/00000
000^7000<S`00P0000@b?000000f?0800009=S`003Hl000f?000=S/003Hk00800004<Q/00000<Q/2
000012gk000002GJ0P0000<U^P0000003P0000@8U000000]MP800003@KH004GF00800008CQH0058F
001B5P00DSH0009F=P09001F=P00ESH005Hf001F=P00009J=P09001J=P00FUH005YF001NEP00009N
MP06001RMV9f001RM@000VJE0`000Vje00P006kEK]D007;E001bm0000W;e00@007;e000000=fm@04
001g5GLE0003MaD01000LaIc5P000WLF00@007<FLaIc5P800005LaH007<GLaL00002LaL01000LaMc
5`000VlH00@006lHKaP0009_6007001_66lH001_6000KaP00P000VlI00<006/I00000V/I00H006/I
JaT006/I0002JaT01000JaU[6@000V/I00<006/I00000V/i00@006/iJcT0009[>@03001[>@00009[
>@06001[>F/i001_>@000Vli00<006liKcT00`000Vli00@006liKcT0009_>@06001_>6lh001_>000
0W<h00@007<hLcP0009c>004001c>0000002LcP01P00LcMc=`00LcL0009c=`04001c=g<g0002LcL0
1000LcMc=`000W<g00H007<GLaL007<G0002LaL01P00KaM_5`00KaL0009_5`<0009Zn003001Zn000
009Zn005001Vf000I]P00002H]P01@00H]P006:i00000Uji0P0000iJ^@00FYUJV@00FYT005JI001B
N@00DWT004ii0P000TYJ00<004IJ00001@0000<n6P0000000P0000<anP00<MX00P0000<]fP00;MX0
0P0000<Y^P00:KX00P0000HYfP00000YfP00:MX200001Rgk0000038K000b6`800003=S/003Xk00<0
0007>U`003iL000nG000?W`00P0000E2O000@W`004Il00L0000LBY`004ZL001:W000BY`004Zl001>
_000C[`004jl001>_000C[`004jl001>_000C[`005:l0002D[`06P00D[`005:l001B_000D[`005:l
001B_000D[`005;K001Bf`00D]/005;K001Bf`00D]/200004U;K001Bf`00D]/005;K001Bf`00D]/0
05KK001Ff`00E]/0009Ff`07001Ff`00E]/005KK00000UKK00<005KK00000P007Goo00<007ooOol0
KWoo001?Ool00`00Oomoo`0=Ool02@00E]/005KK001Ff`00E]/00002E]/01`00E]/005KK001Ff`00
009Ff`0>001Ff`00E]/005KK001Ff`00E]/005KK001Ff`P00007E]/00000E]/005KK00000UKK00l0
05KK001Ff`00E]/005KK001Ff`00E]/005KK00000UKK01<005KK001Ff`00E]/005Jk001F^`00E[/0
05Jk001F^`00E[/00002E[/05000E[/005:k001B^`00D[/005:k001B^`00D[/005:k001BV`00DY/2
00002DjK001>V`00CY/004jK001>NP0200001dYj001:NP00AUX004IJ00<00003?QX0000000800003
@QT003hI00<00006>MP00000>KL004Gg0P0000=9m`00BOL00P0000m>5P00001B5P00DQH0058f001F
=P00ESH005Hf00000UHf00T005Hf001F=P00ESH005Hf00000UHf00/005Xf001JEP00FUH005YF001J
EP00009NEP05001NMP00HWH00002HYH01000IYIVUP000VJF00<006JF00000VJf00@006ZfJ[H0009Z
]`04001Z]fZg0002I]L200001F[G001Zef[G00000V[G00<006KH00000VKH00H006KhI_P006Kh0003
I_P00`00I_P00002I_T00`00I_T00002I_T01P00I_UVn@00I_T0009Vn@06001Vn@00001Vn@000VKi
00@006KjI_X0009VnP04001VnP00I_X20002IaX00`00IaX00002IaX01000IaX006LJ0P000fLJ00<0
06LJ00000V/J00H006/JJaX006/i0003JcT01@00JcU[>@00KcT00P000Vli00D006liKcT006lh0080
00=c>005001c>7<hLcP00003LcP01000LcMc=`000g<g00<007LgMcL00P000gLf00D007Lf001g=P00
009g=P05001g=P00McH00004MaH01000MaIg5P000gLF00@007<FLaH000=c5P<000=^mP03001^m`00
009^m`04001Zef[G0002J]L00`00I]L00002I]P3000016:h001N^0000UjH00`005ZH001JV@00EWT0
059i001BN@00CUT2000014Hi000003Wi1@0000<IF00000003P0000<9FP000000100000LUo0000000
038l000b?0020000138l000003Hl0P0000Tf?000=S`003Hk000f>`00=S/00`0000<b6`00<Q/00P00
00<Yf`000000100000<IN@0000002`0000@8U000000]MP800005@KH004GF0019mP0200001U8F001B
5P00DSH0009F=P05001F=P00ESH00002ESH03@00ESH005Xf001J=P00FUH005YF001NEP00009NMP06
001RMV9f001RM@000VJE0P0000AZ]@00K[D000=^e@800009L_@007;eL_D007;e001fm000009fm@04
001g5@000003MaD01000LaIc5P000gLF00@007<FLaH0009c5P04001c5g<G0002LaL01000LaMc5`00
0VlH00@006lHKaP0009_6004001_66lH0002KaP00`00KaP00002KaT00`00JaU[6@030002JaT01000
JaU[6@000V/I0`000V/I00L006/IJaT006/i001[>@020002JcT01`00JcU[>@00JcT006/i0080009_
>@03001_>@00009_>@04001_>Fli0002KcT01000KcT006li0P000Vlh00<006lhKcP00P0000Ec>000
LcQc>000009c>003001c>000009c>004001c=g<g0002LcL00`00LcMc=`02000017<g001c=`000W<g
00@007<g0000009c5`03001c5g<G00<0009_5`03001_5`00009_5`08001Zn6[h001Zn000J_P0009Z
n0<00007I]P006;HH]P006;H00000V:i00@005ji0000009J^@0:001JV@00FYT005JI001BN@00DWT9
00000dHj0012>P0200000chJ000j6P0600001RgJ000002gJ000]fP800004:KX00000:MX4000012WJ
000002gk100000Db6`00=Q/003Hk0080008jF`800009?U`003iL000nO000@W`0049l00800007AW`0
04JL0016W000BY`01`0000I:W000B[a:_000C[`200003Tjl001>_000C[`004jl001>_000C[`005:l
0002D[`06P00D[`005:l001B_000D[`005:l001B_000D[`005;K001Bf`00D]/005;K001Bf`00D]/2
00004U;K001Bfe;K001Bf`00D]/005;K001Bf`00E]/005KK001Ff`h00003E]/007oo01aoo`03001o
ogoo06ioo`00Cgoo00<007ooOol03Goo00X005KKE]/005KK001Ff`00E]/0009Ff`0>001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`P00008E]/005KK001Ff`00E]/0009Ff`80000<E]/005KK001Ff`00
E]/005KK001Ff`000UKK00d005KK001Ff`00E]/005KK001Ff`00E]/00002E]/0:P00E[/005Jk001F
^`00E[/005Jk001F^`00E[/005Jk001B^`00D[/005:k001B^`00D[/005:k001B^`00DY/005:K001B
V`00CY/004jK001>V`800005CWX004Yj001:NP0200000dIJ0016FP020000148j000003hI100000@n
6@00000mf0800003>MP0000000<00003BOL004Wg0080000JCQH0058F001B5P00DQH0058f001F=P00
ESH005Hf001F=P00ESH005Hf001F=P00ESH0009F=P09001J=P00FUH005YF001JEP00009JEP03001N
EP000080009RMP03001RUP00009VUP04001VUVJF0002IYH00`00I[H00002J[H01`00J[MZ]fZg001Z
]`00009Ve`04001Zef[G0002J]L01000J]MZe`000VKH0`000VKh00@006KhI_P0009Vn003001Vn6Kh
00<0009Vn@06001VnFKi001Vn@000VKi00H006KiI_T006Ki0002I_T01000I_UVn@000VKj00@006Kj
001VnP800005IaX006LJIaX00002IaX00`00IaX00002IaX00`00IaX00003IaX01`00IaYW6P00JaX0
06/J0080009[>@04001[>F/i0003JcT01000KcU_>@000Vli00@006liKcT0009_>009001c>7<hLcP0
07<h001c>000009c>005001c=`00LcL00002LcL00`00McL00002McL02000McIg=P00McH007Lf0003
McH01@00McIg=WLf00000gLF00D007LFMaIg5P00009g5P05001c5W<FLaH00002LaH01000L_IbmP00
0Vkf00<006kgK_L00`000V[G00H006[GJ]L006KG0002I]P01@00H[P006:h00000Ujh00T005jH001J
V000FYT005Ii00000U9i0P0000A>F@000016>@800003>OT003GI008000038GP0000001<000036K/0
02Gk00<00006;Q`00000<S`0038l0P0000@f?000000f?080008f?007000f>`00000f>`00<Q/00`00
00<b6`00;O/00P0000DUfP00000001fI00h0000429@00000;GH20000446f0015eP00BOH004hF001B
5P00DQH0058f001F=P000UHf014005Hf001F=P00ESH005Xf001J=P00FUH005YF001NEP00009NMP06
001RMV9f001RM@000VJE00@006ZeJ[D0009^]@04001^eFkE0002L_@02000L_Ebm@00L_D007Kd0002
M_D01@00MaD007LE00000WLE00@007<F000000=g5P04001c5W<F0002LaH01000LaMc5g<G0P0000Ec
5`00LaMc5`00009_60<0009_6005001_66lH001_60020002KaP00`00KaT00002JaT01P00KaU_6@00
JaT0009[6@04001[6F/I0002JaT00`00JaT00002JaT01000JcU[>@000V/i00H006/iJcT006/i0002
JcT00`00JcT00002KcT00`00KcU_>@030002KcT01000KcU_>@000Vli00H006liKcT006lh0002KcP0
1000LcQc>0000W<h00@007<hLcP0009c>003001c>7<h00800004LcP007<g0002LcL01000LcMc=`00
0W<g00@007<gLcL0009c5`03001c5`00009c5`06001_5flG001_5`000VlG0`000V[h00<006[h0000
0V[h00D006[h001Vf000009Vf003001Rf000009Rf008001R^@00G[T005ji001J^A<00005ASX0048j
00126P0200000cXJ00000002=OX200001RgJ000002gJ000]fP800003:KX002WJ00800003:MX00000
00800004;O/00000<Q/400002CHK000f>`00>S/003YK000jG0020002?U`200001d9l0012O000@W`0
04Il00800008AY`004ZL001:W000BY`0009:W0T0000BC[`004jl001>_000C[`004jl001>_000D[`0
05:l001B_0000U:l01X005:l001B_000D[`005:l001B_000D]/005;K001Bf`00D]/005;K001Bf`00
D]/005;K400000IFf`00E]/005KK0002E]/01`00E]/005KK001Ff`0001eoo`03001oogoo06ioo`00
Cgoo00<007ooOol03Woo00<005KK00000UKK00h005KK001Ff`00E]/005KK001Ff`00E]/005KK1P00
00QFf`00E]/005KK001Ff`000UKK00P005KK001Ff`00E]/005KK0P0000AFf`00E]/0009Ff`0;001F
f`00E]/005KK001Ff`00E]/00002E]/06000E]/005KK001Ff`00E]/005KK001F^`00E[/005Jk001F
^`00E[/005Jk001F^aL00005CY/004jK001>V`0200002Dij001:NP00BWX004Yj0016FP0300000d8j
000n6P0200000cWi00000003000013gH000003WH0P0000<i]`00AOL00P0001e9m`00001>5P00DQH0
058F001B5P00DSH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00009F=P09001J=P00FUH0
05YF001JEP00009JEP<00007HWH0069fHWH006:F00000fJF00<006JF00000VJF0`000VZf00L006Zg
J[MZ]`00J[L00002I]L01000J]MZe`000f[G00<006[G00000VKH00H006[hJ_P006Kh0002I_P01000
I_QVn0000VKh00H006KiI_T006Ki0002I_T01`00I_UVn@00I_T006Ki0080009Vn@03001Vn@00009V
n@05001VnVKj001VnP0200001FKj001W6VLJ00000VLJ00H006LJ001W6P00IaX20002IaX01`00IaYW
6VLJ001W6P00009[6P04001[6F/I0002JcT01@00JcU[>@00JcT00P000Vli00D006liKcT006li0080
00=_>005001c>7<hLcP00002LcP01@00LcQc>7<h00000W<g00D007<gLcMc=`0000=g=`05001g=WLf
McH00003McH01000McIg=P000gLf00H007LFMaH007LF0002MaH01@00MaH007<F00000W<F00@007<F
LaH0009bmP04001^mVkf0002K_L01000K_M^m`000V[G00<006[G00000VKG0`0000UR^000H[QR^000
G[P005jH00000UZH00P005ZI001FN@00DWT0059i0`0000=6>@00@QT00P0000<ef@0000000`0000<A
5`0000003P0000<ANP0000000`0000DUo000000002hL00800003<S`0038l00800004=S`00000=S`3
00000cHk000f>`020000138K000002hK0P0000@]n`00000UfPH000034CP0000000T0000329@00000
0080000A>IH00000AMH004Wf001>5P00DQH0058F001B=P00ESH00002ESH03`00ESH005Hf001F=P00
FSH005Xf001JEP00FUH00002GUH00`00GWH00002HWH01P00HWERM@00IYD0009Z]@04001^]Fje0002
K]D01000L_Abm0000g;e00@007KdM_@000=fm@800003MaD007LE009g5@800009MaD007LFMaH007<F
001g5P00009c5P04001c5g<G0002LaL01000LaMc5`000VlH00@006lHKaP0009_6006001_66lH001_
60000VlH00<006lIKaT00`000VlI00L006/IJaT006/I001[6@020002JaT01`00JaU[6@00JaT006/i
0080009[>@07001[>F/i001[>@00JcT00P000V/i00<006li00000Vli00@006liKcT0009_>@04001_
>@00KcT20002KcT00`00KcQ_>0030003LcP01000LcP007<h0P000W<h00@007<hLcP0009c>003001c
=`00009c=`04001c=g<g0002LcL01000LcMc=`000W<G00<007<GLaL00`000VlG00<006lG00000VlG
00P006khK_P006[h001Zn0000V[h0`000VKH00<006KH00000V;H00D006;H001R^@00009N^@P0000:
EYT005JI001BN@00CWT004ij0002BUX300001THj0000048J000n6P800003>OX003Gj00@00003;MX0
02gJ00800006;MX00000:MX002WJ0P0000H]nP00000]n`00;O/200000c8K000000020002=S/20000
1CYK000jG000?U`01P0000U2O000@W`004Il0016W000AY`00P000TZL00`004ZL001:W000BY`004Zl
001>_000C[`_00005U;K001Bf`00D]/005;K001Bf`00D]/005;K001Ff`00E]/005KK001Ff`000UKK
00D005KK001Ff`00009Ff`03001oogoo01Uoo`<006moo`00Cgoo00<007ooOol03goo00X005KK001F
f`00E]/005KK001Ff`P00006E]/005KK001Ff`000UKK01T005KK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/00002E]/05000E]/005KK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/>00005e:k001B^`00D[/005:k001B^`00D[/005:k001B^`00DY/004jK001>V`00
CY/0200000Y>NP00001:NP00BWX004IJ0016FP<00003?QX003hI00800004=MT00000?OT3000013WH
000003Vg0`0001i9m`00000004hF001B5P00DQH0058F001B=P00ESH005Hf001F=P00ESH005Hf001F
=P00ESH005Hf0002ESH01`00FSH005YF001JEP00009JEP07001JEP00GWH0069f00000V9f00@006:F
HYH0009VUP03001VUP00009VUP04001Z]VZf0002J[H01000J[MZ]`000VZg0P0000EZe`00J]MZe`00
009Ze`03001Zef[G00<0009Zn004001Vn6Kh0002I_P00`00I_QVn0030002I_T01P00I_UVn@00I_T0
009Vn@04001Vn@000002I_T00`00I_T00002I_T01000I_UVn@000VKj00<006Ki00000VKj00<006LJ
00000VLJ00@006LJ001W6P80009W6P03001W6P0000=W6P04001W6P00JaX20002JaT01000JcU[>@00
0f/i00@006liKcT0009_>@04001_>Fli0002KcP01000KcQ_>0000g<h00D007<hLcQc>000009c>005
001c=g<gLcL00002LcL00`00McMg=`02McL01000McIg=P000gLf00D007Lf001g=P00009g=P03001g
5P00009g5P08001g5WLF001g5P00LaH0009c5P04001c5P000002L_H01000K_I^mP000Vkg00@006kg
K_L0009Ze`03001Ze`00009Ve`03001Vf000009R^005001R^000G[P00002GYP02P00FYP005ZI001F
N@00DWT0059i0P0000=:>@00AST00P0000@in@00000]^@8000036EP0000000`000030AP0000000<0
00046K/000009O`2000012hL000002hL0P0000<b?000=S`00P0000<f?00000000SHl0P0000<f>`00
=S/00P0000@b6`00000]n`800004:M/000008KX300000aUi0000000?00003cVF000004GF0019mP00
CQH0058F001B5P00DSH00002ESH04@00ESH005Hf001F=P00ESH005Xf001J=P00FUH005YF00000UiF
00<005if00000V9f00<0069eHWD00`000VZe00@006jeK[D0009^e@05001bm7;dL_@00002L_D01000
M_Afm0000gKe00@007LEMaD000=g5@04001g5GLE0003MaH200001GLF001c5W<F00000W<G00@007<G
LaL0009c5`04001_60000002KaP01000KaQ_60000VlH00H006lHKaP006lH0002KaT01P00KaU_6@00
KaT0009[6@04001[6F/I0002JaT01P00JaU[6@00JaT0009[6@04001[>F/i0002JcT01000JcT006/i
0P0000E[>@00JcU[>@00009_>@<0009_>@04001_>Fli0002KcT01P00KcU_>@00KcT0009_>004001_
>6lh0002LcP01000LcQc>0000W<h00<007<h00000W<h00@007<hLcP0009c=`800008LcL007<gLcL0
07<g001c=`80009c5`06001c5g<G001_5`000VlG00<006lGKaL00`000Vkh00P006[hJ_P006[h001Z
n0000VKh00D006KH001Vf000009Rf003001Rf00000H00006F[T005ZI001JV@000UJI00@005JI001B
N@800006CWX004YJBUX004YJ1P0000<n6P00>QX00P0000<enP00=OX0100000<]fP00;MX01@0000@Y
fP00000]nP@00006;O/00000<Q/003HK0`0000Df>`00>S/003YK00800005?U`003iL0012O0030000
9d9l000004Il0016W000AY`004ZL001:W000BY`004ZL001:W000B[`004jl001>_000C[`004jl001>
_000C[`004jl001>_000D[`00002D[`06P00D[`005:l001B_000D[`005:l001B_000D[`005:k001B
f`00D]/005;K001Bf`00D]/200004U;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00E]/0009F
f`05001Ff`00E]/00002E]/01`00E]/005KK001Ff`0001Qoo`<0009oo`03001oogoo06eoo`00Cgoo
00<007oo00000P003Goo00@005KK001Ff`H00008E]/005KK001Ff`00E]/0009Ff`0?001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`00009Ff`0J001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`X0000>E[/005Jk001F^`00E[/005Jk001B^`00D[/0009B^`0D001B
^`00D[/005:k001B^`00D[/005:k001B^`00DY/004jK001>V`800005CY/004jK001>N`0600001TYj
000004IJ0016FP800006@SX00000?QT003Wi1`0000<if000>KL00P0000<m]`0000000P0001]>5`00
001B5P00DQH0058F001B=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf00000UHf00<005Xf
00000UYF00@005YF001JEP<00007GWH0069fHWH0069f00000V:F00@006JFIYH0009VUP03001VUP00
009Z]P04001Z]VZf0002J[L01000J[MZ]`000V[G00@006[GJ]L0009Ze`04001Zef[G0002J]L00`00
J_P00002I_P01000I_QVn0000VKh00@006KhI_P0009Vn@03001Vn@00009Vn@06001VnFKi001Vn@00
0VKi00<006Ki00000fKi00@006Ki001VnP80009Vn@03001VnP00009W6P04001W6P00IaX200001FLJ
001W6VLJ00000VLJ00D006LJIaX006LJ0080009[6@04001[6F/I0002JcT01000JcT000000Vli00D0
06liKcT006li0080009_>009001_>6lhKcP007<h001c>000009c>005001c>000LcL00002LcL01@00
LcL007<g00000gLg00D007Lf001g=`00009g=P05001g=P00McH00003McH01@00MaIg5WLF00000gLF
00@007<FLaH000=c5P800005LaH007;fL_H00002K_H30002K_L01000J]MZe`000V[G0`000VKH00D0
06:h001R^000009N^00<001NV000FYP005ZI001FN@00DWT0059i0P0000=:>@00AST00P0000<in@00
=MT05`0000<EV`0000000`0000@Z7000000^70800006<S`00000=S`003Hl0P0000Df?000=S`003Hk
00800003=S/0038K00800004;Q/00000:O/200000bGJ0000000@00001`RD00000000>IH0046f0080
000:BOH004hF001B5P00DQH0058f0002ESH03`00ESH005Hf001F=P00ESH005Xf001J=P00FUH00002
FUH01@00GUH005if00000V9f00<0069eHWD00`000VZe00@006jeK[D0009^e@05001bm7;dL_@00002
L_D01@00M_Afm7Kd00000WKe00D007LEMaEg5@00009g5@04001g5GLE0003MaH01000MaIg5P000W<F
00D007<G001c5`00009c5`06001c5g<G001c5`000VlH00D006lHKaP006lH0080009_6003001_66lH
00<0009_6@07001_6FlI001[6@00JaT00P000V/I00L006/IJaT006/I001[6@020002JcT01000JcU[
>@000V/i00<006/i00000V/i00<006/i00000Vli00@006liKcT0009_>@04001_>@00KcT20002KcT0
0`00KcU_>@030002KcP01@00LcQc>000LcP00P000W<h00<007<hLcP00P0000Mc>000LcQc>000LcL0
0002LcL01000LcMc=`000W<g00H007<GLaL007<G0002LaL01P00KaM_5`00KaL0009_5`06001_66lH
001^n0000V[h00<006[h00000P000VKh00<006KH00001P0000ERf000000005ji0080009J^@0F001J
V@00FYT005JI001FV@00DWT004ii001>NP00BUX004YJ0016FP00ASX400000cXJ00000002=OX20000
1S7j000002gJ000]fP800003;MX0000000800004:MX00000;O/400000c8K000b6`0200002CHk0000
0000>S/003YK000jG00200001CiL0012O000@W`01@0000M6O0000016W000BY`00002BY`02P00BY`0
04ZL001:W000B[`004jl0P0000a>_000C[`004jl001>_000C[`004jl0002D[`06@00D[`005:l001B
_000D[`005:l001B_000D[`005:l001B^`00D]/005;K001Bf`00009Bf`05001Bf`00D]/00002D]/0
5@00D]/005;K001Bf`00D]/005;K001Bf`00E]/005KK001Ff`00E]/00002E]/01`00E]/005KK001F
f`0001eoo`03001oogoo06eoo`00Cgoo0P004Goo0`0000IFf`00E]/005KK0002E]/03@00E]/005KK
001Ff`00E]/005KK001Ff`00009Ff`0J001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`X0000:E]/005KK001Ff`00E]/005KK0002E[/0;P00E[/005Jk001F^`00
E[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001BV`00CY/004jK001>V`00
CY/004jK001>N`00BW/004Yk1@0000A6FP000016>P800004?QX00000>OT20000137I000003gH0`00
00Pi]`00000m]`00?ML004Wg0`0001IB5P00DQH0058F001B=P00ESH005Hf001F=P00ESH005Hf001F
=P00ESH0009F=P03001F=P00009J=P04001JEP00FUH3000015iF001NMP000V9f00<0069f00000V:F
00@006JFIYH0009VUP<0009Z]P04001Z]VZf0002J[L01000J[MZ]`000V[G00@006[GJ]L0009Ze`04
001Zef[G0002J]L01000J_QZn0000VKh00@006Kh001Vn080009Vn004001VnFKi0002I_T01000I_T0
06Ki0P000VKi00<006Ki00000VKi00D006KiI_T006Ki0080009Vn@03001Vn@00009VnP03001W6P00
009W6P03001W6P00009W6P04001W6VLJ0002IaX01P00IaYW6P00JaX0009[6@04001[6F/I0002JcT2
0002JcT01000KcU_>@000Vli00@006liKcT0009_>003001_>6lh0080009c>005001c>7<hLcP00002
LcL02000LcMc=`00LcL007<g0004McL01000McMg=`000gLf00D007LfMcIg=P00009g=P03001g5WLF
009g5P04001g5WLF0003LaH01000LaIc5P000W<F00@007;fL_H0009^mP04001^mfkg0002K_L00`00
J]L00002J]L00`00I]P00002I]P00`00H[P00002H[P01`00G[P005jH001JV000009JV@06001FN@00
DWT0059i0`0000=6>@00@QT00P0000@ef@00000YV@8000034AL0000000T000040;H000001CT40000
11Vk000002Gk0P0000@^7000000^70800006<S`00000=S`003Hl0P000SHl0P0000Hb6`00000b6`00
<Q/200001Bgk000000009MX00P0000DMVP000000014h00/0000729@00000000iUP00@KH00P0000Y9
mP00CQH0058F001B5P00DSH0009F=P0=001F=P00ESH005Hf001F=P00FSH005Xf00000UYF00L005YF
001NEP00GWH00003HWH00`00HWD00002JYD00`00J[D00002K[D01000K]D000000g;d00@007;eL_D0
00=fm004001fmGKe0003MaD01000MaD000000gLE00@007LFMaH000=g5P03001c5W<F00800005LaL0
07<GLaL00002LaL01P00LaMc5`00KaP0009_6080009_6003001_6000009_6006001_66lH001_6@00
0VlI00@006/IJaT0009[6@07001[6F/I001[6@00JaT00P000V/i00L006/iJcT006/i001[>@020000
1F/i001[>F/i00000V/i0`000Vli00@006liKcT0009_>@03001_>@00009_>@04001_>Fli0002KcP0
1000KcQ_>0000W<h00<007<h00000W<h00@007<hLcP0009c>006001c>7<h001c=`000W<g00D007<g
LcL007<g0080009c5`03001c5g<G00<0009_5`03001_5`00009_5`04001_66lH0002K_P01000J_P0
06[h1`0000AVf000I]P0009Rf0<0000FH]T005ji001N^@00F[T005ZI001JV@00EYT005JI001BN@00
CWT004ij0002BUX200001DIJ0016>P00@SX0100000<inP00=OX00P0000<anP0000000P0000<]fP00
;MX00P0000H]fP00000YfP00;OX200000bgk0000000200000c8K000f6`020002=S/200001cYK000j
G000?U`003iL00800005@W`0049l0016O00500000dJL00000002BY`06`00BY`004ZL001:W000B[`0
04jl001>_000C[`004jl001>_000C[`004jl001>_000D[`00002D[`06P00D[`005:l001B_000D[`0
05:l001B_000D[`005:k001Bf`00D]/005;K001Bf`00D]/2000065;K001Bf`00D]/005;K001Bf`00
D]/005;K001Bf`00E]/005KK001Ff`00E]/0009Ff`07001Ff`00E]/005KK00007Goo00<007ooOol0
KGoo001?Ool00`00Oomoo`0@Ool00`00E]/00002E]/03@00E]/005KK001Ff`00E]/005KK001Ff`00
009Ff`07001Ff`00E]/005KK00000UKK00@005KK001Ff`800009E]/005KK001Ff`00E]/005KK00P0
000:E]/005KK001Ff`00E]/005KK0002E]/05`00E]/005KK001Ff`00E]/005Jk001F^`00E[/005Jk
001F^`00D[/005:k00000U:k00`005:k001B^`00D[/005:k001B^`00D[/200003E:K001>V`00CY/0
04jK001>V`00CY/004ik00800006BW/00000AUX004IJ1P0000A2>P00000n6@800003=MT0000000@0
0004>MP00000>KL200000cgG000000030000458F001B5P00DQH0058f001F=P00ESH005Hf001F=P00
0UHf00L005Hf001F=P00ESH00002ESH01000FSH005YF0`0000ANEP00GUH0009NMP05001RMP00HWH0
0002HYH01000IYIVUP000VJF00@006ZfJ[H0009Z]P04001Z]VZf0002J[L30003J]L01000J]MZe`00
0V[G0`000V[G00@006[hJ_P0009Vn004001Vn6Kh0002J_P01P00I_QVn000I_T0009Vn@04001Vn@00
0002I_T00`00I_T00002I_T00`00I_T00002I_T200001fKi001VnFKi001Vn@00009VnP04001W6P00
IaX20002IaX00`00IaX00003IaX01000IaX006LJ0P000V/J00X006/IJaT006/I001[>@00JcT0009[
>@04001_>Fli0002KcT01000KcU_>@000Vlh00D006lh001_>00000=c>004001c>7<h0003LcL01000
LcMc=`000g<g00D007LgMcMg=`0000=g=`04001g=WLf0003McH01@00McH007<F00000gLF00D007LF
001c5P00009c5P04001c5W<F0002LaH01000L_IbmP000Vkf00@006kgK_L0009^m`03001Zef[G00<0
009Vf003001Vf000009R^005001R^000G[P00002GYP00`00FYP0000900001TXi0000048I000in@80
0003;KT0000000T0000303<0000000P000035IX0000000<00004:O`00000;Q`20000138l0000038l
0P0000Lf?000=S`003Hl000f>`020000138K0000038K0P0000<]n`00:O/00`0000<Q^P0000003P00
00<8U00000000`0000=1]P00AMH00P0000Q>5P00DQH0058F001B=P000UHf00T005Hf001F=P00ESH0
05Hf00000UXf00T005Xf001JEP00FUH005iF00000Uif00H0069fHWH0069e0002JYD00`00J[D00002
K[D01@00K]D007;D00000W;d00D007;e001fm000009fm005001fm@00Ma@00002MaD01@00MaD007LE
00000WLE00D007LF001g5P00009g5P04001c5W<F0002LaL01@00LaMc5`00LaL00P000W<G00<006lH
KaP00P0000M_>000KaQ_6000KaP00002KaP01000KaQ_60000VlI00@006lI001[6@80009[6@04001[
6F/I0002JaT00`00JcT00002JcT01000JcU[>@000V/i00<006/i00000V/i00<006/i00000V/i00@0
06liKcT0009_>@04001_>@00KcT20002KcT00`00KcU_>@030002KcP01000KcQ_>0000W<h00@007<h
LcP0009c>0<0009c>003001c>7<h00800005LcP007<gLcL00002LcL00`00LcL00002LaL01000LaMc
5`000VlG00<006lG00000VlG0P0000=_6000KaP020000V[h00P006KhI_P006KH001Vf0000V;H00D0
06;I001Rf@00009N^@800006F[T005ZI001JV@000UJI00@005JI001BN@800008CWX004YJBUX004YJ
0016FP800003@SX003hJ00@00003=OX003Gj00800003<OX0000000800004;MX00000;MX400001Rgj
000002gk000an`80008b6`800005=S/003Hk000j>`0400001CiL000nG000@W`00P0000M2O000AW`0
04Il0016W00500006TZL001:W000BY`004ZL001:_000C[`004jl001>_000C[`004jl001>_000C[`0
04jl0002D[`06@00D[`005:l001B_000D[`005:l001B_000D[`005:l001B^`00D]/005;K001Bf`00
009Bf`<0000BD]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Ff`000UKK00D005KK001Ff`00
009Ff`07001Ff`00E]/005KK00007Goo00<007ooOol0K7oo001>Ool00`00Oomoo`0BOol02@00E]/0
05KK001Ff`00E]/00002E]/01`00E]/005KK001Ff`00009Ff`0<001Ff`00E]/005KK001Ff`00E]/0
05KK0P0000=Ff`0000001P0000QFf`00E]/005KK001Ff`000UKK01<005KK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/00002E[/08P00E[/005Jk001F^`00E[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001BV`00CY/004jK0P0000E>V`00CY/004ik00800005BW/004Yk
0016FP0200000d8j0012>P0200001T8j000003hI000in@<00005;KP00000000if00200001SVg0000
03gG0011e`80000?CQH00000DQH0058F001B=P00ESH005Hf001F=P00009F=P09001F=P00ESH005Hf
001F=P00009F=P03001J=P0000800004FUH005iF0002GUH01@00GWH0069f00000V9f00@006:FHYH0
009VUP03001VUP00009Z]P04001Z]VZf0002J[H01000J[MZ]`000V[F00@006[GJ]L0009Ze`04001Z
ef[G0002J]L01000J]MZe`000V[h00@006Kh001Vn080009Zn004001Vn6Kh0002I_T01P00I_UVn@00
I_T0009Vn@03001Vn@00009Vn@07001Vn@00I_T006Ki00000VKi00<006Ki00000VKi00@006Kj001W
6P80009W6P03001W6P00009W6P05001W6VLJ001W6P020002JaX00`00JaX00002JaT01000JaT00000
0f/i00X006/iJcT006li001_>@00KcT0009_>@04001_>6lh0003KcP02000LcQc>000LcP007<h0002
LcL01000LcMc=`0017<g00D007Lg001c=`00009g=`05001g=P00McH00002McH01@00McH007<F0000
0gLF00D007LF001c5P00009c5P05001c5P00LaH00002LaH00`00L_IbmP02000016kg001^m`000Vkg
00H006[GJ]L006[G0002I]P02000I]QVf000H[P006:h0002G[P500001eZI001FV@00EWT0059i00L0
0003>OT003GI00<000058GP000000004eP0700000`1e0000000300000`UI0000000200000agK0000
0002000012XL000002hL0P0000@b?000000b?0800004=S`003Hl=S`20000138K0000038K0P0000@^
6`00000Yn`H000036GT0000000/0000329@0000000<00005@KH004GF0019mP0200001U8F001B5P00
DSH0009F=P05001F=P00ESH00002ESH03@00ESH005Xf001J=P00FUH005YF001NEP00009NMP03001R
MV9f00<0009ZU@04001Z]FZe0002K[D200002G;D001bm7;d001bm@00M_@00002M_@01@00M_D007LD
00000WLE00D007LE001g5@00009g5@05001g5P00MaH00002MaH01000LaIc5P000g<G00@007<GLaL0
009c=`03001c5`00009_6004001_>6lh0002KaP00`00KaQ_6002000016lH001_60000VlI00@006lI
KaT0009_6@07001[6F/I001[6@00JaT00P000V/i00L006/iJcT006/i001[>@020002JcT00`00JcT0
0002JcT30002KcT01000KcU_>@000Vli00<006li00000Vli00@006liKcT0009_>@07001_>6lh001_
>000LcP00P000W<h00@007<hLcP0009c>004001c>7<h0002LcP00`00LcP00002LcL01000LcMc=`00
0W<g00<007<G00000W<G00H006lGKaL006lG0002KaL700002Fkh001Zn6[h001Zn000J_P00002I_P0
0`00I]P00002I]P300001V;I001RfF;I001N^@80009J^@0F001JV@00FYT005JI001FV@00DWT004ii
001>NP00BUX004YJ0016FP00ASX200000chJ000n6P0200001CGj000enP00<OX00P0000HanP00000]
fP00;MX200000bgJ00000002000012gk0000037k0`0000<b6`00=Q/00P0000Df>`00>S/003YK00@0
0007?U`0049l0012O000@W`00P0000M6O000AY`004JL001:W00800001DZL001:_000C[`00P0000a>
_000C[`004jl001>_000C[`004jl0002D[`06@00D[`005:l001B_000D[`005:l001B_000D[`005:l
001B^`00D]/005;K001Bf`00009Bf`05001Bf`00D]/00002D]/03P00D]/005;K001Bf`00D]/005;K
001Bf`00E]/@000MOol00`00Oomoo`1/Ool004ioo`03001oogoo019oo`03001Ff`00009Ff`07001F
f`00E]/005KK00000UKK00h005KK001Ff`00E]/005KK001Ff`00E]/005KK1`0000QFf`00E]/005KK
001Ff`000UKK014005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`0A001Ff`00E]/0
05KK001Ff`00E[/005Jk001F^`00E[/00002E[/04P00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`80000=DY/004jK001>V`00CY/004jK001>V`00CW/00P0000Q:N`000016FP00AUX0048j
0P0000@n6P00000n6P800004>OT00000<MT400001SWH000003Vg000m]`800003@ML000000080000H
DQH0058F001B5P00DSH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P000UHf0`0000IJEP00
FUH005iF0002GUH01@00GWH0069f00000V9f00@006:FHYH0009VUP<0009Z]P04001Z]VZf0002J[H0
1000J[MZ]`000V[F00@006[GJ]L0009Ze`04001Zef[G0002J]L01000J]MZe`000V[h00@006KhI_P0
009Zn003001Zn000009Vn005001VnFKi001Vn@020002I_T00`00I_T00002I_T01000I_T006Ki0P00
0fKi00<006Ki00000VKi00<006Ki00000VKj00<006LJ00000VLJ00@006LJIaX0009W6P06001W6VLJ
001W6P000V/J00@006/JJaX0009[6@03001[6@0000=[>@04001[>F/i0002KcT01000KcU_>@000Vli
00@006lhKcP000=_>005001c>7<hLcP00002LcP02000LcMc=`00LcL007<g0003LcL01@00McL007<g
00000WLg00D007Lf001g=P0000=g=P05001c5W<FLaH00003MaH01000LaIc5P000g<F0P0000Ec5P00
LaIc5P00009bmP04001^mfkg0002K_L00`00K_M^m`030002J]L00`00I]P00002I]P00`00H[P00002
H[P300002ejh001JV@00FYT005JI001FN@00DWT00P0000=:F@00AST0100000@ef@00000YVAD00003
5IX0000000<00007:O`00000000^7000<S`00P0000@b?000000b?080008f?005000f>`00000b6`02
000012hK000002gk0P0000DUfP00000001fJ00h0000329@0012d00<0000@@KH004GF0019mP00CQH0
058F001B5P00DSH005Hf0002ESH04@00ESH005Hf001F=P00FSH005Xf001JEP00FUH005iF00000Uif
00H0069f000006JE0002JYD01000J[EZ]@000Vje00@007;DL]@000=bm0800009M_@007KdM_@007Ke
001g500000=g5@04001g5GLE0003MaD200000gLF001g5P02MaH200001G<f001c5g<G00000W<G00H0
07<gLcL007<G0002KaP01`00KcQ_>6lh001_6000009_6004001_66lH0002KaP01000KaT006lI0P00
0VlI00@006/IJaT0009[6@06001[>F/i001[>@000V/i00H006/iJcT006/i0002JcT00`00JcT00002
JcT01000KcU_>@000Vli00@006li001_>@80009_>@03001_>@00009_>@04001_>Fli0002KcP01000
KcQ_>0000Vlh00<007<h00000W<h00@007<hLcP0009c>006001c>7<h001c>0000W<g00@007<g0000
009c=`03001c5g<G00800003KaL0000000H0009_6004001_66lH0002K_P300001f[h001Zn6[h001V
n000009Vf0<0000TH]P006;IH]T006;I001N^@00G[T005Zi001JV@00FYT005JI001FV@00DWT004ii
001>NP00BUX004YJ0016FP00ASX0048j0P0000<n6P0000000P0000<enP00<OX00P0000<anP000000
0P0000<]fP00;MX00P0000P]nP00000]n`00;O/0037k100000Df6`00=S/003Hk00800003>U/003iL
00<0000>?U`00000@W`0049l0016O000AW`004JL0016W080009:W004001:W000BY`900003Tjl001>
_000C[`004jl001>_000C[`005:l0002D[`06P00D[`005:l001B_000D[`005:l001B_000D[`005:k
001Bf`00D]/005;K001Bf`00D]/200000e;K0000000?00001UKK001Ff`00E]/0009Ff`07001Ff`00
E]/005KK00007Goo00<007ooOol0K7oo001>Ool00`00Oomoo`0COol00`00E]/00002E]/03P00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/800001EKK001Ff`00E]/00P000UKK00l005KK001Ff`00E]/0
05KK001Ff`00E]/005KK00000UKK00d005KK001Ff`00E]/005KK001Ff`00E]/00002E]/08000E]/0
05KK001F^`00E[/005Jk001F^`00E[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/2
00003E:K001>V`00CY/004jK001>V`00CY/004ik00800005BW/004Yk0016FP0200000d8j0012>P02
000013XJ000003hI0`0000Paf@00000]V000>MP003Vg0P0000<m]`00?ML00`0001M9mP000000058F
001B5P00DSH005Hf001F=P00ESH005Hf001F=P00ESH005Hf00H00006FUH005YF001JEP000UiF00L0
05iF001NMP00HWH00002HWH01000HYIRUP000VJF00<006Zf00000VZf00@006ZfJ[H000=Z]P<0009Z
eP05001Zef[GJ]L00002J]L30002J]L02000J]MZef[G001Zn000I_P20002J_P01000J_QZn0000VKh
00@006KiI_T0009Vn@03001Vn@00009Vn@03001Vn@00009Vn@03001Vn@0000=Vn@09001VnFKi001V
n@00I_T006Kj0080009W6P04001W6VLJ0002IaX01000IaX006LJ0P000VLJ00L006/JJaX006/J001[
6@020002JaT02000JcU[>F/i001[>@00KcT20003KcT01`00KcT006lh001_>00000=_>004001c>7<h
0003LcP01000LcMc=`000g<g00D007<gLcMc=`0000=c=`04001g=gLg0003McH01000McIg=P000g<F
00D007LFMaIg5P0000=c5P04001c5W<F0002LaH01000LaIc5P000W;f00@006kgK_L0009^m`06001^
mfkg001Ze`000V[G00H006KHI]P006KH0002H[P300001Ujh001N^000FYT0009JV@04001FV@00EWT3
00001DYI0016>@00@QT0100000D]^@00000001UH010000032ET00000008000037M/0000000800007
:Q`00000000b?000<S`00P0000@b?000000b?0<00003=S/0038K00800007<Q/00000000]n`00:O/0
0`0000DMVP000000015H00d000044;@00000>IH200003TGF0019mP00CQH0058F001B5P00DSH005Hf
0002ESH03`00ESH005Hf001F=P00FSH005Xf001JEP00FUH00002GUH02000GWH00000HWD006JE0002
JYD01000J[EZ]@000Vje00@007;DL]@000=bm004001fm7Kd0003M_@01@00MaAg57LD00000WLE00D0
07LEMaEg5@00009g5@05001g5WLFMaH00002MaH01000LcIc=P000W<G00@007<G0000009c=`03001c
5g<G00800005LcP006lhKcP00002KaP30002KaP01000KaQ_60000VlI00@006lIKaT0009_6@04001[
6@00JaT20002JcT01`00JcU[>@00JcT006/i0080009[>@03001[>@00009[>@<0009_>@04001_>Fli
0002KcT00`00KcT00002KcT00`00KcU_>@02000026li001_>Fli001_>000KcP20002KcP00`00LcQc
>002000027<h001c>7<h001c>000LcP20002LcP01000LcMc=`000W<g00<007<g00001P0000E_5`00
KaM_5`00009_6006001_66lH001_60000Vkh00D006[h001Zn000009Zn003001Vn6Kh00<0000CI]P0
06;HH]P006;I001Rf@00G[T005ji001J^@00FYT005ZI00000UJI00@005JI001BN@80000=CWX004YJ
001:FP00AUX004Hj0012>P00?QX00P0000<j6P0000000P0000<anP00<OX00P0000<anP0000000P00
00@]fP00000]nP@00003;O/0037k0080008f6`800005=S/003Hk000j>`0200000ciL000nG0060000
6D9l0016O000AW`004JL0016W000BY`004ZL001:W000BY`004ZL001:W000C[`004jl02l0000DD]/0
05;K001Bf`00D]/005;K001Bf`00D]/005;K001Ff`00E]/0009Ff`09001Ff`00E]/005KK001Ff`00
01eoo`03001oogoo06aoo`00CWoo00<007ooOol057oo00`005KK001Ff`00E]/005KK001Ff`00E]/6
000025KK001Ff`00E]/005KK0002E]/01000E]/005KK0P0000QFf`00E]/005KK001Ff`000UKK00/0
05KK001Ff`00E]/005KK001Ff`00009Ff`0H001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E[/0
05Jk001F^`00E[/005Jk5`0000=>V`00CY/00P0000E>V`00CY/004ik00800007BW/004Yk0016FP00
AUX00P0000=2>P00?QX00`0000<n6@00>OT00`0000<]^00000000P0000Hi]`00000m]`00?ML30000
0dWf001=mP0300003E8F001B=P00ESH005Hf001F=P00ESH005Hf00D00009ESH005XfFSH005YF001J
EP00009JEP07001NEP00GUH005if00000V9f00<0069f00000V:F00@006JFIYH0009Z]P03001Z]P00
00=Z]P04001Z]VZf0002J]H00`00J]H00003J]L01000J]MZe`000V[G00@006[GJ]L0009Ze`04001Z
n6[h0002J_P00`00J_P00002J_P01@00I_QVn000I_T00P000VKi00<006Ki00000VKi00@006Ki001V
n@80009Vn@04001VnFKi0002I_T01000I_T006Ki0P000VLI00<006LJ00000fLJ00@006LJ001W6P80
009W6P03001W6P00009[6P04001[6V/J0002JaT01000JaU[6@000V/i00@006/i0000009_>@04001_
>Fli0002KcT01@00KcQ_>6lh00000Vlh00D007<h001c>000009c>004001c=g<g0003LcL01@00LcMc
=g<g00000g<g00@007LgMcL000=g=P05001g=P00LaH00003LaH01@00MaH007<F00000W<F00@007<F
LaH000=c5P03001c5W<F00800007K_L006kgK_L006kg00000Vkg00H006[GJ]L006[G0002I]P00`00
I]P00002H[P01@00H[P005jh00000Ujh00X005ZI001JV@00EYT005Ii001BN@800006BUT00000@QT0
03hI0P0000@]^@00000QN0<000031=H0000000h000075IX00000000Qf`00:O`00`0000H^7000000b
?000<S`200000c8l00000002<Q/200000c8K000b6`0200001BhK00000000:O/00P0000DQ^P000000
01Ui00h000034;@0000000<0000>AMH004Wf001>5P00DQH0058F001B=P00ESH0009F=P0?001F=P00
ESH005Hf001J=P00FSH005YF001JEP00009NEP03001NMP00009RM@06001VUFJE001ZU@000VZe00@0
06jeK[D0009be005001bm7;dL_@00002M_@01@00M_Afm7Kd00000gLD00@007LEMaD000=g5@04001g
5GLE0003MaH01000MaIg5P000W<f00@007<GLaMc5`800004LcL007<g0002LaL01000LcQc>0000Vlh
00@006lHKaP0009_>007001_66lH001_6000KaT00P000VlI00@006lIKaT0009[6@06001[>F/i001[
>@000V/i00H006/iJcT006/i0002JcT00`00JcU[>@030002JcT01`00KcU_>@00KcT006li0080009_
>@03001_>@00009_>@04001_>Fli0002KcT01P00KcQ_>000KcP0009_>004001c>7<h0002LcP01000
LcQc>0000W<h00D007<hLcP007<h00T0009c5`06001_5flG001_5`000VlG00@006lHKaP0009_6003
001_66lH00<0009Zn005001Zn000J_P00002I_P01@00I]P006KH00000V;H00T006;I001Rf@00G[T0
05ji00000UZi00@005ZI001JV@T00003CWX004YJ00800009AUX004Hj0012>P00?QX003hJ00800003
>QX0000000800003<OX0037j00800006<OX00000;MX002gJ0P0000<]nP0000000P0000Lan`00<Q/0
03HK000f6`0200001CHk000j>`00>U/00P0000DnG000?U`0049l00<00005@W`00000AW`00002AY`0
1000AY`000000TZL00@004ZL001:W080000BBY`004jl001>_000C[`004jl001>_000C[`004jl001>
_0000Tjl01T005:l001B_000D[`005:l001B_000D[`005:l001B^`00D[/005:k001Bf`00D]/00002
D]/300004U;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0009Ff`05001Ff`00E]/00002
E]/01`00E]/005KK001Ff`0001eoo`03001oogoo06]oo`00CWoo00<007ooOol057oo00@005KK001F
f`P00006E]/005KK001Ff`000UKK00`005KK001Ff`00E]/005KK001Ff`00E]/20002E]/02@00E]/0
05KK001Ff`00E]/00002E]/05000E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/>
00004e:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:K00800003CY/0000000T00004
CW/00000BW/200001DIJ0016FP00@SX00P0000@n6P00000enP800005>OT00000000]^003000013WH
000003Vg0P0000Tme`00000004Wf001=mP00CQH03`0000IF=P00ESH005Hf0002FSH01@00FUH005YF
00000UYF00L005iF001NEP00GWH00002HWH00`00HWH00002HYH01000IYH000000VZf00@006ZfJ[H0
009Z]P04001Z]VZf0002J]H01000J]IZeP000V[G00@006[GJ]L0009Ze`04001Zef[G0002J]L01000
J_P000000V[h00H006[hJ_P006[h0002I_P20002J_P00`00I_T00002I_T01000I_T006Ki0P000VKi
00<006Ki00000fKi00@006Ki001Vn@800005IaT006LIIaT00002IaX01@00IaYW6P00IaX00P0000EW
6P00IaYW6P00009W6P04001[6P00JaX20002JaT01000JaU[6@000f/i00<006/i00000Vli00D006li
KcT006li008000=_>005001_>6lhKcP00002LcP02000LcQc>000LcL007<g0003LcL01@00LcL007<g
00000W<g00D007Lg001c=`00009g=P05001g=P00LaH00003LaH01@00MaH007<F00000W<F00D007<F
001c5P00009c5P04001c5W<F0002K_L01000K_M^m`000Vkg0`000V[G00H006[GJ]L006KH0002I]P3
000046:h001N^5jh001N^000FYT005ZI001FV@00EWT0059i0P0000=:F@00AST00P0000<n6@000000
0P0000<YV@0000004@0000<9F@0000000P0000HMf`00000Yo000:Q`300001RhL0000038l000b?080
0005<S`0038K000b6`020000138K000002hK0P0000@Yn`00000UfP8000037IX00000008000032AP0
000000T000064;@00000<ED0046f0P0000a9mP00CQH0058F001B5P00DSH005Hf0002ESH03@00ESH0
05Hf001F=P00FSH005Xf001JEP00009JEP03001NEP000080009RM@06001VUFJE001ZU@000VZe00@0
06jeK[D000=be004001bm7;d0003M_@01000M_Afm0000gLD00@007LE000000=g5@05001g5@00MaD0
0002MaH01@00MaH007Lf00000W<f00@007<GLaL0009c=`03001c=`00009c5`04001c>7<h0003KcP3
0002KcP01000KaQ_60000VlH00@006liKcT0009_6@04001_6@00JaT20002JcT01`00JcU[>@00JcT0
06/i0080009[>@03001[>@00009[>@03001[>@00009[>@04001_>Fli0002KcT00`00KcT00002KcT0
0`00KcU_>@030003KcT01000KcT006lh0P000Vlh00<006lhKcP00`000W<h00D007<hLcP007<h00L0
0003LcL00000009c=`03001c=g<g00800006LaL006lGKaL006lG0P0000A_6000KaP0009_6006001_
66lH001Zn0000V[h00<006[h00000V[h0`0000]Vf000I]QVf000H]P006;I001Rf@00009N^@03001N
^@0000H00007EYT005JI001BN@00DWX01`0000Q6FP000012>P00?QX003hJ0P0000<j6P00>OX01000
00@anP00000anP@00003;MX002gj00800005<O/00000000an`0200001CHK000f6`00=S/0100000Dj
F`00?U`003iL00800003@W`0049l00D0000EAW`004JL0016W000BY`004ZL001:W000BY`004ZL001:
W000C[`004jl00800006C[`004jl001>_0000Tjl01/004jl001>_000D[`005:l001B_000D[`005:l
001B_000D[`005:k001B^`00D[/005;K00000U;K00L005;K001Bf`00D]/00002D]/04`00D]/005;K
001Bf`00D]/005;K001Bf`00D]/005KK001Ff`00009Ff`09001Ff`00E]/005KK001Ff`0001eoo`03
001oogoo06]oo`00CWoo00<007ooOol05Goo0`0000QFf`00E]/005KK001Ff`000UKK00l005KK001F
f`00E]/005KK001Ff`00E]/005KK00000UKK00H005KK000005KK0002E]/04P00E]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK001Ff`X0000>E]/005Jk001F^`00E[/005Jk001B^`00D[/0009B^`0B
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:K0`0000U>V`00CY/004jK001:V`00BW/0
100000E:N`00BW/004IJ00800003@SX0048j00800004>QX00000<MT30000137I000002fH100000@i
]`00000me`80000KAOH00000COH004hF001B5P00DQH0058f001F=P00ESH005Hf001F=P00ESH005Hf
001F=P00009J=P05001JEP00FUH00002FUH01@00GUH005iF00000Uif00D0069f001RMP0000=RUP<0
009Z]P04001Z]VZf0002J[H01000J[H000000V[F00@006[FJ]H000=Ze`<0009Ze`04001Zef[G0003
J]L01P00J_MZm`00J_P0009Zn003001Zn6[h00800005J_P006[hJ_P00002I_T00`00I_T00002I_T0
0`00I_T00002I_T01000I_UVn@000VKi00H006KiI_T006Ki0002IaT01000IaUW6@000VLJ00H006LJ
IaX006LI0002IaX01`00IaYW6P00IaX006/J0080009[6@04001[6F/I0002JaT01000JcT000000V/i
00@006liKcT0009_>@04001_>Fli0003KcP01000KcP000000g<h00@007<hLcP000=c=`05001c=g<g
LcL00002LcL01@00LcMc=g<g00000W<g00D007LfMcIg=P0000=c5P05001c5W<FLaH00002LaH01000
LaIc5W<F0P0000Ec5P00LaIc5P00009c5P04001^mfkg0002K_L01000K_M^m`000V[g00<006[G0000
0V[G00<006KHI]P00`0000]R^000H[QR^000G[P005jh001JV@00009JV@04001FV@00EWT300001DYI
0016>@00@QT00P0000<in@0000000`0000<IF00000002P0000<0e`0000001@0000@I^`00000Qf`80
0004:Q`00000;Q`200001RhL0000038l000b?0800005<Q/0038K000b6`020000138K000002gk0P00
00DUf`00000001fJ00<000034EP0000000X000034;@0024E0080000?@KH00000BOH004hF001B5P00
DQH0058f001F=P00009F=P0;001F=P00ESH005Hf001J=P00FSH00002FUH01`00FUH005iF001NMP00
009RM@04001VUFJE0002JYD01000J[D006je0P000g;D00@007;dL_@000=fm004001fm7Kd0003Ma@0
1@00MaD007LE00000gLE0P0000=g5@00MaH00WLF0P0000Eg=P00LcIc=P00009c5`04001c=g<g0002
LcL200001G<g001c>7<h00000Vlh00@006lhKcP0009_>004001_6000KaP20002KcT01000KaU_6@00
0VlI00<006li00000V/i00@006/iJcT0009[>@03001[>@00009[>@03001[>F/i00<0009[>@07001[
>F/i001_>@00KcT00P000Vli00<006li00000Vli00@006liKcT0009_>@06001_>Fli001_>0000Vlh
00@006lhKcP0009_>0T0009c>004001c>7<h0002LcP00`00LcL00002LcL01000LaMc5`000VlG00<0
06lG00000VlH00@006lHKaP0009_60<0009Zn005001Zn000J_P00002J_P00`00I_P00002I]P01`00
I]P006;H001Rf@00009Rf@03001N^@000080000CF[T005Zi001JV@00EYT005JI001BN@00DWX004ij
001>FP00BUX00`0000Q6>P00000n6P00?QX003XJ0P0000<inP00=OX00P0000<anP00<OX00P0000<a
nP0000000P0000<]nP00;OX00P0000Lb6`000000038K000f6`0200000cHk000j>`0400001CiL000n
G000?U`00P0000E2O000@W`004Il00D0000NAY`004ZL001:W000BY`004ZL001:W000BY`004jl001>
_000C[`004jl001>_000C[`004jl001>_0000Tjl01T005:l001B_000D[`005:l001B_000D[`005:l
001B^`00D[/005:k001Bf`00D]/00002D]/300005U;K001Bf`00D]/005;K001Bf`00D]/005;K001B
f`00D]/005KK001Ff`000UKK00T005KK001Ff`00E]/005KK00007Goo00<007ooOol0Jgoo001>Ool0
0`00Oomoo`0EOol00`00E]/00002E]/03@00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`0J001F
f`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`X0000:E]/005KK
001Ff`00E]/005KK0002E]/08000E[/005Jk001F^`00E[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00DY/200002DjK001>V`00CY/004jK001:V`0200000dYk0016N`04
00001DIJ0016FP00@SX00P0000Dn6P000000037I00<00006<MT00000;IP002Eg0P0000<i]`00?KL0
0P0000A1e`000019mP80000FCQH0058F001B5P00DSH005Hf001F=P00ESH005Hf001F=P00ESH005Hf
0002FSH00`00FUH00002FUH01`00FUH005iF001NEP00009NMP05001RMP00HWH00003HYH01P00I[IV
]P00J[H0009Z]P04001Z]VZfJ[H2000016[F001ZeP000V[F00D006[GJ]MZe`00009Ze`06001Zef[G
001Ze`000V[G0P000V[g00H006[hJ_P006[h0002J_P01`00J_QZn6[h001Zn000009Vn@04001Vn@00
I_T20002I_T01000I_UVn@000VKi00@006Ki001Vn@80009Vn@03001W6@0000=W6@04001W6P00IaX2
0002IaT00`00IaX00002IaX01P00IaYW6P00JaT0009[6@05001[6F/IJaT00002JaT01P00JcU[>@00
JcT0009_>@04001_>@000003KcT01@00KcQ_>6lh00000Vlh00@007<hLcP0009c>005001c=g<gLcL0
0003LcL01@00LcMc=g<g00000W<g00D007<gLcMc=`00009g=P05001c5W<FLaH00003LaH01@00LaIc
5W<F00000W<F00@007<FLaH000=c5P800005K_L006kgK_L00002K_L30002J_L01P00J]MZe`00J]L0
009Vf003001Vf000009R^005001R^000G[P00002G[P02000FYT005ZI001FV@00EWT200000diI001:
F@0200000d8I000n6@020000137I0000025h4P0000<9F@0000000P0000@Mf`00000Un`800004;Q`0
0000;Q`20000238L0000038l000b?000<Q/200000c8K000^6`02000012hK000002Wk0`0000@Q^P00
000INA0000038AD000000080000=AMH00000CQH0058F001B5P00DSH005Hf00000UHf00L005Hf001F
=P00ESH00002FSH01P00FSH005YF001JEP<00003GWH0069e009RM@03001VU@00009ZU@07001Z]@00
K[D007;D00000W;D00D007;d001fm000009fm005001fm000Ma@00003Ma@200000gLE001g5@02MaD0
1000MaEg5@000gLF00@007LfMcH0009c=P04001c5`000002LcL01000LcMc=`000W<g00@007<hLcP0
009_>004001_>6lh0002KcP01000KaQ_60000Vlh00L006liKcT006lI001_6@020002KcT01`00JcU[
>@00JcT006/i0080009[>@03001[>@00009[>@06001[>F/i001[>@000V/i00H006liKcT006li0002
KcT00`00KcU_>@030002KcT01@00KcU_>@00KcT00P000Vlh00<006lh00001P000W<h00@007<hLcP0
009c>003001c>7<h00<0009c>003001c=g<g00<0009c5`06001_5flG001_5`000VlH00@006lHKaP0
009_6003001_6000009Zn003001Zn000009Zn0<0009Vn007001Vf000I]P006;H00000V;I00<006;I
00000P0000QN^@00F[T005Zi001JV@000UJI00@005JI001BN@800007CWX004iJ001:FP00BUX01P00
00Dn6P00>QX003XJ00800003=OX0000000800003<OX0037j00800003<OX0000000800003;OX0037k
00800007<Q/0038K000f6`00=Q/00P0000<j>`00>S/0100000LnG000?U`0049l0012O002000014Il
0016O0000TJL1`0000=:W000BY`00P0000i:W000C[`004jl001>_000C[`004jl001>_0000Tjl01/0
04jl001>_000D[`005:l001B_000D[`005:l001B_000D[`005:k001B^`00D[/005;K00000U;K00<0
05;K00000P00019Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K0002E]/01@00E]/005KK
00000UKK00L005KK001Ff`00E]/0000MOol00`00Oomoo`1ZOol004ioo`03001oogoo01Ioo`0;001F
f`00E]/005KK001Ff`00E]/00002E]/01`00E]/005KK001Ff`00009Ff`0?001Ff`00001Ff`00E]/0
05KK001Ff`00E]/005KK00P0000:E]/005KK001Ff`00E]/005KK0002E]/05`00E]/005KK001Ff`00
E]/005KK001F^`00E[/005Jk001F^`00D[/005:k00000U:k01<005:k000005:k001B^`00D[/005:k
001B^`00D[/005:K001>V`0200002djK001>V`00CY/004ZK001:N`00BW/00P0000=6F`00AU/01000
00=2>P00@SX00`0000@enP00000]^@<00003;KP0000000800004>KL00000?KL200001T7G000004Wf
001=mP80000@DQH0058F001B=P00ESH005Hf001F=P00ESH005Hf0002ESH01@00ESH005Xf00000UYF
00L005YF001JEP00GUH00002GUH01@00GWH0069f00000V9f00@006:F0000009V]P03001Z]P00009Z
]P05001Z]VZfJ[H00002J]H01P00J]IZeP00J]H0009Ze`80009Ze`04001Zef[G0002J]L200001F[g
001Zmf[g00000V[h00<006[hJ_P00`000f[h00H006[hJ_P006Ki0002I_T01P00I_UVn@00I_T0009V
n@05001VnFKi001Vn@020002I_T00`00I_T00002IaT01@00IaUW6@00IaX00P000VLI00<006LI0000
0VLJ00@006LJ001W6P80009[6@04001[6F/I0002JaT01000JaT000000V/i00@006/iJcT0009_>@04
001_>Fli0002KcT01@00KcQ_>6lh00000Vlh00P007<hLcP007<h001c>0000g<g00D007<g001c=`00
009c=`05001c=`00LcL00002LcL01@00McH007<g00000g<F00D007<F001c5P00009c5P04001c5W<F
0003LaH01000LaIc5P000Vkg00@006kgK_L0009^m`03001^m`00009Zm`04001Zef[G0002J]L30000
1fKH001R^6:h001R^000009N^00:001N^000FYT005ZI001FV@00EWT200001DiI001:F@00AST00P00
00@n6@00000af@D000034CP0000000L0000409H000000?P6000011Vk0000027K0P0000@Yn`00000^
70800004;Q`00000<Q`200001c8l000b6`00<Q/0038K00<00003;Q/002gk008000059M/00000000M
VP0400000`TH0000000900002A2d00000000?IH004GF0019mP0200001U8F001B5P00DSH0009F=P05
001F=P00ESH00002ESH02000ESH005Xf001J=P00FUH3000015iF001NMP000f9e00<006JE00000VZE
00<006ZeJ[D00P0000Ube000L]Abe000L_@007Kd00000WKd00D007Kd001g500000=g5004001g5GLE
0003MaD01@00MaEg5GLE00000WLF00D007LfMcIg=P00009c=P06001c=g<g001c=`000W<g00@007<g
LcL0009c>007001_>000KcP006lh00000Vlh00@006lH0000009_>004001_>Fli0002KaT00`00KcT0
0002KcT01000JcU[>@000V/i00<006/i00000V/i00<006/iJcT00`000V/i00L006/iJcT006/i001_
>@020002KcT00`00KcT00002KcT01000KcU_>@000Vli00<006liKcT02P0000Q_>000KcQ_>000LcP0
07<h0P000W<h00H007<hLcP007<h0002LcP01000LcMc=`000W<H00@007<GLaL0009_5`03001_6000
009_6003001_6000009_6008001_66lH001Zn000J_P0009Zn003001Zn000009Vn005001Vf000I]P0
0002H]P00`00H]T00002000015ji001N^@000UZi010005Zi001JV@00EYT005JI001BN@00DWX004ij
001>FP800005BUX004Hj0012>P0400001CXJ000j6P00>OX00P0000<enP0000000P0000HanP00000a
nP00<OX20002;OX200000c8K000b6`0200001CHK000f6`00=S/00P0000<j>`00?U/00`0001@nG000
0012O000@W`0049l0016O000AW`004JL0016W000BY`004ZL1`0000E:W000C[`004jl00800006C[`0
04jl001>_0000Tjl01/004jl001>_000D[`005:l001B_000D[`005:l001B_000D[`005:k001B^`00
D[/005;K00000U;K00L005;K001Bf`00D]/00002D]/03P00D]/005;K001Bf`00D]/005;K001Bf`00
D]/@000MOol00`00Oomoo`1ZOol004ioo`03001oogoo01Ioo`03001Ff`00009Ff`07001Ff`00E]/0
05KK00000UKK00X005KK001Ff`00E]/005KK001Ff`800003E]/005KK00P00008E]/005KK001Ff`00
E]/0009Ff`0C001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK00000UKK020005Jk001F
^`00E[/005Jk001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:K0P00
00U>V`00CY/004jK001>V`00BY/00P0000E:N`00AW/004IK00800003@U/0048j00800003@SX003hJ
00<00003<MT0000000800003;KP0000000D00003?KL003gG00<0000;BOH004gf001>5P00DQH0058F
001B=P020002ESH02`00ESH005Hf001F=P00ESH005Hf00000UXf00T005YF001JEP00FUH005iF0000
0UiF00D005if001RMP00009RMP800005IYH006JfI[H00002J[H00`00J[H00003J[H01000J]IZeP00
0V[F00<006[FJ]H00P0000E^eP00J]MZe`00009Ze`04001Zef[G0003J_L01P00J_MZm`00J_P0009Z
n004001Zn6[h0002J_P01000J_QZn0000VKi0`000VKi00@006KiI_T0009Vn@06001VnFKi001Vn@00
0VKi00H006KiI_T006LI0002IaT200001FLI001W6FLI00000VLI00@006LJ001W6P80009[6@04001[
6F/I0002JaT01000JaU[6@000V/I00L006/iJcT006/i001_>@020003KcT02000KcU_>@00KcP006lh
0002KcP01000LcQc>0000g<h00D007<gLcMc=`00009c=`08001c=g<g001c=`00LcL0009c=`05001g
=P00LcL00003LaH01@00LaH007<F00000W<F00D007<F001c5P00009c5P04001c5W<F0002K_L01000
K_M^m`000Vkg00@006kgK_L0009Zm`03001Ze`00009Ze`03001Vf000009Vf003001R^000009R^00>
001N^000G[P005ZI001JV@00EYT005Ii001BN@800005BUT004Hi00126@02000013Wi000002fi0P00
00<IF0000000400000<ANP0000000P0000<Qf`009O/00P0000@Z7000000^70800004<Q`00000<Q`2
00001c8K000b6`00<Q/002hK00<00004;O/000009M/3000011fJ0000015I3@0000D@]000000003fF
00<0000<BOH004hF001B5P00DQH0058f001F=P000UHf00X005Hf001F=P00ESH005Xf001J=P<00004
FUH005iF0002GWH01P00HWERM@00IYD0009ZU@04001Z]FZe0002L]@02000L]Abe000L_@007Kd0002
M_@01@00M_@007LD00000gLD00H007LEMaEg5@00MaD20003MaD01@00MaH007Lf00000WLf00@007<f
LcH0009c=`03001c=g<g00800005LcL007<gLcL00002LcP01000KcQ_>0000Vlh00@006lhKcP0009_
>007001_>6lh001_>@00KaT00P000Vli00<006li00000V/i00@006/i0000009[>@03001[>@00009[
>@04001[>F/i0002JcT00`00JcT00002JcT00`00KcT00002KcT00`00KcU_>@030002KcT70002KcT0
0`00KcP00002KcP01000KcQ_>0000Vlh00@007<hLcP0009c>003001c>000009c>006001c>7<h001c
>0000W<g00@007<HLaP0009c5`06001_5flG001_60000VlH00<006lHKaP00`000VlH00<006[h0000
0V[h0`000V[h00L006Kh001Vf000I]P00002H]P3000016;I001N^@000Uji01@005Zi001J^@00FYT0
05JI001FV@00DWT0059j001>NP00CUX004YJ0P0000E6>P00@SX0048j00@00005>QX003Wj000enP02
000023Gj0000037j000anP00<OX400000bgj000an`0200000c8K000f6`0400000cHk000j>`020000
0ciK000nF`0600005D9l0012O000AW`004Il0016W000AY`004ZL001:W000BY`004ZL001:W0090000
2Tjl001>_000C[`004jl001>_0000Tjl01T005:l001B_000D[`005:l001B_000D[`005:l001B^`00
D[/005:k001Bf`00D]/00002D]/300000e;K0000000?000015;K001Bf`000UKK00T005KK001Ff`00
E]/005KK00007Goo00<007ooOol0JWoo001>Ool00`00Oomoo`0GOol00`00E]/00002E]/04000E]/0
05KK001Ff`00E]/005KK001Ff`00E]/005KK1`0000QFf`00E]/005KK001Ff`000UKK014005KK001F
f`00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`0?001Ff`00E]/005KK001Ff`00E]/005Jk001F
^`00009F^`0:001F^`00D[/005:k001B^`00D[/200003E:k001B^`00D[/005:k001B^`00D[/005:K
0080000=CY/004jK001>V`00CY/004ZK001:N`00BW/00P0000=6F`00AU/00P0000=2>P00?SX00P00
00Dn6P000000037I00H00003;IP002Eg00800004>KL00000?ML300006TWf001=mP00CQH0058F001B
5P00DSH005Hf001F=P00ESH005Hf001F=P00ESH005Hf0002FSH01`00FUH005YF001JEP00009NEP07
001NEP00GWH0069f00000V9f00@006JFIYH0009V]P04001Z]VZf0002J[H01000J[H000000V[F00@0
06[FJ]H0009ZeP05001^eVkFK]H00002J]L00`00J]MZe`030003J_L01000J_MZm`000V[h0`000V[h
00P006[hJ_QZn000J_P006Ki0P000V[i00H006KiI_T006Ki0002I_T01000I_T000000VKi00<006Ki
00000VKi00L006LI001W6@00IaT00002IaT00`00IaT00002IaT01P00IaYW6P00JaT0009[6@04001[
6F/I0002JaT01000JaT000000V/I00@006/iJcT0009[>@04001_>Fli0002KcT01@00KcU_>Fli0000
0Vlh00D006lhKcP007<h008000=c>005001c=g<gLcL00003LcL01000LcMc=`000g<g00@007<gLcL0
00=c=`05001c5W<FLaH00002LaH01@00LaIc5W<F00000W<F00P007<FLaH007<F001c5`000Vkg00<0
06kgK_L00`000Vkg00@006[gJ_L0009Ze`<0009Vf003001Vf000009R^007001R^000G[P005jh0000
0UZI00H005ZI001FV@00EWT2000024iI000004Hi00126@00?QT200000c7I0000000400000`dG0000
000400000`1e0000000300000`4H0000000300000aVk0000000300001bWk00000000;Q`002hL0080
0004<Q`00000<Q/400000c8K000^6`02000012gk000002Wk0P0000DQ^P00000001Ui00h000044;@0
0000<ED200003TGF00000000CQH0058F001B5P00DSH005Hf0002ESH01P00ESH005Hf001F=PD00006
FUH005YF001NEP000Uif00H0069eHWD006JE0002JYD01000J[EZ]@000W;D00@007;DL]Abe0800003
M_@007Kd009fm005001g57LDMa@00002Ma@02@00MaEg5GLE001g5@00McD00002MaD01@00MaH007Lf
00000WLf00@007<f0000009c=`04001c=g<g0002LcL01000LcMc=`000W<h00@006lhKcP0009_>004
001_>6lh0002KcP01000KcQ_>0000Vli00<006li00000Vli00D006liKcT006/i00800005JcT006/i
JcT00002JcT30002JcT01`00JcU[>@00JcT006/i0080009_>@04001_>@00KcT800000fli001_>@02
0002KcT00`00KcQ_>0030003KcP01000KcP007<h0P000W<h00<007<hLcP00`000W<h00<007<hLcP0
0P0000Ac>000LaP0009c5`06001_5`00001_60000VlH00@006lHKaP0009_6005001_6000J_P00002
J_P00`00J_P00002J_P01@00I_P006KH00000VKH0`0000ARf@00H]T0009N^@0J001N^@00F[T005Zi
001JV@00EYT005JI001BN@00DWX004ij001>FP00BUX004YJ0016>P800003@SX003hj00@00003>OX0
03Gj00800003=OX0000000800005<OX0037j000anP040000237k0000038K000f6`00=Q/400000cXk
000j>`0200001CiK000nG000?U`00`0000=2O00000000TIl00P004Il0016W000AY`004ZL0P0000e:
W000BY`004ZL001:W000C[`004jl001>_00]000055;K001Bf`00D]/005;K001Bf`00D]/005;K001B
f`00D]/005;K0002E]/02@00E]/005KK001Ff`00E]/0000MOol00`00Oomoo`1ZOol004ioo`03001o
ogoo01Qoo`0<001Ff`00E]/005KK001Ff`00E]/005KK200000=Ff`00E]/00P0001=Ff`00E]]Ff`00
E]/005KK001Ff`00E]/005KK001Ff`00E]/00002E]/03@00E]/005KK001Ff`00E]/005KK001Ff`00
009Ff`0F001Ff`00E]/005KK001F^`00E[/005Jk001F^`00D[/005:k001B^`00D[/200005E:k001B
^`00D[/005:k001B^`00D[/005:K001>V`00CY/004jK001>V`0200002DZK001:N`00BW/004Ik0016
F`0200001T9K000003hj000j6P<00004=OX00000;KT400000bfH0000000500007SgG00000000BOH0
04gf001>5P00DQH0058F001B=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH0009J=P05001JEP00
FUH00002FUH01`00GUH005iF001NMP00009RMP03001RMP0000=VUP03001V]P00009Z]P03001Z]VZf
0080009ZeP06001ZeV[F001ZeP000V[F00D006kFK]I^eP00009Ze`04001Zef[G0002J_L01000J_MZ
m`000V[g00@006[hJ_P0009Zn004001Zn6[h0002J_P01P00J_QZn000J_P0009Zn@04001VnFKi0002
I_T01000I_UVn@000VKi00<006Ki00000VKi00@006Ki001W6@8000=W6@03001W6@00009W6@04001W
6@00IaX20002JaT01000JaU[6@000V/I00@006/I0000009[6@07001[6F/I001[>@00JcT00P000fli
00D006liKcT006li008000=_>004001_>6lh0002LcP02@00LcQc>7<h001c=`00LcL00002LcL01000
LcMc=`000g<g00@007<gLcL000=c=`03001c5W<F008000=c5P04001c5W<F0002LaH01000LaIc5W<F
0P0000Ec5`00K_M^m`00009^m`06001^mfkg001^m`000V[g00H006[GJ]L006KH0002I]P00`00I]P0
0002H[P01@00H[P005jh00000Ujh3P0000A6>@00000n6@800004<MT000009IT200000a4h0000000@
00001AFJ000000008M/0100000LZ7000000002hL000b70020000138L0000038K0`0000@b6`00000]
n`800004:O/000009M/C0000112d0000035E0P0000=5eP00BOH00`0000QB5P00DQH0058f001F=P00
0UHf00<005Hf0000100000QJ=P00FSH005YF001JEP000UiF00<005if00000V9e00H006JEIYD006ZE
0002J[D01000L]Abe0000g;D00@007KdM_@000=fm009001g57LDMa@007LD001k5000009g5@05001g
5@00McD00003MaD200000gLf001g=P02McH2000017Lf001c=`000W<g00@007<gLcL0009c=`05001c
>000LcP00002KcP02@00KcP006lh001_>000KcP00002KcP01000KcT000000Vli00<006li00000Vli
0P0000M_>@00JcU[>@00JcT00002JcT01000JcU[>@000V/i00@006/i001[>@800003KcT0000000L0
009_>@04001_>Fli0002KcT01P00KcU_>@00KcT0009_>004001_>6lh0002KcP01P00KcQ_>000KcP0
009c>004001c>7<h0002LcP00`00LcP00002LcP01000LcQc>0000W<H00@007<GLaL0009_6003001_
6000009_60<0009_6003001_6000009Zn0<0009Zn005001Zn000I_P00002I]P3000016;I001Rf@00
0V;I01h005ji001N^@00F[T005Zi001JV@00EYT005JI001BN@00DWX004ij001>FP00BUX004YJ0016
>P00@SX200000chj000n6P0400001CGj000enP00=OX01@0000<anP00<OX00P000S7k0P0000<b6`00
<Q/00P0000<f6`00=S/0100000<j>`00?U/00P0000DnG000?U`0049l00D0000?AW`004Il0016W000
AY`004ZL001:W000BY`004ZL0080000>BY`004jl001>_000C[`004jl001>_000C[`0009>_00K001>
_000C[`005:l001B_000D[`005:l001B_000D[`005:l001B^`00D[/005:k001B^`00009Bf`03001B
f`000080000BD]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`000U;K00<005;K00000UKK
00T005KK001Ff`00E]/005KK00007Goo00<007ooOol0JGoo001=Ool00`00Oomoo`0IOol01000E]/0
05KK200000QFf`00E]/005KK001Ff`000UKK00h005KK000005KK001Ff`00E]/005KK001Ff`000UKK
00/005KK001Ff`00E]/005KK001Ff`00009Ff`0F001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/005Jk001F^`00E[/L00002djK001>V`00CY/004jK001:V`00BW/00P0000E6N`00AU/004IK0080
000:@SX00000>QX003Gj000enP00<MT500000bfH00000002000012UF000003gG0`0001Y9mP00COH0
04hF001B5P00DQH0058f001F=P00ESH005Hf001F=P00ESH005Hf001F=P000UXf00D005YF001JEP00
009JEP07001NEP00GUH005if00000V9f0`000fJF00H006JfI[H006Zf0002J[H01@00J]IZeV[F0000
0V[F00<006[FJ]H00P0000E^eP00K]I^eP00009Ze`04001Zef[G0002J_L01@00J_MZmf[g00000V[g
0`000V[h00@006[hJ_P0009Zn004001Zn0000002J_P01000J_UZn@000VKi00@006Ki001Vn@80009V
n@06001VnFKi001Vn@000VKi00<006LI00000fLI00H006LIIaT006LI0002IaT01P00IaUW6@00JaT0
00=[6@06001[6F/I001[6@000V/I00@006/IJaT0009[>@04001_>Fli0002KcT01@00KcU_>Fli0000
0Vlh00@006lhKcP0009_>004001c>7<h0004LcP01000LcMc=`000W<g00D007<g001c=`00009c=`05
001c=`00LcL00002LcL00`00LaH00002LaL02000LaIc5P00LaH007<F0002LaH01000LaIc5P000W<G
00@006kgK_L0009^m`04001^mfkg0002K_L00`00J_MZm`030002I]P00`00I]P00002I]P00`00H[P0
0002H[P00`00G[P0000200001eZI001JV@00EYT005Ii00800003CUT004YI00H00004>OT00000;KTC
00000`Di0000000200000aVk0000000300001BWk00000000;Q`00P0000<b7000<Q`00P0000@b6`00
000^6`<00004;Q/00000;O/3000012GK000001fj0`0000<AF@0000002P0000@@]000000aE@800005
AMH004Wf001>5P0>000035Hf001F=P00FSH005Xf001JEP00FUH0009NEP03001NMP00009RM@07001V
UFJE001ZU@00J[D00P000W;D00D007;DL]Abe00000=fm004001fm7Kd0003Ma@01@00Ma@007/D0000
0gLE00@007LeMcD000=g5@05001g=WLfMcH00002McH01000McIg=P000W<g0P0000Ec=`00LcMc=`00
009c=`04001c>7<h0002KcP01000KcQ_>0000Vlh00@006lhKcP0009_>003001_>@00009_>@03001_
>Fli00<0009_>@04001[>F/i0002JcT30002JcT00`00JcU[>@07000016li001_>@000Vli00@006li
KcT0009_>@04001_>@00KcT20002KcT00`00KcU_>@030002KcP01@00KcQ_>000KcP00P000Vlh00<0
07<hLcP00`000W<h00<007<hLcP00`000W<h00@007<HLaP0009c5`06001_66lH001_60000VlH00<0
06lH00000VlH00<006lH00000V[h00<006[h00000V[h00<006[h00000VKh00L006KH001Vf@00H]T0
0002H]T03@00H]T005ji001N^@00F[T005Zi001JV@00009FV@04001FV@00DWT200003Dij001>FP00
BUX004YJ0016>P00@SX0048j00800003?QX003hJ00800005=OX003Gj000enP0200001C7j00000000
<OX00P0000DanP00<O/0038K00800003<Q/003HK00800003=S/003Xk00@00005?U/003iK000nG002
00001D9l0012O000@W`00`0001M6O000AY`004JL001:W000BY`004ZL001:W000BY`004ZL001>_000
C[`004jl0080009>_00M001>_000C[`004jl001>_000D[`005:l001B_000D[`005:l001B_000D[`0
05:k001B^`00D[/00002D[/02@00D]/005;K001Bf`00D]/00002D]/04`00D]/005;K001Bf`00D]/0
05;K001Bf`00D]/005;K001Bf`00009Ff`09001Ff`00E]/005KK001Ff`0001eoo`03001oogoo06Uo
o`00CGoo1P005goo0`0000QFf`00E]/005KK001Ff`000UKK00X005KK001Ff`00E]/005KK001Ff`80
000=E]/005KKE]/005KK001Ff`00E]/005KK00000UKK01@005KK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK300000]B^`00D[/005:k001B^`00D[/005:k0080000?D[/005:k001B^`00
D[/005:k001>V`00CY/004jK00P00007BY/004Yk001:N`00AW/00P0000I6F`000012>P00?SX20000
1CGj00000000<MT02P0000<YEP00?KL00`0001]5mP00001=mP00CQH0058F001B5P00DSH005Hf001F
=P00ESH005Hf001F=P00ESH005Hf00000UXf00D005YF001JEP00009JEP05001NEP00GUH00002GWH0
1@00HWH006JF00000fJF00H006JfI[H006Zf0002J[H01@00J]IZeV[F00000V[F00@006[FJ]H0009^
eP05001^eVkFK]H00002J]L2000016kg001Zm`000f[g00@006[gJ_L0009Zn004001Zn6[h0002J_P0
1000J_QZn0000V[h00<006[h00000V[i00D006KiI_T006Ki0080009Vn@03001Vn@00009Vn@04001V
n@00I_T20002IaT01000IaUW6@000VLI00@006LI001W6@80009W6@04001[6F/I0002JaT01000JaT0
00000V/I00L006/IJaT006/I001[>@020003KcT01@00KcU_>@00KcT00P000Vlh00P006lhKcP006lh
001_>0000W<h00<007<hLcP00P000g<g00@007<gLcL0009c=`05001c=g<gLcL00002LcL01@00LcMc
=g<g00000g<G00P007<FLaH007<F001c5P000W<F00@007<FLaH000=c5`03001^mfkg00<0009^m`04
001^mfkg0002J_L00`00J]L00002I]P02000I]QVf000I]P006:h0002H[P300002Ejh001JV@00FYT0
05JI001FN@0200001diI001:F@00AST0048i00@00004<MT000009IT300000`dG0000000800000`3g
0000000400001AFJ000000008M/00P0000<Yn`00:Q`00`0000H^7000000b7000<Q`20000238K0000
02hK000^6`00;O/200001BWk000000008KX04`0000@Q5@00000mUP80000<BOH004hF001B5P00DQH0
058f001F=P000UHf00d005Hf001F=P00ESH005Xf001J=P00FUH00002FUH01@00GUH005if00000V9e
00@006JEIYD0009ZU@<000=be004001be7;D0003M_@01000M_Afm0000gLD00D007LD001k500000=g
5@05001g=GLeMcD00002MaD01@00McIg=WLf00000WLf00@007LfMcH0009c=`04001c=g<g0002LcL0
1000LcMc=`000W<h00D006lhKcP006lh0080009_>004001_>6lh0002KcP01P00KcU_>@00KcT0009_
>@04001_>Fli0002KcT00`00JcT00002JcT00`00JcT0000600001F/i000006li00000Vli00<006li
KcT00`000Vli00@006liKcT0009_>@03001_>@00009_>@04001_>Fli0002KcP01000KcQ_>0000Vlh
00<006lh00000Vlh00@007<hLcP0009_>003001c>000009c>004001_>6lh0002LcP01000LaP007<G
0P000VlH00@006lH001_6080009_6003001_6000009_60<0009Zn005001Zn000J_P00002I_P30002
I]T02`00H]T006;I001Rf@00G[T005ji00000UZi010005Zi001JV@00EYT005JI001BN@00DWX004ij
001>FP80000;BUX004Hj0012>P00@SX003hj000n6P0500001CGj000enP00<OX00P0000DanP000000
037j00800003<O/0038K00800005<Q/003HK000f6`0200000cXk000j>`0400002CiK000nG000?U`0
049l0012O0020002AW`500000dJL001:W002000054ZL001:W000BY`004ZL001>_000C[`004jl001>
_000C[`004jl0002C[`06`00C[`004jl001B_000D[`005:l001B_000D[`005:l001B_000D[/005:k
001B^`00D[/00002D]/00`00D]/0000200005U;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00
D]/005;K001Bf`000UKK00T005KK001Ff`00E]/005KK00007Goo00<007ooOol0JGoo001=Ool00`00
Oomoo`0JOol00`00E]/00002E]/03`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00002E]/02000
E]/00000E]/005KK0002E]/04P00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`X0000<
E]/005KK001Ff`00E[/005Jk001B^`000U:k00X005:k001B^`00D[/005:k001B^`80000=D[/005:k
001B^`00D[/005:k001>V`00CY/00P0000M>V`00CY/004ZK001:N`0600000dIk0016F`0200001T9K
000003hj000j6PH00003;KT0000000@000039GL0000000D00003AOH004Wf0080000FCQH0058F001B
5P00DSH005Hf001F=P00ESH005Hf001F=P00ESH005Hf0002FSH01@00FUH005YF00000UYF00D005iF
001NEP00009NMP<0009VUP04001VUVJF0002I[H00`00J[IZ]P030003J]H01000J]IZeP000V[F00@0
06kFK]H000=^eP04001Zef[G0002K_L01000J_MZm`000V[g00@006[gJ_L0009Zn004001Zn6[h0002
J_P01000J_P000000V[h00<006[h00000f[i00H006KiI_T006[i0002I_T01`00I_UVn@00I_T006Ki
0080009W6@03001W6@0000=W6@04001W6@00IaT20002IaT01000IaUW6@000V/I00@006/IJaT0009[
6@03001[6@00009[6@04001[6F/I0002JcT01000KcU_>@000fli00@006liKcT0009_>004001_>6lh
0002KcP01P00LcQc>000LcP0009c>004001c=g<g0002LcL01@00LcMc=g<g00000W<g00D007<gLcMc
=`00009c=`05001c5g<GLaL00003LaH01000LaIc5P000W<F00D007<F001c5`00009c5`04001^mfkg
0002K_L01P00K_M^m`00K_L0009Zm`06001Zef[G001Vf0000VKH00<006KH00000V:h0`0000AN^000
G[P0009JV@06001JV@00EYT005Ii0P0000Q>F@000016>@00@ST003hI0P0000@af@00000UVA<00003
3ET00000008000037K/0000000<00004:Q`00000;Q`200001RhL0000038L000b6`800003;Q/002hK
00800003;O/002gk00<000059MX00000000IVP0400000`Cg000000090000124E000003fF0P0000a9
mP00CQH0058F001B5P00DSH005Hf0002ESH02`00ESH005Hf001F=P00FSH005Xf00000UYF00L005YF
001NEP00GWH00003HWD00`00IYD00002JYD200001Fjd001be7;D00000W;D00T007KdM_Afm000M_@0
07/D00000gLD00D007/DNaAk5000009g5@06001g=GLeMcD007LE0P000gLf00@007Lf0000009g=P04
001c=g<g0002LcL02000LcMc=`00LcL007<g0002LcP01000KcQ_>0000Vlh00L006lhKcP006lh001_
>0020002KcT00`00KcU_>@030002KcT00`00KcU_>@0700001F/i001[>F/i00000V/i00<006/i0000
0Vli00<006li00000Vli00@006liKcT0009_>@04001_>@00KcT20002KcT00`00KcU_>@030002KcP0
1000KcQ_>0000Vlh00H006lhKcP006lh0002LcP01P00KcQ_>000LcP0009c>004001_>6lh0002LcP0
1000LaQc60000VlH00<006lH00000VlH00<006lH00000VlH00<006lH00000VlH00<006[h00000V[h
00<006[h00000V[h0`0000eVf000I]UVf@00H]T006;I001Rf@00G[T00002G[T00`00F[T0000@0000
3TYJ000004Hj0012>P00@SX003hj000n6P00?QX50002=OX200002S7j0000037j000anP00<OX0037k
0P0000<f6`0000000P0000<f6`00=S/00P0000<j>`00>U/0100000lnG000?U`0049l0012O000@W`0
04Il0016O000AY`01`0000=:W000BY`00P0000Y:W000C[`004jl001>_000C[`0009>_00M001>_000
C[`004jl001>_000D[`005:l001B_000D[`005:l001B_000D[`005:k001B^`00D[/00002D[/01000
D]/005;K0`00019Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K0002D]/00`00D]/00002
E]/02@00E]/005KK001Ff`00E]/0000LOol00`00Oomoo`1YOol004eoo`03001oogoo01]oo`0;001F
f`00E]/005KK001Ff`00E]/00002E]/06P00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/:00002UKK001Ff`00E]/005KK001Ff`000UKK01H005KK001Ff`00E[/0
05Jk001B^`00D[/005:k001B^`00D[/005:k001B^`80000ED[/005:k001B^`00D[/005:k001>V`00
CY/004jK001>V`00CY/004ZK00800005BW/004Yk0016N`04000014IK0000048j0P0000Dj6P00=OX0
02gI00800003;KT0000000P00009:EH000000015mP00BOH004gf0080000@DQH0058F001B=P00ESH0
05Hf001F=P00ESH005Hf0002ESH02@00ESH005Xf001JEP00FUH00002FUH00`00GUH00002GUH01@00
GWH0069f00000VJF00@006JFIYH0009V]P03001Z]VZf00800005J[H006[FJ]H00002J]H01000J]H0
00000fkF00@006kFK]H0009Ze`04001^mfkg0002J_L01000J_MZmf[g0`000f[h00<006[h00000f[h
00H006[hJ_P006[h0002J_P01@00J_UZn@00I_T00P000V[i00<006Ki00000VKi00H006KiI_T006LI
0002IaT01000IaUW6@000VLI00H006LIIaT006LI0002IaT02000IaUW6FLI001[6@00JaT20002JaT0
1`00JaU[6@00JaT006/I008000=[>@05001_>Fli001_>@020002KcT01@00KcQ_>000KcP00P000flh
00@007<hLcP000=c>008001c=g<g001c=`00LcL0009c=`05001c=`00LcL00002LcL01@00LcL007<G
00000g<G00@007<FLaH000=c5P04001c5W<F0002LaL01000LaMc5`000Vkg00@006kgK_L0009^m`03
001^mfkg00<0009Ze`06001Vf6KH001Vf0000VKH0`0000AR^000G[P0009N^008001JV@00FYT005JI
001FN@800005CUT004YI0016>@0200000chI00000002000012fi0000025h1P0000<0]P0009D00P00
00@0]P00000160D000055IX00000000Qf`02000012Gk000002hL0P0000@^7000000^6`800008<Q/0
0000;Q/002hK000]n`800004;O/000009M/300000afj0000000B00000cfF0015eP0200002ThF001B
5P00DQH0058f001F=P000UHf00L005Hf001F=P00ESH00002FSH02`00FSH005YF001JEP00GUH005if
00000f9e00<006JE00000VZE00@006jdK[@0009be004001be0000003M_@01@00M_@007/D00000gLD
00T007/DNaAk5000MaD007/d00000WLe00D007LE001g=@0000=g=P800004McH007LfMcH200001G<g
001c=g<g00000W<g00@007<gLcL0009c>004001_>6lh0002KcP01000KcQ_>0000Vlh00H006lhKcP0
06li0002KcT00`00KcT000060002JcT01000JcU[>@000V/i00@006/i001[>@80009[>@03001_>@00
009_>@<0009_>@04001_>Fli0002KcT00`00KcT00002KcT01000KcU_>@000Vli00L006lhKcP006lh
001_>0020002KcP00`00KcQ_>00200001Vlh001_>6lh001c>0800004KcP006lh0002LcP01000LaP0
00000VlH00<006lH00000VlH00H006lHKaP006lH0002KaP30002J_P01@00J_P006[h00000V[h00<0
06Kh00000VKH00T006KI001Rf@00H]T006;I00000Uji00<005ji00000P0000mJ^@00FYT005JI001F
V@00DYX0059j001>NP00CWX01@0000Y6>P000012>P00?SX003hJ000n6P800005>QX00000000enP02
00001C7j000anP00<OX00P0000DanP00<O/0038K00800003=Q/0000000800003=S/003Xk00800003
>U/003iK00<00003?U`000000092O0040012O0000002AW`200001dJL0016W000BY`004ZL00L00007
BY`004jl001>_000C[`00P000Tjl01d004jl001>_000C[`004jl001B_000D[`005:l001B_000D[`0
05:l001B_000D[/005:k001B^`00009B^`09001Bf`00D]/005;K001Bf`00009Bf`0>001Bf`00D]/0
05;K001Bf`00D]/005;K001Bfa0001eoo`03001oogoo06Qoo`00CGoo00<007ooOol06goo00<005KK
00000UKK00L005KK001Ff`00E]/00002E]/01000E]/005KK0P0000]Ff`00E]/005KK001Ff`00E]/0
05KK00P0000:E]/005KK001Ff`00E]/005KK0002E]/0<000E]/005KK001Ff`00E]/005KK001Ff`00
E]/005Jk001F^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/004jK001>V`80000;CY/004jK001:V`00BW/004Yk001:N`0200000dIK0012F`0300000d8j000n
>P0200000cGj0000000700000aTG00000002000012UF000003gG0`0000]9mP00COH004hF001B5P00
DQH0058f0080009F=P0A001F=P00ESH005Hf001F=P00ESH005Xf001JEP00FUH00002FUH00`00GUH0
0002GUH01@00GWH0069f00000VJF00L006JFIYIVUP00I[H00002J[H01000J[IZ]P000f[F00<006[F
J]H00P0000E^eP00K]I^eP00009^eP04001Ze`000003K_L01000J_MZm`000V[g00@006[gJ_L0009Z
n004001Zn6[h0002J_P01000J_QZn0000V[h00<006[h00000V[i0P000V[i00<006[i00000VKi00@0
06Ki001Vn@80009W6@04001W6FLI0002IaT01000IaT006LI0P000VLI00@006LIIaT0009W6@04001[
6@000002JaT01`00JaU[6@00JaT006/I0080009[6@04001[>F/i0003KcT01000KcU_>@000Vli00@0
06lhKcP0009_>004001_>6lh0002LcP00`00LcQc>002LcP01000LcMc=`000W<g00P007<gLcL007<g
001c=`000W<g00D007<g001c5`0000=c5`05001c5P00LaL00002LaH01000LaIc5P000W<G00@007<G
LaMc5`<0009^m`04001^mfkg0002K_L01P00J_MZm`00J]L0009Vf003001Vf6KH00<0000@H[P006:h
H[P005jh001N^000FYT005ZI001FV@00EWT200001diI001:F@00AST0048i00800003>OT000000080
00039IT00000018000054GX00000000M^`05000012Wk000002hL0P0000@^7000000^6`800008<Q/0
0000;Q/002gk000Yn`800004:O/000009MX400000aEi0000000?00001CfF0015eP00BOH00P0000QB
5P00DQH0058f001F=P000UHf00<005Hf00000UHf00d005Hf001J=P00FSH005YF001JEP00GUH00002
GWH01P00HWERM@00IYD0009ZU@04001^]6jd0002L]@01@00L]@007Kd00000WKd00D007Kd001k5000
00=g5009001k57/DNa@007LE001k=00000=g=@800003McD007Lf009g=P04001g=WLf0002McH01000
LcMc=`000W<g00@007<gLcL000=c=`07001c>000KcP007<h00000Vlh00@006lh001_>080009_>0L0
0005KcT006liKcT00002KcT30002JcT01000JcU[>@000V/i00<006/i00000V/i00<006li00000Vli
00@006liKcT0009_>@04001_>@00KcT20002KcT00`00KcT00002KcT01000KcU_>@000Vlh00@006lh
KcP0009_>003001_>000009_>004001_>6lh0002KcP00`00LcP00002KcP01000KcQ_>0000W<h00<0
06lH00000VlH00<006lHKaP00`000VlH00<006lH00000VlH00P006[hJ_P006[h001Zn0000V[h0`00
0VKh00<006KH00000VKI0P0000ARf@00H]URf@D00006F[T005Zi001JV@000UJI00H005JI001BVP00
DWX200001Dij001:FP00BUX01P0000@n>P00?QXn6P800004>QX00000>QX30000237j0000037j000a
nP00<OX200000c7k000b6`0200000cHK000f6`0400000cXk000j>`0200000ciK000nF`0500002d9l
0012O000@W`004Il0016O000AY`00P0000U:W000BY`004ZL001:W000BY`02`0000A>_000C[`0009>
_00K001>_000C[`005:l001B_000D[`005:l001B_000D[`005:l001B^`00D[/005:k001B^`00009B
f`03001Bf`0000800003D]/0000000l00004D]/005;K0002D]/02@00D]/005;K001Ff`00E]/0000M
Ool00`00Oomoo`1XOol004eoo`03001oogoo01aoo`03001Ff`00009Ff`0<001Ff`00E]/005KK001F
f`00E]/005KK0P0000=Ff`000000200000QFf`00E]/005KK001Ff`000UKK01<005KK001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/00002E]/05P00E]/005KK001F^`00E[/005:k001B^`00D[/0
05:k001B^`00D[/005:k0P0001EB^`00D[/005:k001B^`00D[/004jK001>V`00CY/004jK001>V`00
BY/00P0000M:N`00BW/004Ik0016F`0200001d9K00000000?SX003XJ00<00005;MT00000000YV@05
00000bEg000YEP06000084Wf001=mP00CQH0058F001B5P00DSH005Hf001F=P00ESH005Hf001F=P00
ESH005Hf001J=P00FUH005YF0002FUH01@00GUINEP00GUH00`000V9f00<006JF00000fJF00<006Jf
00000VZf00@006ZfJ[H000=ZeP04001ZeV[F0002K]H01000K]I^eP000fkF0P0000E^mP00K_M^m`00
009Zm`04001Zmf[g0002J_L01000J_QZn0000V[h00L006[h001Zn000J_P00002J_P01`00J_P006[i
001Zn000009Zn@06001ZnF[i001Vn@000VKi00H006LIIaT006LI0002IaT01@00IaUW6@00IaT00P00
0VLI00<006LI00000VLI00<006LIIaT00P0000E[6@00JaU[6@00009[6@06001[6F/I001[6@000V/I
00H006/iJcU[>@00KcT20002KcT01000KcU_>@000Vlh00@006lhKcP0009_>005001c>000LcP00003
LcP01000LcMc=`000g<g00@007<gLcL000=c=`04001c=g<g0003LaL02000LaMc5`00LaH007<G0002
LaH01@00LaH007<G00000W<G00@007<GLaL0009^m`04001^mfkg0002K_L30002J_L01P00J]MZe`00
I]P0009Vf005001Vf000H[P00002H[P01@00G[P005jh00000UZI00T005ZI000005Ii001BN@00CUT0
0P0000E6>@00@ST003hI00800004=OT000009IT200000aUH0000000<00000`Dh0000000200000aFJ
00000004000012Gk000002Wk0P0000@^7000000^6`800006;Q/00000;Q/002hK0P0000<Yn`00:O/0
0P0000<Uf`0000000P0000<IVP0000000P0000<4m`0000001`0000@04@00000aE@80000>AMH004Wf
001>5P00DQH0058F001B=P00ESH0009F=P0A001F=P00ESH005Hf001J=P00FSH005YF001JEP00GUH0
0002GWH01P00HWERM@00IYD0009ZU@04001^]6jd0002L]@01@00L]@007Kd00000gKd0P0000=k5000
Ma@00WLD00T007/DNaAk5000MaD007/d00000gLe00@007LeMcD000=g=P04001g=WLf0002McH01000
LcMc=`000W<g00D007<g001c=`00009c=`04001c>7<h0002LcP01@00KcQ_>000KcP01`000Vli0P00
00A_>@00KcT0009_>@04001_>Fli0002KcT01`00JcU[>@00JcT006/i0080009[>@03001[>@00009_
>@<0009_>@04001_>Fli0002KcT00`00KcT00002KcT00`00KcU_>@02000026li001_>Fli001_>000
KcP20002KcP00`00KcQ_>0030002KcP01P00KcQ_>000LcP0009_>004001_>6lh0002LcP01P00KaQ_
6000KaP0009_6006001_66lH001_60000VlH0`000V[h00D006[h001Zn000009Zn008001Vn6Kh001V
n000I]P0009Vf@80009Rf@<00004G[T005ji0002F[T04P00F[T005ZI001FV@00EYT005:J001BNP00
CWX004ij001:FP800003AUX004IJ00@0008n6P05000n6P00000j6P020002=QX20000237j0000037j
000anP00=Q/200000c8K000f6`0200000cHK000f>`0400000cXk000jF`0200001CiK000nF`00@W`0
0`0000e2O000@W`004Il0016O000AY`004JL001:W00200003dZL001:W000BY`004ZL001>_000C[`0
04jl001>_00[00004U;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0009Bf`0;001Bf`00
D]/005;K001Ff`00E]/0000MOol00`00Oomoo`1XOol004eoo`03001oogoo01eoo`0<001Ff`00E]/0
05KK001Ff`00E]/005KK1`0000YFf`00E]/005KK001Ff`00E]/0009Ff`0A001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/00002E]/03@00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`06001F
^`00E[/005:k0P0001UB^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/004jK
001>V`0200002DjK001>V`00BY/004Yk001:N`0200001DIk0016F`00@U/01P0000Dj6P00=OX002gI
00/00004:EH00000<GH300007TWf001=mP00CQH0058F001B5P00DSH005Hf001F=P00ESH005Hf001F
=P00ESH005Hf001J=P00FUH0009JEP05001JEUYF001NEP0300001f9f001RMV9f001VUP0000=VUP03
001V]VJf00<0009Z]P05001ZeV[FJ]H00002J]H01000K]I^eP000fkF00@006kFK]H0009^mP04001^
mfkg0002J_L01`00J_L006kg001Zm`0000=Zn004001Zn6[h0002J_P01P00J_QZn000J_P0009Zn007
001Zn6[hJ_P006[i00000V[i00@006Ki001Vn@80009W6@04001W6FLI0002IaT01P00IaUW6@00IaT0
009W6@0:001W6FLI001W6@00IaT006/I0002JaT01`00JaU[6@00JaT006/I0080009[6@04001[6F/I
0002JcT20002KcT02P00KcU_>@00KcT006lh001_>0000Vlh00@006lhKcP0009c>009001c>7<hLcP0
07<g001c=`00009c=`04001c=g<g0003LcL01000LcMc=`000g<G00D007<GLaMc5`00009c5`04001c
5W<FLaH200001G<G001c5g<G00000W<G00@006kgK_L0009^m`04001^mfkg0002J_L00`00J_L00002
J]L00`00I]QVf00300002FKH001R^6:h001R^000G[P00002G[P01000FYT005ZI0P0000UFN@00DWT0
04iI001:F@00AST00P0000<n6@00>OT01@0000DQN000000000Cg008000030;H0000000/000045IX0
00007K/500001bWk00000000;Q`002hL00800009;Q/00000000^6`00;Q/002gk00800004:O/00000
9M/200000b6j0000000200000`di000000090000100A0000035E0P0000i5eP00BOH004hF001B5P00
DQH0058f001F=P000UHf00l005Hf001F=P00ESH005Xf001J=P00FUH005YF00000UiF00<005if0000
0V9e00<006JEIYD00`000Vjd00P007;DL]@007;D001fm0000gKd00T007/DNaAk5000Ma@007/D0000
0g/D00D007/dNcAk=000009g=@04001g=GLe0002McH20002McH01@00McH007Lf00000W<g00@007<g
LcL0009c=`05001c=g<g001c>00200000g<h000000060002KcP00`00KcP00002KcT01000KcU_>@00
0Vli00@006li001_>@80009_>@04001[>F/i0002JcT00`00JcT00002JcT00`00JcU[>@030002KcT0
1`00KcU_>@00KcT006li0080009_>@03001_>@00009_>@04001_>Fli0002KcT01P00KcQ_>000KcP0
009_>004001_>6lh0002KcP01000KcQ_>0000Vlh00<006lh00000Vlh00@006lh001c>080009_6003
001_66lH00<0009_6003001_6000009_6008001_66lH001Zn000J_P0009Zn0<0009Vn003001Vn000
009Vf004001Vf@00H]T3000015kI001N^@000Uji01P005Zi001J^@00FYT005JI001FV@00DYX0059j
001>NP00CWX004YJ001:FP00AUX200001d8j00000000?QX003hJ00800005>QX003XJ000f6P020000
1C7j000anP00<OX00P0000<f6`0000000P0000<f6`00=Q/00P0000<f>`00>S/0100000<jF`00?U/0
0P000SiK0P000T9l10000TIl0P0000e6W000AY`004ZL001:W000BY`004ZL001:W002000014jl001>
_0000Tjl0P000Tjl01d004jl001>_000C[`004jl001B_000D[`005:l001B_000D[`005:l001B^`00
D[/005:k001B^`00009B^`0I001B^`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00
D]/005;K00000U;K00<005;K00000U;K00T005;K001Bf`00E]/005KK00007Goo00<007ooOol0Igoo
001=Ool00`00Oomoo`0MOol01000E]/005KK200000EFf`00E]/005KK0080009Ff`0A001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/00002E]/02`00E]/005KK001Ff`00E]/005KK00000UKK0180
05KK001Ff`00E]/005KK001Ff`00E]/005Jk001F^`00D[/200008E:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00CY/004jK001>V`00CY/004jK001:V`0200000dYk001:N`02
00001dIK0012F`00@U/003Xk00@00005=OX00000000UV@0500000aTG0000000300000bUF00000002
000074Wf001=mP00CQH0058F001B5P00DSH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001J=P00
0UYF00<005YF00000UYF00D005iF001NMP00009RMP05001RMP00IYH00003IYH00`00I[IV]P020000
16Ze001Z]P000f[F00@006[F000000=^eP04001^eVkF0002K]H01000K_I^mP000fkg00@006[gJ_L0
009^m`04001Zmf[g0002J_P01000J_P000000V[h00@006[hJ_P0009Zn0<000=Zn007001ZnF[i001Z
n@00I_T00P000V/I00@006LIIaT0009W6@04001W6@00IaT20002IaT01P00IaUW6@00IaT0009W6@07
001[6F/IJaT006/I00000V/I00@006/IJaT0009[6@03001[6@00009[6@05001[>@00JcT00002KcT0
1000KcU_>@000Vli00@006lhKcP0009_>004001_>0000003LcP01@00LcQc>7<h00000W<g00P007<g
LcL007<g001c=`000W<g00D007<g001c5`0000=c5`04001c5g<G0003LaL01000LaIc5P000W<G00X0
07<GLaL007<G001_5`00K_L0009^m`04001^mfkg0002J_L01P00J_MZm`00J]L0009Vf003001Vf000
009Vf003001R^000009R^00<001N^000G[P005ZI001JV@00EYT005Ii0P0000M>F@00BUT004Hi0012
>@02000013Wi0000037I500000<9F@0000000P0000<I^`0000000`0000@Un`00000Yn`<00003;Q`0
02hK0080000;;Q/00000000^6`00;O/002Wk000Yn`0300000bGJ0000000200000aEi0000000:0000
100A0000035E0P0000i5eP00BOH004hF001B5P00DQH0058f001F=P000UHf00l005Hf001F=P00ESH0
05Xf001J=P00FUH005YF00000UiF00<005if00000V9e00<006JEIYD00`000Vjd00@007;DL]Abe080
0003M_@007Kd009fm009001k57/DNa@007LD001k500000=k5006001k=7/dNc@007Le0P000WLe00<0
07Lf00000WLf00<007LfMcH00P0000Eg=P00LcMc=`00009c=`04001c=g<gLcL70002LcP01P00KcQ_
>000KcP0009_>003001_>6lh00<0009_>@04001_>Fli0002KcT01000KcU_>@000Vli00@006/i001[
>@80009[>@03001[>@00009[>@03001_>@00009_>@04001_>Fli0002KcT00`00KcT00002KcT00`00
KcU_>@030003KcT01000KcT006lh0P000Vlh00<006lh00000Vlh00@006lhKcP0009_>006001_>6lh
001_>0000Vlh00@006lhKcP0009_6003001_6000009_6003001_6000009_6003001_66lH00<0009_
6003001Zn6[h0080009Zn006001Zn6[h001Vn0000VKh00<006KH00000VKI0P0000mRf@00G]UNf@00
G[T005ji001J^@00F[T005ZI00000UJI00H005JI001BVP00DWX200002Dij001:FP00BUX004IJ0016
FP0200000d8j00000003000023XJ000003XJ000f6P00=QX200001C7j000anP00<OX00P0000<f6`00
00000P0000<f6`00=Q/00P0000<j>`00>S/0100000dnF`00?U/003iK0012O000@W`0049l0012O005
0000<DJL000004ZL001:W000BY`004ZL001:W000BY`004jl001>_000C[`004jl001>_000C[`004jl
001>_000C[`005:l001B_000D[`005:l001B_000D[`005:k001B^`00009B^`0;001B^`00D[/005:k
001Bf`00D]/00002D]/04`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00009Bf`0;
001Bf`00D]/005;K001Ff`00E]/0000MOol00`00Oomoo`1WOol004eoo`03001oogoo01ioo`<00008
E]/005KK001Ff`00E]/0009Ff`04001Ff`00E]/200002UKK001Ff`00E]/005KK001Ff`000UKK00T0
05KK001Ff`00E]/005KK00000UKK01H005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ffb@00009CY/004jK001:V`00BW/004Yk00800003AW/004IK00800005@U/00000000f6P05
00000bgI0000000400000aTG0000000300001BUF00000000AOH00P0001Q=mP00CQH0058F001B5P00
DSH005Hf001F=P00ESH005Hf001F=P00ESH005Hf0002FSH01@00FUH005YF00000UYF0`0000MNMP00
HWIRMP00HWH00002IYH01000IYIVUP000VJf00@006ZeJ[D0009Z]P08001ZeV[F001ZeP00K]H0009^
eP05001^eVkF001^eP020003K_H01000K_M^m`000V[g00@006kgK_L0009Zm`05001Zn6[hJ_P00002
J_P01P00J_QZn000J_P0009Zn004001Zn6[h0002J_P01000J_UZn@000V[i00<006/I00000V/I00@0
06LIIaT0009W6@04001W6@000002IaT00`00IaT00002IaT01000IaT006LI0P000f/I00L006/IJaT0
06/I001[6@020002JaT01000JaU[6@000V/I00D006/iJcU[>@00009_>@04001_>@00KcT20003KcP0
1000KcQ_>0000Vlh00D007<hLcQc>000009c>005001c=g<gLcL00002LcL01000LcMc=`000g<g00@0
07<GLaL000=c5`05001c5`00LaL00002LaL01000LaIc5P000g<G00<007<GLaL00P0000E_5`00K_M^
m`00009^m`<0009Zm`04001Zmf[g0002J]L30002I]P01@00I]P006:h00000V:h00D005jh001N^000
009JV@09001JV@00001FN@00DWT004iI00800005AST0048i000n6@02000013Gi000002Vi0P0000<I
F00000001@0000<0]P000;H00P0000<0n0000000100000@EVP00000M^`<000039O/002Wk00<00006
;Q/00000;Q/002hK0`0000<^6`0000000P0000<Yn`00:O/00P0000DUf`00000001fJ00@000031AP0
000000L00003014000000080000??IH00000BOH004hF001B5P00DQH0058f001F=P00009F=P0=001F
=P00ESH005Hf001J=P00FSH005YF00000UYF00D005iF001NMP00009RM@03001VUFJE00<0009^]005
001be7;DL]@00002M_@01@00M_Afm7Kd00000g/D00D007LD001k500000=k5009001k=7/dNc@007Le
001k=@00009g=@80009g=P04001g=WLf0002McH00`00LcMc=`080002LcL01000LcQc>0000W<h00@0
06lhKcP0009_>003001_>000009_>004001_>Fli0002KcT01000KcT006li0P000Vli00@006liKcT0
009[>@03001_>@00009[>@03001[>F/i00<0009_>@07001_>Fli001_>@00KcT00P000Vli00<006li
00000Vli00@006liKcT0009_>@06001_>Fli001_>0000Vlh00<006lhKcP00P0000Q_>000KcQ_>000
KcP006lh0P000Vlh00@006lh001_>080009_6003001_6000009_6006001_66lH001_60000VlH00H0
06lHKaP006lH0002J_P00`00J_P000020002J_P02000I_QVn000I_P006KH0002I]T20002H]T01`00
G]T005ji001N^@00009J^@0B001J^@00FYT005JI001FV@00DYX0059j001>NP00CWX004YJ0P0000E6
FP00AUX0048j00800092>P@00003>QX00000008f6P800008=QX00000<OX0037j000f6`800003=Q/0
000000800003=Q/003Hk00800003>S/003Xk00@00004?U/003iK?U/200002D9l0012O000@W`004Il
0016O00500003dZL000004ZL001:W000BY`004ZL001>_000C[`00002C[`20002C[`07@00C[`004jl
001>_000C[`005:l001B_000D[`005:l001B_000D[`005:k001B^`00D[/005:k00000U:k00@005:k
001Bf`<0000DD]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0009Bf`0;001Bf`00
D]/005;K001Ff`00E]/0000MOol00`00Oomoo`1WOol004eoo`03001oogoo01ioo`03001Ff`00009F
f`0<001Ff`00E]/005KK001Ff`00E]/005KK0P000UKK00T005KK001Ff`00E]/005KK00000UKK01@0
05KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK300000MF^`00D[/005:k001B^`02
00006e:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/004jk001>V`00CY/004jK001>V`08
000024Yk000004Ik0016F`00@U/3000013Xk0000037j1`0000<IF00000001@0000<YEP0000001000
01U9mP00001>5P00DQH0058F001B=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH00002FSH01P00
FUH005YF001JEP800004GUH005if0002HWH00`00HWH00002IYH01000IYIVUP000VJf00@006ZeJ[D0
009Z]P04001ZeV[FJ]H200001FkF001^eVkF00000fkF00@006kfK_H0009^mP08001^mfkg001Zm`00
K_L0009^m`03001Zm`00009Zn080009Zn004001Zn6[h0002J_P30002J_P02000J_QZn6[h001Zn@00
J_T20002JaT01000JaU[6@000VLI00H006LIIaT006LI0002IaT01`00IaUW6@00IaT006LI0080009[
6@07001[6F/IJaT006/I00000V/I00@006/IJaT0009[6@04001[6@00JaT20003JcT01000KcU_>@00
0Vli00@006lhKcP0009_>004001_>6lh0003KcP02000LcQc>000LcP007<h0002LcL01000LcMc=`00
0g<g00@007<gLcL000=c5`05001c5g<GLaL00002LaL02000LaMc5`00LaH007<G0002LaL01000LaMc
5`000VlG00@006kgK_L0009^m`04001^mfkg0002J_L00`00J_L00002J]L00`00I]P00002I]P00`00
I]P00002H[P01@00H[P005jh00000Ujh3P0000I6>@00000n6@00>OT200000c7I0000000C00000`ei
0000000200000afk0000000300000bWk000Yn`0300001RhK000002hK000^6`<00003;O/000000080
0003:O/002GK00<000038KX00000008000033CT0000000d0000??IH00000BOH004hF001B5P00DQH0
058f001F=P00009F=P0;001F=P00ESH005Hf001J=P00FSH00002FUH01`00FUH005iF001NMP0000=R
M@03001VU@00009ZU@04001^]6jd0002L]@01@00M_Afm7Kd00000WKd00L007/DNaAk5000Ma@00002
Na@00`00NaAk50020003Nc@200001G/e001g=GLe00000gLf00<007LfMcH020000W<g00P007<gLcL0
07<g001c=`000W<h00@007<h001_>080009_>003001_>6lh00<0009_>@04001_>Fli0002KcT01000
KcU_>@000Vli00@006li001[>@80009_>@03001[>@00009[>@06001_>Fli001_>@000Vli00H006li
KcT006li0002KcT00`00KcU_>@030002KcT01@00KcU_>@00KcT00P000Vlh00<006lh00000Vlh00@0
06lhKcP0009_>004001_>6lh0002KcP00`00KcP00002KcP00`00KaP00002KaP00`00KaQ_60030002
KaP00`00KaP00002KaP01000KaQ_60000VlH00D006[h001Zn000009Zn003001Zn000009Vn003001V
n000009Vf0<00008H]T006;I001Nf@00G[T0009N^@0H001J^@00F[T005ZI001FV@00EYT005:J001B
NP00CWX004ij001:FP00BUX004IJ0P0000M2>P00@SX0048j000n>P0200001CXJ000j6P00=QX00P00
00<f6P00=QX00P0000<anP00=Q/00P0000<f6`00=Q/0100000<f>`00>S/00P0000<j>`00?U/01000
0SiK00H0049l0012O000@W`200001dIl0016O000AY`004JL00D00005BY`004ZL001:W002000014jl
001>_0000Tjl01d004jl001>_000C[`004jl001>_000C[`005:l001B_000D[`005:l001B_000D[`0
05:k001B^`00009B^`08001B^`00D[/005:k001Bf`<0000BD]/005;K001Bf`00D]/005;K001Bf`00
D]/005;K001Bf`000U;K00<005;K00000U;K00T005;K001Bf`00E]/005KK000077oo00<007ooOol0
Igoo001<Ool00`00Oomoo`0POol02`00E]/005KK001Ff`00E]/005KK00000UKK00@005KK001Ff`80
000FE]/005KKE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/:000035KK001Ff`00
E]/005KK001Ff`00E]/0009F^`06001B^`00D[/005:k0P0001UB^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001>^`00CY/004jK001>V`0200001dZK001:V`00BW/004Yk00D00005AU/0049K
0012F`03000013HJ000002gJ0`0000<UV@000000100000@@mP00000YEP800003<GH003ff00<0000C
COH00000DQH0058F001B=P00ESH005Hf001F=P00ESH005Hf00000UHf00H005Hf001J=P00FUH40000
15iF001NEP000Uif00D0069f001RMP00009VUP04001VUVJFIYH30002J[D01000J[IZ]P000f[F00@0
06kFK]H000=^eP04001^eVkF0002K_H01000K_I^mP000fkg00@006kgK_L0009^m`03001Zmf[g0080
009^m`03001Zn000009Zn004001Zn6[h0002J_P01000J_QZn0000V[h00@006[iJ_T0009Zn@03001[
6@00009[6@05001W6FLI001W6@020002IaT01P00IaUW6@00IaT0009W6@03001[6@00009[6@08001[
6F/IJaT006/I001[6@80009[6@04001[6F/I0002JaT01000JaU[6@000f/i00@006li001_>@80009_
>008001_>6lh001_>000KcP0009_>005001c>7<hLcP00002LcP02000LcMc=`00LcL007<g0002LcL0
1@00LcL007<G00000g<G00@007<GLaL000=c5`04001c5g<G0002LaL01000LaMc5`000W<G00L006lG
KaM_5`00K_L00002K_L01000K_M^m`000V[g00<006[gJ_L00`000VKH00<006KH00000VKH00D006:h
001R^000009N^0<00003FYT005ZI00800007EWT0059i001>N@00BUT01P0000@in@00000af@800003
9IT0000000d000030AP0000000<000035IX0000000@000049O/00000:O/2000012hK000002hK0P00
00@^6`00000^6`800003:O/00000008Yn`8000059M/00000000MVP0?00001PbC000003fF0015eP80
000:CQH0058F001B5P00DSH005Hf0002ESH01`00ESH005Hf001F=P00009J=P0;001J=P00FUH005YF
001NEP00GWH00003HWD00`00IYD00002JYD01000K[A^]0000W;D00T007KdM_Afm000M_@007/C0000
0g/D00T007/DNaAk5000Na@007/d00000g/d00@007/eNcD0009g=@L00005McH007LfMcH00002LcL0
1@00LcMc=g<g00000W<g00@007<gLcL0009c>004001c>7<h0002KcP00`00KcP00002KcP01000KcQ_
>0000Vli00@006li001_>@80009_>@04001_>Fli0002KcT00`00KcT00002KcT00`00JcU[>@030002
KcT01`00KcU_>@00KcT006li0080009_>@03001_>@00009_>@04001_>Fli0002KcT01P00KcU_>@00
KcT0009_>003001_>6lh00<0009_>005001_>6lh001_>0020002KcP01000KcP006lh0P000VlH00<0
06lH00000VlH00H006lHKaP006lH0002KaP2000016lH001_60000VlH00<006[hJ_P00P000V[h00H0
06[hJ_P006Kh0002I_P300001V;I001Rf@00H]T0009Nf@0;001N^@00G[T005Zi001J^@00FYT00002
EYT01P00EYT005:J001BNP800009CWX004YJ001:FP00AUX004IJ00800007@SX0048j000n>P00?QX0
0P0000Dj6P00=QX003HJ00800003=QX0000000800003=Q/003HK00800003=Q/003HK00@00003>S/0
03Xk00800003?U/003iK00<0000;?U/0049l0012O000@W`0049l0016O00200001dJL0016W000BY`0
04ZL00T0000RC[`004jl001>_000C[`004jl001>_000C[`004jl001>_000D[`005:l001B_000D[`0
05:l001B_000D[/005:k0002D[/02`00D[/005:k001B^`00D]/005;K00000U;K010005;K001Bf`00
D]/005;K001Bf`00D]/005;K001Bfa0001eoo`03001oogoo06Ioo`00C7oo00<007ooOol087oo00<0
05KK00000UKK00L005KK001Ff`00E]/00002E]/200003eKK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`0:00002UKK001Ff`00E]/005KK001Ff`000UKK018005KK001Ff`00E]/005KK001Ff`00E[/0
05:k001B^`00D[/200008E:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/004jk001>V`00
CY/004jK001>V`00BY/004ZK001:N`0200000dIk000000050000149K000003Xk0P0000DanP000000
02gI00L000044?H00000:EH200003c5f000m]P00AMH004gf001>5P00DQH0058F001B=P020002ESH0
3000ESH005Hf001F=P00ESH005Hf001J=P<00005FUH005iFGUH00002GUH01@00GWH0069f00000V9f
00<006JF00000fJF0`000VZe00@006ZfJ[H000=ZeP04001^eVkF0003K]H01000K]H000000Vkf00@0
06kfK_H0009^m`80009^m`04001^mfkg0002J_L01@00K_M^mfkg00000V[h00<006[hJ_P00`000V[h
00@006[hJ_P0009Zn004001Zn@000002J_T01000JaU[6@000V/I00@006LIIaT0009[6@03001W6@00
009W6@04001W6@00IaT20002JaT01000JaU[6@000V/I00@006/I0000009[6@07001[6F/I001[6@00
JaT00P000V/I00D006/iJcU[>@00009_>@04001_>Fli0002KcP01000KcQ_>0000Vlh00H006lhKcQ_
>000LcP20003LcP01000LcMc=`000W<g00P007<gLcL007<g001c5`000g<G00D007<G001c5`00009c
5`04001c5g<G0002LaL01000LaMc5g<G0P0000E_5`00KaM_5`00009^m`800004K_L006kg0002J_L0
1P00J_MZm`00J]P0009Vf008001Vf6KH001Vf000H[P0009R^0<00005G[T005ZI001JV@0200002eIi
001BN@00CWT004YI001:F@00AST0100000@en@00000Y^@P000030=L0002f00X000074GX00000000M
^`008M/00`0000@Yn`00000Z6`800004;Q/00000;Q/2000012hK000002gk100000<Yn`009M/01000
00<MVP0000000P0000<5600000001`0000T04@00000003fF0015eP00BOH00P0000QB5P00DQH0058f
001F=P000UHf00<005Hf00000UHf00l005Hf001J=P00FSH005YF001JEP00GUH005if00000f9e0`00
0VZE00@006jdK[@0009be009001fm7KdM_@007Kd001k4`0000=k5009001k57/DNa@007/D001k=000
00=k=0P000=g=P800009McH007LfMcH007<g001g=`00009c=`04001c=g<g0002LcL01@00LcQc>000
LcP00P000Vlh00<006lhKcP00`000Vlh00@006liKcT0009_>@04001_>Fli0002KcT01000KcT006li
0P000Vli00<006li00000V/i00@006liKcT0009_>@04001_>@00KcT200001Fli001_>Fli00000Vli
0`000Vli00D006liKcT006li0080009_>@03001_>000009_>004001_>6lh0002KcP01P00KcQ_>000
KcP0009_>006001_>6lh001_>0000VlH00<006lHKaP00`000VlH00<006lH00000VlH00@006lHKaP0
009_6003001_6000009Zn005001Zn000J_P00002J_P00`00I_QVn003000016KI001RfF;I0P000V;I
00L005kI001N^@00G[T00002F[T01000F[T005ZI2`0000=>NP00BUX00P0000E6FP00AUX0048j0080
0092>P800003?QX003XJ00800005=QX003HJ000f6P0200000cHJ0000000200000cHK000f6`020000
0cHK000j>`0400001CXk000j>`00?U/00P0000<nF`0000000`0000]2O000@W`0049l0016O000AW`0
04JL0080000;BY`004ZL001:W000BY`004ZL001:W00<000074jl001>_000C[`004jl001B_000D[`0
05:l001B_000D[`005:l001B^`00D[/005:k001B^`000U:k00@005:k001BfaD0000?D]/005;KD]/0
05;K001Bf`00D]/005;K001Bf`0001eoo`03001oogoo06Ioo`00C7oo00<007ooOol08Goo00<005KK
00000UKK00P005KK001Ff`00E]/005KK0P0000MFf`00E]/005KK001Ff`0800002UKK001Ff`00E]/0
05KK001Ff`000UKK03P005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001F^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/004jk001>V`00
CY/004jK0P0000e:V`00BY/004Yk001:N`00AW/0049K0012F`0500000cXk000f6P0200000bgJ0000
0003000011UH000001TG1P0000DaMP00000004GF00<0000ECQH0058F001B5P00DSH005Hf001F=P00
ESH005Hf001F=P00ESH005Hf00<00004FUH005YF0002GUH02000GUINEP00GWH0069f0002HWH00`00
IYH00003IYH01000J[EZ]@000VZe00<006Zf00000V[F0P000fkF00P006kFK]H006kF001^mP000Vkf
00<006kfK_H00P0000=^m`00K_L00Vkg00<006kgK_L00`000fkg00@006[hJ_P0009Zn004001Zn6[h
0002J_P01000J_QZn0000V[h00@006[iJ_T0009Zn@07001[6F/I001[6@00IaT00P000V/I00L006LI
IaT006LI001W6@020002JaT00`00JaT00003JaT01P00JaU[6@00JaT0009[6@04001[6F/I0002JaT0
1000JaU[6@000V/I00D006/iJcT006li0080009_>@05001_>6lh001_>0020003KcP01@00KcQ_>6lh
00000W<h00@007<hLcP0009c=`05001c=g<gLcL00002LcL01000LaMc5`0017<G00@007<GLaL0009c
5`05001c5`00LaL00002LaL01000LaMc5`000VlG00@006lGKaL0009^m`04001^mfkg0002K_L00`00
J_MZm`030002J]P00`00I]P00002I]P00`00I]P00002H[P3000015jh001N^@000UZI00T005ZI0000
05Ii001BN@00CWT00P0000E:F@00AST0048J00@00004<MT000009IT300000`dH0000000:00000`Di
0000000200000aFJ00000004000012Gk000002Wk0P0000@^6`00000^6`800004;Q/00000;Q/20000
0bWk00000002000012GK0000026j0`0000<EN@0000002P0000@04@00000aE@80000>AMH004Wf001>
5P00DQH0058F001B=P00ESH0009F=P0A001F=P00ESH005Hf001J=P00FSH005YF001JEP00GUH00002
GWH01P00HWERM@00IYD0009ZU@05001^]6jd001be0020003M_@01@00M_@007/C00000g/D00H007/D
NaAk5000Na@70002NcD01@00McD007Le00000gLf00@007LfMcH000=g=P04001g=gLg0002LcL01@00
LcL007<g00000W<g00H007<hLcP007<h0002KcP01000KcQ_>0000Vlh00L006lhKcP006li001_>@02
0002KcT01000KcU_>@000Vli00<006li00000Vli00<006liKcT00`000Vli00@006liKcT0009_>@03
001_>@00009_>@03001_>@00009_>@04001_>Fli0002KcT01P00KcU_>@00KcT0009_>@03001_>6lh
00<0009_>004001_>6lh0002KcP01P00KcQ_>000KcP0009_>006001_>6lh001_60000VlH00H006lH
KaP006lH0002KaP30002KaP01000KaQ_60000VlH0`0000MZn000J_QZn000J_P00002I_P01@00I_P0
06KI00000V;I00T006;I001Rf@00G]T005ji00000Uji1`0000UFV@00EYX005:J001BNP00CWX01`00
00Y6FP000012>P00@SX0048j000n>P800003>QX003XJ00800005=QX003HJ000f6P0200000cHK0000
000200000cHK000f6`0200000cXk000j>`0400001CXk000nF`00?U/00P000T9K00<0049l00000P00
00i2O0000016O000AW`004JL0016W000BY`004ZL0P0000Y:W000BY`004ZL001>_000C[`0009>_004
001>_000C[`V000055;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K0002D]/02`00
D]/005;K001Bf`00D]/005;K00007Goo00<007ooOol0IWoo001<Ool00`00Oomoo`0ROol03000E]/0
05KK001Ff`00E]/005KK001Ff`T00008E]/005KK001Ff`00E]/0009Ff`0C001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK00000UKK02@005KK001Ff`00E]/005KK001Ff`00E[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/200002Djk001>V`00CY/004jK
001>V`0200001dZK001:N`00BW/004Ik00800004@U/00000?U/500000cHJ000anP0400000bFI0000
0005000010cE000002UF100000=5eP00BOH01@0000eB5P00DSH005Hf001F=P00ESH005Hf001F=P05
00001UXf001JEP00FUH0009NEP08001NEUiF001NMP00HWH0009RMP03001VUP0000=VUP04001Z]FZe
0002J[D00`00J[IZ]P020002K]D01000K]I^eP000fkF0P0000E^mP00K_I^mP00009^mP05001^mfkg
K_L00002K_L01000K_M^m`000Vkg00P006kgK_M^m`00J_P006[h0P000V[h00@006[hJ_P0009Zn004
001Zn0000002J_T01000J_UZn@000V/I00@006/I0000009[6@03001[6@00009W6@06001W6FLI001[
6@000V/I00@006/IJaT0009[6@04001[6@000002JaT01`00JaU[6@00JaT006/I0080009[6@05001[
6F/IJaT00002JcT01000KcU_>@000Vli00@006lhKcP0009_>005001_>6lhKcP00002KcP01000LcQc
>0000W<h00D007<g001c=`00009c=`04001c=g<g0003LaL01@00LaMc5g<G00000W<G00D007<GLaMc
5`00009c5`04001c5g<G0002LaL01000KaM_5`000flG0`000Vkg00@006kgK_L0009Zm`03001Zm`00
009Zf006001Vf6KH001Vf0000VKH0`0000AR^000G[P0009N^@04001JV@00FYT200002EIi001BN@00
CWT004YI001:F@0200000d8J000n6P020000137I000002FI2P0000@0e`000000m`H000035GX00000
00@000049O/00000:O/300000bhK000^6`0200001bhK00000000;Q/002gk00<0008Uf`8000059M/0
0000000IVP0600000`2f0000000400000`0A0000000300003TGF0019mP00CQH0058F001B5P00DSH0
05Hf0002ESH03`00ESH005Hf001F=P00FSH005Xf001JEP00FUH00002GUH01000GWH0069e0P0000EV
U@00JYEZU@00009^]005001be000M]<00002M_@01@00M_@007/C00000W/D1`000g/d00D007/d001k
=000009k=@800003McD007Lf009g=P05001g=WLfMcH00002McH01000McMg=`000g<g00@007<gLcL0
009c=`04001c>7<h0002LcP00`00KcP00002KcP01000KcQ_>0000Vlh00@006liKcT0009_>@07001_
>Fli001_>@00KcT00P000Vli00<006li00000Vli00@006liKcT0009_>@04001_>@00KcT20002KcT0
0`00KcT00002KcT30002KcT01000KcU_>@000Vli00H006liKcT006li0002KcP01000KcQ_>0000Vlh
00@006lh001_>080009_>003001_>6lh00<0009_>003001_66lH00<0009_6003001_6000009_6004
001_66lH0002KaP00`00KaP00002KaP01@00J_P006[h00000V[h00<006[hJ_P00`0000]Vn000I]UV
f@00H]T006;I001Rf@00009Nf@03001N^@000080000EF[T005Zi001JV@00EYT005JJ001BVP00DWX0
04ij001>NP00CWX004YJ00H00007@SX0048j000n>P00?QX00P0000<j6P0000000P0000<f6P00=QX0
0P0000<f6`00=Q/0100000<f6`00=Q/00P0000<j>`00>S/010000SiK0P0000LnF`00@U/0049l0012
O0050000=DIl000004JL0016W000BY`004ZL001:W000BY`004ZL001:W000C[`004jl001>_000C[`0
04jl001>_000C[`004jl001>_000D[`005:l001B_000D[`005:l001B^`00D[/005:k00000U:k01d0
05:k001B^`00D[/005:k001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00009B
f`0>001Bfe;K001Bf`00D]/005;K001Bf`00D]/001eoo`03001oogoo06Eoo`00C7oo00<007ooOol0
8Woo00@005KK001Ff`P00009E]/00000E]/005KK001Ff`00009Ff`0A001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/00002E]/02`00E]/005KK001Ff`00E]/005KK00000UKK00@005KK001Ff`80
000UE]/005Jk001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00C[/004jK001>V`00CY/00P0000E:V`00BY/004Yk00800006AW/00000@U/0049K0P0000@n>`00
000j>`800005<OX00000000QV@08000010cE000002UF0`0000Pm]P000019mP00COH004hF3`0000QF
=P00ESH005Xf001JEP000UYF00<005iF00000UiF00<005if00000V9f00<0069f00000VJF00@006JF
0000009Z]@04001Z]FZe0002J[H01@00K]E^eFkE00000VkF00D006kFK]I^eP00009^mP04001^mVkf
0002K_H01@00K_M^mfkg00000Vkg00@006kgK_L0009^m`05001^mfkgK_L00002J_P01000J_QZn000
0V[h00@006[hJ_P0009Zn006001Zn6[h001Zn@000f[i00H006/IJaT006/I0002JaT01`00JaU[6@00
IaT006LI0080009[6@04001[6F/I0002JaT01000JaU[6@000V/I00<006/I00000V/I00@006/IJaT0
009[6@04001[6F/I0002JaT01000JcT000000Vli00D006liKcT006lh008000=_>008001_>6lh001_
>000KcP0009c>004001c>7<h0002LcL02000LcMc=`00LcL007<g0002LaL01P00LaMc5`00LaL0009c
5`04001c5g<G0002LaL02000LaMc5`00LaL007<G0002KaL01000KaM_5`000Vkg00H006kgK_L006kg
0002J_L01P00J_MZm`00J]P0009Vf003001Vf6KH00<00004H[P006:h0002G[P01P00G[T005ZI001J
V@80000;EWT0059i001>N@00BUT004YI0016>@0200000chJ0000000200000bVi0000000400000`TG
0000e`0:00000`eI00000002000011Vj0000027K0P0000@Un`00000Yn`<00003;Q/002hK00800007
;Q/00000000]n`00:O/00P0000<Uf`009M/00`0000DM^P000000015I00X000030140000000<0000>
AMH004Wf001>5P00DQH0058F001B=P00ESH0009F=P0?001F=P00ESH005Hf001J=P00FSH005YF001J
EP00009NEP06001NMP00001RM@000VJE00<006ZE00000Vjd00D007;D001fd`0000=fm0L00003Na<0
07/D009k5009001k=7/dNc@007/d001k=000009k=@09001g=GLeMcD007Lf001g=P00009g=P05001g
=P00McH00002McL01000LcMc=`000W<g00D007<gLcL007<h0080009c>003001_>6lh00800008KcP0
06lhKcP006lh001_>@80009_>@04001_>Fli0002KcT00`00KcT00002KcT00`00KcU_>@030002KcT0
1000KcU_>@000Vli00P006liKcT006li001_>@000Vli00@006liKcT0009_>@04001_>@00KcT20002
KcT00`00KcU_>@030002KcP01000KcQ_>0000Vlh00H006lhKcP006lh0002KcP01P00KcQ_>000KcP0
009_6006001_66lH001_60000VlH0`000VlH00@006lHKaP0009_60<0009Zn005001Zn000J_P00002
J_P00`00I_P00002I_P01`00I]T006;I001Rf@00009Rf@D00008G[T005Zi001J^@00FYT0009FV@06
001FVP00DYX0059j0P0000U>NP00CWX004YJ001:FP00AUX0100000M2>P00?SX003hJ000j6P020000
0cXJ0000000200000cHJ000f6P0200000cHK000f6`0400000cHK000j>`0200000cXk000j>`030000
0ciK000nF`020002@U/200001D9l0012O000AW`01@0001=6W000001:W000BY`004ZL001:W000BY`0
04ZL001>_000C[`00002C[`01P00C[`004jl001>_080000BC[`004jl001B_000D[`005:l001B_000
D[`005:k001B^`000U:k00`005:k001B^`00D[/005:k001B^`00D]/2000055;K001Bf`00D]/005;K
001Bf`00D]/005;K001Bf`00D]/005;K0002D]/02`00D]/005;K001Bf`00D]/005;K00007Goo00<0
07ooOol0IGoo001<Ool00`00Oomoo`03000POol3000025KK001Ff`00E]/005KK0002E]/200003UKK
001Ff`00E]/005KK001Ff`00E]/005KK0002E]/02`00E]/005KK001Ff`00E]/005KK00000UKK00h0
05KK001Ff`00E]/005KK001Ff`00E]/005KK0P0000]Ff`00E[/005:k001B^`00D[/005:k01<00009
C[/004jK001>V`00CY/004jK00800007BY/004Yk001:N`00AW/00P0000A2F`00000nF`800004>Q/0
0000=QX200000bgJ0000000300001AUH000000004?H00P0000<YEP0000000P0000<m]P00AMH00P00
01Q=mP00CQH0058F001B5P00DSH005Hf001F=P00ESH005Hf001F=P00ESH005Xf0002FUH00`00FUH0
0002GUH01@00GUH005if00000V9f00<0069f00000VJF0P0000EZ]@00J[EZ]@00009Z]@04001Z]VZf
0003K]D01000K]I^eP000fkF00@006kfK_H0009^mP05001^mP00K_H00002K_L01000K_M^mfkg0P00
00E^m`00K_M^m`00009^m`04001Zn6[h0002J_P01000J_QZn0000V[h00@006[h0000009Zn004001Z
nF[i0002J_T01000JaT000000V/I00H006/IJaT006/I0002IaT01P00JaU[6@00JaT000=[6@04001[
6@00JaT20002JaT01`00JaU[6@00JaT006/I0080009[6@05001[6F/IJaT00002JaT01000KaU_6@00
0Vli00@006liKcT0009_>004001_>6lh0003KcP01000KcQ_>0000W<h00@007<h000000=c=`04001c
=g<g0002LcL01P00LaMc5`00LaL0009c5`08001c5g<G001c5`00LaL0009c5`04001c5g<G0002LaL0
1000KaM_5`000VlG00@006kgK_L0009^m`03001^mfkg00<0009Zm`06001Zf6[H001Vf0000VKH00D0
06;H001R^000009R^005001N^000G[T00002FYT200001eJI001FN@00DWT004ii00800005BUT004Hi
00126P0200000cWi0000000200001BFI000000003AP02P0000<1600000000`0000<ENP0000001000
00@Uf`00000Yn`<00006:Q/00000;Q/002hK0`0000@Yn`00000Yn`8000039M/002GK008000048KX0
00006IX?00000bTe000mUP02000034Wf001>5P00DQH0058F001B=P00ESH0009F=P0=001F=P00ESH0
05Hf001J=P00FSH005YF00000UYF00<005iF00000P000V9e00H006JEIYD006ZE0002K[@90003Na<0
1@00Na@007/C00000g/D00<007/dNc@00W/d00@007/dNc@0009k=@09001g=GLeMcD007Lf001g=P00
009g=P05001g=P00McH00002McL01@00LcL007<g00000W<g00@007<gLcL0009c>003001c>000009_
>004001_>6lh0002KcP01000KcQ_>0000Vli00L006liKcT006li001_>@020002KcT00`00KcT00002
KcT01000KcU_>@000Vli00@006li001_>@80009_>@05001_>Fli001_>@030002KcT01000KcU_>@00
0Vli00H006liKcT006li0002KcT01000KcQ_>0000Vlh00@006lh001_>080009_>003001_>6lh00<0
009_>003001_>000009_6004001_66lH0002KaP00`00KaP00002KaP00`00KaP00002KaP01P00KaQ_
6000JaP0009Zn003001Zn000009Zn0<0009Vn007001Vn000I]T006;I00000V;I0`0000INf@00G[T0
05ji0002F[T04P00F[T005ZI001FV@00EYX005:J001BNP00CWX004ij001>NP800005BUX004IJ0016
FP0400001chj000n6P00>QX003XJ00800003>QX0000000800003=QX003HK00800003=Q/003HK00@0
0005>S/003Xk000j>`0200003CiK00000000?U/003iK0012F`00@W`0049l00800005AW`004Il0016
O00500000dZL001:W002000014ZL001:W0000TZL02<004jl001>_000C[`004jl001>_000C[`004jl
001>_000C[`005:l001B_000D[`005:l001B_000D[/005:k001B^`00009B^`08001B^`00D[/005:k
001B^`<0000DD]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0009Bf`0;001Bf`00
D]/005;K001Bf`00D]/0000MOol00`00Oomoo`1UOol004aoo`<002=oo`03001Ff`00009Ff`08001F
f`00E]/005KK001Ff`800006E]/005KK001Ff`000UKK00T005KK001Ff`00E]/005KK00000UKK01@0
05KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK4@0001=B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/004jk001>^`0;00001dZK001:N`00BW/004Ik00800003@U/0049K00800004
?S/00000=Q/200000c7j0000000200000aUH000IF00300000a3f0000000300001C5f000m]P00AMH0
0P0001I=mP00CQH0058F001B5P00DSH005Hf001F=P00ESH005Hf001F=P00ESH0009J=P05001JEP00
FUH00002GUH01@00GUH005if00000V9f00<0069f00000VJF00L006ZeJ[EZ]@00J[D00002J[D01000
J[H000000fkE00@006kFK]H0009^eP8000=^mP03001^mVkf00800003K_H006kg009^m`04001^mfkg
0002K_L01000K_M^m`000fkg0P0000E^n000J_QZn000009Zn004001Zn6[h0002J_P00`00J_P00002
J_T00`00J_UZn@020002JaT00`00JaT00002JaT01000JaT006LI0P000V/I00@006/IJaT0009[6@04
001[6@000002JaT01`00JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT01000JaT000000VlI
00D006liKcT006li0080009_>006001_>6lhKcP006lh0P000flh00@007<hLcP0009c>004001c=g<g
0002LcL01@00LcMc=g<g00000W<G00D007<GLaMc5`00009c5`05001c5`00LaL00002LaL01000LaMc
5`000W<G00X006lGKaL006lG001^m`00K_L0009^m`04001^mfkg0002J_L00`00J_L00002J]P00`00
I]QVf00300002F;H001R^6:h001R^000G[P00002G[T03`00FYT00000EYT005Ii001BN@00CWT004YI
001:F@0200000d8J000n6P020000137I000002FI200000<0m`000000200000DANP00000001Vj0080
00078M/00000000Yn`00:O/00`0000@Z6`00000^6`800004;Q/00000:O/200000bWk000Uf`020000
127K000001fj1@0000<0m`000;H01`0000@<T`00000mUP80000<BOH004hF001B5P00DQH0058f001F
=P000UHf00/005Hf001F=P00ESH005Xf001J=P00009JEP07001JEP00GUH005iF00000V9e00<006JE
IYD0200000=fd`00M_@00WKd00T007/CNa=k4`00Na@007/C00000g/D0P000g/d00P007/dNc@007/e
001k=@000WLe00D007Lf001g=P0000=g=P04001g=WLf0002McL01@00LcL007<g00000W<g00@007<g
LcL0009c>003001c>7<h00<000=_>004001_>000KcP20002KcT01000KcU_>@000Vli00<006li0000
0Vli00<006liKcT00`000Vli00@006liKcT0009_>@04001_>Fli0002KcT01@00KcT006li00000Vli
00L006liKcT006li001_>@020002KcT00`00KcU_>@030002KcP01000KcQ_>0000Vlh00<006lh0000
0Vlh00H006lhKcP006lh0002KcP00`00KcQ_>002000016lH001_60000VlH00<006lH00000VlH00@0
06lHKaP0009_60<0009[6005001Zn000J_P00002J_P00`00I_P00002I_P01@00I_P006KI00000V;I
0`0000IRf@00G]T005ji0002G[T06000F[T005Zi001JV@00EYT005JJ001BVP00DWX004ij001>NP00
CWX004YJ001:FP800003AUX0048j00@00005?QX003XJ000j6P0200000cXJ000j6P0400000cHK000f
6`0200000cHK000j>`0400001CXk000j>`00>S/00P000SiK0P0000TnF`00@U/0049l0012O000@W`0
0P0000M6O000AW`004JL0016W00700009TZL001:W000BY`004jl001>_000C[`004jl001>_000C[`0
04jl001>_000C[`005:l001B_000D[`005:l001B_000D[/005:k0002D[/07`00D[/005:k001B^`00
D[/005:k001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00009Bf`0>001Bfe;K
001Bf`00D]/005;K001Bf`00D]/001aoo`03001oogoo06Eoo`00C7oo00<007ooOol097oo01D005KK
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK00000UKK01@005KK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`00E]/005KK2P0000EFf`00E]/005KK0080000:D[/005:k001B^`00D[/0
05:k0002D[/04000D[/005:k001B^`00D[/005:k001B^`00D[/004jk0P0000U>V`00CY/004jK001>
V`00BY/01`0000=6N`00AW/00P0000=2F`00?U/00P0000@j6`00000anP800003;MX0026I00`00009
<GH003ff0015eP00BOH004gf0080000>DQH0058F001B=P00ESH005Hf001F=P00ESH0009F=P09001F
=P00FSH005YF001JEP00009NEP03001NEP00009NMP05001RMP00HWH00002IYH01@00J[EZ]FZe0000
0VZe00<006ZeJ[D00P0000=^e@00K]D00VkE00<006kFK]H00P000Vkf00@006kfK_H0009^mP04001^
mVkf0003K_L01000K_M^m`000Vkg00@006kgK_L000=^m`04001^n6kh0002J_P01@00J_QZn000J_P0
0P000V[h00X006[hJ_P006[i001Zn@00JaT0009[6@07001[6F/I001[6@00JaT00P000V/I00@006/I
JaT0009[6@06001[6F/I001[6@000V/I00@006/IJaT0009[6@03001[6@00009[6@05001[6F/IJaT0
0002JaT01000JaU[6@000VlI00@006liKcT0009_>@04001_>6lh0003KcP01000KcQ_>0000Vlh00@0
07<hLcP0009c>008001c=g<g001c=`00LcL0009c=`04001c5g<G0004LaL01000LaMc5`000W<G00P0
07<GLaL007<G001c5`000W<G00@006lGKaL0009^m`04001^mfkg0002K_L30002J_L01P00J_MZm`00
J]P0009Vf003001Vf000009Rf005001R^000H[P00002G[P01P00G[T005ZI001JV@80000;EWT0059i
001>N@00BUT004YI0016>@0200000chJ000in@0900000`TG0000000800000`Dh0000000200000aEj
0000000400001BGK00000000:O/00P0000@Z6`00000^6`800004;Q/00000:O/200001RWk000002GK
000Uf`<000047KX000005GT<00000`bC0000000200003DGF000004hF001B5P00DQH0058f001F=P00
009F=P07001F=P00ESH005Hf00000UXf00H005Xf001JEP00FUH;0002JYD01000K[A^]0000WKC00D0
07KdM_Afm00000=k4`03001k5000009k4`05001k5000Nc<00003Nc@02000NcAk=000NcD007/e0003
McD01@00McIg=WLf00000WLf00D007LfMcIg=P00009g=`04001c=g<g0002LcL01000LcL000000W<h
00@007<hLcP0009_>004001_>6lh0002KcP01000KcQ_>0000Vli00@006li001_>@80009_>@03001_
>@00009_>@04001_>Fli0002KcT01000KcT006li0P000Vli00P006liKcT006li001_>@000Vli00@0
06liKcT0009_>@03001_>@00009_>@04001_>Fli0002KcT01`00KcQ_>000KcP006lh0080009_>003
001_>000009_>006001_>6lh001_>0000Vlh00@006lHKaP0009_6008001_6000001_6000KaP0009_
6006001_66lH001[60000V/H00<006[h00000V[h0`000VKh00L006Kh001Vn000I]T00002H]T01@00
H]T006;I00000UkI01h005ji001N^@00F[T005Zi001JV@00EYT005JJ001BVP00DWX004ij001>NP00
CWX004YJ001:FP00AUX200000d8j0012>P0400001CXJ000j6P00>QX00P0000<j6P00>QX0100000<f
6`00=Q/00P0000<j>`00>S/00P0000@j>`00>S/j>`800005?U/003iK000nF`0600001d9l0012O000
AW`004Il00800009AY`004JL001:W000BY`004ZL00T0000:C[`004jlC[`004jl001>_000C[`20000
4Tjl001>_000D[`005:l001B_000D[`005:l001B^`00D[/0009B^`0<001B^`00D[/005:k001B^`00
D[/005;K0P00015Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K010001]oo`<006Ioo`00
C7oo00<007ooOol097oo00<005KK00000UKK01`005KK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK001Ff`X0000:E]/005KK001Ff`00E]/005KK0002E]/01000E]/0
05KK0P0002EB^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
C[/004jk001>V`00CY/004jK001>V`0300000dYk0016N`0600001T9K000003iK000n>`800004=Q/0
0000;MX700001A4G000000003=D00`0000/aMP00000004GF0019mP00COH004hF00800008DQH0058f
001F=P00ESH0009F=P0=001F=P00ESH005Hf001J=P00FUH005YF00000UiF00P005iFGUH005if001R
MP000V9f0`000fZe00@006ZeJ[D0009Z]@800003K]D006kE009^e@04001^eVkF0003K_H01000K_I^
mP000Vkf00D006kfK_I^mP00009^m`05001^m`00K_L00002K_L01000K_M^m`000Vkg00D006khK_Q^
n000009Zn004001Zn6[h0002JaP00`00J_P00002J_P01000J_UZn@000f/I00<006/I00000V/I00H0
06/IJaT006/I0002JaT01000JaU[6@000V/I00@006/I0000009[6@07001[6F/I001[6@00JaT00P00
0V/I00@006/IJaT0009[6@04001[6@000002JaT01000KaU_6@000Vli00@006liKcT0009_>003001_
>6lh0080009_>008001_>6lh001c>000KcP0009c>004001c=g<g0002LcL02000LcMc=`00LaL007<G
0003LaL01000LaMc5`000g<G00@007<GLaL0009c5`04001c5g<G0002KaL01000K_M^m`000Vkg00@0
06kgK_L0009Zm`03001Zm`00009Zm`03001Zf6[H00<0009Vf005001Rf000H[P00002H[P01@00G[P0
05ji00000UZI0P0000MFV@00EWT0059i001>N@0200001DYI0016>@00@QX00P0000<in@00<MT01@00
00<IF00000001@0000<0m`000?P01P0000<ANP000000100000DQf`00000002Gk00800004:O/00000
:Q/2000012hK000002hK0P0000LYn`00000002GK000Uf`02000011fj000001VJ3@0000P<T`00000i
UP00AMH004Wf0P0000QB5P00DQH0058f001F=P000UHf00<005Hf00000UHf00H005Hf001J=P00FSH7
00000eiF001RM@02HWD00`00IYD00002JYD01000K[A^]0000gKC00@007KdM_@000Ak4`09001k4g/C
Na<007/D001k<`0000=k=004001k=7/dNc@200000g/e001g=@02McD02@00McIg=WLf001g=P00McH0
0002McH01000McMg=`000g<g00@007<gLcL0009c=`03001c>000009c>004001_>6lh0002KcP01000
KcP000000Vlh00@006liKcT0009_>@03001_>@00009_>@03001_>Fli00<0009_>@04001_>Fli0002
KcT01000KcU_>@000Vli00@006li001_>@800008KcT006liKcT006li001_>@80009_>@03001_>Fli
00<0009_>@04001_>6lh0002KcP00`00KcP00002KcP00`00KcQ_>002000016lh001_>0000Vlh0`00
0VlH00@006lHKaP0009_6003001_6000009_6004001_6000KaP20002JaP00`00JaP00002J_P30000
2F[h001Vn6Kh001Vn000I_P00002I]T300009V;I001RfF;I001Nf@00G[T005ji001J^@00F[T005ZI
001FV@00EYX005:J001BNP00CWX004ij001>NP00BUX004YJ0016FP00AUX200000d8j0012>P040000
1CXJ000j6P00>QX00P0000<j6P00>Q/0100000<f6`00=Q/00P0000Tj>`00000003Xk000j>`00>S/0
0P0000LnF`00?U/003iK0012F`030000349l000004Il0016O000AW`004JL0016W0800008BY`004ZL
001:W000BY`0009:W003001>W00000`0000DC[`004jl001B_000D[`005:l001B_000D[`005:k001B
^`00D[/0009B^`08001B^`00D[/005:k001B^aD0000?D]/005;KD]/005;K001Bf`00D]/005;K001B
f`0001Qoo`<0009oo`03001oogoo06Aoo`00C7oo00<007ooOol09Goo00<005KK00000UKK014005KK
000005KK001Ff`00E]/005KK001Ff`00E]/005KK00X0000:E]/005KK001Ff`00E]/005KK0002E]/0
3P00E]/005KK001Ff`00E]/005KK001Ff`00E]/200002U:k001B^`00D[/005:k001B^`000U:k0100
05:k001B^`00D[/005:k001B^`00D[/005:k001>^`800009CY/004jK001>V`00CY/004ZK00800006
BW/00000AW/004Ik100000I2F`00000n>`00>Q/200000c7j0000000300000aUH0000000400000`cE
00000005000084GF0019mP00COH004hF001B5P00DQH0058f001F=P00ESH005Hf001F=P00ESH005Hf
001J=P00FUH005YF0002GUH02000GUINEP00GWH0069f0002HWH30003J[D01000J[EZ]@000VZe00@0
06kEK]D000=^e@04001^eVkF0003K_H02000K_I^mP00K_H006kf0002K_H01000K_M^mfkg0P0000E^
m`00K_M^m`00009^m`05001^m`00K_L00002K_P01@00J_QZn000J_P00P000V/H00L006[hJ_P006[h
001Zn@020003JaT01`00JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT01000JaU[6@000V/I
00<006/I00000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01000JaU[6@000V/I00X006/IJaT0
06lI001_>@00KcT0009_>@05001_>000KcP00002KcP01000KcQ_>0000Vlh00@006lhKcP0009c>004
001c=`000003LcL01000LcMc=`000W<G00T007<GLaMc5`00LaL007<G00000W<G00@007<GLaL0009c
5`08001c5g<G001_5`00KaL0009^m`03001^m`00009^m`04001Zmf[g0002J_L00`00J_L00002J]P0
0`00I]P00002I]P00`00H]P00002H[P01@00H[P005jh00000Uji3P0000I:F@0000126P00?QX20000
1S7I000002Vi000MN@D000032AP0000000L000032ET00000008000045IX000007M/200001BGK0000
0000:O/00P0000@Z6`00000^6`<00003;Q/002Wk00800003:O/0000000<000048M/000006IX30000
0`eI0000m`08000010bC000003VF0`0000a9mP00CQH0058F001B5P00DSH005Hf0002ESH01000ESH0
05Hf2@0000IJEP00GUH005iF0003HWD00`00IYD00002JYD01000K[A^]0000gKC00D007Kd001jl`00
00=k4`07001k4g/CNa<007/D00000W/c00D007/d001k=000009k=009001k=G/eNcD007Le001k=@00
009g=P05001g=P00McH00002McH01@00McL007Lg00000W<g00@007<gLcL0009c=`03001c>7<h0080
0005LcP006lhKcP00002KcP01000KcQ_>0000Vlh00@006li001_>@80009_>@03001_>@00009_>@04
001_>Fli0002KcT01000KcT006li0P000Vli00@006liKcT0009_>@05001_>@00KcT00002KcT01P00
KcU_>@00KcT0009_>@04001_>Fli0002KcT01`00KcU_>@00KcP006lh0080009_>003001_>000009_
>006001_>6lh001_>0000Vlh00@006lHKaP0009_6004001_6000KaP200001FlH001_66lH00000VlH
00<006lH00000V/H00<006/H00000V[h00<006[h00000V[h00D006Kh001Vn000009Vn0<0000CH]T0
06;IH]T006;I001Nf@00G[T005ji001J^@00F[T005ZI00000UJI00H005JJ001BVP00DWX200003Dij
001>NP00BUX004YJ0016FP00AUX0048j00800003@SX003hj00@00005>QX003XJ000j6P0200000cXK
000j6`0200001cHK000f6`00>S/003Xk00H00005>S/003iK000nF`0200001CiK0012F`00@W/01P00
00]6O000AW`004JL0016W000BY`004ZL0080009:W00B001:W000BY`004jL001>_000C[`004jl001>
_000C[`004jl8P0001ABf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`000U;K00/0
05;K001Bf`00D]/005;K001Bf`0001eoo`03001oogoo06Aoo`00C7oo00<007ooOol09Woo00H005KK
001Ff`00E]/200001EKK001Ff`00E]/0200000YFf`00E]/005KK001Ff`00E]/0009Ff`0G001Ff`00
E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00002E]/200007e:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001>^`00C[/004jK00800005CY/0
04jK001:V`0200001DYk0016N`00AW/00P0000=2F`00@U/00P0000HnF`00000j6`00=Q/300000bFj
000QV@0?000084GF0019mP00COH004hF001B5P00DQH0058f001F=P00ESH005Hf001F=P00ESH005Hf
001J=P00FUH005YF0002GUH02000GUINEP00GWH0069f0002HWH01000IYEVU@000VZe00@006ZeJ[D0
009Z]@05001^eFkEK]D00002K]D01@00K]H007;e00000fkf00<006kfK_H00P0000=^mP00K_H00Vkf
00@006kgK_L0009^m`05001^mfkgK_L00002K_L01000K_M^m`000Vkh00D006[hJ_QZn000009[6003
001[6000009Zn004001Zn6[h0002JaP01000JaU[6@000V/I00@006/IJaT0009[6@03001[6@0000=[
6@04001[6@00JaT20002JaT01`00JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT01000JaT0
00000V/I00@006/IJaT0009_6@04001_>Fli0002KcT01000KcQ_>0000flh00@006lhKcP0009_>005
001_>6lhKcP00002LcP01000LcQc>0000W<g00@007<gLcL000=c5`05001c5g<GLaL00002LaL02000
LaMc5`00LaL007<G0002LaL01000LaMc5`000VlG00@006kgK_L0009^m`800004K_L006[g0002J_L0
0`00J_MZm`030002I]P00`00I]P00002H]P01@00H[P006:h00000Ujh0`0000aJV@00001FV@00EWT0
059i001>N@00CUT600000chJ000in@0200000bgI0000000=00000`DH0000000300000a5j00000005
000012GK000002Gk0P0000@Yn`00000Z6`800007;Q/00000000Yn`00:O/00`0000@Uf`00000Qf`80
00046IX000005GT;00000`bC000Y=@0200003DGF00000000CQH0058F001B5P00DSH005Hf00P00003
ESH0000000<00006FUH005YF001NEP000UiF00H0069eHWD006JE0002JYD01000K[A^]0000gKC00D0
07Kd001jl`0000=k4`07001k4g/CNa<007/D00000W/c00D007/d001k=000009k=009001k=G/eNcD0
07Le001k=@0000=g=P04001g=WLf0003McH01000McMg=`000W<g00@007<g0000009c=`04001c>7<h
0002LcP01000KcQ_>0000Vlh00@006lhKcP0009_>006001_>Fli001_>@000Vli00<006liKcT00`00
0Vli00@006liKcT0009_>@04001_>Fli0002KcT01000KcT006li0P000Vli00H006li001_>@00KcT2
0002KcT00`00KcT00002KcT01000KcU_>@000Vli00H006lhKcP006lh0002KcP00`00KcQ_>0030002
KcP00`00KcQ_>0030002KaP01000KaQ_60000VlH00<006lH00000VlH00@006lH001_6080009_6003
001[6000009[60<00007J_P006[hJ_P006Kh00000VKh0`0000mVf@00H]URf@00H]T006;I001Nf@00
G[T005ji00000UZi00@005Zi001JV@/00003CWX004ij00800009BUX004IJ0016FP00@SX0048j0080
0003?SX003hj00@00005>QX003XJ000j6P0200000cXK0000000200001CHK000j>`00>S/00P0000@j
>`00>S/j>`800007?U/003iK000nF`00?U/00P0000E2N`00@W`0049l00<0000AAW`00000AY`004JL
001:W000BY`004ZL001:W000BY`00002BY`200007Tjl001>_000C[`004jl001>_000C[`004jl001>
_000D[`005:l001B_000D[`005:k001B^`00D[/0009B^`0M001B^`00D[/005:k001B^`00D[/005:k
001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/00002D]/00`00D]/00002D]/02`00D]/005;K
001Bf`00D]/005;K000077oo00<007ooOol0I7oo001;Ool00`00Oomoo`0WOol01000E]/005KK2@00
00QFf`00E]/005KK001Ff`000UKK01<005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0
0002E]/0;P00E]/005KK001Ff`00E]/005KK001Ff`00E]/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00C[/004jk0P0000M>V`00CY/004jK001:V`02
000024Yk000004Ik0016N`00@U/2000013iK000003hk0P0000@f6`00000]fP`000033;D000000080
000O?KH00000BOH004gf001>5P00DQH0058F001B=P00ESH005Hf001F=P00ESH005Hf001F=P00FSH0
05YF00000UYF00<005iF00000UiF00<005if00000V9f00<0069f00000VJE00@006ZeJ[D0009Z]@04
001Z]@000003K]D02000K]E^e@00K]H007;e0003K_H01000K_I^mP000Vkf00D006kfK_I^mP00009^
m`05001^mfkgK_L00002K_L01000K_M^m`000Vkg00D006khK_Q^n000009Zn004001[66/H0002JaP0
1000J_P006[h0P000V/H00P006/IJaU[6@00JaT006/I0P000V/I00@006/IJaT0009[6@04001[6@00
0002JaT01`00JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT01000JaT000000V/I00L006/I
JaT006/I001_6@020003KcT01000KcT006lh0P0016lh00L006lh001_>000KcP00002KcP01000LcQc
>0000W<h00P007<gLcL007<g001c5`000g<G00@007<GLaL000=c5`04001c5g<G0002LaL01000LaMc
5`000W<G00@006lGKaL0009^m`04001^mfkg0002K_L01P00J_MZm`00J_L0009Zm`06001Vf6KH001V
f0000VKH00D006;H001R^000009R^0<00003G[T005ZI0080000=EYT005Ii001BN@00CWT004iI001:
FP00ASX0100000<in@00<MT01@0000<IF00000000`0000<960000?L01`0000<=F@000000100000DM
f`00000002Gk00800007:O/00000000Z6`00;Q/00`0000@Yn`00000Yn`8000039O/0000000<00004
7KX000005GX>00001RTe000004GF0019mP<00003DQH0000000D0009F=P03001F=P0000@00008ESH0
05Xf001JEP00FUH0009NEP03001NEP00009RM@07001VUFJE001ZU@00K[@00P000gKC00D007Kd001j
l`0000=k4`03001k4g/C009k4`0=001k<g/cNc<007/d001k=000Nc@007/d00000W/e00D007Le001k
=@0000=g=P05001g=WLfMcH00002McH01@00McMg=gLg00000W<g00@007<gLcL0009c=`<000=c>007
001_>000KcP006lh00000Vlh00@006lh001_>@80009_>@03001_>@00009_>@04001_>Fli0002KcT0
1000KcT006li0P000Vli00@006liKcT0009_>@03001_>@00009_>@04001_>@00KcT20002KcT00`00
KcT00002KcT2000026li001_>Fli001_>@00KcP20002KcP00`00KcP00002KcP01000KcQ_>0000Vlh
00<006lh00000VlH00L006lHKaP006lH001_60020002KaP00`00KaP00002KaP00`00KaP00002KaP0
0`00JaP00002JaP00`00J_P00002J_P01@00J_P006Kh00000VKh00D006Ki001Vf@00009Rf@09001R
f@00H]T005kI001N^@00009N^@03001J^@0000@00009EYT005JJ001BVP00DYX0059j00L0000:BUX0
0000AUX0048j0012>P00@SX200000chj000n>P0400001CXJ000j6P00>Q/00P0000<j6`0000000P00
00/j>`00>S/003Xk000j>`00>S/003iK00800007?U/003iK000nF`00@U/00P0000E2O000@W`004Il
00D00003AY`004JL00800004BY`004ZL0002BY`04P00BY`004ZL001>W000C[`004jl001>_000C[`0
04jl001>_080000>C[`005:l001B_000D[`005:l001B^`00D[/0009B^`09001B^`00D[/005:k001B
^`00009B^`03001B^`000080000DD]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0
009Bf`0;001Bf`00D]/005;K001Bf`00D]/0000MOol00`00Oomoo`1SOol004]oo`03001oogoo02Qo
o`<00003E]/005KK00800004E]/005KK0002E]/04@00E]/005KK001Ff`00E]/005KK001Ff`00E]/0
05KK00000UKK00T005KK001Ff`00E]/005KK00000UKK00@005KK001Ff`80000WE]/005KK001Ff`00
E]/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
C[/004jk00800007CY/004jK001>V`00BY/00P0000E:N`00AW/004Ik00800003@U/0049K00800004
>S/00000>Q/200000c7j0000000300000aUH0008mP0800001C5f000m]P00AMH00P0001Q=mP00CQH0
058F001B5P00DSH005Hf001F=P00ESH005Hf001F=P00ESH005Xf0002FUH01@00FUH005iF00000UiF
00<005if00000V9f0`000VJE00D006ZeJ[EZ]@00009Z]@800005K]D006kEK]D00003K]D200000g;e
001^mP02K_H01000K_I^mP000fkf00P006kfK_H006kg001^mP000Vkg00P006kgK_L006kg001^m`00
0Vkg00X006khK_P006[h001_6000JaP0009[6004001Zn6[h0002JaP01000JaQ[60000V/I00@006/I
JaT0009[6@03001[6@0000=[6@06001[6F/I001[6@000V/I00@006/IJaT0009[6@03001[6@00009[
6@05001[6F/IJaT00002JaT00`00JaT00002JaT01000JaU[6@000V/I00@006lIKaT0009_>@04001_
>Fli0002KcP01@00KcQ_>6lh00000Vlh00@006lhKcP0009_>005001c>000KcP00002LcP01000LcMc
=`000W<G00T007<GLaMc5`00LaL007<G00000W<G00@007<GLaL0009c5`08001c5g<G001c5`00KaL0
009_5`03001^mfkg00<0009^m`04001Zmf[g0002J_L30002I]P00`00I]P00002I]P00`00H]P00002
H[P3000015ji001N^@000UZI0P0000UFV@00EWT0059i001>N@00CUT00P0000=6>P00@SX0100000@a
f@00000Y^@L000032AP0000000D000031CP00000008000034GX0000000D000049M/000009O/20000
1bWk00000000;Q/002hK00<00004:O/00000:O/200000bGK0000000300001AVJ000000003ET02`00
00@Y=@000015eQ80000<ESH005Hf001F=P00FSH005YF001JEP000UiF00<005iF00000V9e00X006JE
IYD006ZE001^]000L[@0009fd`05001fm000N_<00003Na<20003Na<00`00Nc=k<`02Nc<02000NcAk
=000Nc@007/d0003NcD02@00NcEk=G/e001g=P00McH00002McH01@00McH007Lg00000WLg00@007<g
LcL0009c=`04001c=g<g0002LcP01000LcQc>0000Vlh00@006lhKcP0009_>006001_>6lh001_>@00
0Vli00<006liKcT00`000Vli00@006liKcT0009_>@04001_>Fli0002KcT01000KcT006li0P000Vli
00<006li00000Vli00<006li00000Vli00<006li00000Vli00@006liKcT0009_>@06001_>Fli001_
>@000Vlh00<006lhKcP00`000Vlh00H006lhKcP006lh0002KaP01000KaQ_60000VlH00<006lH0000
0VlH00@006lH001_6080009_6003001_6000009[60<0009Zn005001Zn000J_P00002I_P300002fKi
001VfFKI001Rf@00H]T006;I00000UkI00<005ji0000100001=J^@00FYT005JI001FVP00DYX005:J
001BNP00CWX004ij001:NP0600001d8j0012>P00@SX003hj00800003?SX003hj00@00005>QX003XK
000j6`0200000cXk000000020002>S/200001cXk000j>`00?U/003iK00@00007?U/0049K0012N`00
@W`00P0000E6O000AW`004Il00L00003BY`00000009:W00U001:W000BY`004jL001>_000C[`004jl
001>_000C[`004jl001>_000C[`005:l001B_000D[`005:l001B^`00D[/005:k00000U:k00X005:k
001B^`00D[/005:k001B^`<0000DD]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0
009Bf`0;001Bf`00D]/005;K001Bf`00D]/0000MOol00`00Oomoo`1SOol004]oo`03001oogoo02Qo
o`03001Ff`00009Ff`0@001Ff`00001Ff`00E]/005KK001Ff`00E]/005KK0002E]/02@00E]/005KK
001Ff`00E]/00002E]/03P00E]/005KK001Ff`00E]/005KK001Ff`00E]/200001eKK001Ff`00E]/0
05KK02@00009CY/004jK001:V`00BY/004Yk00800005AW/004Ik0012F`02000013iK000003Xk0P00
00Df6`00000002Fj00l00003?KH004GF0080000FCOH004hF001B5P00DQH0058f001F=P00ESH005Hf
001F=P00ESH005Hf0002FSH01`00FUH005YF001NEP00009NEP03001NMP00009RMP03001VU@00009V
U@05001Z]FZeJ[D00002J[D200001FkE001^eFkE00000fkE00D007;eL_Ebm@00009^mP04001^mP00
0003K_H01@00K_I^mVkf00000Vkf00D006kgK_M^m`00009^m`04001^mfkg0002K_L01@00K_Q^n6kh
00000VlH00L006/HJaP006/H001Zn0020002JaP01000JaQ[60000V/I00@006/I0000009[6@04001[
6F/I0002JaT01000JaT000000V/I00L006/IJaT006/I001[6@020002JaT01000JaU[6@000V/I00@0
06/I0000009[6@07001[6F/I001[6@00JaT00P000VlI00D006liKcT006li008000=_>005001_>6lh
001_>0020003KcP01000KcQ_>0000Vlh00@007<hLcP0009c=`05001c5g<GLaL00003LaL01000LaMc
5`000W<G00D007<G001c5`00009c5`04001c5g<G0002KaL01000KaM_5`000Vkg00@006kgK_L0009^
m`03001Zm`00009Zm`06001Zn6[h001Vf0000VKH00<006KH00000V;H0`0000AR^000G[T0009N^@0?
001JV@00001FV@00EWT0059i001>N@00CUT004YJ00800003@SX003hJ00@00003;MT0000000@00003
4CP0000000@000031AP0000000D000034GX0000000<000037M/00000008000039O/002Wk00<00004
:O/00000;Q/2000012Wk000002Wk0P0000DUn`000000026j008000036IX001Ej0180000<BOH004hF
001B5P00DQH005Hf001F=P000UHf00d005Hf001F=P00ESH005Hf001J=P00FUH00002FUH01@00GUH0
05iF00000V9e00@006JEIYD0009ZU@800009L[@007KCM]<007Kd001jl`00009k4`03001k4P0000=k
4`03001k<g/c009k<`08001k=7/d001k=000Nc@000=k=@09001k=G/eNcD007Lf001g=P00009g=P05
001g=P00McL00002McL01000LcL000000W<g00@007<gLcL0009c>005001c>7<h001_>0020002KcP0
1@00KcQ_>000KcP00P000Vli00<006li00000Vli00@006liKcT0009_>@04001_>@00KcT20002KcT0
1000KcU_>@000Vli00<006li00000Vli00<006liKcT00`000Vli00D006liKcT006li00<000=_>@04
001_>@00KcT20002KcT00`00KcP00002KcP01000KcQ_>0000Vlh00P006lh000006lh001_60000VlH
00@006lH0000009_6003001_6000009_6003001_6000009_6003001_6000009[6003001Zn000009Z
n005001Zn000J_P00002I_P03000I_UVn@00I_T006KI001Rf@00H]T0009Rf@03001Nf@0000800008
G[T005Zi001J^@00FYT0009FV@06001FVP00DYX005:J0P0000U>NP00CWX004Yj001:FP00BUX00`00
00Q2>P000012>P00?SX003hj0P0000<n>P00>SX0100000<j6`00>Q/00P0000<j>`00>S/00`0000<j
>`00>S/00P000SXk0P0000<nF`00?U/00`0000PnF`000012N`00@W`0049l0P0000U6O000AW`004JL
001:W000BY`01@0000A:W000BY`0009:W080000LC[`004jl001>_000C[`004jl001>_000C[`004jl
001B_000D[`005:l001B_000D[/005:k0002D[/07`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00009Bf`03001Bf`00009Bf`0;001Bf`00D]/0
05;K001Bf`00D]/0000LOol00`00Oomoo`1SOol004]oo`03001oogoo02Uoo`06001Ff`00E]/005KK
0P0000eFf`00E]]Ff`00E]/005KK001Ff`00E]/00002E]/05000E]/005KK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/=00008E:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001>^`00C[/004jk001>V`0200000djK0000000600001DYk0016N`00AW/00P00
00=2F`00@U/00P0000@j>`00000f6`<00003;MX0000000`000097?D003ff0015eP00BOH004gf0080
000>DQH0058F001B=P00ESH005Hf001F=P00ESH0009F=P0;001F=P00FSH005YF001JEP00GUH00002
GUH01P00GWINMP00HWH0009VU@03001VU@0000=Z]@04001Z]FZe0002K]D01@00K]E^eFkE00000VkE
00D007;eL_Ebm@0000=^mP800003L_H006kf009^mP04001^mVkf0002K_H01@00K_M^mfkg00000Vkg
00@006kgK_L0009^m`03001^n6kh0080009_6004001[66/H0002JaP01000JaQ[60000V/H00@006/H
JaP0009[6@04001[6F/I0002JaT00`00JaT00002JaT20002JaT00`00JaT00002JaT01000JaU[6@00
0V/I00<006/I00000f/I00@006/IJaT0009[6@03001[6@00009[6@04001[6@000002JaT01000KaU_
6@000Vli00@006lhKcP0009_>005001_>6lhKcP00002KcP01000KcQ_>0000Vlh00/006lhKcQ_>000
LcP007<g001c5`0000=c5`04001c5g<G0003LaL01000LaMc5`000W<G00@007<GLaL0009c5`04001_
5flG0002KaL01000K_M^m`000Vkg00@006kgK_L0009Zm`<0009Zn006001Vf6KH001Vf0000VKH0`00
00YR^000H[QR^000G[T005ji001JV@80000?EYT005Ii001BN@00CWT004iI001:FP00ASX0048j0080
0003>QX0000000/000032AP0000000D000032CT00000008000055IX00000000Mf`0200001bGK0000
0000:O/002Wk00<00004:O/00000:O/200001BWk000000009O/00P0000<Qf`0000000`0000DENP00
000000DH00P0000439<00000>IH2000034Wf001>5P00DQH0058F001F=P00ESH0009F=P0;001F=P00
ESH005Hf001F=P00FSH00002FUH01`00FUH005iF001NEP0000=RM@03001VU@00009ZU@800003L[@0
07KC009fd`09001jlg[cN_<007/C001k4P0000=k4`8000=k<`05001k=7/dNc@00003Nc@01@00NcD0
07/e00000W/e00D007Lf001g=P0000=g=P04001g=gLg0003McL01000LcMc=`000W<g0P0000Ec>000
LcQc>000009c>004001_>6lh0002KcP01P00KcQ_>000KcP0009_>@03001_>Fli00<0009_>@04001_
>Fli0002KcT01000KcU_>@000Vli00@006li001_>@80009_>@03001_>@00009_>@06001_>Fli001_
>@000Vli00<006li00000Vli00@006liKcT0009_>@03001_>@00009_>@03001_>6lh00<0009_>004
001_>6lh0002KcP00`00KcP00002KaP01P00KaQ_6000KaP0009_6003001_6000009_6006001_66lH
001_60000VlH0`000V[h00D006[h001Zn000009Zn0<0009Vn@07001Vn@00I]T006;I00000V;I1@00
00IN^@00G[T005Zi0002F[T04000FYT005JI001FVP00DYX005:J001BNP00CWX004ij0P0000E:FP00
BUX004IJ00H00005?SX003hj000n>P0200000cXj000j6P0400001CXK000j6`00>S/00P0000/j>`00
000003Xk000j>`00>S/003iK00800003?U/003iK00H00009@W`0049l0016O000AW`004Il00800007
BY`004ZL001:W000BY`02P0000]>_000C[`004jl001>_000C[`004jl0080000>C[`005:l001B_000
D[`005:l001B^`00D[/0009B^`09001B^`00D[/005:k001B^`00009B^`03001B^`000080000?D]/0
05;K001Bf`00D]/005;K001Bf`00D]/005;K018001eoo`03001oogoo069oo`00Bgoo00<007ooOol0
:Goo00<005KK00000UKK00P005KK000005KK001Ff`000UKK018005KK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/:00001EKK001Ff`00E]/00P0000IFf`00E]/005;K0002D[/08000D[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00C[/004jk001>^`00CY/30000
1dZK001:V`00BY/004Yk00@00003AW/004Ik00800003@U/003iK00800004>S/00000<OX800000`Sf
0000000400000aCE0000000200001dGF0019mP00COH004hF00800008DQH0058f001F=P00ESH0009F
=P0?001F=P00ESH005Hf001J=P00FUH005YF001NEP0000=NEP03001NMP000080009VU@03001VU@00
00=Z]@04001Z]FZe0002K]D01P00K]E^eFkE001^e@8000=bm@05001^mVkfK_H00002L_H01P00K_I^
mVkf001^mP8000=^mP08001^mfkg001^m`00K_L0009^m`03001^mfkg0080009_5`07001_66lH001[
6000JaP00P000V/H00@006/HJaP0009[6004001[6@000002JaT02P00JaU[6@00JaT006/I001[6@00
0V/I00L006/IJaT006/I001[6@020002JaT01000JaU[6@000V/I00@006/I0000009[6@04001[6F/I
0002JaT00`00JaT00002JaT01@00KaU_6@00KcT00P000Vlh00H006lhKcQ_>000KcP20002KcP02000
KcQ_>000KcP006lh0002KcP01000LcQc>0000W<G00T007<GLaMc5`00LaL007<G00000W<G00@007<G
LaL0009c5`08001c5g<G001c5`00KaL0009_5`03001_5flG00800004K_L006kg0002K_L01000J_MZ
m`000V[h00<006[h00000VKH00<006KH00000VKH00<006;H00000V:h01@006:h001N^@00G[T005ZI
001JV@00EYT005Ii001BN@00CWT004iI0P0000E6>P00@SX003hJ00800003=OX00000008000038IT0
0000008000034CP0000000@000031AP0000000@000035GX0000000@000058M/00000000Un`020000
12Wk000002Wk0P0000@Yn`00000Yn`800005:O/00000000Uf`0200000b6j0000000>00001PbC0000
03VF0015eP80000:CQH0058F001B5P00ESH005Hf0002ESH01`00ESH005Hf001F=P00009F=P0;001J
=P00FUH005YF001NEP00GUH00003HWD00`00IYD00002JYD01000L[Ab]0000gKC00T007[cN_=jl`00
Na<007/B00000W/C00<007lc00000g/c00D007/dNcAk=00000=k=005001k=@00NcD00003NcD01@00
McIg=WLf00000WLf00D007LgMcMg=`00009g=`04001c=g<g0002LcL01000LcQc>0000W<h00@007<h
LcP0009_>004001_>6lh0002KcP01P00KcQ_>000KcT0009_>@04001_>Fli0002KcT01000KcT006li
0P000Vli00@006liKcT0009_>@03001_>@00009_>@03001_>Fli00<0009_>@08001_>Fli001_>@00
KcT0009_>@05001_>Fli001_>@020002KcT00`00KcT00002KcP01000KcQ_>0000Vlh00@006lh001_
>0800005KcP006lHKaP00002KaP01P00KaQ_6000KaP0009_60<0009_6003001_6000009_6003001[
6000009Zn003001Zn000009Zn0<0009Vn007001Vn@00I_T006KI00000V;I0`0000ARf@00G]T0009N
^@0J001N^@00F[T005Zi001JV@00EYT005JJ001BVP00DYX0059j001>NP00CWX004Yj001:FP800005
AUX004IJ0012>P0400001Chj000n>P00?SX00P0000<j6P00>S/0100000Dj6`00>S/003Xk0080008j
>`800007>S/003Xk000nF`00?U/00P0000DnF`00@U/0049k00<0000<@W`00000AW`004Il0016O000
AY`004ZL0P000TZL0P000TZL00H004ZL001:W000CY`?000044jl001B_000D[`005:l001B_000D[/0
05:k001B^`000U:k00H005:k001B^`00D[/G000015;K001Bf`000U;K00/005;K001Bf`00D]/005;K
001Bf`0001eoo`03001oogoo069oo`00Bgoo00<007ooOol0:Woo01H005KK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK001Ff`X0000:E]/005KK001Ff`00E]/005KK0002E]/01000E]/0
05KK0P0002MFf`00E]/005;K001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00C[/004jk001>^`00CY/00P0000M>V`00BY/004ZK001:V`0200000dIk0016N`04
00000d9K0012F`0300000cXk000f6`0400000bFj0000000800000`be00000003000084GF0019mP00
COH004hF001B5P00DQH0058f001F=P00ESH005Hf001F=P00ESH005Hf001J=P00FUH005YF0002GUH0
2000GUINEP00GWH0069e0002IYD01000IYEVU@000VZe00@006Ze0000009^e@09001^eFkEK]D006kE
001be@0000=bm@04001^mVkf0002L_H02@00K_I^mVkf001^mP00L_H00002K_H01@00K_M^mfkg0000
0Vkg00@006kgK_L0009^m`05001_5flGKaL00002KaP01000JaQ[60000V/H00@006/HJaP0009[6004
001[66/H0002JaT01`00JaU[6@00JaT006/I008000=[6@06001[6F/I001[6@000V/I00@006/IJaT0
009[6@03001[6@00009[6@80009[6@07001[6F/I001[6@00JaT00P000V/I00@006/IJaT0009_6@04
001_6FlI0002KcP01@00KcQ_>6lh00000Vlh00@006lhKcP0009_>004001_>6lh0002KcP01000LcP0
00000g<G00D007<GLaMc5`00009c5`08001c5g<G001c5`00LaL0009c5`04001c5g<G0002KaL01000
KaM_5`000VlG00@006kgK_L0009^m`03001^mfkg00<0009Zn006001Zn6[h001Vf0000VKH0`000V;H
00L006:h001R^000G[T00002G[T200003EZI001FV@00EWT0059i001>N@00CUT004YJ00800005@SX0
03hJ000j6P0400000bFI0000000200000a4h0000000200000`TH0000000500000`eI000000050000
127K000002GK0`0000@Yn`00000Yn`800007:O/00000000Yn`00:O/0300000<ENP0000002@0000P<
T`00000iUP00AMH004Wf0P0000QB5P00DQH005Hf001F=P000UHf00<005Hf00000UHf00l005Hf001F
=P00FSH005YF001JEP00GUH005iF00000f9e00<006JE00000VZE00@007:dL[@000=fd`07001jlg[c
N_<007/C00000W/B00D007/C001o<`00009k<`03001o<`00009k=007001k=7/dNc@007/e00000W/e
00@007/eNcD000=g=P05001g=P00McH00002McL01000McL000000W<g00@007<gLcL0009c>008001c
>7<h001c>000LcP0009_>004001_>000KcP20002KcP00`00KcU_>@030002KcT01000KcU_>@000Vli
00@006liKcT0009_>@04001_>@00KcT20002KcT00`00KcT00002KcT01000KcU_>@000Vli00@006li
001_>@800005KcT006liKcT00002KcT00`00KcT00002KcT00`00KcU_>@030002KcP01000KcQ_>000
0Vlh00<006lh00000Vlh00@006lH001_6080009_6003001_6000009_6006001_66lH001_60000VlH
0`000V/H00D006[h001Zn000009Zn003001Vn000009Vn003001VnFKi00800007I]T006;IH]T006;I
00000V;I020005kI001N^@00G[T005Zi001J^@00FYT005JI001FVP00DYX005:J001BNP00CWX004ij
001:NP00BUX004YJ0P0000E6FP00@SX0048j00@00007?SX003hj000j>P00>QX00P0000<j>`000000
0P000SXk0P0000Dj>`00>S/003Xk00800007>S/003iK000nF`00?U/00P0000E2F`00@W/0049k00H0
000SAW`004Il0016W000BY`004ZL001:W000BY`004ZL001:W000BY`004jL001>_000C[`004jl001>
_000C[`004jl001>_00J00000e:k001B^`03000055:k001Bf`00D]/005;K001Bf`00D]/005;K001B
f`00D]/005;K0002D]/02`00D]/005;K001Bf`00D]/005;K00007Goo00<007ooOol0HWoo001;Ool0
0`00Oomoo`0[Ool02`00E]/00000E]/005KK001Ff`00E]/02P0000YFf`00E]/005KK001Ff`00E]/0
009Ff`0>001Ff`00E]/005KK001Ff`00E]/005KK001Ff`800006E]/005KK001Bf`000U:k01X005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/004jk0P0000E>^`00CY/0
04jK00800009BY/004ZK001:V`00BW/004Ik00800003AW/0049K00800003@U/003iK00<00003=Q/0
037j01<0000PAMH004Wf001=mP00CQH0058F001B5P00DSH005Hf001F=P00ESH005Hf001F=P00ESH0
05Xf001JEP00FUH0009NEP03001NEUiF00<0009RM@03001VU@00009VU@05001Z]FZe001Z]@020003
K]D01000K]E^eFkE0P0000=be@00L_D00W;e00@006kf000000=bmP05001^mVkfK_H00002L_H01000
K_I^mP000Vkg0P000Vkg00D006kgK_L006kg008000=_5`04001_66lH0002JaP01000JaQ[60000V/H
00D006/HJaP006/H0080009[6@04001[6F/I0002JaT00`00JaT00003JaT01`00JaU[6@00JaT006/I
0080009[6@0:001[6F/I001[6@00JaT006/I0002JaT01000JaU[6@000V/I00H006/IJaT006/I0002
JaT01000KaT000000VlI00D006lhKcQ_>000009_>004001_>6lh0002KcP01000KcP000000flh00@0
06lhKcP0009_6005001c5g<GLaL00002LaL01@00LaMc5g<G00000W<G00@007<GLaL0009c5`04001c
5g<G0002KaL01000KaM_5`000VlG00@006kgK_L0009^m`04001^mfkg0002J_L00`00J_P00002J_P0
0`00I]QVf00300001fKH001Rf6;H001R^000009R^006001N^@00G[T005ZI0P0000mFV@00EWT0059i
001>N@00CUT004YJ0016>P00@SX00P0000@j6P00000afP@000037GT00000008000033CP0000000@0
00032CP0000000@000035IX001Vj00@000049M/000009O/2000012Wk000002Wk0P0000<Yn`000000
200000@Qf`00000M^PD000033CT0000000P0000C:CD00000AMH004Wf001>5P00DQH0058F001F=P00
ESH005Hf00000UHf00l005Hf001F=P00ESH005Xf001JEP00FUH005iF00000UiF00H0069eHWD006JE
0002JYD01000L[Ab]0000gKC00L007[cN_=jl`00Na<00002Na800`00Na<00002Oc<01@00Nc<007lc
00000W/d0P000g/d00T007/eNcEk=@00NcD007/e00000WLf00D007Lf001g=P00009g=`05001g=`00
McL00002LcL200001G<g001c>7<h00000W<h00@007<hLcP0009_>004001_>6lh0002KcP00`00KcP0
0002KcT01000KcU_>@000Vli00@006li001_>@80009_>@04001_>Fli0002KcT00`00KcT00002KcT0
0`00KcU_>@030002KcT01000KcU_>@000Vli00D006li001_>@00009_>@04001_>@000002KcT00`00
KcT00002KcT01000KcQ_>0000Vlh00@006lh001_>080009_>003001_>000009_6006001_66lH001_
60000VlH0`000VlH00<006lH00000VlH00P006/HJaP006/H001Zn0000V[h0`000VKh00<006Kh0000
0VKi0P000VKI0`000V;I02H006;I001Nf@00G[T005ji001J^@00F[T005ZI001FV@00EYX005:J001B
VP00DWX004ij001>NP00BWX004YJ001:FP00AUX004IJ0P0000=2>P00@SX0100000Ln>P00>SX003XJ
000j>`0200001cXk00000000>S/003Xk00800005>S/003Xk000n>`03000023iK000003iK000nF`00
@U/200001D9k0012N`00AW`00`0000=6O000AW`00P0000A:W000BY`0009:W080009:W006001:W000
BY`004jL0P0001Y>_000C[`004jl001>_000C[`004jl001>_000D[`005:l001B_000D[/005:k001B
^`000U:k01d005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D]/005;K001Bf`00D]/005;K
001Bf`00009Bf`05001Bf`00D]/00002D]/02`00D]/005;K001Bf`00D]/005;K000077oo00<007oo
Ool0HWoo000>Ool4000>Ool3000<Ool:000BOol00`00Oomoo`0[Ool01000E]/005KK1`0000YFf`00
E]/005KK001Ff`00E]/0009Ff`0E001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`00009Ff`0>001Ff`00001Ff`00E]/005;K001B^`00D[/0009B^`0B001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k0P0000M>^`00C[/004jk001>V`0200001djK001:V`00BY/004ZK0080
0005AW/004Ik0016N`0200000d9K00000003000013Xk0000037j1P0000<=5`002?H00`0000L0<P00
000001ce000m]P02000074Wf001=mP00CQH0058F001B5P00DSH005Hf001F=P00ESH005Hf001F=P00
ESH005Xf001JEP000UYF00@005iF001NEP800007HWH0069eHWD006JE00000VJE00@006ZeJ[EZ]@80
0005K[D006kEK]D00003K]D01000L]Ebe@000g;e00D006kf001bm@00009bmP05001^mVkfK_H00002
L_H01000K_I^mVkf0P000Vkg00@006kgK_L0009^m`04001_5flG0003KaL00`00KaQ_600200001FlH
001[66/H00000V/H00@006/HJaP0009[6007001[6F/I001[6@00JaT00P000V/I00P006/IJaU[6@00
JaT006/I0P000V/I00L006/IJaT006/I001[6@020003JaT01`00JaU[6@00JaT006/I0080009[6@04
001[6F/I0002JaT01000KaU_6@000VlI00P006lhKcP006lh001_>0000Vlh00@006lhKcP0009_>004
001_>6lh0002KcP01000KaQ_60000g<G00D007<G001c5`00009c5`04001c5g<G0002LaL02000LaMc
5`00LaL006lG0002KaL00`00KaM_5`0200001fkg001^mfkg001^m`00009^m`04001Zmf[g0002J_P0
0`00J_P00002I]P00`00I]P00002I]P00`00H]P00002H[P05000H[P005ji001N^@00FYT005ZI001F
V@00EWT0059i001>N@00CUT200001DHj0012>P00?QX00P0000<enP0000000P0000<QV@0000000P00
00<A>00000000`0000<9>0000000100000<AN@000000100000DQf`00000002Gk00800003:O/00000
00L00004:O/00000:O/200001BGK000000008KX00`0000<ENP004ET02`00014Y=@000015eP00BOH0
04hF001B5P00DQH005Hf001F=P00009F=P0?001F=P00ESH005Hf001F=P00FSH005YF001JEP00009N
EP03001NEP00009RM@04001VU@00JYD20002L[@01@00M]=fdgKC00000g[c0P000g/B00<007/C0000
0Wlc00T007/c001o<`00Nc@007/d00000g/d00T007/eNcEk=@00NcD007/e00000gLf00D007LfMcIg
=P00009g=`04001g=gLg0002LcL01000LcMc=`000W<h00@007<hLcP000=c>004001_>000KcP20002
KcP00`00KcQ_>0030002KcT01000KcU_>@000Vli00@006liKcT0009_>@04001_>@00KcT20002KcT0
0`00KcT00002KcT01000KcU_>@000Vli00@006li001_>@80009_>@03001_>@00009_>@03001_>@00
009_>@03001_>Fli00<0009_>004001_>6lh0002KcP00`00KcP00002KcP01000KcP006lH0P000VlH
00<006lH00000VlH00<006lH00000VlH00<006lHKaP00`000V/H00D006/H001Zn000009Zn006001Z
n6[h001Vn0000VKh00@006Ki001Vn@<0009Rf@07001Rf@00H]T005kI00000Uji0P0000IJ^@00F[T0
05ZI0002EYT01P00EYX005:J001BVP80000ACWX004ij001:NP00BUX004YJ0016FP00AUX0048j0012
>P0200000d8j0000000200001cXj000j6P00>S/003Xk00800009>S/00000000j>`00>S/003Xk0080
0003?S/003iK00H00005?U/0049K0012N`0200001D9k0016O000AW`01`0000=:W00000000TZL01`0
04ZL001:W000BY`004ZL001>W000C[`004jl001>_000C[`004jl001>_000C[`004jl001B_0800006
D[`005:k001B^`000U:k00L005:k001B^`00D[/00002D[/01P00D[/005:k001B^`<0000DD[/005;K
001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0009Bf`0;001Bf`00D]/005;K001Bf`00D]/0
000MOol00`00Oomoo`1QOol000aoo`P000]oo`D000]oo`X0019oo`04001oogooOol4000WOol40000
1UKK001Ff`00E]/0009Ff`0C001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK00000UKK
02h005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Bf`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`80000;C[/004jk001>^`00CY/004jK001>
V`0200001dZK001:V`00BW/004Ik00800003AW/0049K00800007?U/003Xk000j>`00=Q/04@0000DL
m@00000004GF0080000HCOH004hF001B5P00DQH0058f001F=P00ESH005Hf001F=P00ESH005Hf001J
=P000UYF00@005YF001NEP800004GWH0069f0002HWD00`00IYD00002IYD01@00J[EZ]FZe00000Vje
00@006kEK]D000=^e@04001beG;E0004L_D200001G;e001bmW;f00000Vkf0P000g;f00@006kfK_H0
00=^m`04001^mfkg0002K_L01000KaM_5`000flG00@006lHKaP0009_6004001[66/H0002JaP01000
JaP000000V/H00@006/IJaT0009[6@06001[6F/I001[6@000f/I00H006/IJaT006/I0002JaT01000
JaU[6@000V/I00<006/I00000f/I00@006/IJaT0009[6@04001[6F/I0002JaT01000JaT006/I0P00
0VlI00D006lIKaU_6@00009_>004001_>6lh0002KcP01000KcQ_>0000Vlh00P006lhKcP006lh001_
60000VlH00D007<GLaMc5`00009c5`08001c5g<G001c5`00LaL0009c5`04001c5g<G0002KaL01000
KaM_5`000VlG00@006kgK_L0009^m`03001^mfkg00800004J_L006[g0002J_P00`00J_QZn0030002
I]P00`00I]P00002H]P01`00H[P006:h001N^@00009N^A400005@SX003hJ000j6P0800000aUi0000
000200000`dh0000000400000`eI0000000600000afk0000000700001bWk00000000:O/002Wk00<0
0004:O/000009O/30000127K000001fj0P0000LENP00000000DH0000]P0600004BTe000004GF0019
mP00CQH0058F001B5P00ESH005Hf00000UHf00l005Hf001F=P00ESH005Hf001J=P00FUH005YF0000
0UiF00<005iF00000V9e00<006JEIYD00`000g:d00@007KCM]<000Ajl`07001k4W/BNa8007/C0000
0Wlc00T007/c001o<`00Nc@007/d00000W/d00<007/d00000g/e00D007/eNcEk=@00009g=P05001g
=WLfMcH00002McL01000McMg=`000W<g00/007<gLcMc=`00LcP007<h001c>000009c>006001_>6lh
001_>0000Vlh00@006lhKcP0009_>@07001_>Fli001_>@00KcT00P000Vli00@006liKcT0009_>@03
001_>@00009_>@03001_>Fli00<0009_>@04001_>Fli0002KcT00`00KcT00002KcT01000KcT006li
0P000Vli00<006li00000Vli00@006liKcT0009_>004001_>000KcP20002KcP00`00KcP00002KcP0
0`00KaP00002KaP00`00KaQ_60030002KaP00`00KaP00002KaP02000JaQ[6000JaP006/H0002J_P3
0002J_P00`00I_P00002I_P00`00I_UVn@0200001f;I001RfF;I001Rf@00009Rf@04001Nf@00G[T2
000025Zi001J^EZi001JV@00EYT900001Dij001>NP00BWX00P0000]:FP00AUX004IJ0012>P00@SX0
048j00800003?SX000000080008j6P800003>S/003Xk0080008j>`800005>S/003Xk000j>`020000
1CiK000nF`00?U/0100000M2F`00@W/0049k0012N`0200001dIl0016O000AW`004JL00D0000XBY`0
04ZL001:W000BY`004ZL001>W000C[`004jl001>_000C[`004jl001>_000C[`004jl001B_000D[`0
05:l001B^`00D[/005:k0002D[/03000D[/005:k001B^`00D[/005:k001B^`<0000DD[/005;K001B
f`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0009Bf`0;001Bf`00D]/005;K001Bf`00D]/0000M
Ool00`00Oomoo`1QOol000aoo`8000Aoo`8000]oo`D000moo`8001Ioo`@002]oo`0E001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`09001Ff`00E]/005KK001Ff`00009F
f`06001Ff`00E]/005KK0P0001=Ff`00E]/005KK001Ff`00E]/005KK001Bf`00D[/005:k001B^`0H
00003Djk001>V`00CY/004jK001:V`00BY/004ZK00800005AW/004Ik0016N`0200000d9K000nF`04
00000cHK000anP0>00001QCE000003Ef0015eP80000FCOH004hF001B5P00DQH0058f001F=P00ESH0
05Hf001F=P00ESH005Hf0002FSH01000FUH005YF0`000Uif00P0069fHWH0069e001VU@000VJE00D0
06ZeJ[EZ]@00009^]@04001^eFkE0002K]D20003L]D01@00L_EbmG;e00000W;e00H007;fL_H006kf
0002L_H01000L_IbmP000Vkf00D006kgK_M^m`00009^m`05001^m`00KaL00002KaL01@00KaM_5`00
KaP00P000VlH00D006/HJaQ[6000009[6004001[66/H0002JaP01000JaT006/I0P000V/I00@006/I
JaT0009[6@04001[6@000002JaT01`00JaU[6@00JaT006/I0080009[6@08001[6F/IJaT006/I001[
6@80009[6@04001[6F/I0002JaT01000JaU[6@000VlI00D006lIKaT006lh008000=_>007001_>000
KcP006lH00000Vlh00@006lhKcP0009_6005001_66lHKaP00002LaL01@00LaMc5g<G00000W<G00@0
07<GLaL0009c5`04001c5g<G0002KaL01000KaM_5`000VlG00@006kgK_L0009^m`04001^mfkg0002
J_L01P00J_MZm`00J_P0009Zn003001Vf000009Vf003001Vf000009Rf003001R^000009R^003001N
^@0000<0000=FYT005JI001FV@00DWT004ii001>FP00BUX00`0000A2>P00000j6P800003<MX00000
008000037GT00000008000033CP0000000<000033CT0000000<000035GX0000000P000049O/00000
:O/3000012Wk000002Wk0P0000@Yn`00000Yn`8000039M/00000008000047KX000005GX200000`di
0000000900003cVF000004Wf001>5P00DQH0058F001F=P00ESH00002ESH03@00ESH005Hf001F=P00
ESH005Xf001JEP00009JEP05001NEP00GUH00002HWD00`00IYEVU@030003L[@01@00M]<007Kc0000
0g[c00<007/BNa800W/B00<007lcOc<00Wlc00H007lcOc<007/d0002Nc@01@00Nc@007/d00000g/e
00T007/eNcEk=@00McH007Lf00000WLf00@007Lg000000=g=`800005LcL007<gLcL00002LcP01000
LcQc>0000W<h00@006lh0000009_>003001_>6lh00<0009_>@04001_>Fli0002KcT01000KcU_>@00
0Vli00@006li001_>@80009_>@03001_>@00009_>@04001_>Fli0002KcT01000KcT006li0P000Vli
00<006li00000Vli00<006li00000Vli00<006liKcT00`000Vli00@006lhKcP0009_>003001_>000
009_>003001_>6lh00<0009_6003001_6000009_6006001_66lH001_60000VlH0`000V/H00<006/H
JaP00P000V[h00H006[hJ_P006[h0002I_P00`00I_P00002I_T20002H]T00`00H]T00002H]T02P00
H]T005kI001N^@00G[T005Zi1`0000MFVP00EYX005:J001BNP09000034YJ000004IJ0012>P00@SX0
048j0012>P800007?SX00000000j6P00>S/00P0000Lj>`00>S/003Xk000j>`0200001CXk000j>`00
?S/00P0000DnF`00?U/003iK00<0000:@U/00000@W/0049k0016O000AW`200001dIl0016W000BY`0
04ZL00P00005BY`004ZL001>W002000064jl001>_000C[`004jl001>_000C[`004jl001B_000D[`0
05:l001B^`00D[/0009B^`0O001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001Bf`00
D]/005;K001Bf`00D]/005;K00000U;K00D005;K001Bf`00009Bf`0;001Bf`00D]/005;K001Bf`00
D]/0000LOol00`00Oomoo`1QOol000]oo`8000Ioo`8000Yoo`D000moo`8001Eoo`03001oogoo02io
o`0:001Ff`00001Ff`00E]/005KK0002E]/02@00E]/005KK001Ff`00E]/00002E]/04000E]/005KK
001Ff`00E]/005KK001Ff`00E]/005KK0P0000=Ff`00E]/0400001=B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`0200000djk001>^`0:00001dZK001:V`00BW/004Ik0080000:AW/0
0000@U/003iK000j>`00=Q/200000c7j0000000200001AEI0000000007D01@0000<De@0000001000
00=9mP00COH00P0000iB5P00DQH0058f001F=P00ESH005Hf001F=P000UHf00H005Hf001J=P00FUH3
00001EiF001NMUif00000V9f00<0069e00000VJE00<006JE00000fZe00@006jeK[D0009^e@06001^
eFkE001be@000W;E00D007;eL_Ebm@0000=bm@03001bmW;f0080009bmP08001bmW;f001^mP00LaH0
00=^m`04001^mfkg0002KaL01000KaM_5`000flG00@006lHKaP0009_6005001[66/H001[60020002
JaP01000JaQ[60000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01P00JaU[6@00JaT0009[6@04
001[6F/I0002JaT00`00JaT00003JaT01000JaU[6@000V/I00L006/IJaT006/I001[6@020002JaT0
1@00KaU_6FlI00000VlI00@006lHKaP0009_>004001_>6lh0002KaP01000KcQ_>0000Vlh00D006lH
KaQ_6000009_6005001c5`00KaL00002LaL01000LaMc5`000W<G00P007<GLaL007<G001_5`000VlG
00<006lGKaL00P0000E_5`00K_M^m`00009^m`<0009Zm`04001Zmf[g0002J_P30002I]P00`00I]P0
0002I]P00`00H]P00002H[P500001Eji000005ZI00000UJI00@005JI001BN@800005CUX004YJ0016
FP0600000cGj0000000600000aUi0000000200000`dh0009>00=0000127K000002GK0`0000<Yn`00
:O/00`0000@Yn`00000Yn`800005:O/00000000Uf`0200001B7K000000006IX00P0000<=F@000000
2P0000liUP000019mP00CQH0058F001B5P00ESH005Hf00000UHf00/005Hf001F=P00ESH005Hf001J
=P00009JEP07001JEP00GUH005iF00000V9e00@006JEIYD0009ZU008001b]7:d001fd`00M_<000=j
l`03001k4W/B009k4P03001o<glc009o<`05001o<glcOc<00003Nc@01@00Nc@007/d00000W/e00<0
07]E00000W/e00D007Lf001g=P0000=g=P04001g=gLg0002McL01000LcMc=`000W<g00@007<h0000
00=c>006001c>7<h001c>0000Vlh00@006lhKcP0009_>007001_>Fli001_>@00KcT00P000Vli00@0
06liKcT0009_>@03001_>@00009_>@03001_>Fli00<0009_>@04001_>Fli0002KcT00`00KcT00002
KcT00`00KcU_>@030002KcT00`00KcT00002KcT01000KcU_>@000Vli00@006lh001_>080009_>003
001_>000009_>003001_6000009_6003001_66lH00<0009_6003001_6000009_6006001_66lH001[
60000V/H00<006/H00000P000V[h00H006[hJ_P006Kh0002I_P3000016KI001Rf@000V;I00L006;I
001Rf@00G]T00002G[T400001UZi001J^@00EYX0009FVP04001FVP00DYX200001dij001>NP00CWX0
04Yj00H00004@SX0048j@SX200000d8j000n>P0200001chj00000000>S/003Xk00800007>S/003Xk
000j>`00?S/0100000Dn>`00?U/003iK00800003?U/0049K00H0000=@W/004Il0016O000AW`004Il
0016W000BY`00P000TZL00@004ZL001:W0T0000?C[`004jl001>_000C[`004jl001>_000C[`005:l
00800006D[`005:k001B^`000U:k00L005:k001B^`00D[/00002D[/01P00D[/005:k001B^`<0000=
D[/005;K001Bf`00D]/005;K001Bf`00D]/050007Goo00<007ooOol0H7oo000;Ool20006Ool2000;
Ool3000@Ool2000EOol00`00Oomoo`0^Ool02`00E]/005KK001Ff`00E]/005KK00000UKK01@005KK
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK2`00011Ff`00E]/005KK001Bf`00D]/0
05:k001B^`00D[/0009B^`0B001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0P0000a>
^`00001>V`00CY/004jK001:V`00BY/600001DIk0016N`00AW/00`0000<nF`00>S/00`0000Dan`00
000002Fj01000007?KH00000001=mP00CQH00P0000QB5P00DSH005Hf001F=P000UHf00P005Hf001F
=P00ESH005Xf0`0000AJEP00GUH0009NMP06001RMV9f001RM@000VJE00<006JE00000VZe0P000Vje
00@006kEK]E^e@80009be@04001beG;E0002L_D20003L_D01000L_IbmP000g;f00@007;fL_IbmP80
0003LaH006kg009^m`04001^mfkg0003KaL01000KaM_5`000VlG00@006lHKaP0009_6003001[66/H
0080009[6007001[66/H001[6000JaT00P000V/I00@006/IJaT0009[6@04001[6@000002JaT01`00
JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT01000JaT000000V/I00@006/IJaT0009[6@04
001[6F/I0002JaT01@00KaU_6@00KaT00P000VlH00D006lhKcP006lh008000=_6007001_>000KcP0
06lH00000VlH00<006lHKaP00P000VlG00P007<GLaL007<G001_5`000W<G00@007<GLaL0009_5`04
001_5flG0002KaL01000KaM_5`000Vkg00@006kgK_L0009^m`06001Zmf[g001Zm`000V[h00H006[h
J_P006KH0002I]P00`00I]P00002H]P300005F:i001N^@00G[T005ZI001JV@00EYT005JI001BN@00
CWT004iJ001:FP0200000d8j0012>P0600001BVi000000006GT02P0000<=F@0000001P0000DM^P00
0000027K008000059O/00000000Yn`02000012Wk000002Wk0P0000@Yn`00000Yn`<000059M/00000
000IVP0200001AEj000000001AP02@0000<iUP00AMH00P0000Y>5P00DQH0058F001F=P00ESH0009F
=P07001F=P00ESH005Hf00000UHf00/005Xf001JEP00FUH005iF001NEP0000=RM@03001VU@00009Z
U008001b]7:d001fd`00M_<000=jl`03001k4W/B009k4P03001o<glc009o<`05001o<glcOc<00003
Nc@20003Nc@01@00NcD007]E00000g/e00D007LfMcIg=P00009g=P04001g=gLg0002McL01@00LcMc
=g<g00000W<g00@007<hLcP0009c>004001c>7<h0002LcP00`00KcP00002KcP01000KcQ_>0000Vli
00@006liKcT0009_>@07001_>Fli001_>@00KcT00P000Vli00<006li00000Vli00@006liKcT0009_
>@04001_>@00KcT20002KcT00`00KcT00002KcT01P00KcU_>@00KcT0009_>@<0009_>@04001_>Fli
0002KcP00`00KcP00002KcP00`00KcQ_>0030002KaP00`00KaP00002KaP01P00KaQ_6000KaP0009_
60<0009_6008001[66/H001[6000JaP0009Zn003001Zn000009Zn004001Vn000I_P200001VKi001V
f@00H]T0009Rf@03001Rf@00009Rf@03001Nf@0000<0000FF[T005ZiF[T005Zi001FVP00EYX005JJ
001BVP00DWX004ij001>NP00CWX200000dYJ0016FP040002@SX01`00@SX00000?SX003hj0080008n
>`800003>S/003Xk0080008j>`800003?S/003hk00@00005?U/003iK000nF`0200001D9K0012F`00
@W/00`0001a2N`000016O000AW`004Il0016W000BY`004ZL001:W000BY`004ZL001:W000CY`004jL
001>_1<00008D[`005:k001B^`00D[/0009B^`04001B^`00D[/I00001U;K001Bf`00D]/0009Bf`0;
001Bf`00D]/005;K001Bf`00D]/0000MOol00`00Oomoo`1POol000Yoo`8000Qoo`8001eoo`8001Eo
o`03001oogoo02moo`0F001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/:
00001eKK001Ff`00E]/005KK0080000VE]/005KKE]/005KK001Ff`00D]/005;K001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`80000;C[/004jk001>V`00CY/0
04jK001:V`0200001DZK001:V`00AW/0100000I6N`000012F`00?U/300000cHK0000000500000aEI
000=5`0400000`0b0000000400000cff0015eP0300004dhF001B5P00DQH0058f001F=P00ESH005Hf
001F=P00ESH005Hf00<00006FUH005YF001NEP000Uif00H0069fHWH0069e0002IYD00`00IYEVU@02
00000fje001^]@02K[D00`00K]E^e@020002L]D01000L]Ebe@000W;e00<007;e00000W;e00@007;f
L_H000AbmP04001bmW;f0003LaH02000K_M^m`00K_L006lG0002KaL02P00KaM_5`00KaL006lG001_
60000VlH00D006/H001_6000009[6004001[66/H0002JaP01000JaQ[60000V/I00@006/IJaT0009[
6@04001[6F/I0002JaT00`00JaT00002JaT01000JaU[6@000V/I00@006/IJaT0009[6@04001[6F/I
0002JaT01000JaT006/I0P000V/I00D006/IJaU[6@00009_6@04001_6FlI0002KaP01000KcQ_>000
0VlH00@006lHKaP0009_>004001_66lH0002KaP01@00KaP006lH00000flG00@007<GLaL0009_5`04
001c5g<G0002LaL01000KaM_5`000VlG00@006lG0000009_5`04001^mfkg0002K_L01000K_M^m`00
0V[g00<006[gJ_L00`000V[h00<006KH00000VKH00<006KH00000V;H00L006:h001R^@00G[T00002
G[T200003eZI001FV@00EYT0059i001>N@00CUX004YJ0016FP0200000d8j000n6P0300000bgI0000
000<00000`di0000000200000a5i000000050000127K000002GK0`0000@Un`00000Yn`800007:O/0
0000000Yn`00:O/00`0000@Uf`00000Qf`@000045GX000002CT70000200?000003VF0015eP00BOH2
0000258F001B5P00ESH005Hf0002ESH00`00ESH00002ESH03`00ESH005Hf001J=P00FUH005YF001N
EP00GUH00003HWD00`00IYD00002JY@02000L[Ab]000M]<007Kc0003N_<20003Na820003Oc<01@00
Oc=o<glc000017/d00T007/dNcAk=000NcD007]E00000g/e00H007LfMcIg=P00McH20002McL01@00
McL007Lg00000W<g00@007<gLcL0009c>005001c>7<h001c>0020002LcP00`00KcQ_>002000026lh
001_>6lh001_>@00KcT20002KcT01000KcU_>@000Vli00<006li00000Vli00<006liKcT00`000Vli
00@006liKcT0009_>@03001_>@00009_>@03001_>Fli00<0009_>@03001_>@00009_>@04001_>Fli
0002KcT01000KcT006lh0P000Vlh00<006lh00000Vlh00<006lH00000VlH00<006lHKaP00`000VlH
00H006lHKaP006lH0002KaP00`00KaP00002JaP00`00JaQ[60020002J_P01P00J_QZn000J_P0009V
n003001Vn@00009Vn@80009Rf@03001Rf@00009Rf@D0000MG[T005ji001J^@00F[T005Zi001FVP00
EYX005JJ001BVP00DWX004ij001>NP00CWX004Yj001:FP0200002DIJ00000000@SX0048j0012>P02
00001chj000n>P00?S/003hk00800007>S/003Xk000j>`00>S/00P0000<n>`00?S/0100000DnF`00
?U/003iK00800005@U/0049k0012N`0500001DIl000004Il00000TJL00@004ZL0000009:W004001:
W000BY`200005djL001>W000C[`004jl001>_000C[`004jl001>_000C[`004jl001B_000D[`04000
01iB^`00D[/005:k001B^`00D[/005:k001B^`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K
0002D]/02@00D]/005;K001Bf`00D]/00002D]/00`00Oomoo`0JOol00`00Oomoo`1POol000Yoo`80
00Qoo`8001eoo`8001Eoo`03001oogoo02moo`0<001Ff`00E]/005KK001Ff`00E]/005KK2P0000YF
f`00E]/005KK001Ff`00E]/0009Ff`06001Ff`00E]/005KK0P00019Ff`00E]/005KK001Ff`00D]/0
05;K001B^`00D[/005:k0002D[/01P00D[/005:k001B^`80000=D[/005:k001B^`00D[/005:k001>
^`00C[/00P0000e>V`00CY/004jK001:V`00BY/004ZK001:V`0200000dIk0016N`0300001D9K000n
F`00>S/00`0000<an`0000000P0000<MV@0000000P0000<0M@000000100000<Lm@00=GH00P0000=5
eP00BOH00`0000eB5P00DQH0058f001F=P00ESH005Hf001F=P0500001UXf001JEP00FUH0009NEP06
001NMUif001RMP000V9e00<006JE00000VJE0P000Vje00@006jeK[D0009^e@05001beG;EL]D00002
L]D00`00L_D00002L_D02000L_Ebm@00L_H007;f0003L_H01000L_IbmP000g<F00@006kgK_M^m`80
0005KaL006lGKaL00003KaL01000KaM_5`000VlH00@006lHKaP000=_6007001[66/H001[6000JaP0
0P000V/H00@006/IJaT0009[6@04001[6@000002JaT01`00JaU[6@00JaT006/I0080009[6@08001[
6F/IJaT006/I001[6@80009[6@04001[6F/I0002JaT01000JaU[6@000V/I00D006/IJaT006lI0080
009_6@05001_66lH001_>0020002KaP01@00KaQ_6000KcP00P000flH00@006lHKaP000=_6004001_
5flG0002LaL01000KaM_5`000W<G00D007<G001_5`00009_5`04001_5flG0002KaL01000KaM_5`00
0Vkg0P0000A^m`00K_L0009Zm`04001Zmf[g0002J_P00`00J_P00002I]P00`00I]P00002I]P30000
26:h001R^F:i001N^@00G[T2000025ZI001FVEJI001FV@00DWT200001diJ001:FP00AUX0048j00T0
00059KT00000000IN@0400000`dh0000000200000`eI0000000600001Afj000000008M/00P0000DU
n`00000002Wk00800004:O/00000:O/3000012Wk000002Gk0`0000@Qf`00000IVP<000053ET00000
0000m`0400005@0?000003VF0015eP00BOH004hF001B5P00DQH005Hf001F=P00ESH00002ESH03`00
ESH005Hf001F=P00FSH005YF001JEP00GUH00002GUH00`00HWERM@030002JY@02000L[Ab]000M]<0
07Kc0002N_<00`00Oa800003Na820002Oc<00`00Oc<00002Oc<20003Nc@01000NcAk=7/d0P000g]E
00D007/e001kEP00009g=P05001g=P00MeH00002McL200002GLg001c=g<g001c=`00LcL00002LcP0
1000LcQc>0000W<h00<007<h00000Vlh00@006lhKcP0009_>004001_>Fli0002KcT01`00KcU_>@00
KcT006li0080009_>@03001_>@00009_>@04001_>Fli0002KcT01000KcT006li0P000Vli00<006li
00000Vli00@006liKcT0009_>@03001_>@000080009_>@04001_>Fli0002KcT00`00KcT00002KcP0
0`00KcQ_>0030002KaP00`00KaP00002KaP01P00KaQ_6000KaP0009_6003001_6000009_6007001_
66lH001[6000JaP00P0000AZn000J_P0009Zn003001Zn6[h00<00009I_T006KiI_T006KI001Rf@00
009Rf@<0000@H]T005kI001N^@00G[T005Zi001J^@00F[T005JJ0002EYX01000EYX005:J0P0000]>
NP00CWX004ij001:NP00BUX004IJ00800003AUX0000000<00003@SX003hj00800007?SX003hk000n
>`00?S/00P0000Lj>`00>S/003Xk000n>`0200000chk000nF`0400001ciK000nF`00@U/0049K0080
0005@W/004Ik0016N`0500005DIl0016W000BY`004ZL001:W000BY`004ZL001:W000CY`004jL001>
_00200005Tjl001>_000C[`004jl001>_000C[`005:l001B_000D[/005:k001B^`000U:k01d005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001Bf`00D]/005;K001Bf`00009Bf`07
001Bf`00D]/005;K00000U;K00/005;K001Bf`00D]/005;K001Bf`0001aoo`03001oogoo061oo`00
2Woo0P0027oo0P007Goo0P005Goo00<007ooOol0;goo00@005KK001Ff`P0000:E]/005KK001Ff`00
E]/005KK0002E]/04000E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0P0002IFf`00E]]Ff`00
E]/005KK001Bf`00D]/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k0P0000]>^`00C[/004jK001>V`00CY/004ZK00800007BY/004ZK0016N`00AW/00P0000M2
N`00000003iK000j>`0200001CHK000000009KX03@0000<Lm@00=GH00P0000E5eP00BOH004hF00<0
0007DQH0058f001F=P00ESH01@0000YF=P00FSH005Xf001JEP00FUH0009NEP06001NMUif001RMP00
0V9e00<006JE00000VJE00D006jeK[E^]@00009^]@04001^eFkE0003L]D01000L]EbeG;E0P000W;e
00@007;eL_Ebm@800003L_H007;f009bmP05001bmP00LaH00002LaH01@00K_M^mfkg00000flG00@0
06lGKaL0009_5`04001_5flG0002KaP01000KaQ_60000flH00@006/HJaP0009[6004001[66/H0002
JaP01000JaU[6@000V/I00@006/IJaT0009[6@04001[6@00JaT20002JaT01000JaU[6@000V/I00@0
06/I0000009[6@07001[6F/I001[6@00JaT00P000V/I00D006/IJaU[6@00009[6@04001_6FlI0002
KaT01000KaQ_60000VlH00@006lHKaP0009_6004001_66lH0002KaP01000KaQ_60000flH00P006lG
KaL007<G001_5`000VlG00@007<GLaL0009_5`04001_5flG0002KaL01000KaM_5`000VlG00@006kg
K_L0009^m`04001^mfkg0002J_L30002J_P01P00J_QZn000I]P0009Vf0<0000HH]P006:hH[P006:i
001N^@00G[T005ZI001JV@00EYT005JI001BN@00CWT004iJ2@0000DinP00000002Vi00L000035ET0
000000@000033ET0000000D000057KX00000000Qf`03000012Gk000002Gk0P0000@Yn`00000Yn`<0
0004:O/00000:O/200001BGK000000007KX01`0000<1600000000`0000<03`0000000P000115eP00
BOH004hF001B5P00DQH005Hf001F=P00ESH0009F=P0?001F=P00ESH005Hf001J=P00FUH005YF001N
EP00009NEP06001RM@00001VM@000VZD00H007:dL[@007KC0002M_<01@00N_<007lB00000W/B00<0
07lb00000Wlc00L007lc001o<`00Oc<00002Nc@00`00Ne@00003Nc@02@00NeEkEG]E001k=@00NeH0
0003McH01000MeIgEP000WLg00@007LgMcL000=c=`04001c=g<g0002LcP01000LcQc>0000W<h00<0
07<hLcP00`000flh00@006lh001_>@80009_>@04001_>Fli0002KcT00`00KcT00002KcT00`00KcU_
>@030002KcT01000KcU_>@000Vli00<006li00000Vli00<006liKcT00`000Vli00H006liKcT006li
0002KcT01`00KcU_>@00KcT006li0080009_>@03001_>000009_>003001_6000009_6003001_66lH
00<0009_6005001_66lH001_6002000016lH001_60000VlH00P006/HJaP006/H001Zn0000V[h00@0
06[h001Zn080000<I_T006KiI_T006Ki001Vf@00H]T006;I0P0000IRf@00H]T005kI0002G[T20000
5UZi001J^EZi001J^@00EYX005JJ001FVP00DYX0059j001>NP00CWX004ij0P0000E:FP00AUX004IJ
00800096FP070012FP00000n>P00?SX00P000Shk0P0000<n>`00?S/00P0000Lj>`00>S/003hk000n
>`0200000ciK000nF`03000023iK0000049K0012F`00@W/200001dIk0016N`00AW/004Il00D0000Z
BY`004ZL001:W000BY`004ZL001:W000CY`004jL001>_000C[`004jl001>_000C[`004jl001>_000
C[`005:l001B_000D[/005:k001B^`000U:k00h005:k001B^`00D[/005:k001B^`00D[/005:k0`00
01AB^`00D[/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`000U;K00/005;K001Bf`00D]/0
05;K001Bf`0001eoo`03001oogoo05moo`002Woo0P0027oo0P007Goo0P005Goo00<007ooOol0<7oo
0`0000QFf`00E]/005KK001Ff`000UKK01<005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/00002E]/01P00E]/005KK001Ff`800004E]/005KK0002E]/05000E]/005;K001Bf`00D[/005:k
001B^`00D[/005:k001B^`00D[/200004e:k001B^`00D[/005:k001B^`00C[/004jk001>^`00CY/0
04jK00800007BY/004ZK001:V`00BY/00P0000M6N`00AW/0049k000nF`0500000cHK000an`050000
0aEI0000000900000cEf000m]P0200001DWf001>5P00DQH02@0000aF=P00ESH005Hf001J=P00FSH0
05YF0002FUH00`00GUH00002GWH00`00HWH00002HWD00`00IYD00002IYD01@00K[E^]Fje00000Vje
00@006kEK]D000Abe@04001beG;E0003L_D01@00L_EbmG;e00000W;f00<007;fL_H00W;f0P0000=c
5P00LaH00W<F00@006kgK_L000=_5`08001_5flG001_5`00KaL0009_5`07001_6000KaP006lH0000
0VlH00D006/HJaP006/H0080009[6004001[66/H0002JaT01000JaT000000V/I00@006/IJaT0009[
6@03001[6@00009[6@05001[6F/IJaT00002JaT00`00JaT00002JaT01000JaU[6@000V/I00@006/I
JaT0009[6@05001[6F/I001[6@020002KaT01@00KaU_6@00KaP00P000VlH00D006lHKaP006lH0080
009_6008001_66lH001_6000KaP000=_6004001_5flG0002KaL01000KaM_5`000W<G00@006lGKaL0
009_5`07001_5`00KaL006lG00000VlG00@006kg0000009^m`04001^mfkg0002J_L01P00J_QZn000
J_P0009Zn003001Vf000009Vf003001Vf000009Rf00@001R^000H[T005ji001N^@00FYT005ZI001F
V@00EYT700000dYJ0016FP0200000d8j000n6P0700001B6I000000005ET0100000<=F@0000000P00
00<AF@0000001P0000@M^`00000Qf`<000049O/00000:O/300000bWk000Yn`03000012Wk000002Gk
0`0000@Q^`00000IVP@000032CT0000000T0000@AMH004Wf001>5P00DQH0058F001F=P00ESH005Hf
0002ESH03@00ESH005Hf001F=P00FSH005YF001JEP00009NEP08001NEP00001RM@00IWD0009ZU004
001b]7:dL[@20002M_<01@00N_<007lB00000W/B00X007lbOc8007lc001o<`00Oc<0009o<`05001k
=000Ne@00003Nc@01`00NeEkEG]E001k=@00009kEP04001g=WLf0002MeH01000McMg=`000gLg00@0
07<gLcL000=c=`04001c>000LcP20002LcP01000LcQc>0000Vlh00@006lhKcP0009_>004001_>Fli
0002KcT01000KcT006li0P000Vli00<006li00000Vli00@006liKcT0009_>@04001_>@00KcT20002
KcT00`00KcT00002KcT01000KcU_>@000Vli00D006li001_>@00009_>@04001_>Fli0002KcT00`00
KcT00002KcT00`00KcQ_>0030002KaP00`00KaP00002KaP01P00KaQ_6000KaP0009_6006001_66lH
001_60000VlH00@006lH001[60800004JaP006[h0002J_P01P00J_QZn000I_P0009Vn@07001Vn@00
I_T006KI00000V;I00D006;I001Rf@00009Rf@0P001Nf@00G[T005ji001J^@00F[T005Zi001FVP00
EYX005JJ001BVP00DWX004ij001>NP00CWX004Yj001:FP800009AUX004IJ0016FP00@UX0048j0080
0007?SX003hj000n>`00?S/00P0000<n>`00?S/0100000Dn>`00?S/003hk00800003?U/003iK00H0
0007@U/0049k0012N`00AW/00P0000I6N`00AW`004JL0002BY`40002BY`01000BY`004ZL0P0001i>
W000CY`004jl001>_000C[`004jl001>_000C[`004jl001>_000D[`005:l001B^`00D[/005:k0002
D[/03P00D[/005:k001B^`00D[/005:k001B^`00D[/3000055:k001B^`00D]/005;K001Bf`00D]/0
05;K001Bf`00D]/005;K0002D]/02@00D]/005;K001Bf`00D]/00002D]/00`00Oomoo`0JOol00`00
Oomoo`1OOol000Yoo`8000Qoo`8001eoo`8001Eoo`03001oogoo031oo`03001Ff`00009Ff`0A001F
f`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00002E]/0;000E]/005KK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005;K001Bf`00D[/005:k001B^`00D[/005:k001B
^`00D[/200006E:k001B^`00D[/005:k001B^`00C[/004jk001>^`00CY/004jK001>V`00BY/004ZK
00800008BY/00000AW/004Ik0012N`<00003>S/0000000<00004<O/000009KX600000`1e00000005
00000cEf000m]P02000064Wf001>5P00DQH0058F001B=P00ESH005Hf001F=P00ESH005Hf001J=P00
FSH0009JEP05001JEP00GUH00002GWH02@00HWIRMP00HWD006JE001VU@020003K[D02000K[E^]@00
K]D007;E0003L]D01000L]Ebe@0017;e00@007;eL_D000=bmP05001bmW;fL_H00003LaH02000LaIc
5P00K_L007<G0002KaL01@00KaM_5flG00000VlG00@006lGKaL0009_6004001_66lH0003KaP01000
JaQ[60000V/H00@006/HJaP0009[6004001[6F/I0002JaT01`00JaU[6@00JaT006/I0080009[6@04
001[6F/I0002JaT01000JaT000000V/I00L006/IJaT006/I001[6@020002JaT01@00JaU[6F/I0000
0V/I00@006lIKaT0009_6@04001_6FlI0002KaP01000KaQ_60000VlH00@006lHKaP0009_6004001_
66lH0002KaP01@00KaQ_66lH00000VlG00@006lGKaL0009_5`05001c5`00KaL00002KaL01000KaM_
5`000VlG00@006lGKaL0009_5`04001^mfkg0002K_L00`00K_L00002J_L01000J_QZn0000V[h00<0
06[h00000VKH0`000VKH00D006;H001R^000009R^@800003G[T0000000H00003EYT0059i00800007
CUX004YJ0016FP00@SX00P0000Dn6P000000037J008000059KT00000000MV@0300000aEI00000003
00000a5i0000000500001Afj000000008M/00`0000@Un`00000Un`800005:O/00000000Yn`020000
1bWk000000009O/002GK00@000036IX0000000D000030?L0000000H0000@AMH004Wf001>5P00DQH0
058F001F=P00ESH005Hf0002ESH02`00ESH005Hf001F=P00FSH005YF00000UYF00D005iF001NEP00
009RM@06001VMFIe001ZU0000g:d00L007KcM_=fl`00N_<00002Oa800`00Na800002Oc801`00Oc<0
07lc001o<`00009o<`03001k=000009kE005001k=000NeD00003NeD01P00NeIkEW]F001g=P8000=g
EP800009MeL007LgMcL007<g001c=`00009c=`04001c>7<h0002LcP00`00LcQc>0030002KcP01@00
KcQ_>000KcP00P000Vli00@006liKcT0009_>@03001_>@00009_>@03001_>Fli00<0009_>@04001_
>Fli0002KcT00`00KcT00002KcT00`00KcU_>@030002KcT01000KcU_>@000Vli00<006li00000Vli
00@006li001_>@80009_>@03001_>@00009_>006001_66lH001_60000VlH0`000VlH00L006lHKaP0
06lH001_600200001FlH001_66lH00000VlH00<006/H00000V/H00H006[h001Zn000J_P200002FKh
001VnFKi001Vn@00I_T00002I]T300005F;I001RfF;I001Rf@00G]T005ji001N^@00F[T005Zi001J
^@00EYX00002EYX01000EYX005:J0P0000]>NP00CWX004ij001:NP00BUX004IJ00800004AUX004IJ
AUX200000d8j0012>P0200001chj000n>`00?S/003hk00800003?S/003hk00@00005?S/003hk000n
F`0200001CiK0012F`00@U/00`0001A2F`000012N`00AW/004Ik0016N`00AW`004JL001:W000BY`0
04ZL2@0000E>W000CY`004jl0080000BC[`004jl001>_000C[`004jl001>_000D[`005:l001B^`00
0U:k024005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005;K001B
f`00D]/005;K00000U;K00L005;K001Bf`00D]/00002D]/02000D]/005;K001Bf`00D]/3000LOol0
0`00Oomoo`1OOol000Yoo`8000Qoo`8001eoo`8001Eoo`03001oogoo035oo`0;001Ff`00E]/005KK
001Ff`00E]/00002E]/02@00E]/005KK001Ff`00E]/00002E]/02000E]/005KK001Ff`00E]/20000
3EKK001Ff`00E]/005KK001Ff`00E]/005KK02`00007BY/004ZK001:V`00BY/00P0000A6N`000012
N`800004?U/00000>S/2000013HK000002WJ100000<EF@0000002P0000<m]P00AMH00P00019>5P00
DQH0058F001B=P00ESH005Hf001F=P00ESH005Hf0002FSH02@00FSH005YF001JEP00GUH00002GWH0
1P00HWIRMP00HWD0009VU@<000=^]@08001^]Fje001^e@00L]D000=be@05001be@00L_D00003L_D0
1@00L_D007;e00000W;f00D007;fL_IbmP0000=c5P05001c5W<FLaH00002LaL01@00KaM_5flG0000
0VlG00@006lGKaL0009_5`04001_60000003KaP01000KaQ_60000V/H00@006/HJaP0009[6005001[
66/H001[6@020002JaT01000JaU[6@000V/I00H006/IJaT006/I0003JaT01000JaU[6@000V/I00<0
06/I00000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01000JaT000000VlI00@006lIKaT0009_
6@04001_66lH0002KaP01000KaQ_60000VlH00D006lHKaP006lH008000=_6008001_66lH001_5`00
KaP0009_5`04001_5flG0002KaL01000KaM_5`000VlG00@006lGKaL0009_5`04001_5flG0002K_L0
1000K_M^m`000Vkg0P0000AZn000J_P0009Zn003001Zn6[h00<00007I]P006KHI]P006;H00000V:h
1`0000=JV@00FYT02@0000=>FP00BUX00P0000=2>P00@SX00P0000<inP0000001@0000DQV@000000
01EI00@000034ET00000008000054GT00000000IVP030000126k0000027K0`0000@Un`00000Yn`<0
0004:O/00000:O/200001BWk000000009M/00P0000DQ^`00000001FJ00@000030AP0000000@00003
:A@003VF0080000>BOH004hF001B5P00DQH005Hf001F=P00ESH0009F=P09001F=P00ESH005Hf001J
=P00009JEP04001JEP00GUH30002HWD01P00IWEVM@00JY@000=b]007001flgKcM_<007[c00000WlB
00<007/B00000Wlb00<007lc00000Wlc00@007lcOc=o<`8000=kE005001k=000NeD00003NeD02@00
NeIkEW]F001g=P00MeH00002MeH01000MeMgE`000WLg00D007<g001c=`00009c=`04001c>0000002
LcP01000LcQc>0000Vlh00@006lhKcP0009_>004001_>Fli0002KcT01000KcT006li0P000Vli00<0
06li00000Vli00@006liKcT0009_>@04001_>@00KcT20002KcT00`00KcT00002KcT01000KcU_>@00
0Vli00@006li001_>@800005KcT006liKcT00002KcT00`00KcT00002KcT00`00KcT00002KcP01P00
KaQ_6000KaP0009_6006001_66lH001_60000VlH00H006lHKaP006lH0002KaP01000KaP006lH0P00
0V/H00D006/H001Zn000009Zn003001Zn000009Vn005001Vn@00I_T00002I_T300004F;I001RfF;I
001Rf@00H]T005kI001N^@00G[T005Zi00000UZi00<005Zi0000300000=>NP00CWX00P0000E:FP00
AUX004IJ00800096FP070012FP000012>P00@SX00P0000Ln>`00?S/003hk000n>`0200000chk000n
>`0300001Shk000003iK000nF`800005@U/0049K0012F`0600005dIk0016N`00AW/004Il0016W000
BY`004ZL001:W000BY`004ZL001:W000BY`02@0001I>_000C[`004jl001>_000C[`004jl001B_000
D[`005:k001B^`00D[/0009B^`0>001B^`00D[/005:k001B^`00D[/005:k001B^`<0000;D[/005:k
001Bf`00D]/005;K001Bf`0D00000e;K001oo`0KOol00`00Oomoo`1OOol000Yoo`8000Qoo`8001eo
o`8001Eoo`03001oogoo035oo`0<001FfeKK001Ff`00E]/005KK001Ff`000UKK01@005KK001Ff`00
E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK3@0001EBf`00D]/005;K001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/00P0001EB^`00D[/005:k001>^`00C[/004jk001>^`00CY/004jK001>
V`00BY/01P0000Q:V`000016N`00AW/0049k0`0000@j>`00000f6`800004<O/000009KX?00001Cff
0015eP00BOH00P0000aB5P00DQH0058f001F=P00ESH005Hf0002ESH03@00ESH005Xf001J=P00FUH0
05YF001NEP00009NMP06001RMV9f001RM@000VJE0P0000EZ]@00K[E^]@0000=^]@800003L]D007;E
009be@05001be@00L_D00003L_D01@00L_D007;e00000g;f00@007;f000000=c5P05001c5W<FLaH0
0002LaL02@00KaM_5flG001_5`00KaL00002KaL01000KaM_5`000VlH00@006lHKaP0009_6007001[
6000KaP006/H00000f/H00@006/HJaP0009[6@07001[6F/I001[6@00JaT00P000V/I00@006/IJaT0
009[6@04001[6@000002JaT01`00JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT20002JaT0
2P00KaU_6@00KaT006lI001_60000VlH00L006lH001_6000KaP00002KaP01000KaQ_60000VlH00D0
06lHKaQ_6000009_6004001_66lH0002KaL01000KaM_5`000VlG00P006lGKaL006lG001_5`000VlG
00T006lG001_5`00KaL006kg00000Vkg00@006kgK_L0009Zn006001Zn6[h001Zn0000V[h00<006KH
00000VKH200000=R^@00G[T01`0000MFV@00EYT0059i001BN@0800000d8j000n6P0300001C7J0000
00008IT00P0000<MV@0000000P0000<EF@0000000P0000<AN@0000001@0000<M^P0000000P0000@Q
f`00000Un`<00003:O/002Wk00<00004:O/00000:O/3000012GK0000027K0`0000<IVP0000002P00
00DY5000>IH004GF0080000:CQH0058F001B5P00ESH005Hf0002ESH01`00ESH005Hf001F=P00009F
=P06001J=P00FUH005YF0`0000ENEP00HWERM@00009VM@04001ZU6ZD0002L[@01`00M_=flgKc001j
l`00009o4P03001k4P0000=o<P05001o<glcOc<00004Oc<01`00NeAkE7]D001k=000009kE@05001k
E@00NeD00003NeH01000MeIgEP000WMF00D007MGMeMgE`00009g=`05001c=g<gLcL00002LcL00`00
LcP00002LcP01000LcQc>0000Vlh00@006lhKcP0009_>004001_>Fli0002KcT01P00KcU_>@00KcT0
009_>@03001_>Fli00<0009_>@04001_>Fli0002KcT00`00KcT00002KcT00`00KcU_>@030002KcT0
1000KcU_>@000Vli00<006li00000Vli00@006li001_>@80009_>@03001_>@00009_>@800006KcT0
06lH001_60000VlH00@006lHKaP0009_6004001_6000KaP20002KaP00`00KaP00002KaP00`00JaP0
0002JaP01P00JaP006[h001Zn080009Zn005001Vn000I_T00002I_T300003fKI001RfF;I001Rf@00
H]T006;I001Nf@00G[T00002G[T00`00F[T0000400002eJJ001FVP00EYX005:J001BVP00DWX01`00
00a:FP000016FP00AUX004IJ0012FP00@SX200000d8j000n>P0400001Chk000n>`00?S/00P0000<n
>`00?S/01P0000DnF`00?U/0049K00800005@U/0049k0012N`0300001DIk000004Ik00000TIl00P0
04JL001:W000BY`004ZL0P0000e:W000BY`004ZL001>W000CY`004jl001>_00f000025;K001Bf`00
D]/005;K0002D]/02`00D]/005;K001Bf`00D]/005;K00007Goo00<007ooOol0GWoo000:Ool20008
Ool2000MOol2000EOol00`00Oomoo`0bOol00`00E]/00002E]/04P00E]/005KK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`/0000<E]/005KK001Ff`00E]/005KK001Ff`000U;K01@005;K001Bf`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k0P0001=B^`00D[/005:k001>^`00C[/004jk001>
^`00CY/004jK001>V`0200001DZK001:V`00BY/00`0000E6N`00AW/0049k00800004?U/00000>S/2
0000137k000002WJ4000028m]P00AMH004Wf001>5P00DQH0058F001B=P00ESH005Hf001F=P00ESH0
05Hf001J=P00FSH005YF001JEP00GUH0009NMP06001RMV9f001RM@000VJE00@006ZeJ[D000=^]@04
001^]Fje0002L]D02@00L]EbeG;E001be@00L_D00003L_D01@00L_D007;e00000g;f00D007;f001c
5P0000=c5P05001c5P00LaH00002LaL01@00KaM_5flG00000VlG00@006lGKaL0009_5`04001_66lH
0003KaP01000KaQ_60000VlH00@006/HJaP0009[6004001[60000002JaT01000JaU[6@000V/I00@0
06/IJaT0009[6@04001[6F/I0002JaT01000JaU[6@000V/I00@006/I001[6@80009[6@0:001[6F/I
001[6@00JaT006/I0002JaT01000KaU_6@000VlI00@006lHKaP0009_6004001_66lH0002KaP01000
KaQ_60000VlH00@006lHKaP000=_6004001_60000003KaP01`00KaL006lG001_5`00009_5`04001_
5flG0002KaL01000KaM_5`000VlG00@006lGKaL0009^m`03001^mfkg00<0009Zn004001Zn6[h0002
J_P80002I]P01@00H]P006:h00000V:i0P0001=N^@00F[T005ZI001FV@00EYT0059i001BN@00CWX0
04YJ001:FP0400001ChJ00000000<MX01P0000DMV@00000001EI00@000034ET0000000H000047KX0
00008K/3000012GK000002Gk0`0000@Yn`00000Yn`<00003:O/002Wk00<000049M/000008K/40000
0a5j0000000200001@3g0000000000l0100000=5eP00BOH00P0000QB5P00DQH005Hf001F=P000UHf
00<005Hf00000UHf00P005Hf001F=P00FSH005YF0`0000AJEP00GUH0009RM@04001VMFIe0002JY@0
1000L[Ab]00017Kc00@007lBOa9o4P8000Ao<P05001o<glcOc<00004Oc<00`00NeAkE002Ne@02@00
NeEkEG]E001kE@00NeD00003NeH02000MeIgEP00MeH007MG0002MeL01000McMg=`000g<g00@007<g
LcL0009c>003001c>7<h0080000;LcP006lhKcP006lh001_>000KcP00002KcT01000KcT006li0P00
0Vli00<006li00000Vli00@006liKcT0009_>@04001_>@00KcT20002KcT00`00KcT00002KcT01000
KcU_>@000Vli00@006li001_>@80009_>@03001_>@00009_>@03001_>@00009_>@03001_>@00009_
>@04001_>Fli0002KaP02000KaP00000KaP006lH0002KaP01P00KaQ_6000KaP0009_6004001_6000
KaP20002JaP01@00JaP006/H00000V[h00<006[h00000V[h00D006Kh001Vn@00009Vn@05001Vn@00
I]T00002H]T01`00H]T006;I001Rf@00009Nf@03001N^@0000@0000EF[T005Zj001FVP00EYX005JJ
001BVP00DYX0059j001>NP00CWX004Yj00H00009AUX004IJ0012FP00@SX0048j00800003?SX003hk
00<00006?S/00000?S/003hk0P0000Dn>`00?S/003iK00@00005?U/0049K0012F`0200001D9k0012
N`00AW/01@000156N`00AW`004JL001:W000BY`004ZL001:W000BY`004ZL0080000JCY`004jL001>
_000C[`004jl001>_000C[`004jl001>_000C[`005:l001B^`00D[/0009B^`0Y001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001Bf`00D]/005;K001Bf`00D]/005;K
001Bf`00D]/00002D]/01`00D]/005;K001Bf`00009Bf`03001Bf`0001aoo`03001oogoo05ioo`00
2goo0P001Woo0P007Woo0P005Goo00<007ooOol0<goo00`005KK001Ff`00E]/005KK001Ff`00E]/:
0000;EKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005;K001Bf`00
D]/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0200006E:k001B^`00D[/004jk001>^`00
C[/004jk001>V`00CY/004jK001:V`00BY/004ZK00800003AW/0000000<00003@W/0049K00800004
>S/00000=Q/200000bWk0000000200000aEI0000000900008CEf000004GF0019mP00CQH0058F001B
5P00DSH005Hf001F=P00ESH005Hf001F=P00FSH005Xf001JEP00FUH00002GUH00`00GWH00002HWH0
1P00HWERM@00IYD0009Z]@05001^]FjeK[D00002K[D01@00L]EbeG;E00000g;E00D007;eL_Ebm@00
00=bm@05001bmG;eL_D00002L_H01@00L_H007<F00000g<F00D007<F001c5P00009c5`05001_5flG
KaL00002KaL02000KaM_5`00KaL006lG0002KaP01@00KaQ_6000KaP00P000VlH00@006/HJaP0009[
6080009[6007001[6F/I001[6@00JaT00P000V/I00@006/IJaT0009[6@04001[6@000002JaT01000
JaU[6@000V/I00<006/I00000V/I00@006/IJaT0009[6@05001[6F/IJaT00002JaT01000KaT006lI
0P000flH00@006lH001_608000=_6007001_6000KaP006lH00000VlH00D006lHKaQ_6000009_6004
001_66lH0002KaL01000KaM_5`000VlG00@006lGKaL0009_5`04001_5flG0002KaL01000KaM_5`00
0Vkg00@006kgK_L0009Zn003001Zn00000H00007I]P006KHI]P006KH00000VKH00<006;H00000V:h
1000011N^@00F[UJ^@00FYT005JI001FV@00DWT0059i001>NP800003BUX004Hj00D00004=OX00000
;MX30000126I000001ei100000<EN@0000000`0000@ENP00000IVP<000057K/00000000Qf`020000
1BGk00000000:O/00P0000@Yn`00000Yn`<00004:O/000009M/30000126k000001VJ2P0000@03`00
000mU@<0000>BOH004hF001B5P00DQH005Hf001F=P00ESH0009F=P08001F=P00ESH005Hf001J=P<0
0006FUH005YF001NEP000V9e00@006IeIWD0009ZU004001b]7:d0004M_<00`00Oa9o4P02Oa800`00
Oc9o<P02Oc801000Oc=o<glc0P000glc0P000g]D00L007]ENeEkE@00NeD00002NeD01000NeH00000
0gMF0P0000UgE`00MeMgE`00McL007MG00000W<g00@007<g0000009c>004001c>7<h0002LcP01000
KcQ_>0000Vlh00@006lhKcP0009_>@06001_>Fli001_>@000Vli00<006liKcT00`000Vli00@006li
KcT0009_>@03001_>@00009_>@03001_>Fli00<0009_>@04001_>Fli0002KcT00`00KcT00002KcT0
1000KcT006li0P000Vli00<006li00000Vli0`000Vli00H006lHKaP006lH0002KaP01`00KaQ_6000
KaP006lH0080009_6003001_6000009_6003001[6000009[6003001[6000009[60<0009Zn005001Z
n000I_P00002I_T300002fKi001VfFKI001Rf@00H]T006;I00000V;I1@0000QN^@00F[T005Zi001J
^P000UJJ00P005JJ001FVP00DYX005:J0P0000U>NP00CWX004Yj001:NP00BUX0100000U6FP00@UX0
048j0012>P00@SX00P0000<n>`00?S/01P0000<n>`00?S/00P0000Dn>`00?U/003iK00@00007@U/0
049K0012F`00@W/00P0000E6N`00AW/004Ik00D0000IAY`004ZL001:W000BY`004ZL001:W000BY`0
04ZL001>W000CY`004jl001>_000C[`00P0000a>_000C[`004jl001>_000D[`005:k0002D[/07`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005;K001Bf`00
009Bf`0;001Bf`00D]/005;K001Bf`00D]/00002D]/02`00D]/005;K001Bf`00D]/005;K000077oo
00<007ooOol0GWoo000;Ool20006Ool2000NOol2000DOol00`00Oomoo`0dOol00`00E]/000090000
2UKK001Ff`00E]/005KK001Ff`000UKK00P005KK001Ff`00E]/005KK0P0000aFf`00E]/005KK001F
f`00E]/005KK0002D]/05000D]/005;K001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/20000
4e:k001B^`00D[/004jk001>^`00C[/004jk001>V`00CY/004jK0080000;BY/004ZK001:V`00AW/0
04Ik0012N`04000013iK000003Xk0P0000@an`00000UfP/0000401400000=GH200007TGF0019mP00
CQH0058F001B5P00DSH005Hf001F=P00ESH005Hf001F=P00FSH005Xf001JEP00FUH0009NEP03001N
MP00009RMP03001RMF9e00<0009Z]@05001^]FjeK[D00002K[D01@00L]EbeG;E00000g;E00D007;e
L_Ebm@0000=bm@05001bmG;eL_D00003L_H01000LaIc5P0017<F00@007<FLaH0009c5`06001_5flG
001c5`000VlG00@006lGKaL0009_5`04001_66lH0003KaP01000KaQ_60000VlH00L006/H001[6000
JaP00002JaP01000JaU[6@000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01000JaU[6@000V/I
00@006/I001[6@80009[6@07001[6F/I001[6@00JaT00P000f/I00@006/IJaT0009_6@04001_6FlI
0002KaP01000KaQ_60000VlH00@006lHKaP0009_6004001_66lH0003KaP01000KaQ_60000VlH00D0
06lHKaP006lG008000=_5`07001_5`00KaL006lG00000VlG00<006lGKaL00P0000Q_5`00KaM_5`00
K_L006kg1P0000AZn000J_QZn0<0009Vf003001Vf000009Vf003001Vf000009Rf0<00003G[T00000
009N^@0B001J^@00FYT005JI001FV@00DWT0059i001>NP00BUX004YJ0P0000M2>P00000003Gj000a
fP03000012Vj000001fI100000<EF@0000000P0000<AN@0000001@0000@M^P00000Q^`@000039O/0
02Gk00<00004:O/00000:O/3000012Wk000002Gk0P0000DUf`00000001fj00@000033ET0000000@0
000600l00000?ID004GF0`0000a>5P00DQH0058F001F=P00ESH005Hf0002ESH01000ESH005Hf1@00
00IJ=P00FUH005YF0002GUH01P00HWERM@00IWD0009ZU004001b]7:d0004M_<00`00Oa9o4P02Oa80
0`00Oc9o<P02Oc801P00Oc=o<`00Oc80009o<`03001oD`00009kE003001oE00000=kE@09001kEG]E
NeD007]F001kEP00009gEP05001gEgMGMeL00002MeL01000MeMgE`000g<g00H007<hLcP007<h0002
LcP02000LcQc>7<h001_>000KcP20003KcP01000KcT006li0P000Vli00<006li00000Vli00@006li
KcT0009_>@04001_>@00KcT20002KcT00`00KcT00002KcT01000KcU_>@000Vli00@006li001_>@80
009_>@03001_>@00009_>@03001_>@00009_>@03001_>@00009_>@04001_>Fli0002KcT01@00KaP0
06lH00000VlH00@006lHKaP0009_6003001_6000009_6003001_66lH00<0009[6005001[6000JaP0
0002JaP00`00J_P00002J_P00`00J_P00002I_P300002fKi001VnFKi001Vf@00H]T006;I00000V;I
0`0000QNf@00G[T005ji001J^@000UZi018005Zj001FVP00EYX005JJ001BVP00DYX0059j001>NP00
CWX200001dYj001:FP00AUX004IJ00<00008@UX00000@SX0048j000n>P800005?S/003hk000n>`04
00001Chk000n>`00?S/00P0000<nF`00?U/00`0000Q2F`000012F`00@W/0049k0P000TIk0P0000A6
N`00AW]6N`D00003BY`004ZL0080000PBY`004ZL001:W000CY`004jL001>_000C[`004jl001>_000
C[`004jl001>_000C[`005:l001B^`00D[/0009B^`0B001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k0`0001AB^`00D[/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`000U;K00/0
05;K001Bf`00D]/005;K001Bf`0001eoo`03001oogoo05eoo`0037oo0P0017oo0P006goo0`0000=o
o`00000057oo00<007ooOol0=Goo00/005KK001Ff`00E]/005KK001Ff`00009Ff`0Q001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00009B
f`0<001Bf`00D]/005:k001B^`00D[/005:k0P0001EB^`00D[/005:k001B^`00D[/005:k001B^`00
C[/004jk001>^`00C[/00P0000E>V`00CY/004ZK00800005BY/004ZK0016N`0200001TIk0000049K
000nF`800004>S/00000=Q/200000bWk0000000300000`Th0000000700000cEf000m]P0200006TWf
001>5P00DQH0058F001B=P00ESH005Hf001F=P00ESH005Hf001J=P00FSH005YF0002FUH01@00GUH0
05if00000V9f00<0069eHWD00`000VZe00D006jeK[E^]@00009^]@05001beG;EL]D00003L]D01@00
L_EbmG;e00000g;e00D007;eL_Ebm@0000=bmP05001c5W<FLaH00003LaH01@00LaIc5W<F00000W<G
0P000W<G00@006lGKaL0009_5`05001_5flGKaL00002KaP01000KaQ_60000VlH00@006lHKaP0009[
6005001[66/HJaP00002JaP01000JaT006/I0P000V/I00P006/IJaU[6@00JaT006/I0P000V/I00@0
06/IJaT0009[6@06001[6F/I001[6@000V/I00@006/IJaT0009[6@08001[6F/IJaT006/I001_6@80
009_6@05001_66lH001_60020002KaP01@00KaQ_6000KaP00P000flH00P006lHKaP006lH001_6000
0VlH00@006lHKaP0009_6004001_5flG0002KaL01000KaM_5`000VlG00@006lGKaL0009_5`L0009^
n003001Zn000009Zn004001Zn6[h0002J_P00`00I]P00002I]P00`00I]P00002I]P300006f;I001N
^@00G[T005ji001J^@00FYT005JI001FV@00DWT0059i001>NP00BUX004YJ0016>P0200001ChJ0000
0000<MX00P0000DYfP00000001fI008000036GT00000008000035GT0000000D000036IX000000080
00048K/000008M/3000012Gk000002Wk0`0000<Yn`00:O/00`0000@Un`00000Uf`<000057K/00000
000EVP0600001@2f00000000:A@00P0000=5eP00COH00`0000YB5P00DQH005Hf001F=P00ESH0009F
=PD0000:ESH005Xf001J=P00FUH005YF0002GUH01P00HWERM@00IWD0009ZU005001b]000L[<00003
M_<00`00Oa9o4P02Oa802`00Oc9o<Wlb001o<P00Oc<007lb00000Wlc00P007mCOe<007]D001oE000
0g]E00T007]ENeEkE@00NeH007]F00000WMF00D007MGMeMgE`00009gE`05001gEgMGMeL00002LcL0
1000LcQc>0000W<h0P0000Ec>000LcQc>000009_>004001_>6lh0002KcP01P00KcU_>@00KcT0009_
>@03001_>Fli00<0009_>@04001_>Fli0002KcT00`00KcT00002KcT00`00KcU_>@030002KcT01000
KcU_>@000Vli00<006li00000Vli00<006liKcT00`000Vli00<006li00000Vli0`000Vli00@006li
KcT0009_6003001_6000009_6004001_6000KaP20002KaP00`00KaP00002KaP00`00JaP00002JaP0
0`00JaP00002JaP30002J_P01@00J_P006[h00000VKh00<006Ki00000VKi00L006Ki001Vf@00H]T0
0002H]T300001UkI001Nf@00G[T0009N^@0J001J^@00F[T005Zj001FVP00EYX005JJ001BVP00DYX0
059j001>NP00CWX004Yj001:NP800005AUX004IJ0016FP0600001D8j000n>P00?S/00P0000Dn>`00
?S/003hk00@00005?S/003hk000nF`0200000ciK0012F`0600004D9k0012N`00AW/004Ik0016N`00
AW/004Ik0016V`00BY`01`0000=:W000BY`00P0001Q>W000CY`004jl001>_000C[`004jl001>_000
C[`004jl001>_000D[`005:k0002D[/05000D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/3000055:k001B^`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K0002D]/01`00D]/0
05;K001Bf`00009Bf`03001Bf`0001aoo`03001oogoo05eoo`0037oo20006goo1P0057oo00<007oo
Ool00`00<Woo01H005KKE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0009Ff`0T
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005;K001Bf`00D]/005:k
001B^`00D[/005:k0P0001]B^`00D[/005:k001B^`00D[/005:k001B^`00C[/004jk001>^`00C[/0
04jK001>V`00CY/00P0000E:V`00BY/004ZK00<00005AW/0049k0012F`02000013YK000003Xk0P00
00@an`00000UfP8000035ET0000000P00003=GH003ff0080000HBOH004hF001B5P00DQH0058f001F
=P00ESH005Hf001F=P00ESH005Xf001J=P000UYF00L005YF001NEP00GWH00003HWH00`00HWD00002
IYD00`00J[D00003K[D01000K[D0000017;E00@007;EL]D000Abm@04001bm@000004L_D01000L_H0
00000g<F00H007<FLaH007<F0002LaH01000LaMc5`000g<G00P006lGKaL006lG001_5`000VlG00P0
06lHKaP006lH001_60000VlH00@006lH001[608000=[6004001[66/H0002JaT01000JaU[6@000V/I
00D006/IJaT006/I0080009[6@07001[6F/I001[6@00JaT00P000V/I00L006/IJaT006/I001[6@02
0002JaT01@00JaU[6F/I00000V/I00@006lIKaT0009_6@04001_66lH0002KaP01000KaQ_60000VlH
00@006lHKaP000=_6004001_66lH0002KaP01000KaQ_60000VlH00@006lHKaP0009_5`04001_5`00
0002KaL00`00KaM_5`070002KaL01000K_M^m`000Vkh00@006[hJ_P0009Zn0<0009Zn003001Vf000
009Vf003001Vf000009Vf003001Rf000009Rf@06001N^@00001N^@000UZi00`005ZI001FV@00EYT0
059i001BN@00CWX200000dYJ0016>P0200000chJ00000003000012gJ000002Vj0`0000<MN@000000
0P0000<EN@0000000`0000@ENP00000IVP8000057KX00000000Qf`03000012Gk000002Gk0P0000DY
n`00000002Wk00800004:O/000009O/200000bGK0000000200000aVJ0000000200000`Ti00000004
000022TD000004GF001=mP00DQH>000035Hf001F=P00ESH005Xf001J=P00FUH0009JEP03001NEP00
009RM@03001VM@00009ZU005001b]000L[<00003M_<00`00Oa9o4P02Oa802@00Oc9o<Wlb001o<P00
Oc<00002Oc800`00Oc<00002Oe<00`00Ne@00002Oe@01@00NeD007]E00000g]E00P007]FNeH007MF
001gEP000WMG00D007MG001gE`00009gE`04001c=`000002LcP01000LcQc>0000W<h00D007<hLcP0
06lh0080009_>005001_>6lh001_>@020002KcT00`00KcT00002KcT01000KcU_>@000Vli00@006li
001_>@80009_>@03001_>@00009_>@04001_>Fli0002KcT01000KcT006li0P000Vli00<006li0000
0Vli00<006li00000Vli00<006li00000Vli00@006liKcT0009_>@04001_>@00KaP200001FlH001_
66lH00000VlH00<006lH00000VlH00<006lHKaP00`000V/H00<006/H00000V/H0`0000M[6000J_QZ
n000J_P00002J_P300002FKi001VnFKi001Vn@00I]T00002H]T3000016;I001Nf@000UkI028005ji
001N^@00F[T005Zi001J^P00EYX005JJ001FVP00DYX005:J001BNP00CWX004ij001:NP00BWX004YJ
0016FP800005AUX004IJ0012FP0400001chj000n>`00?S/003hk00800003?S/003hk00@00005?S/0
03iK000nF`0200001D9K0012F`00@U/00`0000E2N`000016N`000096N`80000=AW/004Ik0016V`00
BY`004ZL001:W000BY`01`0000U>W000CY`004jl001>_000C[`00P0000a>_000C[`004jl001>_000
D[`005:k0002D[/07`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005;K001Bf`00009Bf`0;001Bf`00D]/005;K001Bf`00D]/00002D]/01P00D]/005;K001B
f`D001aoo`03001oogoo05eoo`003Woo100087oo0`0057oo0`00=Woo00T005KK001Ff`00E]/005KK
00000UKK00/005KK001Ff`00E]/005KK001Ff`00009Ff`80000EE]/005KK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005;K02H00003CY/004jK00800007BY/004ZK001:V`00AW/00P0000I6
N`000012F`00?U/2000013Xk000003HK0`0000<UfP0000003@0000<m]P00AMH00P00019>5P00DQH0
058F001B=P00ESH005Hf001F=P00ESH005Hf0002FSH02@00FSH005YF001JEP00GUH00002GWH01P00
HWIRMP00HWD0009VU@04001Z]FZe0002K[D01@00K[D007;D00000g;E00D007;E001bm@0000=bm@05
001bm@00L_D00003L_D01@00L_H007<E00000W<F00<007<F00000W<F00@007<FLaH0009c5`03001c
5g<G009c5`04001_5flG0002KaL01@00KaM_5flG00000VlH00@006lHKaP0009_6004001_66lH0002
KaP02000JaQ[66/H001[6000JaT20002JaT01000JaU[6@000V/I0P0000E[6@00JaU[6@00009[6@04
001[6F/I0002JaT01`00JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT01000JaT000000VlI
00D006lIKaT006lH0080009_6004001_66lH0002KaP01000KaQ_60000flH00@006lH000000=_6007
001_6000KaP006lH00000VlH00<006lGKaL0200000E_5`00KaM_5`00009_5`03001_5flG00800004
K_P006kh0002J_P01000J_QZn0000V[h00<006[h00000VKH00<006KH00000VKH0`000V;H00@006;I
001N^@80009N^@0B001J^@00FYT005JI001FV@00DWT0059i001>NP00BUX004YJ0P0000E2>P000000
03Wj00D00003:KX0000000@000036GT00000008000045GT000005GX400001AVj000000008M/00P00
00DQf`00000002Gk00800005:O/00000000Yn`02000012Wk000002Gk0`0000@Uf`00000M^`<00003
5IX0000000L0000C:A@00000AMH004gf001B5P00DQH0058F001F=P00ESH005Hf00000UHf00/005Hf
001F=P00ESH005Xf001J=P00009JEP05001JEP00GUH00002HWD02P00IWEVM@00JY@007:d001b/`00
0gKc0P000glB0P000Wlb00D007lb001o<`00009o<P03001o<`00009oD`8000=oE005001kE@00NeD0
0003NeD01000NeIkEW]F0P0000=gEP00MeL00WMG00@007MGMeL000=gE`04001c=g<g0002LcP30003
LcP01000LcQc>0000Vlh00@006lhKcP0009_>003001_>@00009_>@03001_>Fli00<0009_>@04001_
>Fli0002KcT00`00KcT00002KcT00`00KcU_>@030002KcT01000KcU_>@000Vli00<006li00000Vli
00<006liKcT00`000Vli00<006li00000Vli0`000Vli00@006liKcT0009_>@03001_6@00009_6004
001_6000KaP20002KaP00`00KaP00002KaP00`00JaP00002JaP00`00JaP00002JaP00`00JaP00002
JaP01@00J_P006[h00000V[h00<006Ki00000VKi00D006Ki001Vn@00009Vf@<00004H]T006;I0002
G]T09P00G]T005ji001N^@00F[T005Zi001J^P00EYX005JJ001FVP00DYX005:J001BNP00CWX004ij
001:NP00BWX004YJ0016FP00AUX200001DIJ0012FP00@UX0100000Ln>`00?S/003hk000n>`020000
0chk000nF`0400001CiK000nF`00?U/00P0000E2F`00@U/0049k00H00096N`0:0016N`00AW/004Ik
0016V`00BY`200002DZL001:W000BY`004ZL001:W00=00003Tjl001>_000C[`004jl001B_000D[/0
05:k0002D[/04P00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`<00007D[/005:k001B
f`00D]/05P0000ABf`00D]/001aoo`03001oogoo05eoo`00BGoo00<007ooOol0=goo00/005KK001F
f`00E]/005KK001Ff`00009Ff`0:001Ff`00E]/005KK001Ff`00E]/200001eKK001Ff`00E]/005KK
00h0000=D]/005;K001Bf`00D[/005:k001B^`00D[/00P0001MB^`00D[/005:k001B^`00D[/005:k
001>^`00C[/004jk001>^`00C[/004jK00L00007BY/004ZK0016N`00AW/00P0000=2N`00@U/00P00
00@jF`00000f6`800005<O/00000000MVP0200000`Th0000000800001Cff0015eP00BOH00P0000aB
5P00DQH0058f001F=P00ESH005Hf0002ESH03@00ESH005Xf001J=P00FUH005YF001NEP00009NMP03
001RMV9f00<0009VU@04001Z]FZe0003K[D200000g;D001be@02L]D01@00L]D007;e00000g;e00D0
07;e001bm@0000=bm@05001bmP00LaD00003LaH20002LaH01000LaIc5W<F0P0000=c5`00LaL00W<G
00@006lGKaL000=_5`05001_5flG001_60020002KaP01@00KaQ_6000KaP00P000VlH00D006/HJaQ[
6000009[6004001[6F/I0002JaT01`00JaT006/I001[6@00009[6@07001[6F/I001[6@00JaT00P00
0V/I00@006/IJaT0009[6@03001[6@0000=[6@04001[6F/I0002JaT01000JaU[6@000VlI00@006lI
KaT0009_600:001_66lH001_6000KaP006lH0002KaP01@00KaQ_66lH00000VlH00@006lHKaP0009_
6003001_66lH00L0009_5`04001_5flG0002KaL01000KaM_5`000VlG00@006lGKaL0009^n007001^
n6kh001Zn000J_P00P000V[h00H006[hJ_P006KH0002I]P30002H]P07P00H]P006;I001N^@00G[T0
05ji001J^@00FYT005JI001FV@00DWT0059i001>NP00BUX004YJ0016>P800005?QX00000000enP02
000012WJ000002Fj0`0000<IN@0000000P0000<EN@0000001@0000@MVP00000M^P@000048M/00000
9O/300000bWk000Yn`03000012Wk000002Wk0P0000DUn`000000027K00@000035IX0000000800003
0AP0000000800003:A@003fE0080000>COH0058F001B5P00DQH005Hf001F=P00ESH0009F=P09001F
=P00ESH005Hf001J=P00009J=P07001JEP00FUH005iF00000V9e00X006IeIWD006ZD001b]000L[<0
00=fl`80009o4P05001o<@00Oc800002Oc800`00Oc<00002Oc820004Oe<01`00OeAoE7mD001kE@00
009kE@05001kE@00NeD00002NeH01@00MeIgEWMF00000WMG00D007MGMeMgE`00009gE`04001c=g<g
0002LcP01000LcQc>0000W<h00@007<hLcP0009_>005001_>6lh001_>0020002KcT00`00KcT00002
KcT01000KcU_>@000Vli00@006li001_>@80009_>@03001_>@00009_>@04001_>Fli0002KcT01000
KcT006li0P000Vli00<006li00000Vli00<006li00000Vli00<006liKcT00`000Vli00L006liKcT0
06li001_>@020002KaT00`00KaP00002KaP00`00KaP00002KaP00`00KaQ_60030002JaP00`00JaP0
0002JaP300001f/H001[66/H001Zn000009Zn0<0009Vn@07001Vn@00I_T006Ki00000VKI00D006;I
001Rf@00009Rf@0?001Nf@00G]T005ji001N^@00F[T005Zi001J^P00009FVP0<001FVP00EYX005:J
001BVP00DWX004ij0P0000e:NP00BWX004YJ0016FP00AUX004IJ0016FP0200000d9J0012FP030000
23hk000003hk000n>`00?S/200000ciK000nF`0400001ciK000nF`00@U/0049K00800005@W/0049k
0016N`0300003dIk0016N`00AW/004Ik0016V`00BY`004ZL001:W00200004DZL001:W000BY`004jL
001>W000C[`004jl001>_000C[`0;P0000aBf`00D]/005;K001Bf`00D]/005;K0002D]/02`00D]/0
05;K001Bf`00D]/005;K00007Goo00<007ooOol0G7oo0019Ool00`00Oomoo`0gOol05`00E]]Ff`00
E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/02@0000iFf`00E]/005KK001Ff`00
E]/005KK001Bf`000U;K00`005;K001Bf`00D[/005:k001B^`00D[/200005E:k001B^`00D[/005:k
001B^`00D[/004jk001>^`00C[/004jk001>^`0200000djK001:V`0200000dZK0000000400001DIk
0016N`00@W/00P0000@nF`00000j>`800005<Q/00000000UfP0>00008Sff0015eP00BOH004hF001B
5P00DQH0058f001F=P00ESH005Hf001F=P00ESH005Xf001J=P00FUH005YF001NEP000Uif00H0069f
000006Ie0002IYD01000J[EZ]@000fje00@007;DL]@000=be@05001be@00L_D00004L_D01000L_Eb
m@0017;e00@007<ELaD000=c5P03001c5W<F009c5P04001c5W<F0002LaL02@00LaMc5g<G001_5`00
LaL00002KaL01@00KaM_5flG00000VlH00@006lHKaP0009_6004001_66lH0002KaP01@00JaQ[6000
JaP00P000V/I00@006/IJaT0009[6@07001[6F/IJaT006/I00000V/I00@006/IJaT0009[6@07001[
6F/I001[6@00JaT00P000V/I00@006/IJaT0009[6@04001[6@000002JaT01@00KaU_6@00KaT00P00
0VlH00@006lHKaP0009_6004001_66lH0003KaP01000KaQ_60000VlH00<006lHKaP01`000VlH00D0
06lG001_6000009_5`09001_5`00KaL006lG001_5`00009_5`04001_5`000002K_P01000K_Q^n000
0V[h00H006[hJ_P006[h0002J_P00`00I]P00002I]P00`00I]P00002H]P00`00H]P00002H]T20000
15ji001N^@000UZi00`005ZI001FV@00EYT0059i001BN@00CWX200000dYJ0016>P02000013hJ0000
03Wj1@0000DY^P000000026J00<000056GT00000000EN@08000011fj0000027K0`0000@Uf`00000U
n`<00004:O/00000:O/2000012Wk000002Gk0`0000@Qf`00000M^`@000034GX0000000D00005:A@0
03fE0015eP020000358F001B5P00DQH005Hf001F=P00ESH0009F=P05001F=P00ESH00002ESH02`00
FSH005Xf001JEP00FUH005iF00000V9e00X006IeIWD006ZD001b]000L[<0009fl`03001o4@00009o
4P05001o<@00Oc800003Oc800`00Oc9o<P02Oc800`00Oe=oD`02Oe<00`00OeAoE002Oe@02@00NeEk
EG]E001kE@00NeD00002NeH02@00MeIgEWMF001gE`00MeL00002MeL01000MeL000000W<g00@007<h
LcP0009c>008001c>7<h001c>000LcP0009_>006001_>6lh001_>@000Vli00<006liKcT00`000Vli
00@006liKcT0009_>@06001_>Fli001_>@000Vli0`000Vli00@006liKcT0009_>@03001_>@00009_
>@03001_>Fli00<0009_>@03001_>@00009_>@03001_>@00009_>@04001_>Fli0002KcT00`00KaT0
0002KaT01000KaP006lH0P000VlH00<006lH00000VlH00<006/H00000V/H00<006/H00000V/H00P0
06/HJaP006/H001[60000V[h0`000VKi00L006Ki001Vn@00I_T00002I_T30002H]T03@00H]T006;I
001Nf@00G]T005ji001N^@00009J^@04001J^@00F[XA00003TYj000004YJ0016FP00AUX004IJ0016
FP00@UX200000d9J0012F`0600001Chk000n>`00?S/00P0000<nF`00?U/00`0000`nF`000012F`00
@U/0049K0012N`00@W/200000dIk0000000300004dIk0016N`00AY/004ZL001:W000BY`004ZL001:
W000BY`004ZL0080000FCY`004jl001>_000C[`004jl001>_000C[`004jl001>^`00D[/005:k0002
D[/0:`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00009Bf`03001Bf`00009Bf`07001Bf`00D]/005;K
000077oo00<007ooOol0G7oo0019Ool00`00Oomoo`0hOol02P00E]/005KK001Ff`00E]/005KK3000
00UFf`00001Ff`00E]/005KK00000UKK01X005KK001Ff`00E]/005KK001Ff`00D]/005;K001Bf`00
D]/005:k001B^`00D[/005:k0P0001]B^`00D[/005:k001B^`00D[/005:k001>^`00C[/004jk001>
^`00C[/004jK001>V`00BY/00`0000E:V`00AW/004Ik00@00003@W/0049K00800004>U/00000=Q/2
00000bgk000UfP0=00008CEf000004GF0019mP00CQH0058F001B5P00DSH005Hf001F=P00ESH005Hf
001F=P00FSH005Xf001JEP00FUH00002GUH01P00GWH00000HWD0009VM@03001VU@00009Z]@05001^
]FjeK[D00002L]@00`00L]Ebe@02L]D01000L_Ebm@0017;e00D007;eL_Ebm@0000=bm@05001c5G<E
LaD00002LaH00`00LaIc5P02LaH01000LaIc5P000g<G00D007<GLaMc5`00009c5`05001_5flGKaL0
0002KaL01000KaQ_60000VlH00@006lHKaP0009_6005001_66lHKaP00002JaP01000JaQ[60000V/I
00@006/I001[6@8000=[6@07001[6F/I001[6@00JaT00P000V/I00@006/IJaT0009[6@04001[6F/I
0002JaT01@00JaU[6@00JaT00P000V/I00@006/IJaT0009_6@04001_6FlI0002KaP01000KaP006lH
0P000flH00D006lHKaP006lH00L00005KaP006lHKaP00002KaP01000KaQ_60000VlH00@006lGKaL0
009_5`04001_5flG0002KaL01000KaM_5`000Vkh00H006khK_P006kh0002J_P01000J_QZn0000V[h
00<006[h00000VKH0`000VKH00<006;H00000V;H00H006;I000005ji0002G[TA00001DYJ00000000
?QX00P0000<inP00=OX00`0000@Y^P00000Q^P<000036GT00000008000045GT000006IX300001AfJ
000000007K/00`0000@Uf`00000Un`<00004:O/00000:O/200001bWk000000009O/002Gk00@00005
7K/00000000EVP0800001bTD000mU@00AMH004gf0080000:DQH0058F001F=P00ESH005Hf0003ESH0
4@00ESH005Hf001F=P00FSH005Xf001JEP00FUH005iF00000V9e00@006IeIWD0009ZU0800007L[<0
07KcM_<007lA00000WlB00D007la001o<P0000=o<P03001o<Wlb009o<P03001oDgmC009oD`8000=o
E003001kEG]E009kE@08001kEG]E001kEP00NeH0009gEP05001gE`00MeL00002MeL01@00MeL007MG
00000W<g0P0000Ec>000LcQc>000009c>004001c>7<h0002KcP01000KcQ_>0000Vli00<006li0000
0Vli00@006liKcT0009_>@04001_>@00KcT20002KcT00`00KcT00002KcT01000KcU_>@000Vli00@0
06li001_>@80009_>@03001_>@00009_>@06001_>Fli001_>@000Vli0`000Vli00L006liKcT006li
001_>@020002KaT00`00KaT00002KaP00`00KaP00002KaP00`00KaQ_60030002JaP00`00JaP00002
JaP30002JaP01@00JaP006/H00000V[h00<006[i00000VKi00D006Ki001Vn@00009Vn@<0009Rf@0;
001Rf@00H]T006;I001Nf@00G]T00002G[T00`00G[T0000600003eJJ001FVP00EYX005:J001BVP00
DYX004ij001>NP05000034YJ000004IJ0016FP00AUX0049J0012FP800005@U/0049K0012F`040000
1Chk000n>`00?U/00P0000<nF`00@U/01P0000U2F`00@U/0049k0012N`00AW/00P000TIk00<004Ik
0000100000=6V`00BY`00P0001E:W000BY`004ZL001:W000BY`004jL001>W000C[`004jl001>_000
C[`00P0000I>_000C[`004jk0002D[/07`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00009B^`0A001Bf`00D]/005;K001Bf`00D]/005;K001B
f`00D]/00002D]/02@00D]/005;K001Bf`00D]/0000LOol00`00Oomoo`1LOol004Uoo`03001oogoo
03Uoo`T0000<E]/005KK001Ff`00E]/005KK001Ff`000UKK0P0001AFf`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK001Bf`000U;K00`005;K001Bf`00D[/005:k001B^`00D[/200004e:k001B
^`00D[/005:k001B^`00D[/004jk001>^`00C[/004jk00800005CY/004jK001:V`0200001DZK001:
V`00AW/00P0000=6N`00@W/0100000LnF`00000003HK000b6`0400000afJ0000000<00007TGF0019
mP00CQH0058F001B5P00DSH005Hf001F=P00ESH005Hf001F=P00FSH005Xf001JEP00FUH0009NEP03
001NMP00009RM@06001VMFIe001VU@000VZe00D006jeK[E^]@00009be003001beG;E009be@05001b
mG;eL_D00003L_D01@00L_EbmG;e00000W;e0P000g<E00D007<F001c5P0000=c5P05001c5P00LaH0
0002LaL01@00LaMc5g<G00000W<G00T006lGKaM_5`00KaL006lG00000VlH00L006lH001_6000KaP0
0002KaP01@00KaQ_6000JaP00P000V/H00@006/IJaT0009[6@04001[6F/I0003JaT00`00JaT00002
JaT01000JaU[6@000V/I00@006/I001[6@80009[6@04001[6F/I0003JaT00`00JaT00002JaT01@00
JaU[6@00KaT00P000VlI00@006lHKaP0009_6005001_66lH001_600700001FlH001_66lH00000VlH
00@006lHKaP0009_6004001_66lH0002KaP01@00KaM_5`00KaL00P000VlG00@006lGKaL0009_5`04
001^n6kh0002K_P00`00K_Q^n002000016[h001Zn0000V[h00<006[hJ_P00`000VKH00<006KH0000
0V;H00P006;H001Rf@00G[T005ji0`0000mJ^@00FYT005JI001FV@00DWT0059j001>NP00BUX01@00
00<n6P00>QX00P0000@enP00000]fP8000049KX000008IX400000aUi0000000500001AVJ00000000
7K/00P0000DQf`00000002GK008000059O/00000000Yn`02000012Wk000002Wk0`0000@Un`00000Q
f`<000037KX00000008000033ET0000000<0000D:A@003fE0015eP00COH0058F001B5P00DQH005Hf
001F=P00ESH0009F=P0A001F=P00ESH005Hf001J=P00FSH005YF001JEP00GUH00002HWD01000IWEV
M@000VZD00@007:cL[<0009fl`0:001o4GlA001o4P00Oc4007lb0003Oc800`00Oc9o<P02Oc820002
Oe<00`00Oe@00002Oe@00`00Ne@00003NeD01000NeEkEG]E0P0000=kEP00MeH00WMF00D007MGMeMg
E`00009gE`04001gEgMG0002LcL01000LcQc>0000W<h00@007<h000000=c>004001_>000KcP20002
KcT00`00KcU_>@030002KcT01000KcU_>@000Vli00H006liKcT006li0002KcT30002KcT01000KcU_
>@000Vli00<006li00000Vli00<006liKcT00`000Vli00<006li00000Vli00H006liKcT006li0002
KcT01P00KcU_>@00KaT0009_6@03001_6FlI00<0009_6003001_6000009_6003001_6000009[6003
001[6000009[6008001[66/H001[6000JaP0009[60<0009Zn@05001Vn@00I_T00002I_T300003FKi
001RfF;I001Rf@00H]T006;I001Nf@00009Nf@D0000IF[T005Zj001J^P00EYX005JJ001FVP00DYX0
05:J001BVP00CWX004ij001>NP00BWX01@0000Y6FP000016FP00@UX0049J0012FP800005@U/0049K
0012F`0400001Chk000nF`00?U/00P0000E2F`00@U/0049K00@00006@U/0049k@W/0049k0P0000U6
N`00AW/004Ik0016N`00AW/01`00025:W000001:W000BY`004ZL001>W000CY`004jl001>_000C[`0
04jl001>_000C[`004jl001>^`00D[/005:k00000U:k01@005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k0`0001AB^`00D[/005:k001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00
0U;K00/005;K001Bf`00D]/005;K001Bf`0001]oo`<005eoo`00BGoo00<007ooOol0>Goo00T005KK
001Ff`00E]/005KK00000UKK00`005KK001Ff`00E]/005KK001Ff`00E]/200001UKK001Ff`00E]/0
009Ff`0?001Ff`00E]/005KK001Ff`00E]/005;K001Bf`00009Bf`80000KD[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001>^`00C[/004jk00800007C[/004jK001>V`00BY/0
0`0000M:V`00AW/004Ik0016N`0200000d9K000nF`0200001cYK00000000<Q/002gk00h00003:CD0
03ff0080000JBOH004hF001B5P00DQH0058f001F=P00ESH005Hf001F=P00ESH005Xf001J=P00FUH0
009JEP03001NEP000080009RM@06001VMFIe001VU@000VZe00<006jeK[D00P000g;D00D007;EL]Eb
e@0000=bm@03001bmG;e008000=bm@06001bmG;e001g5@000W<E00D007<F001c5P0000Ac5P800003
LaH007<G009c5`05001c5`00LaL00002LaL01@00KaM_5flG00000VlG00@006lHKaP0009_6004001_
66lH0002KaP01@00KaQ_66lH00000VlH00L006/HJaP006/I001[6@020002JaT02000JaU[6F/I001[
6@00JaT20002JaT01000JaU[6@000V/I00@006/IJaT0009[6@05001[6F/I001[6@020002JaT01000
JaU[6@000V/I00@006lIKaT0009_6@04001_6000KaP60002KaP01000KaP000000flH00L006lH001_
6000KaP00002KaP01`00KaP006lH001_6000009_6004001_5flG0002KaP03000KaM_5`00KaL006lG
001_6000K_P0009^n004001^n6kh0002J_P01P00J_QZn000J_P0009Zn003001Vf000009Vf003001V
f000009Rf003001Rf000009Rf@@00004G[T005Zi0002FYT02P00EYT005JI001BN@00DWX004ij0P00
00=:FP00AUX00`0000<j6P00>OX00P0000<anP000000100000DQVP00000001Ui00<000046IX00000
6IX300000afJ000000020000127K000002GK0`0000@Un`00000Yn`800004:O/00000:O/3000012Gk
000002GK0`0000DM^`00000001FJ00L0000D:A@003fE0015eP00COH0058F001B5P00DQH005Hf001F
=P00ESH0009F=P0?001F=P00ESH005Hf001J=P00FSH005YF001JEP00009NEP03001RM@00009VM@04
001ZU6ZD0003L[<00`00M_<00002Oa400`00Oa800002Oc400`00Oc9o<P02Oc820002Oc800`00Oe<0
0002Oe<02000OeAoE000Oe@007]D0002NeD20003NeD01@00NeIkEW]F00000WMF00D007MGMeMgE`00
009gE`04001gEgMG0002LcL01@00LcQc>7<h00000W<h00@007<hLcP0009c>004001_>6lh0002KcP0
0`00KcT00002KcT01000KcU_>@000Vli00@006li001_>@80009_>@03001_>Fli00<0009_>@07001_
>Fli001_>@00KcT00P000Vli00<006li00000Vli00@006liKcT0009_>@03001_>@000080009_>@07
001_>Fli001_>@00KcT00P000VlI00<006lI00000VlI00<006lI00000VlH00<006lHKaP00`000VlH
00<006/H00000V/H0`000V/H00<006/HJaP00P000V/H00H006[iJ_T006[i0002I_T20002I_T00`00
I_T00002I_T00`00H]T00002H]T2000016;I001NfEkI0`0000AN^@00G[T0009J^@80000@F[X005JJ
EYX005JJ001FVP00DYX005:J001BVP00CWX200001dij001:NP00BWX004YJ00D0000:AUX00000@UX0
049J0012F`00@U/200000d9K0012F`0400001CiK000nF`00?U/00P0000E2F`00@U/0049K00<00007
@U/0049k0012N`00AW/00P000TIk0P0000U6N`00AW/004ZK001:V`00BY/01@0000E:W000BY`004ZL
0080000BCY`004jl001>_000C[`004jl001>_000C[`004jl001>^`000U:k02l005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001Bf`00D]/0
05;K001Bf`00D]/005;K001Bf`00009Bf`03001Bf`00009Bf`07001Bf`00D]/005;K00005goo0`00
0Woo00<007ooOol0Fgoo0019Ool00`00Oomoo`0jOol05@00E]/005KK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/00002E]/200001UKK001Ff`00E]/0009Ff`0@001Ff`00E]/005KK001Ff`00
E]/005;K001Bf`00D]/200007E:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00C[/004jk001>^`00C[/00P0000E>V`00CY/004ZK00800005BY/004ZK0016N`0200001DIk0012
N`00@U/00P0000DnF`00000003HK00800003;O/0000000h0000K?KH00000BOH004hF001B5P00DQH0
058f001F=P00ESH005Hf001F=P00ESH005Xf001J=P00009JEP07001JEP00GUH005if00000V9e00@0
06IeIWD0009VU@03001Z]@00009^]@8000=be003001beG;E008000=bm@06001bmG;e001fm@000W;e
00<007;e00000WLE00@007<ELaEc5@80009c5P05001c5W<FLaH00003LaH02000LaMc5`00LaL007<G
0002LaL00`00KaM_5`020002KaL01@00KaQ_6000KaP00P000flH00@006lHKaP0009_6004001_66lH
0002JaP01000JaU[6@000V/I00@006/IJaT0009[6@04001[6@000002JaT01`00JaU[6@00JaT006/I
0080009[6@05001[6F/IJaT00002JaT01P00JaU[6@00JaT0009[6@04001[6@000002KaT70002KaP0
1000KaQ_60000flH00@006lHKaP0009_6004001_66lH0002KaP01000KaQ_60000VlH00@006lHKaP0
009_6004001_5flG0002KaP01000KaM_5`000VlG00@006lHKaP0009^n003001^n6kh00<0009Zn004
001Zn6[h0002J_P30002I]P00`00I]P00002I]P00`00H]P00002H]P400005Uji001N^Eji001J^@00
FYT005JI001FV@00DWT0059j001>NP00BUX004YJ1P0000<inP00=OX00P0000D]fP000000026j0080
00078IX00000000IN@006IX01P0000@MVP00000M^`<000048M/000009M/3000012Gk000002Wk0`00
00<Yn`00:O/00`0000@Un`00000Qf`@000036IX00000008000042CT000000002:A@2000044GF001=
mP00DQH0058F001B5P00ESH005Hf001F=P000UHf00d005Hf001F=P00ESH005Xf001J=P00FUH00002
FUH01@00GUH0069e00000VIe00@006ZDJY@000=b/`03001fl`00009o4@03001o4P00009o<@07001o
<WlbOc8007mB00000Wlb00H007mCOe<007mC0002Oe@00`00Oe@00002Ne@01@00NeD007]E00000W]E
00T007]FNeIkEP00MeH007MF00000WMG00D007MG001gE`00009gE`800005LeP007<hLcP00002LcP0
1000LcQc>0000W<h00@006lh0000009_>003001_>Fli00<0009_>@04001_>Fli0002KcT01P00KcU_
>@00KcT0009_>@03001_>@00009_>@04001_>Fli0002KcT00`00JcT00002KcT00`00KcU_>@030002
KcT01P00KcU_>@00KcT0009_>@06001_>Fli001_>@000Vli00<006lI00000VlI00<006lIKaT00`00
0VlI00<006lH00000VlH00P006lHKaP006lH001[60000V/H00H006/HJaP006/H0002JaP00`00JaP0
00020002J_T00`00J_T00002I_T00`00I_T000020002I_T00`00I_T00002H]T01000H]T000000V;I
0`0001iNf@00G[UN^@00G[T005Zi001J^P00F[X005JJ001FVP00EYX005:J001BVP00DYX004ij001>
NP00CWX200001dYj001:FP00BUX004IJ00H00007@UX0049K0012F`00@U/00P0000=2F`00@U/01000
00LnF`00?U/0049K0012F`0200000d9K0012F`0500002d9k0016N`00AW/004Ik0016N`00AW/00P00
00U:V`00BY/004ZK001:W000BY`02@0000U>W000C[`004jl001>_000C[`00P0000I>_000C[`004jk
0002D[/07`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00009B^`0A001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/00002D]/9000LOol0
0`00Oomoo`1KOol004Qoo`03001oogoo03]oo`09001Ff`00E]/005KK001Ff`00009Ff`0V001Ff`00
E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00
D]/005;K001Bfb40000;CY/004jK001:V`00BY/004ZK001:V`0200000dIk0016N`0200000d9K000n
F`0200001CXk000f6`00<Q/04`0001E5eP00001>5P00DQH0058F001B=P00ESH005Hf001F=P00ESH0
05Hf00000UXf00H005Xf001JEP00FUH300001Eif001RMF9e00000VIe00@006JEIYD0009Z]@80009^
]004001be7;D0002L]D00`00L_@00002L_D00`00L_D00002M_D01000L_EbmG;e0P000WLE00D007<E
LaEc5@0000=c5P05001c5W<FLaH00003LaH01@00LaMc5g<G00000W<G00H007<GLaL006lG0002KaL0
1000KaM_5`000VlH00@006lHKaP0009_6008001_66lH001_6000KaP0009_6004001[6000JaT20002
JaT01@00JaU[6F/I00000V/I00<006/I00000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01@00
JaU[6@00JaT00P000V/I00D006/IJaT006/I00H00005KaT006lI001_60020002KaP01P00KaQ_66lH
001_6080009_6005001_66lH001_60020002KaP01@00KaQ_6000KaP00P000VlH00X006lHKaP006lG
001_6000KaP0009_5`04001_5`000002KaP01000K_Q^n0000Vkh00@006[hJ_P0009Zn003001Zn000
009Zn006001Vn6Kh001Vf0000VKH00<006KH00000V;H0`0000=Rf@0000000Uji01@005ji001J^@00
FYT005JI001FV@00DWT0059j001>NP00BUX004YJ0`0000=2>P0000000P0000@enP00000]fP800004
:MX000008IX400000aUi0000000300000aVJ0000000200001Afj000000008M/00P0000DUf`000000
02Gk00800004:O/00000:O/3000012Wk000002Gk0`0000@Qf`00000M^`<000035IX0000000@0008Y
5080000@AMH004gf001B5P00DQH0058F001F=P00ESH005Hf0002ESH02`00ESH005Hf001F=P00FSH0
05Xf00000UYF00L005YF001NEP00HWD00002IWD01000JYAZU0000g:c00<007Kc00000WlA00<007lB
00000Wla00D007lbOc9o<P00009oDP03001o<P00009oD`8000=oE08000=kE009001kE@00NeD007]E
001kEP00009kEP05001gEP00MeH00003MeL01000MeMgE`000WMG00@007=HLeP0009c>005001c>000
LcP00002LcP01P00LcQc>000KcP0009_>004001_>Fli0002KcT01`00KcU_>@00KcT006li0080009_
>@03001_>Fli00<0009_>@07001_>Fli001_>@00KcT00P000V/i00<006li00000Vli00@006/iJcT0
009_>@05001_>@00KcT00002KcT01`00KcU_>@00KcT006li0080009_6@03001_6@00009_6@03001_
6@00009_6@03001_66lH00<0009_6003001_6000009[60<0009[6008001[66/H001[6000JaP0009Z
n@03001Zn@00009Zn@05001Vn@00I_T00002I_T01@00I_T006Ki00000V;I00@006;I001Rf@<0000T
G]T005kIG]T005ji001N^@00F[T005Zj001J^P00EYX005JJ001FVP00DYX005:J001BVP00CWX004ij
001>NP00BWX004Yj0P0000M:FP00AUX004IJ0016FP0400001d9K0012F`00@U/0049K00800003@U/0
049K00<0000:?U/00000@U/0049K0012F`00@U/20000149k0012Nd9k100000e6N`00AW/004Ik0016
N`00AW/004ZK001:V`0200002dZL001:W000BY`004ZL001>W000CY`03@0000Y>_000C[`004jk001B
^`00D[/0009B^`0D001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`<00003D[/0
05:k01H00008D]/005;K001Bf`00D]/001aoo`03001oogoo05]oo`00B7oo00<007ooOol0?7oo00T0
05KK001Ff`00E]/005KK00000UKK00H005KK001Ff`00E]/200003EKK001Ff`00E]/005KK001Ff`00
E]/005KK0100000PD]/00000D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/004jk
001>^`00C[/004jk001>^`T00007BY/004ZK0016N`00AW/00P0000I2N`00000nF`00?U/400000c8K
000]n`0?00001CVF0015eP00BOH00P0000aB5P00DQH0058f001F=P00ESH005Hf0002ESH02000ESH0
05Xf001J=P00FUH3000015iF001NMP000f9e00<006Ie00000VJE00<006ZeJ[D00P000Vjd00@007;D
L]@0009be@03001bm000009bm@03001bm@00009fm@05001bmG;eL_D00004MaD01000LaEc5@000g<F
00H007<FLaH007<F0002LaH01@00LaMc5g<G00000g<G00@007<GLaL000=_5`04001_5flG0002KaP0
1000KaQ_60000flH00@006lHKaP0009_6004001_66lH0002JaP01000JaQ[60000V/I00D006/IJaT0
06/I0080009[6@07001[6F/I001[6@00JaT00P000V/I00D006/IJaU[6@00009[6@03001[6F/I00T0
009[6@04001_6FlI0002KaT01000KaQ_60000VlH00D006lHKaQ_6000009_6004001_66lH0002KaP0
1000KaQ_60000VlH00@006lHKaP0009_6004001_66lH0002KaP01000KaQ_60000VlH00@006lGKaL0
009_6007001_66lH001^n000K_P00P000V[h00@006[hJ_P0009Zn0<0009Vn003001Vf000009Vf003
001Vf000009Rf00=001Rf@00H]T005ji001N^@00G[T005Zi00000UZI00X005JI001FV@00DWT0059j
001>NP800003BUX004IJ00<00003?QX0000000800004<OX00000;MX30000126J000001fJ100000@I
VP00000IVP<000047KX000007K/400000bGK000Uf`03000012Wk000002Wk0`0000@Yn`00000Un`80
00059O/00000000Qf`0400000aFJ000000020000104H000002TD0P000115eP00COH0058F001B5P00
DQH005Hf001F=P00ESH0009F=P09001F=P00ESH005Hf001J=P00009J=P09001JEP00FUH005iF001R
M@00009VM@04001ZU0000003L[<00`00M_<00002Oa420003Oc420002Oc801P00Oe9oDP00Oc8000=o
D`03001oE7mD009oE003001kE7]D009kE008001kEG]E001kE@00NeH000=kEP05001gEWMFMeH00002
MeL01000MeMgE`000WMG00D007=HLeQcF000009c>004001c>7<h0002LcP01000LcQc>0000Vlh00<0
06lhKcP00`000Vli00@006liKcT0009_>@06001_>Fli001_>@000Vli00H006liKcT006li0002KcT0
1P00KcT00000KcT0009[>@03001_>Fli00<0009[>@04001_>Fli0002KcT00`00KcT00002KcT01000
KcT006li0P0000E_6@00KaU_6@00009_6@<0009_6@03001_6@00009_6008001_6FlI001_6000KaP0
009[6006001[66/H001[60000V/H00<006/HJaP00P000V[i00H006[iJ_T006[i0002I_T20002I_T0
0`00I_T00002I_T00`00H]T00002H]T200002f;I001NfEkI001Nf@00G[T005ji00000UZi0P0001]J
^P00EYX005JJ001FVP00DYX005:J001BVP00CWX004ij001>NP00BWX004Yj001:FP00BUX00P0000E6
FP00AUX004IJ00<00008@U/00000@U/0049K0012F`800003@U/0049K00H0000?@U/0049K0012F`00
@U/0049k0012N`00AW/004Ik00800096N`80000=AW/004Ik001:V`00BY/004ZK001:W000BY`00P00
015:W000CY`004jL001>W000C[`004jl001>_000C[`004jk02P0000BD[/005;K001Bf`00D]/005;K
001Bf`00D]/005;K001Bf`000U;K00T005;K001Bf`00D]/005;K00007Goo00<007ooOol0FWoo0018
Ool00`00Oomoo`0mOol04000E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0P0000=Ff`000000
2P00011Ff`00E]/005KK001Ff`00D]/005;K001Bf`00D]/0009Bf`80000KD[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/004jk001>^`00C[/004jk00<00007CY/004ZL001:W000BY`0
1P0000=6N`00AW/00P0000Q2F`00000nF`00>S/0038K0P0000<]n`0000000P0000<AF@000?L02000
01/iUP00000004Wf001>5P00DQH0058F001B=P00ESH005Hf001F=P00ESH005Hf001J=P00FSH00`00
00AJEP00GUH0009NMP06001RMF9e001VM@000VJE00@006ZeJ[D000=^]006001be7;D001be@000W;d
00@007;eL_Ebm@8000=fm@04001bmG;e0004MaD01@00LaD007LE00000g<F00D007<F001c5P0000=c
5P05001c5`00LaH00002LaL01000LaMc5`000flG00P006lGKaL006lH001_60000VlH00D006lHKaP0
06lH0080009_6005001_66lH001[60020002JaP01@00JaU[6F/I00000V/I00H006/IJaT006/I0002
JaT01000JaU[6@000V/I00@006/IJaT0009[6@L0009[6@04001[6F/I0002JaT01`00JaU[6@00KaT0
06lI0080009_6005001_66lHKaP00002KaP01000KaQ_60000VlH00@006lHKaP0009_6004001_66lH
0002KaP01000KaQ_60000VlH00@006lHKaP0009_6004001_66lH0002KaL01000KaQ_60000VlH00@0
06khK_P0009Zn003001Zn000009Zn004001Zn6[h0002J_P00`00I_P00002I]P00`00I]P00002I]P3
000016;I001RfF;I0P0001IN^@00G[UN^@00F[T005ZI001FV@00EYT0059i001BNP00CWX004YJ001:
FP<00004@SX00000>QX4000012gJ000002WJ0`0000LQVP00000001fJ000IVP0400000aVJ00000002
000011fk0000027K0`0000@Uf`00000Un`<00003:O/002Wk00<00004:O/000009O/30000127K0000
01fk100000<ANP0000000`0000<Y5000?ID00P0000i=mP00DQH0058F001B5P00ESH005Hf001F=P00
0UHf00D005Hf001F=P00009F=P0;001J=P00FSH005YF001JEP00GUH00002HWD00`00IWEVM@030003
L[<00`00M_<00003Oa401000Oc5o<Gla0P000Wlb00<007mBOe800P0017mC00<007mDOe@00WmD00<0
07]DNe@00W]D00@007]ENeEkE@80009kEP04001kEW]F0003MeH01@00MeL007MG00000WMG0P0000Eg
E`00LeQcF000009c>008001c>7<hLcP007<h001c>080009_>004001_>6lh0002KcT01`00KcU_>@00
KcT006li0080009_>@03001_>Fli00<0009_>@04001_>Fli0002KcT00`00KcT00002KcT00`00JcT0
0002KcT01000JcU[>@000V/i00@006li001_>@800005KcT006liKcT00002KcT00`00KcT00002KaT0
0`00KaT00002KaT00`00KaT00002KaT00`00KaU_6@030002KaT01@00KaQ_6000KaP00`000V/H00L0
06/HJaP006/H001[6002000016/I001Zn@000V[i00@006[i001Vn@800004I_T006Ki0002I_T00`00
I_T00002H]T40002H]T01@00G]T005kI00000Uji00@005ji001J^@80000OF[X005JJ001FVP00EYX0
05:J001BVP00DYX004ij001>NP00CWX004Yj001:NP00BUX004YJ0016FP00AUX00P0000=6FP00@U/0
1P0000E2F`00@U/0049K00800005@U/0049K0012F`040000149K0012Fd9K0P0000U2N`00@W/004Ik
0016N`00AW/01@0001A6N`00001:V`00BY/004ZK001:W000BY`004ZL001:W000CY`004jL0P00011>
_000C[`004jl001>_000C[/004jk001>^`00C[/0009B^`0a001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D]/005;K001Bf`00D]/005;K
001Bf`00D]/005;K00000U;K00X005;KD]/005;K001Bf`00D]/001aoo`03001oogoo05Yoo`00B7oo
00<007ooOol0?Goo00X005KK001Ff`00E]/005KK001Ff`T0000<E]/005KK001Ff`00E]/005KK001F
f`000UKK010005KK001Ff`00E]/005;K001Bf`00D]/005;K001Bf`80000MD[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/004jk001>^`00C[/004jk001>^`0200001DjK001:W000BY`0
0P0000E:W000AY`004Il00@00004@W/00000?U/200001CXk00000000;O/00`0000<Q^P0000002@00
00@Y=@000011eP<0000ACQH0058F001B5P00DSH005Hf001F=P00ESH005Hf001F=P0500001UYF001J
EP00GUH0009NMP04001RMF9e0002IWD00`00IYD00002J[D01@00K[A^]6jd00000g;D0P000W;d00D0
07;eL_Ebm@0000Afm@05001bm@00MaD00003MaD01@00LaD007LE00000g<F00D007<F001c5P0000=c
5P05001c5`00LaH00002LaL01@00LaL007<G00000flG00@006lGKaL0009_6005001_66lHKaP00002
KaP01000KaQ_60000VlH00@006lHKaP0009[6004001[66/H0002JaT01000JaT000000V/I00L006/I
JaT006/I001[6@0200000f/I0000000500001F/I001[6F/I00000V/I00@006/I001[6@80009[6@04
001[6F/I0002KaT01000KaU_6@000VlH00P006lHKaP006lH001_60000VlH00L006lH001_6000KaP0
0002KaP01`00KaP006lH001_6000009_6007001_6000KaP006lH00000VlH00T006lH001_5`00KaP0
06lH00000VlH00@006kh0000009Zn004001Zn6[h0002J_P30002J_P01P00I_QVn000I]P0009Vf0<0
0006H]P006;IH]T006;I0P000Uji01@005ji001J^@00FYT005JI001FV@00DWT0059j001>NP00BUX0
04YJ0`0000=2>P00?QX00P0000@j6P00000]fP800004:MX000009KX300000afJ0000000400001AfJ
000000007KX00`0000DQf`00000002GK008000049O/00000:O/3000012Wk000002Wk0`0000<Un`00
9O/0100000DM^`00000001FJ00H00007:A@003fE0015eP00COH00P0000YB5P00DQH005Hf001F=P00
ESH000=F=P0A001F=P00ESH005Hf001J=P00FSH005YF001JEP00GUH00002HWD00`00IWEVM@030003
L[<00`00M_<00003Oa401000Oc5o<@000Wla00<007lb00000gmB00<007mCOe<00WmC0P000WmD00<0
07mD00000W]D00<007]E00000W]E00T007]FNeIkEP00NeH007]F00000gMF00@007MGMeL0009gE`04
001gEgMG0002LeP01@00LcP007<h00000W<h00@007<hLcP0009c>003001_>000009_>004001_>Fli
0002KcT01000KcU_>@000Vli00<006li00000Vli00@006liKcT0009_>@04001_>@00KcT20002KcT0
0`00KcT00002JcT30002JcT01000JcU[>@000Vli00<006/i00000Vli00@006li001_>@800005KcT0
06lIKaT00002KaT30002KaT00`00KaT00002KaT01P00JaU[6@00KaT0009_6003001_6000009[6@03
001[6000009[6008001[66/H001[6@00JaT0009Zn@04001Zn@00J_T2000016Ki001Vn@000VKi00H0
06Ki001Vn@00H]T2000026;I001Rf@00H]T005kI0002G]T01P00G[T005ji001J^@80009J^P0@001F
VP00EYX005JJ001BVP00DYX005:J001>NP00CWX200003DYj001:NP00BUX004YJ0016FP00AUX004IJ
00800005@U/0049K0012F`0400001D9K0012F`00@U/00P000T9K0P0000m2F`000000049K0012F`00
@U/0049k0012N`00AW/00P0000E6N`00AW/004Ik00D00003BY/004ZK0080000iBY`004ZL001:W000
BY`004jL001>W000CY`004jl001>_000C[`004jl001>^`00C[/004jk001>^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0080000HD[/005:k001B^`00
D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`000U;K00L005;K001Bf`00D]/0000LOol0
0`00Oomoo`1JOol004Qoo`03001oogoo03ioo`T00007E]/005KK001Ff`00E]/00P000UKK01/005KK
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005;K001Bf`00D]/005;K00000U;K0P0001MB
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00C[/004jk00800003C[/004jk0080
000;CY/004ZL001:W000BY`004ZL0016W00200000dIl0012O00300000ciK000nF`030000138K0000
02Wk100000<AF@0000001P0000HY=@000011eP00BOH300002e8F001B5P00DSH005Hf001F=P00ESH0
1@0000QJ=P00FSH005YF001JEP000UiF00<005if00000V9e00H006IeIWD006JE0002J[D01@00K[A^
]6jd00000g;D0P000W;d00D007;eL_Ebm@0000Afm@05001bm@00MaD00004MaD20002MaD01@00LaIc
5W<F00000g<F00D007<FLaIc5P00009c5P04001c5g<GLaL200000g<G001_5`02KaL01000KaM_5`00
0flH00D006lHKaP006lH0080009_6004001_66lH0002KaP01000JaQ[60000f/H00@006/IJaT0009[
6@05001[6F/I001[6@070002JaT01@00JaU[6@00JaT00P000V/I00@006/IJaT0009[6@04001[6F/I
0002JaT01000JaT006lI0P000VlI00@006lHKaP0009_6080009_6004001_66lH0002KaP01000KaQ_
60000VlH00@006lHKaP0009_6004001_66lH0002KaP01000KaQ_60000VlH00@006lHKaP0009_6004
001_66lH0002KaP01P00K_Q^n000J_P0009Zn004001Zn6[h0002J_P00`00J_P00002I_P00`00I]P0
0002I]P00`00I]P00002H]P03@00H]T006;I001N^@00G[T005ji001J^@00009JV@0:001FV@00EYT0
059i001BNP00CWX2000014YJ0000048j0P0000<n6P00>QX00P0000@enP00000]fP800005:KX00000
000MVP0500000aVJ0000000200001Afj000000008K/00P0000DQf`00000002Gk008000059O/00000
000Yn`02000012Wk000002Wk0`0000@Un`00000Qf`<000037KX000000080000H3ET00000000Y5000
?ID004GF001=mP00DQH0058F001B5P00ESH005Hf001F=P000UHf014005Hf001F=P00ESH005Xf001J
=P00FUH005YF001NEP00009RM@06001VMFIe001ZU0000g:c0P0017lA00@007laOc40009o<@8000Ao
DP07001oDgmCOe<007mC00000WmD00<007mD00000W]D00<007]E00000W]E00T007]FNeIkEP00NeH0
07]F00000gMF00@007MGMeL0009gE`05001gEgMGMeL00002LeP01000LcQc>0000W<h00@007<h0000
009c>003001_>6lh00800008KcP006liKcT006li001_>@80009_>@03001_>Fli00<0009_>@04001_
>Fli0002KcT00`00KcT00002KcT00`00KcT00002JcT01000JcU[>@000V/i00@006/i001_>@80009[
>@03001_>@00009_>@03001_>@00009_>@03001_6@00009_6@06001_6FlI001_6@000VlI0`000V/I
00P006lIKaT006lH001_60000V/I00L006/HJaP006/H001[60020002JaT20002J_T01P00J_UZn@00
I_T0009Vn@80009Vn@04001Vn@00I_T2000026;I001Rf@00H]T006;I0002G]T01`00G]T005ji001N
^@00009J^AH00003BWX004Yj00800009BUX004IJ0016FP00AUX004IJ00800005@U/0049K0012F`04
00002D9K0012F`00@U/0049K0012F`0200000d9K0000000300002D9K0012N`00@W/004Ik0016N`02
00001dIk0016N`00AW/004JK00L00003BY`004ZL0080000HBY`004jL001>W000CY`004jl001>_000
C[`004jl001>^`00C[/004jk001>^`000U:k01P005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/300005U:k001B^`00D[/005;K001Bf`00D]/005;K001Bf`00D]/005;K
001Bf`000U;K00T005;K001Bf`00D]/005;K000077oo00<007ooOol0FWoo0018Ool00`00Oomoo`0n
Ool02@00E]/005KK001Ff`00E]/00002E]/01P00E]/005KK001Ff`80000<E]/005KK001Ff`00E]/0
05KK001Ff`000UKK02H005KK001Ff`00E]/005;K001Bf`00D]/005;K001Bf`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k0P0000M>^`00C[/004jk001>^`0200001DjK001:
W000BY`00P0000M:W000AY`004Il0016O00200001d9l00000000?U/003Xk00<00005;O/00000000Q
^P0:000022Te0000047F0019mP00COH=000035Hf001F=P00FSH005Xf001JEP00FUH0009NEP03001N
MP00009RM@07001VMFIe001VU@00J[D00P0016jd00@007;DL]@000Abm004001bmG;e0004M_D01@00
L_D007LE000017LE00D007LEMaEg5@0000=c5P05001c5W<FLaH00003LaH01@00LaIc5W<F00000W<G
00D007<GLaMc5`00009_5`05001_5`00KaL00002KaP01@00KaQ_66lH00000VlH00X006lHKaP006lH
001_6000KaP0009[6005001[66/H001[6@0200000f/I0000000500000f/I00000002JaT01@00JaU[
6F/I00000V/I00@006/IJaT0009[6@04001[6@00JaT20002JaT01000JaU[6@000V/I00@006lIKaT0
009_6@07001_6000KaP006lH00000flH00@006lH001_608000=_6004001_6000KaP20003KaP01000
KaP006lH0P000VlH00D006lHKaP006lH0080009_6004001_66lH0002KaP01000K_Q^n0000V[h00@0
06[h001Zn080009Zn006001Zn6[h001Vn0000VKH0`000VKH00/006;H001Rf@00H]T005ji001N^@00
009N^@03001J^@0000h00005BUX0048j0012>P0200000cXJ000j6P05000012WJ000002Fj0`0000<M
VP000000100000DMVP00000001fj00@000048M/000009M/300000bGk000Yn`03000012Wk000002Wk
0`0000@Un`00000Uf`<000057K/00000000EVP05000052TD000mU@00AMH004gf001B5P00DQH0058F
001F=P00ESH005Hf0002ESH04@00ESH005Hf001F=P00FSH005Xf001JEP00FUH005iF00000V9e00@0
06Ie0000009ZU005001b/g:cL[<00004Oa401000Oc5o<@000Wla0P0017mB0P000WmC00H007mCOe<0
07mD0002Oe@02@00Ne@007]E001kE@00NeD00003NeH01P00NeIkEW]F001gEP8000=gE`800005MeL0
07MGMeL00002LeP01@00LcQc>7<h00000W<h00H007<hLcP007<h0002KcP01000KcQ_>0000Vli00@0
06liKcT0009_>@03001_>@00009_>@04001_>Fli0002KcT01000KcT006li0P000Vli00<006li0000
0Vli0`000V/i00@006/iJcT0009[>@03001[>@00009[>@04001_>@00KcT20002KcT00`00KcT00002
KaT30002KaT00`00KaT00002KaT01P00JaU[6@00JaT0009_6@08001_66lH001[6@00JaT0009[6006
001[66/H001[6@000V/I00H006/I001Zn@00J_T200002FKi001VnFKi001Vn@00I_T00002I_T01@00
H_T006;I00000V;I0P000V;I00D005kI001Nf@00009N^@03001N^@0000<0000CF[X005Jj001FVP00
EYX005:J001BVP00DYX0059j001>NP00CWX01`0000a:FP000016FP00AUX004IJ0012F`00@U/20000
0d9K0012F`0300002T9K0000049K0012F`00@U/0049K0P0000A2F`00@U]2F`80000;@W/0049k0016
N`00AW/004Ik0016N`0200002DIk0016V`00BY/004ZK001:V`0700001DZL001>W000CY`00P0000a>
_000C[`004jl001>_000C[/004jk0002C[/0=@00C[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D]/005;K001Bf`00D]/005;K
001Bf`00D]/005;K00000U;K00X005;KD]/005;K001Bf`00D]/001aoo`03001oogoo05Uoo`00B7oo
00<007ooOol0?goo01l005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/00002E]/02000E]/005KK001Ff`00D]/200006e;K001Bf`00D]/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0200002djk001>^`00C[/004jk001>
V`00CY/00P0000M:W000BY`004ZL0016W00200000dIl0012O003000013iK000003Xk0P0000@b6`00
000Yn`@000034ET0000000L0000M>IH00000BOH004gf001B5P00DQH0058f001F=P00ESH005Hf001F
=P00ESH005Xf001J=P00FUH00002FUH01@00GUH005if00000V9e00@006IeIWD0009VU@800003K[D0
06jd009^]004001be7;D0004L_@01@00L_D007Kd000017Ke00D007LEMaEg5@0000=g5@05001g5GLE
MaD00002LaH00`00MaH00002LaH01P00LaIc5P00LaH0009c5P04001c5g<G0003LaL01@00KaM_5flG
00000VlG00D006lHKaQ_6000009_6004001_66lH0002KaP01000KaQ_60000VlH00@006/HJaQ[60L0
009[6@04001[6@00JaT20002JaT01000JaU[6@000V/I00@006/I0000009[6@04001[6F/I0002JaT0
1000JaU[6@000V/I00@006/I001[6@80009_6@04001_6FlI0002KaP01@00KaQ_66lH00000VlH00@0
06lHKaP0009_6004001_66lH0002KaP01000KaQ_60000VlH00@006lHKaP0009_6004001_66lH0002
KaP01000KaQ_60000VlH00T006lH001_6000K_P006kh00000V[h00@006[hJ_P0009Zn003001Zn000
009Zn003001Vn6Kh00<0009Vf00;001Vf000H]P006;I001Rf@00G[T00002G[T500003EZI001FV@00
EYT005:J001BNP00CWX004ij00D00003@SX003hJ00800003>QX003Gj00<00004:MX000009KX30000
0afJ0000000300000afJ00000002000011fj0000026k0`0000@Qf`00000Un`<00004:O/00000:O/3
00000bWk000Yn`03000012Gk0000027K100000<IVP0000000P0001H9>@00:A@003fE0015eP00COH0
058F001B5P00DQH005Hf001F=P00ESH0009F=P0?001F=P00ESH005Hf001J=P00FSH005YF001JEP00
009NEP06001RM@00001RM@000VZD00D007:cL[=b/`0000Ao4@800003Oc4007la009o<@05001oDWmB
Oe800002Oe800`00Oe<00002Oe<20003Oe@20003NeD200000g]E001kEP02NeH02@00NeIkEW]F001g
EP00MeL00002MeL01000MeMgE`000WMG00D007=H001cF000009c>004001c>7<h0002LcP00`00LcQc
>0030003KcP01000KcT006li0P000Vli00<006liKcT00`000Vli00@006liKcT0009_>@03001_>@00
009_>@03001_>Fli00<0009[>@07001[>F/i001[>@00JcT00P000V/i00<006/i00000Vli00<006/i
00000Vli00<006li00000VlI00@006lIKaT0009_6@03001_6@000080009[6@07001[6F/I001_6@00
KaP00P0000Q[6@00JaU[6@00JaP006/H0P000V/I00D006/I001[6@00009Zn@03001Zn@00009Vn@05
001Vn@00I_T00002I_T300003F;i001RfF;I001Rf@00H]T006;I001Nf@00009Nf@D00003F[X00000
009J^P0@001F^P00EYX005JJ001BVP00DYX005:J001BNP00CWX200001Dij001:NP00BWX01P0000]6
FP00AUX0049K0012F`00@U/0049K00800003@U/0000000@00092F`0;0012F`000012F`00@U/0049K
0012N`05000034Ik000004Ik0016N`00AW/004Ik0016V`800009BY/004ZK001:V`00BY/004ZK00T0
000[C[`004jl001>_000C[`004jk001>^`00C[/004jk001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P0001EB^`00D[/005:k001Bf`00D]/005;K001B
f`00D]/005;K001Bf`00D]/0300077oo00<007ooOol0FGoo0018Ool00`00Ool00002000mOol01`00
E]/005KK001Ff`00009Ff`08001Ff`00E]/005KK001Ff`80009Ff`0D001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK001Bf`800005D]/005;K001Bf`0L00003Djk001>^`00CY/004jK001:
W000BY`004ZL00800003AY`004Il00800003@W`0049l00<00004>U/00000=S/200001Bgk00000000
7IX02`0000<iUP00@MH00P0001A=mP00DQH0058F001B=P00ESH005Hf001F=P00ESH005Hf001J=P00
0UXf00T005YF001JEP00GUH005if00000V9e00@006IeIWD0009VU@800003K[D006jd009^]004001b
e7;D0004L_@01@00L_D007Kd000017Ke00D007LEMaEg5@00009g5@03001g5@0000=g5@05001c5P00
MaH00003LaH20002LaH02000LaIc5P00LaL007<G0003LaL01000KaM_5`000VlG00T006lHKaQ_6000
KaP006lH00000VlH00@006lH001_60T00003JaP00000009[6@04001[6F/I0002JaT00`00JaT00002
JaT01@00JaU[6F/I00000V/I00@006/IJaT0009[6@04001[6@00JaT20002JaT01000JaU[6@000V/I
00@006/IJaT0009_6@04001_6@00KaP20003KaP01@00KaQ_6000KaP00P000VlH00D006lHKaP006lH
0080009_6005001_66lH001_60020002KaP01000KaQ_60000VlH00@006lHKaP0009_6004001_66lH
0002K_P01`00K_Q^n000J_P006[h0080009Zn006001Zn6[h001Zn0000VKh00<006KH00000VKH00<0
06KH00000V;H0P000V;I00<005ji00000P0000IN^@00F[T005ZI0002EYT01P00EYT005:J001BNP80
0003CWX004YJ00D00003?QX003XJ00800004=OX00000<OX2000012Vj000002Fj1P0000DM^P000000
01fj00<000058KX00000000Uf`0200001BGK000000009O/00P0000@Yn`00000Yn`<00004:O/00000
9O/30000127K000001fk0`0000<EVP0000000P0001@Y5000?ID004GF001=mP00DQH0058F001B5P00
ESH005Hf001F=P000UHf00d005Hf001F=P00ESH005Xf001J=P00FUH00002FUH01@00GUH0069e0000
0V9e00@006ZDJY@000=b/`03001o4GlA009o4@800003Oc4007la009o<@05001oDWmBOe800002Oe82
0004Oe<00`00OeAoE002Oe@01@00NeEkEG]E00000g]E00D007]F001kEP0000=kEP04001gEgMG0002
MeL01@00MeMgEgMG00000WMG00@007=HLeP0009c>004001c>0000002LcP01000LcQc>0000Vlh00@0
06lhKcP0009_>@06001_>Fli001_>@000Vli00@006liKcT0009_>@04001_>@00KcT20002KcT00`00
KcT00002KcT00`00JcT00002JcT01000JcU[>@000V/i00<006/i00000V/i00<006/iJcT00`000V/i
00<006li00000Vli0`000VlI00H006lIKaT006lI0002JaT00`00JaT00002JaT02000KaU_6@00JaT0
06/I0002JaT01P00JaQ[6000JaT0009[6@06001[6@00JaT006[i0P000V[i00P006Ki001Vn@00I_T0
06Ki0P0000eVn@00H_URn@00H]T006;I001Rf@00H]T00002G]T300007eji001N^@00F[X005Zj001J
^P00E[X005JJ001FVP00DYX005:J001BVP00DWX004ij001>NP00CWX004Yj00800003BWX004YJ00<0
000<AUX00000@U/0049K0012F`00@U/0049K0P0000=2F`00@U/00`0000E2F`00@U/0049K00800009
@U/0049K0012N`00@W/004Ik00H0000;AW/004Ik0016N`00AY/004ZK001:V`0200003DZK001:V`00
BY/004ZK001>V`00CY/004jK00l0000LC[/005:kD[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/I00002e;K001Bfe;K001Bf`00D]/005;K000077oo00<007ooOol0
FGoo0018Ool20011Ool02@00E]/005KK001Ff`00E]/00002E]/200004eKK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK00l0000GD[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001>^`0200000djk001>^`0:00001dZL001:W000BY`004JL00800003AW`0049l00<0
0004?U/00000=S/20000138K000002Wk3@0000<iUP00@MH00P00019=mP00DQH0058F001B=P00ESH0
05Hf001F=P00ESH005Hf0002FSH02`00FSH005YF001JEP00GUH005if00000V9e00@006IeIWD0009V
U@04001^]Fje0003K[@01@00L]@007;D00000g;d00D007;e001fm00000Afm@03001g5GLE009g5@05
001g5@00MaD00003MaD01@00LaH007LF00000g<F00D007<FLaIc5P0000=c5P04001c5g<G0003LaL0
1@00KaL007<G00000VlG00D006lHKaQ_6000009_6003001_66lH00L0009_6005001[66/HJaP00002
JaP01`00JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT01000JaT000000V/I00@006/IJaT0
009[6@04001[6F/I0002JaT01000JaT006/I0P000V/I00@006lIKaT0009_6@04001_66lH0003KaP0
1000KaQ_60000VlH00@006lHKaP0009_6004001_66lH0002KaP01000KaQ_60000VlH00X006lHKaP0
06lH001_6000KaP0009_6004001_6000KaP20002K_P01000K_Q^n0000V[h00H006[hJ_P006[h0002
J_P00`00J_QZn0030002I]P00`00I]P00002I]P01000H]P006;I1@00019N^@00G[UN^@00F[T005ZI
001FV@00EYT005:J001BNP00CWX2000014YJ000004IJ100000<j6P00>QX00P0000@anP00000]fP80
00059KX00000000Q^P0200001AfJ000000007IX00`0000@Q^P00000Q^`<000049M/000009O/30000
12Wk000002Wk0`0000@Yn`00000Un`8000059O/00000000Qf`0300000aVJ0000000400004bTD0000
04GF001=mP00DQH0058F001B5P00ESH005Hf001F=P00009F=P09001F=P00ESH005Hf001J=P00009J
=P06001JEP00FUH005iF0`000V9e00@006ZDJY@000=b/`09001o4GlAOa4007l`001o<@0000=o<@80
009oDP05001oDWmBOe800004Oe<00`00OeAoE002Oe@01@00NeEkEG]E00000g]E00D007]F001kEP00
00=kEP08001gEgMG001gE`00MeL0009gE`04001gEgMG0003LeP01000LcQc>0000W<h00<007<hLcP0
0`000Vlh00D006lhKcP006li0080009_>@03001_>Fli00<0009_>@04001_>Fli0002KcT00`00KcT0
0002KcT00`00KcU_>@030002JcT01`00JcU[>@00JcT006/i0080009[>@03001[>@00009[>@03001[
>@00009[>@03001_>@00009_>@04001[6F/I0002KaT01@00KaT006lI00000V/I00L006/IJaT006/I
001_6@020002JaT01P00JaT006/I001[6080009[6@03001[6@00009[6@<00007J_T006[iJ_T006Ki
00000VKi0`0000iVn@00I_UVn@00H_T006;I001Rf@00H]T006;I100000INf@00G[T005ji0002F[X2
00006eZj001F^P00EYX005JJ001BVP00DYX005:J001BNP00CWX004ij001>NP00BWX004Yj001:NP02
00000dIJ0000000400002d9K0012F`00@U/0049K0012F`00@U/00P0000e2F`000000049K0012F`00
@U/0049K0012F`0200001d9k0016N`00AW/004Ik00<0000BAW/00000AW/004JK001:V`00BY/004ZK
001:V`00BY/004ZK0P00019>V`00CY/004jK001>^`00C[/004jk001>^`00C[/004jk0002C[/M0000
6U:k001B^`00D[/005:k001B^`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K0002D]/01`00
D]/005;K001Bf`0001eoo`03001oogoo05Qoo`00B7oo00<007ooOol0@Goo00X005KK001Ff`00E]/0
05KK001Ff`800005E]/005KK001Ff`0>00002EKK001Ff`00D]/005;K001Bf`02000015;K001Bf`00
0U:k01H005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001>^`80000<C[/00000
C[`004jl001>W000BY`004ZL1P0000Q6W0000016O000@W`0049l0`0000@jF`00000f6`800005;O/0
0000000MVP0300000`3G0000000400001cVF0011eP00BOH004gf00800008DQH0058f001F=P00ESH0
009F=P0?001F=P00ESH005Xf001J=P00FUH005YF001NEP00009NMP03001RM@00009VM@04001VUFJE
0002K[D02@00K[A^]6jd001be000L]@00003L_@01@00L_D007Kd00000gKe0P0017LE00D007LE001g
5@0000Ag5@05001g5WLFMaH00002LaH00`00LaIc5P02LaH01000LaIc5P000g<G00D007<GLaMc5`00
009c5`04001_5flG0002KaP800000flH00000002KaP01@00KaQ_66lH00000V/H00@006/HJaP0009[
6@04001[6F/I0002JaT00`00JaT00003JaT01000JaU[6@000V/I00L006/IJaT006/I001[6@020002
JaT01000JaU[6@000V/I00@006/IJaT0009[6@04001_6@00KaT20003KaP01@00KaQ_6000KaP00P00
0VlH00@006lHKaP0009_6004001_66lH0002KaP01000KaQ_60000VlH00@006lHKaP0009_6004001_
66lH0002KaP01000KaQ_60000VlH00L006khK_P006kh001Zn0020002J_P01P00J_QZn000J_P0009Z
n006001Vn6Kh001Vf0000VKH00/006KH001Rf000H]T006;I001N^@00009N^@0D001N^@00F[T005ZI
001FV@00EYT005:J001BNP00CWX004ij001:FP<00003@SX0000000800003>QX003Gj00800005<OX0
0000000U^P0300000b6j0000000200001Afj000000007KX0100000@Q^`00000Uf`<000049O/00000
9O/300000bWk000Yn`03000012Wk000002Gk0`0000@Qf`00000M^`@000044GX00000=E@3000044GF
001=mP00DQH0058F001B5P00ESH005Hf001F=P000UHf00D005Hf001F=P00009F=P08001J=P00FSH0
05YF001JEP<00005GUD0069eHWD00002JY@01@00L[=b/g:c00000glA00D007l`001o<@0000=o<@80
009oDP05001oDWmBOe800003Oe<00`00Oe<00002Oe@01`00Oe@007]E001kE@0000=kE@09001kEW]F
NeH007]F001gE`00009gE`800009MeL007MGMeL007MG001cF000009cF004001c>0000002LcP01000
LcQc>0000W<h00@006lhKcP0009_>006001_>Fli001_>@000Vli00@006liKcT0009_>@04001_>@00
KcT20002KcT00`00KcT00002KcT01P00JcU[>@00JcT0009[>@06001[>@00001[>@000V/i00<006/i
JcT00`000V/i00<006/i00000Vli0`000V/I00@006lIKaT0009_6@03001[6@00009[6@03001[6@00
009[6@03001[6@00009[6@03001[6@00009[6@03001[6@00009[6@03001[6@00009[6@03001Zn@00
009Zn@05001Zn@00I_T00002I_T01@00I_T006Ki00000VKi00D006;i001Rf@00009Rf@<00006H]T0
05kI001Nf@000Uji00@005ji001J^P80009J^P0@001F^P00EYX005JJ001BVP00DYX005:J001BNP00
CWX200002Dij001:NP00BWX004Yj001:FP0200000dIJ0016F`0300000d9K00000002@U/01`00@U/0
0000@U/0049K00800092F`@00009@U/0049K0012F`00@W/0049k00800005AW/004Ik0016N`050000
0dIk0016V`0200004DZK001:V`00BY/004ZK001:V`00BY/004jK001>V`00CY/00P0000Q>^`00C[/0
04jk001>^`000Tjk034004jk001>^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D]/005;K001Bf`00D]/00002D]/02@00
D]/005;K001Bf`00D]/00002D]/01@00D]/005;K000077oo00<007ooOol0F7oo0018Ool00`00Oomo
o`11Ool02000E]/005KK001Ff`00E]/900003UKK001Ff`00E]/005KK001Ff`00E]/005KK0002E]/0
2000E]/005;K001Bf`00D]/200006e;K001Bf`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001>^`0200002djk001>^`00C[`004jl001>W000BY`00P0000E:W000BY`004JL
00D00003@W`0049l00800004?U/00000=S/20000138K000002Wk2`0002<Y=@000011eP00BOH004gf
001B5P00DQH0058f001F=P00ESH005Hf001F=P00ESH005Xf001J=P00FUH005YF001NEP00009NMP03
001RM@0000=VM@03001VU@00009^]@09001^]6jdK[@007;D001be00000Abm005001fm7KdM_@00002
M_D00`00Ma@00003MaD20003MaD01@00MaEg5GLE00000gLF00D007<F001c5P0000=c5P05001c5P00
LaL00003LaL01000LaMc5`000W<G1P000VlH00@006lHKaP0009_6004001_66lH0002KaP02000KaQ_
6000JaP006lH0002JaP01000JaT006/I0P000V/I00@006/IJaT0009[6@04001[6@000002JaT01000
JaU[6@000V/I00@006/IJaT0009[6@04001[6@00JaT20002JaT01000JaU[6@000VlI00@006lIKaT0
009_6005001_66lHKaP00002KaP02P00KaQ_6000KaP006lH001_60000VlH00L006lH001_6000KaP0
0002KaP01000KaP006lH0P000VlH00D006lHKaP006lH0080009_6004001^n6kh0002K_P01P00J_QZ
n000J_P0009Zn003001Zn6[h00<0009Vn003001Vf000009Vf003001Vf000009Rf080000=H]T005ji
G[T005ji001N^@00F[T005ZI00000UJI00H005JI001BVP00DWX200000dij001:FP02000014IJ0000
03hj100000HenP00000anP00;MX300000bFj0000000300000afJ00000002000011fj0000026j0`00
00@Qf`00000Uf`<000049O/00000:O/3000012Wk000002Wk0P0000@Un`00000Un`@000047K/00000
6IX4000013ED000003fE0P0000i=mP00DQH0058F001B5P00ESH005Hf001F=P000eHf00`005Hf001F
=P00ESH005Xf001J=P00FUH3000015YF001NE@000f9e00<006ZD00000g:c0P000WlA00@007l`0000
00=o<@06001oD7m@001oDP000gmB0P000WmC00`007mCOe<007mD001oE000NeD007]E0003NeD02@00
NeIkEW]F001kEP00MeL00002MeL01@00MeMgEgMG00000WMG00@007=HLeP000=cF006001cF7=H001c
>0000W<h00@007<hLcP0009_>004001_>0000002KcT00`00KcU_>@030002KcT01000KcU_>@000Vli
00<006li00000Vli00<006liKcT00`000V/i00@006/iJcT0009[>@03001[>@00009[>@03001[>@00
009[>@03001[>@00009[>@03001[>F/i00<0009[6@07001[6F/I001_6@00KaT00P0000Q[6@00JaU[
6@00JaT006/I0P000V/I00H006/I001[6@00JaT20002JaT00`00JaT00002JaT300001f[i001ZnF[i
001Zn@00009Vn@<00009I_T006KiI_T006Ki001Rn@00009Rf@<00006H]T006;I001Nf@000UkI0200
05ji001N^@00F[X005Zj001J^P00E[X005JJ001FVP00DYX005:J001BVP00DWX004ij001>NP00CWX0
04Yj0P0000M:NP00BUX004IJ0016FP0200000dIK0000000300001D9K0012F`00@U/00P0000U2F`00
@U/0049K0012F`00@U/00P0000]2F`00@U/0049k0012N`00AW/004Ik00800005AW/004Ik0016N`07
00007DZK000004ZK001:V`00BY/004ZK001>V`00CY/004jK001>^`00C[/004jk001>^`00C[/004jk
00000Tjk00X004jk001B^`00D[/005:k001B^`800004D[/005:k0002D[/02P00D[/005:k001B^`00
D[/005:k0`0001QB^`00D[/005:k001B^`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K0002
D]/01`00D]/005;K001Bf`0001aoo`03001oogoo05Qoo`00Agoo00<007ooOol0@goo1`0000=Ff`00
E]/00P0000AFf`00E]/0009Ff`0F001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005;K001B
f`00D]/2000015;K001Bf`000U:k01H005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001>^`80000@C[/00000C[`004jl001>W000BY`004ZL001:W000BY`2000014Il0000049l1000
00@nG000000jF`800004=Q/00000:O/400000aEi0000000500008BTe0000047F0019mP00COH0058F
001B5P00DSH005Hf001F=P00ESH005Hf001F=P00FSH005Xf001JEP00FUH00002GUH01@00GWH0069e
00000fIe0`000Vje00<006jdK[@00Vjd0P0000=be000L_@00g;d00D007KdM_Afm000009fm@03001g
500000Ag5@05001g5GLEMaD00002MaD00`00MaD00002MaH01@00LaH007<F00000g<F00D007<F001c
5`00009c5`L00005LaL006lGKaL00003KaP01000KaQ_60000VlH00@006lHKaP000=_6004001_66lH
0002KaP01000JaQ[60000V/I00@006/IJaT0009[6@03001[6@00009[6@80009[6@07001[6F/I001[
6@00JaT00P000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01000JaT006lI0P000VlI00H006lH
KaQ_6000KaP20002KaP01000KaQ_60000VlH00@006lHKaP0009_6004001_66lH0002KaP01000KaQ_
60000VlH00@006lHKaP0009_6004001_66lH0002KaP00`00KaP00002K_P01000K_Q^n0000V[h00H0
06[hJ_P006[h0002J_P01P00I_QVn000I_P0009Vf003001Vf000009Vf0<00008H]T006;I001N^@00
G[T0009N^@0>001J^@00FYT005JI001FV@00DYX0059j001>NP800006BUX00000AUX0048j0P0000<n
6P0000000P0000@anP00000]fP800005:MX00000000Q^P02000011fJ0000026j0`0000DM^P000000
027K008000059M/00000000Un`0200001BGk00000000:O/00P0000@Yn`00000Yn`<000049O/00000
8M/300000afk000000030002=E@01P00?ID004GF001=mP80000;DQH0058FDQH005Hf001F=P00ESH0
0002ESH02000ESH005Hf001F=P00FSH500001UXf001JEP00GUD000=RM@03001ZU00000=b/`80009o
4@04001o<7l`0003Oc400`00Oe1oD0020003Oe801P00Oe9oDP00Oe<0009oD`07001oE000Oe@007]E
00000W]E00D007]E001kEP0000=kEP04001gEgMG0002MeL01@00MeMgEgMG00000WMG00D007=HLeQc
F000009cF004001cF7=H0002LcP200001G<h001c>7<h00000Vlh00<006li00000Vli00@006liKcT0
009_>@07001_>Fli001_>@00KcT00P000Vli00<006li00000Vli00@006liKcT0009[>@04001[>@00
JcT20002JcT00`00JcT00002JcT30002JcT00`00JcT00002JcT00`00JaT00002JaT01000JaU[6@00
0VlI00<006/I00000V/I00@006/I001[6@800005JaT006/IJaT00002JaT300001f/I001[6F/I001[
6@00009[6@03001[6@00009Zn@03001Zn@00009Zn@<0000;I_T006KiI_T006Ki001Vn@00H_T00002
H]T01@00H]T006;I00000V;I02P005kI001Nf@00G[T005ji001J^P00F[X005Zj001F^P00EYX005JJ
001BVP00DYX005:J001BNP00CWX004ij001>NP00BWX004Yj001:NP800005AUX004IJ0016F`020000
0dIK0016F`0300001D9K0012F`00@U/00P0000U2F`00@U/0049K0012F`00@U/01P0000M2N`00AW/0
04Ik0016N`0200002DIk0016N`00AW/004ZK001:V`0500001DZK001:V`00BY/00P00011>V`00CY/0
04jK001>^`00C[/004jk001>^`00C[/0009>^`0N001>^`00C[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k0`0001QB^`00D[/005:k001B^`00D]/005;K001B
f`00D]/005;K001Bf`00D]/005;K0002D]/01`00D]/005;K001Bf`0001aoo`03001oogoo05Qoo`00
Agoo00<007ooOol0@goo00L005KK001Ff`00E]/00002E]/05000E]/00000E]/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK0002E]/02P00E]/005KK001Bf`00D]/005;K0P0000ABf`00D]/0009B^`0<
001B^`00D[/005:k001B^`00D[/005:k0P0000UB^`00D[/005:k001>^`00C[/00P0000U>^`00C[`0
04jl001>W000BY`00P0000M:W000BY`004JL0016O00300000d9l0012O00200000ciK000jF`030000
138K000002GK1@0000<0e`0000000P00024Y=@000011eP00BOH004gf001B5P00DQH0058f001F=P00
ESH005Hf001F=P00ESH005Xf001J=P00FUH005YF00000UiF00<005if00000V9e00<006IeIWD00`00
0Vje00<006jdK[@00Vjd00@007;DL]@000Abm007001fm7KdM_@007Ke00000WLD00<007LEMaD00WLE
00L007LEMaEg5@00MaD00002MaD01@00MaIg5WLF00000g<F00@007<FLaIc5PH0009c5`04001c5g<G
0002LaL01000KaM_5`0016lH00L006lH001_6000KaP00002KaP01@00KaQ_6000KaP00P000flH00@0
06/H001[6@80009[6@04001[6F/I0002JaT200001F/I001[6F/I00000V/I00@006/IJaT0009[6@07
001[6F/I001[6@00JaT00P000V/I00@006/IJaT0009[6@04001[6F/I0002KaT01@00KaQ_66lH0000
0VlH00L006lHKaP006lH001_60020003KaP01000KaP006lH0P000VlH00D006lHKaP006lH0080009_
6004001_66lH0002KaP01000KaQ_60000VlH00<006khK_P00P0000AZn000J_P0009Zn003001Zn6[h
00<0009Vn006001Vn6Kh001Vf0000VKH0`0000QRf@00H]T006;I001N^@000Uji010005ji001J^@00
FYT005JI001FV@00DYX0059j001>NP800003BUX004IJ00800003@SX003hj00800003>QX000000080
0004<OX00000;MX400000b6j0000000200001Afj000000008KX00P0000<Q^P0000000P0000<Uf`00
9M/00`0000@Un`00000Yn`<00004:O/00000:O/200001BGk000000009M/00`0000@M^`00000IVP@0
000D=E@000000015eP00COH0058F001B5P00DQH005Hf001F=P00ESH0009F=P04001F=P00ESH50000
25Hf001J=P00FSH005YF0002GUD01P00HWERM@00JY@000=b/`80009o4@04001o<7l`0003Oc401@00
Oe1oD7m@00000gmB00<007mBOe800P0017mC00D007mDOeAoE00000=kE@05001kE@00NeH00003NeH0
1000MeMgEgMG0P0000UgE`00MeMgE`00MeL007MG00000W=H00@007=H0000009cF004001c>7<h0002
LcP01@00LcQc>000KcP00P000Vli00<006liKcT00`000Vli00@006liKcT0009_>@03001_>@00009_
>@03001_>Fli00<0009_>@04001[>F/i0002JcT00`00JcT00002JcT00`00JcT00002JcT01P00JcU[
>@00JcT0009[>@<0009[6@07001[6F/I001[6@00KaT00P000V/I00<006/I00000V/I00<006/I0000
0V/I00<006/I00000V/I00<006/I00000V/I00<006/I00000V/I0`000V/I00D006[i001Zn@00009Z
n@03001Vn@00009Vn@07001Vn@00I_T006Ki00000V;i0`0001=Rf@00H]URf@00H]T005kI001Nf@00
G[T005ji001J^P00F[X00002F[X00`00E[X0000?00002Dij001:NP00BWX004Yj001:FP0200001dIJ
0016F`00AU/004IK00800092F`@00009@U/0049K0012F`00@U/0049K00800005@U/0049K0012N`03
0000349k000004Ik0016N`00AW/004Ik0016N`800007BY/004ZK001:V`00BY/02@0000E>V`00CY/0
04jK00800008C[/004jk001>^`00C[/0009>^`0a001>^`00C[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005;K001Bf`00
D]/005;K00000U;K00T005;K001Bf`00D]/005;K00000U;K00D005;K001Bf`0001aoo`03001oogoo
05Moo`00Agoo00<007ooOol0A7oo00X005KK001Ff`00E]/005KK001Ff`80000CE]/005KKE]/005KK
001Ff`00E]/005KK001Ff`00E]/005KK00000UKK0P0001UBf`00D]/005;K001Bf`00D]/005;K001B
^`00D[/005:k001B^`00D[/005:k001B^`0200004e:k001B^`00D[/004jk001>^`00C[/004jk001>
_000C[`004jL00800005BY`004ZL001:W00200001TIl0000049l0012O0800006?U`00000>U/003Hk
0`0000<Yn`0000000`0000<9>@0000001@0001diUP000019mP00COH0058F001B5P00DSH005Hf001F
=P00ESH005Hf001F=P00FSH005Xf001JEP00009JEP05001NEP00GWH00002HWD01P00IWEVM@00JYD0
00=^]@05001^]6jdK[@00003L]@00`00L_Abm0020003M_@00`00M_D00003Ma@01P00MaEg5@00MaD0
00=g5@80009g5@04001g5WLFMaH90003LaL01@00LaMc5g<G00000W<G00P007<GLaL006lG001_5`00
0flH00@006lHKaP0009_6004001_66lH0002KaP20002KaP01000KaQ_60000V/H00@006/IJaT0009[
6@04001[6@00JaT20003JaT01`00JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT01000JaU[
6@000V/I00@006/I001[6@80009[6@05001_6FlIKaT00002KaP01000KaQ_60000VlH00@006lHKaP0
009_6004001_66lH0002KaP01000KaQ_60000VlH00@006lHKaP0009_600<001_66lH001_6000KaP0
06lH001_60000VlH00@006khK_P0009Zn006001Zn6[h001Zn0000V[h00H006[hJ_P006Kh0002I_P0
1000I]P006KH0P0000QRf000H]T006;I001Rf@000Uji00T005ji001N^@00F[T005ZI00000UJI00H0
05JI001BVP00DWX300001DYJ0016FP00AUX00P0000<n>P00?QX00P0000Hj6P00000anP00;MX20000
12WJ0000026j0`0000@Q^P00000Q^P@000048KX000008M/3000012GK000002Gk0`0000@Yn`00000Y
n`800004:O/00000:O/3000012Gk0000027K100000<IVP0000000P0000<eE000AMD00`0000m=mP00
DQH0058F001B5P00ESH005Hf001F=P00ESH01P0000aF=P00ESH005Hf001J=P00FSH005YF0002GUD0
1P00HWERM@00JY@000=b/`80009o4@04001o<7l`0003Oc401@00Oe1oD7m@00000gmB00D007mBOe9o
DP0000AoD`05001oE7mDOe@00004NeD02@00NeIkEW]F001kEP00NeH00002MeL01000MeMgE`000gMG
00@007MGMeL000=cF004001cF7=H0002LeP30003LcP01P00LcQc>000KcT0009_>@04001_>Fli0002
KcT01`00KcU_>@00KcT006li0080009_>@03001_>@00009_>@04001_>Fli0002KcT01000JcT006/i
0P000V/i00<006/i00000V/i0`000V/i00<006/i00000V/i00H006/IJaT006/I0002JaT01P00JaU[
6@00JaT0009[6@04001[6@00JaT200001F/I001[6F/I00000V/I0`0000M[6@00JaU[6@00JaT00002
JaT00`00JaT00002JaT00`00J_T00002J_T300002FKi001VnFKi001Vn@00I_T00002I_T300003f;I
001RfF;I001Rf@00H]T005kI001Nf@00G[T00002G[T00`00F[X0000600003EJJ001FVP00EYX005:J
001BVP00DYX004ij00P00007BWX004YJ0016FP00AUX00P0000]6F`00AU/004IK0012F`00@U/0049K
00800009@U/0049K0012F`00@U/0049K00800005@U/0049k0016N`05000034Ik000004Ik0016N`00
AW/004Ik001:V`80000;BY/004ZK001:V`00BY/004ZK001>V`0900002Tjk001>^`00C[/004jk001>
^`000Tjk00X004jk001B^`00D[/005:k001B^`800004D[/005:k0002D[/02P00D[/005:k001B^`00
D[/005:k0`0000mB^`00D[/005:k001B^`00D]/005;K001Bf`00D]/04P0077oo00<007ooOol0Egoo
0017Ool00`00Oomoo`14Ool00`00E]/00002E]/20002E]/02000E]/00000E]/005KK0002E]/03P00
E]/005KK001Ff`00E]/005KK001Ff`00E]/200003E;K001Bf`00D]/005;K001Bf`00D]/005:k01X0
000;C[/004jl001>_000CY`004ZL001:W00200001DZL0016W000AW`00`0000=2O000@W`00P0000<j
G00000000P0000Df6`00000002GK008000035GT0000000H00003>IH0047F0080000DCOH0058F001B
5P00DSH005Hf001F=P00ESH005Hf001F=P00FSH0009J=P09001JEP00FUH005iF001NMP00009RM@04
001VMFIe0002JYD01000K[E^]@000fjd00D007;DL]Abe000009bm003001fm00000=fm08000=g5006
001g5GLE001g5@000gLE00<007LEMaD01`000g<F00D007<F001c5P0000=c5`05001c5`00LaL00002
LaL01000LaMc5`000VlG00H006lHKaQ_6000KaP20003KaP01`00KaP006lH001_6000009_6005001_
66lH001[60020002JaT01000JaU[6@000V/I00@006/IJaT0009[6@05001[6F/I001[6@020002JaT0
1`00JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT01000JaU[6@000V/I00P006lIKaT006lH
001_60000VlH00@006lH001_6080009_6005001_66lH001_60020002KaP01000KaQ_60000VlH00@0
06lHKaP0009_6004001_66lH0002KaP01`00KaQ_6000KaP006kh0080009Zn004001Zn6[h0002J_P3
0002J_P01P00I_QVn000I_P0009Vf003001Vf000009Rf00;001Rf@00H]T006;I001N^@00G[T00002
G[T01000F[T005ZI300000I:FP000016FP00@SX200000chJ000j6P02000013Gj000002gJ0P0000<Y
fP0000000`0000DQ^P000000026j008000058KX00000000Qf`03000012GK000002GK0P0000DUn`00
000002Wk00800007:O/00000000Yn`009O/00`0000DUf`00000001fk00<000085IX00000=E@004GE
001=mPD00003DQH0000000P0000@ESH005Hf001F=P00ESH005Hf001F=P00FSH005Xf0002FUH00`00
GUD00002HWD00`00JY@00002L[<01P00O`mo3`00Oa40009o<080009o<@04001oD7m@Oe020002Oe80
1@00Oe9oDWmB00000gmC00L007md001oE000NgD00003NeD02@00NeIkEW]F001kEP00NeH00002MeL0
1@00MeMgEgMG00000WMG00D007MGMeMgE`00009cF004001cF7=H0002LeP01000LcQc>0000W<h00@0
07<hLcP0009_>@03001_>@00009_>@04001_>Fli0002KcT01P00KcU_>@00KcT0009_>@03001_>Fli
00<0009_>@04001_>Fli0002JcT00`00JcT00002JcT00`00JcU[>@030002JcT01@00JcU[>@00JcT0
0`000V/I00L006/IJaT006/I001[6@020002JaT00`00JaT00002JaT00`00JaT00002JaT00`00JaT0
0002JaT00`00JaT00002JaT00`00JaT00002JaT30002JaT01@00JaT006[i00000V[i00<006Ki0000
0VKi00D006Ki001Vn@00009Vn@<0000=H_T006;IH]T006;I001Rf@00H]T005kI00000UkI00<005ji
0000100001UJ^P00F[X005Jj001FVP00EYX005JJ001BVP00DYX005:J001>NP00CWX004ij001>NP06
00001dIJ0016FP00AU/004IK00800009AU/0049K0012F`00@U/0049K0080000;@U/0049K0012F`00
@U/0049K0012F`0200001DIk0016N`00AW/01P0000e6N`00AW/004Ik001:V`00BY/004ZK001:V`02
00003DZK001:V`00CY/004jK001>V`00C[/004jk01X00003D[/005:k01l0000:D]/005;K001Bf`00
D]/005;K0002D]/01@00D]/005;K000077oo00<007ooOol0Egoo0017Ool00`00Oomoo`15Ool07P00
E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ffa40
000=D[/005:k001B^`00D[/005:k001B^`00D[/00P0000]B^`00D[/004jk001>^`00C[`004jl00X0
0008BY`00000BY`004JL0016O0800003@W`0049l00800006?U`00000>S`003Hk0P0000<b6`009M/0
2`0000<iUP00@MH00P00019=mP00DQH0058F001B=P00ESH005Hf001F=P00ESH005Hf0002FSH02`00
FSH005YF001JEP00GUH005if00000V9e00@006Ie0000009ZU@04001^]Fje0002K[@20003L]@01P00
L_Abm000M_@000=fm003001g57LD009g5003001g5@00009g5@L0009g5@05001g5P00MaH00003LaH0
1@00LaH007<F00000g<G00D007<G001c5`00009c5`04001c5g<G0003KaL01@00KaQ_66lH00000VlH
00@006lHKaP0009_6005001_66lHKaP00002KaP01000KaQ_60000VlH00L006/IJaT006/I001[6@02
0002JaT01@00JaU[6F/I00000V/I00<006/I00000V/I00@006/IJaT0009[6@04001[6F/I0002JaT0
1000JaT006/I0P000V/I00D006/IJaU[6@00009_6@04001_66lH0002KaP01000KaQ_60000VlH00@0
06lHKaP0009_6004001_66lH0002KaP01`00KaP006lH001_6000009_6004001_6000KaP20002KaP0
1000KaQ_60000VlH00@006[hJ_P0009Zn003001Zn000009Zn006001Zn6[h001Zn0000VKh00<006Kh
I_P00`000VKH00/006;H001Rf@00H]T006;I001N^@00009N^@L00009EYT005JJ001BVP00DWX004ij
00L00003@SX003hj00800003>QX003XJ00800004<OX00000;MX800001B6j000000008KX00`0000@Q
f`00000Qf`<000049M/000009O/3000012Wk000002Wk0P0000DYn`00000002Gk008000059O/00000
000Qf`0300003AVj00000000=E@004GE001=mP00DQH0058F00<00008ESH005Hf001F=P00ESH0009F
=P0=001F=P00ESH005Hf001F=P00ESH005Xf00000UXf00D005YF001NE@00009RM@03001ZU000009b
/`06001o3gl?001o4@000Wl`0P000Wla00@007m@Oe00009oD@8000AoDP80009oD`07001oM000Oe@0
07]e00000W]E00<007]f00000g]F00P007]FNeH007MG001gE`000WMG00D007MG001gE`00009gE`04
001cF0000002LeP01000LeQcF0000W<h00X007<hLcP007<h001_>000KcT0009_>@800008KcT006li
KcT006li001_>@80009_>@03001_>@00009_>@04001_>Fli0002KcT01000KcT006/i0P000V/i00<0
06/i00000V/i00<006/i00000V/i00H006/iJcT006/i0002JcT01`00JaU[6@00JaT006/I00800005
JaT006/IJaT00002JaT30002JaT00`00JaT00002JaT30002JaT00`00JaT00002JaT300001f/I001[
6F/I001[6@00009Zn@<0009Vn@05001Vn@00I_T00002I_T3000016Ki001Rn@000V;I00L006;I001R
f@00H]T00002G]T500002Ujj001J^P00F[X005Zj001F^P000UJJ00X005JJ001FVP00DYX005:J001B
VP800009CWX004ij001>NP00BWX004Yj00@00007AUX004IK0016F`00AU/00P000T9K00L0049K0000
049K0012F`0600001d9K0012F`00@U/0049k00800007AW/004Ik0016N`00AW/00`0000=6N`00AW/0
0P0000m:V`00BY/004ZK001:V`00BY/004ZK001:V`00CY/00P0000i>V`00C[/004jk001>^`00C[/0
04jk001>^`000Tjk00h004jk001>^`00D[/005:k001B^`00D[/005:k1@0002QB^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005;K001Bf`00D]/005;K001Bf`00D]/005;K001B
f`00D]/0009Bf`03001Bf`00009Bf`03001oogoo01Uoo`03001oogoo05Moo`00Agoo00<007ooOol0
AWoo00@005KK001Ff`800009E]/005KK001Ff`00E]/005KK00h00003E]/005;K0080000<D]/005;K
001Bf`00D]/005;K001B^`000U:k00`005:k001B^`00D[/005:k001B^`00D[/200002E:k001B^`00
C[/004jk001>_00200002Djl001>_000CY`004ZL001:W00700001DIl0016O000@W`00P0000I2O000
000jG000>S`200000c8K000000020000126j000000Ti1P0000LiUP00@MH004Wf001=mP020000258F
001B=P00ESH005Hf0002ESH03`00ESH005Hf001J=P00FSH005YF001JEP00GUH00002GWH01P00HWD0
0000IWD0009ZU@04001^]Fje0002K[@20003L]@00`00L_@00002M_@01@00M_Afm7Kd00000gLD1P00
00Ig5@00MaD007LE0003MaD00`00MaH00002MaH01@00LaIc5W<F00000W<F00<007<GLaL00W<G00@0
07<GLaL0009c5`05001c5`00LaL00003KaL01000KaQ_60000VlH00D006lHKaP006lH008000=_6004
001_66lH0002KaP01000KaQ_60000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01000JaT00000
0V/I00L006/IJaT006/I001[6@020002JaT01000JaU[6@000V/I00@006/IJaT0009[6@05001[6F/I
001_6@020003KaP01000KaP006lH0P000VlH00@006lHKaP0009_6004001_66lH0002KaP01000KaQ_
60000VlH00@006lHKaP0009_6004001_66lH0002KaP01000KaP006lH0P000V[h00@006[hJ_P0009Z
n0<0009Zn006001Zn6[h001Vn0000VKh00h006KHI]P006KH001Rf000H]T006;I001Rf@000Uji0`00
00IJ^@00F[T005ZI0002EYT01P00EYX005:J001BNP<00003BUX004YJ00@00003?SX003hJ00800003
>QX003Gj00D00004:MX000009MX200001B6j000000008KX00P0000<Q^P0000000P0000@Qf`00000U
f`<000039O/002Gk00<00004:O/00000:O/3000012Wk000002Gk0P0000DUf`00000001fk00D0000D
=E@004GE001=mP00DQH0058F001F=P00ESH005Hf001F=P00ESH0009F=P09001F=P00ESH005Hf001F
=P00009F=P09001J=P00FSH005YF001NE@00009RM@06001ZU6ZD001b/`000Wl?0P000gl`00@007l`
000000=oD005001oDGmAOe400003Oe802P00Og=oL`00Oe<007md001oE0000W]e00D007]E001kMP00
00=kEP04001kEW]FNeH200000gMG001gE`02MeL01000MeMgE`000gMG00@007=HLeP0009cF0800005
LeP007<hLcP00002LcP01P00KcQ_>000KcT0009_>@04001_>Fli0002KcT01000KcU_>@000Vli00<0
06li00000Vli0`000Vli00@006liKcT0009_>@03001[>@00009[>@03001[>F/i00<0009[>@08001[
>F/i001[>@00JcT0009[>@04001[6F/I0002JaT00`00JaT00002JaT00`00JaT00002JaT00`00JaT0
0002JaT00`00JaT00002JaT00`00JaT00002JaT00`00JaT00002JaT00`00JaT00002JaT00`00JaT0
0002JaT30002I_T01`00I_T006Ki001Vn@00009Vn@05001Vn@00I_T00002H_T01`00H]T006;I001R
f@00009Rf@<00008G]T005ji001N^P00F[X0009J^P0F001J^P00E[X005JJ001FVP00EYX005:J001B
VP00DYX004ij001>NP00CWX200001dYj001:NP00BWX004Yj00@0000;AU/004IK0016F`00@U/0049K
0012F`0200001D9K0012F`00@U/00`0000Y2F`000012F`00@W/004Ik0016N`800005AW/004Ik0016
N`07000064ZK000004ZK001:V`00BY/004ZK001:V`00CY/004jK001>V`00C[/004jk001>^`80009>
^`0a001>^`00C[/004jk001>^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D]/005;K00000U;K014005;K001Bf`00D]/0
05;K001Bf`00D]/005;K001Bf`00009Bf`03001oogoo01Yoo`03001oogoo05Ioo`00Agoo00<007oo
Ool0AWoo00@005KK001Ff`/0000>E]/005KK001Ff`00E]/005KK001Ff`00E]/0009Ff`0M001Bf`00
001Bf`00D]/005;K001Bf`00D]/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0200004e:k
001B^`00C[/004jk001>_000C[`004jl001>_000CY`004ZL00800006BY`00000BY`004JL100000=2
O000@W`00P0000HnG000000j?000=S/200000bhK000Uf`0900008bTe0000047F0019mP00COH0058F
001B5P00DSH005Hf001F=P00ESH005Hf001F=P00FSH005Xf001JEP00FUH005iF00000Uif00<0069e
00000VIe00@006ZEJYD0009^]@06001^]6jd001be0000W;D00<007;d00000WKd20000WLD0P000gLE
00D007LE001g5@0000Ag5@05001g5WLFMaH00003LaH01@00LaIc5W<F00000g<G00D007<GLaMc5`00
009c5`04001c5g<G0003KaL01@00KaP006lH00000VlH00@006lHKaP0009_600;001_66lHKaP006lH
001_6000KaP00002KaP01000JaT006/I0P000V/I00D006/IJaU[6@00009[6@06001[6F/I001[6@00
0V/I00@006/I0000009[6@07001[6F/I001[6@00JaT00P000V/I00D006/IJaU[6@00009[6@04001_
6FlI0002KaP01000KaQ_60000VlH00X006lHKaP006lH001_6000KaP0009_6004001_6000KaP20002
KaP01@00KaQ_6000KaP00P000VlH00@006lHKaP0009_6006001Zn6[h001Zn0000V[h00@006[hJ_P0
009Zn003001Zn000009Zn003001Vn6Kh00<0009Vf003001Vf000009Rf080009Rf@03001Rf@000080
000@G[T005ZiF[T005Zi001JV@00EYT005JJ001BVP00DWX200000dij001:FP0200000dIJ00000002
00000chJ000j6P0200000cGj000anP0300000bWJ000000030000126j0000026j0`0000@Q^P00000Q
f`<000049M/000009M/3000012Gk000002Wk0`0000<Yn`00:O/00`0000@Un`00000Un`<000058M/0
0000000I^P02000053ED0015e@00COH0058F001B5P00ESH005Hf001F=P00ESH005Hf0002ESH01@00
ESH005Hf00000UHf00d005Hf001F=P00FSH005Xf001JEP00GUD00002HWD01P00JYAZU000L[<0009o
3`80009o<003001o<7l`008000=oD005001oDGmAOe400003Oe800`00Og=oL`020003Og@01`00NgEk
MG]e001kE@00009kMP05001kEP00NeH00002NeH01@00MeMgEgMG00000WMG00D007MGMeMgE`00009g
E`04001cF7=H0002LeP01000LeQcF0000W<h00@007<h000000=_>003001_>@00008000=_>@04001_
>@00KcT20002KcT00`00KcT00002KcT01000KcU_>@000Vli00@006li001_>@80009[>@03001[>@00
009[>@06001[>F/i001[>@000V/i00H006/iJcT006/i0002JcT01000JaT006/I0P0000E[6@00JaU[
6@00009[6@<0009[6@03001[6@00009[6@<0009[6@03001[6@00009[6@<0009[6@05001[6@00JaT0
0002JaT00`00J_T00002I_T01@00I_T006Ki00000VKi0`0000]Vn@00I_UVn@00H_T006;I001Rf@00
009Rf@<00006G]T005kI001N^@000Ujj01h005Zj001J^P00F[X005Jj001FVP00EYX005JJ001BVP00
DYX005:J001>NP00CWX004ij001>NP00BWX200001dYj001:NP00AUX004IK00@00009AU/0049K0012
F`00@U/0049K00800005@U/0049K0012F`0600002D9k0016N`00AW/004Ik0016N`0200001dIk0016
N`00AW/004ZK00D00003BY/004ZK0080000FBY/004ZK001>V`00CY/004jK001>^`00C[/004jk001>
^`00C[/004jk0002C[/07P00C[/004jk001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`<0000JD[/005:k001B^`00D[/005;K001Bf`00D]/005;K001Bf`00D]/0
05;K001Bf`00D]/0009Bf`05001Bf`00D]/0000LOol00`00Oomoo`1FOol004Moo`03001oogoo04Mo
o`<0000;E]/00000E]/005KK001Ff`00E]/00002E]/04000E]/005KK001Ff`00E]/005KK001Ff`00
E]/005;K0P0000YBf`00D]/005;K001Bf`00D]/0009B^`0>001B^`00D[/005:k001B^`00D[/005:k
001B^`800009D[/005:k001>^`00C[/004jl0080000;C[`004jl001>W000BY`004ZL001:W0020000
1TZL000004Il0016O0@00003@W`003iL00<00003=S/0038K008000039M/0000000X0000N@MH004Wf
001=mP00DQH0058F001B=P00ESH005Hf001F=P00ESH005Hf001J=P00FSH005YF001JEP000UiF00<0
05if00000P000VIe00@006ZEJYD0009^]@03001^]000009be003001be7;D00L00004M_@007LD0004
Ma@00`00MaEg5@02MaD00`00MaD00002MaD01@00MaEg5GLE000017LF00D007<F001g5P00009c5P06
001c5g<G001c5`000W<G00@007<GLaL000=c5`05001_5flGKaL00002KaP01000KaQ_60000VlH00@0
06lHKaP000=_6004001_66lH0002KaP01000KaQ_60000V/I00@006/IJaT0009[6@05001[6F/I001[
6@020002JaT01000JaU[6@000V/I00<006/I00000V/I00@006/IJaT0009[6@04001[6F/I0002JaT0
1@00JaU[6@00JaT00P000VlI00D006lHKaP006lH0080009_6004001_66lH0002KaP01000KaQ_6000
0VlH00@006lHKaP0009_6004001_66lH0002KaP01P00KaQ_6000KaP0009_6004001_60000002J_P0
1000J_QZn0000V[h0`000V[h00L006[hJ_P006[h001Vn0020002I_P00`00I]P00002I]P01000H]P0
06;I1@0001AN^@00G[UN^@00F[T005Zi001JV@00EYT005JJ001BVP00DWX004ij0P0000=:FP00BUX0
0P0000=2>P00@SX00P0000<j6P00>QX00P0000@anP00000]nP@000059MX00000000Q^P0200001B6j
000000008KX00`0000@Uf`00000Uf`<00004:O/00000:O/200001BWk00000000:O/00P0000@Yn`00
000Un`8000039M/00000008000067K/00000000eE0000TGE0P0000iB5P00DQH005Hf001F=P00ESH0
05Hf001F=P000eHf01<005Hf001F=P00ESH005Hf001F=P00FSH005Xf001JEP00GUD00002HWD01P00
JYAZU000L[<000=o3`04001o<7l`0003Oc001@00Oe1oD7m@00000gmA0P000WmB00D007mcOg=oL`00
00=oM003001kMG]e009kM@09001kMW]fNgH007]F001kEP00009kEP09001gEgMGMeL007MG001gE`00
009gE`07001gE`00MeP007=H00000W=H00D007=HLeQcF000009c>004001c>7<h0002KcP00`00KcT0
0002KcT01000KcU_>@000Vli00@006liKcT0009_>@03001_>@000080009_>@04001_>Fli0002KcT0
0`00JcT00002JcT00`00JcU[>@030002JcT01`00JcU[>@00JcT006/i00800005JcT006/iJcT00002
JaT00`00JaT00002JaT00`00JaT00002JaT00`00JaT00002JaT00`00JaT00002JaT02000JaU[6@00
JaT006/I0002JaT02000JaU[6@00JaT006/I0002JaT30002J_T01@00I_T006Ki00000VKi0`000VKi
00T006Ki001Vn@00H_T006;I00000V;I0`0000ANf@00G]T0009Nf@0V001N^@00G[X005Zj001J^P00
F[X005Jj001FVP00EYX005JJ001BVP00DYX005:J001>NP00CWX004ij001>NP00BWX004Yj001:NP80
0007AUX004IK0016F`00AU/00P000T9K0P0000M2F`00@U/0049K0012F`0200001D9K0012F`00AW/0
0`0000a2N`000016N`00AW/004Ik0016N`00AW/200001dIk001:V`00BY/004ZK00L00005BY/004ZK
001>V`0200002TjK001>^`00C[/004jk001>^`000Tjk028004jk001>^`00C[/004jk001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`<0000JD[/005:k001B^`00
D[/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0009Bf`03001Bf`00009Bf`03001o
ogoo01Uoo`03001oogoo01Ioo`D000eoo`@002Yoo`00Agoo00<007ooOol0Agoo00<005KK00000UKK
0P0001IFf`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0009Ff`0@001Bf`00
001Bf`00D]/005;K001Bf`00D]/005:k0002D[/01000D[/005:k0P0000mB^`00D[/005:k001B^`00
D[/005:k001>^`00C[/00P0000U>_000C[`004jl001>W000BY`00P0000Q:W000001:W000AY`004Il
0P0000=2O000@W`00P0000<nG000>U`00`0000<b6`00;Q/00P0000<Q^P000000200001i1eP00BOH0
04gf001B5P00DQH0058f001F=P00ESH005Hf001F=P00ESH005Xf001J=P00FUH005YF0002GUH01@00
GWH0069e00000VIe00@006ZEJYD0009^]@P00003L]@007Kd00=fm005001fm000Ma@00004Ma@00`00
MaEg5@03MaD01@00MaEg5GLE00000WLE00<007LE00000gLF00D007<F001g5P00009c5P03001c5`00
009c5`08001c5g<G001c5`00LaL000=c5`04001_5flG0003KaP01`00KaP006lH001_6000009_6005
001_66lH001_60020003KaP01000KaP006/I0P000V/I00D006/IJaU[6@00009[6@04001[6F/I0002
JaT01000JaT006/I0P000V/I00L006/IJaT006/I001[6@020003JaT01000JaU[6@000V/I00@006/I
JaT0009_6@04001_66lH0002KaP01`00KaQ_6000KaP006lH008000=_6004001_6000KaP20002KaP0
1000KaQ_60000VlH00@006lHKaP0009_6004001_66lH0002KaP00`00J_P00002J_P01000J_QZn000
0V[h00<006[h00000V[h00H006[hJ_P006Kh0002I_P03P00I]QVf000I]P006;H001Rf@00H]T005kI
0002G[T02@00G[T005Zi001J^@00FYT00002EYT01P00EYX005:J001BNP<00007BUX004YJ0016FP00
@SX00P0000Hn>P00000j6P00=OX200001S7j000002gJ000YfP<000049MX000008KX3000012GJ0000
027K0`0000@Uf`00000Uf`<00004:O/00000:O/3000012Wk000002Wk0P0000DUn`00000002GK0080
00068M/00000000I^P000SED00H004GE001=mP00DQH200002eHf001F=UHf001F=P00ESH005Hf0000
0UHf01<005Hf001F=P00ESH005Hf001F=P00FSH005Xf001JEP00GUD00003HWD01@00JY@007:c0000
0gl?00@007l`Oc0000=o<005001oD7m@Oe000002Oe400`00Og9oLP020004Og<01P00OgAoM000OgD0
00=kM@03001kMW]f009kMP08001kEW]F001kEP00MeL000=gE`04001gEgMG0003MeL01000MeQgF000
0W=H0P0000EcF000LeQcF000009c>004001c>7<h0002KcP00`00KcT00002KcT01@00KcU_>@00KcT0
0P000Vli00H006liKcT006li0002KcT01`00KcU_>@00KcT006li0080009[>@03001[>@00009[>@04
001[>F/i0002JcT01000JcT006/i0P0000Q[>@00JcU[>@00JcT006/I0P000V/I00<006/I00000V/I
0`000V/I00<006/I00000V/I0`000V/I00<006/I00000V/I0`000V/I00<006/IJaT00P000V/I00H0
06[iJ_T006[i0002I_T20002I_T00`00I_T00002I_T01`00I_T006Ki001Rn@00009Rf@<00004H]T0
05kI0002G]T0;000G]T005ji001N^P00F[X005Zj001J^P00E[X005JJ001FVP00EYX005:J001BVP00
DYX004ij001>NP00CWX004ij001:NP00BWX004Yj001:NP00AUX200001DIK0016F`00AU/01P0000M2
F`00@U/0049K0012F`0200001D9K0016N`00AW/01@0000a6N`000016N`00AW/004Ik0016N`00AW/2
00002DZK001:V`00BY/004ZK001:V`0900001djK001>^`00C[/004jk0080009>^`0a001>^`00C[/0
04jk001>^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D]/005;K00000U;K018005;K001Bf`00D]/005;K001Bf`00D]/0
05;K001Bf`00D]/2000LOol00`00Oomoo`0COol8000:Ool8000XOol004Moo`03001oogoo04Qoo`04
001Ff`00E]/200001UKK001Ff`00E]/0009Ff`0V001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001B^`00D[/005:k001B^`80000GD[/005:k001B
^`00D[/005:k001B^`00C[/004jk001>_000C[`004jl001>_00200001DZL001:W000BY`00P0000Q:
W0000016O000AW`0049l0P0000<nG00000000`0000Hf>`00000^6`008M/800000b3d000iUP020000
6TWf001=mP00DQH0058F001B=P00ESH005Hf001F=P00ESH005Hf001J=P00FSH005YF0002FUH00`00
GUH000020000169e001VMFIe2@000W;D00D007;DL]Abe00000Afm003001fm000009g5004001g57LD
Ma@20004MaD01@00MaEg5GLE00000WLE00<007LE000017LF00@007LFMaH000=c5P03001c5g<G009c
5`04001c5g<G0002LaL02@00LaMc5g<G001_5`00KaL00002KaP01000KaQ_60000VlH00D006lHKaQ_
6000009_6004001_66lH0002KaP01000KaQ_60000V/I00@006/IJaT0009[6@04001[6@000002JaT0
1000JaU[6@000V/I00H006/IJaT006/I0002JaT01000JaT000000V/I00@006/IJaT0009[6@04001[
6@000002JaT01@00KaU_6@00KaP00P000VlH00@006lHKaP0009_6004001_66lH0002KaP01000KaQ_
60000VlH00`006lHKaP006lH001_6000KaP006lH0002KaP01000KaQ_60000VlH00L006[hJ_P006[h
001Zn0020002J_P01`00J_QZn000J_P006[h0080009Vn003001Vn000009Vf003001Vf000009Rf080
009Rf@07001Nf@00G[T005ji00000UZi00`005Zi001JV@00EYT005JJ001BVP00DWX200000dij001:
FP0200001DIJ0012>P00@SX00P0000Hn6P00000enP00<OX300000bgJ0000000200001BGJ00000000
8KX00P0000DQ^P000000027K008000059M/00000000Uf`0200001bWk00000000:O/002Wk00<00004
:O/00000:O/200001BGk000000008M/00`0000<M^`0000000SED01<004GE001=mP00DQH0058F001F
=P00ESH005Hf001F=P00ESH00002ESH04`00ESH005Hf001F=P00ESH005Hf001J=P00FSH005YF001N
E@0000=RM@05001ZU000L[<00003O`l01000Oc1o<0000gl`0P0000=oD000Oe400WmA00D007mbOg9o
LP0000=oL`05001oM000Og@00002OgD01@00NgD007]e00000g]f00D007]FNeIkEP00009gE`05001g
EgMGMeL00003MeL01000MeMgE`000WMH00@007=HLeP0009cF008001cF7=H001c>000LcP0009c>006
001_>6lh001_>@000Vli00@006liKcT0009_>@08001_>Fli001_>@00KcT0009_>@05001_>Fli001_
>@020002JcT00`00JcT00002JcT30002JcT01000JcU[>@000V/i00<006/i00000V/i00<006/i0000
0V/i00<006/I00000V/I00<006/I00000V/I00<006/I00000V/I00<006/I00000V/I00@006/IJaT0
009[6@80009[6@06001[6F/I001[6@000V/I00<006/I00000P000V[i00<006[i00000VKi00<006Ki
00000P000VKi00L006Ki001Vn@00I_T00002H_T3000016;I001Rf@000UkI00d005kI001Nf@00G[T0
05jj001J^P00F[X00002F[X05000E[X005JJ001FVP00EYX005:J001BVP00DYX004ij001>NP00CWX2
00003DYj001:NP00BWX004Yj0016FP00AU/004IK00800005AU/004IK0016F`0300002T9K0000049K
0012F`00@U/0049K0P0000E6N`00AW/004Ik00D0000<AW/00000AW/004Ik0016N`00BY/004ZK0P00
00e:V`00BY/004ZK001:V`00BY/004jK001>V`0;000014jk001>^`000Tjk01h004jk001>^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/300002e:k001B^`00
D[/005:k001Bf`00D]/0500000=Bf`00Ool06goo00<007ooOol04goo0P0017oo0`002Goo0P0017oo
0P00:7oo0016Ool00`00Oomoo`19Ool00`00E]/00002E]/2000025KK001Ff`00E]/005KK0002E]/0
2P00E]/005KK001Ff`00E]/005KK0P00015Ff`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005:k
01X00005C[`004jl001>_00200001dZL001:W000BY`004ZL00800003AY`004Il00800003@W`0049l
00800007?U`003YL000f>`00<Q/01@0000<IVP0000001@0000<iUP00@MH00P0001A=mP00DQH0058F
001B=P00ESH005Hf001F=P00ESH005Hf001J=P000UXf00H005YF001JEP00GUH700001FIe001ZUFZE
00000Vje00D007;DL]Abe00000=be003001fm7Kd009fm003001fm000009g5006001g57LD001g5000
17LE00<007LEMaD00WLE00D007LE001g5@0000Ag5P05001g5WLFMaH00002LaH00`00LaMc5`02LaL0
1000LaMc5`000g<G00D007<GLaMc5`00009_5`05001_66lH001_60020003KaP01@00KaQ_6000KaP0
0P000VlH00D006lHKaP006lH0080009[6@05001[6F/IJaT00002JaT01000JaU[6@000V/I00@006/I
001[6@80009[6@04001[6F/I0002JaT00`00JaT00003JaT01@00JaU[6@00JaT00P000V/I00@006/I
JaT0009_6@04001_66lH0002KaP01000KaP006lH0P000VlH00D006lHKaP006lH0080009_6004001_
66lH0002KaP01000KaQ_60000VlH00T006lH001_6000KaP006lH00000V[h00@006[hJ_P0009Zn003
001Zn000009Zn004001Zn6[h0002I_P00`00I_P00002I_P00`00I]P00002I]P3000026;I001Rf@00
G]T005ji0002G[T03P00F[T005Zi001JV@00EYT005JJ001BVP00DWX200001Dij001:FP00BUX00P00
00E2>P00@SX003hj00800004>QX00000<OX200000bgj00000002000012GJ000002GJ0`0000@Q^P00
000UfP<000049M/000009M/3000012Gk000002Wk0`0000@Yn`00000Yn`800004:O/000009O/30000
12GK0000027K10000SED01<004GE001=mP00DQH0058F001F=P00ESH005Hf001F=P00ESH00002ESH0
4@00ESH005Hf001F=P00ESH005Hf001J=P00FSH005YF00000UiE00P0069eHWD006ZD001b/`000gl?
00@007l`Oc0000=o<004001oC`000003Oe401@00Og9oLWmb00000gmc00D007md001oM000009oM@03
001kM@00009kM@05001kMP00NgH00002NeH02@00MeMgEgMG001gE`00MeL00002MeL01@00MeL007MH
00000WMH0`000g=H00@007=HLeP0009c>005001c>7<h001_>00200001Vli001_>Fli001_>@80009_
>@04001_>Fli0002KcT00`00KcT00002KcT01P00KcU_>@00KcT0009[>@03001[>@00009[>@04001[
>F/i0002JcT01000JcT006/i0P000V/i00H006/i001[>@00JcT20002JaT00`00JaT00002JaT30002
JaT00`00JaT00002JaT30002JaT01@00JaU[6@00JaT00`000V/I00P006/IJaT006/I001[6@000V/I
00<006[i00000V[i00D006Ki001Vn@00009Vn@03001Vn@00009Vn@80009Vn@<0000AH]T006;IH]T0
06;I001Nf@00G]T005kI001N^@00G[X00002F[X00`00F[X0000H00003TYj000004Yj001:NP00AUX0
04IK0016F`00AU/200001DIK0016F`00AU/01P0000M2F`00@U/0049K0016N`0200001dIk0016N`00
AW/004Ik00D0000@AW/00000AW/004ZK001:V`00BY/004ZK001:V`00BY/200003dZK001>V`00CY/0
04jK001>^`00C[/004jk001>^`0d00004U;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0
009Bf`03001oogoo01Yoo`03001oogoo019oo`8000Ioo`<000Moo`8000Ioo`8002Moo`00AWoo1P00
Agoo01`005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001F
fa400007D[/005:k001B^`00D[/00P00015B^`00D[/005:k001B^`00D[`004jl001>_000C[`004jl
00/00007BY`004ZL001:W000AY`00P0000=6O000@W`00P0000<nG000?U`0100000Db6`00;Q/0027K
00/0000E@MH00000COH0058F001B5P00DSH005Hf001F=P00ESH005Hf001F=P00009J=P03001J=P00
00H00005GUH0069eHWD00002IWD01000JYEZU@000Vje00D007;DL]Abe00000=be003001fm7Kd009f
m003001fm000009g5004001g57LD0002Ma@01000MaEg5GLE0P000gLE0P000gLE00H007LFMaH007LF
0002MaH01@00LaH007<F00000g<G00D007<G001c5`0000=c5`04001c5g<G0003KaL01000KaQ_6000
0VlH00D006lHKaQ_6000009_6004001_66lH0002KaP01000KaQ_60000VlH00@006/IJaT0009[6@04
001[6@000002JaT01000JaU[6@000V/I00@006/IJaT0009[6@04001[6@00JaT20002JaT01000JaU[
6@000f/I00<006/I00000V/I00D006/IJaT006lI0080009_6004001_66lH0002KaP01000KaQ_6000
0VlH00@006lHKaP0009_6007001_66lH001_6000KaP00P000VlH00@006lHKaP0009_6004001_66lH
0002KaP01000J_P006[h0P000V[h00L006[hJ_P006[h001Zn0020002I_P00`00I_P00002I_P00`00
I]QVf003000026;I001Rf@00H]T005kI0002G[T02@00G[T005Zi001J^@00FYT00002EYT01P00EYX0
05:J001BNP<00007BUX004YJ0016FP00@SX00P0000<n>P00?QX00P0000@j6P00000anP800003;MX0
02WJ008000059MX00000000UfP0200001B6j000000009M/00P0000DUf`00000002Gk00800005:O/0
0000000Yn`02000012Wk000002Wk0`0000<Un`009O/0100000DQf`00000M^`00008eE00C0015e@00
COH0058F001B5P00ESH005Hf001F=P00ESH005Hf00000UHf00d005Hf001F=P00ESH005Hf001F=P00
FSH00002FSH01@00FUH005iE00000V9e00D006ZD001b/`0000=o3`800003Oc0007l`009o<004001o
Cgm?0003Oe401000Og9oLWmb0P000Wmc00@007md000000AoM@0=001kMG]eNgD007]f001kMP00NeH0
07]g00000WMG00D007MG001gE`0000=gE`04001gF7MH0002MeP01000LeQcF0000W=H00@007=H0000
00=c>004001c>7<h0002KcT00`00KcT00002KcT01000KcU_>@000Vli00@006li001_>@800006KcT0
06liKcT006li0P000Vli00<006/i00000V/i0`000V/i00@006/iJcT0009[>@03001[>@00009[>@03
001[>@00009[>@03001[6@00009[6@03001[6F/I00<0009[6@03001[6@00009[6@<0009[6@08001[
6F/I001[6@00JaT0009[6@03001[6@00009[6@03001[6F/I0080009[6@06001ZnF[i001Zn@000VKi
0P000VKi00<006Ki00000VKi00<006Ki00000P0000mRf@00H]URf@00H]T006;I001Nf@00G]T005kI
00000Uji00<005jj0000100001MJ^P00E[X005Jj001FVP00EYX005:J001BVP00DYX005:J001>NP00
CWX004ij00D0000>BWX00000AUX004IK0016F`00AU/004IK0016F`800005AU/004IK0016F`030000
2T9K0000049K0016N`00AW/004Ik0P0000M6N`00AW/004Ik0016N`05000054Ik000004ZK001:V`00
BY/004ZK001:V`00BY/004ZK001>V`00CY/200001Tjk001>^djk001>^`80009>^`0o001>^`00C[/0
04jk001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00009B
f`05001Bf`00D]/0000LOol00`00Oomoo`0AOol20008Ool20007Ool20006Ool2000WOol004Ioo`03
001oogoo04Yoo`0>001Ff`00E]/005KK001Ff`00E]/005KK001Ff`l0000@D]/005;K001Bf`00D]/0
05;K001Bf`00D]/005;K0002D[/01P00D[/005:k001B^`80000?D[/005:k001B^`00D[/005:l001>
_000C[`004jl00800005C[`004jl001>_00200000dZL001:W00600001DJL0016O000AW`00P0000Q2
O000000nG000>U`003Hk0P0000<^6`0000000P0000<ENP000000100000LiM@00000004Wf001=mP02
0000258F001B=P00ESH005Hf0002ESH00`00ESH00006000025YF00000000GUH005iF0002HWD01000
IWEVM@000VZE00@006jeK[D000Abe003001be7;D008000Afm003001g57LD009g5003001g5000009g
5006001g5GLE001g5@0017LE00L007LEMaEg5@00MaH00002MaH02000MaIg5P00LaH007<F0004LaL0
1000LaMc5`000g<G00D007<G001c5`00009_5`04001_66lH0002KaP01P00KaQ_66lH001_6080009_
6004001_66lH0002KaP01000KaQ_60000f/I00@006/IJaT0009[6@07001[6F/I001[6@00JaT00P00
0V/I00@006/IJaT0009[6@04001[6F/I0002JaT01@00JaU[6@00JaT00P000V/I00@006/IJaT0009[
6@04001[6F/I0002KaP01000KaP006lH0P000VlH00@006lHKaP0009_6004001_66lH0002KaP01000
KaQ_60000VlH00L006lHKaP006lH001_60020002KaP01000KaQ_60000V[h00H006[hJ_P006[h0002
J_P01000J_QZn0000V[h00<006Kh00000VKh00<006Kh00000VKH00L006KI001Rf@00H]T00002H]T0
1`00G]T005ji001N^@00009J^@04001J^@00FYT<000024YJ000004IJ0012>P00@SX200000chJ000j
6P0600000bgJ00000002000012GJ000002GJ0`0000@Q^P00000Uf`<000039M/002GK00<00004:O/0
0000:O/3000012Wk000002Wk0P0000DYn`00000002Gk008000059M/00000000Mf`03000053ED0015
e@00COH0058F001B5P00ESH005Hf001F=P00ESH005Hf0002ESH02@00ESH005Hf001F=P00ESH00002
ESH02@00FSH005Xf001JEP00GUD00002HWD01@00JY@007:c00000gl?0P0000Eo<000Oc1o<00000=o
C`80009oD@04001oLWmb0002Og<20003Og@00`00OgEoM@02OgD00`00NgEkM@02NgD02000NgIkMP00
NeH007]g0003MeL01@00MeMgEgMG00000WMG00@007MHMeP0009gF004001cF7=H0003LeP01000LeQc
F0000W<h00@007<hLcP0009_>@04001_>@00KcT20002KcT01000KcU_>@000Vli00H006liKcT006li
0002KcT00`00KcT00002KcT00`00JcU[>@030002JcT01`00JcU[>@00JcT006/i0080009[>@03001[
>@00009[>@<0009[6@03001[6@00009[6@03001[6@00009[6@03001[6@00009[6@03001[6@00009[
6@04001[6F/I0002JaT20002JaT01`00JaU[6@00JaT006/I00800004JaT006/I0002J_T01000J_T0
06Ki0P0000AVn@00I_T0009Vn@07001Vn@00I_T006;i00000V;I00/006;I001Rf@00H]T005kI001N
f@00009Nf@D0000OF[X005Zj001J^P00E[X005Jj001FVP00EYX005:J001BVP00DYX005:J001>NP00
CWX004ij001>NP00BWX01@0000a6FP000016F`00AU/004IK0016F`00AU/200001DIK0016F`00AU/0
1P0000U6N`00AW/004Ik0016N`00AW/00P0000M6N`00AW/004Ik0016N`0500006dZK000004ZK001:
V`00BY/004ZK001:V`00CY/004jK001>V`00C[/004jk001>^`00C[/00002C[/200009Tjk001>^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k0002D[/06@00D[/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001B
f`00009Bf`03001oogoo01Yoo`03001oogoo011oo`8000Qoo`8000Ioo`8000Qoo`8002Ioo`00AWoo
00<007ooOol0BWoo00<005KK00002`0002MFf`00E]/005KK001Ff`00E]/005KK001Ff`00D]/005;K
001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D[/005:k001B^`00D[/00P0001MB^`00D[/005:k
001B^`00D[`004jl001>_000C[`004jl001>_000C[`004jl00800008BY`00000BY`004ZL0016W0@0
0003AW`0049l00800004?U`00000>U`30000138K000002Wk2@0000diM@00@MH004Wf001=mP00DQH0
058F001B=P0900000eHf001J=P05000015YF001NEP000UiF00<0069e00000VIe00@006ZEJYD0009^
]@03001be7;D009be005001be000M_@00004M_@00`00MaAg5002Ma@00`00Ma@00002Ma@01P00MaEg
5@00MaD000Ag5@07001g5GLEMaD007LF00000WLF00D007LFMaIg5P0000=c5P05001c5g<GLaL00003
LaL01@00LaMc5g<G00000W<G00P006lGKaL006lH001_60000VlH00D006lHKaQ_6000009_600:001_
66lH001_6000KaP006lH0002KaP01@00JaU[6@00JaT00P000V/I00@006/IJaT0009[6@04001[6F/I
0002JaT01000JaT006/I0P000V/I00@006/IJaT000=[6@06001[6F/I001[6@000V/I00@006/I0000
009[6@04001_66lH0002KaP01000KaQ_60000VlH00L006lH001_6000KaP00002KaP01000KaP006lH
0P000VlH00@006lHKaP0009_6004001_66lH0002KaP01000KaP006[h0P000V[h00L006[hJ_P006[h
001Zn0020002J_P01P00I_QVn000I_P0009Vn0<0000=I]T006;IH]T006;I001Rf@00G]T005ji0000
0Uji1`0000MFV@00EYX005:J001BNP0200000dij0000000400001D8j0012>P00?SX00P0000<j6P00
>QX0100000@]fP00000YfP<000049MX000009MX3000012GJ000002GK0`0000@Uf`00000Un`<00004
:O/00000:O/2000012Wk000002Wk0`0000@Yn`00000Un`<0000I8M/000007K/003ED0015e@00COH0
058F001B5P00ESH005Hf001F=P00ESH005Hf00000UHf00D005Hf001F=P00009F=P0=001F=P00ESH0
05Xf001J=P00FUH005iE00000V9e00D006ZD001b/`0000=o3`<000=o<006001oCgm?Odl007m@0P00
0gmb00D007mcOg=oL`0000=oM007001oMGmeOgD007]e00000g]e00D007]fNgIkMP0000=kM`04001g
EgMG0003MeL01@00MeL007MG00000WMH0P0000EcF000LeQcF000009cF004001cF7=H0002LcP01000
LcP000000Vli00@006liKcT0009_>@07001_>Fli001_>@00KcT00P000Vli00@006li001_>@80009_
>@03001_>@00009[>@03001[>@00009[>@04001[>F/i0002JcT00`00JcT00002JcT00`00JcU[>@03
00001F/I001[6F/I00000V/I0`000V/I00D006/IJaT006/I00<0009[6@07001[6F/I001[6@00JaT0
0P0000M[6@00JaU[6@00JaT00002JaT01@00JaT006/I00000V/I00@006[i001Zn@800004I_T006Ki
0002I_T00`00I_T00002I_T20002H_T01@00H]T006;I00000V;I0P000UkI00<005kI00000P0000QN
^P00F[X005Zj001J^P000UZj01@005Jj001F^P00EYX005JJ001BVP00DYX005:J001BVP00CWX004ij
0P0000M>NP00BWX004Yj001:NP05000034IK000004IK0016F`00AU/004IK0016F`800005AU/004IK
0016N`03000034Ik000004Ik0016N`00AW/004Ik0016N`800007AW/004Ik001:V`00BY/01@0000E:
V`00BY/004ZK0080000:BY/004jK001>V`00CY/004jk0002C[/01000C[/000000Tjk028004jk001>
^`00C[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`<0000ND[/005:k001B^`00D[/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K
001Bf`000U;K00<007ooOol06Woo00<007ooOol047oo0P0027oo0P001Woo0P0027oo0P009Woo0016
Ool00`00Oomoo`1;Ool03@00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`0<001Ff`00E]/005KK
001Ff`00E]/005KK0P0000aBf`00D]/005;K001Bf`00D]/005;K0002D]/02P00D]/005:k001B^`00
D[/005:k0P0000eB^`00D[/005:k001B^`00D[`004jl001>_00200001djl001>_000C[`004jl0080
0007BY`004ZL001:W000BY`00P0000=6W000AW`01@0000<nG000?U`00`0000@f>`00000]n`@00003
5GX00000008000048?@00000@MH300000dgf0000000500002EHf001F=P00ESH005Hf001F=P030000
25Xf001JEP00FUH005iF0002GUH00`00HWD00002IWD01@00JYEZU@00K[D00P0017;D00D007;D001f
m00000Afm003001g57LD009g508000Ag5003001g5@00009g5@06001g5GLE001g5@000gLE00<007LF
MaH00WLF00@007LFMaH000Ac5P05001c5`00LcL00002LaL00`00LaMc5`020003LaL01000KaM_5`00
0VlH00D006lHKaQ_6000009_6004001_66lH0002KaP01000KaQ_60000VlH00D006lHKaQ_6000009[
6@04001[6F/I0002JaT01000JaT006/I0P000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01@00
JaU[6@00JaT00P000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01000KaP006lH0P000VlH00@0
06lHKaP0009_6004001_66lH0002KaP01000KaQ_60000VlH00L006lHKaP006lH001_60020002KaP0
1000KaQ_60000VlH00H006[hJ_P006[h0002J_P01000J_QZn0000V[h00<006[h00000VKh00@006Kh
001Vn080009Vf00;001Vf@00H]T006;I001Rf@00G]T00002G[T300001UZi001J^@00F[T0009FV@07
001FVP00001BNP00CWX00P0000=:NP00BUX01P0000<n>P00?QX00P0000@j6P00000enP@00004:MX0
0000:MX200001BGJ000000009M/00P0000DUf`00000002GK008000049M/00000:O/3000012Wk0000
02Wk0`0000<Yn`00:O/00`0000@Un`00000Uf`<0000G7M/00000=E@004GE001=mP00DQH0058F001F
=P00ESH005Hf001F=P00ESH00003ESH04`00ESH005Hf001F=P00ESH005Hf001J=P00FSH005YF001N
E@00009RM@05001ZU000L[<00002O`l01000Oc0000000gl`00D007m?OdmoC`00009oD080009oLP05
001oLgmcOg<00002Og@00`00Og@00002OgD02000NgEkM@00NgD007]f0002NgH02@00NgMkMg]g001g
E`00MeL00003MeL01000MeMgE`000WMH00@007=HLeP0009cF005001cF000LeP00002LeP01000LcQc
>0000W<h00<006liKcT00`000Vli00@006liKcT0009_>@06001_>Fli001_>@000Vli00H006liKcT0
06li0002KcT30002JcT01`00JcU[>@00JcT006/i0080009[>@03001[>@00009[>@03001[>@00009[
6@03001[6@00009[6@06001[6F/I001[6@000V/I00<006/I00000V/I00<006/I00000V/I00P006/I
JaT006/I001[6@000V/I00@006/I001[6@80009[6@05001[6@00JaT00002J_T00`00I_T00002I_T0
2000I_T006Ki001Vn@00I_T200001VKi001Rn@00H]T0009Rf@04001Rf@00H]T5000095kI001N^Ujj
001J^P00F[X005Zj001J^P00E[X005Jj001FVP00EYX005:J001BVP00DYX005:J001>NP00CWX004ij
001>NP800007BWX004Yj001:N`00BW/01@0000Y6F`000016F`00AU/004IK0016F`800005AU/004Ik
0016N`05000034Ik000004Ik0016N`00AW/004Ik0016N`800007BY/004ZK001:V`00BY/02@0000E:
V`00CY/004jK00800019C[/004jkC[/004jk001>^`00C[/004jk001>^`00C[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K00000U;K00D005;K001Bf`0001ao
o`03001oogoo011oo`8000Qoo`8000Ioo`8000Qoo`8002Ioo`00AWoo00<007ooOol0Bgoo04D005KK
E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005;K001Bf`00
D]/005;K001Bf`00D]/005;K001Bf`00D]/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:l001>_000C[`00P0000M>_000C[`004jl001>_00200002TZL000004ZL001:W000AY`004JL
0P0000=2O000@W`00`0000<nG000>U`00`0000@b6`00000Un`L000038?@0000000P00007DQH0058f
001F=P00ESH01`0000QF=P00FSH005YF001JEP000UiF00D005iF001RM@00009VM@08001ZUFZE001^
]@00K[@000=be005001be000M_@00004M_@00`00MaAg5003Ma@00`00MaAg5002Ma@20003MaD01P00
MaEg5@00MaD000=g5@03001g5WLF009g5P05001g5P00McH00003LaH01@00LaL007<g00000W<G00<0
07<G00000W<G00@007<GLaL0009_5`05001_66lHKaP00002KaP01@00KaP006lH00000VlH00@006lH
001_608000=_6005001_66lH001[6@020002JaT01000JaU[6@000V/I00@006/IJaT0009[6@04001[
6@00JaT20002JaT01@00JaU[6F/I00000V/I00@006/IJaT0009[6@04001[6@00JaT20002JaT01000
JaU[6@000VlH00@006lHKaP0009_6004001_6000KaP20002KaP01@00KaQ_6000KaP00P000VlH00@0
06lHKaP0009_6004001_66lH0002KaP01000KaP006lH0P000V[h00L006[hJ_P006[h001Zn0020002
J_P01P00J_QZn000I_P0009Vn003001Vn000009Vf007001Vf@00H]T006;I00000V;I1@00011N^@00
F[UJ^@00F[T005Zi001FV@00EYX005:J001BNP800003CWX004Yj00800003AUX004IJ00@00003?QX0
03XJ00<00003=OX0000000@00005:MX00000000UfP0200001bGJ000000009M/002GK00<00004:O/0
00009O/3000012Wk000002Wk0`0000@Yn`00000Yn`<000039O/002Gk00<000068M/00000000eE000
0TGE0P0000IB5P00DQH005Hf0002ESH01`00ESH005Hf001F=P00009F=P0C001F=P00ESH005Hf001F
=P00ESH005Xf001J=P00FUH005iE00000V9e00D006ZD001b/`00009o3`04001o<7l`0003Oc001000
OdmoC`000gm@00@007ma000000=oL`05001oL`00Og@00002Og@00`00OgD00002NgD02@00NgD007]f
001kMP00NgH00003NgL01@00MeMgEgMG00000WMG00@007MGMeL0009gF005001cF7=HLeP00002LeP0
1000LeQcF0000W=H00@007<h0000009c>004001_>Fli0002KcT01`00KcU_>@00KcT006li0080009_
>@03001_>Fli00<0009_>@03001_>@00009_>@06001[>F/i001[>@000V/i00H006/iJcT006/i0002
JcT00`00JcU[>@0300001F/i001[6F/I00000V/I0`000V/I00P006/IJaT006/I001[6@000V/I00L0
06/IJaT006/I001[6@020002JaT01P00JaT006/I001[6@80000:JaT006/IJaT006/I001[6@00J_T2
00002VKi001VnFKi001Vn@00I_T006Ki0P0000IVn@00I_T006;i0002H]T02`00H]T006;I001Rf@00
G]T005kI00000UkI02H005jj001J^P00F[X005Zj001J^P00E[X005Jj001FVP00EYX005:J001BVP00
DYX005:J001>NP00CWX004ij001>NP00BWX004Yj0P0000M:N`00BW/004Ik0016N`0600002DIK0016
F`00AU/004IK0016F`0200001DIk0016N`00AW/01@0000a6N`000016N`00AW/004Ik0016N`00BY/2
00002dZK001:V`00BY/004ZK001:V`00BY/02@0000Q>^`00C[/004jk001>^`000Tjk0P0002I>^`00
C[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`000U:k01@005:k001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K1`00
7Goo00<007ooOol03goo0`001Woo0`001Woo0P0027oo0P009Woo0016Ool00`00Oomoo`1<Ool02@00
E]/005KK001Ff`00E]/00002E]/08P00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Bf`00
D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K0P0001EB^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:l001>_000C[`00P0000U>_000C[`004jl001>_000CY`00P0000E:W000BY`004ZL0080
0005AY`004Il0012O00300001SiL000003YL000f?0<00005;O/00000000M^P0700001d7F0019mP00
COH0058F00T0000>ESH005Hf001F=P00ESH005Xf001JEP00FUH0009NEP05001NEP00HWD00002IWD0
2000JYEZU@00K[D006jd0003L]@01@00L]@007Kd00000gKd00<007/C000017LD00<007LDMa@00gLD
00L007LEMaEg5@00MaD00002MaD01P00MaEg5@00McD000=g5P05001g5P00McH00004LaH01000LcMc
=`000g<G00D007<GLaMc5`00009c5`05001_5`00LaP00002KaP01@00KaQ_66lH00000VlH00@006lH
KaP0009_6004001_66lH0003KaP01000KaQ_60000V/I00L006/IJaT006/I001[6@020002JaT01000
JaU[6@000V/I00@006/IJaT0009[6@05001[6F/I001[6@020002JaT01000JaU[6@000V/I00@006/I
JaT0009[6@04001[6@00KaP20002KaP01000KaQ_60000VlH00@006lHKaP0009_6004001_66lH0002
KaP01`00KaQ_6000KaP006lH0080009_6004001_66lH0002KaP01P00J_QZn000J_P0009Zn004001Z
n6[h0002J_P00`00J_P00002J_P00`00I_QVn0030002I_P01`00I]P006KI001Rf@00009Rf@<00004
G]T005ji0002G[T03P00F[T005Zi001J^@00EYT005JJ001BVP00DWX200001dij001:NP00BUX004IJ
00800003@SX0000000800003>QX003XJ00@00004<OX00000:MX200001BWJ000000009MX00P0000DU
f`00000002GK008000079M/00000000Un`00:O/00`0000@Yn`00000Yn`<00005:O/00000000Yn`02
000012Gk0000027K100001DeE000AME5e@00COH0058F001B5P00ESH005Hf001F=P00ESH005Hf0000
0UHf01<005Hf001F=P00ESH005Hf001F=P00FSH005Xf001JEP00GUD00002HWD01000JYAZU0000gl?
00@007l`Oc0000=o<004001oCgm?0003Oe001000Og5oL@000gmc00D007mc001oM00000=oM003001k
MG]e009kM@08001kMW]f001kMP00NgH000=kM`09001gEgMGMeL007MG001gE`00009gE`800006MeP0
07=HLeP007=H0P000g=H00@007=HLeP0009c>003001c>000009_>@04001_>Fli0002KcT01000KcU_
>@000Vli00<006li00000Vli00@006liKcT0009_>@03001_>@000080009[>@07001[>F/i001[>@00
JcT00P000V/i00<006/i00000V/i00<006/i00000V/i00<006/I00000V/I00@006/IJaT0009[6@03
001[6@00009[6@03001[6@00009[6@03001[6@00009[6@03001[6@00009[6@03001[6@00009[6@03
001[6@00009[6@06001[6@00JaT006/I0P0000YZn@00I_UVn@00I_T006Ki001Vn@800004I_T006Ki
I_T20002H_T01P00H]T006;I001Rf@<0009Nf@0^001Nf@00G]T005jj001J^P00F[X005Zj001J^P00
E[X005Jj001FVP00EYX005:J001BVP00DYX005:J001>NP00CWX004ij001>NP00BWX004Yj001:NP00
BW/200001dIk0016N`00AW/004IK00<0000:AU/00000AU/004IK0016F`00AW/200001dIk0016N`00
AW/004Ik00H0000=AW/004Ik0016N`00BY/004ZK001:V`00BY/00P0000e:V`00BY/004ZK001>V`00
CY/004jK001>V`0>00007djk001>^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k00<00003D[/005:k01L00006D]/005;K001Bf`007Goo00<007ooOol0
3goo100017oo0`001goo0P0027oo0P009Woo0016Ool00`00Oomoo`1=Ool03@00E]/005KK001Ff`00
E]/005KK001Ff`00009Ff`04001Ff`00E]/200005EKK001Ff`00E]/005;K001Bf`00D]/005;K001B
f`00D]/005;K001Bf`0K00003djl001>_000C[`004jl001>W000BY`004ZL001:W00200000dJL0016
W00200000d9l0012O003000013YL000003Hl3`0001a1eP00BOH004gf001B5P00DQH005Hf001F=P00
ESH005Hf001F=P00ESH005Hf001J=P00FUH0009JEP07001NEP00GUH0069e00000VIe00@006ZEJYEZ
U@800003K[@007;D009be003001be000009fm006001fm7Kd001k4`000gLD00<007/D000017LD00<0
07LEMaD00WLE0P000gLE00D007LE001g=@0000Ag5P05001g=WLfMcH00003LaH01@00LcMc=g<g0000
0W<G00<007<GLaL00W<G00@007<GLaL0009c6005001_66lHKaP00002KaP02000KaQ_66lH001_6000
KaP20003KaP01@00KaQ_6000KaP00P000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01000JaT0
06/I0P000V/I00D006/IJaU[6@00009[6@04001[6F/I0002JaT01000JaT006/I0P000V/I00@006/I
JaT0009[6@04001[6F/I0002KaP01000KaP006lH0P000VlH00@006lHKaP0009_6004001_66lH0002
KaP01000KaQ_60000VlH00L006lHKaP006lH001_60020002J_P01`00J_QZn000J_P006[h0080009Z
n007001Zn6[h001Zn000I_P00P000VKh00<006Kh00000VKH0P000V;I0`0000mRf@00G]UNf@00G[T0
05ji001J^@00F[T005Zi00000UJI00L005JJ0000059j001>NP0200001dYj001:FP00AUX004IJ0080
0003@SX0000000800004>QX00000=OX400000bWJ000YfP03000012WJ000002GJ0`0000@Uf`00000U
f`800005:O/00000000Yn`03000012Wk000002Wk0P0000@Yn`00000Yn`<000049O/000009O/20000
1B7K000003ED00000TGE014004gf001B5P00DQH005Hf001F=P00ESH005Hf001F=P00009F=P0C001F
=P00ESH005Hf001F=P00ESH005Xf001J=P00FUH005iE00000f9e00<006ZD00000gl?00@007l`Oc00
00=o<004001oCgm?0002Oe001@00Og5oLGma00000Wmc00D007mcOg=oL`0000AoM003001kMG]e009k
M@05001kMW]fNgH00003NgH01@00NgL007Mg00000gMG00@007MGMeL0009gE`04001gF7MH0003LeP0
1000LeQcF0000W=H00@007=H0000009c>003001c>7<h00800008KcT006liKcT006li001_>@80009_
>@03001_>Fli00<0009_>@06001_>Fli001_>@000V/i00L006/iJcT006/i001[>@020002JcT00`00
JcT00002JcT30002JcT00`00JcT00002JaT30002JaT01`00JaU[6@00JaT006/I00800008JaT006/I
JaT006/I001[6@80009[6@06001[6@00JaT006/I0P0000M[6@00JaU[6@00JaT00002JaT00`00JaT0
0002J_T01@00I_T006Ki00000VKi00D006Ki001Vn@00009Vn@08001Vn@00H_T006;I001Rf@80000:
H]T006;I001Nf@00G]T005kI0002G[X02000F[X00000F[X005Zj0002E[X04000E[X005JJ001FVP00
DYX005:J001BVP00DYX004ij0P0000m>NP00CWX004Yj001:NP00BWX004Yk001:N`00AW/00P0000E6
N`00AU/004IK00D0000:AU/00000AU/004Ik0016N`00AW/200001dIk0016N`00AW/004Ik00<00003
AW/004Ik0080000=BY/004ZK001:V`00BY/004ZK001:V`00BY/00P0000Y>V`00CY/004jK001>V`00
C[/0009>^`08001>^`00C[/004jk001>^bL0000LD[/005:k001B^`00D]/005;K001Bf`00D]/005;K
001Bf`00D]/005;K001Bf`00D]/005;K000MOol00`00Oomoo`0?Ool200000goo000000050008Ool2
0008Ool2000VOol004Ioo`03001oogoo04eoo`0C001FfeKK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/00P0000=Ff`00E]/04P0000=Bf`00D[/00P0001EB^`00D[/005:k001B^`00D[/005:k
001B_000D[`004jl001>_000C[`03@0000M:W000BY`004ZL0016W00200000dIl0012O00;00000c8K
0000000200000aVj0000000300006CUe000004Wf001=mP00DQH0058F001F=P00ESH005Hf001F=P00
ESH005Hf001F=P00009J=P09001JEP00FUH005iF001NEP00009RM@03001VM@0000=ZU@800003K[@0
07;D00=be005001fm7KdM_@00002M_@00`00Na<00003Ma@00`00Na@00003Ma@00`00Na@00003MaD0
0`00MaEg5@02MaD00`00MaD00002McD01@00MaIg5WLF000017Lf00D007<F001c=P00009c=`05001c
5`00LcL00003LaL01000LaMc5`000g<H00P006lHKaP006lH001_60000VlH00@006lHKaP0009_6004
001_66lH0003KaP01000KaQ_60000V/I00@006/I001[6@80009[6@04001[6F/I0002JaT01000JaU[
6@000V/I00D006/IJaT006/I0080009[6@04001[6F/I0002JaT01000JaU[6@000V/I00@006/I001[
6@80009[6@04001_66lH0002KaP01000KaQ_60000VlH00L006lH001_6000KaP00002KaP01000KaP0
06lH0P000VlH00@006lHKaP0009_6006001[66/H001Zn0000V[h00@006[hJ_P0009Zn003001Zn000
009Zn006001Zn6[h001Vn0000VKh00<006Kh00000VKH0P000V;I00<006;I00000V;I00L005kI001N
^@00G[T00002F[T02000F[T005Zi001FV@00EYX200001e9j001>NP00CWX004Yj00800005AUX004IJ
0012>P0200000chj00000003000013Gj0000037j0`0000@YfP00000YfP<000039MX002GK00<00004
:M/000009M/3000012Wk000002Wk0`0000LYn`00000002Wk000Yn`0400000bGk000Un`0200001RGK
00000000=E@00095e@0A001=mP00DQH0058F001F=P00ESH005Hf001F=P00ESH00002ESH04`00ESH0
05Hf001F=P00ESH005Hf001J=P00FSH005YF001NE@0000=RM@03001ZU00000=o3`03001o<7l`0080
009o<004001oCgm?0002Oe001000Og5oLGma0P0000=oL`00Og<00Wmc00L007mdOgAoM000OgD00002
NgD00`00NgH00002NgH02@00NgIkMW]f001kM`00MgL00003MeL01000MeMgE`000WMG00D007MHMeQg
F000009cF004001cF7=H0003LeP01P00LeQcF000LcP0009c>004001_>Fli0002KcT01000KcU_>@00
0Vli00<006li00000Vli00@006liKcT0009_>@05001_>@00KcT00002JcT01000JcU[>@000V/i00<0
06/i00000V/i00<006/i00000V/i00P006/iJcT006/i001[>@000V/I00@006/IJaT0009[6@04001[
6@00JaT2000026/I001[6F/I001[6@00JaT200001f/I001[6F/I001[6@00009[6@03001[6@00009[
6@03001[6@00009[6@<00007JaT006[iJ_T006Ki00000VKi0`0000aVn@00I_UVn@00I_T006Ki001R
n@00H]T200002V;I001Rf@00H]T005kI001Nf@000UkI00X005jj001J^P00F[X005Zj001J^QD00003
CWX004ij0080000=BWX004Yj001:N`00BW/004Ik0016N`00AW/00P0000E6F`00AW/004Ik00H00009
AW/004Ik0016N`00AW/004Ik00800005AW/004Ik0016N`070000FDZK000004ZK001:V`00BY/004ZK
001:V`00BY/004jK001>V`00CY/004jK001>^`00C[/004jk001>^`00C[/004jk001>^`00C[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D]/005;K001Bf`00D]/005;K00000U;K00/005;K001Bf`00D]/005;K
001Bf`0001Uoo`@0019oo`03001oogoo00D000Uoo`8000Qoo`8002Ioo`00AWoo00<007ooOol0CWoo
00X005KK001Ff`00E]/005KK001Ff`d0000BD]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001B
f`000U;K02D005:k000005:k001B^`00D[/005:k001B^`00D[/005:l001B_000C[`004jl001>_000
C[`004jl001>_000CY`004ZL001:W00600000dJL0000000800001SYL000003Hl000b?0<000039O/0
000000D0000G>GD00000BOH004gf001B5P00DQH005Hf001F=P00ESH005Hf001F=P00ESH00002ESH0
2`00FSH005YF001JEP00GUH005iF00000V9e00<006Ie00000fZE00@006jdK[@000Abe007001fm7Kd
M_@007Kd00000g/C00H007LDMa@007/D0003Ma@00`00Na@00003MaD00`00MaEg5@02MaD20003McD0
1P00MaIg5P00McH000=g=P05001c5P00LcH00002LcL01@00LaL007<g00000g<G00D007<G001c5`00
00=c6004001_66lH0002KaP01@00KaQ_6000KaP00P000VlH00H006lHKaQ_6000KaP20002KaP01000
JaU[6@000V/I00@006/IJaT0009[6@04001[6@00JaT20002JaT01@00JaU[6F/I00000V/I00@006/I
JaT0009[6@04001[6@00JaT20002JaT01000JaU[6@000V/I00@006/IJaT0009[6@04001_6000KaP2
0002KaP01000KaQ_60000VlH00@006lHKaP0009_6004001_66lH0002KaP01`00KaQ_6000KaP006lH
0080009[6007001Zn6[h001Zn000J_P00P000V[h00L006[hJ_P006[h001Zn0020002I_P00`00I_P0
0002I_P01000I]P006KI0`000V;I00L006;I001Nf@00G[T00002G[T02P00F[T005Zi001J^@00EYT0
05JJ0P0000]BNP00CWX004ij001:NP00BUX004IJ00800003@SX0048j00800005?SX00000000enP02
0000137j000002gj0P0000@YfP00000YfP<000049M/000009M/300000bGK000Yn`0300001BWk0000
0000:O/00P0000DYn`00000002Wk00H000039O/002Gk00@0000E=E@004GEAMD004gf001B5P00DQH0
05Hf001F=P00ESH005Hf001F=P00009F=P0=001F=P00ESH005Hf001F=P00ESH005Xf00000UXf00D0
05YF001NE@00009RM@03001ZU00000=o3`03001o<7l`00800003Oc0007m?009oC`04001oD7m@0002
Og401000Og9oLP000gmc00<007md00000Wmd00`007meOgD007]e001kMP00NgH007]f0003NgH02@00
MgMgMgMg001gE`00MeL00002MeL200002GMH001gF7MH001cF000LeP00002LeP01000LeQcF0000W=H
00<007<hLcP00`000fli00@006li001_>@80009_>@03001_>Fli00<0009_>@04001_>Fli0002KcT0
0`00KcT00002JcT01000JcT006/i0P000V/i00<006/i00000V/i0`000V/i00<006/i00000V/i0`00
0V/I00@006/IJaT0009[6@03001[6@00009[6@03001[6@00009[6@03001[6@00009[6@03001[6@00
009[6@<0009[6@03001[6@00009[6@<00007JaT006/IJaT006[i00000VKi0`0000aVn@00I_UVn@00
I_T006Ki001Vn@00H_T2000016;I001Rf@000V;I0P000UkI00X005kI001Nf@00G[X005Zj001J^PD0
000CE[X005Jj001FVP00EYX005:J001BVP00DYX005:J001>VP00CWX01`0000=:NP00BWX00P0000U:
N`00AW/004Ik0016N`00AU/00P0000M6N`00AW/004Ik0016N`03000034Ik000004Ik0016N`00AW/0
04Ik0016N`800007AW/004Ik001:N`00BW/01@0000=:V`00BY/00P00011:V`00BY/004ZK001>V`00
CY/004jK001>V`00C[/0009>^`0<001>^`00C[/004jk001>^`00C[/004jk0P0001IB^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0009B^`03001B^`000080000PD[/005:k001B
^`00D[/005:k001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/001Eoo`@0
00Aoo`03001oogoo00moo`8000moo`8000Qoo`8002Ioo`00AWoo00<007ooOol0Cgoo2@0000UFf`00
E]/005KK001Ff`00E]/00P0001QFf`00D]]Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K
001Bf`00D[/200005E:k001B^`00D[/005:k001B^`00D[/005:l001B_000C[`004jl001>_0020000
2Djl001>_000C[`004jL001:W00200000dZL0000000700000d9l0012O00200001SiL000003YL000f
?0800003;Q/00000008000036KX0000000800003>GD0047F0080000BCOH0058F001B5P00ESH005Hf
001F=P00ESH005Hf001F=P000UHf00T005Xf001JEP00FUH005iF00000UiF00<0069e00000VIe00@0
06ZEJYD0009^]003001be7;D009be007001fm7KdM_@007Kd00000g/C00<007LD00000g/D00H007LD
Ma@007/D0003MaD20004MaD00`00McEg=@02McD01@00MaH007Lf000017Lf00D007<fLcIc=P00009c
=`05001c=g<gLcL00003LaL01000LaMc5`000g<H00@006lH000000=_6004001_66lH0002KaP01000
KaQ_60000flH00@006lHKaP0009_6004001[6@00JaT20002JaT01000JaU[6@000V/I00@006/IJaT0
009[6@05001[6F/I001[6@020002JaT01000JaU[6@000V/I00@006/IJaT0009[6@04001[6@00JaT2
0002JaT01000JaU[6@000VlH00@006lHKaP0009_6004001_6000KaP20002KaP01@00KaQ_6000KaP0
0P000VlH00@006lHKaP0009_6006001[66/H001[60000V[h00@006[hJ_P0009Zn003001Zn000009Z
n004001Zn6[h0002I_P00`00I_P00002I_P00`00I_P00002I]P20002H]T01@00H]T006;I00000UkI
00/005ji001N^@00F[T005Zi001J^@00009FV@07001FVP00001BNP00CWX00P0000M:NP00BUX004IJ
0016FP0200000d8j000n>P0200001CXJ00000000<OX00P0000@]nP00000]nP800005:MX00000000Y
f`02000012GK000002WK0`0000DYn`00000002Wk00<00003:O/002Wk00H00003:O/0000000@00007
9O/000008M/003ED00000TGE014004gf001B5P00DQH005Hf001F=P00ESH005Hf001F=P00009F=P05
001F=P00ESH00002ESH03@00ESH005Hf001J=P00FSH005YF001NE@00009RM@03001ZU00000=o3`05
001o<7l`001o<0020002Odl01@00Oe1oD7m@00000Wma00<007mbOg800P000Wmc00H007mdOg@007md
0002OgD01`00NgD007]f001kMP00009kMP04001kMW]f0003MgL01@00MeL007MG00000WMG00@007MH
MeP000=gF004001cF7=H0002LeP01000LeP000000W=H00@007<hLcP0009_>@04001_>Fli0002KcT0
1P00KcU_>@00KcT0009_>@04001_>Fli0002KcT01000KcT006li0P0000E_>@00JcU[>@00009[>@03
001[>@00009[>@03001[>F/i00<0009[>@05001[>F/i001[>@030002JaT01`00JaU[6@00JaT006/I
00800008JaT006/IJaT006/I001[6@800005JaT006/IJaT00002JaT300001f/I001[6F/I001[6@00
009[6@03001[6@00009[6@05001[6@00J_T00002I_T00`00I_T00002I_T01`00I_T006Ki001Vn@00
009Vn@05001Rn@00H]T00002H]T02`00H]T006;I001Nf@00G]T005kI00000Ujj100000AJ^P00F[X0
009F^P06001F^P00EYX005JJ0P0000mBVP00DYX005:J001>VP00CWX004ij001>NP00CWX01`0000a:
N`000016N`00AW/004IK0016F`00AW/200001DIk0016N`00AW/01@0000a6N`000016N`00AW/004Ik
0016N`00AW/200001dYk001:N`00BY/004ZK00L00003BY/004ZK00800006CY/004jK001>V`000TjK
02`004jk001>^`00C[/004jk001>^`00C[/004jk001>^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k0`00021B^`00D[/005:k001B^`00D[/005;K001B
f`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`007Goo00<007ooOol03goo0`003goo
0P001Woo0P009goo0015Ool00`00Oomoo`1@Ool02@00E]/005KK001Ff`00E]/00002E]/02000E]/0
05KK001Ff`00E]/2000055KK001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K0002D]/0
7`00D[/00000D[/005:k001B^`00D[/005:k001B^`00D[`005:l001>_000C[`004jl001>_000C[`0
04jl00L00003BY`004ZL00800004AY`00000AW`400000cil000nG00300000cHl000b?00300000bGk
000000030000223d0000047F0019mP00COH20000258F001F=P00ESH005Hf0002ESH03`00ESH005Hf
001F=P00FSH005YF001JEP00GUH00002GUH00`00HWD00002IWD01000JYEZU@000Vjd00<007;DL]@0
0W;D00L007KdM_Afm000M_@00003Na<00`00Ma@00003Na@00`00Ma@00003Na@01@00MaD007/E0000
17LE00<007LeMcD00WLe00<007LF00000WLf00D007LfMcIg=P0000=c=P04001c=g<g0004LcL01000
LaMc5`000g<G00D007<HLaQc6000009_6004001_66lH0002KaP01000KaQ_60000VlH00<006lHKaP0
0P000VlH00@006lHKaP0009[6@04001[6F/I0002JaT01000JaT006/I0P000V/I00D006/IJaU[6@00
009[6@04001[6F/I0002JaT01000JaT006/I0P000V/I00@006/IJaT0009[6@04001[6F/I0002JaT0
1000JaT006lH0P000VlH00@006lHKaP0009_6004001_66lH0002KaP01000KaQ_60000VlH00<006lH
00000VlH00@006lH0000009[6007001[66/H001Zn000J_P00P000V[h00L006[hJ_P006[h001Zn002
0002I_P00`00I_P00002I_P01000I_P006KH0`000V;I00<006;I00000V;I00L005kI001N^@00G[T0
0002F[T00`00F[T0000=000024Yj000004IJ0016FP00@SX200000chj000n>P060000137j000002gj
0`0000@YfP00000Yf`800004:M/000009M/3000012Wk000002Wk0`0000TYn`00000002Wk000Yn`00
:O/01P0000<Un`0000000P0000DUf`00000eE0000095e@0A001=mP00DQH0058F001F=P00ESH005Hf
001F=P00ESH00003ESH05000ESH005Hf001F=P00ESH005Hf001J=P00FSH005YF001NE@00HWD40003
O`l01@00Oc1o<000Oc000P000Wm?00@007m@Oe0000=oL@03001oLP00009oT`03001oL`0000=oM003
001oMGme009oM@05001kMW]fNgH00003NgH01@00NgH007]g00000gMg00@007MGMeL0009gE`05001g
F7MHMeP00002MeP01@00LeQcF7=H00000W=H00@007=HLeP0009cF0<0009_>@05001_>Fli001_>@02
0002KcT00`00KcU_>@030002KcT01000KcU_>@000Vli00<006li00000Vli00@006/i001[>@80009[
>@03001[>@00009[>@03001[>@00009[>@08001[>F/i001[>@00JaT0009[6@04001[6F/I0002JaT0
0`00JaT00002JaT00`00JaT00002JaT00`00JaT00002JaT00`00JaT00002JaT00`00JaT00002JaT0
0`00JaT00002JaT300001f/I001[6F/I001[6@00009Zn@<00009I_T006KiI_T006Ki001Vn@00009V
n@<0000@H_T006;IH]T006;I001Rf@00H]T005kI001Nf@00G]T400006EZj001J^P00F[X005Zj001F
^P00E[X005JJ001FVP00DYX005:J001BVP00DYX004jJ0080000;CWX004ij001>NP00BWX004Yj001:
N`05000034Ik000004IK0016F`00AW/004Ik0016N`800005AW/004Ik0016N`0600002dIk0016N`00
AW/004Ik0016N`00BW/00P0000U:V`00BY/004ZK001:V`00BY/01`0004Y>V`00CY/004jK001>V`00
C[/004jk001>^`00C[/004jk001>^`00C[/004jk001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005;K001Bf`00
D]/005;K001Bf`000U;K00/005;K001Bf`00D]/005;K001Bf`0001aoo`03001oogoo011oo`<000io
o`8000Ioo`8002Moo`00AGoo00<007ooOol0DGoo03`005KK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[`200001Djl001>_000C[`01P0000E>_000CY`0
04ZL00800007BY`004ZL001:W000AY`00`0000=2O000@W`00P0000<nG000>U`00P0000@f?000000^
6`L0000Q8?@00000@MH004Wf001=mP00DQH0058F001F=P00ESH005Hf001F=P00ESH005Hf001F=P00
FSH005YF001JEP00009NEP05001NEP00HWD00002IWD01000JYD000000fjd00D007;DL]Abe00000Af
m003001k4g/C009k4`03001g500000=k5003001g500000=k5003001g5@00009k5@06001g5GLE001g
=@0017Le00D007LfMcIg=P00009g=P03001g=P00009c=P05001c=`00LcL00003LcL01@00LaL007<g
00000W<G00<007<HLaP00P000VlH00P006lHKaP006lH001_60000VlH00D006lH001_6000009_6007
001_66lH001_6000JaT00P000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01@00JaU[6@00JaT0
0P000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01000JaT006/I0P000V/I00@006/IJaT0009[
6@04001[66/H0002KaP01000KaP006lH0P000VlH00@006lHKaP0009_6004001_66lH0002KaP01000
KaQ_60000V/H00<006/H00000V/H00@006[hJ_P0009Zn003001Zn000009Zn004001Zn6[h0002J_P0
0`00I_P00002I_P00`00I_P00002I_P01`00I]T006;I001Rf@00009Rf@07001Rf@00G]T005ji0000
0Uji1@0000EJ^@00EYX005JJ00800005DYX0059j001>NP0800000d8j0012>P0200001Chj00000000
=QX00P0000HanP00000]nP00;OX3000012WJ000002WK0`0000<Uf`00:M/00`0000DYn`00000002Wk
00H00005:O/00000000Yn`0200001BWk000000009O/01@000SED00d004GE001=mP00DQH0058F001F
=P00ESH00002ESH01@00ESH005Hf00000UHf00`005Hf001F=P00ESH005Hf001F=P00FSH8000015KK
001Ff`000gl?00<007l`00000gl`2P000Wmb00D007nCOi=oT`0000AoM003001oMGme009oM@05001k
MW]fNgH00004NgH01@00NgMkMg]g00000WMg00@007MGMeMgE`800009MeP007MHMeP007MH001cF000
009cF004001cF0000002LeP01000LeQcF0000W=I00@006liKcT0009_>@06001_>Fli001_>@000Vli
00@006liKcT0009_>@04001_>@00KcT20002KcT00`00KcT00002JcT00`00JcT00002JcT00`00JcU[
>@030002JcT02000JcU[>@00JcT006/i0002JaT01`00JaU[6@00JaT006/I0080009[6@03001[6@00
009[6@<0009[6@03001[6@00009[6@<00007JaT006/IJaT006/I00000V/I00<006/I00000V/I00<0
06/I00000V/I0`0000UVn@00I_UVn@00I_T006Ki00000VKi0`0000eRn@00H_URn@00H]T006;I001R
f@00H]T00002G]T300008ekJ001NfP00F[X005Zj001J^P00F[X005Jj001F^P00EYX005JJ001BVP00
DYX005:J001BVP00CYX004ij001>NP00CWX00P0000U:NP00BWX004Yk001:N`00BW/01P0000U6F`00
AW/004Ik0016N`00AW/00P0000M6N`00AW/004Ik0016N`0300003TIk000004Ik0016N`00AW/004Yk
001:N`00BY/200002dZK001:V`00BY/004ZK001:V`00CY/02`000Tjk00`004jk001>^`00C[/004jk
001>^`00C[/200005U:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`000U:k
00<005:k00000P0001=B^`00D[/005:k001B^`00D[/005;K001Bf`00D]/005;K001Bf`0=000LOol0
0`00Oomoo`0AOol3000>Ool20004Ool2000XOol004Eoo`03001oogoo055oo`05001Ff`00E]/00002
E]/03000E]/005KK001Ff`00E]/005KK001Ff`80000@E]/005;KD]/005;K001Bf`00D]/005;K001B
f`00D]/200005E;K001Bf`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B_00800002djl
001>_000C[`004jl001>W000BY`00P0000=:W000BY`00P0000I6W0000016O000@W`200000cil0000
000200001CYL00000000;Q/00P0000<Uf`006KX00P00024Pm0000011eP00BOH004gf001B5P00DQH0
05Hf001F=P00ESH005Hf001F=P00ESH005Hf001J=P00FUH005YF00000UiF00D005iF001RM@00009V
M@800003JYD006jd009^]003001be7;D008000Afm003001k4g/C00=k4`03001k57/D00=k508000=k
5003001g5@0000=k5@05001g5@00McD00004McD01`00McIg=WLf001g=P00009g=P05001c=W<fLcH0
0002LcL00`00LcMc=`02LcL01000LcMc=`000W<G00<007<H00000W<h00@006lHKaP0009_6004001_
66lH0002KaP01000KaQ_60000flH00@006lHKaP0009_6004001_6FlI0002JaT01000JaT006/I0P00
0V/I00D006/IJaU[6@00009[6@04001[6F/I0002JaT01000JaT006/I0P000V/I00@006/IJaT0009[
6@04001[6F/I0002JaT01000JaT006/I0P000V/H00@006lHKaP0009_6004001_66lH0002KaP02@00
KaP006lH001_6000KaP00002KaP01000KaQ_60000V/H00L006/HJaP006/H001Zn0020002J_P01`00
J_QZn000J_P006[h0080009Zn006001Vn6Kh001Vn0000VKh0`0000AVf@00H]T0009Rf@05001Rf@00
H]T00002G]T5000015Zi001J^@000UZi00T005JJ000005:J001BVP00DWX00P0000E>NP00BWX004YJ
00@00003@SX003hj00800005>QX00000000f6P02000012gj000002gj0P0000@]n`00000Yf`800005
:M/00000000Yf`0200000bWk0000000200001BWk000Yn`00:O/01@0000<Yn`000000100000@Un`00
000Un`80000:8M/003ED0015e@00COH0058F0002DQH02`00ESH005Hf001F=P00ESH005Hf00000UHf
00@005Hf001F=PT00006E]/005KK001Ff`000UKK00@005KKE]/0009o3`03001o<00000=o<004001k
:g/[0002Odh01000Og5oL@000Wmb00D007nCOi=oT`0000=oM003001oU@00009oM@07001kMP00NgH0
07]f00000g]f00T007]gNgMkM`00MgL007Mg00000WMG00@007MHMeP000=gF004001cF7=H0003LeP0
1P00LeQcF000LeP0009cF004001cFG=I0002KcT01000KcT000000Vli00<006liKcT00`000Vli00@0
06liKcT0009_>@09001_>Fli001_>@00KcT006/i0080009[>@03001[>@00009[>@06001[>F/i001[
>@000V/i00P006/iJcT006/I001[6@000V/I00H006/IJaT006/I0002JaT00`00JaT00002JaT00`00
JaT00002JaT00`00JaT00002JaT00`00JaT00002JaT00`00JaT00002JaT30002JaT01@00JaT006/I
00000V/I00<006Ki00000VKi00D006Ki001Vn@00009Vn@<0000;I_T006;iH_T006;i001Rf@00H]T0
0002H]T500001UkI001NfP00G]X0009J^P800004F[X005Zj0002E[X01P00E[X005JJ001FVP80000C
DYX005:J001BVP00CYX004ij001>NP00CWX004ij001:NP00BWX00P0000M:N`00BW/004Yk0016N`03
000034IK000004Ik0016N`00AW/004Ik0016N`800005AW/004Ik0016N`0500000dIk0016N`020000
2dYk001:N`00BY/004ZK001:V`00BY/00P0000a:V`00BY/004jK001>V`00CY/004jK0002CY/00`00
C[/0000@00005E:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0K000035;K
001Bf`00D]/005;K001Bf`00D]/001eoo`03001oogoo015oo`P000Qoo`P002Qoo`00AGoo00<007oo
Ool0DWoo00T005KK001Ff`00E]/005KK00000UKK01/005KK000005KK001Ff`00E]/005KK001Bf`00
D]/005;K001Bf`00D]/005;K001Bf`00D]/07`0000]>_000C[`004jl001>W000BY`004ZL00800005
BY`004ZL0016W00300000d9l0012O00200000ciL000jG00200001CHl00000000:O/0200001a1eP00
BOH004gf001B5P00DQH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001J=P00FUH0009JEP07001N
EP00GUH0069e00000VIe0P0000=ZU@00K[@00Vjd00H007;DL]@007KC0003M_@00`00Na=k4`03Na<0
0`00NaAk5003Na@00`00NaAk5003Na@00`00NaEk5@02NaD00`00MaD00002McD01P00McEg=@00McD0
00=g=P03001g=WLf009g=P04001c=W<f0003LcL01@00LcMc=g<g00000g<g00@007<GLaL000=c>005
001_66lH001_60020003KaP01000KaP006lH0P0016lH00@006lH001_6080009_6@04001[6F/I0002
JaT01000JaU[6@000V/I00D006/IJaT006/I0080009[6@04001[6F/I0002JaT01000JaU[6@000V/I
00@006/I001[6@80009[6@04001[6F/I0002JaT01000JaU[6@000V/H00@006lH001_6080009_6004
001_66lH0002KaP01000KaQ_60000VlH00T006lH001_6000JaP006/H00000V/H00@006/HJaP0009Z
n003001Zn000009Zn004001Zn6[h0002J_P00`00J_P00002I_P01000I_P006Kh0P000VKI00@006KI
0000009Rf@03001Rf@00009Rf@<00004G[T005ji0002F[T02000F[T005Zi001FVP00EYX200002E:J
001BNP00CWX004ij001:NP0200000dIJ0000000200000chj000n>P03000013HJ000003Gj0P0000@]
nP00000]nP<00003:M/002WK00<00004:O/00000:O/300001BWk00000000:O/00`0000<Yn`000000
0`0000DYn`00000002Wk008000039O/0000000<0000F=E@004GEAMD004gf001B5P00DQH005Hf001F
=P00ESH005Hf001F=P00ESH6000025KK001Ff`00E]/005KK0002E]/01@00E]/005KK00000UKK00D0
05KK001o3`00009o<005001o<7l`Oc000002Nb/01000OdioCP000Wma0`000gnC00<007nD00000Wmd
00X007nEOiD007me001kMP00NgH0009kMP05001kMP00NgL00003NgL01000MgMgM`000WMG00D007MH
MeQgF000009gF005001cF7=HLeP00002LeP01000LeQcF0000W=H0P0000EcF000LeUcF@00009_>@06
001_>Fli001_>@000Vli00@006liKcT0009_>@04001_>@00KcT20002KcT00`00KcT00002KcT01P00
JcU[>@00JcT0009[>@<0009[>@07001[>F/i001[>@00JcT00P0000Q[6@00JaU[6@00JaT006/I0P00
0V/I00<006/I00000V/I0`000V/I00<006/I00000V/I0`000V/I00<006/I00000V/I0`0000M[6@00
JaU[6@00JaT00002JaT300001fKi001VnFKi001Vn@00009Vn@<00004I_T006Ki0002H_T01@00H_T0
06;I00000V;I0`0000INf@00G]T005kI0002G]X04P00G]X005Zj001J^P00F[X005Zj001F^P00E[X0
05JJ001FVP80000GDYX005:J001BVP00CYX004ij001>NP00CWX004ij001:NP00BWX004Yk001:N`02
00001DYk0016N`00AW/01@0000a6N`000016N`00AW/004Ik0016N`00AW/200001DIk0016N`00AW/0
1`0002a:N`00001:V`00BY/004ZK001:V`00BY/004ZK001:V`00CY/004jK001>V`00CY/004jK001>
^`00C[/004jk001>^`00C[/004jk001>^`00C[/005:k5`0000=B^`00D[/00`00021B^`00D[/005:k
001B^`00D[/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`007Goo00<0
07ooOol04goo1P002Woo1000:Woo0015Ool00`00Oomoo`1COol03000E]/005KK001Ff`00E]/005KK
001Ff`800005E]/005KK001Ff`0C00001e;K001B^`00D[/005:k00L00007D[`005:l001B_000D[`0
0P0000M>_000C[`004jl001>_00=00001DZL001:W000AY`00P0000=6O000@W`00P0000<nO000?U`0
0P0000Dj?000000002hK008000039M/0000000@0000H@MH004Wf001=mP00DQH0058F001F=P00ESH0
05Hf001F=P00ESH005Hf001F=P000UXf00/005YF001JEP00GUH005iF001RM@00009VM@04001ZUFZE
0003K[@01P00L]Abe000M]<000=fm08000Ak4`03001k57/D00=k5003001k57/D00=k5003001k5G/E
00=k5@03001g=GLe009g=@05001g=@00McD00003McH00`00McIg=P02McH01@00LcH007<g00000g<g
00D007<g001c=`00009c=`04001c5g<G0004LcP01000KaQ_60000VlH00@006lHKaP0009_6004001_
66lH0003KaP01000KaQ_60000VlI00L006lIKaT006/I001[6@020002JaT01@00JaU[6F/I00000V/I
00@006/IJaT0009[6@04001[6@00JaT20002JaT01000JaU[6@000V/I00@006/IJaT0009[6@04001[
6@00JaT20002JaT01000JaQ[60000VlH00@006/HJaP0009_6004001_6000KaP20002KaP01000KaQ_
60000VlH00@006/HJaP0009[6004001[6000JaP20002J_P01`00J_QZn000J_P006[h0080009Zn006
001Zn6[h001Vn0000VKh00<006Kh00000VKI00L006KI001Rf@00H]T00002H]T3000045kI001N^Eji
001N^@00F[T005Zi001J^@00EYX005JJ0P0000]BVP00DWX004ij001>NP00BWX004YJ00800003AUX0
048j00800007?SX00000000f6P00=QX00`0000<]nP00;OX00P0000D]n`00000002WK00800004:O/0
0000:O/200000bWk00000006000012Wk000002Wk0P0000DYn`00000002Wk008000049O/000009O/3
00003SED0015eDGE001=mP00DQH0058F001F=P00ESH800001UKK001Ff`00E]/0009Ff`0=001Ff`00
E]/005KK001Ff`00E]/005KK00000UKK00<005KKE]/00P000Wl`00D007l`Oc1o<000009k:`03001o
CP00009oL@03001oTWnB0080009oT`06001oU7nD001oM0000gnE00D007]fNgIkMP0000=kMP03001k
MP00009kM`04001kMg]g0002MgL01@00MeL007MH00000WMH00D007MH001cF000009cF007001cF000
LeP007=H00000W=H00@007=HLeP0009cF@04001_>@000002KcT00`00KcU_>@030002KcT01@00KcU_
>@00KcT00P000Vli00<006li00000Vli0`000V/i00<006/i00000V/i00@006/iJcT0009[>@04001[
>@00JcT2000026/i001[6F/I001[6@00JaT200001F/I001[6F/I00000V/I0`0000M[6@00JaU[6@00
JaT00002JaT00`00JaT00002JaT00`00JaT00002JaT00`00JaT00002JaT00`00JaT00002JaT30000
2FKi001VnFKi001Vn@00I_T00002I_T01@00I_T006Ki00000VKi00D006;i001Rn@00009Rf@<00006
H]T005kI001Nf@000UkI01h005kJ001NfP00F[X005Zj001J^P00F[X005Jj001F^P00EYX005JJ001B
VP00DYX005:J001BVP00CYX200004Dij001>NP00CWX004Yj001:NP00BW/004Yk001:N`00BW/00P00
00E6N`00AW/004Ik00D0000:AW/00000AW/004Ik0016N`00AW/200002DIk0016N`00AW/004Yk001:
N`0500005DZK000004ZK001:V`00BY/004ZK001:V`00CY/004jK001>V`00CY/00002CY/0>P00C[/0
0000C[/004jk001>^`00C[/004jk001>^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001Bf`000U;K01<005;K
001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0000LOol00`00Oomoo`1AOol004Eoo`H0051o
o`06001Ff`00E]/005KK3@0001=Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`07
00003e:k001B^`00D[/005:k001B_000D[`005:l001B_00200001Djl001>_000C[`00P0000]>_000
C[`004jl001:W000BY`004ZL00D00005AY`004Il0016O00200001T9l000003iL000jG0800005=S`0
02hK000Yn`0700005T7F0019mP00COH0058F001B5P00ESH005Hf001F=P00ESH005Hf001F=P000UHf
00/005Xf001JEP00FUH005iF001NEP00009RM@03001VM@00009ZU@05001^]6jdK[@00002L]@00`00
M]<00003M_@20004Na<20004Na@20004Na@00`00NaEk5@03NaD00`00McEg=@02McD00`00McD00002
McD01@00McH007Lf00000gLf00D007<f001c=`0000=c=`05001c=`00LcL00002LcL01@00LaL007<g
00000g<h00@006lHKaP0009_6005001_66lH001_60020003KaP01@00KaQ_6000KaP00P000VlI00@0
06lIKaT0009[6@04001[6F/I0002JaT01@00JaU[6@00JaT00P000V/I00@006/IJaT0009[6@04001[
6F/I0002JaT01000JaT006/I0P000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01000JaP006lH
0P000V/H00@006lHKaP0009_6004001[66/H0002KaP01000KaP006lH0P000V/H00@006/HJaP0009[
6006001[66/H001Zn0000V[h00@006[hJ_P0009Zn003001Zn000009Zn003001Vn6Kh00<0009Vn007
001Vf@00I]T006;I00000V;I0`0000eRf@00G]UNf@00G[T005ji001J^@00F[T00002F[T02@00EYX0
0000DYX005:J001BNP0200002Dij001:NP00BUX004IJ0016FP0200001D8j00000000>QX00P0000<f
6P00=OX00`0000<]nP00;OX00`0000@]n`00000Yf`800005:O/00000000Yn`0200000bWk000Yn`05
00001bWk00000000:O/002Wk00<00004:O/000009O/4000023ED0015eDGE001=mP00DQH700001UKK
001Ff`00E]/0009Ff`0>001FfeKK001Ff`00E]/005KK001Ff`00E]/0009Ff`07001Ff`00E]/005KK
00000UKK0P000Wl`00L007l`Oc1o<000Nb/00002Odh01000Og5oL@000WnB00D007nD001oT`0000=o
U003001oUGnE009oU@05001kMW]fNgH00004NgH02@00NgMkMg]g001kM`00MgL00002MgL01000MeQg
F0000gMH00@007=HLeP000=cF004001cF7=H0002LeP30003LeP01000LeUcF@000Vli00<006li0000
0Vli00@006liKcT0009_>@06001_>Fli001_>@000Vli00<006liKcT00`000V/i00<006/i00000V/i
0`000V/i00@006/iJcT0009[>@03001[>@00009[>@03001[6@00009[6@03001[6@00009[6@03001[
6@00009[6@03001[6@00009[6@03001[6@00009[6@<0009[6@03001[6@00009[6@<0009[6@05001[
6@00JaT00002JaT00`00IaT00002I_T01@00I_T006Ki00000VKi0`0000UVn@00I_UVn@00I_T006;i
00000V;i0`0000ARf@00H]T0009Nf@0A001Nf@00G]T005kJ001NfP00F[X005Zj001J^P00F[X00002
E[XB00000dij001>NP0200003DYj001:NP00BW/004Yk001:N`00BW/004Ik00800007AW/004Ik0016
N`00AW/01P0000U6N`00AW/004Ik0016N`00AW/00P0000U6N`00BW/004Yk001:N`00BY/01@0000=:
V`00BY/00P0000A:V`00BY/0009>V`0d001>V`00CY/004jK001>V`00C[/004jk001>^`00C[/004jk
001>^`00C[/004jk001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/3000085:k001B^`00D[/005:k001B^`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0
05;K001Bf`00D]/005;K000MOol00`00Oomoo`1@Ool004Eoo`03001oogoo05Aoo`D00007E]/005KK
001Ff`00E]/00P0000AFf`00E]/0009Bf`0:001Bf`00D]/005;K001Bf`00D]/800005E;K001B^`00
D[/005:k001B^`00D[/005:k001B_000D[`005:l001B_00200004Djl001>_000C[`004jl001>_000
C[`004jl001:W000BY`00`0000=:W000AY`0100000E6O000@W`0049l00800004?U`00000>S`40000
0bWk000Uf`0500005T7F0019mP00COH0058F001B5P00ESH005Hf001F=P00ESH005Hf001F=P000UHf
00/005Xf001JEP00FUH005iF001NEP00009RM@<000=ZU@06001^]6jd001be0000WKC00H007KdM_@0
07/C0004Na<20003Na@00`00Na@00004Na@20004NaD20004McD02@00McEg=GLe001g=P00McH00004
McH01@00LcMc=g<g00000g<g00D007<gLcMc=`00009c=`04001c=g<g0003LcP01@00KaP006lh0000
0VlH00@006lHKaP0009_6004001_66lH0003KaP01000KaQ_60000VlI00@006lI001[6@80009[6@04
001[6F/I0002JaT20002JaT01`00JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT01000JaU[
6@000V/I00@006/I001[6@80009[6@04001[6F/I0002JaP01000JaQ[60000V/H00@006lH001_6080
009[6004001_66lH0002KaP01000JaQ[60000V/H00@006/H001[6080009[6007001Zn6[h001Zn000
J_P00P000V[h00L006[hJ_P006[h001Vn0020002I_P00`00I_P00002I]T200000f;I001Rf@020000
2f;I001RfF;I001Nf@00G[T005ji00000UZi00H005Zi001J^@00EYX200002e:J001BVP00DWX004ij
001>NP00BWX00P0000E6FP00AUX0048j00800005?SX00000000f6P02000013Gj0000037k0P0000@]
nP00000]n`800004:O/00000:O/300001BWk00000000:O/00`0000@Yn`00000Yn`800005:O/00000
000Yn`02000012Wk000002Wk0P0000HUn`00000eE000AMD600001UKK001Ff`00E]/0009Ff`05001F
f`00E]/00002E]/01`00E]/005KK001Ff`00009Ff`0;001Ff`00E]/005KK001Ff`00E]/00002E]/0
1000E]/000000Wl`00L007l`Oc1o<000Nb/00002Odh01P00Og5oL@00Oi8000=oU003001oU7nD009o
U080009oU@07001kUP00NgH007]f00000g]f00<007]gNgL00W]g00@007MgMgL0009gM`05001gF7MH
MeP00002MeP01@00LeQcF7=H00000W=H00@007=HLeP0009cF004001cF7=H0002LeP01000LeT00000
0Vli00<006liKcT00`000Vli00D006liKcT006li0080009_>@03001_>@00009_>@03001[>@00009[
>@03001[>F/i00<0009[>@07001[>F/i001[>@00JcT00P000V/i00H006/i001[6@00JaT20002JaT0
0`00JaT00002JaT300001F/I001[6F/I00000V/I0`000V/I00D006/I001[6@00009[6@08001[6F/I
001[6@00JaT0009[6@<0009W6@05001Vn@00I_T00002I_T300002FKi001VnFKi001Vn@00I_T00002
H_T3000016;I001Rf@000V;I00/005kI001Nf@00G]T005kJ001NfP00009J^P03001J^P0000H00005
E[X005Jj001FVP0200002E:J001BVP00DYX005:J001>VP0700000dYj001:NP0200002dYk001:N`00
BW/004Ik0016N`00AW/00P0000M6N`00AW/004Ik0016N`0300003TIk000004Ik0016N`00AW/004Ik
0016N`00BW/200001dYk001:V`00BY/004ZK00L0000iBY/004ZK001>V`00CY/004jK001>V`00CY/0
04jk001>^`00C[/004jk001>^`00C[/004jk001>^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k00<0000PD[/005:k001B^`00D[/005:k001Bf`00D]/0
05;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/001eoo`03001oogoo051oo`00AGoo00<0
07ooOol0E7oo00D005KK001Ff`00009Ff`06001Ff`00E]/005KK0P0000UFf`00E]/005;K001Bf`00
D]/01`0001eBf`00D]/005;K001Bf`00D]/005:k001B^`00D[/005:k001B^`00D[/005:l001B_000
D[`005:l00800007C[`004jl001>_000C[`00P0000U>_000C[`004ZL001:W000BY`00P0000I:W000
0016W000AW`400000d9l000nO00200001SYL000003Hl000^6`8000039M/0000000<0000F@MH004Wf
001=mP00DQH0058F001F=P00ESH005Hf001F=P00ESH005Hf0002ESH02@00FSH005YF001JEP00GUH0
0002GUH00`00HWD000020003JYD01P00K[A^]000L]@0009fd`04001fm7Kd0002Na<01000Na=k4`00
0W/C00@007/DNa@0009k5006001k57/D001k=0000g/E00<007/e000017Le00L007LeMcEg=@00McH0
0002McH01@00McIg=WLf000017<g00@007<gLcL000=c=`04001c=g<g0003LcL01@00LcQc>7<h0000
0Vlh00@006lHKaP0009_6004001_66lH0003KaP01000KaP000000VlH00@006lIKaT0009_6@04001[
6F/I0002JaT01`00JaT006/I001[6@00009[6@04001[6F/I0002JaT01000JaU[6@000V/I00@006/I
001[6@80009[6@04001[6F/I0002JaT01000JaU[6@000V/I00@006/I001[6080009[6004001[66/H
0002KaP01000JaQ[60000V/H00@006lH001_6080009[6004001[66/H0002JaP01000JaQ[60000V/H
00<006[h00000V[h00H006[hJ_P006[h0002J_P01P00J_QZn000I_P0009Vn003001Vn000009Vf@03
001Vf@0000800009H]T006;IH]T006;I001Nf@00009N^@0:001N^@00F[T005Zi001J^@00EYX20000
3E:J001BVP00DWX004ij001>NP00BWX004YJ00800003AUX0048j00800007?SX00000000f6P00=QX0
0P0000@anP00000an`800004;O/00000;O/300000bWk000Yn`0300000bWk0000000200001bWk0000
0000:O/002Wk00<00004:O/00000:O/200001BWk000000009O/01@0000IFf`00E]/005KK0002E]/0
2`00E]/005KK001Ff`00E]/005KK00000UKK01D005KKE]/005KK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/01@000Wl`00@007l`Oc00009k:`06001oCWm>001oL@000WnB00@007nDOiAoU080
009oU00:001oUGnE001oU@00NiH007]f0002NgH01@00NgH007]g00000g]g00P007MgMgL007Mg001g
N0000WMH00D007MH001gF000009cF005001cF000LeP00002LeP30002LeP01@00LeQcF7=H00000Vli
00<006li00000Vli00@006liKcT0009_>@06001_>Fli001_>@000Vli00<006liKcT00`000V/i00<0
06/i00000V/i00<006/i00000V/i00@006/iJcT0009[>@03001[>@00009[>@03001[>@00009[6@03
001[6@00009[6@03001[6@00009[6@03001[6@00009[6@03001[6@00009[6@03001[6@00009[6@03
001[6@00009[6@<0009[6@03001[6F/I0080009[6@0:001[6F/I001W6@00I_T006Ki0002I_T00`00
I_T00002I_T01`00I_T006Ki001Vn@00009Rn@05001Rn@00H]T00002H]T02@00H]T005kI001Nf@00
G]T00002G]X00`00G]X0000400005EZj001J^P00F[X005Jj001F^P00EYX005JJ001BVP00DYX005:J
001BVP0200001Dij001>NP00CWX01`0000i:N`00001:N`00AW/004Ik0016N`00AW/004Ik0P0000E6
N`00AW/004Ik00D0000>AW/00000AW/004Ik0016N`00BW/004Yk001:N`800009BY/004ZK001:V`00
BY/004ZK00T00004CY/004jK0002CY/0>P00C[/00000C[/004jk001>^`00C[/004jk001>^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001Bf`000U;K01<005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00
D]/0000LOol00`00Oomoo`1@Ool004Eoo`03001oogoo05Eoo`0<001Ff`00E]/005KK001Ff`00E]/0
05KK0P000UKK2@0001]Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005:k001B^`00D[/005:k
001B^`00D[/00P0000eB_000D[`005:l001B_000C[`004jl001>_00200002Djl001>_000C[`004ZL
001:W00300001DZL0016W000AY`00P0000=2O000@W`0100000@nG000000j?0@00003:O/0000000H0
000DBOH004gf001B5P00DQH005Hf001F=P00ESH005Hf001F=P00ESH0009F=P09001J=P00FUH005YF
001NEP00009NEP05001RM@00IWD00003JYD01000K[A^]6jd0P000gKC00<007Kd00000W/C00@007/C
Na<0009k4`04001k57/D0002Na@01000NaAk50000W/d00H007/ENaD007/e0003McD00`00McD00003
McD00`00McIg=P02McH01@00McH007Lf00000g<g00D007<g001c=`00009c=`05001c=`00LcL00003
LcL01000LcQc>0000flh00L006lH001_6000KaP00002KaP01@00KaQ_66lH00000VlH00L006lHKaP0
06lI001_6@020002JaT01@00JaU[6@00JaT00P000f/I00L006/IJaT006/I001[6@020002JaT01000
JaU[6@000V/I00@006/IJaT0009[6@04001[6@00JaT20002JaT01000JaU[6@000V/I00@006/IJaT0
009[6004001[6000KaP20002JaP01000JaQ[60000VlH00@006/HJaP0009[6004001[6000JaP20002
JaP01`00JaQ[6000J_P006[h0080009Zn007001Zn6[h001Zn000J_P00P000VKh00<006Kh00000VKh
00L006KI001Vf@00H]T00002H]T01@00H]T006;I00000UkI00T005ji001N^@00F[T005Zi00000UZi
00T005JJ000005:J001BVP00DWX00P0000U>NP00BWX004YJ0016FP00AUX00P0000E2>P00000003XJ
00800003=QX003Gj00800004<O/00000;O/2000012gk000002Wk0`0000DYn`00000002Wk00H00007
:O/00000000Yn`00:O/00`0000@Yn`00000Yn`800003:O/0000000800003E]/005KK009Ff`0;001F
f`00E]/005KK001Ff`00E]/00002E]/01`00E]/005KK001Ff`00009Ff`0<001Ff`00E]/005KK001F
f`00E]/005KK1P0000EFf`00E]]Ff`00009o<004001o<7l`0002Nb/01000Odh007ma0`0000EoTP00
OiAoU000009oU@03001oU00000=oU@05001kUW^FNiH00004NgH02@00NgMkMg]g001kM`00MgL00002
MgL01@00MgQgN7Mh00000WMH00D007MHMeQgF000009cF004001cF7=H0002LeP01000LeQcF0000W=H
00@007=HLeP0009_>@03001_>Fli00<0009_>@05001_>Fli001_>@020002KcT00`00KcT00002KcT0
1P00KcU_>@00JcT0009[>@<0009[>@07001[>F/i001[>@00JcT00P000V/i00<006/i00000V/i0`00
0V/I00<006/I00000V/I0`000V/I00<006/I00000V/I0`000V/I00D006/IJaT006/I00<0009[6@03
001[6@00009[6@03001[6@000080009[6@05001W6@00I_T00002I_T30002I_T01`00I_T006Ki001V
n@00009Vn@<0000=H_T006;IH]T006;I001Rf@00G]T005kI00000UkI1@0000YJ^P00F[X005Zj001J
^P00F[X0009F^P04001F^P00EYX200003E:J001BVP00DYX005:J001>VP00CWX004ij00800005CWX0
04Yj001:N`0500003TYk000004Ik0016N`00AW/004Ik0016N`00AW/200001DIk0016N`00AW/01@00
0116N`000016N`00BW/004Yk001:N`00BY/004ZK001:V`80009:V`800004BY/004jK0002CY/00`00
CY/0000:00009djk001>^`00C[/004jk001>^`00C[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`0300002e:k001B^`00D[/005:k001B^`00D]/05@00
77oo00<007ooOol0D7oo0015Ool00`00Oomoo`1EOol02`00E]]Ff`00E]/005KK001Ff`00E]/01P00
00aFf`00D]]Bf`00D]/005;K001Bf`00D]/200005E;K001Bf`00D]/005;K001Bf`00D[/005:k001B
^`00D[/005:k001B^`0200004e:l001B_000D[`005:l001>_000C[`004jl001>_000C[`004jl0080
0005BY`004ZL001:W002000024ZL000004JL0016O000@W`200000d9l000nO00300001CXl000f?000
;Q/00P0000<Uf`000000100001A9mP00COH0058F001B5P00ESH005Hf001F=P00ESH005Hf001F=P00
0UHf00L005Xf001JEP00FUH00002GUH00`00GUH000020002IWD01000JYEZU@000fjd0P000gKC00<0
07Kd00000W/C00@007/CNa<0009k4`04001k57/D0003Na@00`00Na@00003Nc@00`00NaD00002NcD0
1P00McEg=@00McD000=g=@03001g=WLf009g=P05001g=P00McH00004LcL01000LcMc=`000g<g00@0
07<gLcL000=c=`05001c>000LcP00002KcP01000KaQ_60000VlH00D006lHKaQ_6000009_6004001_
66lH0002KaP01000KaU_6@000VlI00@006/IJaT0009[6@03001[6@0000=[6@05001[6F/I001[6@02
0002JaT01`00JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT01000JaU[6@000V/I00@006/I
001[6@80009[6@04001[66/H0002JaP01000JaQ[60000V/H00@006/H001_6080009[6004001[66/H
0002JaP01000JaQ[60000V/H00@006/H001Zn080009Zn003001Zn000009Zn004001Zn6[h0002I_P0
0`00I_P00002I_P00`00I_P00002I]T20002H]T01@00H]T006;I00000V;I00L005kI001N^@00G[T0
0002F[T00`00F[T0000?000024Yj000004IJ0016FP00@SX200001Chj00000000>QX00P0000<enP00
<OX00P0000Lan`00000002gk000]n`0300001Bgk00000000:O/00`0000@]n`00000Yn`<00004;O/0
0000:O/2000012Wk000002Wk0P0000DYn`00000002Gk00800009E]/005KKE]/005KK001Ff`00009F
f`0=001Ff`00E]/005KK001Ff`00E]/005KK00000UKK00H005KK001Ff`00E]/600001UKK001Ff`00
E]/0009Ff`03001Ff`00009o<004001o<7l`0002Nb/01`00Odh00000Ok8007nd0080009oU005001o
UGnEOiD00004OiD01@00NiIkUW^F000017]f00T007]gNgMkM`00NgL007Mg00000WMg00H007MhMgQg
N000MeP20003MeP01000LeP000000W=H00@007=HLeP0009cF005001cF7=H001cF0020002KcT01000
KcU_>@000Vli00@006liKcT0009_>@03001_>@00009_>@03001_>Fli00<0009_>@06001[>F/i001[
>@000V/i00<006/i00000V/i00H006/iJcT006/i0002JcT00`00JcU[>@0300001F/I001[6F/I0000
0V/I0`000V/I00D006/I001[6@00009[6@06001[6F/I001[6@000V/I00D006/I001[6@00009[6@08
001[6F/I001[6@00JaT0009[6@03001[6@00009W6@03001Vn@000080009Vn@07001Vn@00I_T006Ki
00000VKi0`0000eRn@00H_URn@00H]T006;I001Rf@00G]T00002G]T3000025kJ001NfP00F[X005Zj
0002F[X02P00F[X005Zj001F^P00E[X005JJ0P0001=BVP00DYX005:J001BVP00CYX004ij001>NP00
CWX004ij001:NP0200000dYk001:N`05000034Ik000004Ik0016N`00AW/004Ik0016N`800007AW/0
04Ik0016N`00AW/01@0000=6N`00BW/00P0001m:N`00BY/004ZK001:V`00BY/004ZK001:V`00BY/0
04jK001>V`00CY/004jK001>V`00C[/004jk001>^`0g000055;K001Bf`00D]/005;K001Bf`00D]/0
05;K001Bf`00D]/005;K000MOol00`00Oomoo`1?Ool004Aoo`03001oogoo05Moo`03001Ff`0000P0
000AE]/005KK001Ff`00E]/005;K001Bf`00D]/005;K001Bf`0200000e;K001Bf`0V000034jl0000
04ZL001:W000BY`004ZL001:W0800008AY`00000@W`0049l0012O0800005?U`00000000f?0030000
0bWk0000000400005D7F000004gf001B5P00DQH005Hf001F=P00ESH005Hf001F=P00ESH00002ESH0
1@00FSH005YF00000UYF00L005iF001NEP00HWD00002IWD01000JYEZU@000fjd00<007KCM]<00WKC
00<007Kd00000g/C00<007/C00000g/C00<007/D00000g/D0P0017/d0P000g/e00<007Le00000gLe
00D007Le001g=P0000Ag=P05001g=WLfMcH00003LcL01@00LcMc=g<g00000W<g00D007<gLcMc=`00
00=c=`04001c>7<h0002KcP01000KaP000000flH00P006lHKaP006lH001_60000VlH00@006lH001_
6@80009_6@05001[6F/I001[6@020002JaT01@00JaU[6F/I00000V/I00<006/I00000V/I00D006/I
JaT006/I0080009[6@07001[6F/I001[6@00JaT00P000V/I00@006/IJaT0009[6@04001[6F/I0002
JaT01000JaP006/H0P000V/H00@006/HJaP0009[6004001[66/H0002JaP01000JaP006/H0P000V/H
00@006/HJaP0009[6003001Zn000009Zn007001Zn6[h001Zn000J_P00P000VKh00<006Kh00000VKh
00@006Kh001Vf@800006I]T006;I001Rf@000V;I00D006;I001Nf@00009N^@L00003F[X005JJ0080
0009EYX005:J001BNP00CWX004ij00H00003AUX0048j00800004?SX00000>QX200001SHK0000037j
000an`800007;O/00000000]n`00:O/00`0000D]n`00000002Wk00@00003:O/002Wk00<00004;Q/0
0000:O/200001bWk00000000:O/002Wk00@00003E]/005KK009Ff`0A001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/00002E]/00`00E]/0000500001UKK001Ff`00E]/0009Ff`07001Ff`00E]/0
05KK00000UKK0P000gl`00@007/[001oCP800009Ok8007ndOk@007ne001oU00000=oU@80009oU@07
001kUP00NiH007^F00000W]f00<007]g00000g]g00P007MgMgL007Mg001gN0000gMh00@007MHMeP0
00=gF004001cF7=H0002LeP200001G=H001cF7=H00000W=H00@007=ILeT0009_>@<0009_>@05001_
>Fli001_>@020002KcT00`00KcT00002KcT01000KcU_>@000Vli00D006/i001[>@00009[>@07001[
>F/i001[>@00JcT00P000V/i00<006/i00000V/i00<006/I00000V/I00<006/I00000V/I00<006/I
00000V/I00<006/I00000V/I0`000V/I00P006/IJaT006/I001[6@000V/I00H006/IJaT006/I0002
JaT20002JaT02P00JaU[6@00IaT006Ki001Vn@000VKi00D006Ki001Vn@00009Vn@<0000;H_T006;i
H_T006;i001Rf@00H]T00002H]T00`00G]T0000200001UkJ001NfP00G]X0009J^P0H001J^P00F[X0
05Zj001J^P00E[X005Jj001FVP00EYX005:J001BVP00DYX005:J0P0000e>NP00CWX004ij001>NP00
BWX004Yk001:N`0200000dYk001:N`05000034Ik000004Ik0016N`00AW/004Ik0016N`800007AW/0
04Ik0016N`00BW/01`0000U:N`00001:V`00BY/004ZK00000TZK0P0000A:V`00CY/0009>V`1@001>
V`00001>V`00C[/004jk001>^`00C[/004jk001>^`00C[/004jk001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0009Bf`05001Bf`00D]/0000LOol00`00
Oomoo`1?Ool004Aoo`03001oogoo05Aoo`L00003E]/005KK00800007E]/005KK001Ff`00E]/04@00
01=Bf`00D]/005;K001Bf`00D[/005:k001B^`00D[`005:l001B_00200004E:l001B_000D[`004jl
001>_000C[`004jl001>_000C[`02@0000M:W000BY`004JL0016W00200001T9l0000049l000nO0<0
0004=S`00000<Q`300000bGK000Le00200001D7F0019mP00COH00P0000QB5P00ESH005Hf001F=P00
0UHf00L005Hf001F=P00ESH00002FSH01P00FUH005YF001NEP<00005HWD006IeIWD00002JYD01@00
K[A^]6jd000017KC00<007Kd00000g/C00<007/C00000g/C0P001G/D00<007/dNc@00g/d00L007/e
NcEk=@00McD00003McD01@00McD007Lf000017Lf00D007LfMcIg=P00009c=`03001c=`00009c=`05
001c=`00LcL00003LcL01000LcMc=`000g<h00@006lhKcP0009_>005001_66lHKaP00002KaP01000
KaQ_60000VlH00@006lHKaP0009_6@04001_6FlI0002JaT01000JaU[6@000V/I00D006/IJaT006/I
0080009[6@04001[6F/I0002JaT00`00JaT00002JaT01000JaU[6@000V/I00@006/IJaT0009[6@04
001[6@00JaT20002JaT01000JaU[6@000V/H00@006/HJaP0009[6004001[6000JaP20002JaP01000
JaQ[60000V/H00@006/HJaP0009[6004001[6000JaP20002J_P01P00J_QZn000J_P0009Zn006001Z
n6[h001Vn0000VKh00<006Kh00000VKh00L006KI001Vf@00H]T00002H]T01@00H]T006;I00000UkI
0`0001=N^@00F[T005Zi001J^P00EYX005JJ001FVP00DYX0059j001>NP0200001DYj001:NP00AUX0
1@0000Hn>P00000j6P00>QX2000013HK0000037k0P0000@]n`00000]n`800005:O/00000000]n`03
000012Wk000002gk0`0000@Yn`00000]n`800004;Q/00000:O/200001BWk00000000:O/00P0000DU
n`00001Ff`00009Ff`0<001Ff`00E]/005KK001Ff`00E]/005KK2@0000IFf`00E]/005KK0002E]/0
2`00E]/005KK001Ff`00E]/005KK00000UKK00@005KK000000=o<003001k:`000080009o/P03001o
]00000=o]@80009oU@0:001oUWnF001oU@00NiH007^F0002NiH00`00NgH00002NgL01000NgMkM`00
0gMg00D007MhMgQgN000009gN005001gF7MHMeP00002MeP01000LeQcF0000W=H00@007=HLeP0009c
F004001cF0000002LeT01000KcU_>@000Vli00@006liKcT0009_>@03001_>@00009_>@03001_>Fli
00<0009_>@04001_>Fli0002JcT00`00JcT00002JcT01000JcT006/i0P000V/i00<006/i00000V/i
0`000V/I00<006/I00000V/I0`000V/I00D006/IJaT006/I00<0009[6@06001[6F/I001[6@000V/I
00D006/I001[6@00009[6@04001[6@00JaT2000016/I001[6@000V/I00D006LI001Vn@00009Vn@03
001Vn@00009Vn@03001Vn@000080000;I_T006;iH_T006;i001Rn@00H]T00002H]T5000015kI001N
fP000UkJ02@005kJ001J^P00F[X005Zj001J^P00F[X005Jj001F^P00EYX005JJ001BVP00DYX005:J
001BVP00CYX004ij001>NP00CWX200002DYj001:N`00BW/004Yk001:N`0200000dYk001:N`050000
34Ik000004Ik0016N`00AW/004Ik0016N`800009AW/004Yk001:N`00BW/004Yk00D00003BY/004ZK
0080009:V`0H001:V`00BY/004jK001>V`00CY/004jK001>V`00C[/004jk001>^`00C[/004jk0P00
02Q>^`00C[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/0009B^`0K001B^`00D[/005;K001Bf`00D]/005;K001Bf`00D]/0
05;K001Bf`00D]/005;K001Bf`0001aoo`03001oogoo04moo`00A7oo00<007ooOol0CGoo1`0017oo
00<005KK0000300000eBf`00D]/005;K001Bf`00D]/005;K001Bf`0200005U;K001Bfe;K001Bf`00
D]/005;K001B^`00D[/005:k001B_000D[`005:l0P0000mB_000D[`005:l001>_000C[`004jl001>
_000C[`00P0000Q>_000001:W000BY`004ZL1P0000E6W000AW`0049l00800004@W`00000?U`30000
13Hl000002hK0`0001TLe0000011eP00BOH004gf001B5P00DQH005Hf001F=P00ESH005Hf001F=P00
ESH00002ESH01P00FSH005YF001JEP<00004GUH0069e0002IWD01000JYEZU@000fjd00<007KCM]<0
0WKC00<007Kd00000g/C0P001G/C00<007/DNa@00g/D00<007/dNc@00g/d00<007/eNcD00W/e00<0
07LeMcD00WLe00<007Le00000WLf00H007LfMcH007Lf0002McH00`00LcL00002LcL01@00LcMc=g<g
00000W<g00T007<gLcMc=`00LcL007<h00000W<h00@006lhKcP000=_>005001_66lH001_60020003
KaP01000KaP006lH0P000VlI00D006lIKaT006/I0080009[6@04001[6F/I0003JaT01P00JaU[6@00
JaT0009[6@04001[6@000002JaT01`00JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT01000
JaU[6@000V/I00@006/I001[6080009[6004001[66/H0002JaP01000JaQ[60000V/H00@006/H001[
6080009[6004001[66/H0002JaP01P00J_QZn000J_P0009Zn004001Zn000J_P20002J_P01P00I_QV
n000I_P0009Vn0<00004I]T006KI0002H]T01@00H]T006;I00000V;I0`0000aN^@00G[UN^@00F[T0
05Zi001J^P00EYX200003EJJ001BVP00DWX004ij001>NP00BWX004Yj00800003AUX0000000<00006
?SX00000>QX003HK0P0000@f6`00000an`800004;O/00000;O/200000bgk0000000500001BWk0000
0000;O/00P0000@]n`00000^6`800004;Q/00000:O/3000012Wk000002Gk0`0000YFf`00E]]Ff`00
E]/005KK001Ff`H00008E]/005KK001Ff`00E]/0009Ff`0<001FfeKK001Ff`00E]/005KK001Ff`00
0UKK00P005KK001Ff`00E]/005KK0P000gl`00D007/[001g/@00009o/P03001o]00000=o]@05001o
]P00OiD00003OiH01@00NiIkUW^F000017^F00T007]gNgMkM`00NgL007Mg00000WMg00T007MhMgQg
N000MgP007Mh00000WMH00P007MH001cF000LeP007=H0P000g=H00@007=HLeP0009cF@03001cF@00
009_>@04001_>Fli0002KcT01000KcT000000Vli00<006li00000Vli00@006liKcT0009_>@04001_
>@00JcT200001F/i001[>F/i00000V/i00<006/i00000V/i00<006/i00000V/i00P006/IJaT006/I
001[6@000V/I00H006/IJaT006/I0002JaT01@00JaT006/I00000V/I00L006/IJaT006/I001[6@02
000026/I001[6F/I001[6@00JaT2000016/I001[6@000V/I00@006/I001W6@800004I_T006Ki0002
I_T01`00I_T006Ki001Vn@00009Vn@07001Rn@00H_T006;i00000V;I0`0000IRf@00G]T005kI0002
G]X04@00G]X005kJ001J^P00F[X005Zj001J^P00F[X005Jj00000UJj01T005JJ000005:J001BVP00
DYX005:J001>VP00CWX004ij001>NP00CWX004Yj001:N`0200001dYk001:N`00BW/004Yk00800003
BW/004Ik00D0000<AW/00000AW/004Ik0016N`00AW/004Ik0P0000A:N`00BW]:N`800003BY/004ZK
00L0000mBY/004ZK001:V`00CY/004jK001>V`00CY/004jK001>^`00C[/004jk001>^`00C[/004jk
001>^`00C[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/00`00021B^`00D[/005:k001B^`00D[/005;K001Bf`00D]/005;K001Bf`00D]/005;K
001Bf`00D]/005;K001Bf`007Goo00<007ooOol0CWoo0014Ool00`00Oomoo`17Ool6000<Ool01P00
E]/005KK001Ff`800006E]/005KK001Ff`000U;K00`005;K001Bf`00D]/005;K001Bf`00D]/20000
5E;K001Bf`00D]/005;K001Bf`00D[/005:k001B^`00D[`005:l001B_00200004e:l001B_000D[`0
04jl001>_000C[`004jl001>_000C[`004jl00800003BY`004ZL00800005BY`004ZL0016W0040000
1T9l0000049l000nO0<00004=S`00000<Q`200000bWk0000000200005T7F0019mP00COH0058F001B
5P00ESH005Hf001F=P00ESH005Hf001F=P000UHf00@005Xf001JEP<00004FUH005iF0002HWD00`00
IWD00002JYD01@00K[A^]6jd00001GKC00<007/CNa<00g/C00<007/CNa<00g/C00<007/DNa@00W/D
00<007/d00000g/d00<007/d00000g/e00<007LeMcD00gLe00<007LfMcH00WLf00D007Lf001g=P00
00=g=P03001c=g<g009c=`04001c=g<g0003LcL01@00LcMc=g<g00000W<h00P007<hLcP006lh001_
>0000Vlh00D006lHKaQ_6000009_6004001_66lH0002KaP01000KaQ_60000VlI00@006lIKaT0009[
6@04001[6F/I0002JaT01000JaT000000V/I00@006/IJaT0009[6@06001[6F/I001[6@000V/I00@0
06/I0000009[6@07001[6F/I001[6@00JaT00P000V/I00@006/IJaT0009[6@04001[6F/I0002JaP0
1000JaP006/H0P000V/H00@006/HJaP0009[6004001[66/H0002JaP01000JaP006/H0P000V[h00L0
06[hJ_P006[h001Zn0020002J_P00`00J_P00002I_P01000I_P006Kh0P000VKi00T006KI001Vf@00
H]T006;I00000V;I0`0000iNf@00G[UN^@00G[T005Zi001J^@00F[X005JJ0P0000mFVP00DYX0059j
001>NP00CWX004Yj001:NP00AUX00P0000=2FP0000000`0000Hj6P00000f6`00=Q/2000013HK0000
02gk0P0000@]n`00000]n`<00003;O/0000000@00005;O/00000000]n`02000012gk000002hK0`00
00<Yn`00:O/00`0000LYn`00000Un`00E]/00002E]/600001UKK001Ff`00E]/0009Ff`07001Ff`00
E]/005KK00000UKK00D005KK001Ff`00009Ff`0=001Ff`00E]/005KK001Ff`00E]/005KK00000UKK
00P007l`Oc1o<000Nb/007Na100000Eo]000OkEo]@0000=o]P03001oUWnF009oUP04001kUW^FNiH2
0003NiH00`00NgMkM`02NgL02000MgMgM`00MgL007Mh0003MgP01000MgQgN0000gMH00@007=HLeP0
009cF004001cF7=H0002LeP01000LeP000000W=I00<007=ILeT00P0000E_>@00KcU_>@00009_>@03
001_>@00009_>@03001_>Fli00<0009_>@04001_>Fli0002KcT00`00JcT00002JcT01000JcT006/i
0P000V/i00<006/i00000V/i0`000V/I00<006/I00000V/I0`000V/I00P006/IJaT006/I001[6@00
0V/I00L006/IJaT006/I001[6@02000016/I001[6@000V/I00H006/IJaT006/I0002JaT01@00JaT0
06/I00000V/I00D006Ki001Vn@00009Vn@07001Vn@00I_T006Ki00000VKi00<006Ki00000V;i0P00
0V;i0`0000ARf@00H]URf@80009Nf@0=001NfP00G]X005kJ001J^P00F[X005Zj00000UZj00@005Zj
001F^Q00000?CWX004ij001>NP00CWX004Yj001:N`00BW/004Yk00800007BW/004Yk001:N`00BW/0
0P0000=6N`00AW/01@000196N`000016N`00AW/004Ik001:N`00BW/004Yk001:N`00BY/200001DZK
001:V`00BY/01`0000I>V`00CY]>V`00CY/20000;djK001>^`00C[/004jk001>^`00C[/004jk001>
^`00C[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/00`0001YB^`00D[/005:k001B^`00D[/005;K001Bf`00D]/005;K001Bf`00D]/005;K001B
f`000U;K00D005;K001Bf`0001aoo`03001oogoo04ioo`00A7oo00<007ooOol0@7oo1`004Woo00L0
05KKE]/005KK001Ff`020000:eKK001Ff`00E]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001B
f`00D]/005;K001Bf`00D]/005;K001B^`00D[/005:k001B_000D[`005:l0080000?D[`005:l001B
_000C[`004jl001>_000C[`004jl0080000<C[`00000BY`004ZL001:W000BY`004ZL0P0000=6W000
AW`00`0000E2O000?W`003iL00<00004=S`00000;Q/7000054Wf001=mP00DQH0058F001F=P00ESH0
05Hf001F=P00ESH005Hf0002ESH500001UYF001JEP00GUH0009RM@03001VM@00009ZU@03001^]6jd
008000Efd`03001k4g/C00=k4`03001k4g/C00=k4`8000=k5003001k=00000=k=003001k=000009k
=@03001k=@0000Ag=@03001g=WLf009g=P03001g=P00009g=P04001g=WLf0004LcL01@00LcL007<g
00000g<g00@007<gLcL000=c>004001c>7<h0002KcP01P00KcQ_>6lh001_6080009_6005001_66lH
001_60020002KaP01@00KaU_6@00KaT00P000V/I00D006/IJaU[6@00009[6@04001[6F/I0002JaT0
1000JaT006/I0P000V/I00@006/IJaT0009[6@03001[6@00009[6@05001[6F/I001[6@020002JaT0
1`00JaU[6@00JaT006/I0080009[6@04001[66/H0002JaP01000JaQ[60000V/H00@006/H001[6080
009[6004001[66/H0002JaP01P00JaQ[6000J_P0009Zn006001Zn6[h001Zn0000V[h00H006[hJ_P0
06Kh0002I_P00`00I_T00002I_T01`00I]T006KI001Rf@00009Rf@<0000JG]T005kIG]T005ji001N
^@00F[T005Zi001J^P00EYX005JJ001FVP00DYX0059j001>NP800005BWX004Yj0016FP020000149J
0000048j0P0000<j6P00>QX00P0000<f6`00=Q/00`0000<]n`00;O/00`0000D]n`00000002gk00<0
0004;O/00000;O/2000012gk000002hK0P0000@^6`00000^6`<00004:O/00000:O/200000bWk0000
000400001UKK001Ff`00E]/0009Ff`0=001Ff`00E]/005KK001Ff`00E]/005KK00000UKK01<005KK
E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`040003Oc0200001WNa000007OE001ke@<0
0003OkD007nf009o]P80009oUP05001kUP00NiH00002NiL01@00NiH007^G00000g]g00D007MgMgMg
M`0000=gN004001gN7Mh0003MgP01000MeQgF0000W=H00@007=HLeP0009cF005001cF7=HLeP00002
LeT00`00LeT00002LeT01000KcU_>@000Vli00@006li0000009_>@03001_>@00009_>@04001_>Fli
0002KcT01000KcT006li0P000V/i00<006/i00000V/i00<006/i00000V/i00<006/iJcT00`000V/i
00D006/IJaT006/I00<0009[6@06001[6F/I001[6@000V/I00D006/I001[6@00009[6@06001[6F/I
001[6@000V/I00H006/I001[6@00JaT200002V/I001[6F/I001[6@00JaT006/I0P0000AVn@00I_T0
009Vn@04001Vn@00I_T200001VKi001Vn@00I_T0009Rn@03001Rn@000080000AH]T006;IH]T006;I
001Nf@00G]T005kJ001NfP00G]X00002F[X01000F[X005Zj1`0000mF^P00EYX005JJ001BVP00DYX0
05:J001BVP00DYX0200000]:NP00BW/004Yk001:N`00BW/004Yk00800007BW/004Yk0016N`00AW/0
0P0000=6N`00AW/01@0000U6N`000016N`00BW/004Yk00000TYk0P0000M:V`00BY/004ZK001:V`02
0002BY/01000BY/004jK2@0000]>V`00C[/004jk001>^`00C[/004jk0080000XC[/004jk001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k0002D[/05000D[/005:k001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/7000LOol0
0`00Oomoo`1>Ool004Aoo`03001oogoo03Yoo`H001Yoo`06001Ff`00E]/005KK0P0001AFf`00E]]F
f`00E]/005;K001Bf`00D]/005;K001Bf`00D]/005;K0P0000iBf`00D]]Bf`00D]/005;K001Bf`00
D[/005:k0P0001=B_000D[`005:l001B_000D[`005:l001B_000C[`004jl001>_00200001Djl001>
_000C[`00P0000=:W000BY`00P0000M:W000BY`004JL0016W00200000d9l0000000300000ciL000j
G00300000c8L0000000400004dGF00000000COH0058F001B5P00ESH005Hf001F=P00ESH005Hf00H0
0008FSH005Xf001JEP00FUH0009NEP05001RM@00IWD00002JYD01P00K[A^]000L[<000Afd`03001k
4g/C00=k4`03001k4g/C009k4`03001k4`0000=k5006001k=7/d001k=0000g/d00<007/e00000W/e
00H007LeMcD007Le0004McH02@00McIg=WLf001g=P00McH00003LcL01@00LcL007<g00000g<g00D0
07<g001c=`00009c>004001c>7<h0003KcP01@00KcQ_>6lh00000VlH00@006lHKaP0009_6004001_
66lH0002KaP01000KaU_6@000VlI00@006/IJaT0009[6@04001[6@000002JaT01000JaU[6@000V/I
00@006/IJaT0009[6@04001[6@00JaT20002JaT01000JaU[6@000V/I00<006/I00000V/I00@006/I
JaT0009[6@04001[6F/I0002JaT01000JaP006/H0P000V/H00@006/HJaP0009[6004001[66/H0002
JaP01000JaP006/H0P000V/H00L006[hJ_P006[h001Zn0020002J_P00`00J_P00002J_P00`00I_QV
n0030002I_T01`00I_T006KI001Vf@00009Rf@<00009H]T005kIG]T005kI001N^@00009N^@04001J
^@00F[T200004EJJ001FVP00EYX005:J001BNP00CWX004ij001:NP00BWX00P0000=6FP00@UX00`00
00Hn>`00000j6P00=Q/200000cHK000f6`0300000bgk000]n`0300001Bgk00000000;O/00`0000@]
n`00000]n`800007;O/00000000^6`00;Q/00`0000@^6`00000Yn`800003:O/0000000800003E]/0
05KK009Ff`0=001Ff`00E]/005KK001Ff`00E]/005KK00000UKK00L005KK001Ff`00E]/00002E]/0
2P00E]/005KK001Ff`00E]/005KK1P0000AFf`00E]/000=o<0@00005MmD007_ENmD00002NmH20002
OkH01P00NkIk]P00OiH0009kUP03001kUg^G009kU`09001kUg^GNiL007]g001kM`00009gM`09001g
N7MhMgP007Mh001gN000009gN005001gF000LeP00002LeP200001G=H001cF7=H00000W=H00@007=I
LeT0009cF@<000=_>@06001_>Fli001_>@000Vli00<006liKcT00`000Vli00D006liKcT006li0080
009[>@06001[>@00JcT006/i0P000V/i00<006/i00000V/i00<006/i00000V/i00P006/IJaT006/I
001[6@000V/I00L006/IJaT006/I001[6@02000026/I001[6F/I001[6@00JaT200001f/I001[6F/I
001[6@00009[6@03001[6@00009[6@06001[6@00JaT006/I0P0000YW6@00I_UVn@00I_T006Ki001V
n@800006I_T006Ki001Vn@000VKi00L006;i001Rn@00H_T00002H]T03@00H]T006;I001Nf@00G]T0
05kJ001NfP00009NfPL0000MF[X005Zj001F^P00E[X005JJ001FVP00DYX005:J001BVP00DYX005:J
001>VP00CYX004ij001>NP0600002DYk001:N`00BW/004Yk001:N`0200001dIk0016N`00AW/004Ik
00800003AW/004Yk00D00005AW/00000BW/00002BW/01000BW/004ZK0P0001=:V`00BY/004ZK001:
V`00BY/004jK001>V`00CY/004jK001>V`0?00008Djk001>^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0300000e:k001B^`0G00001U;K001B
f`00D]/001aoo`03001oogoo04ioo`00A7oo00<007ooOol0<goo1`008Goo00H005KK001Ff`00E]/2
00001UKK001Ff`00E]/0009Bf`06001Bf`00D]/005;K0P0001=Bf`00D]/005;K001Bf`00D]/005;K
001Bf`00D]/005:k001B^`0200004e:l001B_000D[`005:l001B_000D[`005:l001>_000C[`004jl
0080000;C[`004jl001>_000C[`004ZL001:W00200000dZL001:W00200002DJL0016O000@W`003il
000nG00200000cYL000f?00300000bhK0000000200000dGF001=mP0500001E8F001F=P00ESH01`00
00eF=P00ESIF=P00FSH005Xf001JEP00FUH00002GUH01@00HWD006Ie00000VZE00H006jdK[@007:c
0004M]<00`00Na=k4`03Na<20003Na<00`00Na<00002Na@01`00NcAk=7/d001k=00000=k=003001k
=@00009k=@06001g=GLe001g=@0017Lf00L007LfMcIg=P00McH00002McH01@00LcMc=g<g00000g<g
00D007<gLcMc=`00009c=`08001c>7<h001c>000LcP000=_>004001_>6lh0002KaP01@00KaQ_6000
KaP00P000VlH00D006lHKaP006lI0080009_6@05001[6F/IJaT00002JaT01000JaU[6@000V/I00@0
06/I001[6@80009[6@04001[6F/I0002JaT01P00JaU[6@00JaT0009[6@04001[6@000002JaT01`00
JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaP01000JaQ[60000V/H00@006/H001[6080009[
6004001[66/H0002JaP01P00JaQ[6000JaP0009Zn004001Zn6[h0002J_P00`00J_P00002J_P01000
J_P006Kh0P000VKi00<006Ki00000VKi0P000VKI0`0000URf@00H]URf@00G]T005kI00000Uji00H0
05ji001J^@00F[T200004eJJ001FVP00EYX005:J001BNP00CWX004ij001:NP00BWX004IJ00800004
@UX00000@SX200001Shk000003HK000f6`800004=Q/00000<Q/2000012gk000002gk1`0000@]n`00
000]n`800004;O/00000;Q/300000bhK000^6`03000012XK000002Wk0P0000HYn`00000005KK0002
E]/01@00E]/005KK00000UKK00d005KK001Ff`00E]/005KK001Ff`00E]/00002E]/01P00E]/005KK
001Ff`H00006E]/005KK001Ff`000UKK00<005KK00000Wl`0`000WOE00<007_E00000g_F00D007^g
001o]P0000=k]P05001kUW^FNiH00004NiL00`00NiMkU`02NiL01000NgMkMg]g0P0000=gN000MgP0
0WMh00D007MhMgQgN000009gN004001cF7=H0002LeP01000LeQcF0000W=H00L007=H001cF@00LeT0
0002LeT01000KeU_F@000Vli00@006li0000009_>@03001_>@00009_>@04001_>Fli0002KcT01P00
KcU_>@00KcT0009[>@03001[>@00009[>@03001[>@00009[>@03001[>F/i00<0009[>@08001[>F/i
001[6@00JaT0009[6@07001[6F/I001[6@00JaT00P0000M[6@00JaU[6@00JaT00002JaT00`00JaT0
0002JaT01P00JaT006/I001[6@80009[6@05001[6@00JaT00002JaT00`00IaT00002IaT01@00I_T0
06Ki00000VKi00L006Ki001Vn@00I_T00002I_T00`00I_T00002H_T20002H_T01@00H]T006;I0000
0V;I0P0000INf@00G]YNfP00G]X3000035Zj001J^P00F[X005Zj001J^P00E[X0009F^P0<001FVP00
EYX005:J001BVP00DYX005:J0P0000e>VP00CYX004ij001>NP00CW/004Yk001:N`0400002DYk001:
N`00BW/004Yk0016N`0200001dIk0016N`00AW/004Ik00800003BW/004Yk00D0000=BW/004Yk001:
N`00BY/004ZK001:V`00BY/00P000TZK00@004ZK001>V`80000CCY/004jK001>V`00CY/004jk001>
^`00C[/004jk001>^`00C[/0:@0001aB^`00D[/005:k001Bf`00D]/005;K001Bf`00D]/005;K001B
f`00D]/005;K001Bf`00D]/001eoo`03001oogoo04eoo`00A7oo00<007ooOol0;Goo1P00:7oo01H0
05KK001Ff`00E]/005KK001Ff`00E]/005KK001Bf`00D]/005;K001Bf`800003D]/005;K02/0000=
C[`004jl001:W000BY`004ZL001:W000BY`00P0000A6W0000012O0800004?W`00000>U`400000cHl
0000000400001dGF001=mP00DQH0058F00L00008ESH005Hf001F=P00ESH0009F=P07001J=P00FSH0
05YF00000UYF00D005iF001RM@00009VM@03001ZU@00009^]003001b/`0000Afd`03001k4g/C009k
4`03001k4`0000=k4`06001k4g/C001k50000g/d00<007/d00000g/d0P0017/e00<007Le00000WLe
00H007LfMcH007Lf0003McH01@00McIg=WLf00000g<g00D007<gLcMc=`00009c=`8000=c=`04001c
>7<h0003LcP02000KcQ_>000KcP006lh0002KaP01000KaQ_60000VlH00@006lHKaP0009_6004001_
6FlI0002KaT01@00JaU[6@00JaT00P000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01000JaT0
06/I0P000V/I00@006/IJaT0009[6@06001[6F/I001[6@000V/I00@006/I0000009[6@07001[6F/I
001[6@00JaP00P000V/H00@006/HJaP0009[6004001[66/H0002JaP01000JaP006/H0P000V/H00L0
06/HJaP006[h001Zn0020002J_P00`00J_P00002J_P01P00J_QZn000I_P0009Vn@03001Vn@00009V
n@03001Vf@0000800009H]T006;IH]T006;I001Nf@00009Nf@0<001N^@00G[T005Zi001J^@00F[X0
05JJ300000E:NP00BWX004IJ00800006@UX00000@SX003hk0P0000Hj>`00000f6`00=Q/20000138K
0000038K0`0000D]n`00000002gk00800004;O/00000;O/300000bgk000]n`03000012hK000002hK
0P0000@^6`00000Z6`800003:O/0000000800003E]/005KK009Ff`0D001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK001Ff`L00006E]/005KK001Ff`000UKK00X005KK001Ff`00E]/005KK
001o<0800003Hm@0000000D00003NmH007^g009k]`8000=k]P06001kUW^F001kU`000W^G00<007^G
00000g^G00<007]gNgL00W]g00@007MhMgP0009gN006001gN7MhMgP007Mh0P000W=H00@007=H0000
00=cF004001cF7=H0002LeT00`00LeUcF@030002KeT01`00KcU_>Fli001_>@00009_>@03001_>Fli
00<0009_>@05001_>Fli001_>@020002KcT00`00JcT00002JcT30002JcT00`00JcT00002JcT01P00
JcU[>@00JcT0009[>@08001[6F/I001[6@00JaT0009[6@06001[6F/I001[6@000V/I00H006/I001[
6@00JaT20002JaT00`00JaT00002JaT300001f/I001[6F/I001[6@00009[6@<0000:IaT006LIIaT0
06Ki001Vn@00I_T2000036Ki001VnFKi001Vn@00I_T006Ki001Rn@800006H_T006;i001Rf@000V;I
00@006;I0000009Nf@D00008G]X005Zj001J^P00F[X0009J^P0J001J^P00E[X005Jj001FVP00EYX0
05:J001BVP00DYX005:J001BVP00CYX004jJ001>NP800009CW/004Yk001:N`00BW/004Yk00@0000;
BW/004Yk0016N`00AW/004Ik0016N`0200001DIk001:N`00BW/00P0000=:N`00BW/01`0001U:V`00
BY/004ZK001:V`00BY/004ZK001:V`00CY/004jK001>V`00CY/004jK001>V`020000@4jk001>^`00
C[/004jk001>^`00C[/004jk001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001Bf`00D]/005;K001Bf`00
0U;K00d005;K001Bf`00D]/005;K001Bf`00D]/0000LOol00`00Oomoo`1=Ool000Moo`@000ioo`<0
00Yoo``0019oo`03001oogoo02Ioo`L002moo`800009E]/005KK001Ff`00E]/005KK00l0000AD]/0
05;K001Bf`00D]/005;K001Bf`00D[/005:k001B_00200004e:l001B_000D[`005:l001B_000D[`0
04jl001>_000C[`004jl00800003C[`004jl00X00003BY`004ZL00800009AY`004Il0012O000?W`0
03iL00800003>U`003Hl00800004<Q`000007=@3000054gf001B5P00DQH0058F001F=P00ESH005Hf
001F=P00ESH005Hf0002ESH01`00FSH005Xf001JEP00009JEP05001NEP00HWD00002IWD01@00JYD0
06jd00000W:c00<007KCM]<00WKC0P000g/C00<007/C00000W/C00L007/CNa=k4`00Na@00004Nc@0
0`00NcAk=003Nc@00`00NcEk=@03NcD01`00McEg=GLe001g=P00009g=P05001g=WLfMcH00004McH0
1@00LcL007<g00000W<g00<007<g00000W<g00D007<gLcL007<h008000=c>005001_>6lhKcP00002
KcP01000KaQ_60000VlH00@006lHKaP0009_6004001_66lH0002KaT01@00KaU_6FlI00000V/I00@0
06/IJaT0009[6@04001[6@00JaT20002JaT01000JaU[6@000V/I00@006/IJaT0009[6@04001[6@00
JaT20002JaT01000JaU[6@000V/I00<006/I00000V/I00@006/IJaT0009[6@04001[6F/I0002JaP0
1000JaP006/H0P000V/H00@006/HJaP0009[6006001[66/H001[60000V/H00@006[hJ_P0009Zn003
001Zn000009Zn004001Zn000J_P20002I_P00`00I_T00002I_T01`00I_T006KI001Rf@00009Rf@05
001Rf@00H]T00002G]T01@00G]T005ji00000Uji00<005Zi00001@0000UFVP00EYX005:J001BVP00
CWX02@0000=2FP00@UX00P0000<n>`00?S/00P0000Hj6`00000f6`00=Q/20000238K0000038K000]
n`00;O/3000012gk000002gk0P0000L]n`00000002gk000^6`03000012hK000002hK0P0000@Z6`00
000Yn`800006:O/00000001Ff`000UKK00h005KK001Ff`00E]/005KK001Ff`00E]/005KK1P0000MF
f`00E]]Ff`00E]/00002E]/03@00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`D00004KoP007Og
0002MmP20003NkL02@00NkL007^f001k]`00NiH00002NiL00`00NiL00002NiL01@00NiL007NH0000
0g]g00P007MhMgP007Mh001gN0000gMh00@007MhMgP0009cF004001cF7=H0002LeP01000LeP00000
0W=I00@007=ILeT0009_F@04001_FFmI0002KcT01P00KcU_>@00KcT0009_>@04001_>Fli0002KcT0
1P00KcU_>@00KcT0009_>@03001[>F/i00<0009[>@03001[>@00009[>@<0009[>@07001[>F/i001[
>@00JaT00P0000Q[6@00JaU[6@00JaT006/I0P000V/I00H006/I001[6@00JaT200001f/I001[6F/I
001[6@00009[6@03001[6@00009[6@03001[6@00009[6@<00007IaT006LIIaT006LI00000VKi0`00
00aVn@00I_UVn@00I_T006Ki001Vn@00I_T200001V;i001Rn@00H_T0009Rf@06001Rf@00H]T005kI
0`0000INfP00G]X005kJ0002F[X09P00F[X005Zj001J^P00F[X005Jj001F^P00EYX005JJ001BVP00
DYX005:J001BVP00DYX004jJ001>VP00CWX004ij001>N`00BW/200001dYk001:N`00BW/004Yk00@0
000;AW/004Ik0016N`00AW/004Ik0016N`0200001DYk001:N`00BW/00P0000I:N`00BW]:N`00BY/4
00009dZK001:V`00BY/004ZK001:V`00CY/004jK001>V`00CY/004jK001>V`00C[/004jk001>^`00
C[/004jk001>^`00C[/004jk001B^`02000055:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k0002D[/01000D[/005:k0`00021B^`00D[/005:k001B^`00D[/005;K001Bf`00D]/005;K
001Bf`00D]/005;K001Bf`00D]/005;K001Bf`0077oo00<007ooOol0CGoo0005Ool8000;Ool50009
Ool<000BOol01000Oomoogoo10006goo1P00=goo2P0000]Bf`00D]/005;K001Bf`00D]/005;K0080
000DD]/005;KD]/005;K001Bf`00D]/005;K001Bf`00D[/005:k001B_080000CD[`005:l001B_000
D[`005:l001B_000C[`004jl001>_000C[`00P0000a>_000001>_000B[`004ZL001:W000BY`50000
1DJL0016O000@W`00P0000HnO000000jG000>U`200001C8l000000007=@00`0001A=mP00DQH0058F
001B5P00ESH005Hf001F=P00ESH005Hf001F=P000UHf00D005Xf001J=P00009JEP07001JEP00GUH0
069e00000VIe00<006ZEJYD00P000W:c00L007KCM]=fd`00Na800003Na<01P00Na=k4`00Na<000=k
4`8000Ek=003001k=7/d00=k=003001k=G/e00=k=@03001g=GLe009g=@03001g=WLf009g=P05001g
=P00McH00004McH01000LcMc=`000g<g00D007<gLcMc=`0000=c=`04001c>7<h0003LcP01000KcP0
00000flh00L006lH001_6000KaP00002KaP01`00KaP006lH001_6@00009_6@05001_6FlI001[6@02
0002JaT01000JaU[6@000V/I00@006/IJaT0009[6@04001[6@00JaT20002JaT01000JaU[6@000V/I
00@006/IJaT0009[6@04001[6@00JaT20002JaT01`00JaU[6@00JaT006/I0080009[6@04001[66/H
0002JaP01000JaQ[60000V/H00@006/H001[6080009[6007001[66/H001[6000J_P00P000V[h00H0
06[hJ_P006[h0002J_P01P00I_QVn000I_P0009Vn@03001Vn@00009Vn@80009Rf@05001Rf@00H]T0
0002H]T01@00G]T005kI00000Uji1@0000EJ^@00001FVP00009FVP06001FVP00DYX005:J0P0000E>
NP00CWX004Yj00D00003@UX0048j00800003?S/003Xk00800006>Q/00000=Q/0038K0`0000Db6`00
000002gk00800007;O/00000000]n`00;O/00`0000@^6`00000^6`800004;Q/00000;Q/2000012hK
000002XK0`0000HYn`00000005KK0002E]/01P00E]/005KK001Ff`P00006E]/005KK001Ff`000UKK
00`005KKE]/005KK001Ff`00E]/005KK0002E]/02000E]/005KK001Ff`00E]/30002KoP00`00MoL0
0003MmP01@00MmP007^g00000g^g00D007^gNkMk]`0000AkU`03001kUg^G009kU`09001gV7NHMiP0
07]g001gN000009gN005001gN7MhMgP00002MgP01000MgQgN0000W=H00D007=HLeQcF000009cF004
001cFG=I0002LeT30002KeT01@00KeU_F@00KcT00P000Vli00<006liKcT00`000Vli00D006liKcT0
06li0080009_>@03001_>@00009[>@03001[>@00009[>@03001[>@00009[>@04001[>F/i0002JcT0
1000JcT006/i0P0000M[6@00JaU[6@00JaT00002JaT00`00JaT00002JaT00`00JaT00002JaT00`00
JaT00002JaT00`00JaT00002JaT300001f/I001[6F/I001[6@00009[6@03001[6@00009W6@03001W
6@00009W6@<0000<I_T006KiI_T006Ki001Vn@00I_T006Ki0P0000ARn@00H_URn@80009Rn@05001R
f@00H]T00002H]T20000=5kJ001NfUkJ001NfP00G]X005Zj001J^P00F[X005Zj001J^P00E[X005Jj
001FVP00EYX005:J001BVP00DYX005:J001BVP00CYX004jJ001>NP00CWX004ik001:N`00BW/004Yk
0P0000M:N`00BW/004Yk001:N`0400002dIk0016N`00AW/004Ik001:N`00BW/00P0000e:N`00BW/0
04Yk001:N`00BY/004ZK001:V`060002BY/01000BY/004jK0P0003E>V`00CY/004jK001>V`00C[/0
04jk001>^`00C[/004jk001>^`00C[/004jk001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k00<0000PD[/005:k001B^`00D[/005:k001Bf`00D]/0
05;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/001aoo`03001oogoo04eoo`001Goo0P00
17oo0P002goo1@002Woo0`001Woo0P004Woo100067oo1`00?Goo0P0000QFf`00E]/005KK001Bf`00
0U;K00X005;K001Bf`00D]/005;K001Bf`80000CD]/005;K001Bf`00D]/005;K001Bf`00D]/005:k
001B^`00D[`00P0001=B_000D[`005:l001B_000D[`005:l001>_000C[`004jl001>_00200002djl
001>_000C[`004Zl001:W000BY`00P0000=:W000AY`01@0000E2O000@W`003il00<00003>U`003Hl
00800003<Q`001cD0080000AAMH00000DQH0058F001B5P00ESH005Hf001F=P00ESH00002ESH01@00
ESH005Hf00000UXf00/005Xf001JEP00FUH005iF001RM@00009VM@03001ZUFZE0080009b/`07001f
dgKCM]<007/B00000g/C00H007/CNa<007/C0004Na<00`00NcAk=003Nc@20003Nc@00`00NcD00003
NcD00`00NcD00003McD00`00McIg=P02McH00`00McH00002McH01@00McIg=WLf00000g<g00@007<g
LcL000Ac=`04001c=g<g0002LcP00`00LcQc>002LcP01000KcQ_>0000Vlh00@006lHKaP0009_6004
001_66lH0002KaP01000KaU_6@000flI00@006lIKaT0009[6@07001[6F/I001[6@00JaT00P000V/I
00@006/IJaT0009[6@04001[6F/I0002JaT01000JaT006/I0P000V/I00@006/IJaT0009[6@06001[
6F/I001[6@000V/I00@006/I0000009[6@07001[6F/I001[6000JaP00P000V/H00@006/HJaP0009[
6006001[66/H001[60000V/H00@006/HJaP0009Zn003001Zn000009Zn004001Zn000J_P20002I_P0
0`00I_P00002I_T01000I_T006Ki0P0000IVf@00H]T006;I0002H]T01P00H]T005kI001Nf@@0000G
G[T005Zi001J^@00F[X005JJ001FVP00EYX005:J001BVP00CWX004ij001>NP0200000dYJ00000003
00000d8j000n>`0200000cXk000j6`0200001SHK0000038K000b6`L00004;O/00000;O/300000bgk
000]n`03000012hK000002hK0P0000@^6`00000^6`800004:Q/00000:O/3000012Gk001Ff`000UKK
1P0000QFf`00E]/005KK001Ff`000UKK00L005KK001Ff`00E]/00002E]/00`00E]/00002E]/03P00
E]/005KK001Ff`00E]/005KK001Ff`00E]/900000gOH001gf002MmP20003NkL01000NkMk]g^g0P00
0g^G0P000g^G00<007NHMiP00WNH00@007MhMgP0009gN00?001gN7MhMgP007Mh001gN000MgP007=H
001cF000009cF004001cF0000002LeT01000LeUcF@000W=I00@006mIKeT0009_F@06001_>Fli001_
>@000Vli00@006liKcT0009_>@06001_>Fli001_>@000Vli00<006liKcT00`000V/i00<006/i0000
0V/i0`000V/i00@006/iJcT0009[>@03001[6@00009[6@06001[6@00JaT006/I0P000V/I00<006/I
00000V/I0`0000E[6@00JaU[6@00009[6@<00007JaT006/IJaT006/I00000V/I0`0000M[6@00IaUW
6@00IaT00002IaT01@00I_T006Ki00000VKi00<006Ki00000VKi0`0000AVn@00H_T0009Rn@08001R
n@00H_T006;I001Rf@D0009NfP0E001NfP00G]X005kJ001J^P00F[X005Zj001J^P00F[X005Jj001F
^P00009FVP0:001FVP00DYX005:J001BVP00DYX200004djJ001>VP00CWX004ij001>N`00BW/004Yk
001:N`00BW/004Yk00800007BW/004Yk001:N`00BW/01P0000U6N`00BW/004Yk001:N`00BW/00P00
00A:N`00BW]:N`800009BY/004ZK001:V`00BY/004ZK00T00007CY/004jK001>V`00CY/00P0002]>
^`00C[/004jk001>^`00C[/004jk001>^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`0300004U:k001B^`00D[/005:k001B^`00D]/005;K001B
f`00D]/0009Bf`0=001Bf`00D]/005;K001Bf`00D]/005;K000077oo00<007ooOol0C7oo0004Ool2
0006Ool2000:Ool5000;Ool3000HOol00`00Oomoo`0DOol60015Ool20000:EKK001Ff`00E]/005;K
001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005:k
001B^`00D[`00P0001=B_000D[`005:l001B_000D[`005:l001>_000C[`004jl001>_00200000djl
001>_00200003dZl001:W000BY`004ZL001:W000AY`004JL0016O00400000cil000nG002000013YL
0000038l0P0000PLe0000015eP00COH0058F0P0000AB5P00ESH0009F=P09001F=P00ESH005Hf001F
=P00009F=P0;001J=P00FSH005YF001JEP00GUH00002HWD00`00IWD00002JYD20002L[<01`00M]=f
dgKC001k4P00009k4`07001k4g/CNa<007/C000017/C00<007/dNc@00W/d00@007/dNc@0009k=004
001k=G/e0002NcD00`00NcD00002McD00`00McH00004McH01@00McIg=WLf00000WLf00<007Lg0000
0W<g00D007<g001c=`0000=c=`05001c=`00LcP00002LcP00`00LcQc>0020002KcP01@00KcQ_>000
KaP00P000flH00@006lH001_608000=_6@05001_6FlI001_6@020002JaT01000JaU[6@000V/I00@0
06/IJaT0009[6@04001[6@00JaT20002JaT01000JaU[6@000V/I00@006/IJaT0009[6@04001[6@00
JaT20002JaT01000JaU[6@000V/I00<006/I00000V/I00@006/IJaT0009[6004001[66/H0002JaP0
1000JaP006/H0P000V/H00L006/HJaP006/H001[60020002J_P01`00J_QZn000J_P006[h0080009V
n003001Vn000009Vn004001Vn@00I_T200001VKi001Vf@00H]T0009Rf@06001Rf@00H]T005kI0P00
00ANf@00G[T0009N^@80009J^@80000?EYX005JJ001FVP00DYX005:J001>NP00CWX004ij00800004
BUX00000AUX400000chk000n>`0200000cXK000j6`02000013HK0000038K0P0000<b6`00<Q/01000
00D]n`00000002hK00800004;O/00000;Q/2000012hK000002hK0P0000@^6`00000^6`800005:Q/0
0000000Yn`0600001UKK001Ff`00E]/0009Ff`0=001Ff`00E]/005KK001Ff`00E]/005KK00000UKK
01D005KKE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00`000foj00<007?iLoT0
0P000gOH00T007OH001k]`00NkP007^g00000W^h00<007^G00000W^H00D007^G001gV00000=gV008
001gN7Mh001gN000MgP000=gN004001gN7Mh0002MgP01000LeQcF0000g=H00L007=ILeT007=I001c
F@020002LeT01@00KeU_F@00KeT00P000Vli00<006liKcT00`000Vli00D006liKcT006li0080009_
>@03001_>@00009_>@06001[>F/i001[>@000V/i0`000V/i00L006/iJcT006/i001[>@020002JaT0
1P00JaT006/I001[6@800005JaT006/IJaT00002JaT300001f/I001[6F/I001[6@00009[6@03001[
6@00009[6@03001[6@00009[6@<00007JaT006/IJaT006LI00000VLI0`0000UVn@00I_UVn@00I_T0
06Ki00000VKi00D006Ki001Vn@00009Rn@08001Rn@00H_T006;i001Rf@80000DH]T005kI001NfP00
G]X005kJ001NfP00G]X005Zj001J^P00F[X0009J^P06001J^P00E[X005Jj3`0000M>VP00CYX004ij
001>NP0200003DYk001:N`00BW/004Yk001:N`00BW/004Yk00800009BW/004Yk001:N`00BW/004Yk
00@0000ABW/004Yk001:N`00BW/004Yk001:N`00BY/004ZK001:V`0200002dZK001:V`00BY/004jK
001>V`00CY/02`0000m>^`00C[/004jk001>^`00C[/004jk001>^`00D[/00P0001AB^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`000U:k00@005:k001B^`<0000AD[/005:k001B^`00
D[/005:k001Bf`00D]/005;K001Bf`0?000LOol00`00Oomoo`1<Ool000Aoo`8000Ioo`8000]oo`<0
00eoo`<001Moo`03001oogoo00eoo`L004]oo`80000DE]/005KKE]/005KK001Bf`00D]/005;K001B
f`00D]/005;K001Bf`80000<D]/005;KD]/005;K001Bf`00D]/005;K0P0001=B^`00D[/005:l001B
_000D[`005:l001B_000D[`005:l001B_00200002Djl001>_000C[`004jl001>_00200001djl001:
_000BY`004ZL00800003BY`004JL00800006AY`00000@W`0049l100000@jG000000f?0<0000I7=@0
0000AMH004gf001B5P00DQH0058F001F=P00ESH005Hf001F=P00ESH005Hf00000UHf00T005Xf001J
=P00FUH005YF00000UiF00D0069e001VM@00009ZU@8000=b/`04001fdgKC0002Na800`00Na<00004
Na<00`00Na=k4`03Na<20003Nc@01000NcAk=0000W/d00@007/eNcD0009k=@08001k=G/e001g=@00
McH000Ag=P03001g=WLf009g=P05001g=P00McL00003LcL01@00LcMc=g<g00000g<g00@007<hLcP0
009c>003001c>000009_>004001_>6lh0002KcP01000KcQ_>0000VlH00@006lHKaP0009_6005001_
6FlIKaT00002KaT01000JaU[6@000V/I00@006/I001[6@80009[6@04001[6F/I0002JaT01000JaU[
6@000V/I00@006/I001[6@80009[6@04001[6F/I0002JaT01000JaU[6@000V/I00@006/I001[6@80
009[6@07001[6F/I001[6@00JaP00P000V/H00@006/HJaP0009[6006001[66/H001[60000V/H00@0
06/HJaP0009Zn003001Zn000009Zn006001Zn6[h001Zn0000VKh00H006KhI_P006Kh0002I_T00`00
I_T00002I_T20002H]T01P00H]T006;I001Rf@80000<G]T005kIG]T005ji001N^@00F[T005Zi0P00
00YFVP00EYYFVP00EYX005:J001BVP800007CWX004ij001:NP00BUX00`0000=2FP00@U/00P0000<n
>`00>S/00P0000<j6`00=Q/00P0000Df6`000000038K00<00006<Q/00000;O/002gk0`0000@^6`00
000^6`800004;Q/00000;Q/2000012hK000002hK0`0000<Z6`00:O/00`0000@Yn`00E]/000=Ff`0=
001Ff`00E]/005KK001Ff`00E]/005KK00000UKK00L005KK001Ff`00E]/00002E]/02P00E]/005KK
001Ff`00E]/005KK300000=_nP00LoT00W?i00D007OI001gf00000=gf005001k^7^hNkP00004NkP0
0`00NiQkV002NiP02@00MiQgV7NH001gV000MiP00002MgP01@00MgQgN7Mh00000WMh00@007MhMgP0
009gN005001cF7=HLeP00002LeP01000LeUcF@000W=I00@007=ILeT0009cF@04001_FFmI0002KeT0
0`00KcT00002KcT01000KcU_>@000Vli00@006liKcT0009_>@03001_>@00009_>@<0009[>@03001[
>@00009[>@03001[>@00009[>@04001[>F/i0002JcT00`00JcT00002JaT00`00JaT00002JaT00`00
JaT00002JaT00`00JaT00002JaT00`00JaT00002JaT00`00JaT00002JaT300001f/I001[6F/I001[
6@00009[6@03001[6@00009[6@03001[6@00009W6@<00009I_T006KiI_T006Ki001Vn@00009Vn@<0
000<I_T006KiI_T006;i001Rn@00H_T006;i0P0000YRf@00H]T005kI001NfP00G]X0009NfP06001N
fP00001J^P000UZj00<005Zj0000200000eF^P00EYX005:J001BVP00DYX005:J001BVP0;00000dYk
001:N`0200002dYk001:N`00BW/004Yk001:N`00BW/00P0000U:N`00BW/004Yk001:N`00BW/01000
01=:N`00BW/004Yk001:N`00BY/004ZK001:V`00BY/004ZK001:V`0200003djK001>V`00CY/004jK
001>V`00CY/004jK001>^`0C00004e:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
01/0000>D]/005;K001Bf`00D]/005;K001Bf`00D]/001aoo`03001oogoo04aoo`000goo0P0027oo
0P006goo0`005Woo00<007ooOol01goo1P00Dgoo0P0000QFf`00E]/005KK001Bf`000U;K01L005;K
000005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K0080000CD[/005:k001B_000
D[`005:l001B_000D[`005:l001B_000D[`00P00015>_000C[`004jl001>_000C[`004jl001>_000
B[`004ZL0080000;BY`004ZL0016W000AY`004Il0012O00200000cil000nG00200001SYL0000038l
000Le080000FAMH004gf001B5P00DQH0058F001F=P00ESH005Hf001F=P00ESH005Hf0002ESH02@00
FSH005Xf001JEP00FUH00002GUH01@00HWD006Ie00000VZE00<007:cL[<00W:c00@007KCM]<0009k
4P03001k4`0000Ak4`03001k4g/C009k4`04001k<g/c0002Nc@01000NcAk=7/d0P0017/e0P000g/e
00<007Le00000WLf00H007LfMcH007Lf0004McH01@00McMg=gLg00000W<g00D007<gLcMc=`0000=c
=`05001c>7<hLcP00002LcP01@00KcQ_>6lh00000Vlh00@006lh0000009_>005001_66lH001_6002
0003KaP01@00KaU_6@00KaT00P000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01000JaT006/I
0P000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01000JaT006/I0P000V/I00@006/IJaT0009[
6@06001[6F/I001[6@000V/I00@006/IJaT0009[6@07001[66/H001[6000JaP00P000V/H00L006/H
JaP006/H001[60020002J_P01`00J_QZn000J_P006[h0080009Zn003001Vn000009Vn004001Vn000
I_T2000036Ki001VnFKi001Vf@00H]T006;I001Rf@80000PH]T005kIG]T005kI001N^@00G[T005Zi
001J^@00F[X005JJ001FVP00EYX005:J001BVP00CWX004ij001>NP800006BUX00000AUX0049J0P00
00I2>`00000j>`00>Q/200000cHK000f6`0200000cHK000000020000138K0000038K0P0000@]n`00
000^6`800004;Q/00000;Q/2000012hK000002hK0P0000@^6`00000^6`<00004:O/00000:O/30000
2eKK001FfeKK001Ff`00E]/005KK00000UKK00d005KK001Ff`00E]/005KK001Ff`00E]/00002E]/0
1000E]/005KK3@0000AKo000Io]Wn`@00003LoT007OI009gf@8000=gf004001k^7^hNkP20003NkP2
0003NiP00`00MiQgV002MiP01000MiQgV0000WMh00T007MhMgQgN000MgP007Mh00000WMh0P0000Uc
N000LeQcF000LeP007=I00000W=I00<007=I00000W=I00D007=ILeT006mI0080009_F@03001_>Fli
00<0009_>@05001_>Fli001_>@020002KcT00`00KcT00002KcT01000JcU[>@000V/i00<006/i0000
0P000V/i00L006/iJcT006/i001[>@020002JcT00`00JaT00002JaT30002JaT00`00JaT00002JaT3
00001f/I001[6F/I001[6@00009[6@03001[6@00009[6@03001[6@00009[6@<00007JaT006/IJaT0
06/I00000VLI00<006LI00000VKi00D006Ki001Vn@00009Vn@<00009I_T006KiI_T006Ki001Rn@00
009Rn@<00004H]T006;I0002H]T01000G]T000000UkJ00P005kJ001NfP00G]X005Zj1@0001mJ^P00
F[X005Jj001F^P00E[X005JJ001BVP00DYX005:J001BVP00DYX004jJ001>VP00CYX004ij001>N`07
000044Yk000004Yk001:N`00BW/004Yk001:N`00BW/004Yk0P0000M:N`00BW/004Yk001:N`040000
14Yk001:NdYk0P00015:V`00BY/004ZK001:V`00BY/004ZK001>V`00CY/004jK0080000ICY/004jK
001>V`00C[/004jk001>^`00C[/004jk001>^`00C[/005:k001B^`00D[/05@0000EB^`00D[/005:k
00<0000ND[/005:k001B^`00D[/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K
001Bf`000U;K00<007ooOol06Woo00<007ooOol0Bgoo0003Ool20008Ool2000LOol3000EOol00`00
Oomoo`07001IOol03P00E]/005KK001Ff`00E]/005;K001Bf`00D]/200001E;K001Bf`00D]/0<`00
00=:_000BY`00P0000E:W000BY`004JL00800008AY`00000@W`0049l000nO0800007>U`00000000b
?0007=@00P0001I5eP00COH0058F001B5P00DQH005Hf001F=P00ESH005Hf001F=P00ESH0009F=P07
001J=P00FSH005YF00000UYF00L005iF001RM@00IWD00002JYD00`00L[=b/`02L[<00`00M]<00003
Na800`00Na<00004Na<00`00Na=k4`02Na<01000Nc=k<`000W/d00<007/dNc@00W/d00<007/eNcD0
0g/e00<007/eNcD00W/e00<007LfMcH00WLf00<007Lf00000WLf00D007LfMcIg=P0000=g=`05001c
=`00LcL00003LcL01@00LcL007<g00000W<h00@007<hLcP000A_>004001_>6lh0002KcP01000KcQ_
>0000VlH00@006lHKaP0009_6005001_6FlIKaT00002KaT01`00JaU[6@00JaT006/I0080009[6@05
001[6F/I001[6@020002JaT01`00JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT01000JaU[
6@000V/I00@006/I001[6@80009[6@07001[6F/I001[6@00JaT00P000V/I00@006/HJaP0009[6004
001[66/H0002JaP00`00JaP00002JaP01P00JaQ[6000J_P0009Zn004001Zn6[h0002J_P00`00J_P0
0002I_P01000I_P006Kh0P000VKi00X006Ki001Vn@00I]T006;I001Rf@80000;H]T006;IH]T005kI
001Nf@00G[T00002G[T200004eZi001J^P00EYX005JJ001FVP00DYX005:J001>NP00CWX004ij0080
0008BUX00000AUX0049J0012F`800006?S/00000>Q/003XK0P0000@f6`00000f6`<00004<Q/00000
<Q/20000138K000002gk0P0000@^6`00000^6`800004;Q/00000;Q/300000bhK000^6`03000012hK
000002Wk0P0000@Yn`00E]/000=Ff`0D001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`P0008_G@P00003Emd0000000@000=_n`<0000;MmT007OIMmT007OH001g^@00NkP00002MkP0
0`00NkP00002MiP01@00NiP007NH00000gNH00P007NHMiP007Mh001gN0000gMh00@007MhMgP0009g
N005001cN7=hLgP00002LeP01000LeUcF@000W=I0P0000EcF@00LeUcF@00009cF@06001_FFmI001_
F@000Vli00@006liKcT0009_>@04001_>Fli0002KcT00`00KcT00002KcT30002JcT01P00JcU[>@00
JcT0009[>@03001[>@00009[>@06001[>@00001[>@000V/i00<006/IJaT00`0000M[6@00JaU[6@00
JaT00002JaT00`00JaT00002JaT00`00JaT00002JaT30002JaT00`00JaT00002JaT300001f/I001[
6F/I001[6@00009[6@<00007IaT006KiI_T006Ki00000VKi0`0000UVn@00I_UVn@00I_T006Ki0000
0V;i0`0000ARn@00H]T0009Rf@0>001Rf@00G]T005kJ001NfP00G]X005kJ001NfP<0000<F[X005Zj
001J^P00F[X005Jj001F^P000UJj00X005JJ001BVP00DYX005:J001BVP80000?CYX004jJ001>VP00
CWX004ik001>N`00CW/004Yk00D0000@BW/00000BW/004Yk001:N`00BW/004Yk001:N`00BW/20000
1dYk001:N`00BW/004Yk00L00003BY/004ZK0080000GBY/004ZK001:V`00CY/004jK001>V`00CY/0
04jK001>V`00CY/004jk001>^`020000=4jk001>^`00C[/004jk001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001Bf`000U;K01D005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K000077oo
00<007ooOol0Bgoo0003Ool20008Ool2000MOol3000DOol3001POol01P00E]/005KK001Ff`l0000?
D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K0080000CD[`005:l001B_000D[`005:l001B_000
D[`005:l001B_000D[`00P0000e>_000C[`004jl001>_000C[`004jl001>_00700001dZL0016W000
AY`004JL00800006@W`00000?W`003iL0P0000DjG000000001cD0080000FAMH004gf001B5P00DQH0
058F001F=P00ESH005Hf001F=P00ESH005Hf0002ESH01`00FSH005Xf001JEP00009JEP07001NEP00
HWD006Ie00000VZE00<007:cL[<00W:c00<007KC00000g/B00<007/C000017/C0P000g/C00@007/c
Nc=k<`8000Ek=003001k=G/e00=k=@03001k=G/e009k=@03001g=WLf009g=P03001g=P00009g=P06
001g=WLf001g=P000WLg00D007<g001c=`0000Ac=`04001c=g<g0002LcP01@00LcP007<h00000flh
00@006lhKcP0009_>005001_>6lh001_60020003KaP01@00KaQ_6000KaT00P000VlI00@006/IJaT0
009[6@04001[6F/I0002JaT01P00JaU[6@00JaT0009[6@04001[6F/I0002JaT01000JaU[6@000V/I
00@006/I001[6@80009[6@04001[6F/I0002JaT01000JaU[6@000V/I00@006/I001[6@80009[6@07
001[6F/I001[6000JaP00P000V/H00L006/HJaP006/H001[60020002JaP01`00J_QZn000J_P006[h
0080009Zn006001Zn6[h001Vn0000VKh00<006Ki00000VKi00P006Ki001Vn@00I]T006;I0P0000UR
f@00H]URf@00H]T005kI00000UkI00@005ji001N^@800006F[T005Zj001FVP000UJJ00H005JJ001B
VP00DYX200000dij001>NP0200000dYJ0016FP0200001D9J0012F`00@S/00P0000Hn>`00000j6`00
=Q/200000cHK000000040000138K0000038K0P0000@b6`00000^6`800007;Q/00000000^6`00;Q/0
0P0000L^6`00000002hK000^6`03000012hK000002Wk0`00019Ff`00E]]Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/800000c=N0000000600000cnN0000000200000doM0000000200001eol001W
o6Ol001_n`0000=_n`8000=gf@04001g^GNiMkT20003MkP00`00MiQgV002MiP02@00MiQgV7NH001g
V000MiP00002MiP01@00MgQgN7Mh00000WMh00D007MhMgP007Mh008000=cN004001cF0000003LeT0
1P00LeUcF@00LeT0009cF@04001cF@000002KeT00`00KeU_F@030002KcT01@00KcU_>@00KcT00P00
0Vli00<006liKcT00`000V/i00P006/iJcT006/i001[>@000V/i00@006/iJcT0009[>@03001[>@00
009[>@03001[>@00009[6@03001[6@00009[6@03001[6@00009[6@<0009[6@03001[6@00009[6@<0
009[6@05001[6@00JaT00002JaT00`00JaT00002JaT00`00JaT00002JaT300002FLI001W6FLI001V
n@00I_T00002I_T01@00I_T006Ki00000VKi00D006Ki001Vn@00009Rn@05001Rn@00H_T00002H]T0
3000H]T006;I001Nf@00G]X005kJ001NfPD0000TF[X005ZjF[X005Zj001J^P00F[X005Jj001F^P00
E[X005JJ001BVP00DYX005:J001BVP00DYX004jJ001>VP00CYX004ij0P0000U>N`00CW/004Yk001:
N`00BW/01@0000=:N`00BW/00P0000]:N`00BW/004Yk001:N`00BW/004Yk00800009BW/004Yk001:
V`00BY/004ZK00L00003BY/004ZK0080000kCY/004jK001>V`00CY/004jK001>V`00CY/004jk001>
^`00C[/004jk001>^`00C[/004jk001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`03000085:k001B^`00D[/005:k001Bf`00D]/005;K001B
f`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K000LOol00`00Oomoo`1;Ool000=oo`8000Qo
o`8001ioo`<001=oo`03001oogoo065oo`D00009D]/005;K001Bf`00D]/005;K00800004D]/005;K
0002D]/03P00D]/005;K001Bf`00D]/005;K001Bf`00D]/200004e:l001B_000D[`005:l001B_000
D[`005:l001B_000D[`005:l0080000;C[`004jl001>_000C[`004jl001>_00200000dZl001:W002
00000dZL0000000400001DJL0016O000@W`00P0000@nO000000jG0<00004<S`00000>ID2000054gf
001B5P00DQH0058F001F=P00ESH005Hf001F=P00ESH005Hf0002ESH01`00FSH005Xf001JEP00009J
EP05001NEP00HWD00002IWD30004L[<00`00M]<00004Na800`00Na=k4`03Na<20003Na<00`00Nc=k
<`02Nc<00`00NcAk=002Nc@00`00Nc@00003NcD00`00NcD00002NcD00`00NcD00004McH00`00McIg
=P02McH01@00McH007Lf00000gLg00D007<gLcMc=`0000=c=`05001c=g<gLcL00002LcP01000LcQc
>0000flh00D006lh001_>000009_>004001_>6lh0002KcP01000KaQ_60000flH00@006lIKaT0009_
6@04001[6@00JaT20002JaT01@00JaU[6@00JaT00P000V/I00L006/IJaT006/I001[6@020002JaT0
1000JaU[6@000V/I00@006/IJaT0009[6@04001[6@00JaT20002JaT01000JaU[6@000V/I00<006/I
00000V/I00@006/IJaT0009[6004001[6F/I0002JaP01000JaP006/H0P000V/H00H006/HJaP006[h
0002J_P01P00J_QZn000J_P0009Zn004001Vn000I_P20002I_T01`00I_T006Ki001Vn@00009Vf@03
001Rf@00009Rf@05001Rf@00H]T00002G]T02P00G]T005ji001N^@00F[T005Zi5@0000E6FP00AUX0
049J00800003@S/003hk00800006?S/00000=Q/003HK0P0000<f6`0000000P0000<b6`00<Q/00P00
00Lb6`00000002hK000^6`0200001bhK00000000;Q/002hK00<00004;Q/00000;Q/2000012hK0000
02XK0P0000@Yn`00E]/0009Ff`08001Ff`00E]/005KK001Ff`P00003;ed0000000H00003=gh003]n
00H00003Bkh0000000800003Fmd0000000800003Io`000000080000;Ko/007?KLm/007OI001gfP00
MkT00002MkT01@00MkP007Ni00000gNH00<007NHMiP00WNH00D007NHMiP007NH008000=gN005001g
N000MgP00002MgP01000LgQcN0000g=h00@007=ILeT0009cF@04001cF@000002LeT01000LeUcF@00
0VmI00H006mIKeT006mI0002KcT01000KcU_>@000Vli00H006liKcT006li0002KcT00`00KcT00002
JcT01@00JcU[>@00JcT00P0000Q[>@00JcU[>@00JcT006/i0P000V/i00<006/i00000V/i0`000V/I
00<006/I00000V/I0`0000M[6@00JaU[6@00JaT00002JaT00`00JaT00002JaT00`00JaT00002JaT3
0002JaT01@00JaT006/I00000V/I00<006LI00000VLI00D006LI001Vn@00009Vn@<00009I_T006Ki
I_T006Ki001Vn@00009Vn@<0000;H_T006;iH_T006;I001Rf@00H]T00002G]T20000<UkJ000005kJ
001NfP00G]X005Zj001J^P00F[X005Zj001J^P00E[X005Jj001F^P00EYX005:J001BVP00DYX005:J
001BVP00CYX004jJ001>VP00CWX004ik001>N`00CW/200001dYk001:N`00BW/004Yk00L0000>BW/0
0000BW/004Yk001:N`00BW/004Yk001:N`80000;BY/004ZK001:V`00BY/004ZK001:V`0700001DjK
001>V`00CY/00P0003=>V`00CY/004jK001>^`00C[/004jk001>^`00C[/004jk001>^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00`00
01iB^`00D[/005:k001B^`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K
0002D]/00`00Oomoo`0IOol00`00Oomoo`1;Ool000=oo`8000Qoo`8001moo`<001=oo`03001oogoo
061oo`05001Bf`00D]/00002D]/02000D]/005;K001Bf`00D]/200008E;K001Bf`00D]/005;K001B
f`00D]/005;K001Bf`00D]/005;K001Bg000D[`005:l001B_000D[`005:l001B_00200001e:l001B
_000D[`004jl0080000?C[`004jl001>_000C[`004jl001>_000B[`004ZL00<00005BY`004JL0016
W00400000d9l0012O002000013iL000003YL100000<iU@00AMH00P0000iB5P00DQH0058F001F=P00
ESH005Hf001F=P000UHf00/005Hf001F=P00FSH005Xf001JEP00009JEP05001NEP00HWD00002IWD3
0004L[<00`00M]<00004Na800`00Na=k4`02Na<01000Oc=o<`000W/C00<007/cNc<00W/c00<007/d
Nc@00W/d00<007/d00000g/e00<007/e00000W/e00@007/eNcD000=g=P03001g=WLf00=g=P05001g
=WLfMcH00002McL00`00LcMc=`02LcL01@00LcL007<g00000W<g00@007<hLcP000=c>005001_>6lh
KcP00002KcP01000KcQ_>0000Vlh00D006lhKcQ_>000009_6004001_60000002KaT01000KaU_6@00
0V/I00@006/IJaT0009[6@04001[6F/I0002JaT00`00JaT00002JaT01000JaT000000V/I00L006/I
JaT006/I001[6@020002JaT01`00JaU[6F/I001[6@00009[6@07001[6F/I001[6@00JaT00P000V/I
00L006/IJaT006/I001[60020002JaT01000JaQ[60000V/H00<006/H00000V/H00L006/HJaP006[h
001Zn0020002J_P01`00J_QZn000J_P006Kh0080009Vn@03001Vn@00009Vn@80009Vn@<0009Rf@05
001Rf@00H]T00002H]T01`00G]T005kI001N^@00009N^@@0000AF[X005Jj001FVP00EYX005:J001B
VP00DYX004ij001>NP0500001DIJ0012FP00@U/00P0000<n>`00?S/00P0000@j>`00000f6`800005
=Q/00000000b6`0200000c8K000b6`0200001c8K00000000;Q/002hK00<00006;Q/00000;Q/002hK
0`0000@^6`00000^6`800004;Q/00000:O/2000015KK001FfeKK7P0000<oWP000000100000=CgP00
00000P0000AOo@00000000=[o08000=cf`05001gfWOJMmX00004MkT02@00MkUg^GNi001gV000MiT0
0003MiP01@00MiQgV7NH00000WMh00D007MhMgQgN000009gN004001gN7Mh0003LgP01000LgQcN000
0g=I00@007=ILeT0009cF@04001cF@00LeT20002KeT01P00KeU_F@00KeT0009_>@05001_>Fli001_
>@020002KcT00`00KcU_>@030002KcT01000JcU[>@000V/i00D006/i001[>@00009[>@06001[>F/i
001[>@000V/i00<006/i00000V/i00<006/I00000V/I00<006/I00000V/I00<006/I00000V/I00<0
06/I00000V/I0`000V/I00D006/IJaT006/I00<0009[6@05001[6@00JaT00002JaT30002IaT01@00
IaT006LI00000VKi0`0000UVn@00I_UVn@00I_T006Ki00000VKi0`0000]Rn@00H_URn@00H_T006;I
001Rf@00009Rf@D0000eG]X005kJ001NfP00G]X005Zj001J^P00F[X005Zj001J^P00E[X005Jj001F
^P00EYX005:J001BVP00DYX005:J001BVP00CYX004jJ001>VP00CWX004ik001>N`00CW/004Yk001:
N`0200002DYk001:N`00BW/004Yk001:N`05000044Yk000004Yk001:N`00BW/004Yk001:N`00BY/0
04ZK0P0000]:V`00BY/004ZK001:V`00BY/004jK00T00009CY/004jK001>V`00C[/004jk0080000d
C[/004jk001>^`00C[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005;K0002D]/04P00D]/005;K001B
f`00D]/005;K001Bf`00D]/005;K001Bf`<001aoo`03001oogoo04Yoo`000goo0P0027oo0P0087oo
0P004goo00<007ooOol0HGoo02@005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K
001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/200004e:l001B_000D[`005:l001B_000D[`0
05:l001B_000D[`005:l0080000;C[`004jl001>_000C[`004jl001>_00200000dZl001:W0020000
1DZL001:W000AY`00P0000=6W000@W`01@0000<nG000>U`01@0000LiU@00AMH004gf001B5P020000
158F001F=P000UHf014005Hf001F=P00ESH005Hf001F=P00FSH005Xf001JEP00009JEP05001NEP00
HWD00002IWD30004L[<00`00M]<00004Na800`00Na=k4`02Na<01000Oc=o<glc0P0017/c00<007lc
00000g/d00H007/dNc@007/e0003NcD00`00NcD00002NcD01P00McIg=P00McH000Ag=P09001g=WLf
McH007Lg001g=`0000=c=`05001c=`00LcL00002LcL01@00LcP007<h00000g<h00@006lhKcP000=_
>007001_>000KcP006lh00000Vlh00D006lHKaQ_6000009_6@07001_6FlI001_6@00JaT00P000V/I
00D006/IJaT006/I0080009[6@04001[6F/I0002JaT00`00JaT00002JaT01000JaU[6@000V/I00@0
06/IJaT0009[6@06001[6F/I001[6@000V/I00L006/IJaU[6@00JaT00002JaT00`00JaT00002JaT0
1000JaU[6@000V/I00L006/IJaT006/H001[60020002JaP01`00JaQ[6000JaP006[h0080009Zn003
001Zn000009Zn006001Zn6[h001Vn@000VKi00<006Ki00000VKi00<006Ki00000P000V;I00D006;I
001Rf@00009Rf@05001Rf@00G]T00002G]T6000045Zj001J^UZj001F^P00EYX005JJ001BVP00DYX0
05:J0P0000A>NP00001:NP@00005@UX0049K0012>`0200000chk000n>`0200001CXk00000000=Q/0
0P0000@b6`00000b6`800003<Q/0038K00<00006<Q/00000;Q/002hK0`0000@^6`00000^6`800004
;Q/00000;Q/2000012hK000002XK0P0000<Yn`0000001@0000DMf`00000001Vk00h000058_d002/n
000cGP0600000dNO001;_P04000015_N000000000V?m00<006_l00000V_L00T007?K001cf`00MmX0
07>j00000gNi0P000gNi00T007NIMiUgV@00MiP007NI00000WNH00H007MhMgQgN000MgP20002MgP0
1@00MgP007=i00000W=h00D007=h001cF@00009cF@04001cF@000002LeT01000LeUcF@000VmI00@0
06mIKeT0009_F@03001_F@00009_>@04001_>Fli0002KcT00`00KcT00002KcT01P00KcU_>@00KcT0
009[>@04001[>@000002JcT01P00JcT006/i001[>@80009[>@03001[>@00009[>@<0009[6@03001[
6@00009[6@<0009[6@03001[6@00009[6@<0009[6@03001[6@00009[6@05001[6@00JaT00002JaT0
1@00JaU[6@00JaT00`000VLI00D006LI001W6@00009W6@<00009I_T006KiI_T006Ki001Vn@00009V
n@<0000;H_T006;iH_T006;i001Rn@00H]T00002H]T300001UkJ001NfP00G]X0009NfP06001NfP00
001J^P000UZj00X005Zj000005Zj001F^P00E[X0009F^P0<001FVP00DYX005:J001BVP00DYX005:J
0P0001=>VP00CYX004ij001>N`00CW/004ik001:N`00BW/004Yk001:N`0200002DYk001:N`00BW/0
04Yk001:N`0500000dYk001:N`0200003DYk001:N`00BY/004ZK001:V`00BY/004ZK0080000=BY/0
04ZK001>V`00CY/004jK001>V`00CY/03@0002M>^`00C[/004jk001>^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00`0000UB^`00D[/0
05:k001B^`00D]/05@0000=Bf`00Ool06Goo0`00C7oo0003Ool20008Ool2000QOol2000COol00`00
Oomoo`1QOol03P00D]/005;K001Bf`00D]/005;K001Bf`00D]/2000015;K001Bf`000U;K00H005;K
001Bf`00D]/200004e;K001Bf`00D]/005;L001B_000D[`005:l001B_000D[`005:l0080000AD[`0
05:l001B_000C[`004jl001>_000C[`004jl001>_00200001Djl001:_000BY`00P0000Q:W0000016
W000AY`004JL0P0000=2O000@W`00`0000<jG000>U`00`00020iU@00AMH004gf001B5P00DQH0058F
001F=P00ESH005Hf001F=P00ESH005Hf001F=P00FSH005Xf001JEP000UYF00<005iF00000V9e00D0
06Ie001VU@0000Eb/`03001k4W/B00=k4P8000=k4`04001o<glcOc<20004Nc<00`00Oc<00002Nc@0
1`00NcAk=7/d001k=@0000=k=@8000Ak=@03001g=P00009g=P06001g=WLf001g=P000gLf00D007Lg
McMg=`0000=c=`05001c=g<gLcL00002LcL01@00LcQc>7<h00000W<h00D006lh001_>000009_>004
001_>6lh0002KcP01P00KcQ_>6lh001_6080009_6@04001_6FlI0002KaT01000JaU[6@000V/I00@0
06/IJaT0009[6@07001[6F/I001[6@00JaT00P000V/I00L006/IJaT006/I001[6@020002JaT01@00
JaU[6F/I00000V/I00<006/I00000V/I00H006/IJaT006/I0002JaT01`00JaU[6@00JaT006/I0080
009[6@04001[6F/I0002JaP01P00JaU[6@00JaP0009[6006001[66/H001Zn0000V[h00L006[hJ_P0
06[h001Zn0020002I_T00`00I_T00002I_T01`00I_T006Ki001Vf@00009Rf@03001Rf@00009Rf@05
001Rf@00H]T00002G]T300005eji001N^@00F[T005Zj001J^P00E[X005JJ001FVP00DYX005:J001B
VP00CWX00P0000I:NP00001:FP00AUX400001D8k000n>`00?S/00P0000@j>`00000j6`<00004=Q/0
0000<Q/200001S8K0000038K000b6`<00004<Q/00000;Q/2000012hK000002hK0P0000@^6`00000^
6`800004;Q/00000;Q/3000012Wk000002Gk0`0000@Qf`00000Mf`@000034IX0000001000003=eh0
03mo00H00004Dkh000000002Gmh01000Hod000000f_L0P000g?K00L007>jLkYc^P00MkT00002MkT0
1@00MkT007Ni00000gNI00P007NIMiT007NH001gV@000gMh00@007MiMgT0009gN005001cNG=iLgT0
0002LgP01000LeUcF@000g=I00L007=ILeT007=I001cF@020002KeT01@00KeU_F@00KeT00P0000I_
F@00KcU_>@00KcT20002KcT00`00KcU_>@030002KcT01000KcU_>@000V/i00<006/i00000V/i00@0
06/i001[>@80009[>@03001[>@00009[>@<00005JaT006/IJaT00002JaT30002JaT01@00JaT006/I
00000V/I00<006/I00000V/I00P006/IJaT006/I001[6@000V/I00X006/IJaT006/I001[6@00IaT0
009W6@03001W6FLI0080009W6@03001Vn@00009Vn@05001Vn@00I_T00002I_T3000016Ki001Rn@00
0V;i00D006;i001Rn@00009Rf@<00006H]T005kJ001NfP000UkJ01@005kJ001NfP00G]X005Zj001J
^P00F[X005Zj001J^P00E[X005Jj4@0000M>VP00CYX004ij001>N`0200003dik001:N`00BW/004Yk
001:N`00BW/004Yk001:N`0200001dYk001:N`00BW/004Yk00L0000DBW/00000BY/004ZK001:V`00
BY/004ZK001:V`00BY/004ZK001>V`80000ACY/004jK001>V`00CY/004jK001>^`00C[/004jk001>
^`0e00005U;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`0067oo0P000Woo
00<007ooOol0BWoo0003Ool20008Ool2000QOol2000DOol00`00Oomoo`1POol01@00D]/005;K0000
0U;K01D005;K000005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/00P0000MBf`00D]/0
05;K001Bg00H00001djl001>_000C[`004jl00800007C[`004Zl001:W000BY`00P0000=:W000AY`0
0P0000E6W000@W`0049l00<00004?U`00000>U`200007acD000004GF001=mP00DQH0058F001B5P00
ESH005Hf001F=P00ESH005Hf001F=P00ESH005Xf001J=P00009JEP03001JEP00009NEP07001RM@00
IWD006JE00001G:c00<007/BNa800g/B0P000g/C00<007lcOc<00Wlc00<007/cNc<00W/c00H007lc
Oc<007/d0004Nc@00`00NcEk=@03NcD00`00NcEk=@03NcD01`00McIg=WLf001g=P00009g=P05001g
=WLfMcH00003McL01@00LcMc=g<g00000g<g00@007<gLcL000=c>005001c>7<hLcP00002KcP01@00
KcQ_>000KcP00P000flh00D006lhKcQ_>000009_6007001_6FlI001_6@00KaT00P000V/I00D006/I
JaT006/I0080009[6@04001[6F/I0002JaT01P00JaU[6@00JaT0009[6@04001[6@000002JaT01000
JaU[6@000V/I00H006/I000006/I0003JaT01P00JaU[6@00JaT0009[6@03001[6@00009[6@04001[
6F/I0002JaT01000JaT006/H0P000V/I00L006/HJaP006/H001[60020002J_P01P00J_QZn000J_P0
009Zn006001VnFKi001Vn@000VKi00<006Ki00000VKi0P000VKI00<006;I00000V;I00H006;I001R
f@00H]T4000015kI001N^Eji0P0001EJ^@00F[X005Zj001F^P00EYX005JJ001BVP00DYX005:J001>
NP00CWX00P0000=:NP00BUX00P0000=6F`00@U/00P0000Dn>`00?S/003hk00<00003>Q/0000000<0
0004<Q/00000<Q/20000138K0000038K0P0000@b6`00000b6`800004;Q/00000;Q/2000012hK0000
02hK0P0000@^6`00000^6`800005:Q/00000000Yn`0200001BGk000000008M/00`0000<I^`000000
100000<1>@000000400000=3O`00Bkl00`000UON00@005oN0000009Wg@03001[g000009_g005001c
f`00Lm/00003LkX00`00MkUg^@02MkT01P00MkUg^GNi001gV@8000=gV@05001gVGNIMiT00002MgP0
1@00MgUgN@00MgP00P000g=i00@007=h000000=cF@04001cFG=I0002LeT01000LeUcF@000W=I00@0
06mIKeT0009_F@06001_FFmI001_F@000Vli00H006liKcT006li0002KcT01000KcU_>@000Vli00@0
06li001[>@80009[>@03001[>@00009[>@03001[>@00009[>@03001[>@00009[>@03001[>@00009[
6@03001[6@00009[6@03001[6@00009[6@05001[6F/I001[6@030002JaT01`00JaU[6@00JaT006/I
00800004JaT006/I0002JaT01@00JaT006/I00000VLI00<006LI00000VLI00<006LI00000P000VKi
00D006Ki001Vn@00009Vn@<00004I_T006Ki0002H_T01@00H_T006;i00000V;i0`0000ARf@00H]T0
009NfP0B001NfP00G]X005kJ001NfP00G]X005Zj001J^P00F[X005Zj1`0000mF^P00EYX005JJ001B
VP00DYX005:J001BVP00DYX02`0000=>N`00BW/00P0000e:N`00BW/004Yk001:N`00BW/004Yk001:
N`0200002DYk001:N`00BW/004Yk001:N`0500000dZK001:V`0200004dZK001:V`00BY/004ZK001:
V`00CY/004jK001>V`00CY/004jK0080000aCY/004jk001>^`00C[/004jk001>^`00C[/004jk001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/00`0001IB^`00D[/005:k001B^`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0009Bf`09
001Bf`00D]/005;K001Bf`0001]oo`03001oogoo04Yoo`0017oo0P001Woo0P006Goo0P001goo0P00
57oo00<007ooOol0HGoo00P005;K001Bf`00D]/005;K0P0000EBf`00D]/005;K01D0000=D]`005:l
001B_000D[`005:l001B_000D[`00P0000UB_000D[`004jl001>_000C[`03@0000U:W000BY`004ZL
001:W000AY`00P0000I6W0000012O000@W`300001CYL000000007=@00P0001Q5eP00COH0058F001B
5P00DQH005Hf001F=P00ESH005Hf001F=P00ESH005Hf0002FSH01@00FSH005YF00000UYF00@005iF
001RM@<00003IYD007:c00Ab/`03001k4W/B009k4P04001k4W/B0002Na<00`00Oc=o<`02Oc<01@00
Nc=k<g/c00000glc00<007/d000017/d00<007/eNcD00g/e00<007/eNcD00g/e00<007LfMcH00WLf
00<007LfMcH00WLf00D007Lf001g=`0000=g=`05001c=`00LcL00002LcL01@00LcL007<h00000g<h
00@007<h000000=_>004001_>6lh0002KcP01@00KcQ_>6lh00000Vlh00@006lHKaP0009_6@04001_
6FlI0002KaT01000JaU[6@000V/I00@006/IJaT0009[6@04001[6@00JaT20002JaT01000JaU[6@00
0V/I00<006/I00000f/I00@006/IJaT0009[6@06001[6F/I001[6@000V/I00H006/I000006/I0003
JaT200000f/I00000002JaT01000JaU[6@000V/I00H006/IJaT006/I0002JaP01000JaQ[60000V[i
00<006[h00000V[h00@006[h001Zn080009Vn@03001Vn@00009Vn@04001Vn@00I_T2000016Ki001V
f@000V;I00H006;I001Rf@00H]T2000016;I001Nf@000UkI00@005ji001N^@80000@F[X005ZjF[X0
05Jj001FVP00EYX005:J001BVP00DYX200002Tij000004Yj001:FP00AUX004IK0P0000Q2F`00000n
>`00?S/003Xk100000Hf6`00000b6`00<Q/20000138K0000038K0P0000@b6`00000b6`800004<Q/0
0000;Q/2000012hK000002hK0P0000L^6`00000002hK000^7003000012Wk000002Gk0`0000@Qf`00
000Mf`@000035I/0000001P0009?_`04001GgP000002Gmh00`00Imd000020003Km`02@00Lm]cfg?K
001c^P00LkX00003MkT00`00MkUg^@02MkT01000MiUgV@000WNI00T007NIMiUgV@00MgP007Mi0000
0WMi00@007=iLgT000=cN@04001cNG=i0002LeT01`00LeT007=I001cF@00009cF@04001cFG=I0002
KeT01000KeT000000VmI00@006mI001_>@80009_>@03001_>Fli00<0009_>@04001_>Fli0002KcT0
1P00JcU[>@00JcT0009[>@<0009[>@03001[>@00009[>@<0009[>@03001[6@00009[6@<0009[6@08
001[6F/I001[6@00JaT0009[6@03001[6@00009[6@08001[6F/I001[6@00JaT0009[6@04001[6@00
JaT2000016LI001W6@000VLI00D006LI001W6@00009Vn@03001Vn@00009Vn@80009Vn@03001Vn@00
009Vn@07001Vn@00H_T006;i00000V;i0`0000ARf@00H]T0009Rf@0@001NfP00G]X005kJ001NfP00
G]X005kJ001J^P00F[X500001UZj001F^P00E[X0009F^P80000EEYX005:J001BVP00DYX005:J001B
VP00CYX004jJ001>VP00CY/004jK00L0000@BW/00000BW/004Yk001:N`00BW/004Yk001:N`00BW/2
00002DYk001:N`00BW/004ZK001:V`0700000dZK001:V`0200006dZK001:V`00CY/004jK001>V`00
CY/004jK001>V`00CY/004jk001>^`00C[/004jk001>^`0200009Tjk001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0002D[/0
7`00D[/005:k001B^`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001B
f`0001aoo`03001oogoo04Uoo`0017oo0P001Woo0P006Goo0`001Woo0P005Goo00<007ooOol0HGoo
3P0000eBf`00D]/005;K001Bf`00D]/005;K001Bf`0200001U;K001Bg000D]`0009Bg00<001B_000
D[`005:l001B_000D[`005:l0P0000MB_000D[`004jl001>_00200001djl001>_000C[`004jl0080
0003C[`004Zl00P00003AY`004JL00800003@W`0049l00<00006?U`00000>U`001cD0P0001I5eP00
COH0058F001B5P00DQH005Hf001F=P00ESH005Hf001F=P00ESH0009F=P07001J=P00FSH005YF0000
0UYF00<005iF00000P0000ARM@00IYD000Eb/`03001k4W/B009k4P04001k4W/B0002Na<00`00Oc=o
<`02Oc<20002Nc<00`00Oc=o<`02Oc<00`00NcAk=003Nc@20003NcD00`00NeD00003NcD00`00NcH0
0003McH00`00McIg=P02McH00`00McH00002McL01@00McMg=gLg00000W<g00D007<gLcMc=`0000=c
>005001c>7<hLcP00002LcP01@00KcQ_>000KcP00P000flh00P006lhKcP006lh001_>0000VlH00@0
06lI001_6@80009_6@05001[6F/I001[6@020002JaT01000JaU[6@000V/I00@006/IJaT0009[6@04
001[6@00JaT20002JaT01000JaU[6@000V/I00@006/I0000009[6@04001[6F/I0002JaT01P00JaU[
6@00JaT0009[6@03001[6@00009[6@07001[6F/I001[6@00JaT00P000V/I00L006/IJaT006/H001[
60020002J_T01`00J_QZn000J_P006[h0080009Zn@03001Vn@00009Vn@04001Vn@00I_T200001VKi
001Vn@00I]T0009Rf@04001Rf@00H]T200007V;I001RfF;I001Nf@00G]T005ji001N^@00F[T005Zj
001J^P00E[X005JJ001FVP00DYX005:J001BVP800003CWX004Yj00800007BUX004IJ0016F`00@U/0
0P0000=2>`0000000P0000@j>`00000j6`<00006=Q/00000<Q/0038K0P0000@b6`00000b6`800004
<Q/00000<Q/20000138K000002hK0`0000<^6`00;Q/00`0000@^6`00000^70<00003:O/002Wk0080
00059O/0027K000Qf`0300000aVk0000000400001@EI000000000=L02@0000HNg@00:ah003]O0002
@il01000Ckl000000U^n00<005oN00000P000VOM00D006oL001_g00000=cf`80009c^P05001g^@00
LkX00002MkT20002MiT01@00MiT007NI00000gNI00@007MiMgT0009gN@05001cNG=iLgT00002LgT0
1@00LgUcNG=i00000W=I00@007=ILeT0009cF@800005LeT007=ILeT00002KeT01P00KeU_F@00KeT0
009_F@06001_>Fli001_>@000Vli00@006liKcT0009_>@04001_>@00KcT20002JcT00`00JcT00002
JcT00`00JcT00002JcT00`00JcU[>@030002JcT01@00JcT006/I00000V/I00H006/IJaT006/I0002
JaT00`00JaU[6@020002JaT01`00JaU[6@00JaT006/I00800007JaT006/IJaT006/I00000V/I00D0
06/I001W6@00009W6@03001W6@00009W6@80009Vn@07001VnFKi001Vn@00I_T00`000VKi00L006Ki
001Vn@00H_T00002H_T3000016;i001Rf@000V;I00T006;I001NfP00G]X005kJ00000UkJ00<005kJ
0000100001UJ^P00F[X005Zj001J^P00E[X005Jj001F^P00EYX005JJ001BVP00DYX005:J001BVP02
00003djJ001>VP00CYX004jK001>V`00CW/004ik001>N`0500000dYk001:N`0200003DYk001:N`00
BW/004Yk001:N`00BW/004Yk00800009BY/004ZK001:V`00BY/004ZK00L00005BY/004ZK001>V`02
0000>DjK001>V`00CY/004jK001>V`00C[/004jk001>^`00C[/004jk001>^`00C[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`03
000085:k001B^`00D[/005:k001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00
D]/005;K000LOol00`00Oomoo`19Ool000Eoo`8000Aoo`8001Yoo`@000Aoo`8001Ioo`03001oogoo
065oo`08001Bf`00D]/005;K001Bf`800004D]/005;K0002D]/03000D]/005;K001Bf`00D]/005;K
001Bf`80000CD]/005;L001Bg000D]`005:l001B_000D[`005:l001B_000D[`00P00015B_000D[`0
04jl001>_000C[`004jl001>_000C[`004jl0080000:C[`00000BY`004ZL001:W000BY`500001D9l
0012O000@W`00`0000<jG00000000`0001I5eP00COH0058F001B5P00DQH005Hf001F=P00ESH005Hf
001F=P00ESH0009F=P07001J=P00FSH005YF00000UYF0`0000ANE@00HWD0009VU@03001b/g:c009b
/`03001k4W/B009k4P04001k4W/B0002Na<01@00Oc=o<glc00000Wlb00<007/c000017lc00<007/d
Nc@00W/d00@007]ENeD0009k=@04001kEG]E0002NcD00`00NcH00002McH00`00McH00004McH01@00
McMg=gLg00000gLg00D007<gLcMc=`00009c=`05001c>7<hLcP00003LcP01000LcQc>0000flh00@0
06lhKcP0009_>005001_>6lhKcP00002KcP01000KaQ_60000VlI00@006lIKaT0009_6@04001[6F/I
0002JaT01`00JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT01000JaU[6@000V/I00D006/I
JaT006/I0080009[6@07001[6F/I001[6@00JaT00P000V/I00@006/IJaT0009[6@80009[6@04001[
6F/I0002JaT01000JaU[6@000V/I00<006/I00000V/H00H006/IJaT006[i0002J_P01P00J_QZn000
J_T0009Zn@06001VnFKi001Vn@000VKi00<006Ki00000VKi0P000VKI00@006;I001Rf@80000;H]T0
06;IH]T006;I001Nf@00G]T00002G[T200004EZi001J^P00F[X005Jj001FVP00EYX005:J001BVP00
DYX00P0000M>NP00BWX004Yj001:FP0200001DIK0012F`00@U/00P0000<n>`00?S/00`0000@j6`00
000f6`800006=Q/00000<Q/0038K0P0000Lb6`000000038K000b6`020000138K0000038K0P0000L^
6`00000002hK000^6`03000012hK000002hL0`0000<Yn`009O/0100000<Qf`007M/0100000<EV`00
0000200000<0M@0000000`0000<1nP0000002@0000=C_`00Fkh00`000V?N00<006OM00000P000VoL
00<007?K00000Vnk00@007>j0000009c^P03001g^@00009cV@04001gVGNI0003MiT01000MiT00000
0WMi00D007Mi001cN@00009cN@05001cN@00LgT00002LgT01000LeT000000W=I00@007=ILeT0009c
F@05001cFG=I001_F@020002KeT00`00KeU_F@030002KcT00`00KcU_>@030002KcT01@00KcU_>@00
KcT00P000V/i00<006/i00000V/i0`000V/i00<006/i00000V/i00<006/i00000V/i00D006/iJcT0
06/I00<0009[6@07001[6F/I001[6@00JaT00P0000Q[6@00JaU[6@00JaT006/I0P0000Y[6@00JaU[
6@00JaT006/I001[6@80000:JaT006LIIaT006LI001W6@00IaT2000016LI001Vn@000VKi00D006Ki
001Vn@00009Vn@07001Vn@00I_T006Ki00000V;i0`0000ARn@00H_T0009Rf@09001Rf@00H]T005kJ
001NfP00009NfPD0000WG]X005Zj001J^P00F[X005Zj001J^P00E[X005Jj001F^P00EYX005JJ001B
VP00DYX005:J001BVP00DYX004jJ001>VP00CYX004jK00800009CW/004ik001>N`00BW/004Yk00L0
000@BW/00000BW/004Yk001:N`00BW/004Yk001:N`00BY/200002dZK001:V`00BY/004ZK001:V`00
BY/02@0000E>V`00CY/004jK0080000aCY/004jk001>^`00C[/004jk001>^`00C[/004jk001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/00`0001IB^`00D[/005:k001B^`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0009Bf`09001B
f`00D]/005;K001Bf`0001]oo`03001oogoo04Uoo`001Goo20006goo200067oo00<007ooOol0HGoo
00P005;K001Bf`00D]/005;K0P0002MBf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001B
f`00D]/005;L001Bg000D]`005:l001B_000D[`005:l001B_000D[`00P0000UB_000D[`004jl001>
_000C[`00P0000E>_000C[`004jl00800009C[`004Zl001:W000BY`004ZL00800003AY`004JL00D0
0003@W`003il00H0000C>ID00000COH0058F001B5P00DQH005Hf001F=P00ESH005Hf00000UHf00`0
05Hf001F=P00FSH005Xf001JEP00FUH200001UYF001NE@00HWD0009VU@03001b/g:c009b/`8000=k
4P04001k4W/BNa820004Oc<00`00Oc9o<P020005Oc<20003Nc@01`00NeEkEG]E001k=@0000=kE@03
001k=@00009k=P03001g=P00009g=P05001g=WLfMcH00004McL01@00McL007<g00000W<g00D007<g
001c=`0000=c>005001c>000LcP00002LcP01000KcQ_>0000Vlh00H006lhKcQ_>000KcP20003KcP0
1000KaP006lI0P000VlI00D006lIKaT006/I0080009[6@04001[6F/I0002JaT01000JaU[6@000V/I
00@006/I001[6@80009[6@04001[6F/I0003JaT00`00JaT00002JaT01000JaU[6@000V/I00@006/I
JaT0009[6@04001[6@00JaT2000026/I001[6F/I001[6@00JaT20002JaT01`00JaU[6@00JaT006/H
0080009[6@07001ZnF[i001Zn000J_P00P000V[i00<006[i00000VKi00@006Ki001Vn@80009Vn@07
001Vn@00I_T006KI00000V;I00<006;I00000V;I00L006;I001Rf@00G]T00002G]T02000G[T00000
F[T005Zj0002F[X>00002Tij000004Yj001:FP00AUX004IK0P0000E2F`00@S/003hk00800005?S/0
0000000f6`02000013HK000003HK0P0000<b6`00<Q/00P0000Lb6`000000038K000b6`020000138K
0000038K0`0000@^6`00000^6`<00003;Q/002hL00H000039O/0000000@000047M/000006K/50000
0`UJ0000000200000`3h0000000400000`2d0000000200001akN000_7`00>el004NO00D0009K_P03
001SgP000080009Wg@03001_g000008000=_^`03001c^P0000=c^P09001cVG>ILiT007NI001cV@00
00=gV@04001cNG=i0002MgT01@00LgUcNG=i00000W=i00D007=iLgUcN@00009cN@04001cFG=I0002
LeT30003LeT01000LeUcF@000VmI00<006mI00000VmI00H006liKcT006li0002KcT01000KcU_>@00
0Vli00H006liKcT006/i0002JcT00`00JcU[>@030002JcT00`00JcT00002JcT30002JcT02000JcU[
>@00JcT006/I0002JaT01`00JaU[6@00JaT006/I00800004JaT006/I0002JaT01P00JaU[6@00JaT0
009[6@06001[6@00JaT006/I0P0000Y[6@00JaU[6@00IaT006LI001W6@800004IaT006LI0002I_T0
1000I_T006Ki0`000VKi00<006Ki00000VKi00<006Ki00000P0000ARn@00H_T0009Rn@07001Rf@00
H]T006;I00000UkJ00<005kJ00000P0000QNfP00G]X005kJ001J^P000UZj00P005Zj000005Zj001F
^P000UJj01d005Jj000005JJ001BVP00DYX005:J001BVP00DYX004jJ001>VP00CYX004jK001>V`00
CW/004ik00800009BW/004Yk001:N`00BW/004Yk00D00003BW/004Yk0080000=BW/004Yk001:N`00
BY/004ZK001:V`00BY/00P0000e:V`00BY/004ZK001>V`00CY/004jK001>V`0900002djK001>^`00
C[/004jk001>^`00C[/00P0002I>^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`000U:k01@005:k001B^`00D[/005;K001B
f`00D]/005;K001Bf`00D]/005;K2`0077oo00<007ooOol0B7oo0007Ool4000OOol5000JOol00`00
Oomoo`1POol07000D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00
D]/005;K0P0000IBf`00D]`005;L0002D]`01000D[`005:l0P0000mB_000D[`005:l001B_000D[`0
05:l001>_000C[`00P0000M>_000C[`004jl001>_00200000djl001:_00200001dZL001:W000BY`0
04JL00<00003@W`0049l00800003?W`003iL00800005<C@003VE0015eP020000258F001B5P00DQH0
05Hf0002ESH03P00ESH005Hf001F=P00ESH005Hf001J=P00FSH4000025Xf001JEP00GUD0069e0002
IYD01`00L[=b/g:c001o4@0000=k4P04001k4W/BNa820004Oc<01@00Oc9o<Wlb000017lc00@007mD
Oe@0009k=003001kEG]E009kE@03001kEG]E00=kE@07001k=W/fNcH007Lf00000WLf00H007LfMcH0
07Lg0004McL01000LcMc=`000g<g00D007<gLcMc=`0000=c>004001c>7<h0002LcP01@00KcP006lh
00000Vlh00<006lhKcP00P000Vlh00@006lhKcP0009_6004001_6FlI0002KaT01000KaU_6@000V/I
00L006/IJaT006/I001[6@020002JaT01000JaU[6@000V/I00@006/IJaT0009[6@05001[6F/I001[
6@020002JaT01`00JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT01P00JaU[6@00JaT0009[
6@03001[6@00009[6@07001[6F/I001[6@00JaT00P000V/I00H006/IJaT006[i0002J_P01P00J_UZ
n@00J_T0009Zn@04001Vn@00I_T20002I_T02P00I_T006Ki001Vn@00I]T006;I0P000V;I00D006;I
001Rf@00009Rf@08001Nf@00G]T005ji001N^@L0000;E[X005JJ001FVP00DYX005:J001BVP070000
1dYJ0016FP00AU/0049K00800003@S/003hk00800003?S/0000000<00004=Q/00000=Q/200001SHK
0000038K000b6`<00006<Q/00000<Q/0038K0`0000Lb6`00000002hK000^6`0600001BhL000^7000
:Q`0100000<Un`009O/0100000DMf`00000001FK00/0000307D0000000@000030O/0000000H00006
Bil005>oDkl005^n0`000V>m00@006OM000000=__004001_^`000002LkX01@00LkX007>j00000g>I
00H007>ILiUcV@00MiT20002LgT01000MgT000000g=i00@007=i000000=cN@04001cN@000002LeT0
1000LeUcF@000W=I00D007=ILeT007=I0080009_F@03001_FFmI00<0009_>@03001_>Fli00<0009_
>@05001_>Fli001_>@020002JcT00`00JcT00002JcT00`00JcT00002JcT00`00JcT00002JcT01P00
JcU[>@00JcT0009[>@03001[>F/i0080009[6@04001[6F/I0002JaT00`00JaT00002JaT01P00JaT0
06/I001[6@800007JaT006/IJaT006/I00000V/I00<006/I00000V/I00H006/I001W6@00IaT20000
2FLI001W6FLI001W6@00I_T00002I_T01`00I_T006Ki001Vn@00009Vn@07001Vn@00I_T006;i0000
0V;i00T006;i001Rn@00H]T006;I00000V;I1@0000INfP00G]X005kJ0002G]X04000F[X005Zj001J
^P00F[X005Zj001F^P00E[X005Jj0P0001eFVP00DYX005:J001BVP00DYX005:J001>VP00CYX004jJ
001>V`00CY/004ik001>N`00CW/004Yk00800009BW/004Yk001:N`00BW/004Yk00L0000DBW/00000
BW/004ZK001:V`00BY/004ZK001:V`00BY/004ZK001:V`80000=CY/004jK001>V`00CY/004jK001>
V`00CY/03`0002=>^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k01T0000:D]/005;K001Bf`00D]/005;K000LOol00`00Oomoo`18
Ool004Uoo`03001oogoo065oo`08001Bf`00D]/005;K001Bf`800004D]/005;K0002D]/01P00D]/0
05;K001Bf`80000AD]/005;K001Bf`00D]/005;L001Bg000D]`005:l001B_00200004E:l001B_000
D[`005:l001B_000D[`004jl001>_000C[`00P0000U>_000C[`004jl001>_000C[`00P0000E:W000
BY`004ZL00800003AY`004JL00800004@W`00000@W`500006c4d00000000AMH004gf001B5P00DQH0
058F001F=P00ESH005Hf001F=P00ESH005Hf001F=P0500002eXf001J=UXf001JEP00GUD0069e0000
0VJE00L007:cL[=b/`00Oa400002Na800`00Na9k4P03Na800`00Oc=o<`02Oc<01@00Oc9o<Wlb0000
17lc00@007mDOeAoE08000EkE@03001kEG]E00=kE@03001k=W/f009k=P03001g=WLf009g=P05001g
=P00McL00004McL01@00LcMc=g<g00000W<g00D007<gLcMc=`0000=c>005001c>7<hLcP00002LcP0
1000KcQ_>0000Vlh00D006lh001_>000009_>005001_>6lh001_60020002KaT01@00KaU_6@00KaT0
0P000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01000JaT006/I0P000V/I00D006/IJaU[6@00
009[6@06001[6F/I001[6@000V/I00@006/I0000009[6@07001[6F/I001[6@00JaT00P000V/I00<0
06/I00000V/I00<006/I00000V/I00@006/IJaT0009[6@03001[6@00009[6@07001[6F/I001Zn@00
J_P00P000V[i00H006[iJ_T006[i0002I_T00`00I_T00002I_T00`00I_UVn@0200000fKi001Vf@02
0002H]T01@00H]T006;I00000V;I00P006;I001Nf@00G]T005ji0`0000IJ^P00F[X005Zj0002E[X0
2000EYX005JJ001BVP00DYX300001Dij001>NP00BWX0100000M6F`00@U/0049K0012>`0200001Chk
00000000>S/00P0000<f6`00=Q/00P0000@f6`00000f6`800003<Q/0038K00<00006<Q/00000<Q/0
038K0`0000Lb6`00000002hK000^6`0600001BhL00000000:Q`01P0000<Qn`0000000P0000<I^`00
00000`0000<=NP000000400000TRgP00<al003mO001;W`00Dkl00`000Unn00@006>m0000009W_@05
001__6nlKk`00002Kk/01000LkX000000g>j00@007>I000000AcV@04001cVG>I0002LgT01000LgUc
N@000g=i00@007=iLgT000=cN@07001cNG=i001cF@00LeT00P000g=I00@007=ILeT0009_F@03001_
F@00009_F@04001_FFmI0002KcT00`00KcT00002KcT01000KcU_>@000Vli00<006li00000V/i00<0
06/iJcT00`000V/i00<006/i00000V/i0`000V/i00L006/iJcT006/i001[>@02000026/I001[6F/I
001[6@00JaT200001f/I001[6F/I001[6@00009[6@03001[6@00009[6@03001[6@00009[6@<00007
JaT006/IJaT006/I00000VLI00D006LI001W6@00009W6@06001W6@00I_T006Ki0P0000AVn@00I_T0
009Vn@07001Vn@00I_T006Ki00000V;i00T006;i001Rn@00H_T006;I00000V;I0`0000INfP00G]X0
05kJ0002G]X09000G]X005kJ001J^P00F[X005Zj001J^P00F[X005Jj001F^P00E[X005JJ001FVP00
DYX005:J001BVP00DYX005:J001>VP80000CCYX004jK001>V`00CW/004ik001>N`00BW/004Yk001:
N`00BW/00P0000U:N`00BW/004Yk001:N`00BW/01@0000=:N`00BY/00P0001=:V`00BY/004ZK001:
V`00BY/004ZK001>V`00CY/004jK001>V`0200004djK001>V`00CY/004jk001>^`00C[/004jk001>
^`00C[/004jk02L0000PD[/005:k001B^`00D[/005;K001Bf`00D]/005;K001Bf`00D]/005;K001B
f`00D]/005;K001Bf`00D]/001aoo`03001oogoo04Qoo`00BWoo00<007ooOol0HGoo01D005;K0000
05;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/00P0000=Bf`00D]/09`0000]>_000C[`0
04jl001:_000BY`004ZL00800003BY`004JL00<00003@W`0049l00800003?W`003il00<0000CAKD0
0000001=mP00DQH0058F001B5P00ESH005Hf001F=P00ESH01`0000IF=P00ESH005Xf0002FSH01@00
FUH005iE00000V9e00<006JE00000g:c00<007lA00000W/B00<007/BNa800g/B00D007lcOc=o<`00
00Ao<P8000=o<`03001oE7mD009oE003001kEG]E009kE@03001kE@0000=kE@03001kEP0000=k=P03
001g=WLf00=g=P05001g=gLgMcL00002McL00`00McL00002LcL01@00LcL007<g00000g<g00D007<h
001c>000009c>004001c>0000003KcP01000KcQ_>0000flh00@006lhKcP0009_>004001_>Fli0002
KaT01000KaU_6@000VlI00L006/IJaT006/I001[6@020003JaT01P00JaU[6@00JaT0009[6@04001[
6F/I0002JaT01000JaT000000V/I00@006/IJaT0009[6@03001[6@00009[6@04001[6F/I0002JaT0
1000JaU[6@000V/I00@006/I001[6@800008JaT006/IJaT006/I001[6@80009[6@07001[6F/I001[
6@00J_T00P000V[i00<006[i00000V[i00@006[i001Vn@80009Vn@03001Vn@00009Vn@03001Vn@00
00800007H]T006;IH]T006;I00000V;I00P006;I001Rf@00G]T005kI0P0000=N^@0000000UZj0100
05Zj001J^P00E[X005JJ001FVP00DYX005:J001BVP800003CWX004ij00800003BWX004IJ00@00005
@U/0048k000n>`0200001Chk00000000>S/00P0000<f6`00=Q/00P0000@f6`00000f6`800004<Q/0
0000<Q/20000138K0000038K0P0000<b6`000000100000D^6`00000002hL00D00004:Q`00000:O/3
000012Gk0000027K0P0000@I^`00000E^``0000309D00000008000030EP0000000/0009GW`04001O
_P000002Hkd01@00IkeW_@00Kk`00P000fnk00@007>kLk/000=c^P04001cVW>J0003LiT01@00LiUc
V@00LgT00P000g=i00@007=i000000=cN@04001cN@000002LgT01000LeUcF@000W=I00D007=ILeT0
07=I0080009_F@03001_FFmI00<000=_F@05001_>@00KcT00002KcT01@00KcU_>@00KcT00P000Vli
00<006/i00000V/i00H006/iJcT006/i0002JcT30002JcT01`00JcU[>@00JcT006/i00800004JaT0
06/I0002JaT01P00JaU[6@00JaT0009[6@06001[6@00JaT006/I0P000V/I00<006/I00000V/I0`00
00M[6@00JaU[6@00JaT00002JaT300002VLI001W6FLI001W6@00IaT006Ki0P0000aVn@00I_UVn@00
I_T006Ki001Vn@00I_T200002V;i001Rn@00H_T006;i001Rn@000V;I0`0000INfP00G]X005kJ0002
G]X05000G]X005kJ001NfP00F[X005Zj001J^P00F[X005Zj001F^P00E[XE00001DjJ001>V`00CY/0
0P0000m>N`00CW/004Yk001:N`00BW/004Yk001:N`00BW/00P0000U:N`00BW/004Yk001:N`00BY/0
1`0000=:V`00BY/00P0001M:V`00BY/004ZK001>V`00CY/004jK001>V`00CY/004jK001>V`00CY/0
04jk0080000nC[/004jk001>^`00C[/004jk001>^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05;K001Bf`00D]/0009Bf`0A001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0000KOol00`00
Oomoo`18Ool004Yoo`03001oogoo065oo`07001Bf`00001Bf`00D]/04`0000mBg000D]`005;L001B
g000D]`005:l001B_000D[`00P00015B_000D[`005:l001B_000D[`005:l001>_000C[`004jl0080
0003C[`004jl00X00008BY`00000BY`004JL0016W0800006@W`00000@W`003il100000=5]@00COH0
0`0000MB5P00DQH0058F001F=P07000035Hf001F=P00ESH005Hf001F=P00FSH0009J=P05001JEP00
GUD00002HWD00`00IYD00003L[<01P00Oa5o4@00Na8000Ek4P80009o<`05001o<WlbOc800002Oe<0
1000Oc=o<`0017mD0P000g]E00H007]ENeD007]E0003NeH01@00NcH007MF000017Lf00L007LgMcMg
=`00McL00002McL01@00LcMc=g<g00000g<g00D007<gLcMc=`00009c>005001c>7<hLcP00002KcP0
1000KcQ_>0000Vlh00D006lhKcQ_>000009_>004001_>0000002KcT01@00KaU_6@00KaT00P000VlI
00@006/IJaT0009[6@04001[6F/I0002JaT01P00JaU[6@00JaT000=[6@04001[6F/I0002JaT01000
JaU[6@000V/I00@006/I001[6@80009[6@07001[6F/I001[6@00JaT00P000V/I00@006/IJaT0009[
6@05001[6@00JaT00002JaT01000JaU[6@000V/I00<006/I00000V/I00H006/IJaT006[i0002J_T0
1`00J_UZn@00J_T006[i0080009Vn@03001Vn@00009Vn@07001Vn@00I_T006Ki00000V;I00<006;I
00000V;I00D006;I001Rf@00009Rf@<0000GG]T005ji001N^@00F[X005Zj001J^P00E[X005JJ001F
VP00DYX005:J001BVP0200001dij001>NP00BWX004Yj00800003AU/004IK00800003@S/003hk0080
0004?S/00000>S/200001SXk000003HK000f6`800004=Q/00000=Q/20000138K0000038K0P0000Tb
6`000000038K000b6`00<Q/0100000D^7000000002hL00D00003:Q`0000000@000038O/0000000<0
00056K/00000000=VP0@0000107K000001JN0P0000Pg?`00@em3G`00Bil005NO0P000Unn00D006>m
Hkd006Nm0080009[_004001_^`000003Lk/01000LkX000000g>J00D007>I001cVP00009cV@04001c
NG=i0003LgT01000LgUcN@000g=i00L007=iLgT007=i001cF@020003LeT01000LeUcF@000VmI00<0
06mI00000VmI00@006mIKeT0009_F@06001_>@00001_>@000Vli00@006liKcT0009_>@03001_>@00
009[>@<0009[>@08001[>F/i001[>@00JcT0009[>@04001[>F/i0002JcT00`00JcT00002JaT01P00
JaT006/I001[6@80009[6@03001[6@00009[6@<00007JaT006/IJaT006/I00000V/I00<006/I0000
0V/I00<006/I00000V/I0`0000MW6@00IaUW6@00IaT00002IaT3000036Ki001VnFKi001Vn@00I_T0
06Ki001Vn@800006I_T006;i001Rn@000V;i0P000V;i0`0000ARfP00G]X0009NfP0;001NfP00G]X0
05kJ001NfP00G]X00002F[X01000F[X005Zj1`0000=F^P00E[X00P0000mFVP00DYX005:J001BVP00
DYX005:J001BVP00CYX02@0000=>N`00CW/00P0000m:N`00BW/004Yk001:N`00BW/004Yk001:N`00
BW/00P0000U:N`00BY/004ZK001:V`00BY/01`0000E:V`00BY/004ZK0080000oCY/004jK001>V`00
CY/004jK001>V`00CY/004jk001>^`00C[/004jk001>^`00C[/004jk001>^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k00<0000P
D[/005:k001B^`00D[/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00
D]/001aoo`03001oogoo04Moo`00Bgoo00<007ooOol0HGoo1P0000mBf`00D]/005;K001Bf`00D]/0
05;K001Bf`00D]/00P00019Bf`00D]aBg000D]`005;L001Bg000D]`005:l001B_000D[`200004E:l
001B_000D[`005:l001B_000D[`004jl001>_000C[`00P0000a>_000001>_000C[`004Zl001:W000
BY`500001dJL0016W000AY`0049l00800004@W`00000?W`200001DFe001=mP00DQH02@00019F=P00
ESH005Hf001F=P00ESH005Hf001F=P00ESH005Xf0002FSH00`00FUH00002GUD01@00HWD006JE0000
0g:c00H007lAOa4007/B0004Na800`00Oc800002Oc<01@00Oc9o<Wlb00000gmC0P0017mD00@007]D
Ne@0009kE@06001kEG]E001kE@000g]F00<007/f00000WMF00H007LfMcH007MF0003McL00`00McMg
=`02McL01000LcMc=`000g<g00D007<gLcMc=`0000=c>004001c>7<h0002KcP02000KcQ_>000KcP0
06lh0003KcP01000KcQ_>0000Vlh00@006liKcT0009_6@04001_6FlI0002KaT01000JaT006/I0P00
0f/I00D006/IJaT006/I00800005JaT006/IJaT00002JaT01000JaT000000V/I00@006/IJaT0009[
6@06001[6F/I001[6@000V/I00@006/IJaT0009[6@07001[6F/I001[6@00JaT00P000V/I00H006/I
001[6@00JaT20002JaT01`00JaU[6@00JaT006/I0080009Zn@06001ZnF[i001Zn@000V[i00<006Ki
00000VKi00H006KiI_T006Ki0002I_T20002I_T00`00H]T00002H]T01P00H]T006;I001Rf@@00004
G]T005kI0002G[T200001UZj001J^P00F[X0009F^P08001FVP00EYX005:J001BVP<0000;CWX004ij
001:NP00BWX004IJ0016F`0200000d9K0000000300001Shk000003Xk000j>`800006>S/00000=Q/0
03HK0P0000@f6`00000f6`800007<Q/00000000b6`00<Q/00`0000Db6`000000038L00D00004;Q`0
0000;Q`2000012XL000002Wk0`0000@Un`00000Qf`D000035K/0000000@000040CT000000?P30000
0`2e0000000400000`hm0000000200000cLo0013G`0500001UNO001O_Unn001S_@800003Ikd006^l
009[_004001_^fnk0003Lk/01000LiYcVP000g>J00L007>JLiYcVP00LiT00003LgT01000LgT00000
0g=i00@007=iLgT0009cN@04001cNG=i0002LeT01@00LeUcF@00LeT00P000VmI00<006mIKeT00`00
0fmI00P006mIKeT006li001_>@000Vli00@006li0000009_>@03001_>@00009[>@04001[>F/i0002
JcT01@00JcT006/i00000V/i00L006/iJcT006/i001[>@020002JcT01P00JaT006/I001[6@800007
JaT006/IJaT006/I00000V/I00<006/I00000V/I00<006/I00000V/I0`0000M[6@00JaU[6@00JaT0
0002JaT00`00IaT00002IaT01@00IaT006LI00000VLI00D006Ki001Vn@00009Vn@06001Vn@00I_T0
06Ki0P0000IVn@00I_T006;i0002H_T01000H_T006;i0`00015RfP00H]YRfP00G]X005kJ001NfP00
G]X005kJ001NfP00009NfPL0000CF[X005Zj001F^P00E[X005Jj001F^P00EYX005:J001BVP00DYX0
0P0000eBVP00DYX004jJ001>V`00CY/004jK001>V`0700000dYk001:N`0200003DYk001:N`00BW/0
04Yk001:N`00BW/004Yk0080000;BY/004ZK001:V`00BY/004ZK001:V`0900001DjK001>V`00CY/0
0P0003M>V`00CY/004jK001>^`00C[/004jk001>^`00C[/004jk001>^`00C[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`030000
85:k001B^`00D[/005:k001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0
05;K000LOol00`00Oomoo`17Ool004aoo`03001oogoo061oo`06001Bf`00001Bf`000U;K00h005;K
001Bf`00D]/005;K001Bf`00D]/005;K0P00015Bf`00D]`005;L001Bg000D]`005;L001B_000D[`0
05:l0080000AD[`005:l001B_000D[`005:l001B_000C[`004jl001>_00200002djl001>_000C[`0
04jl001:_000BY`00P0000A:W0000016W0H00003@W`0049l0080000R?W`000000015]@00COH0058F
001B5P00EQH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf0002FSH00`00FSH0
0002FUH01`00GUD0069e001VU@0000=b/`06001o4GlA001k4P0017/B00H007lbOc8007lc0003Oc80
0`00Oe=oD`02Oe<20003Oe@01000NeAkE7]D0P0017]E00<007]FNeH00g]F00<007MFMeH00WMF00D0
07Lf001gEP0000=g=`03001g=gLg009g=`05001c=`00LcL00003LcL01@00LcL007<h00000W<h00D0
07<h001c>000009_>004001_>6lh0002KcP01P00KcQ_>6lh001_>080009_>005001_>Fli001_6@02
0002KaT01@00KaU_6@00JaT00P000V/I00@006/IJaT000=[6@03001[6@00009[6@05001[6F/I001[
6@020002JaT01`00JaU[6@00JaT006/I0080009[6@07001[6F/I001[6@00JaT00P000V/I00@006/I
JaT0009[6@08001[6F/I001[6@00JaT0009[6@06001[6F/I001[6@000V/I00@006/IJaT0009Zn@03
001Zn@00009Zn@04001Zn@00J_T20002I_T00`00I_T00002I_T01000I_T006Ki0P0000IVn@00I_T0
06;I0002H]T01000H]T006;I0P0000ARf@00G]T0009Nf@04001Nf@00G[T20002F[X03P00F[X005Zj
001F^P00EYX005JJ001BVP00DYX200001Dij001>NP00CWX00P0000M:NP00AUX004IK0016F`020000
0d9K0012F`0300001SXk000003Xk000j>`800006=S/00000=Q/003HK0P0000Lf6`000000038K000b
6`0300000c8K000000040000138K0000038L0P0000@^7000000^70800004;Q`00000:Q`3000012Gk
0000027k0`0000@Mf`00000E^`8000034I/00000010000043Sd00000:_l4000024MO001?Odmo001G
W`00Gkh200002F>m001W_FNm001[_000Jk`00002Kk/01@00Lk/006nK00000W>J00D007>J001cVP00
00=cVP03001cNP0000=cN@04001cNG=i0002LgT02000LgT007=i001cN@00LgT20003LeT01000LeUc
F@000VmI00<006mI00000VmI00@006mIKeT0009_F@04001_F@000002KcT00`00KcT00002KcT01P00
KcU_>@00KcT0009_>@<0009[>@04001[>F/i0002JcT01@00JcT006/i00000V/i00H006/iJcT006/i
0002JcT00`00JaT00002JaT00`00JaT00002JaT00`00JaT00002JaT30002JaT00`00JaT00002JaT3
00001f/I001[6F/I001[6@00009[6@<00007IaT006LIIaT006LI00000VLI0`0000MVn@00I_UVn@00
I_T00002I_T3000016Ki001Vn@000VKi00/006;i001Rn@00H_T006;i001Rn@00009RfP0;001RfP00
G]X005kJ001NfP00G]X00002G]X00`00G]X00002000035Zj001J^P00F[X005Zj001J^P00E[X0009F
^P0A001F^P00001FVP00DYX005:J001BVP00DYX005:J001BVP0200003DjK001>V`00CY/004jK001>
V`00CY/004ik00L00003BW/004Yk0080000=BW/004Yk001:N`00BW/004ZK001:V`00BY/00P0000e:
V`00BY/004ZK001:V`00BY/004jK001>V`0900001djK001>V`00CY/004jk0080000]C[/004jk001>
^`00C[/004jk001>^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k00<0000>D[/005:k001B^`00D[/005;K001Bf`00D]/0009Bf`0A
001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0000KOol00`00Oomoo`17Ool004aoo`03001o
ogoo065oo`0Y001Bf`00001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0
05;L001Bg000D]`005;L001Bg000D[`005:l001B_00200004E:l001B_000D[`005:l001B_000D[`0
04jl001>_000C[`00P0000=>_000C[`00P0000U>_000B[`004ZL001:W000BY`00`0000E6W000AY`0
04JL00@00005@W`00000000a=002000064gf001B5P00DQH005HF001F=P00ESH005Hf001F=P00ESH0
05Hf001F=P00ESH0009F=P05001F=P00FSH00002FSH02@00FUH005iE001RM@00IYD00002L[<01000
Oa5o4GlA0P001G/B00<007lbOc800P0017lb00<007mCOe<00WmC00<007mC00000WmD00<007]DNe@0
0W]D00<007]ENeD00W]E00<007]FNeH00g]F00<007MFMeH00gMF00T007MFMeIgEP00McL007Lg0000
17Lg00@007<gLcL000Ac=`04001c>7<h0003LcP01000LcQc>0000Vlh00@006lh000000=_>005001_
>6lhKcP00002KcP01000KcQ_>0000Vli00@006lIKaT0009_6@06001_6FlI001[6@000f/I00D006/I
JaT006/I0080009[6@03001[6@0000=[6@03001[6@00009[6@04001[6F/I0002JaT01000JaU[6@00
0V/I00@006/I001[6@80009[6@07001[6F/I001[6@00JaT00P000V/I00<006/IJaT00P0000=[6@00
00000V/I00L006/IJaT006/I001[6@020002J_T01`00J_UZn@00J_T006[i0080009Vn@03001Vn@00
009Vn@04001Vn@00I_T200001VKi001Vn@00I_T0009Rf@03001Rf@00009Rf@03001Rf@00009Rf@0J
001Nf@00G]T005kI001N^@00G[T005Zj001J^P00F[X005Jj001FVP00EYX005:J001BVP800009CWX0
04ij001>NP00BWX004Yj00800005AU/004IK0012F`0200000d9K0000000300001SXk000003Xk000j
>`800006=S/00000=Q/003HK0P0000Df6`000000038K00800005<Q/00000000b6`050000138L0000
038L0P0000@^7000000^70800004;Q`00000:O/3000012Gk0000027K1P0000<E^`0000000`0000@5
NP000001>@<000030?L0000000P00008:_l003/o>cl004MO001?O`@00006Gih006>mHkd006Nm0P00
0f^l00@006nk000000=_V`04001cVP000003LiX01000LiX000000W=j00@007=i000000=cN@04001c
NG=i0002LgT01000LgUcN@000W=I00D007=ILeT007=I0080009_F@03001_FFmI00<000=_F@04001_
FFmI0002KeT01P00KcT006li001_>@80009_>@03001_>Fli00<0009[>@07001[>F/i001[>@00JcT0
0P0000Q[>@00JcU[>@00JcT006/i0P000V/i00<006/i00000V/I0`000V/I00<006/I00000V/I0`00
00M[6@00JaU[6@00JaT00002JaT00`00JaT00002JaT00`00JaT00002JaT300001fLI001W6FLI001W
6@00009W6@<00009IaT006KiI_T006Ki001Vn@00009Vn@05001Vn@00I_T00002I_T02000I_T006;i
001Rn@00H_T30002H_T02@00H]X006;J001NfP00G]X00002G]X00`00G]X00004000025[J001J^P00
F[X005Zj0002F[X02000F[X005Jj001F^P00E[X200005EJJ001BVP00DYX005:J001BVP00DYX005:J
001>VP00CY/004jK001>V`0200002djK001>V`00CW/004ik001:N`00BW/01`0000=:N`00BW/00P00
00e:N`00BY/004ZK001:V`00BY/004ZK001:V`0200003dZK001:V`00CY/004jK001>V`00CY/004jK
001>V`0;0000;Djk001>^`00C[/004jk001>^`00C[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0300003E:k001B^`00D[/005:k
001Bf`00D]/005;K01<001aoo`03001oogoo04Ioo`00CGoo00<007ooOol0H7oo01H005;K001Bf`00
D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`80000:D]/005;LD]`005;L001Bg000D]`2
00004E:l001B_000D[`005:l001B_000D[`005:l001B_000D[`00P0000U>_000C[`004jl001>_000
C[`00P0000M>_000C[`004Zl001:W002000024ZL000004JL0016W000AY`200000d9l0012O0040000
0c4d0015]@020000458F001B5P00EQH005Hf001F=P00ESH005Hf001F=P000UHf00/005Hf001F=P00
ESH005Hf001J=P00009J=P09001JEP00GUD0069e001VU@00009b/`03001o4GlA009o4@03001k4W/B
00=k4P04001o<WlbOc820003Oc800`00Oe=oD`02Oe<00`00Oe=oD`020005Ne@01`00NeEkEG]E001k
E@0000=kEP03001kEP0000AgEP07001gEWMFMeH007Lg00000WLg00D007LgMcMg=`0000=c=`03001c
=g<g008000=c>004001c>7<h0003LcP01000KcQ_>0000Vlh00D006lhKcQ_>000009_>004001_>6lh
0002KcP01000KcT000000VlI00D006lIKaT006lI0080009[6@04001[6F/I0003JaT01P00JaU[6@00
JaT0009[6@04001[6@000002JaT01`00JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT00`00
JaT00002JaT01000JaU[6@000V/I00@006/IJaT0009[6@05001[6@00JaT00002JaT01P00JaU[6@00
JaT0009[6@06001[6F/I001Zn@000V[i00H006[iJ_T006Ki0002I_T01P00I_UVn@00I_T0009Vn@03
001Vn@00009Vn@80009Vn@03001Rf@00009Rf@<0009Rf@0C001Rf@00G]T005kI001Nf@00G[T005ji
001J^P00F[X005Zj00000UJj00<005JJ0000200000]>NP00CWX004Yj001:NP00AUX004IK00800003
@U/0049K00<00006?S/00000>S/003Xk0P0000<j>`00=S/00P0000Hf>`00000f6`00=Q/300001c8K
00000000<Q/0038K00<00004<Q/00000<Q/20000138L0000038L0P0000@^7000000^70800005:Q`0
0000000Un`0200001BGk000000007M/01@0000@AV`000009NPT000030AP0004h00@000035Ud00000
00L00004Cgl005NO0002Gih01000Hkd000000VNm00D006^lJka[_000009_V`05001_VfnKKi/00002
Ki/01@00LiYcVW>J00000W>J00@007=jLgX0009cNP05001cNG=i001cN@020002LgT01000LgT00000
0g=I00@007=ILeT0009_F@03001_F@00009_F@04001_FFmI0002KeT01000KeT000000VmI00@006li
001_>@80009_>@03001_>@00009_>@03001[>@00009[>@05001[>F/i001[>@020002JcT01P00JcT0
06/i001[>@80009[>@03001[>@00009[>@<00007JaT006/IJaT006/I00000V/I00<006/I00000V/I
00<006/I00000V/I0`0000M[6@00JaU[6@00JaT00002JaT00`00IaT00002IaT01@00IaT006LI0000
0VLI00<006LI00000VLI00D006Ki001Vn@00009Vn@<0000<I_T006KiI_T006Ki001Vn@00H_T006;i
0P0000QRn@00H_T006;i001RfP000V;J0P000UkJ1@0000INfP00G]X005[J0002F[X06000F[X005Zj
001J^P00F[X005Jj001F^P00E[X005Jj001FVP00DYX005:J001BVP80000ADYX005:J001>VP00CY/0
04jK001>V`00CY/004jK001>V`0200002dik001:N`00BW/004Yk001:N`00BW/01`0001A:N`00001:
V`00BY/004ZK001:V`00BY/004ZK001:V`00BY/004jK0P00015>V`00CY/004jK001>V`00CY/004jK
001>V`00C[/004jk03l0000BD]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`0077oo00<0
07ooOol0AWoo001=Ool00`00Oomoo`1QOol01P00D]/00000D]/0009Bf`06001Bf`00D]/005;K0P00
015Bf`00D]/005;K001Bf`00D]/005;L001Bg000D]`005;L0080000AD[`005:l001B_000D[`005:l
001B_000D[`005:l001B_00200003djl001>_000C[`004jl001>_000C[`004jl001>_00200001DZL
001:W000BY`00P0000Q6W0000016W000AY`0049l0P0000Q2O000000a=000AKD004gf0P0000IB5P00
EQH005Hf0002ESH04`00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001J=P00009J=P09001J
EP00GUD0069e001VU@00009b/`03001o4GlA009o4@03001k4W/B00=k4P09001o<WlbOc8007la001o
<P0000AoD`03001oDgmC009oD`03001kE7]D009kE003001kE@00009kE@04001kEG]E0002NeH01000
NeIkEP000WMF00<007MF00000gMF00D007LgMcMg=`00009g=`03001g=`00009c=`03001c=`00009c
>008001c>7<h001c>000LcP0009c>004001_>6lh0003KcP02000KcQ_>000KcP006lh0002KcP01000
KcQ_>0000Vli00@006lIKaT0009_6@04001[6F/I0002JaT01@00JaU[6@00JaT00P000V/I00@006/I
JaT0009[6@06001[6F/I001[6@000V/I00@006/I0000009[6@07001[6F/I001[6@00JaT00P000V/I
00L006/IJaT006/I001[6@020002JaT02000JaU[6@00JaT006/I0002JaT01`00JaU[6@00JaT006/I
0080009[6@07001ZnF[i001Zn@00J_T00P000VKi00<006Ki00000VKi00@006Ki001Vn@80009Vn@0:
001Vn@00I_T006Ki001Rf@00H]T20002H]T01`00H]T006;I001Nf@00009Nf@800004G[T005ji0002
F[X900001EJJ001BVP00DYX02@0000U:NP00AUX004IK0016F`00@U/00P0000E2F`00000003hk0080
0003>S/003Xk00800003=S/003Hk00800006=S/00000=Q/003HK0`0000Db6`000000038K00800004
<Q/00000<Q/20000138L0000038L0P0000@^7000000^70800005;Q`00000000Yn`0200001BGk0000
00007M/00`0000@I^`00000AV`@000031GX0000000H000030AP0000000@000095Ud00000;_l003/o
0017G`00009?O`04001GW`00Gih20002Hid01@00IkeW_@00Jk`00P000fnK00@006nK000000=_V`04
001cVP000002LiX01000LgX000000g=j00@007=iLgT0009cN@04001cNG=i0002LgT01@00LeUcF@00
LeT00P000VmI00<006mIKeT00`000fmI00@006mIKeT0009_F@03001_F@00009_>@03001_>@00009_
>@03001_>Fli00<0009[>@04001[>F/i0002JcT00`00JcT00002JcT00`00JcT00002JcT00`00JcX0
0002JcT00`00JcT00002JcT00`00JaT00002JaT00`00JaT00002JaT30002JaT00`00JaT00002JaT3
00001f/I001[6F/I001[6@00009[6@<00007IaT006LIIaT006LI00000VLI0`0000MW6@00IaUW6@00
I_T00002I_T300002FKi001VnFKi001Vn@00I_T00002I_T3000026;i001Rn@00H_T006;i0002H]X0
1000H]X005kJ0`0000QNfP00G]X005kJ001NfP000U[J01X005Zj001J^P00F[X005Zj001J^P00E[X0
05Jj001F^P00E[X005JJ001BVP00DYX005:J0P0001MBVP00DYX004jJ001>V`00CY/004jK001>V`00
CY/004jK001>N`00CW/004Yk0080000;BW/004Yk001:N`00BW/004ZK001:V`0500000dZK001:V`02
00005DZK001:V`00BY/004ZK001:V`00CY/004jK001>V`00CY/004jK001>V`020000=DjK001>V`00
C[/004jk001>^`00C[/004jk001>^`00C[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00`0001QB^`00D[/005:k001B^`00
D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K0002D]/01`00D]/005;K001Bf`0001]oo`03001o
ogoo04Ioo`00CWoo00<007ooOol0H7oo00h005;K001Bf`00D]/005;K001Bf`00D]/005;K0P0000=B
f`000000<@0000Y>_000001:W000BY`004ZL001:W0800003AY`004JL0080000X@W`0049l0012O000
<C@004Fe001=mP00DQH0058F001F5P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00
ESH005Xf0002FSH02@00FUH005iE001RM@00IYD00002L[<00`00Oa5o4@02Oa400`00Na9k4P02Na80
0`00Oc9o<P02Oc800`00Oc5o<@020004Oe<00`00Oe=oD`02Oe<00`00NeAkE002Ne@01P00NeEkE@00
NeD000=kE@03001kEP0000=kEP03001gEP00009gEP04001gEWMF0004McL01@00McL007Lg00000g<g
00D007<hLcQc>00000=c>004001c>7<h0002LcP01@00KcP006lh00000Vlh00D006lhKcQ_>000009_
>005001_>6lh001_>0020002KcT01@00KaU_6@00KaT00P000V/I00@006/IJaT000=[6@04001[6F/I
0002JaT01000JaT006/I0P000V/I00@006/IJaT0009[6@03001[6@00009[6@04001[6F/I0002JaT0
1P00JaU[6@00JaT0009[6@04001[6@000002JaT01`00JaU[6@00JaT006/I00800008JaT006/IJaT0
06/I001[6@80009[6@06001[6F/I001Zn@000V[i00H006[iJ_T006Ki0002I_T01000I_T006Ki0P00
0VKi00X006Ki001Vn@00I_T006Ki001Rf@800007H]T006;IH]T006;I00000V;I00P005kI001Nf@00
G]T005ji1@0000QJ^P00F[X005Jj001FVP000UJJ0P0000YBVP00001>VP00CWX004ij001:NP@00005
AU/004IK0012F`020000149K000003hk0P0000Pn>`00000j>`00>S/003Hk0P0000@f>`00000f>`80
0004=Q/00000<Q/60000138K0000038K0P0000@b7000000b70800004<Q`00000;Q`2000012hL0000
02XL0`0000@Un`00000Un`<000037M/0000000@000044I/000001GX300000`4i0000000=00001bko
000k?`00Ael004mo00@0009OWP05001SWF>M001W_@020002Ji`01@00Ki]_VfnK00000VnK00D006nK
Ki]_V`00009_VP04001cVW>J0002LgX01@00LgYcNP00LgT00P000W=i00@007=i000000=cN@04001c
FG=I0002KeT01000KeT006mI0P000VmI00D006mIKeT006mI0080009_F@03001_FFmI00<0009_>@03
001_>@00009_>@06001[>F/i001[>@000V/i00@006/i0000009[>@06001[>@00JcT006/i0P000V/j
00<006/i00000V/i0`000V/I00<006/I00000V/I0`000V/I00D006/I001[6@00009[6@03001[6@00
009[6@03001[6@00009[6@<0009W6@05001W6@00IaT00002IaT300001fLI001W6FLI001W6@00009V
n@<00009I_T006KiI_T006Ki001Vn@00009Vn@<00004H_T006;i0002H_T20002H_T02@00H]X006;J
001NfP00G]X00002G]X20002G]X04@00G]X005[J001J^P00F[X005Zj001J^P00F[X005Jj00000UJj
01D005Jj000005JJ001BVP00DYX005:J001BVP00DYX005:J001>VP00CY/00P0001=>V`00CY/004jK
001>V`00CW/004ik001:N`00BW/004Yk001:N`0200002DYk001:V`00BY/004ZK001:V`0700000dZK
001:V`0200006dZK001:V`00CY/004jK001>V`00CY/004jK001>V`00CY/004jK001>V`00C[/004jk
001>^`020000;Tjk001>^`00C[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`000U:k01d005:k001B^`00D]/0
05;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`0001]oo`03001oogoo04Io
o`00Cgoo00<007ooOol0H7oo4000015Bf`00D]`005;L001Bg000D]`005;L001Bg000D]`005;L0080
000AD[`005:l001B_000D[`005:l001B_000D[`005:l001B_00200003Djl001>_000C[`004jl001>
_000C[`004jl00T00007BY`004JL0016W000AY`00P0002M2O0000012O000<C@004Fe001=mP00DQH0
058F001F5P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Xf00000UXf00T0
05YF001NE@00HWD006JE00000W:c00<007lAOa400WlA0P000g/B00D007lbOc9o<P0000Ao<@8000=o
D`07001oDgmCOe<007mD00000W]D00<007]ENeD00W]E00<007]ENeD00g]E00<007]FNeH00g]F00T0
07MFMeIgEP00MeH007MG000017Lg00D007LgMcMg=`00009c=`03001c>7<h009c>004001c>7<h0003
LcP01000LcQc>0000flh00D006lhKcP006lh008000=_>004001_>6lh0002KcT01000KcU_>@000VlI
00@006lIKaT0009[6@05001[6F/I001[6@020002JaT01000JaU[6@000V/I00@006/IJaT0009[6@04
001[6@00JaT20002JaT01`00JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT00`00JaT00002
JaT01000JaU[6@000V/I00D006/I001[6@00009[6@06001[6F/I001[6@000V/I00L006/IJaT006[i
001Zn@020002J_T01P00I_UVn@00I_T0009Vn@03001Vn@00009Vn@08001Vn@00I_T006Ki001Vn@80
0007H]T006;IH]T006;I00000V;I00P006;I001Nf@00G]T005kI0`0000AJ^P00F[X0009J^P0<001J
^P00E[X005JJ001FVP00DYX005:J0P0000E>VP00CWX004ij00800003BWX004Yk00@00004@U/00000
@U/200000chk000n>`02000023Xk000003Xk000f>`00=S/2000013Hk000003Hk0`0000Db6`00<Q/0
038K00@00004<Q/00000<Q/20000138L0000038L0P0000@^7000000^70800005;Q`00000000Z7002
00001BGk000000008O/00`0000<I^`0000001P0000<5FP000000100000<1>@0000001P0000<JOP00
00001P000U=o00<005NO00000UnN00@006>M0000009WW@05001[W6^L001_V`020003Ki/01000Ki/0
00000VnJ00@007>J000000=cNP04001cNW=j0002LgX01000LgUcN@000W=i00D007=iLgT007=I0080
009_F@06001_FFmI001_F@000fmI00@006mIKeT0009_F@03001_F@00009_F@06001_>Fli001_>@00
0Vli0`000V/i00@006/iJcT0009[>@03001[>@00009[>@03001[>F/i00<0009[>P03001[>P00009[
>@<00007JaX006/IJaT006/I00000V/I00<006/I00000V/I00<006/I00000V/I0`000V/I00D006/I
001[6@00009[6@03001W6@00009W6@03001W6@00009W6@<00009IaT006LIIaT006LI001W6@00009V
n@05001Vn@00I_T00002I_T00`00I_T00002I_T3000016;i001Rn@000V;i00X006;i001Rn@00H_T0
06;J001RfP<0009NfP0?001NfP00G]X005kJ001NfP00F]X005Zj001J^P00009J^P06001J^P00F[X0
05Jj6P0000E>V`00CY/004jK0080000ACW/004ik001:N`00BW/004Yk001:N`00BW/004Yk001:V`02
00002DZK001:V`00BY/004ZK001:V`0700001DZK001:V`00CY/00P0003m>V`00CY/004jK001>V`00
CY/004jK001>V`00C[/004jk001>^`00C[/004jk001>^`00C[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00`00021B^`00
D[/005:k001B^`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00
77oo00<007ooOol0AGoo001?Ool00`00Oomoo`1POol03P00D]`005;L001Bg000D]/005;K001Bf`00
D]/20002D]/04000D]`005;L001Bg000D]`005;L001Bg000D]`005;L0P00015B_000D[`005:l001B
_000D[`005:l001B_000D[`005:l0080000;C[`004jl001>_000C[`004jl001>_002000024jl0000
04ZL001:W000BY`600001TJL0000049l0012O080000R<C@004Fe001=mP00DQH0058F001F5P00ESH0
05Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Xf0002FSH02@00FUH005iE001RM@00
IYD00002L[<00`00Oa5o4@02Oa420003Na801@00Oc9o<Wlb000017la00<007mB00000WmC00D007mC
Oe=oD`00009oE003001kE00000AkE@03001kEG]E00=kE@03001kEW]F00=kEP03001gEWMF009gEP05
001gEgMGMeL00003McL02@00McMg=gLg001c=`00LcL00003LcP01@00LcP007<h00000W<h00@007<h
000000=_>005001_>6lhKcP00002KcP01000KcQ_>0000Vlh00@006liKcT0009_>@04001_6@000002
KaT01@00JaU[6F/I00000V/I00@006/IJaT0009[6@04001[6@00JaT20002JaT01000JaU[6@000V/I
00H006/IJaT006/I0002JaT01000JaU[6@000V/I00L006/IJaT006/I001[6@020002JaT01`00JaU[
6@00JaT006/I0080009[6@06001[6@00JaT006/I0P000V/I00L006/IJaT006/I001Zn@020002J_T0
0`00J_T00002I_T01000I_T006Ki0P000VKi00<006Ki00000VKi00<006Ki00000P0000MRn@00H]UR
f@00H]T00002H]T02000H]T006;I001Nf@00G]T3000055ji001J^UZj001J^P00F[X005Zj001F^P00
EYX005JJ001BVP00DYX200002DjJ001>NP00CWX004Yj001:NP0200000dIk0016F`0500000chk000n
>`02000013hk000003Xk0P0000Df>`00=S/003Hk00<00003=S/003Hk00<00005<Q/00000000b>`02
00000c8K000b6`020000138L0000038L0P0000@b7000000^70800004;Q`00000:Q`3000012Wl0000
02Gk0`0000<Qf`0000000P0000<E^`0000001P0000<1FP0000001@0000<1NP0000000`0000TJOP00
000fo`00?cl004]O00000U=o00@005NO001OWP80009SW@05001WWFNM001[W0020002Ji`01@00Ki]_
VfnK00000VnK00@006nJKiX0009_NP05001cNW=j001cNP020002LgX01000LgT000000g=i00@007=i
LgT0009_F@04001_F@00KeT20002KeT01@00KeU_F@00KeT00P000VmI00<006mIKeT00`000Vli00H0
06liKcT006li0002JcT01`00JcU[>@00JcT006/i0080009[>@03001[>@00009[>@03001[>P00009[
>P03001[>P00009[>@03001[>P00009[6P03001[6@00009[6@<0009[6@05001[6F/I001[6@030002
JaT01@00JaT006/I00000V/I0`000VLI00<006LIIaT00P000VLI00<006LI00000VLI00D006LI001W
6@00009W6@<00009I_T006KiI_T006Ki001Vn@00009Vn@05001Rn@00H_T00002H_T02P00H_T006;i
001Rn@00H_T006;J0P00011RfP00G]X005kJ001NfP00G]X005kJ001NfP00F]X0009J^P03001J^P00
00P0000=E[X005Jj001F^P00E[X005JJ001BVP00DYX00P0000UBVP00DYX005:J001>V`00CY/02@00
00=>N`00CW/00P0000m:N`00BW/004Yk001:N`00BW/004ZK001:V`00BY/00P0000]:V`00BY/004ZK
001:V`00BY/004jK00T00007CY/004jK001>V`00CY/00P0003E>V`00CY/004jk001>^`00C[/004jk
001>^`00C[/004jk001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k00<0000HD[/005:k001B^`00D[/005;K001Bf`00D]/005;K
001Bf`00D]/005;K001Bf`000U;K00L005;K001Bf`00D]/0000KOol00`00Oomoo`15Ool0051oo`03
001oogoo061oo`0>001Bg000D]`005;L001Bf`00D]/005;K001Bf`80000KD]/005;L001Bg000D]`0
05;L001Bg000D]`005;L001Bg000D]`005:l001B_000D[`005:l0080000;D[`005:l001B_000D[`0
04jl001>_00200002djl001>_000C[`004jl001>_000C[`00P0000=:W000BY`00P0000E:W000AY`0
04JL00<00003@W`0049l0080000P<C@004Fe001=mP00DQH0058F001F5P00ESH005Hf001F=P00ESH0
05Hf001F=P00ESH005Hf001F=P00ESH0009J=P0;001J=P00FUH005iE001RM@00IYD00002L[<01@00
Oa5o4GlA00000WlB00@007/BNa8000=o<P03001o<Gla009o<@03001oDWmB008000AoD`05001oE7mD
Oe@00004NeD00`00NeD00003NeD00`00NeH00003NeH00`00MeH00003MeH00`00MeMgE`02MeL01@00
McL007Lg00000gLg00D007<gLcMc=`0000=c>004001c>7<h0003LcP01000LcQc>0000flh00@006lh
0000009_>008001_>6lh001_>000KcT0009_>@04001_>Fli0002KaT01000KaU_6@000V/I00@006/I
0000009[6@04001[6F/I0002JaT01000JaU[6@000V/I00@006/I001[6@80009[6@07001[6F/I001[
6@00JaT00P000V/I00@006/IJaT0009[6@06001[6F/I001[6@000V/I00@006/IJaT0009[6@05001[
6@00JaT00002JaT01P00JaU[6@00JaT0009[6@06001[6F/I001Zn@000V[i00L006[iJ_T006Ki001V
n@020002I_T00`00I_T00002I_T01`00I_T006Ki001Vn@00009Rn@03001Rf@00009Rf@05001Rf@00
H]T00002H]T300004UkI001Nf@00G[T005Zj001J^P00F[X005Zj001F^P00EYX0009FVP80000@DYX0
0000CYX004ij001>NP00BWX004Yj001:N`00AW/200000dIK0000000300000chk000n>`02000013Xk
000003Xk100000<f>`00=S/00`0000<f>`000000100000@b6`00000b>`800003<Q/0038K00800004
<Q`00000<Q`2000012hL000002hL0`0000@Z7000000Z708000059O`00000000Qn`0300000aVk0000
000700000`5J0000000800000`6k0000000500001cKo000o?`00Bel005=o00@0009OWP05001SWF>M
001WW@020002Ji`01@00Jia[W000Ki/00P000VnK00@006nJ000000=_NP04001cNW=j0002LgX01000
LgYcNP000Vmj00D007=iLgT007=i0080009_F@04001_FFmI0002KeT01000KeU_F@000VmI00H006mI
KeT006mI0002KeT01000KcU_>@000Vli00D006li001_>@00009[>@05001[>F/i001[>@020002JcX0
0`00JcT00002JcT30002JcX00`00JcX00002JcX30002JcX00`00JaX00002JaT30002JaX00`00JaT0
0002JaT01@00JaT006/I00000V/I00D006/IJaT006/I00<0009W6@03001W6@00009W6@03001W6@00
0080009W6@05001W6@00IaT00002IaT300002FKi001VnFKi001Vn@00I_T00002I_T300003V;i001R
nF;i001Rn@00H_T006;i001Rn@00H_T2000026;J001RfP00G]X005kJ0002G]X200001UkJ001NfUkJ
001JfPD0000OF[X005Zj001J^P00E[X005Jj001F^P00E[X005Jj001FVP00DYX005:J001BVP00DYX0
05:J001BVP00CY/00P0000M>V`00CY/004jK001>V`0700000dYk001:N`0200003dYk001:N`00BY/0
04ZK001:V`00BY/004ZK001:V`0200003DZK001:V`00CY/004jK001>V`00CY/004jK00/00009CY/0
04jK001>^`00C[/004jk0080000YC[/004jk001>^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`03000065:k001B^e:k001B
^`00D[/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`T001]oo`03001oogoo04Eoo`00D7oo
00<007ooOol0H7oo028005;L001Bg000D]`005;K001Bf`00D]/005;K001Bf`00D]/005;L001Bg000
D]`005;L001Bg000D]`005;L001Bg080000AD[`005:l001B_000D[`005:l001B_000D[`005:l001B
_00200002djl001>_000C[`004jl001>_000C[`00P0000a>_000001:W000BY`004ZL001:W000AY`2
00000dJL0000000300007D9l000004Fe001=mP00DQH0058F001F5P00ESH005Hf001F=P00ESH005Hf
001F=P00ESH005Hf00000UHf014005Hf001J=P00FSH005YF001NE@00HWD006JE001b/`0000Ao4@04
001o4WlB0002Na801@00Oc9o<Wlb00000gla00<007mBOe800WmB00D007mCOe=oD`0000AoE08000=k
E@04001kEG]E0002NeD01P00NeIkEP00NeH000=gEP05001gEP00MeL00004MeL01@00McMg=gLg0000
0WLg00D007<gLcMc=`0000=c>005001c>7<hLcP00002LcP01@00LcQc>7<h00000flh00@006lhKcP0
009_>004001_>6lh0002KcT01@00KcU_>@00KcT00P000VlI00D006lIKaU_6@00009[6@04001[6F/I
0002JaT01000JaT006/I0P000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01000JaT006/I0P00
0V/I00L006/IJaT006/I001[6@020002JaT01`00JaU[6@00JaT006/I0080009[6@03001[6F/I0080
0003JaT00000009[6@07001[6F/I001[6@00JaT00P000V[i00H006[iJ_T006[i0002I_T00`00I_T0
0002I_T02P00I_UVn@00I_T006Ki001Vn@000VKi00D006;i001Rf@00009Rf@03001Rf@00009Rf@<0
000<G]T005kI001Nf@00G[T005Zj001J^P000UZj00P005Zj001F^P00EYX005JJ0P0000UBVP00DYX0
04jJ001>NP00CWX00P0000E:NP00BW/004Ik00800004AU/00000@U/200001Chk000n>`00?S/00P00
00Hj>`00000j>`00>S/2000013Hk000003Hk0`0000<f>`0000000`0000@b>`00000b>`800003<Q/0
038L00800007<Q`00000000^7000;Q`00P0000D^7000000002XL00800004:O`000009O`300001B7K
000000006K/01P0000@9NP000001FP<000040EX000000GX300001@Wl000000008Yh020000U=o00<0
05]n00000UnN00H006>M000006NM0003Ji`01000Ji`000000VnK00@006nKKi/0009_V`05001_NVmj
001cNP020002LgX01000LgX000000fmj00@007=iLgT0009_FP04001_F@00KeT20002KeT01@00KeU_
F@00KeT00P000VmI00<006mIKeT00`000Vli00D006liKcT006li00800005KcT006/iJcT00002JcT0
0`00JcX00002JcX00`00JcT00002JcT00`00JcX00002JcX00`00JcY[>P030002JcX01@00JcX006/J
00000V/I00<006/J00000V/J00P006/IJaT006/I001[6@000V/I00X006/IJaT006/I001[6@00IaT0
009W6@08001W6FLI001W6@00IaT0009W6@03001W6@00009W6@03001W6@0000800009I_T006KiI_T0
06Ki001Vn@00009Vn@<0000;I_T006;iH_T006;i001Rn@00H_T00002H_T3000016;J001RfP000V;J
0P000UkJ00@005kJ0000009NfPD0000<F[X005Zj001J^P00F[X005Zj001F^P000UJj00`005Jj001F
^P00E[X005JJ001BVP00DYX200001e:J001BVP00DYX004jK0080000=CY/004jK001>V`00CY/004jK
001>V`00CY/01`0000=:N`00BW/00P00015:V`00BY/004ZK001:V`00BY/004ZK001:V`00BY/004jK
0080000?CY/004jK001>V`00CY/004jK001>V`00CY/004jK00d0000YC[/004jk001>^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`0300000e:k0000000E000025;K001Bf`00D]/005;K000KOol00`00Oomoo`15Ool0055oo`03
001oogoo061oo`0>001Bg000D]`005;L001Bf`00D]/005;K001Bf`80009Bf`08001Bg000D]`005;L
001Bg080000?D]`005;L001Bg000D]`005:l001B_000D[`005:l0080000AD[`005:l001B_000D[`0
04jl001>_000C[`004jl001>_00200001Djl001>_000C[`00P0000E:W000BY`004ZL00800009AY`0
04JL0016W000@W`0049l00<0000DAKD004gf001B5P00DQH005HF001F=P00ESH005Hf001F=P00ESH0
009F=P0C001F=P00ESH005Hf001F=P00FSH005Xf001JEP00GUD0069e00000VJE0P0017lA00@007lB
Oa9o4P8000Ao<P05001o<GlaOc400004Oe820002Oe<01@00OeAoE7mD00000W]E00@007]ENeD000=k
E@03001kE@00009kEP03001kEP0000=gEP03001gEP00009gE`05001gEgMGMeL00003McL01@00McL0
07<g00000g<g00D007<h001c>000009c>005001c>000LcP00002LcP01@00KcQ_>6lh00000Vlh00D0
06lhKcP006lh008000=_>@04001_>Fli0002KcT01000KaU_6@000VlI00@006/I0000009[6@04001[
6F/I0002JaT01000JaU[6@000V/I00@006/I001[6@80009[6@04001[6F/I0002JaT00`00JaT00002
JaT01000JaU[6@000V/I00@006/IJaT0009[6@03001[6@00009[6@04001[6F/I0002JaT01@00JaT0
06/I00000V/I00H006/IJaT006/I0002JaT01P00J_UZn@00J_T0009Zn@04001Zn@00I_T20002I_T0
0`00I_T00002I_T01000I_T006Ki0P0000IVn@00I_T006;i0002H]T01000H]T006;I100000ARf@00
G]T0009Nf@80000@G[T005ZjF[X005Zj001J^P00F[X005Jj001FVP00EYX200003E:J001BVP00CYX0
04ij001>NP00BWX004Yj00800005AW/004IK0016F`0300000d9K0000000200000chk000j>`020000
0cXk000j>`0200001cXk00000000=S/003Hk00<00004=S/00000<Q/20000138k0000038k0P0000<b
7000<Q`00P0000Lb7000000002hL000^7003000012hL000002XL0P0000DUo0000000027k00<00003
7M/00000008000035K/0000000<000030EX0000000L000040K/000004Sd200002B:N000003[o0013
?`00Bel00002Dgl01000Fgh005nN0P0000ESW@00IieWW@00009[W0800006Ji`006nKKi/006nK0P00
0fnK00@006mj0000009_NP04001cNW=j0002KgX01@00KgY_NP00LgT00P000VmJ00@006mIKeT0009_
F@04001_FFmI0002KeT01P00KeU_F@00KeT0009_F@04001_FFmI0002KcT02000KcU_>@00KcT006li
0002JcT01000JcT000000V/j00<006/j00000V/i0`000V/j00<006/j00000V/j00<006/j00000V/j
00D006/jJcX006/J00<0009[6P07001[6V/J001[6@00JaT00P0000A[6@00JaT0009[6@05001[6@00
JaT00002IaT01P00IaUW6@00IaT0009W6@80009W6@0:001W6FLI001W6@00IaT006LI0002I_T01@00
I_T006Ki00000VKi0`0000]Vn@00I_UVn@00H_T006;i001Rn@00009Rn@<00004H_X006;J0002H]X0
2P00H]X005kJ001NfP00G]X005kJ0`0000QNfP00F]X005Zj001J^P000UZj01@005Zj001J^P00E[X0
05Jj001F^P00E[X005Jj001FVP00DYX005:J0P0000mBVP00DYX005:J001>V`00CY/004jK001>V`00
CY/00P0000]>V`00CY/004jK001>V`00CY/004jK00L00003BY/004ZK0080000CBY/004ZK001:V`00
BY/004ZK001>V`00CY/004jK001>V`00CY/00P0001=>V`00CY/004jK001>V`00CY/004jk001>^`00
C[/004jk001>^`0_00007U:k001B^`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00
D]/005;K001Bf`00D]/001aoo`03001oogoo04Aoo`00DWoo00<007ooOol0H7oo00P005;L001Bg000
D]`005;K0P0000mBf`00D]/005;K001Bf`00D]`005;L001Bg000D]`00P0000=Bg000D]`0700000=>
_000C[`00P0000]>_000C[`004jl001:_000BY`004ZL00800003BY`004JL00800004AY`00000@W`3
00000c4d0015]@020000258F001B5P00EQH005Hf0002ESH06@00ESH005Hf001F=P00ESH005Hf001F
=P00ESH005Hf001J=P00FSH005YF001NE@00009RM@04001VU@000004Oa401000Oa9o4WlB0P000glb
00<007laOc400Wla00D007mBOe9oDP00009oD`03001oD`0000=oE004001kEG]ENeD20005NeD00`00
NeIkEP02NeH00`00MeIgEP03MeH01@00MeMgEgMG00000WMG00<007MG00000gLg00D007<gLcMc=`00
00=c=`04001c>7<h0003LcP01@00LcQc>7<h00000W<h00D006lh001_>000009_>004001_>6lh0002
KcP01000KcU_>@000Vli00@006liKcT000=_6@04001_6FlI0002JaT01`00JaU[6@00JaT006/I0080
009[6@05001[6F/I001[6@020002JaT01`00JaU[6@00JaT006/I0080009[6@07001[6F/I001[6@00
JaT00P000V/I00L006/IJaT006/I001[6@020002JaT02000JaU[6@00JaT006/I0002JaT01`00JaU[
6@00JaT006/I0080009Zn@07001ZnF[i001Zn@00J_T00P000VKi00<006Ki00000VKi00@006Ki001V
n@800006I_T006Ki001Vn@000V;i00<006;I00000V;I00D006;I001Rf@00009Rf@0E001Nf@00G]T0
05kI001N^@00F[X005Zj001J^P00F[X005Jj001FVP00009FVP80000@DYX00000CYX004ij001>NP00
BWX004Yj001:N`00AW/2000014IK0000049K0P0000=2F`00?U/00P0000<j>`00>S/00P0000Hj>`00
000j>`00>S/3000013Hk000003Hk0P0000@f>`00000b>`800004<S/00000<S`200000c8L000b7003
00001S8L000002hL000^70<00004;Q`00000:O`200001BGl000000008M/00`0000<Mf`0000000`00
00<=VP0000000P0000<1FP0000001`0000@9o000000NGP@00007>_l004<o001;G`00Dgl0100000IO
OP00HieSW@00Iid300001VNL001[W6^L001_V`80009_V`07001_VfnKKi/006mj00000Vmj00@007=j
000000=_NP04001_NVmj0002KgX01000KeX006mI0P000VmI00D006mIKeT006mI0080009_F@03001_
FFmI00<0009_F@05001_>Fli001_>@020002KcT00`00KcT00002JcT01P00JcY[>P00JcX0009[>P<0
009[>P03001[>P00009[>P<0009[>P08001[>V/j001[>P00JaX0009[6P03001[6P00009[6P08001[
6F/I001[6P00JaT0009[6@04001[6@00JaT2000016LI001W6@000VLI00@006LI001W6@80000;IaT0
06LIIaT006LI001W6@00IaT00002IaT01@00I_T006Ki00000VKi0`0000AVn@00I_T0009Vn@05001R
n@00H_T00002H_T3000016;j001RnP000V;J00X006;J001RfP00G]X005kJ001NfP<00004G]X005kJ
G]X20002F[X08P00F[X005Zj001J^P00F[X005Jj001F^P00E[X005Jj001F^P00EYX005:J001BVP00
DYX005:J001BVP00DYX004jK0P0000]>V`00CY/004jK001>V`00CY/004jK0080000;CY/004jK001>
V`00BY/004ZK001:V`0700000dZK001:V`0200005dZK001:V`00CY/004jK001>V`00CY/004jK001>
V`00CY/004jK001>V`00CY/00P0003=>^`00C[/004jk001>^`00C[/004jk001>^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/00`00021B^`00D[/005:k001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001B
f`00D]/005;K001Bf`0077oo00<007ooOol0A7oo001BOol00`00Oomoo`1POol02P00D]`005;L001B
g000D]/005;K500000eBg000D]`005;L001B_000D[`005:l001B_00200003E:l001B_000D[`005:l
001>_000C[`004jl00d00005BY`004ZL001:W00200001DJL0016W000AY`00`0002Y2O000<C@004Fe
001=mP00DQH0058F001F5P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Xf
001J=P00FUH005iE0002HWD01000IYD0000017lA00<007lBOa800WlB00D007lbOc9o<P0000=o<@03
001oDWmB009oDP04001oDgmCOe<20003Oe@00`00NeEkE@02NeD00`00NeEkE@03NeD00`00NeIkEP02
NeH20004MeH00`00MeMgE`02MeL00`00MeL00002MeL01000McMg=`000g<g00D007<gLcMc=`0000=c
>004001c>7<h0003LcP01@00LcQc>7<h00000Vlh00D006lhKcP006lh0080009_>008001_>Fli001_
>@00KcT0009_>@05001_6FlI001_6@020002JaT01@00JaU[6@00JaT00P000V/I00@006/IJaT0009[
6@03001[6@00009[6@04001[6F/I0002JaT01P00JaU[6@00JaT0009[6@04001[6@000002JaT01`00
JaU[6@00JaT006/I0080009[6@07001[6F/I001[6@00JaT00P0000Q[6@00JaU[6@00JaT006/I0P00
0V[i00<006[i00000V[i00H006[iJ_T006Ki0002I_T01P00I_UVn@00I_T0009Vn@07001Vn@00I_T0
06Ki00000VKi00H006;i001Rf@00H]T20002H]T04P00H]T006;I001Nf@00G]T005kI001N^@00F[X0
05Zj001J^QH00005BWX004Yk0016N`02000024IK0000049K0012F`00@U/200001Shk000003Xk000j
>`800004>S/00000>S/5000013Hk000003Hk0P0000@f>`00000b>`800004<S/00000<S`200000c8L
000b70030000138L000002hL0P0000@^7000000Z708000059O`00000000Uo00200000agK00000002
00000aFk0000000200000`Uj0009VP03000010Ej0000006K0P0000@9g000000B?@800003:Yl003;O
00L00004Del005]n0002Ggh01P00Hid00000Iid000=WW006001[W6^L001[V`000fnK00@006nK0000
009_NP04001_NVmj0002KgX01@00KgY_NP00KgX00P000Vmj00@006mJKeX0009_FP04001_FFmI0002
KeT01P00KeY_FP00KeT0009_F@04001_FFmI0002KeT01000KcU_>@000Vlj00H006li001_>@00JcT2
0002JcX00`00JcX00002JcX00`00JcX00002JcX00`00JcX00002JcX01P00JcY[>P00JcX0009[>P03
001[>V/j0080009[6P07001[6V/J001[6P00JaT00P000V/J00H006/I001[6@00JaT2000016LI001W
6@000VLI00@006LI001W6@800004IaT006LI0002IaT01000IaT006LI0P0000AW6@00IaT0009Vn@80
009Vn@05001Vn@00I_T00002I_T01@00I_T006;i00000V;i0`0000ARn@00H_X0009RnP0:001RfP00
H]X006;J001NfP00G]X200000ekJ00000002G]X0:000G]X005[J001J^P00F[X005Zj001J^P00F[X0
05Jj001F^P00E[X005Jj001F^P00EYX005:J001BVP00DYX005:J001BVP00DYX004jK0P00015>V`00
CY/004jK001>V`00CY/004jK001>V`00CY/004jK0080000;BY/004ZK001:V`00BY/004ZK001:V`07
00001DZK001:V`00CY/00P0002=>V`00CY/004jK001>V`00CY/004jK001>V`00CY/004jK001>^`00
C[/004jk001>^`00C[/004jk001>^`00D[/005:k0080000FD[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k0002D[/02000D[/005:k001B^`00D[/300002E:k001B^`00D[/005;K
001Bf`02000035;K001Bf`00D]/005;K001Bf`00D]/0009Bf`07001Bf`00D]/005;K00006goo00<0
07ooOol0A7oo001COol00`00Oomoo`1POol:00003e;L001Bg000D]`005;L001Bg000D]`005;L001B
g002000045;L001Bg5;L001Bg000D]`005:l001B_000D[`005:l0P0000]B_000D[`005:l001B_000
C[`004jl00800003C[`004jl00800007C[`004jl001>_000B[`01`0000E6W000AY`004JL0080000U
@W`00000<C@004Fe001=mP00DQH0058F001F5P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf
001F=P00ESH005Xf00000UXf00P005YF001NE@00HWD006JE0P0017lA00<007lBOa800WlB00D007lb
Oc9o<P0000=o<@03001oDWmB009oDP06001oDgmCOe<007md0`001G]E0P000g]E00<007]F00000W]F
00@007]FNeH0009gEP03001gE`0000AgE`09001gEgMGMeL007Lg001cE`0000=c=`05001c=`00LcP0
0002LcP01@00LcP007<h00000g<h00@007<h000000=_>004001_>6lh0002KcP01000KcQ_>0000Vli
00@006liKcT000=_>@04001_6FlI0002JaT01000JaU[6@000V/I00<006/I00000V/I00D006/IJaT0
06/I0080009[6@07001[6F/I001[6@00JaT00P000V/I00@006/IJaT0009[6@03001[6@00009[6@04
001[6F/I0002JaT00`00JaT00002JaT01000JaU[6@000V/I00D006/I001[6@00009[6@06001[6F/I
001[6@000V[i00L006[iJ_T006[i001Zn@020002I_T00`00I_T00002I_T01000I_T006Ki0P0000aV
n@00I_UVn@00I_T006Ki001Rn@00H]T20002H]T04000H]T006;I001Rf@00G]T005kI001Nf@00G[T0
05Zj100000UJ^P00F[X005Jj001F^P00EYX00P0000]BVP00DYX005:J001>VP00CWX004ij00@00006
AW/00000AU/0049K0P0000E2F`00@U/003iK00800006?S/00000>S/003Xk0P0000Dj>`00000003Hk
00@00004=S/00000=S/2000013Hk0000038k0P0000@b?000000b?0800004<Q`00000<Q`20000138L
000002hL0P0000@^7000000Z708000059O`00000000Qo00300000agK0000000300000a6k00000003
00000`5j00000003000010Fk0000018M0P0000<NGP00:Yl00P0000Hjo`00@cl004]O0002Del01000
Fgh005mn0P0000ESO@00IieWW@00009WW004001[W0000002Ji/01@00Ki]_VfnK00000Vmk00@006mj
001_NP8000=_NP04001_NVmj0002KgX01000KgX006mJ0P000VmJ00D006mIKeT006mI0080009_FP03
001_FFmI00<0009_F@05001_FFmI001_>@020002KcX01000KcT006li0P000V/j00<006/j00000V/j
0`000V/j00D006/jJcX006/j00<0009[>P07001[>V/j001[>P00JcX00P0000Q[6P00JaY[6P00JaX0
06/J0P0000M[6P00JaY[6P00JaT00002JaT00`00IaX00002IaT01P00IaT006LI001W6@80000:IaT0
06LIIaT006LI001W6@00IaT2000016LI001W6@000VLI00@006Ki001Vn@<0009Vn@07001Vn@00I_T0
06Ki00000V;i0`0000ARn@00H_T0009RnP05001RnP00H]X00002H]X00`00H]X0000200005UkJ001N
fP00G]X005kJ001NfP00F]X005Zj001J^P00F[X005Zj001J^P000UJj00h005Jj001F^P00E[X005Jj
001FVP00DYX005:J0P0000]BVP00DYX005:J001>V`00CY/004jK0080000CCY/004jK001>V`00CY/0
04jK001>V`00CY/004jK001:V`00BY/00P0000]:V`00BY/004ZK001:V`00CY/004jK00T00005CY/0
04jK001>V`020000?DjK001>V`00CY/004jK001>V`00C[/004jk001>^`00C[/004jk001>^`00C[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k00<0000PD[/005:k001B^`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0
05;K001Bf`00D]/005;K001Bf`00D]/001aoo`03001oogoo04=oo`00Dgoo00<007ooOol0H7oo01X0
05;L001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`005;L0P0000mBg000
D]`005;L001Bg000D[`005:l001B_000D[`00P00015B_000D[`005:l001B_000C[`004jl001>_000
C[`004jl00800005C[`004jl001>_00200001DZl001:W000BY`01`0002I6W000@W`0034d0015]@00
COH0058F001B5P00EQH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001J=P00
0UXf00P005YF001NE@00HWD006JE0P0017lA00<007lBOa800WlB0P000Wlb00D007laOc5o<@0000=o
DP05001oDgmCOe<00004Og@20003NeD01P00NeEkE@00NeD000=kEP03001kEP0000=kEP03001gEP00
009gE`03001gEgMG008000AgE`05001cEg=GLeL00003LcL01@00LcQc>7<h00000W<h00D007<hLcQc
>00000=c>004001_>6lh0002KcP01000KcP000000Vlh00D006lhKcP006li008000=_>@05001_>Fli
001_6@020002JaT01@00JaU[6@00JaT00P000V/I00@006/IJaT0009[6@06001[6F/I001[6@000V/I
00@006/I0000009[6@07001[6F/I001[6@00JaT00P000V/I00L006/IJaT006/I001[6@020002JaT0
1`00JaU[6@00JaT006/I0080009[6@06001[6@00JaT006/I0P000V/I00H006[iJ_T006[i0002J_T0
1P00I_UVn@00I_T0009Vn@04001Vn@00I_T20002I_T02P00I_T006Ki001Vn@00I_T006;i0P0000MR
f@00H]URf@00H]T00002H]T01000H]T000000UkI1@0000AJ^P00F[X0009J^P04001J^P00E[X20000
3EJJ001BVP00DYX005:J001BVP00CYX004ij00800003BWX004Yk00@00006AU/00000@U/0049K0P00
00<nF`00?S/00P0000@n>`00000j>`800003>S/003Xk00<00006=S/00000=S/003Hk0P0000@f>`00
000f>`800004<S/00000<S`20000138l0000038L0P0000@b7000000^70800004;Q`00000:Q`20000
1BXL000000009O`00P0000<Qn`0000000P0000<If`0000000P0000<A^`0000000`0000<5NP000000
1@0000<B7@0000000`0000Tbg`00>_l004<o001;G`00Del0100000EOOP00HgeSO@00009WW@04001W
W0000002Ji`01@00Ji][V`00Ki/00P000Vmk00@006mjKgX0009_NP05001_NVmj001_NP020002KgX0
1000KgY_NP000VmJ00@006mJKeX0009_F@07001_FVmJ001_FP00KeT00P000VmJ00@006mIKeT0009_
F@06001_>Vlj001_>P000Vli00<006/j00000V/j00<006/jJcX00`000V/j00<006/j00000V/j00<0
06/j00000V/j00L006/jJcX006/j001[>P02000016/J001[6P000V/J00H006/JJaX006/J0002JaX0
1P00JaX006/I001[6@800007IaX006LIIaT006LI00000VLI00<006LI00000VLI00D006LI001W6@00
009W6@05001W6@00IaT00002IaT01`00IaT006Ki001Vn@00009Vn@07001Vn@00I_T006Ki00000VKi
0`0000ARn@00H_T0009Rn@05001RnP00H_X00002H]X5000015kJ001NfP000UkJ0P0000ANfP00G]YN
fP800004F[X005Zj0002F[X01000F[X005Zj800000E>V`00CY/004jK0080000ACY/004jK001>V`00
CY/004ZK001:V`00BY/004ZK001:V`0200003DZK001>V`00CY/004jK001>V`00CY/004jK00T00007
CY/004jK001>V`00CY/00P0003=>^`00C[/004jk001>^`00C[/004jk001>^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/00`00021B^`00D[/005:k001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00
D]/005;K001Bf`0077oo00<007ooOol0@goo001DOol00`00Oomoo`1POol02000D]`005;L001Bg000
D]`2000025;L001Bg000D]`005;L0002D]`200005E;L001Bg000D]`005;L001Bg000D]`005;L001B
_000D[`005:l001B_00200002e:l001B_000D[`005:l001>_000C[`00P0000E>_000C[`004jl0080
000AC[`004jl001:_000B[`004ZL001:W000AY`004JL0016W00400008S4d0015]@00COH0058F001B
5P00EQH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001J=P000UXf00T005YF
001NE@00HWD006JE000017lA00<007lBOa800glB0P000Wlb00D007laOc5o<@0000=oDP05001oDgmC
Oe<00004Og@00`00OgD00002NeD01@00NeEkEG]E00001G]F00<007]FNeH00g]F00L007MGMeMgE`00
MeL00002MeL01@00MeMgEgMG00000g=G00D007<gLcMc=`0000=c>004001c>0000003LcP01@00LcQc
>7<h00000Vlh00D006lhKcQ_>000009_>004001_>6lh0002KcP01000KcU_>@000fli00@006liKcT0
009_6@04001[6F/I0002JaT01P00JaU[6@00JaT0009[6@04001[6@000002JaT01000JaU[6@000V/I
00<006/I00000V/I00@006/IJaT0009[6@06001[6F/I001[6@000V/I00@006/IJaT0009[6@03001[
6@00009[6@04001[6F/I0002JaT01@00JaT006/I00000V/I00H006/IJaT006/I0002J_T01000J_T0
06[i0P000VKi00H006KiI_T006Ki0002I_T00`00I_T00002I_T02000I_T006Ki001Vn@00I_T20000
1f;i001RfF;I001Rf@00009Rf@06001Rf@00H]T005kI0`0000ANf@00G[X0009J^P0<001J^P00F[X0
05Zj001F^P00E[X005JJ0P0000]BVP00DYX005:J001>VP00CWX004ij00800003BW/004Yk00D00005
@U/0049K0012F`0200000chk000n>`0200001chk00000000>S/003Xk00800004=S/00000=S/20000
0cHk000f>`02000013Hk000003Hk0P0000@b?000000b?0800004<S`00000<Q`20000138L000002hL
0P0000@^7000000Z70800005:Q`00000000Qo00300000agK0000000200000a6k0000000200000`VJ
0009V`0300000`VK0000000300001A8M00000000;[l02@0000MCG`00FgiKOP00Ggh00002Hgd01000
Iid000000VNL00D006^LJi`006^K0080009[N`04001_N`00KgX20003KgX01000KgY_NP000Vmj00@0
06mj001_NP8000=_FP04001_FP00KeT20002KeX01P00KeY_FP00KeX000=_FP04001_F@00KeT20002
KcX00`00KcY_>P030002JcX00`00JcX00002JcX00`00JcX00002JcX01000JcY[>P000V/j0P000V/j
00@006/jJcX0009[>P03001[>P00009[6P06001[6P00JaX006/J0P000V/J00<006/J00000V/J0`00
00Y[6P00IaYW6P00IaT006LI001W6@80000:IaT006LIIaT006LI001W6@00IaT200002VLI001W6FLI
001W6@00IaT006Ki0`000VKi00<006KiI_T00P000VKi0`0000ARn@00H_T0009Rn@05001Rn@00H_X0
0002H_X300001V;J001NfP00G]X0009NfP08001NfP00G]X005kJ001NfP80009J^P03001J^P0000H0
000IE[X005Jj001F^P00E[X005Jj001F^P00DYX005:J001BVP00DYX005:J001BVP00DY/00P0000=>
V`00CY/02@0000E>V`00CY/004jK0080000ABY/004ZK001:V`00BY/004ZK001:V`00BY/004jK001>
V`0200003DjK001>V`00CY/004jK001>V`00CY/004jK00/0000AC[/004jk001>^`00C[/004jk001>
^`00C[/005:k001B^`0200005U:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`000U:k00P005:k001B^`00D[/005:k0`0000UB^`00D[/005:k001Bf`00D]/00P0000=Bf`000000
4@0077oo00<007ooOol0@goo001EOol00`00Oomoo`1POol06@00D]`00000D]`005;L001Bg000D]`0
05;L001Bg000D]`005;L001Bg000D]`005;L0080000:D]`005;LD]`005;L001Bg000D[`200003e:l
001B_000D[`005:l001B_000D[`005:l001>_00200001Djl001>_000C[`00P0000E>_000C[`004jl
00800005B[`004ZL001:W00200000dJL0016W00200007dJL0000034d0015]@00COH0058F001B5P00
EQH005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00009F=P0?001F=P00FSH005Xf001JEP00
GUD0069e001VU@0000Ao4@03001o4WlB009o4P03001o4WlB008000=o<@03001oDWmB009oDP05001o
DgmCOe<00003Og@01`00OgEoMGme001kE@0000=kE@8000AkEP8000AkEP03001gEgMG009gE`03001g
EgMG009gE`05001gE`00MeL00003LeL01@00LcL007<h00000g<h00@007<hLcP000=c>005001c>000
LcP00002KcP01000KcQ_>0000Vlh00D006lhKcP006lh008000=_>@05001_>Fli001_>@020002KaT0
1@00JaU[6@00JaT00P000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01000JaT006/I0P000V/I
00L006/IJaT006/I001[6@020002JaT01`00JaU[6@00JaT006/I0080009[6@07001[6F/I001[6@00
JaT00P000V/I00<006/IJaT00P0000=[6@0000000V/I00L006/IJaT006[i001Zn@020002I_T00`00
I_T00002I_T01000I_T006Ki0P000VKi00D006Ki001Vn@00009Vn@<00007H_T006;iH_T006;I0000
0V;I00/006;I001Rf@00H]T005kI001Nf@00009Nf@0@001N^P00F[X005Zj001J^P00F[X005Jj001F
^P00EYX200003E:J001BVP00DYX004jJ001>NP00CWX004Yj00800006BW/00000AU/004IK0P0000E2
F`00@U/003iK00800003?S/003hk00800007>S/00000000j>`00=S/00P0000@f>`00000f>`800003
=S/003Hk00800004=S/00000=S`20000138l0000038l0P0000@b?000000b70800004;Q`00000;Q`2
000012XL000002XL0`0000@Uo000000Qn`<000036M/00000008000034K/0000000D000041I/00000
3K/800000bjo000fg`020002Acl01@00Ccl005=O00000U]n00@005mn001SO@80009WO@05001WW6NL
001[W00200001V]k001[Nf]k001_N`80009_N`05001_NVmj001_NP020003KgX00`00KgX00002KeX0
1@00KeY_FP00KeX00P000VmJ00@006mJ001_FP80009_FP05001_FVmJ001_F@020002KcX00`00KcX0
0002KcX01P00JcY[>P00JcX0009[>P<0009[>P07001[>V/j001[>P00JcX00P0000Q[>P00JcY[>P00
JcX006/j0P000V/j00H006/J001[6P00JaX200001f/J001[6V/J001[6P00009[6P03001[6P00009[
6P03001W6P00009W6@<00007IaT006LIIaT006LI00000VLI0`0000YW6@00IaUW6@00IaT006LI001W
6@800006I_T006Ki001Vn@000VKi00<006Ki00000P0000ARn@00H_T0009Rn@05001Rn@00H_T00002
H_X300001V;J001RfP00G]X0009NfP0<001NfP00G]X005kJ001NfP00G]X005[J1@0002=J^P00F[X0
05Zj001F^P00E[X005Jj001F^P00E[X005Jj001BVP00DYX005:J001BVP00DYX005:J001BV`00CY/0
04jK00800007CY/004jK001>V`00CY/02@0000=:V`00BY/00P0001=:V`00BY/004ZK001:V`00CY/0
04jK001>V`00CY/004jK001>V`0200003djK001>V`00CY/004jK001>V`00CY/004jK001>^`0E0000
5E:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0J00004U;K001Bf`00D]/0
05;K001Bf`00D]/005;K001Bf`00D]/001aoo`03001oogoo04=oo`00EGoo00<007ooOol0H7oo01@0
05;L001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`005;L0P0000mBg000D]`005;L001Bg000
D]`005;L001Bg000D[`00P0000mB_000D[`005:l001B_000D[`005:l001B_000C[`00P0000e>_000
C[`004jl001>_000C[`004jl001>_00200001DZl001:W000BY`00`0001a6W000AY`004JL000a=000
AKD004gf001B5P00DQH005HF001F=P00ESH005Hf001F=P00ESH0009F=P0@001F=P00ESH005Hf001F
=P00FSH005Xf001JEP00GUD50004Oa400`00Oa9o4P02Oa800`00Oa9o4P0200000gla000000070000
0gmC001oM003Og@00`00OgEoM@02OgD01@00NeEkEG]E00000W]f00@007]FNeH0009kEP06001kEW]F
001gE`000gMG00<007MGMeL00WMG00<007MG00000WMG00D007=GLeMcE`0000=c>004001c>7<h0003
LcP01@00LcQc>7<h00000W<h00P006lhKcP006lh001_>0000Vlh00@006lhKcP0009_>@04001_>Fli
0003KcT01000KcU_>@000VlI00@006/IJaT0009[6@07001[6F/I001[6@00JaT00P000V/I00@006/I
JaT0009[6@06001[6F/I001[6@000V/I00@006/I0000009[6@07001[6F/I001[6@00JaT00P000V/I
00L006/IJaT006/I001[6@020002JaT02000JaU[6@00JaT006/I0002JaT01P00JaU[6@00JaT0009Z
n@03001Zn@00009Vn@07001VnFKi001Vn@00I_T00P000VKi00<006Ki00000VKi0P000VKi00<006Ki
00000V;i00<006;i00000V;I00H006;I001Rf@00H]T50002G]T02@00G]T005jj001J^P00F[X00002
F[X01000F[X005Jj0P0000eFVP00DYX005:J001BVP00DYX004jJ001>NP0200001DYj001:N`00BW/0
0P0000A6F`000012F`@00005?U/003hk000n>`0300000cXk00000002000013Xk000003Hk0P0000@f
>`00000f>`800003=S/003Hk00800004=S/00000=S`20000138l0000038l0P0000@b?000000b7080
0004;Q`00000;Q`200001BXL000000009O`00P0000DQo000000001gK00@000035K/0000000800003
4K/0000000<000042I/000004M`400001R9N000002jo000fg`800097?`06001??`00Del005]n1000
0V=m00D006MmIgd006NL00800005Jg`006]kJg/00002Jg/00`00Kg/00003Kg/01000KgX000000Vmj
00H006mjKgX006mj0003KeX01P00KeY_FP00KeX0009_FP04001_FVmJ0002KeX01000KeY_FP000VmJ
00<006mJ00000Vlj00<006ljKcX00`000V/j00<006/j00000V/j00H006/jJcX006/j0002JcX01000
JcX000000V/j0P000V/j00H006/j000006/j0002JcX00`00JaX00002JaX00`00JaX00002JaX00`00
JaX00002JaX30002JaX01@00JaX006LJ00000VLI00<006LJ00000VLI00<006LI00000VLI0`0000UW
6@00IaUW6@00IaT006LI00000VLI00L006Ki001Vn@00I_T00002I_T01`00I_T006Ki001Vn@00009R
n@07001Rn@00H_T006;i00000V;i0`0000ARnP00H]X0009RfP0>001NfP00G]X005kJ001NfP00G]X0
05kJ001NfP<00004F[X005Zj0002F[X2000075Zj001F^UJj001F^P00E[X005Jj001F^P00E[X005:J
001BVP00DYX005:J001BVP00DYX005:K0P0000M>V`00CY/004jK001>V`0200002DjK001>V`00CY/0
04jK001>V`0700000dZK001:V`0200005DZK001>V`00CY/004jK001>V`00CY/004jK001>V`00CY/0
04jK001>V`0200006djK001>V`00CY/004jk001>^`00C[/004jk001>^`00C[/004jk001B^`00D[/0
05:k001B^`0G00002E:k001B^`00D[/005:k001B^`0300002E:k001B^`00D[/005;K001Bf`020000
35;K001Bf`00D]/005;K001Bf`00D]/0009Bf`07001Bf`00D]/005;K000077oo00<007ooOol0@Woo
001FOol00`00Oomoo`1POol04`00D]`00000D]`005;L001Bg000D]`005;L001Bg000D]`005;L02h0
0003C[`004jl00800005B[`004ZL001:W00200001DJL0016W000AY`00P0000ha=000AKD004gf001B
5P00DQH005HF001F=P000UHf018005Hf001F=P00ESH005Hf001F=P00ESH005Hf001F=P00FSH70000
15KK001Ff`0017lA00<007lBOa800WlB00@007lBOa9o4P80009oC`05001oLGmaOg400002Og<30003
Og@00`00OgEoM@02OgD20002NeD01`00NgIkMW]f001kEP0000=kEP03001kEP00009gE`05001gE`00
MeL00004MeL01@00MeMgEgMG00000g=G00T007<hLcQc>000LcP007<h00000g<h00@007<h000000=c
>004001_>6lh0002KcP01@00KcQ_>000KcP00P000fli00D006liKcT006li0080009_>@05001_6FlI
001[6@020002JaT01000JaU[6@000V/I00@006/IJaT0009[6@04001[6@00JaT20002JaT01000JaU[
6@000V/I00<006/I00000V/I00@006/IJaT0009[6@03001[6@00009[6@04001[6F/I0002JaT00`00
JaT00002JaT01000JaU[6@000V/I0P000V/I00L006/IJaT006/I001Zn@020002J_T01P00I_UVn@00
I_T0009Vn@03001Vn@00009Vn@07001VnFKi001Vn@00I_T00`000VKi00<006;i00000V;i00H006;I
001Rf@00H]T2000036;I001Nf@00G]T005kI001Nf@00G[X0009J^P08001J^P00F[X005Zj001F^P80
000?EYX005:J001BVP00DYX005:J001>VP00CWX004ij00800003BW/004Yk00800003AU/004IK0080
0003@U/0049K00800005?S/003hk000n>`0400000cXk0000000200000cHk000f>`02000013Hk0000
03Hk0P0000<f>`00=S/00P0000@f?000000f?0800004<S`00000<S`20000138l000002hL0P0000@^
7000000^70<00004:Q`000009O`200001B7k000000007M/0100000<E^`0000000`0000<9V`003K/0
0P0000@=^`00000Eo@@00003:Yh0000000@00003Acl0000000@00005Fgh005mnGgh00002Hgd01P00
Igd00000Ig`0009[O004001[N`00Jg/20002Kg/01`00Kg]_Nfmk001_NP0000=_NP06001_NVmj001_
NP000VmJ00@006mJ0000009_FP04001_FP00KeX20002KeX01@00KeY_FP00KeX00P000VmJ00<006lj
00000Vlj00H006/jJcX006/j0002JcX30002JcX01000JcY[>P000V/j00<006/j00000V/j00<006/j
00000V/j00<006/j00000V/j00<006/j00000V/J0`000V/J00<006/J00000V/J0`0000M[6P00JaY[
6P00JaX00002IaX300001fLJ001W6FLI001W6@00009W6@05001W6@00IaT00002IaT00`00IaT00002
IaT300002FKi001VnFKi001Vn@00I_T00002I_T20002I_T01`00H_T006;i001Rn@00009Rn@<00004
H_X006;j0002H]X02@00H]X005kJ001NfP00G]X00002G]X500000ekJ00000002F[X08P00F[X005Zj
001J^P00F[X005Jj001F^P00E[X005Jj001F^P00E[X005:J001BVP00DYX005:J001BVP00DYX005:K
0P0000U>V`00CY/004jK001>V`00CY/00P0000e>V`00CY/004jK001>V`00CY/004jK001>V`070000
1DZK001>V`00CY/00P0001]>V`00CY/004jK001>V`00CY/004jK001>V`00CY/004jK001>V`00CY/0
04jk001>^`00C[/00P0002e>^`00C[/004jk001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00`00021B^`00D[/0
05:k001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`0077oo
00<007ooOol0@Woo001FOol00`00Oomoo`1QOolB00004U;L000005;L001Bg000D]`005;L001Bg000
D]`005:l001B_080000?D[`005:l001B_000D[`005:l001B_000C[`004jl00800009C[`004jl001>
_000C[`004jl00T00007BY`004ZL0016W000AY`00`0000Pa=000AKD004gf001B5P000U8F018005HF
001F=P00ESH005Hf001F=P00ESH005Hf001F=P00ESH700001UKK001Ff`00E]/0009Ff`03001Ff`00
00=o4@03001o4WlB009o4P05001o4WlBOa800003Odl01@00Og5oLGma00000gmc00<007md00000P00
17me00H007]fNgH007]E0004NgH00`00NeIkEP03NeH01`00MeMgEgMG001gE`00009gE`05001gEgMG
MeL00004MeL01@00LeL007=H00000g<h00@007<hLcP000Ac>004001c>7<h0002LcP01000KcP00000
0flh00@006lhKcP0009_>@04001_>Fli0003KcT01000KcU_>@000Vli00@006lIKaT0009[6@07001[
6F/I001[6@00JaT00P000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01000JaT006/I0P000V/I
00L006/IJaT006/I001[6@020002JaT01`00JaU[6@00JaT006/I0080009[6@07001[6F/I001[6@00
JaT00P0000Q[6@00JaU[6@00JaT006/I0P000V[i00<006[i00000VKi00@006Ki001Vn@80009Vn@03
001Vn@00009Vn@05001Vn@00I_T00002I_T01@00I_T006;i00000V;i00@006;I001Rf@800004H]T0
06;IH]T2000015kI001Nf@000UkI010005jj001J^P00F[X005Zj001J^P00E[X005Jj001FVP80000;
DYX005:J001BVP00CYX004ij001>NP0200001DYk001:N`00AW/00P0000E6F`00@U/0049K00800006
@U/00000?S/003hk0P0000Lj>`00000003Xk000j>`0200000cHk000f>`02000013Hk000003Hk0P00
00<f>`00=S/00P0000@f?000000f?0800004<S`00000<S`200001c8l00000000;Q`002hL00800005
;Q`00000000Uo00200001BGl000000007M/00`0000<If`0000000P0000<A^`000000100000@Ag000
000Ag08000056Sd00000000ZWP02000023[o00137`00Acl004lo0002Deh00`00Fgh00002Ggh01P00
Hgd00000Hgd0009WO004001[O000Jg/20002Jg/01@00Kg]_N`00Kg/00P000Vmj00D006mjKgX006mj
0080009_NP04001_FVmJ0002KeX00`00KeX00002KeX01000KeY_FP000VmJ00@006mJKeX0009_FP03
001_FP00009_>P<0009[>P03001[>V/j00<0009[>P07001[>V/j001[>P00JcX00P000V/j00H006/j
001[>P00JcX20002JcX00`00JcX00002JcX30002JaX01@00JaX006/J00000V/J00<006/J00000V/J
00<006/J00000V/J0`0000MW6P00IaYW6P00IaT00002IaT300001fLI001W6FLI001W6@00009W6@<0
000<IaT006KiI_T006Ki001Vn@00I_T006Ki0P0000AVn@00I_T0009Rn@80009Rn@<00004H_X006;j
0002H_X01`00H]X006;J001NfP00009NfP03001NfP000080000eG]X005kJ001NfP00F]X005Zj001J
^P00F[X005Zj001J^P00E[X005Jj001F^P00E[X005Jj001F^P00DYX005:J001BVP00DYX005:J001B
VP00DY/004jK001>V`00CY/004jK001>V`0200001djK001>V`00CY/004jK0080000;CY/004jK001>
V`00CY/004jK001>V`0900001DjK001>V`00CY/00P0003m>V`00CY/004jK001>V`00CY/004jK001>
V`00C[/004jk001>^`00C[/004jk001>^`00C[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P0002AB^`00D[/005:k001B
^`00D[/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K000L
Ool00`00Oomoo`12Ool005Moo`03001oogoo061oo`0B001Bg000001Bg000D]`005;L001Bg000D]`0
05;L001Bg0000U;L0P0000mBg000D]`005;L001Bg000D]`005;L001B_000D[`00P0000mB_000D[`0
05:l001B_000D[`005:l001>_000C[`00P0000M>_000C[`004jl001>_00200000djl001>_0020000
0dZl001:W00600000dJL0016W00200005C4d0015]@00COH0058F001B5P00EQH005Hf001F=P00ESH0
05Hf001F=P0700001UKK001Ff`00E]/0009Ff`09001Ff`00E]/005KK001Ff`0000=o4@03001o4WlB
009o4P05001o4WlBOa800003Odl01000Og5oL@0017mc00@007mdOgAoM080009oM@03001kMW]f009k
MP8000AkMP8000AkEP03001gEgMG009gE`03001gEgMG009gE`05001gE`00MeL00004MeL01@00LeQc
F7=H00000W<h00D007<hLcQc>000009c>08000=c>004001c>7<h0002KcP01@00KcQ_>000KcP00P00
0fli00D006liKcT006li0080009_>@05001_>Fli001_6@020002JaT01000JaU[6@000V/I00@006/I
JaT0009[6@04001[6@00JaT20002JaT01000JaU[6@000V/I00H006/IJaT006/I0002JaT01000JaU[
6@000V/I00<006/I00000V/I00@006/IJaT0009[6@03001[6@00009[6@04001[6F/I0002JaT20002
JaT01P00JaU[6@00J_T0009Zn@07001ZnF[i001Vn@00I_T00P000VKi00<006Ki00000VKi00@006Ki
001Vn@<0009Vn@03001Vn@00009Rn@04001Rn@00H]T2000026;I001RfF;I001Rf@00G]T20002G]T0
2P00G]T005jj001J^P00F[X005Zj5P0000=:NP00BW/00P0000E6N`00AU/004IK00800003@U/0049K
00800003?U/0000000<00006>S/00000>S/003Xk0P0000Hj>`00000f>`00=S/2000013Hk000003Hk
0P0000<f>`00=S`00`0000<f?000=S`00`0000<b?000<S`00P0000Lb?000000002hL000^70040000
0bGl000Uo00200001BGl000000007M/00`0000<E^`0000000P0000<A^`004K/01@0000<Ag0005Od0
0P0000@RGP00000ZWP800008>_l004<O0017?`00Ccl0009CGP04001KOP00Ggh2000026=m001SOF=m
001WO000Jg`200000f]l001[N`02Jg/01000Kg/000000Vmk00D006mjKgX006mj0080009_NP04001_
NP00KeX20002KeX01000KeX006mJ0P000VmJ00D006mJKeX006mJ0080009_FP04001_FP00KcX20002
JcX02000JcY[>P00JcX006/j0002JcX01@00JcY[>P00JcX00P000V/j00<006/j00000V/j0`000V/j
00D006/j001[>P00009[>P03001[6P00009[6P03001[6P00009[6P<0009[6P03001[6P00009[6P<0
0007IaX006LJIaX006LJ00000VLI0`0000MW6P00IaUW6@00IaT00002IaT3000036LI001W6FLI001V
n@00I_T006Ki001Vn@800004I_T006Ki0002I_T01000H_T006;i0`0000eRnP00H_YRnP00H_X006;j
001RfP00H]X00002G]X500001UkJ001NfP00G]X0009NfP800006F[X005ZjF[X005Zj0P0000QJ^P00
E[X005Jj001F^P000UJj010005Jj001F^P00DYX005:J001BVP00DYX005:J001BVP800009CY/004jK
001>V`00CY/004jK0080000=CY/004jK001>V`00CY/004jK001>V`00CY/00P0000e>V`00CY/004jK
001>V`00CY/004jK001>V`0900001DjK001>V`00CY/00P0003]>V`00CY/004jK001>^`00C[/004jk
001>^`00C[/004jk001>^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k00<00009D[/005:k001B^`00D]/005;K
0080000<D]/005;K001Bf`00D]/005;K001Bf`000U;K00L005;K001Bf`00D]/0000GOol60013Ool0
05Qoo`03001oogoo061oo`0C001Bg000001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`00P00
01UBg000D]`005;L001Bg000D]`005;L001B_000D[`005:l001B_000D[`005:l001B_00200001E:l
001>_000C[`00P0000e>_000C[`004jl001>_000C[`004jl001>_002000024Zl000004ZL001:W000
AY`500003C4d0015]@00COH0058F001B5P00EQH005Hf00T00006E]/005KK001Ff`000UKK00/005KK
001Ff`00E]/005KK001Ff`00009Ff`03001Ff`00009o4@03001o4WlB009o4P05001o4WlBOa800002
Odl01@00Og5oLGma00000gmc00<007mdOg@00Wmd00D007me001oM@0000AkMP03001kMP00009kMP04
001kMW]f0002NeH00`00MeL00003MeL20004MeL01@00MeMgEgMG00000WMG0P000g=H00D007<h001c
>000009c>003001c>000009c>005001c>7<h001c>0020002KcP01@00KcQ_>6lh00000Vli00@006li
KcT000=_>@04001_>Fli0002KcT01000KcU_>@000V/I00L006/IJaT006/I001[6@020002JaT01@00
JaU[6@00JaT00P000V/I00L006/IJaT006/I001[6@020002JaT01`00JaU[6@00JaT006/I0080009[
6@07001[6F/I001[6@00JaT00P000V/I00L006/IJaT006/I001[6@020002JaT01P00JaT006/I001[
6@80009Zn@06001ZnF[i001Zn@000VKi00<006Ki00000VKi00H006KiI_T006Ki0002I_T01`00I_T0
06Ki001Vn@00009Vn@03001Rn@00009Rn@03001Rf@00009Rf@0@001Rf@00H]T005kI001Nf@00G]T0
05kI001N^P00F[X400001EZj001J^P00E[X00P0000mFVP00EYX005:J001BVP00DYX004jJ001>NP00
CWX01`0000E6F`00AU/0049K00800003@U/0049K00800003?U/003iK00<00006>S/00000>S/003Xk
0P0000Hj>`00000f>`00=S/2000013Hk000003Hk0P0000<f?000=S`00`0000<f?000=S`00`0000<b
?000<S`01P0000<^7000;Q`0100000<Uo0009O`00`0000DMf`00000001gL00@000035M/000000080
00034M`0000000<000035Od001Xm00800003:Wh0000000800009>_l004<O0017?`00Ccl005=N00@0
0008Ggh006=mHgd006=m001WO0800005Ig`006]lJg`00003Jg/00`00Jg/00003Kg/01P00KgY_NP00
KgX0009_NP04001_NVmj0002KeX01P00KeY_FP00KeX0009_FP04001_FVmJ0002KeX01P00KeY_FP00
KeX0009_FP03001[>P00009[>P06001[>V/j001[>P000V/j00@006/jJcX0009[>P03001[>P00009[
>P03001[>P00009[>P03001[>P00009[>P03001[>P00009[>P<0009[6P03001[6P00009[6P<00007
JaX006/JJaX006/J00000V/J00<006LJ00000VLJ00D006LJ001W6P00009W6@03001W6P00009W6P05
001W6@00IaT00002IaT01@00IaT006LI00000VLI00<006Ki00000VKi0`0000mVn@00I_UVn@00I_T0
06Ki001Rn@00H_T006;j00000V;j00T006;j001RnP00H_X006;J00000V;J0`0000INfP00G]X005kJ
0002G]X03000G]X005kJ001JfP00F[X005Zj001J^P80009J^P06001F^P00E[X005Jj5P0000M>V`00
CY/004jK001>V`0200004djK001>V`00CY/004jK001>V`00CY/004jK001>V`00CY/004jK0080000?
CY/004jK001>V`00CY/004jK001>V`00CY/004jK00T0000;CY/004jK001>V`00C[/004jk001>^`02
0000;Djk001>^`00C[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0300005e:k001B^`00D[/005;K001Bf`00
D]/005;K001Bf`00D]/005;K001Bf`00D]/02@0077oo00<007ooOol0@Goo001HOol00`00Oomoo`1P
Ool01P00D]`00000D]`0009Bg004001Bg000D]`2000015;L001Bg0000U;L0P0000mBg000D]`005;L
001Bg000D]`005;L001B_000D[`00P0000mB_000D[`005:l001B_000D[`005:l001>_000C[`00P00
00M>_000C[`004jl001>_00200000djl001>_00200001dZl001:W000BY`004ZL0080000;AY`004JL
000a=000AKD004gf001B5P07000025KK001Ff`00E]/005KK0002E]/02`00E]/005KK001Ff`00E]/0
05KK00000UKK00D005KK001Ff`00009Ff`04001Ff`000004Oa801@00Oa9o4WlB00000gm?00D007ma
Og5oL@0000=oL`05001oM7mdOg@00003OgD20003NgH01`00NgIkMW]f001kMP0000=kMP03001kEP00
009gE`03001gE`00009gE`05001gEgMGMeL00003MeL00`00MeL00002LeP01@00LeQcF7=H00000W<h
00D007<hLcQc>00000=c>005001c>7<hLcP00002KcP01000KcQ_>0000Vlh00D006liKcU_>@00009_
>@04001_>@000002KcT01@00KcU_>@00KcT00P000V/I00D006/IJaT006/I0080009[6@04001[6F/I
0002JaT00`00JaT00002JaT01000JaU[6@000V/I00@006/IJaT0009[6@04001[6@00JaT20002JaT0
1`00JaU[6@00JaT006/I0080009[6@07001[6F/I001[6@00JaT00P000V/I00<006/IJaT00P000V/I
00H006/IJaT006[i0002J_T01000J_T006Ki0P000VKi00<006Ki00000VKi00@006Ki001Vn@800004
I_T006Ki0002I_T01P00I_T006;i001Rn@80009Rf@05001Rf@00H]T00002H]T200001EkI001Nf@00
G]T0100000AJ^P00F[X0009J^P80000?E[X005Jj001FVP00EYX005:J001BVP00DYX004jJ00800006
CWX00000BW/004Yk100000M6F`00@U/0049K0012F`0300000ciK000nF`0500000cXk000j>`020000
13Xk000003Xk0P0000<f>`00=S/00P0000@f>`00000f?0800004=S`00000=S`200000cHl00000003
00001C8l000b?000;S`0100000<^70000000100000<Uo0009O`0100000@Mf`00000Mg0@000035M/0
000000<000034M`001Gm008000036Sd0029N00800003;Yh003KO00T00004Eeh005]N0002Ggh01000
Hgd006=m0P0000EWO000IgaWO000009[O004001[N`000002Jg/01@00Kg]_N`00KgX00P000Vmj00@0
06mj001_NP8000=_FP05001_FP00KeX00003KeX01000KeX006mJ0P000VmJ00<006mJKeX00`000V/j
00@006/jJcX0009[>P05001[>P00JcX00002JcX01000JcX000000V/j00<006/j00000V/j0`000V/j
00<006/j00000V/j0`000V/J00<006/J00000V/J0`0000M[6P00JaY[6P00JaX00002JaX300001fLJ
001W6VLJ001W6P00009W6P<00007IaX006LJIaX006LI00000VLI0`0000MW6@00IaUW6@00IaT00002
I_T3000016Ki001Vn@000VKi00H006Ki001Vn@00H_T30002H_X02@00H_X006;j001RnP00H_X00002
H]X300001UkJ001NfP00G]X0009NfP0@001NfP00G]X005kJ001JfP00F[X005Zj001J^P00F[X90000
4eJj001F^P00E[X005:J001BVP00DYX005:J001BVP00DYX005:K00`00005CY/004jK001>V`020000
4djK001>V`00CY/004jK001>V`00CY/004jK001>V`00CY/004jK0080000?CY/004jK001>V`00CY/0
04jK001>V`00CY/004jK00l0000YC[/004jk001>^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0200001E:k001B^`00D[/0
5`0000QBf`00D]/005;K001Bf`0077oo00<007ooOol0@Goo001IOol00`00Oomoo`1POol07@00D]`0
0000D]`005;L001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`00P0000mB
g000D[`005:l001B_000D[`005:l001B_000D[`00P0000eB_000C[`004jl001>_000C[`004jl001>
_00200001Djl001>_000C[`00P0000=:_000BY`00P0000E:W000AY`004JL00800003<C@0000000D0
0006E]/005KK001Ff`000UKK00/005KK001Ff`00E]/005KK001Ff`00009Ff`07001Ff`00E]/005KK
00000UKK00P005KK001Ff`00E]/005KK0P0017lB00D007lBOa9o4P0000=oC`05001oLGmaOg400003
Og<01000OgAoM00017me00<007]f00000W]f00<007]fNgH00W]f00<007]fNgH00g]f00<007MGMeL0
0WMG00<007MGMeL00WMG00D007MG001gE`0000=gE`03001cF7=H009cF004001cF7=H0003LcP01000
LcQc>00017<h00@007<hLcP0009_>008001_>6lh001_>000KcP0009_>@05001_>FliKcT00002KcT0
1000KcU_>@000Vli00@006liKcT0009[6@06001[6F/I001[6@000V/I00D006/IJaT006/I0080009[
6@07001[6F/I001[6@00JaT00P000V/I00@006/IJaT0009[6@03001[6@00009[6@04001[6F/I0002
JaT00`00JaT00002JaT01000JaU[6@000V/I00<006/I00000V/I00<006/IJaT00P0000=[6@000000
0V/I00L006[iJ_T006[i001Zn@020002I_T00`00I_T00002I_T01000I_T006Ki0P000VKi00X006Ki
001Vn@00I_T006Ki001Rn@80009Rf@05001Rf@00H]T00002H]T01`00H]T00000G]T005kI00800004
G]X005jj0002F[X02000F[X005Zj001J^P00E[X200003EJJ001FVP00DYX005:J001BVP00CYX004ij
00800003BW/004Yk00800003BW/004Ik00@00005@U/0049K0012F`0200001CiK00000000?S/00P00
00Dj>`00>S/003Xk00800004>S/00000>S/200000cHk000f>`02000013Hk000003Hl0`0000<f?000
=S`00`0000<b?00000000P0000Db?000000002hL00H00003:Q`00000008000049O`000008O`30000
1AgL000000005M/0100000<A^`000000100000<N7@0000000P0000<ZOP00;Yh00P0000Pno`00@al0
04/O001??`000UMN00H005]N001OOP00Hgd200001F=m001WO6Ml00000VMl00@006]l0000009[N`05
001[Nf]k001_N`020002Kg/01000KgX006mj0P000VmJ00D006mJKeX006mJ00800006KeX006mJKeX0
06mJ0P000VmJ00<006mJ00000VmJ00@006/jJcX0009[>P04001[>P00JcX200001F/j001[>V/j0000
0V/j00H006/jJcX006/j0002JcX30002JcX00`00JcX00002JcX300001f/j001[6V/J001[6P00009[
6P03001[6P00009[6P03001[6P00009[6P<0009W6P05001W6P00IaX00002IaX300001fLJ001W6VLJ
001W6P00009W6@<00007IaX006LIIaT006LI00000VLI0`0000AVn@00I_T0009Vn@06001Vn@00I_T0
06Ki0P0000IRnP00H_X006;j0002H_X01000H_X000000V;j0`0000ANfP00G]X0009NfP0@001NfP00
G]X005kJ001NfP00G]X005[J001J^P00F[X500009EZj001F^P00E[X005Jj001F^P00E[X005Jj001B
VP00DYX005:J001BVP00DYX005:J001BV`00DY/004jK001>V`00CY/004jK00X00003CY/004jK0080
000ECY/004jK001>V`00CY/004jK001>V`00CY/004jK001>V`00CY/004jK0080000ECY/004jK001>
V`00CY/004jK001>V`00C[/004jk001>^`00C[/004jk0380000ND[/005;K001Bf`00D]/005;K001B
f`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`0077oo00<007ooOol0@Goo001IOol0
0`00Oomoo`1POol03000D]`005;L001Bg000D]`005;L001Bg080000?D]`005;L001Bg000D]`005;L
001Bg000D]`005;L00800003D]`0000001@00007C[`004jl001>_000C[`00P0000U>_000C[`004jl
001:_000B[`00P0000=:W000BY`00P0000=6W00000000P0000IFf`00E]/005KK0002E]/02`00E]/0
05KK001Ff`00E]/005KK00000UKK00L005KK001Ff`00E]/00002E]/03000E]/005KK001Ff`00E]/0
05KK001Ff`@000Ao4P05001o4WlBOa800003Odl01000Og5oL@000gmc00D007mdOgAoM00000=oM@07
001kMW]fNgH007]f000017]f00<007]fNgH00g]f00<007MGMeL00WMG00<007MGMeL00gMG00D007MG
MeMgE`00009gE`03001cF7=H009cF005001cF000LeP00002LcP01@00LcP007<h00000g<h00D007<h
001c>000009_>004001_>6lh0003KcP01@00KcU_>@00KcT00P000Vli00D006liKcT006li0080009_
>@05001[6F/I001[6@020002JaT01000JaU[6@000V/I00H006/IJaT006/I0002JaT01000JaT00000
0V/I00L006/IJaT006/I001[6@020002JaT01`00JaU[6@00JaT006/I0080009[6@07001[6F/I001[
6@00JaT00P000V/I00P006/IJaT006/I001[6@000V/I00<006/I00000V[i00H006[iJ_T006Ki0002
I_T01P00I_UVn@00I_T0009Vn@03001Vn@00009Vn@08001Vn@00I_T006Ki001Vn@800007H_T006;I
H]T006;I00000V;I00H006;I001Rf@00G]T3000045kI001NfUkJ001N^P00F[X005Zj001J^P00F[X0
05Jj0P0000mFVP00EYX005:J001BVP00DYX004jJ001>NP00CWX00P0000E:N`00BW/004Yk00800003
AU/004IK00800003@U/0049K00800003?U/003iK00<00008?S/00000>S/003Xk000j>`800004>S/0
0000>S/200000cHk000f>`0300000cHl000f?00300000cHl000f?00300000c8l00000003000012hl
000002hL1P0000<Z700000000P0000<Qo00000000P0000<Mg0007M`00`0000<Ef`0000000P0000<A
g0005O`0100000<RG@009Wh00P00014^WP00=]l003ko00137`00Bal004lo001GGP00Feh005mn0080
0005Ggd006=mHgd00002Ig`01P00Ig`00000Jg`000=[N`06001[Nf]k001[N`000Vmk00H006mjKgX0
06mJ0003KeX01P00KeY_FP00KeX0009_FP06001_FVmJ001_FP000VmJ00<006mJKeX00`000V/j00D0
06/jJcX006/j0080009[>P06001[>P00JcX006/j0P000V/j00<006/j00000V/j00<006/j00000V/j
00<006/j00000V/j00<006/j00000V/j00<006/J00000V/J0`000V/J00D006/J001[6P00009[6P03
001W6P00009W6P03001W6P00009W6P<00007IaX006LJIaX006LJ00000VLJ0`0000UW6P00IaYW6P00
IaT006LI00000VLI00D006Kj001Vn@00009Vn@05001Vn@00I_T00002I_T01`00H_X006;j001RnP00
009RnP06001RnP00H_X006;j0`0000ARfP00G]X0009NfP09001NfP00G]X005kJ001NfP00009NfP03
001NfP0000@00003F[X005Zj0080009J^P06001F^P00001F^P000UJj010005Jj001F^P00DYX005:J
001BVP00DYX005:J001BVP800009DY/004jK001>V`00CY/004jK00800007CY/004jK001>V`00CY/0
1`0000E>V`00CY/004jK0080000ICY/004jK001>V`00CY/004jK001>V`00CY/004jK001>V`00CY/0
04jK001>V`00CY/00P0003=>^`00C[/004jk001>^`00C[/004jk001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
0P00011B^`00D[/005:k001B^`00D]/005;K001Bf`00D]/0009Bf`0C001Bf`00D]/005;K001Bf`00
D]/005;K001Bf`00D]/005;K000077oo00<007ooOol0@7oo001JOol00`00Oomoo`1OOol02000D]`0
05;L001Bg000D]`H00003e;L001B_000D[`005:l001B_000D[`005:l001B_00200001E:l001>_000
C[`03`0000M:_000B[`004ZL001:W00200001TJL0016W000E]/0009Ff`0;001Ff`00E]/005KK001F
f`00E]/00002E]/01`00E]/005KK001Ff`00009Ff`0<001Ff`00E]/005KK001Ff`00E]/005KK1P00
00AFf`00E]/000Ao4P05001o4WlBOa800003Odl00`00Og4000090003OgD00`00NgIkMP02NgH20003
NgH00`00NgL00003NgH00`00MgL00002MeL00`00MeL00004MeL02@00MeMgEgMG001gE`00MeP00004
LeP01@00LeQcF7=H00000W<h00D007<hLcQc>00000=c>004001c>7<h0002KcP01000KcP000000flh
00D006liKcU_>@00009_>@04001_>Fli0002KcT01000KcU_>@000Vli00@006/IJaT0009[6@03001[
6@00009[6@04001[6@000002JaT01000JaU[6@000V/I00<006/I00000V/I00@006/IJaT0009[6@06
001[6F/I001[6@000V/I00@006/IJaT0009[6@03001[6@00009[6@04001[6F/I0002JaT00`00JaT0
0002JaT00`00JaU[6@020002JaT01`00JaU[6@00J_T006[i0080009Vn@03001Vn@00009Vn@04001V
n@00I_T20002I_T02000I_T006Ki001Vn@00I_T200001f;i001RnF;i001Rf@00009Rf@06001Rf@00
H]T006;I0`0000eNf@00G]UNf@00G]X005jj001J^P00F[X00002F[X200003eJj001F^P00EYX005JJ
001BVP00DYX005:J001>VP02000034ij000004Yk001:N`00BW/004Ik0016F`800003@U/0000000<0
0003?U/003iK00800004?S/00000>S/400000cXk000j>`02000013Xk000003Xk0P0000<f>`00=S/0
0`0000<f?00000000`0000@f?000000b?0800003<S`0000000<00004;Q`00000;Q`3000012XL0000
02XL100000<Qo0008O`00P0000@Mg000000Ig08000035M/001WL00@000056Qd00000000RG@020000
0bjN0000000200001cko00137`00Bal004lo00H00005Geh005mmGgd00002Hgd01P00Ig`00000Ig`0
009[O005001[Nf]k001[N`020002Jg/01000Kg/006mj0P000VmJ00D006mJKeX006mJ0080009_FP04
001_FP00KeX20002KeX01000KeX006mJ0P000V]J00@006/jJcX0009[>P03001[>P00009[>P04001[
>P00JcX20002JcX00`00JcX00002JcX30002JcX00`00JcX00002JcX30002JcX00`00JcX00002JaX3
0002JaX00`00JaX00002JaX00`00JaX000020002IaX00`00IaYW6P020002IaX00`00IaX00002IaX0
1@00IaX006LJ00000VLJ00D006LJ001W6P00009W6P03001W6@00009W6@<00009I_X006KiI_T006Ki
001Vn@00009Vn@<0000CH_X006;jH_X006;j001RnP00H_X006;j001RnP00H_X006;J00000UkJ00T0
05kJ001NfP00G]X005kJ00000UkJ1@0002mJfP00F]X005Zj001J^P00F[X005Zj001F^P00E[X005Jj
001F^P00E[X005Jj001BVP00DYX005:J001BVP00DYX005:J001BV`00DY/004jK001>V`00CY/004jK
00800005CY/004jK001>V`0200001DjK001>V`00CY/02@0000E>V`00CY/004jK0080000SCY/004jK
001>V`00CY/004jK001>V`00CY/004jK001>V`00CY/004jk001>^`00C[/004jk001>^`00C[/005:k
001B^`0200009E:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k00<0000PD[/005:k001Bf`00D]/005;K001Bf`00D]/005;K
001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/001aoo`03001oogoo041oo`00FWoo00<007oo
Ool0H7oo1`0000EBg000D]`005;L0080000?D]`005;L001Bg000D]`005;L001Bg000D]`005;L0080
009Bg00>001B_000D[`005:l001B_000D[`005:l001B_0800003D[`004jl00800007C[`004jl001>
_000C[`00P0000E>_000C[`004jl00T00003AY`004JL00800008E]/005KK001Ff`00E]/0009Ff`05
001Ff`00E]/00002E]/03000E]/005KK001Ff`00E]/005KK001Ff`P00006E]/005KK001Ff`000UKK
00<005KK00000glB00D007lBOa9o4P00009oC`05001oL@00Nm@00003OiD01@00OiEoU@00NiH00P00
00=oM@00NgH00g]f00H007]f000007]f0002NgL00`00NgH00003MgL00`00MeL00002MeL01P00MeMg
E`00MeL000=gE`05001gF7MHMeP00003LeP01P00LeQcF7=H001c>08000Ac>004001c>0000003LcP0
1000KcQ_>0000Vlh00H006lhKcQ_>000KcT20002KcT01@00KcU_>@00KcT00P000Vli00D006liKcT0
06/I0080009[6@04001[6F/I0002JaT01000JaU[6@000V/I00@006/I001[6@80009[6@07001[6F/I
001[6@00JaT00P000V/I00L006/IJaT006/I001[6@020002JaT01`00JaU[6@00JaT006/I0080009[
6@07001[6F/I001[6@00JaT00P0000M[6@00JaU[6@00JaT00002J_T01P00I_UVn@00I_T0009Vn@04
001Vn@00I_T20002I_T00`00I_T00002I_T20002I_T00`00I_T00002H_T00`00H_T00002H]T01P00
H]T006;I001Rf@800003H]T00000009Nf@07001Nf@00G]X005jj00000UZj00@005Zj001J^P80000?
E[X005Jj001FVP00EYX005:J001BVP00DYX004jJ00800005CWX004Yk001:N`0200001dYk0016N`00
AU/004IK00800003@U/0049K00<00003?U/003hk00800006?S/00000>S/003Xk0P0000<j>`00>S/0
0P0000@j>`00000j>`800004=S/00000=S`300000cHl000000020000138l0000038l0P0000@b?000
000^?0800004;Q`00000;Q`3000012XL000002HL0P0000<Qo0000000100000@Ig000000Io0@00003
6O`00000008000047Qd000008Ud300000c:n000jg`07000014ln001GGP000U]N00<005mN00000Umm
00H006=m000006Ml0002Ig`01@00Jga[O000Jg/00P000V]k00@006]k001_N`80009[F`05001_FVmJ
001_FP020002KeX00`00KeX00002KeX01P00KeY_FP00KeX0009_FP03001[FP0000=[FP04001[>P00
JcX20002JcX00`00JcX00002JcX00`00JcX00002JcX00`00JcY[>P030002JcX00`00JcX00002JcX3
0002JcX00`00JcX00002JcX01@00JaX006/J00000V/J00P006/JJaX006/J001[6P000VLJ00<006LJ
00000VLJ00<006LJ00000P000VLJ00D006LJ001W6P00009W6P<0009W6P05001W6P00IaX00002IaT3
00002FKj001VnVKj001Vn@00I_T00002I_T3000036;j001RnV;j001RnP00H_X006;j001RnPD0009R
nP09001RfP00G]X005kJ001NfP00009NfP03001NfP0000800008G]X005kJ001JfP00F]X0009J^P0Y
001J^P00001J^P00E[X005Jj001F^P00E[X005Jj001F^P00DYX005:J001BVP00DYX005:J001BVP00
DY/005:K001>V`00CY/004jK001>V`0200001DjK001>V`00CY/00P0000e>V`00CY/004jK001>V`00
CY/004jK001>V`0900001DjK001>V`00CY/00P0003M>V`00CY/004jK001>V`00CY/004jK001>^`00
C[/004jk001>^`00C[/004jk001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`020000;5:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K000LOol0
0`00Oomoo`10Ool005]oo`03001oogoo05moo`07001Bg000D]`005;L00000U;L00@005;L001Bg080
000?D]`005;L001Bg000D]`005;L001Bg000D]`005;L0080000?D]`005:l001B_000D[`005:l001B
_000D[`005:l0080000=D[`004jl001>_000C[`004jl001>_000C[`00P0000=>_000C[`00P0000M:
_000B[`004ZL001:W00600002eKK001FfeKK001Ff`00E]/005KK00000UKK00X005KK001Ff`00E]/0
05KK001Ff`H00008E]/005KK001Ff`00E]/0009Ff`09001Ff`00E]/005KK001Ff`0000=o4P05001o
4WlBOa800002Odl200000g_D001oU@02OiD01000OiEoU@0017^F0P000g]f00<007]fNgH00W]f00<0
07]gNgL00W]g0P0017Mg00<007MGMeL00WMG00<007MG00000WMG00@007MGMeL000AgF005001cF000
LeP00003LeP01000LcQc>00017<h00@007<hLcP0009c>004001_>0000003KcP00`00KcQ_>0020002
KcT01000KcU_>@000Vli00@006liKcT0009_>@04001_>Fli0002JaT01`00JaU[6@00JaT006/I0080
009[6@04001[6F/I0002JaT01P00JaU[6@00JaT0009[6@04001[6@000002JaT01`00JaU[6@00JaT0
06/I0080009[6@07001[6F/I001[6@00JaT00P000V/I00H006/IJaT006/I0002JaT00`00JaU[6@02
0002JaT01000JaT006[i0P000VKi00H006KiI_T006Ki0002I_T00`00I_T00002I_T01`00I_UVn@00
I_T006Ki00<0009Vn@03001Rn@00009Rn@06001Rf@00H]T006;I0P0000YRf@00H]T005kI001Nf@00
G]T0009NfP0<001N^P00F[X005Zj001J^P00F[X005Jj0P0000mFVP00EYX005:J001BVP00DYX004jJ
001>NP00CWX00P0000M:N`00BW/004Yk0016N`0200000dIK0012F`0200000d9K00000002000013iK
000003hk0P0000<j>`00>S/00P0000Hj>`00000j>`00>S/300000cXk000f>`0300000cHl000f?003
00000cHl000000020000138l0000038l0P0000@b?000000^70800005;Q`00000000Z7002000012XL
000002HL0`0000<Qo00000000`0000@Ig000000Io0@000036O`00000008000048Sd000009Wh20000
0c:n000jg`02000014LO001;7`000Tln00<005MN00000U]N00@005mN001OO@800005Hgd006MlIg`0
0002Ig`01P00Jg`00000Jg/0009[N`06001[Nf]k001[N`000f]K00H006mJKeX006]J0002KeX01000
KeX006mJ0P000VmJ00@006mJ001_FP80009[FP05001[FV]J001[>P020002JcX00`00JcX00002JcX3
0002JcX00`00JcX00002JcX00`00JcX00002JcX00`00JcX00002JcX00`00JcX00002JcX02000JcY[
>P00JcX006/J0002JaX01`00JaY[6P00JaX006/J00<0009W6P08001W6VLJ001W6P00IaX0009W6P03
001W6P00009W6P03001W6P000080009W6P05001W6P00IaX00002IaX300002FLJ001VnVKj001VnP00
I_T00002I_T3000036Kj001RnV;j001RnP00H_X006;j001RnP80000>H_X006;j001RnP00H_X006;J
001NfP00G]X0009NfPD00006G]X005kJ001NfP000U[J00`005[J001J^P00F[X005Zj001J^P00E[X2
00009EJj001F^P00E[X005Jj001BVP00DYX005:J001BVP00DYX005:J001BV`00DY/004jK001>V`00
CY/004jK001>V`00CY/004jK00800005CY/004jK001>V`0200003djK001>V`00CY/004jK001>V`00
CY/004jK001>V`0900002DjK001>V`00CY/004jK001>V`020000<djk001>^`00C[/004jk001>^`00
C[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`02000045:k001B^`00D[/005:k001Bf`00D]/005;K001Bf`00
0U;K01<005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0000KOol00`00Oomoo`10Ool0
05aoo`03001oogoo05moo`0<001Bg000D]`005;L001Bg000D]`005;L0P0000QBg000D]aBg000D]`0
05;L0P0001MBg000D]`005;L001Bg000D]`005:l001B_000D[`005:l001B_000D[`005:l00800005
D[`004jl001>_00200001Djl001>_000C[`00P0000]>_000C[`004jl001:_000B[`004ZL00<00003
AY`004JL0080000:E]/005KK001Ff`00E]/005KK0002E]/01000E]/005KK1P0000IFf`00E]/005KK
0002E]/03@00E]/005KK001Ff`00E]/005KK001Ff`00009Ff`03001Ff`00009o4P05001o4WlBOa80
0002Odl00`00Nm@00003OiD01@00OiEoUGnE000017^F00H007^G000007]f0004NgH20003NgL00`00
MgL00003MgL20004MeL02@00MeMgEgMG001gE`00MeP00004MeP01@00LeQcF7=H00000W=H00D007<h
LcQc>00000=c>004001c>7<h0003LcP01000KcQ_>0000Vlh00D006lh001_>@00009_>@05001_>Fli
001_>@020002KcT01@00KcU_>@00KcT00P000V/I00@006/IJaT0009[6@04001[6F/I0002JaT01000
JaT006/I0P000V/I00@006/IJaT0009[6@03001[6@00009[6@04001[6F/I0002JaT00`00JaT00002
JaT01000JaU[6@000V/I00<006/I00000V/I00L006/IJaT006/I001[6@020002JaT01P00JaT006/I
001[6@80009Vn@03001Vn@00009Vn@04001Vn@00I_T20002I_T00`00I_T00002I_T01@00I_T006Ki
00000VKi00<006Ki00000V;i00H006;i001Rf@00H]T2000016;I001Rf@000V;I0P0000iNf@00G]UN
f@00G]X005jj001J^P00F[X005Zj5`0000U:N`00BW/004Yk0016N`00AU/00P0000=2F`00@U/00`00
00=2F`0000000P0000<n>`00?S/00P0000<j>`00>S/00P0000Hj>`00000j>`00>S/300000cHk000f
?003000013Hl000003Hl0P0000Hf?000000b?000<S`20000138l0000038l0P0000@^7000000^70<0
0004:Q`000009Q`200000bHL0000000200001R7l000001WL000Io0<000056M`00000000N7@040000
0bIN0000000200000c:n000jg`02000014LO001;7`000Tln00@005MN001KGP@00005Ged006=mHgd0
0002Ig`01P00Ig`00000Ig`0009[N`04001[N`00Jg/20002Jg/01@00Je][F`00KeX00P000V]J00@0
06mJ001_FP80009_FP03001_FP00009_FP04001[FV]J0002JeX01P00JeY[FP00JcX0009[>P04001[
>P00JcX20002JcX00`00JcX00002JcX30002JcX01@00JcY[>P00JcX00`000V/j00L006/jJcX006/j
001[>P02000016/J001[6P000V/J00P006/JJaX006LJ001W6P000VLJ00@006LJ001W6P<0009W6P0:
001W6VLJ001W6P00IaX006LJ0002IaX00`00IaYW6P020002IaX01@00IaX006LJ00000VKj00<006Kj
00000VKi0`0000AVnP00I_X0009RnP05001RnP00H_X00002H_X02@00H_X006;j001RnP00H_X00002
H_X2000015kJ001NfUkJ0`0000INfP00G]X005kJ0002G]X0;P00G]X005[J001JfP00F[X005Zj001J
^P00F[X005Jj001F^P00E[X005Jj001F^P00E[X005:J001BVP00DYX005:J001BVP00DYX005:K001B
V`00CY/004jK0P0000U>V`00CY/004jK001>V`00CY/00P0000]>V`00CY/004jK001>V`00CY/004jK
0080000?CY/004jK001>V`00CY/004jK001>V`00CY/004jK00d0000?C[/004jk001>^`00C[/004jk
001>^`00D[/005:k0080000UD[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00`0000]B^`00D[/005;K001Bf`00D]/005;K
01D001aoo`03001oogoo03moo`00G7oo00<007ooOol0H7oo00`005;L001Bg000D]`005;L001Bg000
D]`200003e;L001Bg000D]`005;L001Bg000D]`005;L001Bg0020002D]`01P00D[`005:l001B_080
000;D[`005:l001B_000D[`005:l001>_00200001djl001>_000C[`004jl00800005C[`004jl001>
_00200001DZl001:W000BY`00P0000e6W000000005KK001Ff`00E]/005KK001Ff`0700001UKK001F
f`00E]/0009Ff`0;001Ff`00E]/005KK001Ff`00E]/00002E]/01`00E]/005KK001Ff`00009Ff`04
001Ff`000003Oa801P00OdmoCgm?001ke0H0009oU@05001kUW^FNiH00004NiL20003NgH01P00NgMk
M`00NgL000=gM`03001gM`00009gM`05001gEgMGMeL00004MeL01@00MeQgF7MH00000gMH00T007=H
LeQcF000LeP007=H00000g<h00D007<h001c>000009c>004001c>7<h0002KcP01@00KcQ_>6lh0000
0fli00@006liKcT0009_>@04001_>Fli0002KcT01000KcU_>@000V/i00L006/IJaT006/I001[6@02
0002JaT01@00JaU[6@00JaT00P000V/I00L006/IJaT006/I001[6@020002JaT01`00JaU[6@00JaT0
06/I0080009[6@07001[6F/I001[6@00JaT00P000V/I00L006/IJaT006/I001[6@020002JaT00`00
JaU[6@020002JaT00`00I_T00002I_T01`00I_UVn@00I_T006Ki0080009Vn@03001Vn@00009Vn@04
001Vn@00I_T30002I_T00`00I_T00002H_T01000H_T006;I0P0001ARf@00H]URf@00H]T006;I001N
f@00G]T005kI001NfP00G[X005Zj1000019J^P00001F^P00E[X005Jj001FVP00DYX005:J001BVP00
CYX200000dij001>N`0400002DYk0016N`00AU/004IK0012F`0200001d9K00000000?U/003iK0080
0005?S/003Xk000j>`02000013Xk000003Xk0P0000Hj>`00000j>`00=S/6000013Hl000003Hl0P00
00Hf?000000b?000<S`20000138l0000038l0P0000D^7000000002hL00800004:Q`000009Q`30000
1B7l000000007O`00P0000<Io0006O`00`0000DIo0000000028m00@00003;Wh003:N00H00005Aal0
04/O001??P04000015]N001OG@000UmM00D006=mHgd006Ml00800008Ig`006MlIg`006]k001[N`80
009[N`05001[Nf]k001[F`020002Je/00`00JeX00002KeX00`00JeX00003KeX00`00KeX000020002
JeX01@00JeY[FP00JeX00P000V/j00<006/j00000V/j00<006/j00000V/j00@006/j001[>P80009[
>P03001[>P00009[>P03001[>P00009[>P03001[>P00009[>P08001[>V/j001[6P00JaX0009[6P04
001[6P00JaX20002IaX20002IaX02000IaYW6P00IaX006LJ0002IaX00`00IaX00002IaX20002IaX0
1`00IaYW6P00IaX006LJ00<0009W6P05001W6P00I_X00002I_X3000016Kj001VnP000VKj00D006;j
001RnP00009RnP<0000>H_X006;jH_X006;j001RnP00H_X006;J001NfP<00006G]X005kJ001NfP00
0UkJ01@005kJ001NfP00F]X005[J001J^P00F[X005Zj001J^P00E[X005Jj7`0000Q>V`00001>V`00
CY/004jK0P0001E>V`00CY/004jK001>V`00CY/004jK001>V`00CY/004jK001>V`00CY/00P00015>
V`00CY/004jK001>V`00CY/004jK001>V`00CY/004jk01<0000ID[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/06P0001ABf`00D]/005;K001Bf`00D]/005;K001B
f`00E]/005KK001Ff`0077oo00<007ooOol0?goo001MOol00`00Oomoo`1OOol05P00D]`005;L001B
g000D]`005;L001Bg000D]`005;L001Bg000D]`005;L0P0000mBg000D]`005;L001Bg000D]`005:l
001B_000D[`00P0000eB_000D[`005:l001B_000D[`004jl001>_00200002djl001>_000C[`004jl
001>_000C[`00P0000E:_000B[`004ZL00800006BY`00000AY`005KK200000MFf`00E]]Ff`00E]/0
0002E]/02`00E]/005KK001Ff`00E]/005KK00000UKK00L005KK001Ff`00E]/00002E]/02000E]/0
05KK001Ff`00E]/20003Oa800`00OdmoC`040002NmL00`00NkMk]`040002NiH00`00NiMkU`02NiL0
1P00NiL00000NgH000=kM`03001gMgMg00=gM`03001gMgMg009gM`05001gE`00MeL00003MeL00`00
MeQgF002MeP01@00MeP007=H00000g=H00D007=HLeQcF00000=c>004001c>7<h0002LcP01@00LcP0
06lh00000Vlh00@006lhKcP000=_>@05001_>Fli001_>@020002KcT01@00KcU_>@00KcT00P000V/i
00D006/IJaT006/I0080009[6@04001[6F/I0002JaT00`00JaT00002JaT01000JaU[6@000V/I00H0
06/IJaT006/I0002JaT01000JaT000000V/I00<006/I00000V/I00@006/I0000009[6@03001[6@00
009[6@06001[6F/I001[6@000V/I00<006/IJaT00P0000=[6@0000000VKi00H006KiI_T006Ki0002
I_T00`00I_T00002I_T01P00I_UVn@00I_T0009Vn@07001Vn@00I_T006Ki00000VKi00@006;i001R
n@80000BH]T006;IH]T006;I001Rf@00H]T005kI001Nf@00G]T005kJ100001=J^P00F[X005Zj001J
^P00E[X005Jj001F^P00EYX005:J001BVP0200001DjJ001>VP00CWX00P0000=:N`00BW/01P0000=6
F`00@U/00P0000I2F`000012F`00?U/2000023iK000003Xk000j>`00>S/2000013Xk000003Xk0`00
00Lj>`00=S/003Hl000f?004000013Hl000003Hl0P0000Hf?000000b?000<S`20000138l0000038l
0P0000D^7000000002XL008000049Q`000009Q`300001B7l000000007O`00P0000@Io000000Mo080
00056O`00000000V?@03000022in000003Jn000ng`00@_l5000015<n001G?P000U]N00<005mM0000
0UmM00H006=m000006=l0002Ig`01000Ig`006]k0P0000=[N`00Jg/00V]k00H006]kJg/006]K0002
Je/01000JeX006mJ0P000V]J00H006mJKeX006mJ0002JeX01000JeY[FP000V]J00H006/jJcX006/j
0002JcX30002JcX00`00JcX00002JcX00`00JcX00002JcX01000JcY[>P000V/j0P000V/j00L006/j
JcX006/j001[>P020002JaX01P00JaX006/J001[6P80000:IaX006LJIaX006LJ001W6P00IaX20000
16LJ001W6P000VLJ00@006LJ001W6P800004IaX006LJ0002IaX01@00IaX006LJ00000VLJ00D006LJ
001W6P00009VnP<00004I_X006Kj0002I_X01@00I_X006;j00000V;j0`0000iRnP00H_YRnP00H_X0
06;j001RnP00H_X006;J0`0000ANfP00G]X0009NfP0;001NfP00G]X005kJ001NfP00F]X00002F]X0
1000F[X005Zj200001eF^P00E[X005Jj001F^P00E[X005:J001BVP00DYX005:J001BVP00DY/005:K
001BV`00CY/004jK00X00005CY/004jK001>V`0200005djK001>V`00CY/004jK001>V`00CY/004jK
001>V`00CY/004jK001>V`00CY/00P0001]>V`00CY/004jK001>V`00C[/004jk001>^`00C[/004jk
001>^`00D[/005:k001B^`00D[/07000029B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005;K
001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/0009Bf`09001Bf`00E]/005KK001Ff`0001]o
o`03001oogoo03moo`00GGoo00<007ooOol0H7oo00H005;L001Bg000D]`200002E;L001Bg000D]`0
05;L001Bg00^00001Djl001>_000C[`00P0000E:_000BY`004ZL0080000<AY`004JL001Ff`00E]/0
05KK001Ff`000UKK00`005KKE]/005KK001Ff`00E]/005KK0002E]/02`00E]/005KK001Ff`00E]/0
05KK00000UKK00P005KK001Ff`00E]/005KK10000glB00H007m?Odl006og0002NmL00`00NkMk]`02
NkL00`00NkMk]`040002NiL00`00NiMkU`02NiL00`00NgMkM`02NgL20004MgL20004MgL02@00MeMg
EgMG001gE`00MeP00004MeP01@00LeQcF7=H00000W=H00D007=HLeQcF00000=c>005001c>7<hLcP0
0002LcP01000KcQ_>0000Vlh00D006lh001_>@0000=_>@04001_>Fli0002KcT01000KcU_>@000Vli
00@006liKcT0009[>@06001[6F/I001[6@000V/I00D006/IJaT006/I0080009[6@07001[6F/I001[
6@00JaT00P000V/I00@006/IJaT0009[6@03001[6@00009[6@04001[6F/I0002JaT00`00JaT00002
JaT01`00JaU[6@00JaT006/I0080009[6@08001[6F/I001[6@00JaT0009W6@03001Vn@00009Vn@04
001Vn@00I_T20002I_T02@00I_UVn@00I_T006Ki001Vn@02000016Ki001Vn@000VKi00<006Ki0000
0V;i00<006;i00000V;I00h006;I001Rf@00H]T006;I001Nf@00G]T005kI0P0000ANfP00G[X0009J
^P80009J^P80000?E[X005Jj001F^P00EYX005:J001BVP00DYX004jJ00800005CWX004ik001:N`02
00001DYk001:N`00AW/00P0000I2F`000012F`00@U/200000ciK000nF`02000023iK000003Xk000j
>`00>S/300000cXk000j>`0300000cHk000f?00300000cHl00000002000013Hl000003Hl0P0000Hf
?000000b?000<S`20000138l000002hl0P0000D^7000000002XL008000059Q`00000000Uo0020000
1B7l000000008O`00P0000@Mo000000N708000057Qd00000000ZG@0200001Rin000003Jn000ng`80
0009Aal004lNCah005<n001G?P00009KGP04001OG@00Ged2000026=M001SO6=l001WO000Ig`20000
1FMl001[Nf]k00000V]k00@006]k0000009[F`04001[F`00JeX20002JeX01000JeY[FP000VmJ0P00
0f]J00@006]J001[FP80009[>P04001[>P00JcX20002JcX00`00JcX00002JcX30002JcX01`00JcY[
>P00JcX006/j00800008JcX006/jJcX006/j001[>P80009[>P05001[6P00JaX00002JaX00`00IaX0
0002IaX01P00IaX006LJ001W6P80000:IaX006LJIaX006LJ001W6P00IaX2000016LJ001W6P000VLJ
00@006LJ001W6P<0009W6P03001W6VLJ0080009VnP05001VnP00I_X00002I_X01@00I_X006Kj0000
0V;j0`0000iRnP00H_YRnP00H_X006;j001RnP00H_X006;j0`0000mNfP00G]YNfP00G]X005kJ001N
fP00G]X005kJ00000UkJ00<005[J00001P0000]J^P00F[X005Jj001F^P00E[X005Jj0080000QE[X0
05Jj001BVP00DYX005:J001BVP00DYX005:K001BV`00DY/004jK001>V`00CY/004jK001>V`00CY/0
04jK00P00005CY/004jK001>V`0200007DjK001>V`00CY/004jK001>V`00CY/004jK001>V`00CY/0
04jK001>V`00CY/004jK001>^`00C[/00P0002M>^`00C[/004jk001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P0000iB^`00D[/0
05:k001B^`00D[/005:k001B^`000U:k01d005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00
D]/005;K001Bf`00E]/005KK001Ff`0001aoo`03001oogoo03ioo`00GWoo00<007ooOol0H7oo4000
00EBg000D]`005;L0080000?D]`005;L001Bg000D]`005;L001B_000D[`005:l0080000=D[`005:l
001B_000D[`005:l001>_000C[`00P0000M>_000C[`004jl001>_00900001dZL001:W000BY`004JL
0080009Ff`09001Ff`00E]/005KK001Ff`00009Ff`03001Ff`00009Ff`0A001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/00002E]/8000015KK001Ff`000glB00D007m?001_m`0000=ke`05001k
]g^gNkL00004NkL00`00NiMkU`020005NiL20002NgL01000MgMgM`000WMg00@007MgMgL000=gM`03
001gEgMG009gE`05001gF7MHMeP00003MeP02@00LeQcF7=H001cF000LeP00003LeP01@00LcP007<h
00000W<h00@007<h000000=_>004001_>6lh0003KcT01@00KcU_>@00KcT00P000Vli00D006liKcT0
06li0080009_>@05001[>F/i001[6@020002JaT01000JaU[6@000V/I00H006/IJaT006/I0002JaT0
1000JaT000000V/I00L006/IJaT006/I001[6@020002JaT01`00JaU[6@00JaT006/I0080009[6@07
001[6F/I001[6@00JaT00P000V/I00<006/I00000V/I00<006/IJaT00P000VLI00L006KiI_T006Ki
001Vn@020002I_T00`00I_T00002I_T01000I_T006Ki0P000VKi00X006Ki001Vn@00I_T006Ki001R
n@80009Rn@05001Rf@00H]T00002H]T20002H]T5000035kJ001NfUkJ001N^P00F[X005Zj001J^P80
0004E[X005Jj0002E[X01P00EYX005:J001BVP80000>CYX00000CWX004ik001:N`00BW/004Yk001:
N`800003AW/0000000<00003@U/0049K00800003?U/003iK00800003?U/0000000800003>S/003Xk
00<00003>S/0000000800005=S/00000000f?00200000cHl000f?002000013Hl000003Hl0P0000Hf
?000000b?000<S`20000138l000002hl0`0000@Z7000000Z708000059Q`00000000V700200001Agl
000000008O`00P0000@Mo000000R7@8000058Sd00000000^OP0400000cJn000ng`0200002TLO001?
7TlN001C?P00Ech005]N100000QOG@00HeeSG@00Hg`006Ml0P0000EWG000IgaWO000009[N`04001[
N`000002Je/00`00Je/00002Je/00`00JeX00003JeX01000JeX006mJ0P0000I[FP00JeY[FP00JeX2
0002JeX00`00JcX00002JcX00`00JcX00002JcX01P00JcY[>P00JcX0009[>P03001[>P00009[>P04
001[>P000002JcX20002JcX01P00JcY[>P00JcX0009[>P06001[6P00JaX006/J0P000VLJ00<006LJ
00000VLJ0`0000YW6P00IaYW6P00IaX006LJ001W6P80000:IaX006LJIaX006LJ001W6P00IaX20000
16LJ001W6P000VLJ00@006LJ001W6P<0009VnP07001VnP00I_X006Kj00000VKj0`0000ARnP00H_X0
009RnP05001RnP00H_X00002H_X3000046;J001RfP00G]X005kJ001NfP00G]X005kJ001NfP000UkJ
1@0002UJfP00F[X005Zj001J^P00F[X005Jj001F^P00E[X005Jj001F^P00E[X005Jj001BVP00DYX0
05:J001BVP00DYX005:K001BV`00DY/004jK00800009CY/004jK001>V`00CY/004jK00800005CY/0
04jK001>V`0900001djK001>V`00CY/004jK0080000gCY/004jK001>V`00CY/004jK001>V`00CY/0
04jK001>^`00C[/004jk001>^`00C[/004jk001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/00P00039B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00E]/0
05KK001Ff`0077oo00<007ooOol0?Woo001OOol00`00Oomoo`1OOol01P00D]`005;L001Bg0800008
D]`005;L001Bg000D]`0009Bg004001Bg000D]`200003e;L001Bg000D]`005;L001Bg000D[`005:l
001B_00200003E:l001B_000D[`005:l001B_000C[`004jl00800005C[`004jl001>_00200001Djl
001>_000B[`00P0000=:_00000001P0000Q6W000E]/005KK001Ff`000UKK00<005KK00000UKK0100
05KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`L00008E]/005KK001Ff`00E]/0009Ff`03001F
f`00009o4P04001oC`00KoL:0002NkL00`00NiMkU`02NiL20003NiL01P00NiMkU`00NgL000=gM`03
001gM`0000=gM`05001gM`00MgP00003MeL00`00MeQgF002MeP01@00MeP007=H00000g=H00D007=H
LeQcF00000=cF005001c>7<hLcP00002LcP01000KcQ_>0000Vlh00@006lh000000=_>@05001_>Fli
KcT00002KcT01000KcU_>@000Vli00@006liKcT0009_>@04001[>F/i0002JaT00`00JaT00002JaT0
1000JaT000000V/I00@006/IJaT0009[6@03001[6@00009[6@04001[6F/I0002JaT01P00JaU[6@00
JaT0009[6@04001[6F/I0002JaT00`00JaT00002JaT01P00JaU[6@00JaT0009[6@07001[6F/I001[
6@00JaT00P0000QW6@00IaUW6@00I_T006Ki0P0000EVn@00I_UVn@00009Vn@04001Vn@00I_T20000
36Ki001VnFKi001Vn@00I_T006Ki001Vn@80009Rn@05001Rn@00H]T00002H]T01000H]T006;I0`00
00ANf@00G]X0009NfP0H001NfP00G[X005Zj001J^P00F[X005Zj001F^P00E[X005Jj001FVP00DYX0
05:J0P0000M>VP00CYX004ij001>N`0200001dYk001:N`00BW/004Ik00800003AU/0000000<00005
@U/003iK000nF`0200001SiK000003iK000nF`800004>S/00000>S/300000cXk0000000500000cHl
000f?002000013Hl000003Hl0P0000@f?000000b?0800003<S`0038l00800004;S`00000;S`30000
12XL000002XL0P0000DUo000000002HL008000037O`00000008000037O`001hL008000048Sd00000
9Sd300000c:N000f_P0600000dLO001?7P06000015]N001KG@000UmM00@006=M001SO0800005Ie`0
06MLIe`00002Ig`01P00Jg/00000Je/0009[F`04001[F`00Je/20002JeX01@00JeY[FP00JeX00P00
0V]J00<006]J00000V]J00<006]J00000V]J00<006/jJcX00`000V/j00P006/jJcX006/j001[>P00
0V/j00@006/jJcX0009[>P03001[>P00009[>P06001[>P00JcX006/j0P000V/j00<006/j00000V/J
0`0000MW6P00IaYW6P00IaX00002IaX00`00IaX00002IaX01@00IaX006LJ00000VLJ00<006LJ0000
0VLJ00D006LJ001W6P00009W6P07001W6P00IaX006LJ00000VLJ00D006LJ001W6P00009VnP07001V
nP00I_X006Kj00000VKj0`0000ARnP00H_X0009RnP05001RnP00H_X00002H_X3000026;j001RfP00
H]X005kJ0002G]X200001UkJ001NfUkJ001NfP<0000:F]X005[J001JfP00F[X005Zj0002F[X01000
F[X005Jj0P0002EF^P00E[X005Jj001F^P00E[X005:J001BVP00DYX005:J001BVP00DY/005:K001B
V`00CY/004jK001>V`00CY/004jK001>V`0200001DjK001>V`00CY/00P0000M>V`00CY/004jK001>
V`0;00001DjK001>V`00CY/00P0002m>V`00CY/004jK001>V`00C[/004jk001>^`00C[/004jk001>
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0080
000XD[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001Bf`00D]/005;K001B
f`00D]/005;K001Bf`00D]/005;K0002D]/02@00D]/005KK001Ff`00E]/0000KOol00`00Oomoo`0n
Ool005moo`03001oogoo061oo`06001Bg000D]`005;L0P0000eBg000D]`005;L001Bg000D]`005;L
001Bg00200001U;L001Bg000D]`0009Bg080000=D[`005:l001B_000D[`005:l001B_000D[`00P00
00EB_000C[`004jl0080000=C[`004jl001>_000C[`004jl001>_000B[`00`0000M:W000BY`004ZL
0016W0020002E]/01`00E]/005KK001Ff`00009Ff`0<001Ff`00E]/005KK001Ff`00E]/005KK1P00
00IFf`00E]/005KK0003E]/02`00E]/005KK001Ff`00E]/005KK00000WlB1@000W?i00D007OIMmUg
f@00009g^0<000=kU`06001kV7^H001kU`0017^G0P0017Mg00<007MgMgL00gMg00T007MhMgQgN000
MeL007MH000017MH00D007=HLeQcF000009cF003001cF7=H009cF004001cF0000003LcP01000LcP0
00000flh00@006lhKcP0009_>@06001_>FliKcT006li0P000Vli00D006liKcT006li0080009_>@05
001_>Fli001[>@020002JaT01000JaU[6@000V/I00@006/IJaT0009[6@04001[6@00JaT20002JaT0
1`00JaU[6@00JaT006/I0080009[6@07001[6F/I001[6@00JaT00P000V/I00L006/IJaT006/I001[
6@020002JaT01`00JaU[6@00JaT006/I00800004JaT006LI0002IaT01P00I_UVn@00I_T0009Vn@06
001VnFKi001Vn@000VKi00<006Ki00000VKi00P006Ki001Vn@00I_T006Ki0P0000MRn@00H_URn@00
H_T00002H]T02@00H]T006;I001Rf@00G]T00002G]T02@00G]X005kJ001NfP00G[X00002F[X20000
3eZj001J^P00E[X005Jj001F^P00EYX005:J001BVP0200002djJ001>VP00CWX004ik001:N`00BW/0
0P0000=:N`00AW/00P0000A6F`000012F`@00005?U/003iK000nF`0200000ciK000nF`0200001ciK
00000000>S/003Xk00<00003>S`003Xl00800006=S`00000=S`003Hl0P0000@f?000000f?0800004
=S`00000<S`200000c8l000b?00200001Bhl00000000:Q`00P0000@Z7000000Z708000059O`00000
000R700200000b7l0000000200000ahL000R7@02000012Hm000002YM0P0000PbWP00000j_P00?]h0
04Kn0`0000I?7P00Dch005Ln0002Feh01P00Fed005mM001SG@800005He`006MLIe`00002Ie`01P00
IgaWO000Ie/0009[F`04001[F`00Je/20002Je/01000JeY[FP000V]J00<006]J00000V]J00@006]J
001[FP80009[FP03001[FP00009[>P06001[>V/j001[>P000V/j00H006/j000006/j0002JcX01000
JcX006/j0P000V/j00H006/j001[>P00JcX20002JcX00`00JcX00002JcX300001fLJ001W6VLJ001W
6P00009W6P<00007IaX006LJIaX006LJ00000VLJ0`0000YW6P00IaYW6P00IaX006LJ001W6P80000:
IaX006LJIaX006LJ001W6P00IaX30002I_X00`00I_YVnP020002I_X3000016;j001RnP000V;j00D0
06;j001RnP00009RnP<00004H_X006;j0002H]X20002G]X01000G]X000000UkJ1@0000INfP00F]X0
05[J0002F]X04000F[X005Zj001J^P00F[X005Jj001F^P00E[X005Jj0P00025F^P00E[X005:J001B
VP00DYX005:J001BVP00DY/005:K001BV`00CY/004jK001>V`00CY/004jK001>V`00CY/00P0000=>
V`00CY/00P00015>V`00CY/004jK001>V`00CY/004jK001>V`00CY/004jK00T0000;CY/004jK001>
V`00CY/004jk001>^`0200009djk001>^`00C[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0200003U:k001B^`00D[/005:k001B
^`00D[/005:k0002D[/04P00D]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Bf`/001]oo`03
001oogoo03ioo`00H7oo00<007ooOol0Ggoo01H005;L001Bg000D]`005;L001Bg000D]`005;L001B
g000D]`005;L001Bg080000?D]`005;L001Bg000D]`005;L001B_000D[`005:l0080000=D[`005:l
001B_000D[`005:l001>_000C[`00P0000E>_000C[`004jl00800005C[`004jl001:_00200001dZl
001:W000BY`004ZL0080000@AY`005KKE]/005KK001Ff`00E]/005KK001Ff`00E]/800001UKK001F
f`00E]/0009Ff`05001Ff`00E]/00002E]/01`00E]/005KK001Ff`00009Ff`04001Ff`00Oa830003
LoT01@00MmUgfGOI000017Nh00H007Nh000007^G0003NiP20004NiL00`00MgP00003MgL20003MgL2
0004MgP01@00MeQgF7MH00000gMH00T007=HLeQcF000LeP007=H000017=H00@007=HLeP000=c>004
001c>7<h0002KcP01000KcP000000fli00D006liKcU_>@00009_>@04001_>Fli0002KcT01000KcU_
>@000Vli00@006liKcT0009[>@07001[6F/I001[6@00JaT00P000V/I00@006/IJaT0009[6@06001[
6F/I001[6@000V/I00@006/I0000009[6@07001[6F/I001[6@00JaT00P000V/I00L006/IJaT006/I
001[6@020002JaT00`00JaT00002JaT01P00JaU[6@00JaT0009[6@06001W6@00IaT006Ki0P000VKi
00<006Ki00000VKi00@006Ki001Vn@80009Vn@03001Vn@00009Vn@03001Vn@0000800007I_T006;i
H_T006;i00000V;i00H006;I001Rf@00H]T30002G]T01`00G]T005kJ001NfP00009NfP04001N^P00
F[X20002F[X200001EJj001F^P00E[X02@0000i>VP00001>NP00CW/004Yk001:N`00BW/004Yk0P00
00=6N`00AU/00`0000=2F`00@U/00P0000DnF`00?U/003iK00800006?U/00000?U/003YK0`0000Hj
>`00000j>`00>S`200001SXl000003Hl000f?0800004=S`00000=S`2000013Hl0000038l0P0000<b
?00000000P0000@^?000000^?0<00004:Q`00000:Q`2000012XL000002HL0`0000<V700000000P00
00HR7000000R7@008Sd200002bYM00000000<Yh003Jn000j_P00?]h00P0000i;7P00Cai?7P00Dch0
05Ln001KGP00Fed005mM0P0000ESG@00HeaSG000009WG004001WG000Ig`20002Ie/00`00Je/00002
Je/00`00Je/00003Je/01000JeX006]J0P000V]J00@006]J001[FP80009[FP03001[FP00009[FP<0
009[>P04001[>V/j0002JcX01@00JcX006/j00000V/j00@006/j0000009[>P03001[>P00009[>P<0
0007JcX006/jJcX006/j00000V/j00<006/J00000VLJ00<006LJ00000VLJ0`0000MW6P00IaYW6P00
IaX00002IaX300001fLJ001W6VLJ001W6P00009W6P<0000:IaX006LJIaX006LJ001W6P00IaX20000
16LJ001VnP000VKj00@006Kj001VnP<00004H_X006;j0002H_X01@00H_X006;j00000V;j0`0000AR
nP00H_X0009RnP0:001RfP00H]X005kJ001NfP00G]X300001UkJ001NfP00G]X0009JfP0D001JfP00
F]X005Zj001J^P00F[X005Zj001F^P00E[X005Jj001F^P80009F^P0@001F^P00DYX005:J001BVP00
DYX005:J001BV`00DY/200004djK001>V`00CY/004jK001>V`00CY/004jK001>V`00CY/004jK0080
0005CY/004jK001>V`0200004DjK001>V`00CY/004jK001>V`00CY/004jK001>V`00CY/03`00025>
^`00C[/004jk001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/00P0000mB^`00D[/005:k001B^`00D[/005:k001B^`00D[/00`0000=B^`0000004`0000YF
f`00E]/005KK001Ff`00E]/001aoo`03001oogoo03eoo`00H7oo00<007ooOol0H7oo00H005;L001B
g000D]`200005e;L001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`00P00
00eB_000D[`005:l001B_000D[`005:l001B_00200003E:l001>_000C[`004jl001>_000C[`004jl
00800005C[`004jl001:_00200000dZl001:W00200003DZL0016W000AY`005KK001Ff`00E]/005KK
00H00008E]/005KK001Ff`00E]/0009Ff`0;001Ff`00E]/005KK001Ff`00E]/00003E]/02P00E]/0
05KK001Ff`00E]/005KK3P000WNh00@007NhMkQg^0<000=kV006001gV000001kU`000gMh00<007Mg
00000WMh00<007Mg00000WMh00@007MhMgQgN08000=gF005001gF000LeP00003LeP01@00LeQcF7=H
00000g=H00D007=HLeQcF000009c>005001c>7<hLcP00002KcP01000KcU_>@000fli00@006li0000
009_>@05001_>Fli001_>@020002KcT01@00KcU_>@00KcT00P000V/i00@006/IJaT0009[6@04001[
6F/I0002JaT01000JaT006/I0P000V/I00@006/IJaT0009[6@03001[6@00009[6@04001[6F/I0002
JaT00`00JaT00002JaT01000JaU[6@000V/I00<006/I00000V/I00L006/IJaT006/I001[6@020002
JaT01@00JaT006LI00000VLI00H006KiI_T006Ki0002I_T01000I_T006Ki0P000VKi00<006Ki0000
0VKi00L006Ki001Vn@00I_T00002I_T00`00H_T00002H_T01P00H_T006;I001Rf@800008H]T006;I
001Nf@00G]T0009NfP0:001NfP00G]X005jj001J^P00F[X900001eJj001FVP00DYX005:J00/00007
BW/004Yk001:N`00AW/00P0000I6F`000012F`00@U/200000d9K0000000200001CiK000nF`00?U/0
0`0000<jF`0000000`0000Hj>`00000j?000>S`200001SXl000003Hl000f?0800004=S`00000=S`2
000013Hl0000038l0P0000<b?000<S`00P0000D^?000000002hL00800004:Q`00000:Q`200001BHL
000000008Q`00P0000<V700000000P0000HV7@00000R?@009Sd200005Bin00000000=[h003Zn000n
gP00A_h004/N001?7P00Dch005Ln001KGP0400001EmM001SGF=M00000V=L00@006ML001WG080009W
G006001WF`00Je/006]K0P000V]K00D006]KJe/006]J0080009[FP03001[FP00009[FP03001[FP00
009[FP04001[FP00JeX20002JcX01`00JcY[>P00JcX006/j0080009[>P03001[>P00009[>P03001[
>P00009[>P03001[>P00009[>P03001[>P00009[>P03001[>P00009[>P<0009[6P05001W6P00IaX0
0002IaX00`00IaX00002IaX00`00IaX00002IaX300001fLJ001W6VLJ001W6P00009W6P<00009IaX0
06LJIaX006LJ001W6P00009W6P07001W6P00IaX006Kj00000VKj00L006Kj001VnP00I_X00002H_X0
1`00H_X006;j001RnP00009RnP<00004H_X006;j0002H_X02P00H_X006;J001RfP00G]X005kJ0`00
00ANfP00G]YNfP80009NfP0?001JfP00F]X005[J001J^P00F[X005Zj001J^P00009F^P800005E[X0
05Jj001F^P0E00002DjK001>V`00CY/004jK001>V`0200001djK001>V`00CY/004jK0080000?CY/0
04jK001>V`00CY/004jK001>V`00CY/004jK0080000ECY/004jK001>V`00CY/004jK001>V`00CY/0
04jk001>^`00C[/004jk03P0000JD]/005;K001Bf`00D]/005;K001Bf`00D]/005;K001Ff`00E]/0
05KK001Ff`00E]/0009Ff`03001Ff`0001]oo`03001oogoo03eoo`00HGoo00<007ooOol0H7oo0P00
00eBg000D]`005;L001Bg000D]`005;L001Bg00200003E;L001Bg000D]`005;L001Bg000D]`005;L
01L00007C[`004jl001>_000C[`00P0000M>_000C[`004Zl001:_00200001DZL001:W000BY`00P00
00=6W000E]/01P0000IFf`00E]/005KK0002E]/02`00E]/005KK001Ff`00E]/005KK00000UKK00L0
05KK001Ff`00E]/00002E]/02P00E]/005KK001Ff`00E]/005KK0`000f_k00D007?jLoYcnP0000=c
fP@00003MkP007Ni009g^@03001kV00000AgV08000AgN003001gN7Mh009gN003001gN7Mh009gN003
001gN000009gN005001gF7MHMeP00003LeP01@00LeP007=H00000g=H00D007=H001cF000009cF005
001c>000LcP00002LcP01000KcP000000fli00D006liKcU_>@00009_>@04001_>Fli0002KcT01000
KcU_>@000Vli00@006liKcT0009[>@07001[>F/i001[6@00JaT00P000V/I00D006/IJaT006/I0080
009[6@07001[6F/I001[6@00JaT00P000V/I00L006/IJaT006/I001[6@020002JaT01`00JaU[6@00
JaT006/I0080009[6@07001[6F/I001[6@00JaT00P000V/I00P006/I001[6@00IaT006LI0P000VKi
00H006KiI_T006Ki0002I_T00`00I_T00002I_T02P00I_UVn@00I_T006Ki001Vn@000VKi00<006Ki
00000V;i00H006;i001Rn@00H]T2000026;I001Rf@00H]T005kI0002G]T02P00G]X005kJ001NfP00
G[X005Zj0`0000QJ^P00F[X005Jj001F^P000UJj00@005JJ001BVP<00009DYX004jJ001>V`00CW/0
04ik00@00003BW/004Ik00800003AU/004IK00800003@U/0049K00800003@U/003iK00800003?U/0
03iK00800005?U/00000000jF`0400000cXk000j?002000013Xl000003Xl0P0000<f?000=S`00P00
00@f?000000f?0800004<S`00000<S`200000c8l000b?00200001Bhl00000000;Q`00P0000@Z7000
000Z708000059Q`00000000V700300001B8L000000009Sd00P0000LV?@00:Ud002in000fWP080000
0d/N001?7P06000015/n001KG@000UmM00L006=MHed006=L001WG002000026ML001WG6ML001WF`00
Je/20002Je/01000Je][F`000V]K00<006]K00000V]J00@006]J001[FP80009[FP03001[FP00009[
FP03001[>P00009[>P05001[>V/j001[>P020002JcX01P00JcX006/j001[>P80009[>P03001[>P00
009[>P<0009[>P03001[>P00009[>P<00007JaX006/JJaX006LJ00000VLJ0`000VLJ00D006LJ001W
6P00009W6P03001W6P00009W6P05001W6P00IaX00002IaX00`00IaX00002IaX01@00IaX006LJ0000
0VLJ0`0000YW6P00IaYW6P00I_X006Kj001VnP<0009VnP07001RnP00H_X006;j00000V;j0`0000AR
nP00H_X0009RnP0:001RnP00H_X006;J001RfP00G]X200000ekJ00000002G]X03`00G]X005kJ001N
fP00F]X005[J001JfP00F[X00002F[X01000F[X005Zj2P0001=F^P00E[X005Jj001BVP00DYX005:J
001BV`00DY/005:K001BV`0=00001TjK000004jK001>V`80000KCY/004jK001>V`00CY/004jK001>
V`00CY/004jK001>V`00CY/004jK001>V`00CY/004jK0080000[CY/004jk001>^`00C[/004jk001>
^`00C[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/00P0001aB^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D]/005;K001B
f`00D]/0009Bf`0E001Bf`00D]/005;K001Ff`00E]/005KK001Ff`00E]/005KK001Ff`0001]oo`03
001oogoo03eoo`00HWoo00<007ooOol0Ggoo0P0000=Bg000D]`06@00011Bg000001B_000D[`005:l
001B_000D[`005:l001B_0800005D[`004jl001>_00?00001dZl001:_000BY`004ZL0080000:AY`0
04JL001Ff`00E]/005KK0002E]/02`00E]/005KK001Ff`00E]/005KK00000UKK00L005KK001Ff`00
E]/00002E]/03000E]/005KK001Ff`00E]/005KK001Ffa00009cfP04001g^WNjMkX20004MkT20004
MiP00`00MiP00003MgP20003MgP20004MgP00`00MgQgN002MgP01000MeP0000017=H00D007=HLeQc
F00000=cF005001cF7=HLeP00002LeP01000LcQc>0000g<h00@006liKcT0009_>@05001_>FliKcT0
0002KcT01@00KcU_>@00KcT00P000Vli00D006liKcT006li0080009[>@05001[>F/i001[6@020002
JaT01000JaU[6@000V/I00<006/I00000V/I00@006/IJaT0009[6@06001[6F/I001[6@000V/I00@0
06/I0000009[6@03001[6@00009[6@04001[6F/I0002JaT00`00JaT00002JaT01P00JaU[6@00JaT0
009[6@05001[6F/I001[6@030002I_T02@00I_UVn@00I_T006Ki001Vn@020002I_T02@00I_UVn@00
I_T006Ki001Vn@02000016Ki001Vn@000VKi00H006;i001Rn@00H_T200001V;I001RfF;I001Rf@80
009Nf@08001Nf@00G]X005kJ001NfP@00003F[X00000009J^P0>001J^P00E[X005Jj001F^P00EYX0
05:J001BVP800007DYX004jJ001>V`00CW/00P0000=:N`00BW/0100000Q6N`000016F`00@U/0049K
0P0000=2F`00@U/00P0000@nF`00000nF`800003?U/003YK00<00003>U/0000000800003>S`003Xl
00800004>S`00000>S`200000cHl000f?002000013Hl000003Hl0P0000@b?000000b?0800003<S`0
038l00800005;S`00000000^7002000012XL000002HL0`0000@R7000000V70<000058Q`00000000Z
?@0400002bin00000000>[h003kN0012gP00A_h00`0000I?7P00Dch005Ln0002Fch00`00Fed00002
Ged01000Hed006=L0P0000QSG000IeaWG000Ie`006MK0P0000=[F`00Je/00V]K00@006]K001[F`80
009[F`04001[FP00JeX20002JeX01@00JeY[FP00JeX00`000V/j00@006/jJcX0009[>P03001[>P00
009[>P04001[>P00JcX20002JcX00`00JcX00002JcX30002JcX01@00JcX006/j00000V/j00<006/j
00000V/J00<006/J00000VLJ0`0000MW6P00IaYW6P00IaX00002IaX30002IaX01@00IaX006LJ0000
0VLJ0`0000MW6P00IaYW6P00IaX00002IaX300002FLJ001W6VLJ001W6P00I_X00002I_X01`00I_X0
06Kj001VnP00009RnP80009RnP<00004H_X006;j0002H_X01@00H_X006;j00000V;j00<006;J0000
0P00019NfP00G]X005kJ001NfP00G]X005kJ001NfP00F]X005[J0002F]X00`00F[X0000600001eJj
001F^P00E[X005Jj0080009F^P80000KE[X005:J001BVP00DYX005:K001BV`00DY/005:K001BV`00
DY/004jK001>V`00CY/004jK00X00005CY/004jK001>V`0200009DjK001>V`00CY/004jK001>V`00
CY/004jK001>V`00CY/004jK001>V`00CY/004jk001>^`00C[/004jk001>^`00C[/005:k0080000I
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P0000AB^`00
D[/0009B^`0:001B^`00D[/005:k001B^`00D[/3000085:k001Bf`00D]/005;K001Bf`00D]/005;K
001Bf`00D]/005KK001Ff`00E]/005KK001Ff`00E]/005KK000LOol00`00Oomoo`0lOol0069oo`03
001oogoo061oo`@0000;D]`005;L001Bg000D]`005;L001Bg002000035;L001Bg000D]`005;L001B
g000D]`0009Bg080000=D[`005:l001B_000D[`005:l001B_000D[`00P0000=B_000C[`00P0000M>
_000C[`004jl001>_00200001Djl001>_000B[`02@0000A6W000AY`0009Ff`0;001Ff`00E]/005KK
001Ff`00E]/00002E]/01`00E]/005KK001Ff`00009Ff`0<001Ff`00E]/005KK001Ff`00E]/005KK
30000V?l00D006_lJoa[o00000=_f`<000=g^P06001g^P00001g^@000WNI0P0000=gV000MiP00WNH
00<007Mh00000WMh00<007Mh00000WMh00@007MhMgQgN08000AgN004001cF7=H0003LeP00`00LeQc
F002LeP01000LeP000000g=H00@007=H000000=c>004001c>7<h0003KcT02000KcU_>@00KcT006li
0002KcT01000KcU_>@000Vli00@006liKcT0009_>@04001[>F/i0002JcT01P00JcU[>@00JaT0009[
6@05001[6F/I001[6@020002JaT01`00JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT00`00
JaT00002JaT01`00JaU[6@00JaT006/I0080009[6@07001[6F/I001[6@00JaT00P000V/I00X006/I
JaT006/I001[6@00IaT0009Vn@07001VnFKi001Vn@00I_T00P000VKi00<006Ki00000VKi00@006Ki
001Vn@800004I_T006Ki0002I_T01P00I_T006;i001Rn@80000@H_T006;IH]T006;I001Rf@00H]T0
05kI001Nf@00G]X400005ekJ001J^P00F[X005Zj001J^P00F[X005Jj001F^P00E[X005JJ001BVP00
DYX00P0000]BVP00CYX004jK001>N`00CW/004Yk00800003BW/004Ik00D00005@U/0049K0012F`02
00000d9K000nF`0200000ciK00000003000013YK000003YK0P0000<jF`00>U`00P0000<j?000>S`0
0P0000@j?000000j?0800003=S`003Hl00800004=S`00000=S`200001S8l0000038l000b?0800005
<S`00000000^7002000012XL000002XL0P0000DV7000000002HL00<000049Qd000009Qd300000bYM
000^O@020000239n000003Zn000ngP00@]h200002D/N001?7TlN001C?P00Ech00002Fch01000Fed0
05mM100000QSG000HeaSG000Ie`006ML0P0000EWF`00Je][F`00009[F`04001[F`000002Je/00`00
Je/00002JeX00`00JeX00002JeX01P00JeY[FP00JeX0009[FP07001[>V/j001[>P00JcX00P000V/j
00<006/j00000V/j00<006/j00000V/j00<006/j00000V/j00<006/j00000V/j00<006/j00000V/j
0`000V/j00<006/J00000V/J0`0000MW6P00IaYW6P00IaX00002IaX300001fLJ001W6VLJ001W6P00
009W6P<00007IaX006LJIaX006LJ00000VLJ0`0000aW6P00IaYW6P00IaX006LJ001VnP00I_X20000
16Kj001VnP000VKj00@006;j001RnP<00004H_X006;j0002H_X01@00H_X006;j00000V;j1@0000AN
fP00G]X0009NfP80009NfP06001NfP00001NfP000U[J00<005[J00001000025J^P00F[X005Zj001F
^P00E[X005Jj001F^P00E[X005Jj001F^P00E[X005:J001BVP00DYX005:K001BV`00DY/00P0001=B
V`00DY/004jK001>V`00CY/004jK001>V`00CY/004jK001>V`0:00001djK001>V`00CY/004jK0080
000aCY/004jK001>V`00CY/004jK001>V`00CY/004jk001>^`00C[/004jk001>^`00C[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P0003AB^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D]/005;K001Bf`00D]/005;K001B
f`00D]/005;K001Ff`00E]/005KK001Ff`00E]/0009Ff`03001Ff`0001]oo`03001oogoo03aoo`00
Hgoo00<007ooOol0Ggoo0P0000iBg000D]aBg000D]`005;L001Bg000D]`005;L0P0000eBg000D]`0
05;L001Bg000D]`005;L001Bg00200003E:l001B_000D[`005:l001B_000D[`005:l0080000=D[`0
04jl001>_000C[`004jl001>_000C[`00P0000=>_000C[`00P0000M:_000B[`004ZL001:W0060000
15KK001Ff`000UKK00L005KK001Ff`00E]/00002E]/03000E]/005KK001Ff`00E]/005KK001Ffa80
009Kg@P0009_f`06001cfg?K001g^P0017Nj0P0017NI0P0017NH00<007MhMgP00WMh00<007MhMgP0
0WMh00<007Mh00000WMh00D007MhMgQgN00000=cF005001cF000LeP00004LeP01000LeQcF0000g=H
00@007=HLeP0009c>005001c>000KcT00002KcT01@00KcU_>Fli00000Vli00D006liKcT006li0080
009_>@05001_>Fli001_>@020002JcT01@00JcU[>@00JcT00P000V/I00@006/IJaT0009[6@06001[
6F/I001[6@000V/I00@006/I0000009[6@07001[6F/I001[6@00JaT00P000V/I00L006/IJaT006/I
001[6@020002JaT01`00JaU[6@00JaT006/I0080009[6@03001[6@00009[6@05001[6@00JaT00002
IaT01`00I_UVn@00I_T006Ki00800005I_T006KiI_T00002I_T01000I_T006Ki0P0000IVn@00I_T0
06Ki0002I_T01000I_T006;i0P0000MRn@00H_URn@00H]T00002H]T200001F;I001Nf@00G]T00P00
00ANfP00G]X0009NfP80009J^P800006F[X005Zj001F^P000UJj00H005Jj001FVP00DYX200000e:J
001BVP0200002DjK001>N`00CW/004Yk001:N`02000014Ik000004Ik100000M2F`00@U/0049K0012
F`02000013iK000003iK1@0000HjF`00000jF`00>U/200001SYL000003Xl000j?0800004>S`00000
>S`200000cHl000f?002000013Hl000003Hl0`0000Db?000<S`0038l00800005;S`002hL000^7002
000012XL000002HL0`0000@V7000000V70<000039Sd0000000<00004:Ud00000<Wh400001CZn000n
gP00@]h00P0000a;7P00Cai?7P00Dch005Ln001K?P00Fed2000015mM001OG@000V=L00@006=L001W
G0800005Ie`006MKIe/00002Je/01P00Je/00000Je/0009[F`04001[F`00JeX20002JeX01000JeY[
FP000V]J0P000V]J00D006/jJcX006/j0080009[>P03001[>P00009[>P<0009[>P03001[>P00009[
>P<0009[>P03001[>P00009[>P<0009[>P05001[>P00JaX00002JaX00`00IaX00002IaX00`00IaX0
0002IaX300001fLJ001W6VLJ001W6P00009W6P<00007IaX006LJIaX006LJ00000VLJ0`0000UW6P00
IaYW6P00IaX006LJ00000VLJ0`0000mVnP00I_YVnP00I_X006Kj001RnP00H_X006;j00000V;j00L0
06;j001RnP00H_X00002H_X300001V;j001RfP00G]X0009NfP0<001NfP00G]X005kJ001NfP00G]X0
05kJ1@0000YJfP00F[X005Zj001J^P00F[X0009F^P06001F^P00E[X005Jj0P0001eF^P00E[X005Jj
001BVP00DYX005:J001BV`00DY/005:K001BV`00DY/005:K001>V`00CY/004jK00800007CY/004jK
001>V`00CY/00P0000M>V`00CY/004jK001>V`0;00002DjK001>V`00CY/004jK001>V`020000:djK
001>^`00C[/004jk001>^`00C[/004jk001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k0080000LD[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005;K001Bf`00D]/005;K0002D]/04000D]/005;K001Bf`00E]/005KK001Ff`00E]/0
05KK1@006goo00<007ooOol0?7oo001SOol00`00Oomoo`1POol200005E;L001Bg000D]`005;L001B
g000D]`005;L001Bg000D]`005;L001Bg002000015;L001Bg0000U;L0P0000eB_000D[`005:l001B
_000D[`005:l001B_00200001E:l001>_000C[`00P0000E>_000C[`004jl0080000;C[`004jl001:
_000B[`004Zl001:W00300000dJL0016W00200001UKK001Ff`00E]/0009Ff`0<001Ff`00E]/005KK
001Ff`00E]/005KK20000SMN1P000T>N10000U?N10000VOm00@006_LJma[g0<000=cf`8000Ag^P06
001c^P00001gV@000WNI0P0000AgV000MiT000=gN08000AgN003001gN7Mh009gN005001gN000LeP0
0003LeP01@00LeQcF7=H00000g=H00D007=HLeQcF000009cF005001cF7=HLeP00002LcP01@00KcU_
>Fli00000Vli00@006li000000=_>@04001_>Fli0002KcT01000KcU_>@000Vli00@006liKcT0009[
>@04001[>F/i0002JcT00`00JaT00002JaT01000JaT000000V/I00@006/IJaT0009[6@03001[6@00
009[6@04001[6F/I0002JaT01P00JaU[6@00JaT0009[6@06001[6F/I001[6@000V/I00@006/IJaT0
009[6@03001[6@00009[6@07001[6F/I001[6@00JaT00P0000AW6@00IaT0009Vn@06001VnFKi001V
n@000VKi00H006KiI_T006Ki0002I_T01@00I_T006Ki00000VKi00H006Ki001Vn@00I_T200001f;i
001RnF;i001Rn@00009Rf@07001Rf@00001Rf@00G]T00P0000aNfP00G]YNfP00G]X005kJ001J^P00
F[X20002F[X03000F[X005Jj001F^P00E[X005JJ001BVP80000;DYX005:J001>VP00CY/004ik001>
N`0200000dYk001:N`0200001TIk000004Ik0016F`@00005@U/0049K000nF`03000013iK000003iK
100000HjF`00000jF`00>U`200001SYL000003Xl000j?0800004>S`00000=S`4000013Hl000003Hl
0P0000Tf?0000000038l000b?000<S`0100000<^7000:Q`00P0000DZ7000000002HL008000049Q`0
00009Q`300000bXm000ZG@0200001bYM00000000=Yh003Zn00H00007A_h004/N001?7P00Dch01P00
00YKG@00GeeOG@00Ged006=L001SG0800005Ie`006MLIe`00002Ie/01P00Je/00000Je/0009[F`04
001[F`00Je/20002Je/01`00JeY[FP00JeX006]J00800005JeX006]JJeX00002JcX00`00JcX00002
JcX01000JcX006/j0P000V/j00<006/j00000V/j0`000V/j00<006/j00000V/j0`0000M[>P00JcY[
>P00JcX00002JaX30002IaX01@00IaX006LJ00000VLJ00<006LJ00000VLJ00<006LJ00000VLJ0`00
00UW6P00IaYW6P00IaX006LJ00000VLJ00D006LJ001W6P00009W6P03001W6P00009W6P<0000<I_X0
06KjI_X006Kj001VnP00I_X006;j0`000V;j00L006;j001RnP00H_X00002H_X300001V;j001RnP00
H]X0009NfP0<001NfP00G]X005kJ001NfP00G]X005kJ0`0000QJfP00F]X005[J001J^P000UZj0100
05Zj001J^P00E[X005Jj001F^P00E[X005Jj001F^P80000SE[X005:J001BVP00DYX005:K001BV`00
DY/005:K001BV`00DY/004jK001>V`00CY/004jK001>V`00CY/004jK001>V`02000044jK000004jK
001>V`00CY/004jK001>V`00CY/004jK3@0000m>V`00C[/004jk001>^`00C[/004jk001>^`00D[/0
0P0001UB^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`020000
15:k001B^`000U:k00X005:k001B^`00D[/005:k001B^`<00009D[/005;K001Bf`00D]/005;K01<0
0004E]/005KK000KOol00`00Oomoo`0lOol006Aoo`03001oogoo05moo`0@001Bg000D]`005;L001B
g000D]`005;L001Bg000D]`200005E;L001Bg000D]`005;L001Bg000D]`005;L001Bg000D[`005:l
001B_00200002e:l001B_000D[`005:l001B_000C[`00P0000M>_000C[`004jl001>_00200001Djl
001>_000B[`00P0000E:_000BY`004ZL00800004AY`000000002E]/03000E]/005KK001Ff`00E]/0
05KK001Ff`P0008cGPP0008kOPH0009?_P@0009OgP@00003Jm`006_L009[g003001cf`00009c^`80
0003MkX007>j00=c^P8000AgV@07001gVGNIMiT007Mh00000WMi00D007MhMgQgN00000EgN005001c
F7=HLeP00002LeP00`00LeQcF002LeP01@00LeP007=H00000W=H00D007=H001cF000009cF004001c
>0000003KcT01@00KcU_>Fli00000Vli00D006liKcT006li0080009_>@05001_>Fli001_>@020002
KcT01@00JcU[>@00JcT00P000V/i00@006/IJaT0009[6@04001[6F/I0002JaT01000JaT006/I0P00
0V/I00L006/IJaT006/I001[6@020002JaT01`00JaU[6@00JaT006/I0080009[6@07001[6F/I001[
6@00JaT00P000V/I00H006/IJaT006/I0002JaT01@00IaT006LI00000VLI00@006Ki001Vn@80009V
n@03001Vn@00009Vn@04001Vn@00I_T20002I_T01`00I_T006Ki001Vn@00009Vn@03001Rn@00009R
n@03001Rn@00009Rn@06001Rf@00H]T006;I0`00021Nf@00G]YNfP00G]X005kJ001NfP00F[X005Zj
001J^P00F[X005Zj001F^P00E[X005Jj001FVP00DYX005:J0P0000eBVP00CYX004jK001>N`00CW/0
04Yk001:N`0200001TIk000004Ik0016N`800003@U/0049K00800005@U/003iK000nF`0200001CiK
00000000?U/00P0000DjF`00>U/003YK00800004>U`00000>U`200000cXl000j?00200001SXl0000
03IL000fG0<00003=S`003Hl00D00008<S`00000<S`002hl000^?0800003:Q`002XL00800005:S`0
0000000V7002000012Xl000002HM0P0000@Z?@00000^G@800004;Wd00000=Yh200001Cjn000ngP00
@]h01`0000IC?P00Ech005/m0002Fed00`00GeeOG@0200001F=L000006=L00000VML00@006MLIe`0
009WF`03001WF`00009[F`04001[F`00Je/200000f]K001[F`02Je/01000JeX006]J0P000V]J00H0
06]J001[FP00JcX20002JcX00`00JcX00002JcX00`00JcX00002JcX00`00JcX00002JcX00`00JcX0
0002JcX00`00JcX00002JcX00`00JcX00002JcX01@00JcY[>P00JcX00`000VLJ00<006LJ00000VLJ
00<006LJ00000P000VLJ00D006LJ001W6P00009W6P03001W6P00009W6P05001W6P00IaX00002IaX3
00001fLJ001W6VLJ001W6P00009W6P<00004I_X006Kj0002I_X01P00I_X006Kj001VnP800006H_X0
06;j001RnP000V;j0P000V;j0`0000ARnP00H_X0009RnP0<001RfP00G]X005kJ001NfP00G]X005kJ
1@0000INfP00F]X005[J0002F]X05000F[X005Zj001J^P00F[X005Jj001F^P00E[X005Jj001F^P00
E[X200008eJj001BVP00DYX005:J001BV`00DY/005:K001BV`00DY/005:K001>V`00CY/004jK001>
V`00CY/004jK001>V`00CY/00P0000M>V`00CY/004jK001>V`0200004djK001>V`00CY/004jK001>
V`00CY/004jK001>V`00CY/004jK01<0000CD[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/00P0000UB^`00D[/005:k001B^`00D[/06@0001IBf`00D]/005KK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/001aoo`03001oogoo03]oo`00IGoo00<007ooOol0Ggoo0P0000IBg000
D]aBg000D]`200003E;L001Bg000D]`005;L001Bg000D]`005;L0080000=D]`005;L001Bg000D]`0
05:l001B_000D[`00P0000eB_000D[`005:l001B_000D[`004jl001>_00200002djl001>_000C[`0
04jl001>_000C[`00P0000E:_000B[`004ZL00800004BY`00000AY`200001EKK001Ff`00E]/05000
0RmN20000T>O1P000UON100000=Sg@0000000P000V_L10000W>k0`0017>j00<007>J00000gNI0P00
0gNI0P000gMi00D007Mh001cN@0000=gN08000=cF005001cF000LeP00003LeP20003LeP01000LeQc
F0000g=H00@007=HLeP0009_>@06001_>FliKcT006li0P000fli00@006liKcT0009_>@04001_>Fli
0002KcT01000KcU_>@000Vli00@006/iJcT0009[>@07001[>F/i001[6@00JaT00P000V/I00@006/I
JaT0009[6@06001[6F/I001[6@000V/I00@006/I0000009[6@07001[6F/I001[6@00JaT00P000V/I
00<006/I00000V/I00@006/IJaT0009[6@03001[6@00009[6@04001[6@00JaT20002IaT01P00IaT0
06LI001Vn@80009Vn@03001Vn@00009Vn@04001Vn@00I_T20002I_T02P00I_T006Ki001Vn@00I_T0
06Ki0P000V;i00<006;i00000V;i00H006;i001Rf@00H]T300002ekI001NfEkI001NfP00G]X005kJ
00000UkJ0P0000]J^P00F[X005Zj001J^P00E[X005Jj00h00009CY/004ik001>N`00BW/004Yk0080
0003AW/004Ik00800005AW/004IK0012F`0200000d9K00000002000013iK000003iK0P0000@nF`00
000nF`@00003>U/003YL00800004>U`00000>U`4000013Xl000003Hl0P0000<fG000=S`00`0000Df
?000=S`0038l00H00005;S`00000000^?00200000bXL000Z700400000bHL000V700200001RXm0000
02Hm000Z?@<00006;Wd00000<Wh003JN0P0000<n_P00?]h00P0000I6oP00Bah004lN0002Dch01@00
Ech005/m00000U]M00L005mM001OG@00He`00002He`01`00IeaWG000Ie`006MK0080009WF`03001[
F`00009[F`03001[F`00009[F`05001[Ff]K001[FP02000026]J001[FV]J001[FP00JeX20002JcX0
0`00JcX00002JcX30002JcX00`00JcX00002JcX30002JcX01@00JcY[>P00JcX00`000V/j00<006/j
00000V/j00D006/j001W6P00009W6P08001W6VLJ001W6P00IaX0009W6P03001W6P00009W6P03001W
6P000080009W6P05001W6P00IaX00002IaX300001fLJ001W6VLJ001W6P00009W6P<00004IaX006Kj
0002I_X00`00I_X00002I_X300001V;j001RnP00H_X0009RnP04001RnP00H_X3000016;j001RnP00
0V;j00L006;j001RfP00G]X00002G]X00`00G]X0000200006UkJ001NfP00G]X005kJ001JfP00F]X0
05[J001J^P00F[X005Zj001J^P00E[X005Jj0002E[X07`00E[X00000E[X005Jj001F^P00DYX005:J
001BVP00DY/005:K001BV`00DY/005:K001BV`00CY/004jK0080000=CY/004jK001>V`00CY/004jK
001>V`00CY/00P0000e>V`00CY/004jK001>V`00CY/004jK001>V`0200006djK001>V`00CY/004jK
001>V`00C[/004jk001>^`00C[/004jk001B^`00D[/005:k001B^`0P000085:k001B^`00D[/005:k
001B^`00D[/005:k001Bf`00D]/005;K001Bf`00D]/005;K001Bf`00E]/005KK0002E]/03@00E]/0
05KK001Ff`00E]/005KK001Ff`0001]oo`03001oogoo03]oo`00IGoo00<007ooOol0Ggoo00P005;L
001Bg000D]`005;L0P0000=Bg000D]`0<P0000E>_000C[`004Zl00800005B[`004ZL001:W0020000
0dJL0016W00600001D:L00000000?W`00P0000@jG000000fG0800003<S`0000000P00004;ch00000
=eh6000014^O000004no100000AOgP00000000=Wg@<000=_g0<0009c^`800003LkX007>J009cVP03
001gV@00009cV@03001gV@00009cN@05001gNGMiMgT00003LgT00`00MgP00002LgT01@00LeQcF7=H
00000g=H00D007=H001cF@0000=cF004001cF0000003LeP01000LeP000000fli00D006liKcU_>@00
009_>@05001_>Fli001_>@020002KcT01@00KcU_>@00KcT00P000Vli00D006liKcT006/i0080009[
>@05001[>F/i001[6@020002JaT01`00JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT00`00
JaT00002JaT01000JaU[6@000V/I00<006/I00000V/I00L006/IJaT006/I001[6@020002JaT01`00
JaU[6@00JaT006/I0080009W6@05001W6@00IaT00002IaT00`00I_T00002I_T01P00I_UVn@00I_T0
009Vn@03001Vn@00009Vn@03001VnFKi0080009Vn@<0009Vn@05001Rn@00H_T00002H_T01000H_T0
06;I0P0000=Rf@0000000UkI00D005kI001NfP00009NfP08001NfP00G]X005Zj001J^P800003F[X0
000000@00007E[X005Jj001FVP00DYX00P0000EBVP00DYX004jJ00P00003BW/004Yk00800005AW/0
04Ik0016N`0200000d9K0012F`0200000d9K0012F`0300000ciK000nF`0200001SiK000003iK000n
F`800003>U`003YL00800006>U`00000>U`003YL0`0000<f?000=U`00P0000<f?00000000`0000Lf
?0000000038l000b?005000012hl000002hl0P0000DZ7000:S`002Xl008000039Q`002Xl00800003
:Sd0000000800005:Ud00000000bOP0400001CZn000n_P00?]h00P0000I6oP00Bah004lN0002Dch0
1P00Ech005/m001KG@D0009SG007001SG6=L001WG000Ie`00P000VMK00H006MK001[F`00Je/20002
Je/01000Je][F`000V]K00<006]K00000V]J00@006]J001[FP800008JcX006/jJcX006/j001[>P80
009[>P03001[>P00009[>P<0009[>P03001[>P00009[>P03001[>P00009[>P03001[>P00009[>P03
001[>V/j0080009W6P07001W6VLJ001W6P00IaX00`000VLJ00P006LJIaX006LJ001W6P000VLJ00<0
06LJ00000VLJ00<006LJ00000P0000UW6P00IaYW6P00IaX006LJ00000VLJ00D006LJ001W6P00009V
nP03001VnP00009VnP<00004H_X006;j0002H_X03@00H_X006;j001RnP00H_X006;j001RnP00009R
nP07001RnP00H_X006;J00000UkJ1@0001ANfP00G]X005kJ001NfP00G]X005[J001JfP00F]X005Zj
001J^P000UZj00H005Zj001F^P00E[XT00002DjK001>V`00CY/004jK001>V`02000084jK000004jK
001>V`00CY/004jK001>V`00CY/004jK001>V`00CY/004jK001>V`00CY/004jK001>^`00C[/20000
7djk001>^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k0080000GD[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`020000
85;K001Bf`00D]/005;K001Bf`00D]/005;K001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0
05KK000KOol00`00Oomoo`0kOol006Ioo`03001oogoo05moo``0000;D]`005;L001Bg000D]`005;L
001Bg00200003E;L001Bg000D]`005;L001B_000D[`005:l0080000=D[`005:l001B_000D[`004jl
001>_000C[`00P0000M>_000C[`004jl001>_00;00001DZL001:W000AY`00P0000=6W000AY`00P00
00=2W000@W`00`0000<nO00000000P0000DfG000000002hl00h00004=el00000@il6000015No0000
00000V?N0P0000AWg@00Jme[g@800005Km`006nlKk`00003Lk/20003LiX20004LiT20003LgT01@00
MgT007=i00000g=i00<007=iLgT00W=i00@007=H000000AcF005001cFG=ILeT00003LeP01000LeUc
F@000g=H00@006mIKeT000=_>@04001_>@000003KcT01000KcU_>@000Vli00@006liKcT0009_>@04
001_>Fli0002KcT01000KcU_>@000V/i00@006/iJcT0009[>@03001[6@0000=[6@04001[6@00JaT2
0002JaT01`00JaU[6@00JaT006/I0080009[6@07001[6F/I001[6@00JaT00P000V/I00L006/IJaT0
06/I001[6@020002JaT01P00JaU[6@00JaT0009[6@03001W6@00009W6@03001W6FLI00800003IaT0
0000009Vn@09001VnFKi001Vn@00I_T006Ki0080009Vn@03001Vn@00009Vn@03001Vn@0000800007
I_T006KiI_T006;i00000V;i00@006;i001Rn@80000:H]T006;I001Rf@00G]T005kI0002G]X02000
G]X005kJ001NfP00F[X500001UZj001J^P00E[X0009F^P800009EYX005:J001BVP00DYX005:J0080
0007CY/004jK001>N`00BW/01`0000E6N`00AW/004IK00800003@U/0049K00800003@U/0049K0080
0004?U/00000?U/200000ciK000nF`0200001SiK000003YL000jG0800006>U`00000>U`003YL0`00
00LfG000=U`003Hl000f?00500000c8l000b?00200000c8l00000003000012hl000002hl0P0000DZ
?000000002Xl00800003:S`002Xm00800003:Sd002iM00800007;Ud00000000fWP00=Yh0100000dn
gP00@]h004Kn001;7P00Cah005<n001G?P0400001U/m001OG@00Ged0009SG004001SG000Ie`20000
26ML001WFfMK001WF`00Je/20002Ie/01`00Je][F`00Je/006]K0080009[F`03001[FP00009[FP03
001[>P00009[>P03001[>P00009[>P03001[>P00009[>P04001[>P00JcX200001F/j001[>V/j0000
0V/j00<006/jJcX00P000V/j00L006/jJcX006/j001[>P02000016LJ001W6P000VLJ00P006LJ0000
06LJ001W6P000VLJ00@006LJ001W6P<0009W6P0:001W6VLJ001W6P00IaX006LJ0002IaX01@00IaX0
06LJ00000VLJ0`0000UW6P00IaYW6P00I_X006Kj00000VKj00D006;j001RnP00009RnP08001RnP00
H_X006;j001RnP<0009RnP09001RnP00H_X006;j001RnP00009RfP<00006G]X005kJ001NfP000UkJ
00@005kJ0000009NfP800004F]X005[J0002F[X00`00F[X0000800001eJj001F^P00E[X005Jj0080
000IE[X005:j001BVP00DYX005:K001BV`00DY/005:K001BV`00DY/005:K001BV`00CY/0300000M>
V`00CY/004jK001>V`020000=DjK001>V`00CY/004jK001>V`00CY/004jK001>V`00CY/004jK001>
^`00C[/004jk001>^`00C[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/00P0001UB^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`03000085;K001Bf`00D]/005;K001Bf`00D]/005;K001Ff`00E]/005KK001Ff`00E]/005KK001F
f`00E]/005KK000KOol00`00Oomoo`0kOol006Ioo`03001oogoo05moo`08001Bg000D]`005;L001B
g080000>D]`005;LD]`005;L001Bg000D]`005;L001Bg080000=D]`005;L001Bg000D]`005:l001B
_000D[`00P0000eB_000D[`005:l001B_000C[`004jl001>_00200001Djl001>_000C[`00P0000E>
_000C[`004Zl00800003B[`004Zl00H00003AY`004JL00800003@Y`004:L00<00006?W`00000>W`0
03YL0P0000LfG000000002hl000V700200000agL0000000;00000dNO001?_`030002Fkh200000f?N
000000020002Jmd30003Kk`00`00Lk/00002Lk/00`00LiX00002LiX01`00LiUcVG>I001cVP0000=c
N@09001cNG=iLgT007=i001cN@0000AcN@04001cFG=I0003LeP00`00LeUcF@02LeT01000LeQcF000
0g=I00@007=HLeP000=_F@05001_>FliKcT00002KcT01@00KcU_>@00KcT00P000Vli00D006liKcT0
06li0080009_>@05001_>Fli001_>@020003JcT01000JcT006/i0P000V/I00@006/IJaT0009[6@03
001[6@0000=[6@03001[6@00009[6@06001[6F/I001[6@000V/I00@006/I0000009[6@03001[6@00
009[6@06001[6F/I001[6@000V/I00L006/IJaT006/I001[6@020002IaT02000IaUW6@00IaT006LI
0002I_T00`00I_T00002I_T01000I_T006Ki0P000VKi00<006Ki00000VKi00L006Ki001Vn@00I_T0
0002I_T00`00I_T00002H_T00`00H_T00002H_T01@00H]T006;I00000V;I0P000UkI00X005kI001N
fP00G]X005kJ001NfP<00004F[X005Zj0002F[X03000F[X005Jj001F^P00E[X005JJ001BVP800009
DYX005:J001>VP00CY/004jK00800003BW/004Yk00800003BW/0000000800007AW/004IK0012F`00
@U/00P0000A2F`000012F`D00003?U/003iK00800003?U/003iK00800006?U`00000>U`003YL0P00
00@jG000000jG0D00003=U`003Hl00<00003=S`0000000<00003<S`0038l00800004<S`00000;S`2
000012hl000002hl0P0000DZ?000000002Xm00800005:Sd002Xm000Z?@0200001biM00000000<Wh0
03JN00800003>[h003jn00d00004Ech005/m0002Fcd01P00Ged005mM001SG0@00008He`006MLIe`0
06MK001WF`800003Ie/006MK009WF`04001[F`00Je/20002Je/01P00Je/006]J001[FP80009[>P03
001[>P00009[>P<0009[>P08001[>V/j001[>P00JcX0009[>P07001[>V/j001[>P00JcX00P0000Q[
>P00JcY[>P00JcX006/j0P000VLj0P000VLJ00H006LJIaX006LJ0002IaX20002IaX02000IaYW6P00
IaX006LJ0002IaX00`00IaX00002IaX20002IaX01@00IaX006LJ00000VLJ0`0000UW6P00IaYW6P00
IaX006Kj00000VKj0`0000aRnP00H_YRnP00H_X006;j001RnP00H_X2000036;j001RnP00H_X006;j
001RnP00H_X0009RnP<00006G]X005kJ001NfP000UkJ00P005kJ001NfP00G]X005kJ0P000U[J00<0
05[J0000100001EJ^P00F[X005Jj001F^P00E[X005Jj001F^P00E[X005Jj001F^P00D[X00P0001mB
VP00DY/005:K001BV`00DY/005:K001BV`00DY/005:K001>V`00CY/004jK001>V`00CY/004jK001>
V`0:00001djK001>V`00CY/004jK0080000[CY/004jK001>V`00CY/004jK001>^`00C[/004jk001>
^`00C[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P0002iB
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005;K001B
f`00D]/005;K001Bf`00D]/005;K001Ff`00E]/0009Ff`0=001Ff`00E]/005KK001Ff`00E]/005KK
00006goo00<007ooOol0>Woo001WOol00`00Oomoo`1OOol02000D]`005;L001Bg000D]`200005E;L
001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`005;L001Bg00200003E:l001B_000D[`005:l
001B_000D[`005:l00800007C[`004jl001>_000C[`00P0000]>_000C[`004jl001>_000C[`004Zl
00800008B[`00000BY`004ZL0016W0D00005@Y`004:L0012O002000013il000003Yl0P0000DfG000
000002hl00@000038O`0000001400004Dkl00000Fkh30003Hmd30002Jk`2000016nl000000000g>k
0P000g>J00<007>I00000g>J00D007=i001cN@0000=cN@05001cNG=iLgT00003LgT02@00LeUcFG=I
001cF000LeT00003LeT01@00LeP007=I00000W=I00D007=H001_F@0000=_F@04001_>@000003KcT0
1000KcU_>@000Vli00@006liKcT0009_>@04001_>Fli0002KcT01000KcU_>@000V/i00@006/iJcT0
009[>@04001[6F/I0002JaT01P00JaU[6@00JaT0009[6@07001[6F/I001[6@00JaT00P000V/I00@0
06/IJaT0009[6@03001[6@00009[6@07001[6F/I001[6@00JaT00P000V/I00L006/IJaT006/I001[
6@020002IaT00`00IaT00002IaT00`00IaUW6@020002I_T01`00I_UVn@00I_T006Ki00800005I_T0
06KiI_T00002I_T00`00I_T00002I_T20002I_T00`00I_T00002I_T01P00H_T006;i001Rn@80009R
f@0>001Rf@00H]T006;I001Nf@00G]T005kJ001NfP@0000EG]X005Zj001J^P00F[X005Zj001J^P00
E[X005Jj001F^P00EYX005:J0080000;DYX005:J001>VP00CY/004jK001>N`0200000dYk001:N`02
00000dYk0016N`0400001D9K0012F`00@U/00P0000M2F`00000003iK000nF`0200001CiK000nF`00
?U/00P0000@nF`00000jG0800003>U`003YL00800005>U`00000000jG004000013Hl000003Hl0P00
00Hf?000000b?000<S`20000138l0000038l0P0000@^?000000^?0800004;S`00000:S`3000022Xm
000002Xm000Z?@00;Ud200002C9m000bOP00=Yh003JN000j_P02000034;N0016oP00B_h004lN001?
7P00Dah0009G?P08001K?@00Fcd005mM001OG@800004He`006=L0002He`01000Ie`006MK0P0000EW
F`00Ie]WF`00009WF`06001[F`00001[F`000V]K00@006]K001[FP80009[>P06001[>P00JcX006/j
0P000V/j00P006/jJcX006/j001[>P000V/j00L006/jJcX006/j001[>P020002JcX20002JcX01P00
JcX00000IcX0009W>P06001W6P00IaX006LJ0P000VLJ00P006LJ001W6P00IaX006LJ0P000VLJ0P00
0VLJ00@006LJ001W6P800004IaX006LJ0002IaX00`00IaX0000200002FLJ001W6VLJ001W6P00IaX0
0002I_X300002FKj001RnV;j001RnP00H_X00002H_X300001V;j001RnP00H_X0009RnP80009RnP03
001RnP0000800004G]X005kJ0002G]X03P00G]X005kJ001NfP00G]X005kJ001NfP00F]X5000035Zj
001J^P00F[X005Zj001F^P00E[X0009F^P06001F^P00E[X005Jj0P0001MF^P00D[X005:J001BVP00
DY/005:K001BV`00DY/005:K001BV`00DY/005:K0080000=CY/004jK001>V`00CY/004jK001>V`00
CY/00P0000E>V`00CY/004jK00/0000=CY/004jK001>V`00CY/004jK001>^`00C[/00P0001m>^`00
C[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`02
00005e:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P00015Bf`00
D]/005;K001Bf`00D]/005;K001Bf`00E]/005KK00l001]oo`03001oogoo03Yoo`00J7oo00<007oo
Ool0Ggoo01L005;L000005;L001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`005;L0080000=
D]`005;L001Bg000D]`005:l001B_000D[`00P0000eB_000D[`005:l001B_000C[`004jl001>_002
00001Djl001>_000C[`00P0000E>_000C[`004Zl00800007B[`004Zl001:W000BY`00P0000=6W000
AY`01@0000=2O000?W`00P0000@nO000000jG0800005=U`00000000^?00400000b7l000E^`0>0000
0dNO0000000400001Enn000006?M00000VNm0P0000A[_0000000009_^`03001c^`00009_V`04001c
VW>JLiX20004LiX02@00LgUcNG=i001cN@00LgT00003LgT01@00LgT007=i00000g=I00D007=ILeUc
F@0000=cF@05001cFG=ILeT00002LeT01@00KeU_FFmI00000fmI00@006liKcT0009_>@04001_>@00
0002KcT01@00KcU_>@00KcT00P000fli00@006li001_>@8000=[>@06001[>F/i001[>@000f/I00<0
06/I00000f/I00<006/I00000V/I00H006/IJaT006/I0002JaT01`00JaU[6@00JaT006/I0080009[
6@07001[6F/I001[6@00JaT00P000V/I00<006/I00000V/I00H006/IJaT006LI0002IaT01`00IaUW
6@00IaT006LI00800007IaT006KiI_T006Ki00000VKi00<006Ki00000VKi00T006KiI_T006Ki001V
n@00I_T00P0000AVn@00I_T0009Vn@06001Vn@00H_T006;i0P000V;i00h006;I001Rf@00H]T006;I
001Nf@00G]T005kJ0P00011NfP00G]X005kJ001J^P00F[X005Zj001J^P00F[X0009F^P0A001F^P00
001FVP00DYX005:J001BVP00DYX004jJ001>V`0200001Dik001:N`00BW/00P0000=:N`00BW/00P00
00=6N`00AW/00P0000=2F`00@U/00P0000=2F`00@U/00P0000@nF`00000nF`800005?U/003iK000n
F`02000013iL000003YL1@0000<jG000>U`00`0000DjG000000003Hl00<00004=S`00000=S`20000
0c8l000b?0020000138l0000038l0P0000@^?000000^?0800004;S`00000:S`3000022hm000002Xm
000^G@00;Ud600006CJN000j_P00?[h004;N0016oP00B_h004lN001?7P00Dah005Ln001K?@00Fcd0
05mM00800007Ged006=LHe`006=L00000V=L00D006ML001WG000009WF`04001WFfMK0002Ie/00`00
Ie/00002Je/00`00Je/00002Je/00`00Je/00002JcX01000JcX006/j0P0000E[>P00JcY[>P00009[
>P08001[>P00001[>P00JcX0009[>P06001[>P00001[>P000V/j00<006/j00000V/j00<006Lj0000
0VLj00H006Lj001W6P00IaX200002VLJ001W6VLJ001W6P00IaX006LJ0P0000YW6P00IaYW6P00IaX0
06LJ001W6P800004IaX006LJ0002IaX01`00IaX006LJ001W6P00009W6P05001W6P00IaX00002IaX3
00002FKj001VnVKj001RnP00H_X00002H_X3000016;j001RnP000V;j00H006;j001RnP00H_X50000
16;J001NfP000UkJ00T005kJ001NfP00G]X005kJ00000UkJ0P0000aNfP00000005[J001JfP00F[X0
05Zj0002F[X05000F[X005Jj001F^P00E[X005Jj001F^P00E[X005Jj001F^P00D[X200007E:J001B
V`00DY/005:K001BV`00DY/005:K001BV`00DY/004jK001>V`00CY/004jK001>V`00CY/00P0000E>
V`00CY/004jK0080000;CY/004jK001>V`00CY/004jK001>V`0A00006djk001>^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0200006E:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k01D0000>E]/005KK001Ff`00E]/005KK001F
f`00E]/001]oo`03001oogoo03Yoo`00J7oo00<007ooOol0Ggoo00P005;L001Bg000D]`005;L0P00
00QBg000D]aBg000D]`005;L0P0000]Bg000D]`005;L001Bg000D]`005;L0080000=D[`005:l001B
_000D[`005:l001B_000D[`00P0000e>_000C[`004jl001>_000C[`004jl001>_00200001Djl001>
_000B[`00P0000E:_000B[`004ZL00800009AY`004JL0016W000@Y`004:L00@00004?W`00000>W`2
00001CIL00000000<S`00`0000<V700000000`0000<AV`001GX030000T^O0P0000=G_`0000000`00
16Nm00H006^lJka[_000Kk/30003Ki/00`00LiX00002LiX01@00LiYcVW>J000017=i00D007=iLgUc
N@0000=cN@09001cNG=iLgT007=I001cF@0000=cF@04001cF@000003LeT01000LeT000000fmI00D0
06mIKeU_F@0000=_>@04001_>Fli0002KcT01000KcU_>@000Vli00@006liKcT0009_>@04001_>@00
0002KcT01000JcU[>@000f/i00<006/i00000V/I00D006/IJaT006/I0080009[6@03001[6@0000=[
6@80009[6@04001[6F/I0002JaT01P00JaU[6@00JaT0009[6@06001[6F/I001[6@000V/I00L006/I
JaT006/I001[6@020002IaT01`00IaUW6@00IaT006LI00800004IaT006LI0002I_T01000I_T006Ki
0P000VKi00<006Ki00000VKi00@006Ki001Vn@800004I_T006Ki0002I_T01P00I_T006Ki001Rn@80
000>H_T006;iH_T006;I001Rf@00H]T006;I001Nf@@00008G]X005kJG]X005kJ001NfP80000<F[X0
05ZjF[X005Zj001J^P00E[X005Jj0P0000mFVP00DYX005:J001BVP00DYX004jJ001>V`00CY/00P00
00=:N`00BW/00P0000M:N`00BW/004Ik0016N`0200000dIk0000000300000d9K0012F`0200000ciK
000nF`0200000ciK0000000200000ciK000nF`0200001SYL000003YL000jG0<00004>U`00000>U`2
00000cYL00000002000013Hl000003Hl0P0000<f?00000000P0000@b?000000b?0800004<S`00000
;S`2000012hl000002hl0P0000DZ?@00000002iM00@00007;Ud0039m000fWP00=Yh01000014n_P00
@]h004Kn001:oP00Cah004lN001C7P00Ech005/m00@00005Gcd005mMGed00002He`01000He`006=L
0`000VML00L006MKIe/006MK001WF`020002Ie/00`00Je/00002Je/30002Je/00`00JcX00002JcX0
0`00JcX00002JcX01000JcY[>P000V/j00D006/j001[>P00009[>P06001[>V/j001[>P000V/j00H0
06/j001[>P00JcX20002IcX00`00IcX00002IcX300001fLJ001W6VLJ001W6P00009W6P<0000:IaX0
06LJIaX006LJ001W6P00IaX200002VLJ001W6VLJ001W6P00IaX006LJ0`000VLJ00D006LJ001W6P00
009W6P<00009I_X006KjI_X006Kj001RnP00009RnP<00004H_X006;j0002H_X03`00H_X006;j001R
nP00H_X006;j001RnP00H]X00002G]X01`00G]X005kJ001NfP00009NfP03001NfP0000@00003G]X0
0000009JfP80009J^P0H001J^P00F[X005Zj001F^P00E[X005Jj001F^P00E[X005Jj001F^P00E[X0
05:j0P00025BVP00DY/005:K001BV`00DY/005:K001BV`00DY/005:K001>V`00CY/004jK001>V`00
CY/004jK001>V`00CY/00P0000=>V`00CY/00P0001U>V`00CY/004jK001>V`00CY/004jK001>V`00
CY/004jK001>^`00C[/004jk001>^`0h00006U;K001Bf`00D]/005;K001Bf`00D]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK0002E]/2000015KK001Ff`0077oo00<007ooOol0>Goo001YOol00`00
Oomoo`1OOol04@00D]`00000D]`005;L001Bg000D]`005;L001Bg000D]`00P0000=Bg000D]`08`00
00=>_000C[`00P0000U>_000C[`004Zl001:_000B[`00P0000=:W000BY`00P0000=6W000AY`00P00
00I2W0000012O000@W`5000013YL000003IL0`0000D^?0000000027l00T000030?L0000000P00004
Bil000000002Ekl02000Gkh00000Ikd006Nm0003Jk`20002Kk/2000016nK000000000g>J00D007>J
001cVP0000=cN@8000=cN@04001cN@000004LgT01@00LeUcFG=I00000g=I00@007=ILeT000=cF@04
001cFG=I0003KeT01@00KeT006li00000Vli00@006li0000009_>@05001_>Fli001_>@020003KcT0
1P00KcU_>@00KcT000=_>@05001[>F/i001[>@020002JcT01@00JaU[6@00JaT00P000V/I00<006/I
00000V/I00H006/I000006/I0002JaT01000JaT006/I0P000V/I00L006/IJaT006/I001[6@020002
JaT01`00JaU[6@00JaT006/I0080009W6@03001W6@00009W6@06001W6FLI001W6@000VLI00H006LI
001Vn@00I_T20002I_T00`00I_T00002I_T01000I_T006Ki0P0000aVn@00I_UVn@00I_T006Ki001V
n@00I_T200001f;i001RnF;i001Rn@00009Rf@80009Rf@<00004G]X005kJ0002G]X06P00G]X005kJ
001NfP00F[X005Zj001J^P00F[X005Zj001F^P00E[X005Jj001FVP00DYX200002E:J001BVP00CYX0
04jK001>V`0200001dYk001:N`00BW/004Yk00800005AW/004Ik0016N`0200000dIk0012F`020000
1T9K0000049K000nF`800006?U/00000?U/003iK0P0000<nF`00?U`00P0000@jG000000jG0D00004
>U`00000>U`200000cYL000jG002000013Hl000003Hl0P0000<f?000=S`00P0000@b?000000b?080
0004<S`00000;S`2000012hl000002hm0P0000LZ?@00000002iM000bG@020000139m000003JN0P00
00<j_P00?[h04@0000AK?@00Fcd0009O?@07001OGEmM001SG000He`00P0000ASG000Ie`0009WG004
001WF`00Ie/20002Ie/01P00Ie/006]K001[F`80009[F`05001[Ff]K001[>P030002JcX01`00JcY[
>P00JcX006/j0080009[>P06001[>P00JcX006/j0P000V/j00<006/j00000V/j0`000VLj00D006Lj
001W>P00009W>P03001W6P00009W6P03001W6P00009W6P<00007IaX006LJIaX006LJ00000VLJ0`00
00UW6P00IaYW6P00IaX006LJ00000VLJ00L006LJ001W6P00IaX00002IaX00`00IaX00002000016Kj
001VnP000VKj00<006Kj00000V;j0`0000ARnP00H_X0009RnP08001RnP00H_X006;j001RnP<0009R
nP0;001RnP00H]X005kJ001NfP00G]X00002G]X5000075kJ001NfP00G]X005[J001JfP00F]X005Zj
001J^P00F[X005Zj001F^P00E[X005Jj001F^P000UJj01T005Jj000005Jj001B^P00DYX005:J001B
V`00DY/005:K001BV`00DY/005:K001BV`0200004djK001>V`00CY/004jK001>V`00CY/004jK001>
V`00CY/004jK0080000=CY/004jK001>V`00CY/004jK001>V`00CY/00P0002M>V`00CY/004jk001>
^`00C[/004jk001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/00P00029B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D]/005;K001Bf`00D]/0009Bf`0B001Bf`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK
0P0000AFf`00E]/001Qoo`D003]oo`00JGoo00<007ooOol0H7oo5@0000UBg000D]`005;L001Bg000
D]`00P0000eB_000D[`005:l001B_000D[`005:l001B_00200002Djl001>_000C[`004jl001>_00=
00001DZl001:_000BY`00P0000E6W000AY`004JL00<00003@Y`0049l00800007?W`003il000jG000
=U`00`0000@b?000000Z?0D000036M/000000100009?W`800003Ekl005nn00<0009W_@03001[_000
009[_004001_^fnkKk/20002Ki/200000g>J00000003LiX00`00LgT00002LgX01@00LgUcNG=i0000
0W=i00@007=iLgUcN@8000=cF@04001cF@000003LeT01000LeT000000g=I00D006mIKeU_F@00009_
>@05001_>FliKcT00002KcT01000KcU_>@000Vli00@006liKcT0009_>@04001_>@000002KcT01000
KcU_>@000f/i00H006/iJcT006/i0003JaT00`00JaT00002JaT01@00JaU[6@00JaT00P000V/I00H0
06/I001[6@00JaT20002JaT01`00JaU[6@00JaT006/I0080009[6@03001[6@00009[6@06001[6F/I
001W6@000VLI00L006LIIaT006LI001W6@020002IaT01@00IaT006LI00000VKi00<006Ki00000VKi
00H006KiI_T006Ki0002I_T00`00I_T00002I_T02000I_T006Ki001Vn@00I_T200001f;i001RnF;i
001Rn@00009Rn@04001Rf@00H]T300002f;I001NfUkJ001NfP00G]X005kJ00000UkJ0P0000]J^P00
F[X005Zj001J^P00F[X005Jj01@00005CW/004Yk001:N`0200001DYk001:N`00AW/00P0000I6N`00
0016N`00@U/700000ciK000nF`0200000ciK000nF`02000013iK000003iL0P0000<jG000>U`00`00
00<jG00000000P0000HjG000000jG000>U`2000013IL000003Hl0P0000<f?000=S`00P0000@f?000
000b?0800004<S`00000<S`2000012hl000002hl0P0000@^?@00000^?@800004;Ud00000<Wd20000
0c9m000fWP0200004cZn000004;N0016gP00A_h004[n001?7P00Dah005<N001G?@00009K?@03001K
?@00009O?@04001OG@00He`200002V=L001SG6=L001WG000Ie`006MK0P0000QWF`00Ie]WF`00Ie/0
06]K0P0000=[F`00Je/00V]K00D006]K001[>P00009[>P07001[>V/j001[>P00JcX00P000V/j00H0
06/j001[>P00JcX20002JcX01P00JcX006/j001[>P800007IcX006LjIcX006Lj00000VLj0`000VLJ
00D006LJ001W6P00009W6P03001W6P00009W6P05001W6P00IaX00002IaX00`00IaX00002IaX02000
IaX006LJ001W6P00IaX2000016LJ001W6P000VLJ00L006LJ001W6P00I_X00002I_X01@00I_X006Kj
00000VKj0`0000ARnP00H_X0009RnP05001RnP00H_X00002H_X300003V;j001RnP00H_X006;j001R
fP00G]X005kJ0002G]X3000025kJ001NfP00G]X005kJ0002G]X20002F]X2000025Zj001J^P00F[X0
05Zj0002E[X01P00E[X005Jj001F^Qh0000;CY/004jK001>V`00CY/004jK001>V`0200001DjK001>
V`00CY/00P00025>V`00CY/004jK001>V`00CY/004jK001>V`00CY/004jK001>V`00C[/004jk001>
^`00C[/005:k001B^`00D[/00P0001=B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`0200002U:k001B^`00D[/005:k001B^`000U:k00h005:k001B^`00D[/005:k001B^`00D[/005:k
0`00021Bf`00D]/005;K001Bf`00D]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`006goo00<007ooOol0>Goo001ZOol00`00Oomoo`1OOol04@00D]`00000D]`005;L001B
g000D]`005;L001Bg000D]`00P0000aBg000D]aBg000D]`005;L001Bg000D]`200003E:l001B_000
D[`005:l001B_000D[`005:l00800007C[`004jl001>_000C[`00P0000=>_000C[`00P0000M>_000
C[`004Zl001:_00700001DJL0016W000AY`00P0000=2W000@Y`00P0000=2O000?W`01P0000@fG000
000b?0<00003:Q`0000000<000035K/0000001000003Cil0000000<0009O_P03001W_@00008000=[
_003001_^`00009_W005001_VfnKKi/00002KiX01000LiYcVW>J0P000g=j00@007=i000000=cN@03
001cN@00009cF@05001cFG=ILeT00002LeT01@00LeUcFG=I00000W=I00H007=ILeUcF@00KeT20003
KcT01000KcU_>@000Vli00D006liKcT006li008000=_>@04001_>Fli0002KcT01000KcU_>@000Vli
00@006/i0000009[>@05001[>F/i001[6@020002JaT01000JaU[6@000V/I00<006/I00000V/I00<0
06/I00000V/I00<006/I00000V/I00@006/IJaT0009[6@03001[6@00009[6@07001[6F/I001[6@00
JaT00P000VLI00L006LIIaT006LI001W6@020002IaT02000IaT006LI001W6@00I_T20002I_T02@00
I_UVn@00I_T006Ki001Vn@020002I_T02000I_T006Ki001Vn@00I_T200001f;i001RnF;i001Rn@00
009Rn@09001Rn@00H]T006;I001Rf@00009Rf@05001NfP00G]X00002G]X01000G]X005kJ0P0000EJ
^P00F[X005Zj00H00003E[X005Jj0080000?E[X005:J001BVP00DYX005:J001BVP00CY/004jK00L0
0009BW/004Yk0016N`00AW/004Ik00800007AW/000000012F`00@U/00P0000DnF`00?U/003iK0080
0003?U/003iK00800003?U`0000000<00003>U`003YL00<00003>U`0000000800006>U`00000>U`0
03YL0P0000@fG000000f?0800003=S`003Hl00800004<S`00000<S`20000138l0000038l0P0000@^
?000000^?@800006;Ud00000;Ud002iM0`0000<bO@0000000P0000<fWP00>[h00P000112gP00A]h0
04Kn001:oP00Cah005<N001C7P00Ecd0009K?@04001K?@00Gcd400002UmL001SG6=L001SG000Ie`0
06ML0P0000QWF`00Ie]WF`00Ie/006MK0P0000EWF`00Je][F`00009[F`03001[F`000080009[>P05
001[>V/j001[>P0200001f/j001[>V/j001[>P00009[>P03001[>P00009[>P03001[>P00009[>P03
001W>P00009W>P03001W>P00009W>P<00007IaX006LJIaX006LJ00000VLJ0`000VLJ00D006LJ001W
6P00009W6P<0009W6P05001W6P00IaX00002IaX300002VLJ001W6VLJ001W6P00IaX006LJ0`000VKj
00D006Kj001VnP00009VnP<00004H_X006;j0002H_X01@00H_X006;j00000V;j0`0000QRnP00H_X0
06;j001RnP000V;j0P000UkJ00<005kJ00000P0000INfP00G]X005kJ0002G]X02000G]X005kJ001J
fP00F]X2000025Zj001J^UZj001J^P00F[X900002EJj001F^P00E[X005Jj001F^P0200004E:j001B
V`00DY/005:K001BV`00DY/005:K001BV`00DY/03`0000I>V`00001>V`00CY/20000<DjK001>V`00
CY/004jK001>V`00CY/004jK001>V`00CY/004jk001>^`00C[/004jk001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k0080000MD[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`03000065;K001Bf`00D]/005;K001Bf`00
E]/005KK001Ff`00E]/005KK001Ff`00E]/0009Ff`800004E]/005KK000KOol00`00Oomoo`0iOol0
06]oo`03001oogoo05moo`0A001Bg000001Bg000D]`005;L001Bg000D]`005;L001Bg00200002e;L
001Bg000D]`005;L001Bg000D]`00P0000eB_000D[`005:l001B_000D[`005:l001B_00200003Djl
001>_000C[`004jl001>_000C[`004jl00800005C[`004jl001:_00200001DZl001:_000BY`01`00
00=6W000@Y`00P0000Y2O000000nO000?W`003Yl000jG0800004<U`00000;S`300000bHL000Mg00F
0002Cil01000Fil005nn0`000VNm0P0000A[_000000000=_W005001_V`00Ki/00002KiX00`00LiX0
0002LgX01@00LgYcNW=j00000W=i00D007=iLgUcN@0000AcF@04001cF@000003LeT01000LeT00000
0g=I00D007=ILeUcF@00009_F@08001_>Fli001_>@00KcT0009_>@04001_>Fli0002KcT01@00KcU_
>@00KcT00P000fli00D006liKcT006li0080009[>@04001[>F/i0002JcT01P00JaU[6@00JaT0009[
6@04001[6@000002JaT02000JaU[6@00JaT006/I0002JaT01`00JaU[6@00JaT006/I0080009[6@07
001[6F/I001[6@00JaT00P000VLI00<006LI00000VLI00H006LIIaT006LI0002IaT01@00IaUW6@00
IaT00`000VKi00<006Ki00000VKi00@006Ki001Vn@80009Vn@03001Vn@00009Vn@80009Vn@03001V
n@00009Rn@03001Rn@00009Rn@06001Rn@00H_T006;I0`000V;I00D006;I001NfP00009NfP08001N
fP00G]X005kJ001NfPD0000GF[X005Zj001J^P00E[X005Jj001F^P00E[X005:J001BVP00DYX005:J
001BVP02000024jK000004ik001:N`00BW/400001DIk0016N`00AW/00P0000=6N`00@U/00P0000A2
F`000012F`@00005?U/003iK000nF`0300000ciL000nG005000013YL000003YL0P0000<jG000>U`0
0P0000<jG000>U`00P0000@fG000000fG0800003=S`003Hl00800004=S`00000<S`20000138l0000
038l0P0000@b?000000^?0800004;Sd00000;Ud200000biM000bG@0300000cIm000jWP0400005Cjn
0012gP00A]h004Kn001:oP00Cah005<N001C7P00Ecd005/m001K?@02000015lm001O?@000UmL00H0
06=L001SG000Ie`2000026ML001WFfMK001WF`00Ie/200001FMK001WFfMK00000V]K00P006]KJe/0
06/k001[>`000V/j00H006/jJcX006/j0002JcX00`00JcX00002JcX30002JcX00`00JcX00002JcX3
0002IcX00`00IcX00002IcX300001fLJ001W6VLJ001W6P00009W6P<00007IaX006LJIaX006LJ0000
0VLJ0`0000MW6P00IaYW6P00IaX00002IaX300002FLJ001W6VLJ001W6P00IaX00002IaX01`00IaX0
06LJ001VnP00009VnP80009VnP05001RnP00H_X00002H_X01@00H_X006;j00000V;j0`0000ARnP00
H_X0009RnP80009RnP04001RnP00H]X5000015kJ001NfP000UkJ010005kJ001NfP00G]X005kJ001J
fP00F]X005[J001J^PL0000EE[X005Jj001F^P00E[X005Jj001F^P00E[X005Jj001F^P00D[X005:j
0080000KDY/005:K001BV`00DY/005:K001BV`00DY/005:K001BV`00CY/004jK001>V`00CY/004jK
00X0000;CY/004jK001>V`00CY/004jK001>V`0200009djK001>V`00C[/004jk001>^`00C[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0200008U:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001Bf`00D]/005;K
001Bf`000U;K010005;K001Ff`00E]/005KK001Ff`00E]/005KK001Ff`P001aoo`03001oogoo03Qo
o`00Jgoo00<007ooOol0Ggoo00H005;L000005;L0002D]`05`00D]`00000D]`005;L001Bg000D]`0
05;L001Bg000D]`005;L001Bg000D]`00P0000eB_000D[`005:l001B_000D[`005:l001B_0020000
1djl001>_000C[`004jl00800007C[`004jl001>_000C[`00P0000m:_000B[`004Zl001:_000BY`0
04JL0016W000AY`0100000I2W0000012O000?W`3000013Yl000003IL0P0000Db?000000002XL00D0
00045K/000000EX900002AJM000Zo`00>cl004Mo001?W`050002Gih2000016Nm000000000V^L00D0
06nLKia_W00000=_V`03001_VP00008000=cNP04001cNP000003LgT01@00LgT007=i000017=I00@0
07=ILeT000=cF@04001_FFmI0003LeT01000LeT000000fmI00@006liKcT0009_>@05001_>Fli001_
>@020003KcT01000KcU_>@000Vli00@006liKcT000=_>@03001[>@00009[>@05001[>F/i001[>@02
0002JaT01000JaU[6@000V/I00H006/IJaT006/I0002JaT01P00JaT00000JaT0009[6@04001[6@00
JaT20002JaT00`00JaT00002JaT01P00JaU[6@00IaT0009W6@07001W6FLI001W6@00IaT00P000VLI
00X006LIIaT006LI001W6@00I_T0009Vn@07001VnFKi001Vn@00I_T00P0000EVn@00I_UVn@00009V
n@04001Vn@00I_T30002I_T00`00H_T00002H_T01P00H_T006;i001Rn@800008H]T006;I001Rf@00
H]T0009NfP08001NfP00G]X005kJ001NfP<00004F[X005Zj0002F[X02000F[X005Zj001F^P00E[X2
00003EJj001BVP00DYX005:J001BVP00DYX004jK00800005CY/004ik001:N`0200000dYk001:N`04
00001TIk000004Ik0012F`800003@U/0049K00800003@U/0049K00800005?U/003iK000nF`020000
1CiL00000000?U`0100000HjG000000jG000>U`200001SYL000003YL000jG0800004=U`00000=U`2
00000cHl000f?0020000138l0000038l0P0000@b?000000b?0800006<S`00000;Sd002hm0`0000<b
G@0000000P0000@bO@00000fO@800003>Yh003jn00H00009A_h004[n001?7P00Dah005<N00H0000<
Fcd005lmGcd005lm001OG000He`006=L0P0000MSG000IeaWG000Ie/00002Ie/00`00Ie/00002Ie/0
1`00Ie]WF`00Je/006]K0080009[>`06001[>`00JcX006/j0P000V/j00<006/j00000V/j0`000V/j
00<006/j00000V/j0`000VLj00D006Lj001W>P00009W>P03001W>P00009W6P03001W6P00009W6P<0
0007IaX006LJIaX006LJ00000VLJ0`0000MW6P00IaYW6P00IaX00002IaX3000036LJ001W6VLJ001W
6P00IaX006LJ001W6P800004IaX006LJ0002I_X01000I_X006Kj0`0000URnP00H_YRnP00H_X006;j
00000V;j0`0000ARnP00H_X0009RnP0A001RnP00H_X006;j001RnP00H]X005kJ001NfP00G]X00002
G]X02@00G]X005kJ001NfP00G]X00002G]X200000e[J0000000300003UZj001J^P00F[X005Jj001F
^P00E[X005Jj0002E[X02000E[X005Jj001F^P00E[X200003e:j001BV`00DY/005:K001BV`00DY/0
05:K001BV`0200004e:K001BV`00CY/004jK001>V`00CY/004jK001>V`00CY/004jK00800003CY/0
000000d0000ACY/004jK001>^`00C[/004jk001>^`00D[/005:k001B^`0200004e:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k0080000:D[/005:k001B^`00D[/005:k0002D[/03P00
D[/005:k001B^`00D[/005:k001B^`00D[/300001E;K001Bf`00D]/04`0000MFf`00001Ff`00E]/0
000LOol00`00Oomoo`0hOol006aoo`03001oogoo05moo`0A001Bg000001Bg000D]`005;L001Bg000
D]`005;L001Bg00200001U;L001Bg5;L001Bg080000;D]`005;L001Bg000D[`005:l001B_0020000
3E:l001B_000D[`005:l001>_000C[`004jl00800005C[`004jl001>_00200001Djl001>_000B[`0
0P0000E:_000B[`004ZL00800003AY`004JL00800003AY`004JL00<00005@W`003il000nO0020000
1CYl00000000=U`01P0000<V70007O`01`0000<1>@000=H03P000U=o00D005^N000005nN00<0009W
W@08001[W6^L001_W000Ji`000=_V`05001_NfmkKg/00003LgX01000LgYcNP000g=i00D007=iLgUc
N@0000=cF@05001cFG=ILeT00002LeT01@00KeU_FFmI00000g=I00@006mIKeT0009_F@04001_>@00
0003KcT01000KcU_>@000Vli00D006liKcT006li008000=_>@05001_>Fli001_>@020002JcT01000
JcU[>@000V/i00@006/iJcT0009[6@04001[6@00JaT20002JaT01000JaU[6@000V/I00<006/I0000
0V/I00<006/I00000V/I00<006/I00000V/I00L006/IJaT006/I001[6@020002IaT01`00IaUW6@00
IaT006LI0080009W6@03001W6@00009W6@03001W6FLI0080009Vn@06001VnFKi001Vn@000VKi00<0
06Ki00000VKi00X006KiI_T006Ki001Vn@00I_T0009Vn@03001Vn@00009Rn@06001Rn@00H_T006;i
0P0000QRn@00H]T006;I001Rf@000V;I00H005kJ001NfP00G]X400000ekJ00000002F[X03000F[X0
05Zj001J^P00F[X005Jj001F^P80009F^P06001BVP00DYX005:J0P0000EBVP00CY/004jK00800007
CW/004Yk001:N`00BW/00P0000=:N`00AW/0100000I6N`000012F`00@U/200000d9K0012F`020000
0d9K0000000200001SiK000003iL000nG0<00003?U`0000000800006>U`00000>U`003YL0P0000Hj
G000000jG000=U`2000013IL000003IL100000@f?000000b?0800006<U`00000<S`0038l0`0000Hb
G@00000^?@00;Ud300000c9M000bO@0200000c9m000fO@02000023ZN000004:n0012gP00A]h90000
1U<M001G7@00Fcd0009K?@06001O?@00Gcd005mL100000ESG000HeaSG000009WG0800003Ie/00000
009WF`07001WFfMK001WF`00Je/00P000VLk00H006/k001[>`00JcX20002JcX01P00JcX006/j001[
>P800008JcX006/jJcX006/j001[>P800007IcX006LjIcX006Lj00000VLj0`000VLj00D006LJ001W
6P00009W6P03001W6P00009W6P03001W6P00009W6P<00007IaX006LJIaX006LJ00000VLJ0`0000UW
6P00IaYW6P00IaX006LJ00000VLJ0`0000eW6P00IaYW6P00IaX006Kj001VnP00I_X00002H_X01`00
H_X006;j001RnP00009RnP<00004H_X006;j0002H_X02P00H_X006;j001RnP00H_X006;j0`000UkJ
0P000UkJ00T005kJ001NfP00G]X005kJ00000UkJ1@0000EJfP00001J^P00009J^P80000HF[X005Jj
E[X005Jj001F^P00E[X005Jj001F^P00E[X005Jj001F^P00D[X005:j0P0001UBV`00DY/005:K001B
V`00DY/005:K001BV`00DY/005:K001>V`00CY/004jK001>V`0200001djK001>V`00CY/004jK0080
000=CY/004jK001>V`00CY/004jK001>V`00CY/05@0000mB^`00D[/005:k001B^`00D[/005:k001B
^`00D[/00P0000eB^`00D[/005:k001B^`00D[/005:k001B^`0I00004eKK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK0080009Ff`03001Ff`0001]oo`03001oogoo03Qoo`00K7oo00<0
07ooOol0Ggoo00X005;L001Bg000D]`005;L001Bg080000=D]`005;L001Bg000D]`005;L001Bg000
D]`00P0000]Bg000D]`005;L001B_000D[`005:l0080000=D[`005:l001B_000D[`004jl001>_000
C[`00P0000]>_000C[`004jl001>_000C[`004jl00800007B[`004Zl001:_000BY`00P0000I6W000
0016W000AY`200000d:L0000000300001Sil000003Yl000jG0<00005<U`0038l000Z7005000011Fk
000000VJ3`0000<k?`00Agl00P0000=CO`00Fih00`000UnN00D006NMIid006^L00<0009[W005001_
V`00Ki/00003Kg/01000LgX000000g=j00D007=i001_NP0000=cN@05001cF@00LeT00002LeT01@00
LeT006mI00000fmI00@007=I000000=_F@04001_FFmI0002KcT01@00KcU_>@00KcT00P000fli00@0
06liKcT0009_>@04001_>Fli0003KcT01000JcU[>@000V/i00@006/i001[>@80009[>@05001[6F/I
001[6@020002JaT01`00JaU[6@00JaT006/I0080009[6@03001[6@00009[6@03001[6@00009[6@07
001[6F/I001[6@00JaT00P000VLI00<006LI00000VLI00H006LIIaT006LI0002IaT01`00IaUW6@00
IaT006LI00800004IaT006Ki0002I_T01000I_T006Ki0P000VKi00<006Ki00000VKi00@006Ki001V
n@<0009Vn@09001VnFKi001Rn@00H_T006;i00800004H_T006;i0002H]T02P00H]T006;I001Rf@00
G]X005kJ0P00011NfP00G]X005kJ001NfP00F[X005Zj001J^P00F[X0009J^P80000?E[X005Jj001F
^P00DYX005:J001BVP00DYX005:J00800003CY/004jK00800009BW/004Yk001:N`00BW/004Yk0080
0003AW/0000000D00003@U/0049K00800003@U/0049K00800003?U/003iK00<00003?U`003iL0080
0004?U`00000?U`400000cYL000jG002000013YL000003YL100000@fG000000fG0800003=U`003IL
00800004<S`00000<S`200001S9L0000038l000b?0<00003<Ud0000000800004;Ud00000<Ud20000
0cIm0000000200000cZN000jWP0200000d:n0012gP02000024[n001:oP00C_h005<N0002Dad02P00
Ead005/m001K?@00Gcd005lm0P0000AO?000Hc`0009SG008001SG6=L001WG000Ie/0009WF`07001W
FfMK001WF`00Ie/00P0000QW>`00Ic]W>`00Jc/006/k0P0000MW>`00JcY[>P00JcX00002JcX00`00
JcX00002JcX00`00JcX00002JcX00`00IcX00002IcX00`00IcX00002IcX30002IcX01@00IcX006LJ
00000VLJ0`000VLJ00D006LJ001W6P00009W6P03001W6P00009W6P05001W6P00IaX00002IaX01@00
IaX006LJ00000VLJ00<006LJ00000VLJ0`0000aW6P00IaYW6P00IaX006LJ001VnP00I_X30002H_X0
1@00H_X006;j00000V;j0`0000ARnP00H_X0009RnP05001RnP00H_X00002H_X200004F;j000006;j
001NfP00G]X005kJ001NfP00G]X005kJ00000UkJ00<005kJ00000P0002EJfP00F]X005[J001JfP00
F[X005Zj001J^P00F[X005Jj001F^P00E[X005Jj001F^P00E[X005Jj001F^P00E[X005:j001B^P02
00008E:K001BV`00DY/005:K001BV`00DY/005:K001BV`00DY/004jK001>V`00CY/004jK001>V`00
CY/004jK001>V`0200008TjK000004jK001>V`00CY/004jK001>V`00CY/004jk001>^`00C[/005:k
001B^`00D[/005:k001B^`00D[/005:k800001iB^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05;K001Bf`00D]/005;K001Ff`00E]/005KK0002E]/2000045KK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`006goo00<007ooOol0>7oo001]Ool00`00Oomoo`1NOol02000D]`005;L001Bg000D]`l
00001dZl001:_000B[`004ZL00800003AY`004JL00800009AY`004JL0012W000@W`003il00@00007
>W`00000000fG000<U`0100000<V700000005@0000<k?`00Agl01@000U^N00D005nNGih006NM0080
00=[W003001[W0000080009_V`05001_NfmkKg/00002KgX01@00LgYcNW=j00000fmj00D007=iLgUc
N@0000=cF@04001cFG=I0003KeT01@00KeU_FFmI00000VmI00D006mIKeT006mI008000=_>@04001_
>Fli0002KcT01@00KcU_>@00KcT00P000fli00D006liKcT006li0080009[>@05001[>F/i001[>@02
0002JcT01000JcU[>@000V/I00<006/I00000V/I00D006/IJaT006/I0080009[6@03001[6@00009[
6@08001[6@00001[6@00JaT0009[6@06001[6F/I001[6@000VLI00L006LIIaT006LI001W6@020002
IaT01`00IaUW6@00IaT006LI0080009W6@80009Vn@04001Vn@00I_T20002I_T00`00I_T00002I_T0
1000I_T006Ki0P0000AVn@00I_T0009Vn@06001Vn@00H_T006;i0P00011Rn@00H_URn@00H_T006;I
001Rf@00H]T006;I001NfP800004G]X005kJG]X20002G]X200002UZj001J^UZj001J^P00F[X005Zj
0P0000mF^P00E[X005Jj001BVP00DYX005:J001BVP00DYX00P0000U>V`00CY/004ik001:N`00BW/0
0P0000=:N`00BW/00P0000I6N`000016N`00AW/200001d9K0012F`00@U/0049K00800006@U/00000
?U/003iK0P0000@nG000000nG0800006?U`00000?U`003iL0P0000<jG000>U`00P0000HjG000000j
G000>U`200001SIL000003IL000fG0800007=U`00000000b?000<U`00P0000<bG00000000`0000Hb
G@00000bG@00<Ud200000c9M000bG@0300000cIm000jW@0200001cZN000n_P00@[h004;N0080000?
B_h004[n001>oP00Dah005<M001G7@00Fcd005/m00@00007Gcd005llGc`006<l00000V=L00@006=L
001WG0<000=WF`04001WF`00Ie/200001fLk001W>fLk001W>`00009[>`03001W>`00009W>`03001[
>P00009[>P<0009[>P03001[>P00009[>P<0009W>P03001W>P00009W>P<00005IcX006LjIcX00002
IcX00`00IaX000020002IaX01@00IaX006LJ00000VLJ0`000VLJ00D006LJ001W6P00009W6P<00007
IaX006LJIaX006LJ00000VLJ0`0000aW6P00IaYW6P00IaX006LJ001W6P00I_X2000016Kj001RnP00
0V;j0P000V;j0`0000ARnP00H_X0009RnP05001RnP00H_X00002H_X5000036;j001RnP00G]X005kJ
001NfP00G]X0009NfP03001NfP0000@00006G]X005[J001JfP000U[J0P0001IJ^P00F[X005Zj001J
^P00E[X005Jj001F^P00E[X005Jj001F^P00E[X0009F^P0?001F^P00001B^P00DY/005:K001BV`00
DY/005:K0080000IDY/005:K001BV`00DY/004jK001>V`00CY/004jK001>V`00CY/004jK001>V`00
CY/00P00015>V`00CY/004jK001>V`00CY/004jK001>V`00C[/004jk0080000MD[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0200006U:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0002D[/00`00D[/000020000
3E;K001Bf`00D]/005KK001Ff`00E]/005KK00800008E]/005KK001Ff`00E]/0009Ff`800004E]/0
05KK000LOol00`00Oomoo`0gOol006eoo`03001oogoo05moo`L00003D]`005;L0080000=D]`005;L
001Bg000D]`005;L001Bg000D]`00P0000]Bg000D]`005;L001B_000D[`005:l0080000=D[`005:l
001B_000D[`004jl001>_000C[`00P0000]>_000C[`004jl001>_000C[`004jl00T00005BY`004JL
0016W002000014JL000004:L0P0000I2O000000nO000?W`600001C9L000b?000:S`00`0000<Mo000
6M`04@0000<R_`0000000P000T]O00L005=o000005^N001OWP020002Iid01@00Jia[W6^L00000f^L
00P006nKKi/006mk001_N`000Vmj00D007=j001_NP0000=_NP04001cN@000003LeT01@00LeT006mI
00000fmI00@006mI000000=_F@04001_FFmI0002KeT01@00KcU_>@00KcT00P000fli00@006liKcT0
009_>@04001_>Fli0003KcT01000JcU[>@000V/i00H006/iJcT006/i0002JcT01@00JcU[>@00JaT0
0P000V/I00@006/IJaT0009[6@03001[6@00009[6@04001[6F/I0002JaT01@00JaT006/I00000V/I
00@006/I001[6@80009[6@07001W6FLI001W6@00IaT00P000VLI00<006LI00000VLI00H006LIIaT0
06LI0002IaT01P00IaT006Ki001Vn@800005I_T006KiI_T00002I_T00`00I_T00002I_T01`00I_T0
06Ki001Vn@00009Vn@04001Vn@00H_T2000046;i001RnF;i001Rn@00H_T006;I001Rf@00H]T006;I
0P0001YNfP00G]YNfP00G]X005kJ001NfP00G]X005Zj001J^P00F[X005Zj001J^P00E[X005Jj0P00
00=F^P0000001`0000EBVP00CY/004jK0080000;CW/004Yk001:N`00BW/004Yk001:N`02000014Ik
000004Ik0P0000=6N`0000000P0000E2F`00@U/0049K00800004?U/00000?U/700001SiL000003iL
000nG0800006>U`00000>U`003YL0P0000HjG000000jG000>U`200001SIL000003IL000fG0800007
=U`00000000bG000<U`00P0000TbG000<Ud0039M000bG@00<Ud00P0000@bG@00000bG@800003=Wd0
03Im00800003>Yh0000000@00005@]h004KN001:oP0200001dkn001C7P00Dad005LM00@00004Fcd0
05lm0002Gcd01`00GcaO?000Hc`006=L00@00004He`006MK0002Ie/01P00Ie/00000Ic/0009W>`03
001W>`00009W>`<0009W>`03001W>`00009[>P<0009W>P03001[>V/j00800003JcX00000009W>P03
001W>P00009W>P05001W>P00IcX00002IcX02P00IcYW>P00IcX006LJ001W6P000VLJ00D006LJIaX0
06LJ00<0009W6P05001W6P00IaX00002IaX300001fLJ001W6VLJ001W6P00009W6P<00009IaX006LJ
IaX006LJ001W6P00009W6P<00004I_X006KjI_X20002H_X00`00H_X00002000016;j001RnP000V;j
00D006;j001RnP00009RnP<00006H_X006;j001RnP000V;j00@005kJ001NfP80009NfPD00006G]X0
05kJ001NfP000U[J00X005[J001JfP00F]X005Zj001J^P800004F[X005Jj0002E[X02P00E[X005Jj
001F^P00E[X005Jj500000mBV`00DY/005:K001BV`00CY/004jK001>V`00CY/00P0000M>V`00CY/0
04jK001>V`020000;DjK001>V`00CY/004jK001>V`00CY/004jK001>^`00C[/004jk001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0200008E:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`030000
6E;K001Bf`00D]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0080009Ff`03
001Ff`0001]oo`03001oogoo03Moo`00KWoo00<007ooOol0GWoo00L005;L001Bg000D]`00002D]`0
4@00D]`00000D]`005;L001Bg000D]`005;L001Bg000D]`00P0000]Bg000D]`005;L001B_000D[`0
05:l0080000=D[`005:l001B_000D[`004jl001>_000C[`00P0000U>_000C[`004jl001>_000C[`0
0`0000M:_000B[`004Zl001:W00700001DJL0016W000@Y`00P0000A2O000000nO0800007>W`003Yl
000fG000<U`0100000<Z700000000`0000DEf`000000005j00D000030=H0000000@000038[l00000
00<00003Bel005=o00@0009SWP08001WWFNM001[W000Ii`000=[W004001_V`000003Kg/00`00KgX0
00020002KgX01@00KgY_NVmj00000Vmj00D007=ILeUcF@0000=_F@05001_FFmIKeT00002KeT01@00
KeU_F@00KeT00P000fmI00@006liKcT0009_>@05001_>Fli001_>@020003KcT01@00KcU_>@00KcT0
0P000V/i00D006/iJcT006/i0080009[>@04001[>F/i0002JcT01P00JaU[6@00JaT0009[6@04001[
6@000002JaT01`00JaU[6@00JaT006/I0080009[6@06001[6@00JaT006/I0P000V/I00<006/I0000
0VLI00H006LI000006LI0002IaT01`00IaUW6@00IaT006LI0080009W6@03001W6FLI0080009Vn@03
001Vn@00009Vn@09001VnFKi001Vn@00I_T006Ki0080009Vn@08001Vn@00I_T006Ki001Vn@800007
H_T006;iH_T006;i00000V;i0P000V;I1@0001QNfP00G]YNfP00G]X005kJ001NfP00G]X005kJ001J
^P00F[X005Zj001J^P00F[X700002EJj001FVP00DYX005:J001BVP0900002DYk001:N`00BW/004Yk
001:N`0200001TIk000004Ik0016N`800003@W/0049k00800005@U/0049K0012F`0200001ciK0000
0000?U`003iL00800003?U`003iL00800003?U`003iL00800003>U`0000000800006>U`00000>U`0
03YL0P0000TjG000000003IL000fG000=U`01P0000DbG000<U`0039L00@00005<Ud0039M000bG@02
00002C9m00000000=Wd003Im000jW@0200001Cjn000n_P00@[h03P0000AG7@00Fcd0009K?@03001O
?@00009O?@04001O?000Hc`2000016<l001S?0000V=L00@006MK001WF`80000:Ic/006LkIc/006Lk
001W>`00Ic/20002Ic/01P00Ic/006Lk001[>P800005IcX006LjIcX00002JcX01@00JcX006Lj0000
0VLj00P006LjIcX006Lj001W>P000VLj00<006Lj00000VLj00<006Lj00000P000VLJ00X006LJIaX0
06LJ001W6P00IaX0009W6P03001W6P00009W6P<00009IaX006LJIaX006LJ001W6P00009W6P05001W
6P00IaX00002IaX00`00IaX00002IaX300003fKj001VnVKj001VnP00H_X006;j001RnP00H_X00002
H_X01`00H_X006;j001RnP00009RnP<00006H_X006;j001RnP000V;j00P006;j001NfP00G]X005kJ
0`0000QNfP00G]X005kJ001NfP000UkJ018005[J001JfP00F]X005[J001J^P00F[X005Zj001J^P00
E[X=00001eJj001F^P00D[X005:j00800009DY/005:K001BV`00DY/005:K01<00005CY/004jK001>
V`020000;TjK000004jK001>V`00CY/004jK001>V`00CY/004jk001>^`00C[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0P00031B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005;K001Bf`00
D]/005;K001Ff`00E]/005KK0002E]/200002eKK001Ff`00E]/005KK001Ff`00E]/01@006goo00<0
07ooOol0=goo001_Ool00`00Oomoo`1NOol02P00D]`005;L001Bg000D]`005;L0P000U;L00@005;L
001Bg080000=D]`005;L001Bg000D]`005;L001Bg000D]`00P0000]B_000D[`005:l001B_000D[`0
05:l0080000;C[`004jl001>_000C[`004jl001>_00200001Djl001>_000C[`00P0000E:_000B[`0
04Zl00800005BY`004ZL0016W00500001T:L0000049l000nO0800003?W`003Yl00@00003<U`0038l
00@000039Q`0000000<000034K/0000000<000030AP0000000D000032Q`0000000L0009GO`03001K
WP00009SWP03001WW@000080009WW005001[W6^LJi`00002Jg/01@00Kg]_Nfmk00000fmj00D006mj
KgX006mj008000=_NP05001cF@00KeX00003KeT01000KeT000000fmI00@006mIKeT0009_F@05001_
FFmI001_>@020003KcT01000KcU_>@000Vli00@006liKcT000=_>@04001_>Fli0002JcT01000JcU[
>@000V/i00L006/iJcT006/i001[>@020002JaT01000JaU[6@000V/I00H006/IJaT006/I0002JaT0
1000JaT000000V/I00H006/I001[6@00JaT200001F/I001[6F/I00000V/I00H006LIIaT006LI0002
IaT01`00IaUW6@00IaT006LI0080009W6@03001W6@00009W6@800003I_T00000009Vn@03001Vn@00
009Vn@04001Vn@00I_T20002I_T01`00I_T006Ki001Vn@00009Vn@03001Rn@00009Rn@03001Rn@00
009Rn@04001Rn@00H_T3000016;I001RfP000UkJ00D005kJ001NfP00009NfP800007G]X005kJ001J
^P00F[X01P0000MJ^P00001F^P00E[X00002E[X01P00EYX005:J001BVP800008DY/00000CY/004jK
001>V`H00003BW/004Yk00800005AW/004Ik0016N`0200000dIk0012N`0200000d9K000000020000
1T9K000003iK000nF`800004?U`00000?U`200001CiL000nG000?U`00P0000HjG000000jG000>U`2
00001SYL000003YL000jG0800004>U`00000=U`200001CIL000fG000=U`0100000LbG000<U`0039M
000bG@0200001C9M000bG@00<Ud00P0000dfO@00000003Im000jW@00>Yh003jn000n_P0200001DKN
0016gP00B_h00P0000I>oP00Dad005<M0002Ead00`00Fcd00002Fcd01P00Gcd005lm001O?080000:
Hc`006<lHc`006<l001SG000Ie/200002VLk001W>fLk001W>`00Ic/006Lk0P0000QW>`00Ic]W>`00
Ic/006Lk0P0000EW>`00IcYW>P00009W>P03001[>V/j0080009W>P07001W>VLj001W>P00IcX00P00
00AW>P00IcX0009W>P0:001W>VLj001W6P00IaX006LJ0002IaX00`00IaX000020002IaX01@00IaYW
6P00IaX00`0000UW6P00IaYW6P00IaX006LJ00000VLJ0`0000MW6P00IaYW6P00IaX00002IaX30000
16LJ001VnP000VKj00H006Kj001RnP00H_X30002H_X01`00H_X006;j001RnP00009RnP<00004H_X0
06;j0002H_X04`00H_X006;j001RnP00G]X005kJ001NfP00G]X005kJ001NfP00009NfP0B001NfP00
G]X005[J001JfP00F]X005[J001J^P00F[X005Zj1@0001MF^P00E[X005Jj001F^P00E[X005Jj001F
^P00E[X005:j001B^P00D[/005:K0080000GDY/005:K001BV`00DY/005:K001BV`00DY/005:K001B
V`00DY/004jK001>V`0<00003djK001>V`00CY/004jK001>V`00CY/004jk001>^`0200007E:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P0001YB
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`000U:k00<005:k
00000P0000]Bf`00D]/005;K001Ff`00E]/005KK01000004E]/005KK000LOol00`00Oomoo`0fOol0
06moo`03001oogoo05moo`04001Bg000D]`20002D]`04@00D]`00000D]`005;L001Bg000D]`005;L
001Bg000D]`00P0000]Bg000D]`005;L001B_000D[`005:l0080000=D[`005:l001B_000D[`004jl
001>_000C[`00P0000U>_000C[`004jl001>_000C[`00P0000=>_000B[`00P0000M:_000BY`004ZL
001:W00300000dJL0016W0040000149l000003il0P0000DjO000>W`003IL00D00005:S`00000000R
700B00002PXL000Zg`00=al004<o001?G`000UMo00@005^N001SWP<0009WW@08001WW6NL001[W000
Jg`0009[N`05001_N`00Kg/00003KgX01000KgX000000Vmj00D006mjKgY_NP0000=_FP05001_FFmI
KeT00002KeT01@00KeU_F@00KeT00P000fmI00@006mIKeT0009_>@05001_>Fli001_>@020003KcT0
1@00KcU_>@00KcT00P000Vli00D006/iJcT006/i0080009[>@05001[>F/i001[>@020002JcT01`00
JaU[6@00JaT006/I0080009[6@04001[6F/I0002JaT00`00JaT00002JaT02000JaU[6@00JaT006/I
0002JaT01`00JaU[6@00JaT006LI0080009W6@03001W6@00009W6@06001W6FLI001W6@000VLI00P0
06LIIaT006LI001W6@000VKi00<006Ki00000VKi00@006Ki001Vn@800005I_T006KiI_T00002I_T2
00000fKi001Vn@020002H_T00`00H_T00002H_T02@00H_T006;i001Rn@00H]T00002H]T01@00H]X0
05kJ00000UkJ00P005kJ001NfP00G]X005kJ1@0001EJ^P00F[X005Zj001J^P00E[X005Jj001F^P00
E[X005JJ001BVP00DYX00P0000MBV`00CY/004jK001>V`0200001Dik001:N`00BW/01P0000I6N`00
0016N`00AW/200000d9k0012N`0200000d9K0012F`0500001SiK000003iL000nG0800003?U`00000
00800003?U`003iL00800006>U`00000>U`003YL0`0000DjG000>U`003YL00P00005=U`00000000f
G00400000c9L000bG@0300000c9M0000000200001c9M000bO@00=Wd003Im00@0000=>Yh003jn000n
_P00@[h004KN0016gP00B_h00P0000I>oP00Dad005<M0002Ead01P00Fcd005/m001O?@@0000:Gc`0
06<lHc`006<l001S?000He`200002V<l001W>fLk001W>`00Ic/006Lk0P0000MW>`00Ic]W>`00Ic/0
0002Ic/00`00Ic/00002Ic/01`00IcYW>P00IcX006/j00800008IcX006LjIcX006Lj001W>P800004
IcX006Lj0002IcX01000IcX006Lj0P000VLJ0P000VLJ00X006LJIaX006LJ001W6P00IaX0009W6P05
001W6P00IaX00002IaX01@00IaX006LJ00000VLJ0`0000MW6P00IaYW6P00IaX00002IaX3000016LJ
001W6P000VKj00<006Kj00000VKj0`0000IRnP00H_X006;j0002H_X20002H_X3000016;j001RnP00
0V;j00L006;j001RnP00H_X00002H_X60002G]X03@00G]X005kJ001NfP00G]X005kJ001JfP00009J
fP03001JfP0000L0000@F[X005Zj001F^P00E[X005Jj001F^P00E[X005Jj0002E[X01P00E[X005:j
001B^P800007DY/005:K001BV`00DY/00P0001UBV`00DY/005:K001BV`00DY/005:K001BV`00CY/0
04jK001>V`00CY/004jK001>V`0200000djK0000000A00006E:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k0080000MD[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`0C00004eKK000005KK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`0001aoo`03001oogoo03Ioo`00L7oo00<007ooOol0GWoo018005;L001Bg000
D]`005;L001Bg000D]`005;L001Bg000D]`200003E;L001Bg000D]`005;L001Bg000D]`005;L0080
000;D[`005:l001B_000D[`005:l001B_00200002djl001>_000C[`004jl001>_000C[`00P0000E>
_000C[`004jl00800005B[`004Zl001:_00200001DZL001:W000AY`00P0000I6W0000012W000@Y`5
00000cil000jO00400000cIL000bG004000012HL0000027l0P0000@A^`000001NPd00009:]l003LO
0013?`00Cel005Mo00D0009OW@05001WWFNM001WW0020003Jg`01000Jg/000000fmk00D006mjKgY_
NP00009_NP08001_NVmj001_NP00KeX000=_FP04001_F@000003KeT01000KeU_F@000VmI00D006mI
KeT006mI008000=_>@04001_>Fli0002KcT01000KcU_>@000fli00@006liKcT0009_>@04001[>F/i
0002JcT01000JcU[>@000V/i00<006/i00000V/i00D006/IJaT006/I0080009[6@07001[6F/I001[
6@00JaT00P000V/I00P006/IJaT006/I001[6@000V/I00<006/I00000V/I00@006/I0000009W6@03
001W6@00009W6@04001W6@00IaT20002IaT01P00IaUW6@00IaT0009W6@80009Vn@07001VnFKi001V
n@00I_T00P0000EVn@00I_UVn@00009Vn@04001Vn@00I_T30002I_T00`00H_T00002H_T01P00H_T0
06;i001Rn@<0009Rf@05001Rf@00H]X00002G]X02000G]X005kJ001NfP00G]X3000015kJ001JfP00
0UZj00H005Zj001J^P00F[X200003eJj001F^P00E[X005JJ001BVP00DYX005:J001BV`0200002DjK
001>V`00CY/004ik001:N`0200000dYk001:N`0500001dIk0016N`00AW/0049k00800006@U/00000
@U/0049K1@0000<nF`00?U`00P0000HnG000000nG000?U`200000ciL000jG00200000cYL000jG002
000013YL000003YL0P0000LjG000>U`003IL000fG00500001SIL000003IL000fG0D00004<Ud00000
=Ud400000c9m000fO@0300000cZM000jW@0400005Cjn0012_P00A]h004KN001:oP00C_h004kn001C
7@00Dad005LM001K?@04000015/m001O?@000Ull00H006<l001S?000Hc`200002V<l001S?6<l001W
>`00Ic/006Lk0P0000EW>`00Ic]W>`00009W>`03001W>`000080009W>`07001W>fLk001W>P00IcX0
0P000VLj0P000VLj00H006Lj000006Lj0002IcX01P00IcX006Lj001W>P80009W>P08001W6P00IaX0
06LJ001W6P80009W6P80009W6P05001W6P00IaX00002IaX00`00IaX00002IaX00`00IaX000020000
2FLJ001W6VLJ001W6P00IaX00002IaX01@00IaX006LJ00000VLJ00<006Kj00000VKj0`0000IRnP00
H_X006;j0002H_X01000H_X006;j0`0000ARnP00H_X0009RnP07001RnP00H_X006;j00000V;j0`00
011NfP00G]X005kJ001NfP00G]X005kJ001NfP00G]X0009NfP03001JfP0000@00007F]X005Zj001J
^P00F[X00P0001IJ^P00E[YF^P00E[X005Jj001F^P00E[X005Jj001F^P00E[X005:j001B^P80000I
DY/005:K001BV`00DY/005:K001BV`00DY/005:K001BV`00DY/005:K001BV`00CY/00P0000U>V`00
CY/004jK001>V`00CY/00P00015>V`00CY/004jK001>V`00C[/004jk001B^`00D[/005:k03X00003
D[/005;K00<0000=D]/005KK001Ff`00E]/005KK001Ff`00E]/00P00015Ff`00E]]Ff`00E]/005KK
001Ff`00E]/005KK001Ff`0001]oo`03001oogoo03Ioo`00L7oo00<007ooOol0Ggoo00@005;L001B
g0800007D]`005;L001Bg000D]`0<@0000]>_000C[`004jl001:_000B[`004Zl00800003BY`004ZL
00800006AY`00000AY`004:L0P0000=2W000@W`00`0000<jO000>W`00`0000@fG000000^?0@00003
8Q`0000000L000030EX0000000L000034Ud0000000P0009GO`03001KOP00009OW@04001WW@000002
Ig`01@00Jga[O6]l00000V]k00H006mkKg]_N`00KgX20003KgX01000KgX000000fmJ00D006mJKeY_
FP00009_FP05001_FFmI001_F@020003KeT01000KeU_F@000Vli00L006liKcU_>@00KcT00003KcT0
1@00KcU_>@00KcT00P000fli00@006li001[>@80009[>@05001[>F/i001[>@020002JcT01000JcU[
>@000V/I00<006/I00000V/I00@006/IJaT0009[6@06001[6F/I001[6@000V/I00P006/I000006/I
001[6@000V/I00H006/IJaT006LI0002IaT01`00IaUW6@00IaT006LI0080009W6@03001W6@00009W
6@04001W6@00IaT200001fKi001VnFKi001Vn@00009Vn@03001Vn@00009Vn@03001Vn@00009Vn@07
001Vn@00I_T006Ki00000VKi00T006;iH_T006;i001Rn@00H_T00P0000QRn@00H]T006;I001Rf@00
0V;J00P005kJ001NfP00G]X005kJ0`0000iNfP00G]YNfP00F]X005Zj001J^P00F[X005Zj0P000UJj
00X005Jj001F^P00EYX005:J001BVP800005DY/004jK001>V`0200001DjK001>N`00BW/00P0000=:
N`00BW/00P0000=6N`00AW/0100000E6N`00@W/0049k00800004@U/00000@U/200000d9K00000002
00000ciL000nG00200000ciL000nG00200001SiL000003YL000jG0800003>U`003YL00P00004>U`0
0000=U`200000cIL00000002000013IL000003IL0P0000<fG00000000P0000LbG@00000003IM000f
O@0200000cIm000fO@0200001SZM000003jN000n_PH00009A]h004[n001>oP00C_h005<M00H00004
Fcd005/m0002Fcd02000Gcd005ll001S?000Hc`200002V<l001S?6<l001S?000Ic/006Lk0P0000EW
>`00Ic]W>`00009W>`05001W>`00Ic/00002Ic/01`00Ic]W>`00Ic/006Lj00800007IcX006LjIcX0
06Lj00000VLj00<006Lj00000VLj00H006Lj001W>P00IcX200002VLj001W>VLj001W6P00IaX006LJ
0P000VLJ00P006LJ001W6P00IaX006LJ0P0000AW6P00IaX0009W6P07001W6P00IaX006LJ00000VLJ
00D006LJ001W6P00009W6P<00009IaX006LJIaX006LJ001VnP00009VnP05001RnP00H_X00002H_X0
3@00H_X006;j001RnP00H_X006;j001RnP00009RnP07001RnP00H_X006;j00000V;j0`0000QNfP00
G]X005kJ001NfP000UkJ0P0000INfP00G]YNfP00G]X500009e[J001JfP00F]X005Zj001J^P00F[X0
05Zj001J^P00E[X005Jj001F^P00E[X005Jj001F^P00E[X005Jj001B^P00D[X005:k001BV`020000
7e:K001BV`00DY/005:K001BV`00DY/005:K001BV`00DY/005:K001>V`00CY/004jK001>V`00CY/0
04jK00800003CY/004jK0080000WCY/004jK001>^`00C[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0080000TD[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005;K001Bf`000U;K
00@005KK001Ff`80000HE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`006goo00<007ooOol0=Woo001aOol00`00Oomoo`1OOol<00001E;L001Bg000D]`00P0000eBg000
D]`005;L001Bg000D]`005;L001Bg00200002e:l001B_000D[`005:l001B_000D[`00P0000]>_000
C[`004jl001>_000C[`004jl00800003C[`0000000P00008B[`00000BY`004ZL0016W0800003AY`0
04JL00800003@Y`004:L00<00004?W`00000>W`2000013IL0000039L0P0000<^?0009Q`00P0000@Q
o000000A^`8000032I/0000000X0000;4Ud00000;]l003/O0017?`00Cel00002Egl01000Fgh005nM
0P000V=m00P006MlIg`006]l001[O0000V]k00D006mkKg]_N`00009_N`05001_NVmjKgX00002KgX0
1P00KeY_FVmJ001_FP8000=_FP04001_FFmI0002KeT01@00KeU_F@00KeT00P000fli00L006liKcU_
>@00KcT00003KcT01000KcT000000Vli00D006liKcT006li0080009[>@04001[>F/i0002JcT01P00
JcU[>@00JcT0009[>@04001[6@000002JaT01`00JaU[6@00JaT006/I0080009[6@04001[6F/I0002
JaT01@00JaT006/I00000V/I00@006/I001[6@80009W6@07001W6FLI001W6@00IaT00P0000EW6@00
IaUW6@00009W6@04001W6@00IaT2000016LI001Vn@000VKi00@006Ki001Vn@80009Vn@03001Vn@00
009Vn@04001Vn@00I_T30002I_T00`00I_T00002H_T01000H_T006;i0P0000QRn@00H_T006;I001R
f@000V;I00H006;J001NfP00G]X4000035kJ001NfP00G]X005kJ001JfP00F[X0009J^P0A001J^P00
001F^P00E[X005Jj001F^P00EYX005:J001BVP0200002e:K001>V`00CY/004jK001>V`00CW/00P00
00E:N`00BW/004Yk00800006AW/00000AW/004Ik0P0000E2N`00@W/0049K00800003@U/0049K00<0
0003@U/0000000800003?U`003iL00800003?U`003iL00800003?U`0000000<00009>U`003YL000j
G000>U`003YL00@00004>U`00000=U`200001SIL000003IL000fG0800004=U`00000=Ud200000c9M
000bG@02000013IM000003Im100000<fO@00>Yd00P0000PnWP000012_P00@]h004KN2@0000IC7@00
Dad005LM0002Fcd02P00Fcd005/m001O?@00Gc`006<l0P0000ES?000HcaS?000009S?0800005Ic/0
0000Ic/00002Ic/01`00Ic]W>`00Ic/006Lk00<0009W>`05001W>fLk001W>`0200002VLk001W>VLj
001W>P00IcX006Lj0P000VLj00H006Lj001W>P00IcX200001fLj001W>VLj001W>P00009W6P<0000:
IaX006LJIaX006LJ001W6P00IaX2000016LJ001W6P000VLJ00@006LJ001W6P<0009W6P05001W6P00
IaX00002IaX300002FLJ001W6VLJ001W6P00IaX00002I_X3000036;j001RnV;j001RnP00H_X006;j
001RnP<0009RnP07001RnP00H_X006;j00000V;j00<006;j00000P0000ANnP00G]X0009NfP06001N
fP00G]X005kJ0P000UkJ1@0000QNfP00F]X005[J001JfP000U[J00@005Zj001J^P80000KF[X005Zj
001F^P00E[X005Jj001F^P00E[X005Jj001F^P00E[X005:j001B^P00D[/005:K0080000QDY/005:K
001BV`00DY/005:K001BV`00DY/005:K001BV`00DY/004jK001>V`00CY/004jK001>V`00CY/004jK
0080000GCY/004jK001>V`00CY/004jk001>^`00D[/005:k001B^`00D[/005:k001B^`0200004E:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P0000aB^`00D[/005:k001B^`00D[/005:k
0002D[/05000D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D]/300001E;K001Ff`00
E]/00P0000AFf`00E]/0009Ff`80000@E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK000LOol0
0`00Oomoo`0eOol0079oo`03001oogoo05ioo`04001Bg000D]`200001U;L001Bg000D]`0009Bg004
001Bg000D]`200003E;L001Bg000D]`005;L001Bg000D]`005;L0080000;D[`005:l001B_000D[`0
05:l001B_00200002djl001>_000C[`004jl001>_000C[`00`0000U>_000C[`004jl001:_000B[`0
1`0000E6W000AY`004JL00800006@Y`00000@Y`0049l0`0000<nO00000000`0000@fG000000^?0@0
00038Q`0000000<000033K/0000000X000030M`0000000800009;]l003/O0017?`00Cel005Mo00@0
009OO@05001SOF=m001WO0030002Jg`01@00Jg][N`00Kg/00P000fmk00D006mj001_NP00009_NP05
001_FVmJKeX00002KeX01@00KeY_FP00KeT00P000fmI00@006mIKeT0009_F@06001_>FliKcT006li
0P000Vli00L006liKcU_>@00KcT00003KcT01P00KcU_>@00JcT000=[>@04001[>@00JcT20002JcT0
1000JcU[>@000V/i00H006/IJaT006/I0002JaT01000JaT000000V/I00L006/IJaT006/I001[6@02
0002JaT01P00JaT006/I001[6@80009W6@03001W6@00009W6@06001W6FLI001W6@000VLI00L006LI
IaT006LI001W6@0200002VLI001W6FLI001Vn@00I_T006Ki0P000VKi00<006Ki00000VKi00@006Ki
001Vn@800006I_T006Ki001Vn@000VKi00@006;i001Rn@800006H_T006;iH_T006;i0P000V;I00H0
06;I001RfP00G]X2000035kJ001NfP00G]X005kJ001NfP00G]X0009JfP06001J^P00F[X005Zj0P00
015F^P00E[X005Jj001F^P00EYX005:J001BVP00DYX005:K00800009CY/004jK001>V`00CW/004Yk
00800003BW/004Yk00800005AW/004Ik0016N`0200000dIk0000000200001T9K0000049K0012F`80
0006@U/00000@U/003iL0P0000DnG000?U`003iL00800006?U`00000?U`003iL0P0000@jG000000j
G0800004>U`00000>U`4000013IL000003IL0P0000<fG00000000P0000@fG000000fG0800003=Ud0
000000800004=Ud00000=Wd200000cIm000jO@0200001CZM000jW@00?Yh00P0000=2_P00@]h00P00
00Q:gP00B_h004kn001>o@000U<M00`005<M001G7@00Fcd005/m001K?@00Gcd400001Ell001S?6<l
00000V<l00L006<l001S?000Ic/00002Ic/01`00Ic]W>`00Ic/006Lk00800004Ic/006Lk0002Ic/0
1P00Ic]W>`00Ic/0009W>`03001W>P00009W>P<0009W>P05001W>P00IcX00002IcX00`00IcX00002
IcX00`00IcX00002IcX300001fLJ001W6VLJ001W6P00009W6P<0000:IaX006LJIaX006LJ001W6P00
IaX200001VLJ001W6P00IaX0009W6P03001W6P0000800009IaX006LJIaX006LJ001W6P00009W6P<0
000<H_X006;jH_X006;j001RnP00H_X006;j0P0000YRnP00H_X006;j001RnP00H_X0009RnPD00004
H_X005kj0002G]X02P00G]X005kJ001NfP00G]X005kJ0`0000QNfP00G]X005kJ001JfP000U[J00X0
05[J001JfP00F[X005Zj001J^P800006F[X005Jj001F^P000UJj00h005Jj001F^P00E[X005Jj001F
^P00D[X005:j0P0001UBV`00DY/005:K001BV`00DY/005:K001BV`00DY/005:K001BV`00DY/005:K
001>V`0200002DjK001>V`00CY/004jK001>V`020000:DjK001>V`00CY/004jK001>^`00C[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P00
02=B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005;K00<0000=D]/005KK001Ff`00E]/005KK001Ff`00E]/00P00015Ff`00E]]Ff`00
E]/005KK001Ff`00E]/005KK001Ff`0001]oo`03001oogoo03Eoo`00LWoo00<007ooOol0Ggoo00@0
05;L001Bg080000;D]`005;L001Bg000D]`005;L001Bg00200001U;L001Bg5;L001Bg080000;D]`0
05;L001Bg000D[`005:l001B_00200002e:l001B_000D[`005:l001>_000C[`00P0000E>_000C[`0
04jl00800009C[`004jl001>_000C[`004Zl00800006B[`00000BY`004ZL1P0000I6W0000012W000
@Y`300001Sil000003Yl000jO0<00006<U`00000;S`002XL0P0000@Qo000000Ig0L000030EX00000
00@000030M`0000000X0009GOP03001KOP00009OO@03001SO@000080009WO005001[O6]l001[N`02
0002Jg/01@00Kg]_Nfmk00000fmj00D006mjKgX006mJ008000=_FP04001_FP000002KeX01@00KeU_
F@00KeT00P000fmI00D006liKcU_>@00009_>@05001_>Fli001_>@020002KcT01@00KcU_>@00KcT0
0P000V/i00D006/iJcT006/i0080009[>@07001[>F/i001[>@00JcT00P000V/I00@006/IJaT0009[
6@03001[6@00009[6@04001[6F/I0002JaT01P00JaU[6@00JaT0009[6@05001[6@00IaT00002IaT0
1`00IaUW6@00IaT006LI0080009W6@03001W6@00009W6@06001W6FLI001W6@000VLI00H006LI001V
n@00I_T200001FKi001VnFKi00000VKi00<006Ki00000VKi00L006Ki001Vn@00I_T00002I_T00`00
I_T00002H_T00`00H_T00002H_T03000H_T006;i001Rf@00H]T006;I001RfP800004G]X005kJG]X2
0002G]X20002G]X03000G]X005[J001J^P00F[X005Zj001J^P800003E[X0000001800005CY/004ik
001:N`0200001DYk001:N`00BW/00P0000E6N`00AW/004Ik00800003AW/004Ik00D00003@U/0049K
00800003@U/0049K00800003?U`0000000800003?U`003iL00800004?U`00000?U`800000cYL000j
G00200000cYL00000002000013IL000003IL0P0000<fG000=U`00P0000@fG000000fG@800003=Ud0
03IM00800003=Ud003Im00800004=Wd00000>Yd400001cjN000n_P00@[h004;N00800008B]h004[n
001>oP00C_d0009C7@09001C7@00001K?@00Fcd005/m00800004Gc`005ll0002Gc`01`00HcaS?000
Hc`006<l00<0009W>`07001W>fLk001W>`00Ic/00P0000YW>`00Ic]W>`00Ic/006Lk001W>`80009W
>`06001W>`00IcX006Lj0P0000MW>P00IcYW>P00IcX00002IcX30002IcX01@00IcX006Lj00000VLj
00<006LJ00000VLJ00<006LJ00000VLJ0`0000UW6P00IaYW6P00IaX006LJ00000VLJ00<006LJ0000
0VLJ0P000VLJ00L006LJ001W6P00IaX00002IaX01@00IaX006LJ00000VLJ0`0000URnP00H_YRnP00
H_X006;j00000V;j0`0000IRnP00H_X006;j0002H_X20002H_X300001V;j001RnP00H_X0009NnP0:
001NfP00G]X005kJ001NfP00G]X300001UkJ001NfP00G]X0009NfP0F001JfP00F]X005[J001JfP00
F[X005Zj001J^P00F[X005Zj001F^P00E[X^00001djK001>V`00CY/004jK00800003CY/004jK0080
000WCY/004jK001>^`00C[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k0080000TD[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005;K001Bf`000U;K00@005KK001Ff`800009E]/0
05KK001Ff`00E]/005KK00l001]oo`03001oogoo03Eoo`00Lgoo00<007ooOol0GWoo00X005;L001B
g000D]`005;L001Bg080009Bg004001Bg000D]`200003E;L001Bg000D]`005;L001Bg000D]`005;L
0080000;D[`005:l001B_000D[`005:l001B_00200002djl001>_000C[`004jl001>_000C[`00P00
00=>_000C[`00P0000M>_000B[`004Zl001:_002000024ZL000004JL0016W000AY`300001D:L0012
W000@W`00P0000@nO000000jO0800005=U`00000000^?00400000bHL0000000300001AGL00000000
1I/03@0000<Z_`00=_l00P0000A7?`00Cel0009GOP04001KOP00Ggd30002Hgd01@00IgaWO000Jg`0
0P000V]k00P006]kJg/006mk001[N`000fmj00@006mj0000009_FP07001_FVmJKeX006mJ00000fmJ
00@006mI0000009_F@06001_FFmIKeT006li0P000fli00@006liKcT0009_>@04001_>Fli0002KcT0
1000JcU[>@000V/i00H006/iJcT006/i0002JcT01@00JcU[>@00JcT00P000V/I00L006/IJaT006/I
001[6@020002JaT01`00JaU[6@00JaT006/I0080009[6@08001[6F/I001[6@00JaT0009W6@07001W
6FLI001W6@00IaT00P000VLI00<006LI00000VLI00@006LI001W6@80009W6@05001W6@00IaT00002
I_T00`00I_T00002I_T02@00I_UVn@00I_T006Ki001Vn@020002I_T02P00I_T006Ki001Vn@00I_T0
06;i0P000V;i00<006;i00000V;i0P0000ERf@00H]T006;I0080000FG]X005kJG]X005kJ001NfP00
G]X005kJ001NfP00G]X005[J001J^P00F[X700002eJj001F^P00E[X005Jj001BVP00DYX00P0000MB
V`00DY/004jK001>V`0600000dYk001:N`0200001DYk0016N`00AW/00P0000=6N`00AW/00P0000=6
N`00@W/0100000A2F`000012F`800003@U/003iL00800003?U`003iL0080000<?U`00000?U`003iL
000nG000?U`003iL100000@jG000000jG0800003>U`003YL00800006=U`00000=U`003IL0P0000Hf
G000000fG000=Ud2000013IM000003Im0P0000<fO@00=Wd00P0000HjO@00000jW@00?Yd600004D;N
0016gP00B]h004[n001>oP00C_d005<M001C7@00Ead01@0000MK?@00GcaO?000Gc`00002Gc`01000
Hc`006<l0P0000AS?000Hc`0009W>`04001W>`00Ic/200002VLk001W>fLk001W>`00Ic/006Lk0P00
0VLk00H006Lk001W>`00IcX200001fLj001W>VLj001W>P00009W>P<0009W>P05001W>P00IcX00002
IcX30002IaX01@00IaX006LJ00000VLJ00<006LJ00000VLJ00P006LJ001W6P00IaX006LJ0P000VLJ
00P006LJ001W6P00IaX006LJ0`000VLJ00D006LJ001W6P00009W6P<00009H_X006;jH_X006;j001R
nP00009RnP<00004H_X006;j0002H_X01P00H_X006;j001RnP<00006H_X006;j001RnP000V;j00D0
05kj001NfP00009NfP03001NfP0000800003G]X00000009NfP0?001NfP00G]X005kJ001JfP00F]X0
05[J001JfP00009J^P05001J^P00001J^P0700004eJj001F^P00E[X005Jj001F^P00E[X005Jj001B
^`00D[/005:k0080000GDY/005:K001BV`00DY/005:K001BV`00DY/005:K001BV`00DY/005:K001B
V`0@00004djK001>V`00C[/004jk001B^`00D[/005:k001B^`00D[/005:k0080000AD[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`02000035:k001B^`00D[/005:k001B^`00D[/0009B^`0D
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001Bfa@0000>E]/005KK001Ff`00E]/0
05KK001Ff`00E]/001aoo`03001oogoo03Aoo`00Lgoo00<007ooOol0Ggoo00@005;L001Bg080000C
D]`005;L001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`00P0000]Bg000D]`005;L001B_000
D[`005:l0080000;D[`005:l001B_000D[`004jl001>_00200001djl001>_000C[`004jl00800007
C[`004jl001>_000B[`00P0000=:_000B[`00P0000E:W000AY`004JL00800003AY`0000000D00007
?W`00000000jO000>W`00`0000@bG000000^?0@000039Q`0000000<000054M/000000005V`050000
1@6k000000006Uh00P0000<Z_`00=_l00P0000E7?`00Cel005Mn00D0009OO@05001SOF=m001WO002
00000fMl001[N`02Jg/01000Jg/000000f]k00L006mjKgY_NP00KeX00003KeX01000KeX000000VmJ
00D006mJKeY_FP00009_FP04001_FFmI0003KeT01000KcU_>@000Vli00@006li0000009_>@05001_
>Fli001_>@020002JcT01@00JcU[>@00JcT00P000V/i00@006/iJcT0009[>@03001[>@00009[6@05
001[6F/I001[6@020002JaT00`00JaT00002JaT01000JaT000000V/I00L006/IJaT006/I001[6@02
000016LI001W6@000VLI00H006LIIaT006LI0002IaT01`00IaUW6@00IaT006LI0080009W6@03001W
6@00009W6@03001W6@000080009Vn@03001Vn@00009Vn@04001Vn@00I_T20002I_T02P00I_T006Ki
001Vn@00I_T006Ki0P000V;i00<006;i00000V;i00L006;i000006;I001Rf@02000056;J001NfUkJ
001NfP00G]X005kJ001NfP00G]X005kJ001NfP00F]X400000eZj001J^P0200002UJj001F^UJj001F
^P00E[X005Jj0P0000UBVP00DYX005:K001BV`00CY/00P0000E>V`00CY/004jK00L00007AW/004Ik
0016N`00AW/00P0000A6N`000012N`800003@W/0000000800005@U/0049K0012F`0200000ciL000n
G00200000ciL0000000300000ciL000nG002000013iL000003iL0P0000<jG000>U`00P0000<jG000
>U`00P0000HjG000000fG000=U`2000013IL000003IL0P0000<fG@00=Ud00P0000@fG@00000fO@@0
0003=Wd003Ym00800008>Yd00000?[d004:n0012_Q800004Fad005/m0002Fcd02@00GcaO?000Gc`0
05ll001S?00200002V<l001S?6<l001S?000Ic/006Lk0P0000YW>`00Ic]W>`00Ic/006Lk001W>`80
0007Ic/006LkIc/006Lk00000VLk00<006Lk00000VLj00<006Lj00000VLj0`0000MW>P00IcYW>P00
IcX00002IcX30002IaX01@00IaX006LJ00000VLJ0`000VLJ00D006LJ001W6P00009W6P<0000:IaX0
06LJIaX006LJ001W6P00IaX200001VLJ001W6P00IaX0009W6P03001W6P0000800009HaX006;jH_X0
06;j001RnP00009RnP<00004H_X006;j0002H_X03@00H_X006;j001RnP00H_X006;j001RnP00009R
nP07001RnP00H_X005kj00000UkJ1@00019NfP00G]X005kJ001NfP00G]X005kJ001NfP00F]X005[J
0002F]X00`00F]X0000700006eZj001F^P00E[X005Jj001F^P00E[X005Jj001F^P00E[X005Jj001B
^`00D[/005:k001B^`0200007e:K001BV`00DY/005:K001BV`00DY/005:K001BV`00DY/005:K001B
V`00DY/005:K001BV`00DY/005:K00800003DY/005:K01L0000?D[/005:k001B^`00D[/005:k001B
^`00D[/005:k0080000=D[/005:k001B^`00D[/005:k001B^`00D[/06@0000EFf`00E]/005KK0080
000>E]/005KK001Ff`00E]/005KK001Ff`00E]/0009Ff`09001Ff`00E]/005KK001Ff`0001]oo`03
001oogoo01Aoo`H000eoo`@000Uoo`00M7oo00<007ooOol0GWoo00X005;L001Bg000D]`005;L001B
g080000;D]`005;L001Bg000D]`005;L001Bg00R00001djl001>_000C[`004jl00800007C[`004Zl
001:_000B[`00P00011:W0000016W000AY`004JL0016W000@Y`004:L0012O0800004?W`00000>W`2
00001CIL00000000<U`00`0000DZ70000000028L00D000034K/0000000<000050GX000000005g002
00000aYN0000000:00001EMN001KOU]n00000Umm00H006=m000006Ml0002Ig`01@00Jg][Nf]k0000
0V]k00H006]kJg][N`00KgX20002KeX01@00KeY_FVmJ00000VmJ00D006mJKeX006mJ008000=_FP05
001_FFmI001_F@020003KcT01000KcU_>@000Vli00@006liKcT0009_>@04001[>F/i0002JcT01000
JcU[>@000V/i00L006/iJcT006/i001[>@020002JcT01000JaU[6@000V/I00<006/I00000V/I00@0
06/IJaT0009[6@03001[6@00009[6@04001[6F/I0002JaT01@00IaT006LI00000VLI00@006LI001W
6@80009W6@07001W6FLI001W6@00IaT00P0000EW6@00IaUW6@00009W6@05001W6@00IaT00002I_T0
0`00I_T00002I_T01000I_T006Ki0P0000EVn@00I_UVn@00009Vn@800003I_T006Ki00800007H_T0
06;iH_T006;i00000V;i00@006;i001Rn@<00009H]X006;JH]X005kJ001NfP00009NfP80009NfP80
0003G]X000000080000GF]X005Zj001J^P00F[X005Zj001F^P00E[X005Jj001F^P00E[X005:J001B
VP0200002E:K001BV`00CY/004jK001>V`0200001TjK000004Yk001:N`@00007AW/004Ik0016N`00
AW/00P0000=6N`00@W/00`0000=2N`00@W/00P0000E2F`00@U/003iL00800003?U`003iL00800003
?U`0000000<00006?U`00000?U`003iL0P0000<jG00000000P0000HjG000000jG000>U`200001SYL
000003IL000fG0800004=U`00000=Ud400000cIM000fG@0300000cIm000jO@0200001CYm000jW@00
>Yd00P0000<n_@00@[h00P0001I6gP00A]h004[N001:oP00C_d005;m001C7@00Ead005LM001K7@00
Fcd0009K?@04001O?000Gc`400002V<l001S?6<l001S?000Hc`006Lk0P0000YW>`00Ic]W>`00Ic/0
06Lk001W>`800007Ic/006LkIc/006Lk00000VLk0`000VLk00H006Lj001W>P00IcX200001fLj001W
>VLj001W>P00009W>P<00007IaX006LJIaX006LJ00000VLJ0`000VLJ00D006LJ001W6P00009W6P<0
0007IaX006LJIaX006LJ00000VLJ0`0000AW6P00IaYW6P80009W6P07001W6P00IaX006LJ00000V<J
00D006;j001RnP00009RnP<00004H_X006;j0002H_X02000H_X006;j001RnP00H_X30002H_X02@00
H_X006;j001RnP00H_X00002G_X300001UkJ001NfP00G]X0009NfP80009NfP800004G]X005kJ0002
F]X00`00F]X0000400002EZj001J^P00F[X005Zj001J^P0200005UJj001F^UJj001F^P00E[X005Jj
001F^P00E[X005Jj001B^`00D[/005:k0P0001MBV`00DY/005:K001BV`00DY/005:K001BV`00DY/0
05:K001BV`00DY/005:K00800007DY/005:K001BV`00DY/00P0001UBV`00DY/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`0P00005E:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005;K001Bf`03000085KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/005KK000KOol00`00Oomoo`0COol8000:Ool80007Ool007Eo
o`03001oogoo05iooaH00003D]`005;L0080000;D]`005;L001Bg000D]`005:l001B_00200002e:l
001B_000D[`005:l001>_000C[`00P0000=>_000C[`03@0000M:_000B[`004Zl001:W00200000dJL
0016W00200001TJL000004:L0012W0800007?W`00000000jO000>W`00P0000DfG000000002hl00<0
00059Q`00000000Mo00500000`FK0000000300000`6K0000000300003aYN000002kO000jo`00@al0
04/o001CG`00Eeh00002Fgh01P00Ggd00000Hgd0009WO008001WO6Ml001[N`00Jg/0009[N`05001[
Nf]kJg/00002Je/01@00KeY_FP00KeX00P000fmJ00@006mJKeX0009_FP06001_FVmJKeX006mI0P00
0VmI00D006liKcT006li008000=_>@04001_>@00KcT20002JcT01@00JcU[>@00JcT00P000V/i00D0
06/iJcT006/i0080009[>@07001[>F/i001[6@00JaT00P000V/I00L006/IJaT006/I001[6@020002
JaT01`00JaU[6@00JaT006/I0080009W6@06001W6@00IaT006LI0P000VLI00<006LI00000VLI00H0
06LIIaT006LI0002IaT01`00IaUW6@00IaT006LI00<0009Vn@06001VnFKi001Vn@000VKi00<006Ki
00000VKi00L006KiI_T006Ki001Vn@0300001f;i001RnF;i001Rn@00009Rn@04001Rn@00H_T30000
1f;J001RfV;J001RfP00009NfP06001NfP00G]X005kJ1@0000ANfP00F]X0009JfP06001J^P00F[X0
05Zj0P0000IF^P00E[X005Jj0002E[X01`00E[X00000DYX005:J00800009DY/004jK001>V`00CY/0
04jK00800003BW/004Yk00800003BW/004Yk00@00003AW/004Ik00800003AW/0049k00800003@W/0
049k00800003@W/0000000800005?U`003iL000nG00200001CiL00000000?U`00`0000@nG000000n
G0800006?U`00000>U`003YL0P0000<jG000>U`00P0000@jG000000jG0@00004=U`00000=U`20000
0cIM000fO@0200000cIM000fO@02000013Im000003Ym100000DjW@00?Yd003jm0080000K@[h004KN
0016gP00B]h004[n001>o@00D_d005<M001G7@00Ead005/M001K?@00Fcd005ll00800004Gc`005ll
0002Hc`01P00Hc`006<l001S?080000:Hc/006LkIc/006Lk001W>`00Ic/200001fLk001W>fLk001W
>`00009W>`<0009W>`05001W>`00IcX00002IcX00`00IcX00002IcX00`00IcX00002IcX300001fLj
001W6VLJ001W6P00009W6P<00007IaX006LJIaX006LJ00000VLJ0`0000MW6P00IaYW6P00IaX00002
IaX3000036LJ001W6VLJ001W6P00IaX006LJ001W6P<0009W6P05001S6P00H_X00002H_X3000016;j
001RnP000V;j00D006;j001RnP00009RnP<0000<H_X006;j001RnP00H_X006;j001RnP000V;j0`00
00INfP00G]X005kJ0002G]X01P00G]X005kJ001NfP80009NfP03001NfP0000@0000WF]X005[J001J
^P00F[X005Zj001J^P00F[X005Jj001F^P00E[X005Jj001F^P00E[X005Jj001F^P00E[X005:k001B
^`00D[/005:k0080000ODY/005:K001BV`00DY/005:K001BV`00DY/005:K001BV`00DY/005:K001B
V`00DY/005:K001BV`00DY/00P0000MBV`00DY/005:k001B^`0200007e:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0080000HD[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`000U:k00X005:k001B^`00D[/005;K
001Bf`@0000NE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`006goo00<007ooOol04Woo0`0017oo0`002Goo0P0017oo0P001goo001eOol00`00Oomo
o`1NOol02P00D]`005;L001Bg000D]`005;L0P0000YBg000D]`005;L001Bg000D]`0009Bg00?001B
g000001Bg000D]`005;L001Bg000D[`005:l0080000;D[`005:l001B_000D[`004jl001>_0020000
2Tjl000004jl001>_000C[`004jl0P0000=>_000B[`02@0000M6W000AY`004JL0016W002000014:L
0000049l0P0000<nO00000000`0000@fG000000bG0<00003;S`00000008000048Q`000007O`20000
116k000000FK3@0000d^g`00>_l004<O001;?`00Del005MN001KOP0200001Emm001SOF=m00000VMl
00<006Ml00000P000V]k00D006]kJg/006]k008000=[F`04001_FVmJ0002KeX01@00KeY_FP00KeX0
0P000fmJ00L006mJKeY_FP00KeX00003KeT01000KcU_>@000Vli00D006liKcT006li0080009[>@04
001[>F/i0002JcT01000JcU[>@000V/i00H006/iJcT006/i0002JcT01@00JcU[>@00JaT00P000V/I
00<006/I00000V/I00@006/I0000009[6@03001[6@00009[6@04001[6@000002IaT01@00IaT006LI
00000VLI00<006LI00000VLI00L006LIIaT006LI001W6@020002IaT00`00IaT00002IaT02000IaUW
6@00IaT006Ki0002I_T01P00I_T006Ki001Vn@80009Vn@03001Vn@00009Vn@07001Vn@00I_T006Ki
00000V;i00<006;i00000V;i00<006;i00000V;i00@006;i0000009RfP03001RfP00009RfP0=001N
fP00G]X005kJ001NfP00G]X005kJ00000UkJ01H005[J001JfP00F[X005Zj001J^P00F[X005Jj001F
^P00E[X005Jj001F^P80000=DYX005:J001BV`00DY/004jK001>V`00CY/00P0000Q>V`00001:N`00
BW/004Yk0P0000=6N`00AW/0100000I6N`000012N`00@W/200000d9k0012N`0200000d9k0012O004
00001SiL000003iL000nG0<00003?U`0000000800003?U`003iL00800003>U`003YL00800006>U`0
0000>U`003YL0P0000HjG000000jG000>U`200000cIL000fG002000013IM000003Im100000@fO@00
000jO@800003>Yd003jM00@0000J?[d00000@[h004KN0016gP00B]h004[n001>o@00D_d005<M001G
7@00Ead005/M001K?@@0000<Gc`005llGc`005ll001S?000Hc`006<l0P0000YS?000Hc]S>`00Ic/0
06Lk001W>`80000:Ic/006LkIc/006Lk001W>`00Ic/200001fLk001W>fLk001W>`00009W>P<0009W
>P06001W>P00IcX006Lj0P0000MW>P00IcYW>P00IaX00002IaX300001fLJ001W6VLJ001W6P00009W
6P<00009IaX006LJIaX006LJ001W6P00009W6P05001W6P00IaX00002IaX01P00IaX006LJ001W6P80
0006IaX006LJ001W6P000V<J00<006;j00000P0000ARnP00H_X0009RnP05001RnP00H_X00002H_X3
00001V;j001RnP00H_X0009RnP80009RnP03001RnP0000800004G_X005kJ0002G]X03000G]X005kJ
001NfP00G]X005kJ001NfPD00008F]X005[J001JfP00F]X0009J^P04001J^P00F[X20002F[X20000
5eJj001F^P00E[X005Jj001F^P00E[X005Jj001F^P00D[/005:k001B^`00D[/00P0001mBV`00DY/0
05:K001BV`00DY/005:K001BV`00DY/005:K001BV`00DY/005:K001BV`00DY/005:K001BV`020000
9E:K001BV`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k0080000WD[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D]/005;K00<00005E]/005KK001Ff`020000
3UKK001Ff`00E]/005KK001Ff`00E]/005KK0002E]/02@00E]/005KK001Ff`00E]/0000KOol00`00
Oomoo`0@Ool30006Ool30007Ool20006Ool20006Ool007Ioo`03001oogoo05ioo`0:001Bg000D]`0
05;L001Bg000D]`200003E;L001Bg000D]`005;L001Bg000D]`005;L0080000AD]`005;L001Bg000
D]`005:l001B_000D[`005:l001B_00200001E:l001>_000C[`00P0000]>_000C[`004jl001>_000
C[`004jl0080000:C[`00000B[`004Zl001:_000B[`500000dJL0016W00200000d:L0012W0020000
1cil000nO000>W`003Yl00800004=U`00000<U`300000bXl0000000200000agl0000000300000`fk
0000000:00000b9n0000000<0002Feh00`00Ggd00002Hgd00`00Ig`000020002Ig`01@00Jg][N`00
Jg/00P000V]k00D006]KJe/006mJ008000=_FP04001_FVmJ0002KeX01P00KeY_FVmJ001_FP80009_
FP05001_FFmI001_>@020003KcT01P00KcU_>@00JcT000=[>@04001[>@00JcT20002JcT01@00JcU[
>@00JcT00P000V/i00@006/iJcT0009[>@03001[6@00009[6@04001[6F/I0002JaT00`00JaT00002
JaT01000JaU[6@000V/I00<006/I00000VLI00<006LIIaT00P0000=W6@0000000VLI00L006LIIaT0
06LI001W6@020002IaT00`00IaT00002IaT01000IaT006LI0P0000AW6@00I_T0009Vn@04001Vn@00
I_T20002I_T00`00I_T00002I_T01000I_T006Ki0`000VKi00<006;i00000V;i00H006;i001Rn@00
H_T200001V;i001Rn@00H]X0009RfP08001RfP00G]X005kJ001NfP<0009NfP09001NfP00G]X005[J
001JfP00009J^P80000AF[X005Zj001F^P00E[X005Jj001F^P00E[X005:J001BVP0200002E:K001B
V`00CY/004jK001>V`0200001DjK001:N`00BW/00P0000E:N`00BW/004Ik00800003AW/004Ik00@0
0006@W/00000@W/0049k0P0000=2N`00@W/00P0000=2O000@W`00P0000@nG000000nG0800006?U`0
0000?U`003iL0P0000<nG000?U`00P0000<jG000>U`00P0000<jG00000000P0000HjG000000jG000
>U`2000013YL000003IL0P0000<fG@00=Wd00P0000<jO@00>Wd00`0000DjO@00>Wd003ZM00800003
?Yd003jm00D0000?A]h004KN001:gP00B_h004km001Bo@00Dad005LM00H00004Fad005/m0002Gc`0
2000Gc`005ll001S?000Hc`200002V<l001S?6<l001S>`00Ic/006Lk0P0000YW>`00Ic]W>`00Ic/0
06Lk001W>`800005Ic/006LkIc/00002Ic/00`00Ic/000020002IcX00`00IcX00002IcX01@00IcX0
06Lj00000VLj00H006Lj001W6P00IaX200001fLJ001W6VLJ001W6P00009W6P<00009IaX006LJIaX0
06LJ001W6P00009W6P<00007IaX006LJIaX006LJ00000VLJ0`0000AW6P00IaYW6P80009W6P09001S
6P00H_X006;j001RnP00009RnP05001RnP00H_X00002H_X3000016;j001RnP000V;j00H006;j001R
nP00H_X5000015kj001NnP000UkJ00`005kJ001NfP00G]X005kJ001NfP00G]X3000025kJ001JfP00
F]X005[J0002F]X03000F]X005Zj001J^P00F[X005Zj001J^P800004E[X005Jj0002E[X04000E[X0
05Jj001F^P00E[X005Jj001B^`00D[/005:k0P0001MBV`00DY/005:K001BV`00DY/005:K001BV`00
DY/005:K001BV`00DY/005:K00800007DY/005:K001BV`00DY/00P0002EBV`00DY/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`02
00009e:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005;K001Bf`0300005EKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`0;000KOol00`00Oomoo`0@Ool20008Ool20007Ool20006Ool20006Ool007Ioo`03
001oogoo05ioo`03001Bg000009Bg080000;D]`005;L001Bg000D]`005;L001Bg00200001U;L001B
g5;L001Bg080000;D]`005;L001Bg000D]`005:l001B_00200002e:l001B_000D[`005:l001>_000
C[`00P0000=>_000C[`00P0000M>_000C[`004jl001>_00200001dZl001:_000B[`004Zl00<00003
AY`004JL00H00004@Y`00000@W`2000013il000003Yl0P0000<jO@000000100000H^?000000Z?000
8Q`2000011gl0000016k0P0000D=^`00000000Vk00L000038Wh002Zo00800005?_l00000Bcl00002
Del00`00Eeh00002Feh01000Ggd006=m0`000VMl00D006MlIg`006]k00800003Jg/006]k009[N`04
001[F`000002JeX02000KeY_FP00KeX006mJ0002KeX01@00KeY_FVmJ00000VmJ00D006mJKeX006mI
0080009_>P05001_>Fli001_>@020002JcT01@00JcU[>@00JcT00P000V/i00@006/iJcT0009[>@06
001[>F/i001[>@000V/i00@006/i0000009[6@07001[6F/I001[6@00JaT00P000V/I00L006/IJaT0
06/I001[6@020002JaT02000IaUW6@00IaT006LI0002IaT00`00IaT00002IaT01P00IaUW6@00IaT0
009W6@07001W6FLI001W6@00IaT00P000VLI00P006LI001Vn@00I_T006Ki0P0000EVn@00I_UVn@00
009Vn@03001Vn@00009Vn@07001Vn@00I_T006Ki00000V;i00H006;i001Rn@00H_T2000016;i001R
nF;i0P000V;J00H006;J001RfP00G]X400002UkJ001NfP00G]X005kJ001NfP000U[J00@005[J001J
^P80000;F[X005Zj001F^P00E[X005Jj001F^P0:00002E:K001>V`00CY/004jK001>V`0200001dYk
001:N`00BW/004Yk00800003AW/004Ik00800004AW/00000AW/400001D9k0012N`00@W/00P0000=2
N`00@W`00P0000=2O000@W`01@0000HnG000000nG000?U`200000ciL0000000200000cYL000jG002
00001SYL000003YL000jG0800006>U`00000>U`003YL0P0000/jG000000003IM000fO@00=Wd003Ym
0080000;>Wd00000000jO@00>Yd003jM000nW@02000014:m000004KM3`0000IG7@00Ead005LM0002
Fad02P00Fcd005ll001O?000Gc`006<l0P0000YS?000HcaS?000Hc`006<k001W>`800005Ic/006Lk
Ic/00002Ic/200001FLk000006Lk00000VLk00X006LkIc/006Lk001W>`00Ic/0009W>P08001W>VLj
001W>P00IcX0009W>P03001W>P00009W>P05001W6P00IaX00002IaX01@00IaX006LJ00000VLJ00<0
06LJ00000VLJ00D006LJ001W6P00009W6P<00007IaX006LJIaX006LJ00000VLJ0`0000AW6P00IaX0
009W6P06001W6P00IaX006<J0`000V;j00L006;j001RnP00H_X00002H_X3000016;j001RnP000V;j
00l006;j001RnP00H_X006;j001RnP00H_X005kj00000Ukj00L005kJ001NfP00G]X00002G]X00`00
G]X0000200000ekJ00000002G]X20002F]X05P00F]X005[J001JfP00F[X005Zj001J^P00F[X005Zj
001F^P00E[X005Jj;P0000MBV`00DY/005:K001BV`0200001e:K001BV`00D[/005:k0080000OD[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
0P0001QB^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0002D[/02P00
D[/005:k001B^`00D]/005;K100000=Ff`00E]/04@0000YFf`00E]/005KK001Ff`00E]/001]oo`03
001oogoo011oo`8000Qoo`8000Ioo`8000Qoo`8000Eoo`00Mgoo00<007ooOol0GWoo00X005;L001B
g000D]`005;L001Bg080000CD]`005;L001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`00P00
00]Bg000D[`005:l001B_000D[`005:l00800009D[`004jl001>_000C[`004jl00800007C[`004jl
001>_000C[`00P0000=>_000B[`00P0000E:_000B[`004Zl00800008AY`00000AY`004JL0016W0<0
0005@W`003il000nO00200001cYl00000000=Ud003IM00@00003:S`00000008000037O`0000000H0
00053K`00000000=g00600000b9n000Z_`0200001Cko000004/o00000U=O00@005MN001KGPD0009S
O@05001WO6Ml001WO00200001FMk001[Nf]k00000f]k00<006]K00000f]J00@006mJ000000=_FP05
001_FVmJ001_FP020003KeX01P00KeY_FP00KcX000=_>P04001_>Fli0002JcX01000JcU[>@000V/i
00<006/i00000f/i00@006/i001[>@80009[>@04001[>F/i0002JcT01P00JcU[>@00JaT0009[6@04
001[6@000002JaT00`00JaT00002JaT01000JaT000000V/I00<006/I00000VLI00<006LI00000P00
0VLI00L006LIIaT006LI001W6@020002IaT01`00IaUW6@00IaT006LI0080000:IaT006LIIaT006LI
001Vn@00I_T200001FKi001VnFKi00000VKi00H006Ki001Vn@00I_T2000016Ki001Vn@000VKi00H0
06;i001Rn@00H_T200003V;i001RnF;i001Rn@00H_T006;J001RfP00H]X200002UkJ001NfP00G]X0
05kJ001NfP000UkJ00`005kJ001JfP00F]X005Zj001J^P00F[X900000eJj001F^P0200001E:J001B
VP00DY/03@0000U:N`00BW/004Yk001:N`00AW/00P0000=6N`00AW/00`0000=6N`00AW/0100000E2
N`00@W/0049k00800004@W`00000@W`200000d9l0000000200001SiL000003iL000nG0800003?U`0
03iL00800003>U`003YL00800003>U`003YL00800009>U`00000000jG000>U`003YL00800003>Wd0
000000<00005=Wd003Ym000jO@03000033Ym000003ZM000nW@00?Yd003jm0012_@<0000>A]d004[M
001:o@00C_d004km001Bo@00Dad0009G7@0<001G7@00Ead005/M001K?@00Gc`005ll100000EO?000
HcaS?000009S?0800005Hc/00000Hc/00002Ic/02P00Ic]W>`00Ic/006Lk001W>`000VLk00L006Lk
Ic/006Lk001W>`030002Ic/01`00IcYW>P00IcX006Lj00800004IcX006Lj0002IcX01@00IcX006LJ
00000VLJ00<006LJ00000VLJ00<006LJ00000P000VLJ00D006LJ001W6P00009W6P<00009IaX006LJ
IaX006LJ001W6P00009W6P05001W6P00IaX00002IaX01P00IaX006LJ001W6P80000:H_X006;j001R
nP00H_X006;j0002H_X3000016;j001RnP000V;j00P006;j001RnP00H_X006;j0`000V;j0P000Ukj
00L005kj001NfP00G]X00002G]X5000055kJ001NfP00G]X005kJ001JfP00F]X005[J001JfP00F]X0
05Zj0002F[X01@00F[X00000F[X01`0001=F^P00E[X005Jj001F^P00E[X005Jj001F^`00D[/005:k
001B^`0200005e:k001B^`00DY/005:K001BV`00DY/005:K001BV`00DY/005:K001BV`00DY/05000
01]B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P00
01]B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/05000
01AFf`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`000UKK00D005KK001Ff`0001Yo
o`03001oogoo011oo`8000Qoo`8000Ioo`8000Qoo`8000Eoo`00N7oo00<007ooOol0GWoo00@005;L
001Bg080000;D]`005;L001Bg000D]`005;L001Bg00200002e;L001Bg000D]`005;L001Bg000D]`0
0P0000=Bg0000000300000U>_000C[`004jl001>_000C[`00P0000U>_000C[`004jl001>_000C[`0
0P0000E:_000B[`004Zl00800003BY`004JL00800003AY`004JL00800003@Y`0000000<00006?W`0
0000>W`003Yl0P0000PfG@00000bG@00;S`002Xl0P0000@V7000000Mo08000036O`0000000<00005
3M`00000000Ao00:00001Sko000004/o001CG`D00005Feh005mMGed00002Hgd01P00Ig`00000Ig`0
009WN`05001[Nf]k001[N`020002Je/01@00JeY[FV]J00000V]J00H006mJKeY_FP00KeX20002KeX0
1@00KeY_FP00KeX00P000Vlj00D006ljKcX006li0080009[>P05001[>F/i001[>@020002JcT01@00
JcU[>@00JcT00P000V/i00L006/iJcT006/i001[>@020002JcT01000JaU[6@000V/I00<006/I0000
0V/I00@006/IJaT0009[6@03001[6@00009[6@04001[6F/I0002IaT01@00IaT006LI00000VLI00@0
06LI001W6@80009W6@03001W6@00009W6@06001W6FLI001W6@000VLI00<006LIIaT00P000VKi00<0
06Ki00000VKi00<006Ki00000VKi00@006Ki001Vn@80000<I_T006KiI_T006Ki001Vn@00H_T006;i
0P0000iRn@00H_URn@00H_T006;i001Rn@00H]X006;J0P0000ARfP00G]YNfP80009NfP0>001NfP00
G]X005kJ001NfP00F]X005[J001J^PD0000AF[X005Jj001F^P00E[X005Jj001F^P00D[X005:J001B
VP0200001e:K001>V`00CY/004jK00800003CY/0000000@00007BW/004Yk0016N`00AW/00P0000I6
N`000016N`00AW/200000d9k0012N`0200001D9k0012N`00@W`00P0000=2O000@W`00`0000PnO000
000nG000?U`003iL0P0000<nG000?U`00P0000HnO000000jG000>U`200000cYL000jG00200000cYL
0000000300001cYL000jG000>Wd003Ym00@00005>Wd003Ym000jO@0300000cjM0000000200001cjM
000n_@00@[d004:m0080000>A]d004[M001:o@00C_d004km001Bo@00Dad0009G7@07001G7@00001K
7@00Fcd0100000AO?000Gc`0009O?00:001S?6<l001S?000Hc`006<k0002Hc/01`00Ic]W>`00Ic/0
06Lk00<0009W>`07001W>fLk001W>`00Ic/00P0000AW>`00Ic/0009W>`04001W>P00IcX2000016Lj
001W>P000VLj00@006Lj001W>P800004IaX006LJ0002IaX01@00IaX006LJ00000VLJ00D006LJ001W
6P00009W6P<00009IaX006LJIaX006LJ001W6P00009W6P<00007IaX006LJIaX006LJ00000VLJ0`00
00IS6P00H_X006;j0002H_X20002H_X3000016;j001RnP000V;j00D006;j001RnP00009RnP<0000<
H_X006;j001RnP00H_X005kj001NnP000UkJ00<005kJ00000P0000INfP00G]X005kJ0002G]X20002
G]X2000015[J001JfP000U[J00@005[J001J^PL0000NF[X00000E[X005Jj001F^P00E[X005Jj001F
^P00E[X005Jj001F^`00D[/005:k001B^`00D[/005:k0P0001]BV`00DY/005:K001BV`00DY/005:K
001BV`00DY/005:K001BV`00DY/005:K001BV`00DY/00P0000UB^`00D[/005:k001B^`00D[/0>P00
00]B^`00D[/005:k001Bf`00D]/005KK00@0000:E]/005KK001Ff`00E]/005KK0002E]/04`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`0001]oo`03001oogoo00moo`<000Ioo`<000Io
o`8000Qoo`8000Eoo`00N7oo00<007ooOol0GWoo00@005;L001Bg1d0000;D]`005:l001B_000D[`0
05:l001B_00200000e:l0000000C000024Zl000004Zl001:_000B[`200000dJL0016W00200002DJL
0016W000@Y`004:L0012O00400001cYl00000000=Ud003IM00@00003:S`002Xl008000038Q`00000
00<000035M`0000000L000035Qd0000000<00003<[l003[O00L00007Deh005MNEeh005]N00000UmM
00H006=m000006=l0002Ig`01@00Ig]WN`00Jg/00P000V]K00D006]KJe/006]J008000=[FP07001_
FVmJKeX006]J00000fmJ00@006mJKeX0009_FP04001_>Vlj0002KcX01000JcY[>P000V/j00@006/i
JcT0009[>P04001[>F/i0002JcT00`00JcX00002JcT01@00JcU[>@00JcT00P000V/i00L006/iJcT0
06/I001[6@020002JaT01`00JaU[6@00JaT006/I0080009[6@07001[6F/I001[6@00IaT00P000VLI
0P000VLI00H006LI000006LI0002IaT01`00IaUW6@00IaT006LI0080009W6@03001W6@00009W6@03
001W6@000080009Vn@03001Vn@00009Vn@04001Vn@00I_T2000036Ki001VnFKi001Vn@00I_T006Ki
001Rn@80000>H_T006;iH_T006;i001Rn@00H_T006;i001RfP80000DH]X006;JH]X005kJ001NfP00
G]X005kJ001NfP00G]X005kJ001JfP@00005F[X00000F[X00002F[X02P00E[X005Jj001F^P00E[X0
05Jj0P0000UBVP00DYX005:K001BV`00CY/00P0000=>V`00CY/00P0000E>V`00BW/004Yk00@00003
AW/004Ik00800003AW/004Ik00800005AW/004Ik0012N`0200000d9k0000000200001T9l0000049l
0012O0800004@W`00000?W`400000ciL000nG00200000ciL000nG00200000cil0000000300001CYL
000jG000>U`00`0000<jO00000000P0000<jG000>Wd00`0000<jO@00>Wd0100000@jO@00000jO@80
0003?Yd003jM00H0000G@[d004KM0016g@00B]d004[m001>o@00C_d005;m001C7@00Ead005LM001G
7@03000015/m001O?0000Ull00<005ll00000Ull00@006<l001S?0<0009S>`07001S>f<k001W>`00
Ic/00P0000AW>`00Ic/0009W>`04001W>`00Ic/200002VLk001W>fLk001W>`00Ic/006Lj0P0000YW
>`00IcYW>P00IcX006Lj001W>P800004IaX006LJ0002IaX01000IaX006LJ0`000VLJ00D006LJIaX0
06LJ00<00009IaX006LJIaX006LJ001W6P00009W6P<00009IaX006LJIaX006LJ001W6P00009W6P05
001S6P00HaX00002H_X01P00H_X006;j001RnP<00004H_X006;j0002H_X01@00H_X006;j00000V;j
0`0000IRnP00H_X006;j0002H_X2000015kj001NnUkj1@0000INfP00G]X005kJ0002G]X01P00G]X0
05kJ001NfP80009JfP03001JfP0000H0000;F[X005Zj001J^P00F[X005Jj001F^P020002E[X04P00
E[X005Jj001F^P00E[X005Jj001F^`00D[/005:k001B^`80000GD[/005:k001BV`00DY/005:K001B
V`00DY/005:K001BV`00DY/005:K001BV`0200001e:K001BV`00DY/005:k0080000SD[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`020000BU:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D]/005;K001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK000KOol00`00Oomoo`0@Ool30004Ool30007
Ool20008Ool20005Ool007Uoo`03001oogoo05ioo`<0000>D]`00000D]`005;L001Bg000D]`005;L
001Bg080000;D]`005;L001Bg000D]`005;L001Bg0020002D]`02P00D[`005:l001B_000D[`005:l
0`0000UB_000C[`004jl001>_000C[`00P0000U>_000C[`004jl001>_000C[`01`0000E:_000BY`0
04JL00800003AY`004JL00800004@Y`00000@Y`200000cil000nO00500001SIM0000039M000bG@L0
00038Q`0000000<000035M`0000000L000036Sd000000080000<<[l003[O0012o`00Aal004lo001C
GP000UMN00@005]N001OG@800005Hed006=lHg`00002Ig`01P00Ig/00000Je/000=[F`04001[F`00
0002Je/01P00JeY[FV]J001_FP80009[FP05001_FVmJ001_FP020003KeX01000KcX006lj0P000f/j
00@006/j001[>@80009[>P05001[>F/i001[>@020002JcX01000JcU[>@000V/i00<006/j00000V/i
00D006/iJcT006/I0080009[6P07001[6F/I001[6@00JaT00P000V/J00<006/I00000V/I00@006/I
0000009W6P05001W6@00IaT00002IaT00`00IaT00002IaT01`00IaUW6@00IaT006LI0080009W6@03
001W6@00009W6@05001W6@00IaT00002I_T00`00I_T00002I_T01000I_T006Ki0P0000aVn@00I_UV
n@00I_T006Ki001Vn@00I_T200001f;i001RnF;i001Rn@00009Rn@80009Rn@<0000BH]X006;JH]X0
06;J001NfP00G]X005kJ001NfP00G]X005kJ100001EJfP00F]X005Zj001J^P00F[X005Zj001F^P00
E[X005Jj001F^P00E[X00P0000eBVP00DYX005:K001BV`00CY/004jK001>V`0200001DjK001>V`00
BW/00P0000=:N`00BW/01P0000I6N`000016N`00AW/200000d9k0012N`0200000d9k0012N`050000
0d9l0012O00200001Sil000003il000nO0800005?U`003iL000nG00200001Sil000003il000nO080
0006>U`00000>U`003YL0`0000<jO00000000P0000HjO@00000jO@00>Wd200000cYm000000020000
0cYm000jO@02000023jM000003jM0012_@00@[d800002D[m001>o@00C_d005;m001C7@0700001e/M
001K?E/m001O?000009O?006001O?000Gc`006<l0P0000AS?000Hc`0009S>`04001S>`00Ic/20000
2V<k001W>fLk001W>`00Ic/006Lk0P0000YW>`00Ic]W>`00Ic/006Lk001W>`80000:Ic/006LkIc/0
06Lj001W>P00IcX200002VLJ001W6VLJ001W6P00IaX006LJ0P0000AW6P00IaX0009W6P07001W6P00
IaX006LJ00000VLJ00D006LJ001W6P00009W6P<00009IaX006LJIaX006LJ001W6P00009W6P<0000A
HaX006<JHaX006;j001RnP00H_X006;j001RnP00H_X00002H_X01@00H_X006;j00000V;j0`0000AR
nP00H_X0009RnP04001RnP00H_X20002G_X300001UkJ001NfP00G]X0009NfP0<001NfP00G]X005kJ
001NfP00G]X005[J1@0000aJfP00F]X005Zj001J^P00F[X005Zj0002F[X200006eJj001F^P00E[X0
05Jj001F^P00E[X005Jj001F^P00E[/005:k001B^`00D[/005:k001B^`0200006e:K001BV`00DY/0
05:K001BV`00DY/005:K001BV`00DY/005:K001BV`00DY/005:K001BV`0200004E:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/00P00015B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k0080000:D[/005:k001B^`00D[/005:k0002D[/06000D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001Bf`80000NE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK001Ff`000UKK00D005KK001Ff`0001Yoo`03001oogoo015oo`P0
00Qoo`8000Qoo`8000Eoo`00NGoo00<007ooOol0GWoo00<005;L00000U;L0P0000]Bg000D]`005;L
001Bg000D]`005;L0080000;D]`005;L001Bg000D]`005;L001Bg00200002e;L001B_000D[`005:l
001B_000D[`00P0000]B_000D[`004jl001>_000C[`004jl00800007C[`004jl001>_000C[`00P00
00I:_000001:_000B[`900001DJL0016W000@Y`00P0000A2W000000nO0800007?Wd003Ym000fG@00
=Ud0100000<^?@00;Sd01@0000<R700000000`0000LEo0003M`0017l000Ao00300004B9N00000000
<[l003[O0012o`00Aal004lo001CGP00Eeh0100000EOG@00HeeSG@00009SO006001WO000001WG000
0V]K00D006]KJe][F`00009[F`04001[Ff]K0003JeX01000JeY[FP000V]J00@006mJ0000009[FP05
001_FVmJ001_>P020002JcX01@00JcY[>P00JcX00P000V/j00@006/jJcX0009[>@04001[>V/j0002
JcX01000JcT006/i0P000V/j00@006/iJcT0009[>@03001[6P00009[6P05001[6F/I001[6@020000
1F/J001[6V/J00000V/I00H006/IJaT006LJ0002IaX00`00IaUW6@0200000fLI00000002IaT00`00
IaT00002IaT01P00IaUW6@00IaT0009W6@07001W6FLI001W6@00IaT00`000VKi00H006KiI_T006Ki
0002I_T00`00I_T00002I_T01@00I_T006Ki00000VKi0`0000MRn@00H_URn@00H_T00002H_T01000
H_T006;i0`0000MRnP00H]YRfP00H]X00002H]X01000G]X000000UkJ1@0000ANfP00G]X0009JfP80
009J^P800004F[X005Zj0002E[X01000E[X005Jj0P0000eF^P00D[X005:J001BVP00DY/005:K001>
V`02000034jK000004jK001>V`00BW/004Yk001:N`800003BW/004Yk00D00007AW/004Ik0016N`00
@W/00P0000I2N`000012N`00@W`40000149l0000049l0P0000<nO000?W`00P0000<nO00000000P00
00<nG000?U`00P0000<nO000?W`0200000@jG000000jO0800003>W`0000000@00004>Wd00000>Wd2
00000cYm000jO@0200001CYm000nW@00?Yd00P0000<nW@00@[d00P0000M6_@00A]d004[M001:g@09
00002U<M001G7@00Ead005LM001K7@000U/m00H005ll001O?000Gc`400002V<l001S?6<l001S?000
Hc/006<k0P0000YS>`00Hc]S>`00Ic/006Lk001W>`80000:Ic/006LkIc/006Lk001W>`00Ic/20000
2VLk001W>fLk001W>`00IcX006Lj0P0000YW>P00IaYW6P00IaX006LJ001W6P800004IaX006LJIaX2
0002IaX00`00IaX000020002IaX01@00IaX006LJ00000VLJ0`0000UW6P00IaYW6P00IaX006LJ0000
0VLJ0`0000aS6P00HaYS6P00HaX006;j001RnP00H_X30002H_X01`00H_X006;j001RnP00009RnP<0
0004H_X006;j0002H_X02000H_X006;j001RnP00H_X300001UkJ001NfP00G]X0009NfP0<001NfP00
G]X005kJ001NfP00G]X005kJ0`0000YJfP00F]X005[J001JfP00F[X0009J^P0:001J^P00F[X005Zj
001F^P00E[X200005eJj001F^P00E[X005Jj001F^P00E[X005Jk001B^`00D[/005:k001B^`00D[/0
0P0001eBV`00DY/005:K001BV`00DY/005:K001BV`00DY/005:K001BV`00DY/005:K001BV`00DY/0
05:k0080000QD[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k0080000YD[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D]/005;K001Ff`0400002UKK001Ff`00E]/0
05KK001Ff`000UKK00`005KK001Ff`00E]/005KK001Ff`00E]/7000KOol00`00Oomoo`0@Ool80008
Ool20008Ool20005Ool007Yoo`03001oogoo05ioo`04001Bg000D]`200001U;L001Bg5;L001Bg080
0009D]`005;L001Bg000D]`005;L0080000CD]`005;L001Bg000D]`005;L001B_000D[`005:l001B
_000D[`00P0000=B_000D[`00P0000]>_000C[`004jl001>_000C[`004jl00800005C[`004jl001:
_00200002TZl000004Zl001:W000BY`004JL1@0000I2W0000012W000@W`200000cil000nO@060000
1C9M00000000;Sd00P0000<Z?@0000000`0000<N70005M`02@0000DF7@00000002Yn00h00004Eeh0
05]M0002Ged01@00HeeSG@00Hg`00P0000EWG000IeaWG000009[F`05001[F`00Je/00002Je/01@00
Je][F`00JeX00P000f]J00H006]JJeX006]J0003JeX01P00KeY_FP00JcX000=[>P06001[>V/j001[
>P000f/j00@006/j001[>@80009[>P05001[>V/j001[>@020002JcX01`00JcY[>P00JcT006/i0080
009[6P04001[6V/J0002JaT00`00JaX00002JaX01`00JaY[6P00JaT006/I0080009W6P08001W6VLJ
001W6@00IaT0009W6P03001W6@00009W6@04001W6@00IaT20002IaT01P00IaUW6@00IaT0009W6@05
001W6@00I_T00002I_T01P00I_T006Ki001Vn@80009Vn@03001Vn@00009Vn@03001Vn@0000800007
H_T006;iH_T006;i00000V;i00T006;i001Rn@00H_T006;j00000V;j00<006;J00000V;J00H006;J
001NfP00G]X3000015kJ001NfP000UkJ01@005kJ001JfP00F]X005Zj001J^P00F[X005Zj001F^P00
E[X005Jj0P0000eF^P00D[X005:J001BVP00DY/005:K001>V`0200001djK001>V`00CY/004jK0080
0003BW/004Yk00800003BW/004Yk00800003AW/004Ik00@00005AW/0049k0012N`0200000d9k0012
N`0300000d9l0000000200000d9l000nO00200000cil000nO00200000cil000nO002000033iL0000
03il000nO000?W`003il000nO0@00004>W`00000>W`200000cYl000jO@0200000cYm000jO@020000
0cYm000jO@0200000cjM0000000200001cjM000nW@00?Yd004:m00800005A[d004KM001:g@020000
24[m001>o@00C_d005;m0002Dad03P00Ead005LM001G7@00Fad005/m001O?000Gc`2000015ll001O
?0000V<l00H006<l001S?000Hc/200002V<k001S>f<k001S>`00Ic/006Lk0P0000YW>`00Ic]W>`00
Ic/006Lk001W>`80000:Ic/006LkIc/006Lk001W>`00IcX200002VLj001W>VLj001W6P00IaX006LJ
0P0000UW6P00IaYW6P00IaX006LJ00000VLJ00L006LJ001W6P00IaX00002IaX00`00IaX000020000
2FLJ001W6VLJ001W6P00IaX00002IaX300002F<J001S6V<J001S6P00HaX00002H_X300002V;j001R
nP00H_X006;j001RnP000V;j0`0000ARnP00H_X0009RnP08001RnP00H_X006;j001RnP<00004G_X0
05kJ0002G]X02@00G]X005kJ001NfP00G]X00002G]X00`00G]X0000200001ekJ000005[J001JfP00
009JfP0@001JfP00F[X005Zj001J^P00F[X005Zj001F^P00E[X2000015Jj001F^P000UJj00h005Jj
001F^P00E[X005Jk001B^`00D[/005:k0P0001MB^`00D[/005:K001BV`00DY/005:K001BV`00DY/0
05:K001BV`00DY/005:K00800007DY/005:K001BV`00D[/00P0002=B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0080000WD[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001Bf`00D]/005KK00<0000;E]/005KK001Ff`00E]/005KK001Ff`0?00001UKK001Ff`00E]/0
01Qoo`@0015oo`<000Aoo`<000Moo`8000Qoo`8000Eoo`00Ngoo00<007ooOol0GGoo00<005;L0000
0U;L0P0000]Bg000D]`005;L001Bg000D]`005;L0080000;D]`005;L001Bg000D]`005;L001Bg002
0002D]`02`00D[`00000D[`005:l001B_000D[`00P0000UB_000C[`004jl001>_000C[`00P0000M>
_000C[`004jl001>_00200001DZl001:_000B[`00P0000E:_000BY`004ZL00<00003AY`004JL00@0
0004@Y`00000?W`200001cim000jO@00>Wd003IM00<00003<Ud002hm00<00003:Sd0028L00D00004
5M`000005O`9000022Yn000003KO000no`00@_l2000014ln001C?P000UMN00<005]M00000UmM00H0
06=M000006=L0002Ie`01@00IeaWG000Je/00P000f]K00D006]KJe/006]K0080009[FP05001[FV]J
001[FP020002JeX01@00JeY[FP00KeX00P000V/j00D006/jJcX006/j0080009[>P05001[>V/j001[
>P020002JcX01000JcY[>P000V/j00<006/j00000V/j00D006/jJcX006/i0080009[6P07001[6V/J
001[6P00JaT00P000V/J00L006/JJaX006/J001[6@020002IaX00`00IaX00002IaX00`00IaT00002
0002IaX01`00IaUW6@00IaT006LI0080009W6@03001W6@00009W6@04001W6@00IaT2000016LI001V
n@000VKi00@006Ki001Vn@80009Vn@03001Vn@00009Vn@07001Vn@00I_T006Ki00000V;i00<006;i
00000V;i00H006;i001Rn@00H_T30002H_X00`00H_X00002H]X02`00H]X006;J001NfP00G]X005kJ
00000UkJ01`005kJ001NfP00G]X005[J001JfP00F[X005Zj001J^P00F[X005Jj001F^P00E[X005Jj
001F^P80000=DYX005:J001BV`00DY/004jK001>V`00CY/00P0000U>V`00CY/004Yk001:N`00BW/0
0P0000=:N`00BW/00P0000I6N`000016N`00AW/200000d9k0012N`0200001D9k0012N`00@W`00`00
00=2O000@W`00P0000DnO000?W`003il00800003?W`003il00800003?W`0000000<00003?W`003il
00800004?W`00000?W`400000cYl000jO002000013Yl000003Ym100000<jO@00>Wd00P0000HjO@00
000nW@00?Yd400002CjM0012_@00@[d004Jm0016g@0200005D[M001:o@00C_d004km001Bo@00Dad0
05LM001G7@00Ead005/M001K?@04000035ll001O?5ll001O?000Hc`006<l001S?080000:Hc`006<k
Hc/006<k001S>`00Ic/200002FLk001W>fLk001W>`00Ic/00002Ic/00`00Ic/00002Ic/01P00Ic/0
06Lk001W>`800009Ic/006LjIcX006Lj001W6P00009W6P03001W6P00009W6P08001W6P00IaX006LJ
001W6P80009W6P80009W6P07001W6P00IaX006LJ00000VLJ00D006LJ001W6P00009W6P<00009HaX0
06<JHaX006<J001S6P00009S6P<00004H_X006;jH_X20002H_X20002H_X3000016;j001RnP000V;j
00D006;j001RnP00009RnP<00003H_X00000009NnP09001NfP00G]X005kJ001NfP00009NfP03001N
fP0000@0000QG]X005kJ001JfP00F]X005[J001JfP00F]X005Zj001J^P00F[X005Zj001J^P00E[X0
05Jj001F^P00E[X005Jj02`00005DY/005:K001BV`0200004E:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/00P00015B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0080000:D[/0
05:k001B^`00D[/005:k0002D[/06000D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001Bfa80000DE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0015oo`L0
00=oo`03001oogoo00ioo`8000Qoo`8000Ioo`8000Qoo`8000Eoo`00Ngoo00<007ooOol0GWoo00`0
05;L001Bg000D]`005;L001Bg000D]`200002E;L001Bg000D]`005;L001Bg00200002e;L001Bg000
D]`005;L001Bg000D[`00P0000]B_000D[`005:l001B_000D[`005:l0080000;C[`004jl001>_000
C[`004jl001>_00200001Djl001>_000B[`00P0000=:_000B[`00P0000E:W000BY`004JL00800006
AY`00000AY`004:L1@0000<nO000?Wd00`0000@jO@00000fG@800005<Ud00000000Z?@040000128L
000001gl0P0000@Eo000000Io@D000048Uh00000:Wh200001CKO000no`00@_l00P0000A??P00Dch0
009GGP04001KG@00Ged20002Hed00`00He`00002Ie`01000Ie`000000VMK00H006]KJe][F`00Je/2
00000f]K001[FP02JeX01000JeY[FP000V]J00@006]JJeX0009[FP04001[>V/j0002JcX01000JcY[
>P000V/j00@006/jJcX0009[>P03001[>P0000=[>P04001[>P00JcX20002JcX01000JcY[>P000V/j
00<006/j00000V/J00D006/JJaX006/J0080009[6P03001[6P00009[6P06001[6P00001W6P000VLJ
00@006LJIaX0009W6P05001W6P00IaX00002IaX01000IaT006LI0P0000EW6P00IaUW6@00009W6@04
001W6@00IaT20002IaT02000IaT006Ki001Vn@00I_T200001FKi001VnFKi00000VKi00<006Ki0000
0VKi0P000VKi00<006;i00000V;i00H006;i001Rn@00H_T200001V;j001RnP00H_X0009RnP06001R
fP00H]X006;J1@000UkJ00L005kJ001NfP00G]X00002G]X03@00F]X00000F[X005Zj001J^P00F[X0
05Jj01T00009CY/004jK001:N`00BW/004Yk00800003BW/004Yk00800005AW/004Ik0016N`020000
0dIk0000000200001T9k0000049k0012O0800003@W`0049l00800003@W`0000000800003?W`003il
00800003?W`003il00800003?W`0000000800007?W`00000000nO000?W`00P0000<nO000>W`00P00
00<jO000>W`00P0000HjO@00000jO@00>Wd200001CYm000jO@00>Wd00P0000HnW@00000nW@00@Yd6
00000dJm0016g@0200003d[M001:o@00C_d004km001Bo@00Dad005LM001G7@06000015/M001K?000
0Ull00P005ll001O?000Hc`006<l0P0000YS?000HcaS?000Hc/006<k001S>`800009Hc/006LkIc/0
06Lk001W>`00009W>`<0009W>`05001W>`00Ic/00002Ic/00`00Ic/00002Ic/01@00IcX006Lj0000
0VLJ0`000VLJ00D006LJ001W6P00009W6P<0009W6P08001W6P00IaX006LJ001W6P<0009W6P05001W
6P00IaX00002IaX300002F<J001S6V<J001S6P00HaX00002HaX3000036;j001RnV;j001RnP00H_X0
06;j001RnP<0000;H_X006;jH_X006;j001RnP00H_X00002H_X300003V;j001RnP00G_X005kj001N
fP00G]X005kJ0002G]X500001UkJ001NfP00G]X0009NfP80000<F]X005[J001JfP00F]X005Zj001J
^P000UZj00@005Zj001J^PX0000CE[X005Jj001F^P00E[X005Jk001F^`00D[/005:k001B^`00D[/0
0P0001EB^`00D[/005:k001B^`00D[/005:K001BV`00DY/005:k001B^`00D[/0700000mB^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/00P0000]B^`00D[/005:k001B^`00D[/005:k01`0000BE]/0
05KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`000UKK00X005KK001Ff`00E]/005KK001Ff`80
0004E]/005KK000:Ool7000:Ool00`00Oomoo`0>Ool20008Ool20007Ool20006Ool20006Ool007ao
o`03001oogoo05eoo`0:001Bg000D]`005;L001Bg000D]`f00002Djl001>_000B[`004Zl001:_002
00001DZl001:W000BY`00P0000I6W0000016W000AY`200000d:L0012W00300000cim000jO@020000
1CYm00000000=Ud01P0000<Z?@009Qd00P0000@N7000000N70D000036Qd00000008000038Uh00000
00<00005=]l003ko0012o`0200001Dln001C?P00Eeh01@0000QOG@00HeeSG@00He`006ML0P000VML
00@006MKIe/000=[F`03001[F`00009[F`05001[FV]J001[FP020003JeX01000JeX006]J0P000f/j
00@006/j001[>P80009[>P05001[>V/j001[>P020002JcX01@00JcY[>P00JcX00P000V/j00L006/j
JcX006/j001[>P020002JcX01000JaY[6P000V/J00<006/J00000V/J00@006/JJaX0009[6P03001W
6P00009W6P07001W6VLJ001W6P00IaX00P000VLJ0P000VLJ00H006LIIaT006LJ0002IaX01`00IaUW
6@00IaT006LI0080000:IaT006LIIaT006LI001Vn@00I_T200001FKi001VnFKi00000VKi00H006Ki
001Vn@00I_T2000016Ki001Vn@000V;i00H006;i001Rn@00H_T200001V;j001RnP00H_X0009RnP06
001RnP00H]X006;J0P0000YNfP00G]X005kJ001NfP00G]X0009NfP0:001NfP00G]X005[J001JfP00
F[X700001EJj001F^P00E[X00P0000eF^P00D[X005:J001BV`00DY/005:K001BV`0200000djK001>
V`0600000dYk001:N`0200001dYk001:N`00AW/004Ik00800003AW/004Ik00800003AW/004Ik00@0
0004@W/00000@W`200000d9l0012O00200000d9l0012O00400002Sil000003il000nO000?W`003il
1P0000HnO000000nO000?W`200000cYl0000000200000cYl000jO@02000013Ym000003Ym100000Dj
O@00?Yd003jM00800008?Yd00000@[d004:m0016_A@00006Ead005LM001K7@000U/M00P005/l001O
?000Gc`005ll100000YS?000HcaS?000Hc`006<k001S>`800009Hc/006<kHc/006Lk001W>`00009W
>`<0009W>`05001W>`00Ic/00002Ic/30002Ic/01@00Ic/006Lj00000VLj0`000VLJ00D006LJ001W
6P00009W6P<0000:IaX006LJIaX006LJ001W6P00IaX200001VLJ001W6P00IaX0009W6P03001W6P00
00800009HaX006<JHaX006<J001S6P00009S6P<0000<H_X006;jH_X006;j001RnP00H_X006;j0`00
00]RnP00H_YRnP00H_X006;j001RnP00009RnP<00004H_X006;j0002H_X20002G_X20002G]X00`00
G]X00002000025kJ001NfP00G]X005kJ0002G]X01000G]X005[J0P0000AJfP00F]X0009JfP04001J
^P00F[X700000eJj001F^P0200006EJj001F^P00E[X005Jj001F^P00E[X005Jk001F^`00D[/005:k
001B^`00D[/005:k0080000KD[/005:k001B^`00D[/005:K001BV`00DY/005:k001B^`00D[/005:k
001B^`00D[/005:k0080000AD[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0N00006E:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D]/005KK00800004E]/005KK
0002E]/07`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`00009oo`L0015oo`03001oogoo00ioo`8000Qoo`8000Moo`8000Ioo`8000Ioo`00O7oo
00<007ooOol0GWoo2@0000=Bg000D]`00P0000UBg000D]`005;L001Bg000D]`00P0000]Bg000D]`0
05;L001Bg000D]`005:l0080000;D[`005:l001B_000D[`005:l001B_00200002djl001>_000C[`0
04jl001>_000C[`03P0000E:W000BY`004JL00800003AY`004JL00800003@Y`004:L00<00003?W`0
000000<00004>Wd00000=Ud200001C9M000bG@00:Sd0100000<V7@0000000`0000<N700000000`00
00TN?@000000029N000^WP00=[l03@0000MGGP00FeeKG@00Ged00002Hed00`00He`00002Ie`01000
IeaWG0000VMK00@006]K0000009[F`05001[Ff]K001[FP020002JeX01@00JeY[FP00JeX00P000V]J
00D006/jJcX006/j0080009[>P04001[>V/j0002JcX01000JcY[>P000V/j00H006/jJcX006/j0002
JcX01@00JcY[>P00JcX00P000V/j00L006/jJcX006/J001[6P020002JaX01`00JaY[6P00JaX006/J
0080009W6P03001W6P00009W6P04001W6P000002IaX02000IaX006LJ001W6P00IaT20002IaX00`00
IaX00002IaT01P00IaUW6@00IaX0009W6@03001W6FLI0080009Vn@03001Vn@00009Vn@03001Vn@00
009Vn@04001Vn@00I_T2000016Ki001Vn@000VKi00H006;i001Rn@00H_T200003V;j001RnV;j001R
nP00H_X006;j001RnP00H]X2000016;J001NfUkJ0P00011NfP00G]YNfP00G]X005kJ001NfP00G]X0
05[J001JfP<00006F[X005Zj001J^P000UJj0P0000]F^P00E[X005Jj001B^P00DYX005:K00800007
DY/005:K001>V`00CY/00P0000E>V`00CY/004jK00H00003BW/004Yk00800005AW/004Ik0016N`02
000014Ik000004Ik0P0000=2N`000000100000=2O000@W`00P0000=2O000@W`00P0000=2O000@W`0
0P0000HnO000000nO000?W`300000cil000nO00200000cil000nO00200000cil000jO00200000cYl
000jO00200000cYm000jO@0200001SYm000003im000nO@@00003?Yd003jM00800005@Yd004:m0012
_@0200000dJm0016g@0200003T[M001>o@00C_d004km001Bo@00Dad005LM0002Ead03000Ead005/M
001K7@00Fc`005ll001O?0800004Gc`005ll0002Hc`01P00Hc`006<l001S>`800009Hc/006<kHc/0
06<k001W>`00009W>`<00007Ic/006LkIc/006Lk00000VLk0`000VLk00D006Lk001W>`00009W>P<0
0007IaX006LJIaX006LJ00000VLJ0`0000MW6P00IaYW6P00IaX00002IaX3000016LJ001W6VLJ0P00
0VLJ00L006LJ001W6P00HaX00002HaX01@00HaX006<J00000V<J0`0000URnP00H_YRnP00H_X006;j
00000V;j0`0000=RnP0000000V;j00L006;j001RnP00H_X00002H_X3000016;j001RnP000V;j00P0
06;j001NnP00G_X005kJ1@0000INfP00G]X005kJ0002G]X02000G]X005kJ001NfP00F]X20002F]X0
0`00F]X0000600002eZj001J^P00F[X005Jj001F^P00E[X00P0001IF^P00E[YF^P00E[X005Jj001F
^P00E[/005Jk001B^`00D[/005:k001B^`80000ID[/005:k001B^`00D[/005:k001BV`00DY/005:K
001B^`00D[/005:k001B^`00D[/00P0002AB^`00001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/2000065:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/0009B^`06001B^`00D[/005:k0P0002UBf`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK00<001Qoo`03001oogoo00moo`<000Aoo`@000Qoo`8000Aoo`8000Moo`00
OGoo00<007ooOol0GGoo00T005;L001Bg000D]`005;L00000U;L00d005;L000005;L001Bg000D]`0
05;L001Bg00200002e;L001Bg000D]`005;L001Bg000D[`00P0000]B_000D[`005:l001B_000D[`0
05:l0080000GC[`004jl001>_000C[`004jl001>_000C[`004jl001>_000B[`004Zl001:_0050000
1DJL0016W000AY`00P0000I6W0000012W000@Y`300000cim000nO@0200001cYm00000000=Ud0039M
00@00003:Sd00000008000038Qd0000000<000037Qd0000000<000068Sd000008Uh002jN0P0000Xj
g`00@_l004LO001;7`00Cch0009C?P03001GGP00009KG@04001OG@00Hed200001F=L001WG6ML0000
0VML00@006MK0000009[F`05001[Ff]K001[F`0200000f]K001[FP02JeX01P00JeY[FP00JeX000=[
FP06001[>V/j001[>P000f/j00@006/j001[>P8000=[>P04001[>P00JcX20002JcX01000JcY[>P00
0V/j00<006/j00000V/j00D006/jJcX006/J0080009[6P03001[6P00009[6P04001[6P000002IaX0
0`00IaX00002IaX01P00IaYW6P00IaX0009W6P03001W6VLJ00800003IaX00000009W6P03001W6P00
009W6P04001W6@00IaT20002IaX00`00IaT00002IaT00`00IaT000020002I_T00`00I_T00002I_T0
1000I_T006Ki0P0000aVn@00I_UVn@00I_T006Ki001Rn@00H_T200003V;j001RnV;j001RnP00H_X0
06;j001RnP00H_X2000056;J001RfV;J001NfP00G]X005kJ001NfP00G]X005kJ001NfP00G]X50000
3UZj001J^UZj001J^P00F[X005Jj001F^P00E[X200003EJj001B^P00DYX005:K001BV`00DY/005:K
00800007CY/004jK001>V`00CY/00P0000=:V`00BW/01`0000M6N`00AW/004Ik0016N`0200000dIk
0016N`0300000d9k0012O00200001D9l0012O000@W`00P0000=2O000@W`00P0000=2O000@W`01@00
00HnO000000nO000?W`200000cil0000000200000cil000nO00200000cYl000jO00200000cil0000
000200000cYm000jO@0200001Sim000003jM000nW@D0000;@Yd004:m0012_@00A[d004Jm0016g@02
00003T[M001>o@00C_d004km001Bo@00Dad005LM0002Ead200001E/M001K7@00Fc`0100000aO?000
GcaO?000Gc`006<l001S?000Hc`200002F<k001S>f<k001S>`00Hc/00002Ic/300001fLk001W>fLk
001W>`00009W>`<00007Ic/006LkIc/006Lk00000VLk0`0000MW6P00IaYW6P00IaX00002IaX30000
1fLJ001W6VLJ001W6P00009W6P<0000<IaX006LJIaX006LJ001W6P00IaX006LJ0`000V<J00D006<J
001S6P00009S6P<00009HaX006;jH_X006;j001RnP00009RnP<0000:H_X006;j001RnP00H_X006;j
0002H_X00`00H_X00002000016;j001RnP000V;j014006;j001RnP00G_X005kj001NfP00G]X005kJ
001NfP00009NfP0>001NfP00G]X005kJ001NfP00G]X005[J001JfPD0000<F]X005[J001J^P00F[X0
05Zj001J^P000UJj01d005Jj000005Jj001F^P00E[X005Jj001F^P00E[X005Jk001F^`00D[/005:k
001B^`00D[/005:k0080000KD[/005:k001B^`00D[/005:K001BV`00DY/005:k001B^`00D[/005:k
001B^`00D[/005:k0080000OD[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/00P00025B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P0001QBf`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`00E]/005KK0002E]/02P00E]/005KK001Ff`00E]/005KK0P0000AFf`00
000001Yoo`03001oogoo00moo`X000Uoo`P000Moo`00OWoo00<007ooOol0GGoo018005;L001Bg000
D]`005;L001Bg000D]`005;L001Bg000D]`200002E;L001Bg000D]`005;L001Bg00200002e;L001B
g000D[`005:l001B_000D[`00P0000]B_000D[`005:l001>_000C[`004jl00800005C[`004jl001>
_00200002Djl001>_000C[`004Zl001:_00300000dZl001:W00600001TJL000004:L0012W0800004
@W`00000?Wd200001cYm00000000=Ud003IM00800003<Ud002hm00<000059Qd00000000R7@050000
0ahM0000000300001BIN00000000;Yh00P0000Xjg`00@_l004LO001;7`00Cch0009C?P04001GGP00
Fed400001F=M001SG6=L00000VML00H006ML000006MK0003Je/01P00Je][F`00Je/0009[F`05001[
FV]J001[FP020002JeX01@00JeY[FP00JcX00P000V/j00D006/jJcX006/j0080009[>P04001[>V/j
0002JcX01000JcY[>P000V/j00@006/j001[>P80009[>P04001[>V/j0002JcX00`00JaX00002JaX0
1000JaY[6P000V/J00<006/J00000VLJ00L006LJIaX006LJ001W6P020002IaX02P00IaYW6P00IaX0
06LJ001W6P000VLJ00L006LJIaX006LJ001W6@020002IaX00`00IaX00002IaT01@00IaT006LI0000
0VKi00<006Ki00000VKi00@006Ki001Vn@80000<I_T006KiI_T006Ki001Vn@00I_T006;i0P0000MR
nP00H_YRnP00H_X00002H_X200000f;j001RnP0200004V;J001RfV;J001RfP00G]X005kJ001NfP00
G]X005kJ001NfP@0000MG]X005[J001JfP00F[X005Zj001J^P00F[X005Jj001F^P00E[X005Jj001F
^P00D[X005:J001BV`0200001E:K001BV`00CY/00P0000E>V`00CY/004jK00800003BY/004Yk0080
0005BW/004Yk001:N`0400000dIk0016N`0200000dIk0016N`0200000d9k0012N`0200000d9l0000
000200001D9l0012O000@W`00P0000=2O000@W`00`0000DnO000000003il00<00003?W`003il0080
0003?W`003il00800005?W`003Yl000jO00200001SYl000003im000nO@800008>Wd00000?Wd003im
000nW@800003?Yd003jM00<0000K@[d004:m0016_@00A[d004KM001:g@00B]d004km001>o@00C_d0
05;m001C7@00Ead005LM00800003Fad0000000800004Fa`005ll0002Gc`01@00GcaO?000Gc`00P00
00ES?000001S?000009S>`03001S>`00009S>`03001S>`0000800005Ic/006LkIc/00002Ic/00`00
Ic/0000200001fLk001W>fLk001W>`00009W>`<00007Ia/006LJIaX006LJ00000VLJ0`0000UW6P00
IaYW6P00IaX006LJ00000VLJ00<006LJ00000VLJ00P006LJ001W6P00IaX006LJ0P0000IW6P00IaX0
06<J0002HaX00`00HaX0000200002F<J001S6V<J001RnP00H_X00002H_X3000016;j001RnP000V;j
0P000V;j00<006;j0000100000ARnP00H_X0009RnP05001RnP00H_X00002H_X2000015kj00000000
0UkJ0P000UkJ00T005kJ001NfP00G]X005kJ00000UkJ00<005kJ00000`0000YJfP00F]X005[J001J
fP00F[X0009J^P0:001J^P00F[X005Jj001F^P00E[X200005eJj001F^P00E[X005Jj001F^P00E[/0
05Jk001B^`00D[/005:k001B^`00D[/00P0001]B^`00D[/005:k001B^`00DY/005:K001BV`00D[/0
05:k001B^`00D[/005:k001B^`00D[/00P0001mB^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`0200009e:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005;K001Ff`020000
15KK001Ff`000UKK00`005KK001Ff`00E]/005KK001Ff`00E]/@00000eKK001oo`0IOol00`00Oomo
o`0AOol6000=Ool40009Ool007ioo`03001oogoo05ioo`04001Bg000D]`200001U;L001Bg5;L001B
g0800009D]`005;L001Bg000D]`005;L0080000;D]`005;L001Bg000D]`005;L001B_00200002e:l
001B_000D[`005:l001B_000D[`00P0000]>_000C[`004jl001>_000C[`004jl00800003C[`004jl
00800005B[`004Zl001:_002000024Zl000004JL0016W000AY`500000d:L0012W002000013il0000
03im0P0000LjO@00000003IM000bG@04000012hm000002HM100000<R7@0000000`0000<N?@007Sd0
0`0000<ZOP0000000`0000/jg`00@_l004LO001;7`00Cch005<n00@00004Fed005mM0002Hed01@00
HeaSG000Ie`00P0000EWG000Ie]WF`00009[F`04001[F`000002Je/01@00Je][F`00JeX00P000V]J
00D006]JJeX006]J0080009[>P04001[>V/j0002JcX00`00JcX00003JcX01P00JcY[>P00JcX000=[
>P04001[>P00JcX20002JcX01`00JcY[>P00JcX006/j0080009[6P07001[6V/J001[6P00JaX00P00
0V/J00L006LJIaX006LJ001W6P020002IaX00`00IaX00002IaX00`00IaYW6P020002IaX01`00IaYW
6P00IaX006LJ00800005IaX006LJIaX00002IaX01000IaT006LI0`000VKi00L006KiI_T006Ki001V
n@02000036Ki001VnFKi001Vn@00I_T006Ki001Vn@800007H_X006;jH_X006;j00000V;j00@006;j
001RnP<00007H_X006;JH]X006;J00000V;J00L005kJ000005kJ001NfP0400003UkJ001NfP00G]X0
05[J001JfP00F[X005Zj0002F[X01000F[X005Jj0P0000]F^P00E[X005Jj001B^P00DYX005:K0080
000=DY/005:K001>V`00CY/004jK001>V`00CY/00P0000=:V`00BW/00P0000=:N`00BW/00P0000=:
N`00AW/0100000I6N`000016N`00AW/200000d9k0012O00200000d9l0012O0040000249l0000049l
0012O000@W`300000cil0000000200000cil000nO00200000cil000nO00200000cil000000020000
0cYl000jO00200000cil000nO@0200003Cim00000000?Wd003im000nW@00?Yd003jM00<00003@[d0
000000@0000EA[d004KM001:g@00B]d004km001>o@00C_d005;m001C7@00Ead005LM00<00004Fad0
05/L0002Fa`00`00Gc`00002Gc`02@00Gc`005ll001S?000Hc`00002Hc`03000Hc]S>`00Hc/006<k
001S>`00Hc/0009W>`0:001W>fLk001W>`00Ic/006Lk0002Ic/01@00Ic]W>`00Ic/00`0000YW>`00
Ia]W6`00IaX006LJ001W6P800009IaX006LJIaX006LJ001W6P00009W6P<0009W6P05001W6P00IaX0
0002IaX3000016LJ001W6VLJ0P000V<J00L006<J001S6P00HaX00002HaX01@00HaX006;j00000V;j
0`0000ARnP00H_X0009RnP0=001RnP00H_X006;j001RnP00H_X006;j00000V;j00L006;j001RnP00
H_X00002H_X500003Ukj001NfP00G]X005kJ001NfP00G]X005kJ0002G]X00`00G]X0000400000e[J
00000002F]X20002F]X04000F]X005Zj001J^P00F[X005Zj001F^P00E[X005Jj0P0000AF^P00E[X0
009F^P0@001F^P00E[X005Jk001F^`00D[/005:k001B^`00D[/200006E:k001B^`00D[/005:k001B
^`00DY/005:K001BV`00D[/005:k001B^`00D[/005:k0080000TD[/00000D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0P0001QB^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0002D[/01P00D[/005:k001B
^`800009D]/005KK001Ff`00E]/005KK00l0000;E]/005KK001Ff`00E]/005KK001Ff`02000015KK
001Ff`006goo00<007ooOol0<7oo001oOol00`00Oomoo`1MOol04P00D]`005;L001Bg000D]`005;L
001Bg000D]`005;L001Bg0800009D]`005;L001Bg000D]`005;L0080000;D]`005;L001B_000D[`0
05:l001B_00200002e:l001B_000D[`004jl001>_000C[`00P0000E>_000C[`004jl00800009C[`0
04jl001>_000B[`004Zl00800003B[`004Zl00800003AY`004JL00800004AY`00000@Y`40000149l
000003im0P0000DjO@00>Wd003Im00@00003<Ud0000000800003:Sd0000000D000038Qd001hM00P0
0004:Wh00000<[h<000015Ln001G?P000U]M00<005mM00000V=M00H006=L000006=L0002Ie`01@00
Ie]WF`00Je/00P000V]K00D006]KJe/006]K00800003JeX006]J009[FP06001[FV]J001[>P000f/j
00@006/j001[>P80009[>P06001[>V/jJcX006/j0P0000E[>P00JcY[>P00009[>P03001[>P0000=[
>P04001[>P00JcX20002JaX00`00JaX00002JaX01000JaX000000V/J00<006/J00000VLJ00H006LJ
000006LJ0002IaX01`00IaYW6P00IaX006LJ00800004IaX006LJ0002IaX01P00IaX00000IaX0009W
6P07001W6VLJ001W6P00IaT00P0000AW6P00I_X0009Vn@03001Vn@00009Vn@03001VnP00009Vn@03
001Vn@00009Vn@03001Vn@0000800007H_X006;jH_X006;j00000V;j00T006;j001RnP00H_X006;j
00000V;j00<006;J00000V;J00H006;J001NfP00G]X3000015kJ001NfP000UkJ018005kJ001NfP00
F]X005[J001J^P00F[X005Zj001J^P00E[X20002E[X200003EJj001B^P00DYX005:K001BV`00DY/0
05:K00800007CY/004jK001>V`00CY/00P0000=:V`00BW/00P0000M:N`00BW/004Yk001:N`020000
0dIk0016N`0400001TIk0000049k0012N`800003@W`0049l00800003@W`0049l00800006@W`00000
@W`0049l0P0000HnO000000nO000?W`200001Cil000nO000?W`00P0000HnO000000nO000?W`50000
1Cil000nO@00?Wd00P0000<nO@0000000`0000LnW@00?Yd003jM000nW@0300001D:m0016_@00A[d0
5@0000=G7@0000000U/M00<005/L00000U/L00H005ll001O?000Gc`50002Hc`02@00HcaS?000Hc/0
06<k001S>`030002Hc/01`00Ic]W>`00Ic/006Lk00<0009W>`0:001W>fLk001W>`00Ic/006Lk0002
Ic/00`00Ia]W6`0200001FLJ000006LJ00000VLJ00D006LJ001W6P00009W6P<0009W6P05001W6P00
IaX00002IaX3000036LJ001W6VLJ001W6P00IaX006<J001S6P<0009S6P05001S6P00HaX00002H_X3
000016;j001RnP000V;j00P006;j001RnP00H_X006;j0`000V;j00T006;j001RnP00H_X006;j0000
0V;j0`0000QNnP00G_X005kj001NfP000UkJ0P0000INfP00G]YNfP00G]X500006UkJ001JfP00F]X0
05[J001JfP00F]X005[J001JfP00F[X005Zj001J^P00F[X005Jj0002E[X200001EJj001F^P00E[X0
<000029B^`00001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`80000ID[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/05000021Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`006Woo00<007ooOol0<7oo001oOol00`00Oomoo`1NOol01000D]`005;L
0P0000MBg000D]`005;L001Bg00a00001Djl001>_000C[`00P0000E:_000B[`004Zl00800003B[`0
04ZL00800005AY`004JL0016W00300000d:L0012W00500000cim000jO@0400000cIM000fG@030000
2Bhm00000000:Sd002Xm000R7@0500000ahM00000002000012IN000002Yn0P0000@b_P00000ng`80
0006Aah004lN001C?P000ULn00<005Ln00000U]M00@005mM001SG@800005He`006=LHe`00002Ie`0
1P00Ie/00000Ie/000=[F`06001[Ff]K001[F`000V]J00D006]JJeX006]J0080009[>P07001[>V/j
JcX006/j00000V/j00@006/jJcX000=[>P03001[>P00009[>P06001[>V/j001[>P000V/j00@006/j
JcX0009[>P03001[>P00009[6P04001[6V/J0002JaX00`00JaX00002JaX01000JaY[6P000VLJ00<0
06LJ00000VLJ00L006LJIaX006LJ001W6P020002IaX20002IaX01P00IaYW6P00IaX0009W6P03001W
6P00009W6P06001W6VLJ001W6P000VLJ0P000VKi00@006Ki001Vn@80009VnP03001Vn@00009Vn@07
001Vn@00I_T006;j00000V;j00<006;j00000V;j00H006;j001RnP00H_X30002H_X00`00H_X00002
H]X02`00H]X006;J001NfP00G]X005kJ00000UkJ01P005kJ001NfP00G]X005kJ001JfP00F]X005Zj
001J^P00F[X005Zj001F^P00E[XE00001DjK001>V`00CY/00P0000U:V`00BW/004Yk001:N`00BW/0
0P0000=:N`00AW/00P0000A6N`000016N`@00005@W/0049k0012O00200000d9l0012O00200000d9l
0012O0040000149l0000049l0P0000<nO000?W`00P0000<nO00000000P0000<nO000?W`00P0000<n
O000?W`00P0000<nO000?W`00`0000/nO@00?Wd003im000nO@00?Yd003jM00@00005?Yd003jM0012
W@0200000d:m0016_@02000054KM001:g@00B]d004[M001>o@00C_d005;m001Bo@00D_d005LM0002
Ead20002Fad02000Fa`005/L001O?000Gc`200001Ull001O?000Hc`0009S?004001S?000Hc/40000
16<k001S>`000V<k00@006Lk001W>`800004Ic/006Lk0002Ic/01000Ic/006Lk0`000VLk00<006Lk
00000VLK00D006LJ001W6`00009W6P05001W6P00IaX00002IaX300001fLJ001W6VLJ001W6P00009W
6P<0000<IaX006LJIaX006LJ001W6P00IaX006<J0P0000QS6P00HaX006<J001S6P000V<J0`0000AR
nP00H_X0009RnP05001RnP00H_X00002H_X3000036;j001RnP00H_X006;j001RnP00H_X0009RnP<0
0006G_X005kj001NnP000Ukj00@005kJ001NfP80009NfPD00008G]X005kJ001NfP00F]X0009JfP80
009JfP800006F]X005[J001J^P000UZj00H005Zj001J^P00E[X:00004eJj001F^P00E[X005Jk001F
^`00E[/005:k001B^`00D[/005:k0080000ID[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/0?`0000MB^`00D[/005:k001B^`0200003UKK001Ff`00E]/005KK001F
f`00E]/005KK0002E]/03000E]/005KK001Ff`00E]/005KK001Ff`80000<E]/005KK001Ff`00E]/0
05KK001Ff`006Woo00<007ooOol0<7oo0020Ool00`00Oomoo`1NOol<00001E;L001Bg000D]`00P00
00UBg000D]`005;L001Bg000D]`00P0000]Bg000D]`005;L001B_000D[`005:l0080000;D[`005:l
001B_000C[`004jl001>_00200001Djl001>_000C[`02`0000E:_000B[`004Zl00800003AY`004JL
00800003AY`004JL00800006@Y`00000@Y`003jM0`0000<jO@00>Wd00`0000@fG@00000bG@800005
;Sd00000000Z?@040000128M0000028m0P0000<N?@0000000P0000<ZOP0000000P0000@b_P00000n
g`800006Aah004lN001C?P000ULn00@005Ln001KG@@00005Ged006=LHe`00002He`01P00Ie`00000
Ie/0009WF`05001[Ff]K001[F`020002Je/01@00JeY[FP00JeX00P000V/j00@006/jJcX000=[>P80
00=[>P05001[>V/j001[>P020002JcX01@00JcY[>P00JcX00P0000E[>P00JcY[>P00009[>P03001[
>P00009[>P07001[6V/J001[6P00JaX00P000V/J00L006/JJaX006/J001W6P020002IaX00`00IaX0
0002IaX01P00IaX00000IaX0009W6P06001W6P00IaX006LJ0P000VLJ00<006LJ00000VLJ00@006LJ
001W6P80009W6P08001W6P00I_X006Ki001Vn@80009VnP03001VnP00009Vn@04001Vn@00I_T30002
H_X00`00H_X00002H_X01P00H_X006;j001RnP800006H_X006;j001RnP000V;j00H006;J001RfP00
H]X50002G]X01@00G]X005kJ00000UkJ00d005kJ000005[J001JfP00F[X005Zj001J^P0700002eJj
001F^P00E[X005Jj001B^P00DY/00P0000MBV`00DY/004jK001>V`0800000dZK001:N`0200001dYk
001:N`00BW/004Yk00800004AW/00000AW/200000dIk0016N`0400001D9l0012O000@W`00P0000=2
O000@W`00`0000=2O0000000100000HnO000000nO000?W`200000cil000nO004000023il000003il
000nO000?W`800000cim000nO@02000013jM000003jM1P0000M2W@00@[d004:m0016_@0200007DKM
001:g@00B]d004[M001>o@00C_d005;m001Bo@00D_d005LM001G7@00Ead005/M001K7000Fa`01000
00aO?000GcaO?000Gc`006<l001S?000Hc`2000016<k001S>`000V<k00H006<k001S>`00Ic/20000
2V<k001W>fLk001W>`00Ic/006Lk0P0000IW>`00Ic/006Lk0002Ic/00`00Ia]W6`020002Ia/00`00
IaX00002IaX00`00IaX0000200001fLJ001W6VLJ001W6P00009W6P<00009IaX006LJIaX006LJ001W
6P00009W6P<00004HaX006<JHaX20002HaX00`00HaX00002000016;j001RnP000V;j00D006;j001R
nP00009RnP<00006H_X006;j001RnP000V;j0P000V;j00<006;j00000P0000ARnP00G_X0009NnP0:
001NnP00G_X005kJ001NfP00G]X3000025kJ001NfP00G]X005kJ0002G]X02000F]X005[J001JfP00
F]X20002F]X01000F]X005Zj2@0000=F^P00E[X00P0001UF^P00E[X005Jj001F^P00E[X005Jk001F
^`00E[/005:k001B^`00D[/005:k001B^`0200006E:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k0080000OD[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P0002]B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005KK001Ff`00E]/005KK001F
f`0300006EKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0080
0004E]/005KK000JOol00`00Oomoo`0`Ool0081oo`03001oogoo05ioo`04001Bg000D]`200001U;L
001Bg000D]`0009Bg004001Bg000D]`200002E;L001Bg000D]`005;L001Bg00200002e;L001Bg000
D]`005:l001B_000D[`00P0000]B_000D[`005:l001>_000C[`004jl00800003C[`004jl00800005
C[`004jl001>_00200000dZl001:_00900001DJL0016W000AY`00P0000I2W0000012W000@Y`30000
0cim0000000300000cIm000fG@0300001C9M00000000:Sd00P0000<Z?@009Sd00P0000@R7@00000V
?@L00003;Yh003:N00@0000:?]l00000Aah004lN001C?P00Ech4000015/m001OG@000UmM00D006=L
He`006=L00800005Ie`006MKIe/00002Ie/01000Je/000000V]K00@006]KJe/0009[FP03001[FP00
00=[>P05001[>V/j001[>P0200000f/j001[>P02JcX01000JcX000000V/j00@006/jJcX0009[>P03
001[>P00009[>P05001[>V/j001[>P02000016/j001[>P000V/J00@006/J0000009[6P03001[6P00
009[6P04001[6P000002IaX00`00IaX00002IaX01P00IaYW6P00IaX0009W6P03001W6VLJ00800003
IaX00000009W6P03001W6P00009W6P04001W6P00IaX20002IaX00`00IaX00002IaX200001FKi0000
06Kj00000VKj00H006KjI_X006Ki0002I_T01`00I_X006;j001RnP00009RnP06001RnP00H_X006;j
0P0000IRnP00H_X006;j0002H_X01P00H_X006;J001RfP80000:G]X005kJ001NfP00G]X005kJ0002
G]X02000G]X005kJ001NfP00F]X700001EZj001J^P00E[X00P000UJj00H005Jj001F^P00E[X20000
2E:K001BV`00DY/005:K001>V`0200001DjK001>V`00CY/01`0000U:N`00BW/004Yk001:N`00AW/0
0P0000I6N`000016N`00AW/200000dIk0016N`0400000d9l0012O00200000d9l0012O00300000d9l
0012O00200001Cil000nO000?W`00P0000<nO000?W`00P0000<nO000?W`00`0000/nO000?W`003il
000nO000?Wd003im00@00003?Wd003im00800008?Yd00000?Yd004:M0012W@@0000=@[d004Jm0016
_@00A]d004[M001:g@00B]d00P0000m>o@00D_d005;m001Bo@00Ead005LM001G7@00Fad0100000AK
7000Ga`0009O?008001O?000Gc`006<l001S?080000<Hc`006<kHc/006<k001S>`00Hc/006<k0P00
00YS>`00Hc]S>`00Ic/006Lk001W>`800004Ic/006LkIc/20002Ic/01000Ic/006LK0P0000AW6`00
Ia/0009W6P07001W6P00IaX006LJ00000VLJ00<006LJ00000VLJ0`0000UW6P00IaYW6P00IaX006LJ
00000VLJ0`0000mS6P00HaYS6P00HaX006<J001S6P00HaX006;j00000V;j00L006;j001RnP00H_X0
0002H_X3000016;j001RnP000V;j00H006;j001RnP00H_X5000016;j001RnP000Ukj00X005kj001N
nP00G_X005kJ001NfP<00006G]X005kJ001NfP000UkJ00h005kJ001NfP00F]X005[J001JfP00F]X0
05[J1`0000mJ^P00F[X005Zj001F^P00E[X005Jj001F^P00E[X00P000UJj018005Jj001F^P00E[/0
05Jk001F^`00D[/005:k001B^`00D[/200006e:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`0200001E:k001B^`00D[/00P0001MB^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k00800006D[/005:k001B^`000U:k01@005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0P00031B^`00D[/005KK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/005KK000IOol00`00Oomoo`0`Ool0085oo`03001oogoo05ioo`04001Bg000D]`20000
4E;L001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`00P0000UBg000D]`005;L001Bg000D]`0
0P0000]B_000D[`005:l001B_000D[`005:l00800009C[`004jl001>_000C[`004jl00800007C[`0
04jl001>_000C[`00P0000Y:_000001:_000B[`004Zl001:_0D00003AY`004JL00800006@Y`00000
@Y`003jM0`0000<nO@00>Wd00P0000DfO@000000039M00800005<Ud00000000Z?@0400000bHm0000
0002000012Hm000002IM100000H^WP00000f_P00?]h:0002Ech20002Fcd00`00Ged00002Ged01P00
He`00000He`0009WG005001WFfMK001WF`020002Ie/01000Je][F`000V]K00<006]J00000V]J00H0
06/jJcY[>P00JcX20002JcX00`00JcX00003JcX00`00JcX00003JcX01000JcX006/j0P000V/j00<0
06/j00000f/j00<006/j00000V/j00<006/j00000V/J00<006/J00000V/J00@006/JJaX0009[6P03
001W6P00009W6P07001W6VLJ001W6P00IaX00P000VLJ00<006LJ00000VLJ00D006LJ001W6P00009W
6P07001W6VLJ001W6P00IaX00P0000EW6P00IaYW6P00009W6P07001W6P00I_X006Kj00000VKj00T0
06KjI_X006Kj001Vn@00I_T00P0000AVnP00H_X0009RnP06001RnP00H_X006;j0P0000ARnP00H_X0
009RnP08001RnP00H_X006;j001RfP800008H]X005kJ001NfP00G]X0009NfP0:001NfP00G]X005kJ
001NfP00G]X300001U[J001J^P00F[X0009J^P80000?E[X005Jj001F^P00E[X005Jj001F^P00D[X0
05:K00800009DY/005:K001>V`00CY/004jK00800008CY/00000CY/004ZK001:V`H00003BW/004Ik
00800003AW/004Ik00800005AW/004Ik0016N`0200000dIl0016O00200001T9l0000049l0012O080
0003@W`0049l00800003@W`0000000800003?W`003il00800005?W`003il000nO00200000cil0000
000300000cil000nO002000013im000003im1P0000<nW@00?Yd00P0000<nW@00@Yd00P0000=2_@00
@[d01P0000M6g@00B]d004[M001:g@0200002Dkm001Bo@00D_d005;m001G7@06000015/M001K7000
0U/L00X005lL001O?000Gc`005ll001S?080000<Hc`006<lHc`006<k001S>`00Hc/006<k0P0000YS
>`00Hc]S>`00Hc/006Lk001W>`80000<Ic/006LkIc/006Lk001W>`00Ic/006Lk0P000VLK0P000VLK
00@006LJ001W6P<0009W6P06001W6P00IaX006LJ0P0000UW6P00IaYW6P00IaX006LJ00000VLJ0`00
00aS6P00HaYS6P00HaX006<J001S6P00HaX30002H_X01`00H_X006;j001RnP00009RnP<00004H_X0
06;j0002H_X03`00H_X006;j001RnP00H_X006;j001RnP00H_X00002H_X01`00G_X005kj001NnP00
009NnP<00003G]X00000009NfP0=001NfP00G]X005kJ001NfP00G]X005[J00000U[J0P00019JfP00
000005[J001JfP00F[X005Zj001J^P00F[X005Jj0002E[X07@00E[X00000E[X005Jj001F^P00E[X0
05Jj001F^`00E[/005Jk001B^`00D[/005:k001B^`00D[/00P0001UB^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`0200007E:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P0002=B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0080000>E]/0
05KK001Ff`00E]/005KK001Ff`00E]/0009Ff`0<001Ff`00E]/005KK001Ff`00E]/005KK3P006Goo
00<007ooOol0<7oo0022Ool00`00Oomoo`1MOol02P00D]`005;L001Bg000D]`005;L0P000U;L00@0
05;L001Bg0800009D]`005;L001Bg000D]`005;L0080000;D]`005;L001Bg000D[`005:l001B_002
00002e:l001B_000D[`004jl001>_000C[`00P0000=>_000C[`00P0000U>_000C[`004jl001>_000
B[`00P0000E:_000B[`004Zl00<00003AY`004JL00L00003@Y`004:L00800004?Wd00000?Wd20000
0cYm0000000300001S9M0000039M000^G@800003:Sd00000008000059Sd00000000V?@0300001BYN
00000000;Yh00P0000df_P000012oP00A_h004/N001?7P00Dch00002Ech20002Fcd01000Ged005mM
0P000V=L00<006=L00000VML00@006MK0000009WF`04001WFfMK0002Je/01P00Je/00000Je/0009[
FP07001[>V/jJcX006/j00000f/j00@006/j001[>P80009[>P05001[>V/j001[>P020002JcX01`00
JcY[>P00JcX006/j0080009[>P06001[>P00JcX006/J0P000V/J00L006/JJaX006/J001[6P020002
IaX01`00IaYW6P00IaX006LJ0080009W6P03001W6P00009W6P03001W6VLJ0080009W6P07001W6VLJ
001W6P00IaX00P0000EW6P00IaYW6P00009W6P04001W6P00IaX30002I_X00`00I_X00002I_X01000
I_X006Ki0P000VKj00X006Kj001RnP00H_X006;j001RnP80000>H_X006;jH_X006;j001RnP00H_X0
06;j001RnP80000BH]X006;JH]X005kJ001NfP00G]X005kJ001NfP00G]X005kJ1@0000iJfP00F]YJ
fP00F[X005Zj001J^P00F[X005Jj0P0000AF^P00E[X0009F^P0;001F^P00001BV`00DY/005:K001B
V`0200001djK001>V`00CY/004jK00800003CY/004ZK00800005BY/004Yk001:N`04000024Ik0000
04Ik0016N`00AW/200000dIk0016N`0200000dIl0012O0040000149l0000049l0P0000=2O000@W`0
0P0000=2O000@W`0100000<nO000?W`00P0000<nO000?W`00`0000DnO000000003il00800004?W`0
0000?Wd200000cim000nW@0400001CjM000nW@00?Yd00P0000=2W@00@[d00P0000E6_@00A[d004Jm
01800006Ead005LM001G7@000U/M00X005/L001K7000Ga`005ll001O?0@0000<Gc`006<lHc`006<l
001S>`00Hc/006<k0P0000YS>`00Hc]S>`00Hc/006<k001W>`80000<Hc/006LkIc/006Lk001W>`00
Ic/006Lk0P0000YW6`00Ia]W6`00Ia/006LK001W6P800006IaX006LJ001W6P000VLJ00D006LJ001W
6P00009W6P05001W6P00IaX00002IaX300002F<J001S6V<J001S6P00HaX00002HaX300001V<J001S
6P00H_X0009RnP80009RnP<00004H_X006;j0002H_X02000H_X006;j001RnP00H_X30002H_X02@00
H_X006;j001RnP00G_X00002G_X00`00G_X00002000045kJ001NfP00G]X005kJ001NfP00G]X005kJ
001NfP000UkJ00<005[J0000100000UJfP00001JfP00F]X005Zj00000UZj00h005Zj001J^P00E[X0
05Jj001F^P00E[X005Jj0P0001EF^P00E[X005Jj001F^`00E[/005Jk001B^`00D[/005:k001B^`00
D[/00P0001UB^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`02
00007e:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k0080000[D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001Ff`00E]/005KK001Ff`00E]/00`0000=Ff`00E]/0400000aFf`00
E]/005KK001Ff`00E]/005KK000IOol00`00Oomoo`0`Ool0089oo`03001oogoo05ioo`04001Bg000
D]`200004E;L001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`00P0000UBg000D]`005;L001B
g000D]`00P0000]B_000D[`005:l001B_000D[`005:l0080000;C[`004jl001>_000C[`004jl001>
_00200001Djl001>_000C[`00P0000Y:_000001:_000B[`004Zl001:_0800008AY`00000AY`004JL
0016W0<00003@Y`003jM00800003?Wd003im00<00007>Wd003Im000bG@00<Ud0100000@^G@00000Z
?@@000049Sd000009Sd400001bin00000000<Yh003Jn0080000:@_h004Kn001;7P00Cah005<n0002
Ech200000e/m000000020002Ged01`00HeaSG000He`006ML0080009WF`04001WFfMK0002Ie/01P00
Je/00000Je/0009[F`05001[FV]J001[>P020002JcX01@00JcY[>P00JcX00P000V/j00@006/jJcX0
009[>P03001[>P00009[>P05001[>V/j001[>P020002JcX02000JcY[>P00JcX006/j0002JaX01`00
JaY[6P00JaX006/J0080009W6P03001W6P00009W6P06001W6P00001W6P000VLJ00L006LJIaX006LJ
001W6P02000016LJ001W6P000VLJ00H006LJIaX006LJ0002IaX00`00IaX00002IaX02P00IaYW6P00
I_X006Kj001VnP000VKj00@006Kj001VnP80000<I_X006KjI_X006Kj001RnP00H_X006;j0P0000iR
nP00H_YRnP00H_X006;j001RnP00H_X006;j0P00019RnP00H]YRfP00H]X005kJ001NfP00G]X005kJ
001NfP00G]X200007EkJ001NfP00F]X005[J001JfP00F[X005Zj001J^P00F[X005Jj001F^P00E[X0
05Jj001F^P00E[X00P0000eBV`00DY/005:K001BV`00CY/004jK001>V`02000034jK000004jK001:
V`00BY/004ZK001:N`800003BW/004Yk00D00007AW/004Ik0016N`00AW/00P0000=6O000AW`00P00
00=2O00000001@0000=2O000@W`00P0000=2O000@W`00P0000=2O000@W`00P0000PnO000000nO000
?W`003il0`0000<nO0000000100000HnO@00000nO@00?Wd200000cjM000nW@0400001cjM0012W@00
@Yd004:m00800003A[d004Jm00800007B]d004[M001:g@00C]d00P0000Q>o@00D_d005;m001Bo@00
0ULM00h005LM001G7@00Fad005/L001K7000Ga`005ll0P0000AO?000Gc`0009O?005001S?000Hc`0
0002Hc/300002V<k001S>f<k001S>`00Hc/006<k0P0000US>`00Hc]S>`00Ic/006Lk00000VLk0`00
00YW6`00Ia]W6`00Ia/006LK001W6`800004Ia/006LJIaX20002IaX01@00IaX006LJ00000VLJ00D0
06LJ001W6P00009W6P<00009HaX006<JHaX006<J001S6P00009S6P<00006HaX006<J001S6P000V;j
00@006;j001RnP<00004H_X006;j0002H_X01@00H_X006;j00000V;j0`0000aRnP00H_X006;j001R
nP00H_X006;j0002G_X5000015kJ001NfP000UkJ0P000UkJ0P0000INfP00G]YNfP00G]X500007E[J
001JfP00F]X005[J001JfP00F]X005Zj001J^P00F[X005Zj001F^P00E[X005Jj001F^P00E[X00P00
01AF^P00E[YF^P00E[X005Jk001F^`00E[/005:k001B^`00D[/005:k0P0001]B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P0000EB^`00D[/005:k0080
000GD[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0200001U:k001B
^`00D[/0009B^`0D001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`800003D[/0
00000140000=E]/005KK001Ff`00E]/005KK001Ff`00E]/00P0000eFf`00E]]Ff`00E]/005KK001F
f`00E]/0000HOol00`00Oomoo`0`Ool008=oo`03001oogoo05eoo`0:001Bg000D]`005;L001Bg000
D]`200001e;L001Bg000D]`005;L02/00009C[`004jl001>_000C[`004Zl00800005B[`004Zl001:
_00200000dZL0016W00200000dJL0016W00300000d:L00000002000013im000003im0P0000<jO@00
>Wd01P0000<bG@0000000P0000<^G@0000001@0000DZG@00000002IM00<00003<Yh0000000D0000;
@_h004Kn001;7P00Cah005<n001G?P030002Fcd00`00Ged00002Ged02000HeaSG000He`006=L0003
Ie/01@00Ie]WF`00Ie/00P0000EWF`00Je][F`00009[F`04001[FP000002JcX01000JcY[>P000V/j
00<006/j00000f/j00@006/j001[>P80009[>P04001[>V/j0002JcX00`00JcX00002JcX01@00JcY[
>P00JcX00`000V/J00D006/JJaX006/J00800005IaX006LJIaX00002IaX01P00IaYW6P00IaX0009W
6P07001W6VLJ001W6P00IaX00P000VLJ0P000VLJ00@006LJ001W6P80009W6P03001W6P00009W6P04
001W6P00IaX2000016Kj001VnP000VKj00@006Kj001VnP800005I_X006KjI_X00002I_X200000f;j
001RnP0200001f;j001RnV;j001RnP00009RnP80009RnP<00007H_X006;jH_X006;J00000V;J0P00
00ENfP00G]X005kJ00@0000<G]X005kJ001NfP00F]X005[J001JfP000UZj00@005Zj001J^P80000?
E[X005Jj001F^P00E[X005Jj001F^P00D[X005:K00800009DY/005:K001>V`00CY/004jK00800007
CY/004jK001>V`00BY/00P0000=:V`00BW/00P0000=:N`00BW/00P0000=6N`000000100000E6N`00
AW/004Ik00800003AW`0049l00<00003@W`0049l00@00003@W`0049l00800005@W`0049l0012O002
00000d9l00000002000013il000003il0P0000HnO000000nO000?W`400000cim000nO@0200000cjM
000nW@0200000cjM0012W@0400000d:M0012_@0200003DJm0016_@00A[d004[M001:g@00B]d004kM
00800008C_d005;m001Bo@00D_d0009G7@09001G7@00001K7@00Fa`005/L00@0000<Ga`005llGc`0
05ll001O?000Hc`006<l100000YS>`00Hc]S>`00Hc/006<k001S>`800009Hc/006<kHc/006<k001W
>`00009W>`<00007Ia/006LKIa/006LK00000VLK0`0000aW6`00Ia]W6`00IaX006LJ001W6P00IaX2
000016LJ001W6P000VLJ00<006LJ00000P0000US6P00HaYS6P00HaX006<J00000V<J0`0000AS6P00
HaX0009S6P0;001S6P00H_X006;j001RnP00H_X00002H_X01`00H_X006;j001RnP00009RnP<00006
H_X006;j001RnP000V;j0P0000ARnP00H_YRnP<00006G_X005kj001NfP000UkJ00H005kJ001NfP00
G]X20002G]X5000025kJ001JfP00F]X005[J0002F]X200003U[J001JfP00F[X005Zj001J^P00F[X0
05Jj0002E[X02@00E[X00000E[X005Jj001F^P0i00005E:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`0200001e:k001B^`00D[/005:k01X0000DE]/005KK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`00E]/0009Ff`0H001Ff`00001Ff`00E]/005KK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`0067oo00<007ooOol0<7oo0023Ool00`00Oomoo`1NOolB00001E;L001Bg000
D]`00P0000UBg000D]`005;L001Bg000D]`00P0000]B_000D[`005:l001B_000D[`005:l0080000;
C[`004jl001>_000C[`004jl001>_00<00001dZl001:_000B[`004Zl00800008AY`00000AY`004JL
0016W0<00003@Y`004:M00@00004?Wd00000>Wd200001CIm000fG@00=Ud00`0000T^G@00000002iM
000ZG@009Sd00`0000DZG@00000002YN00800004<Yh00000=[h200000ckN00000009000015Ln001K
?@000U/m00<005mM00000UmM00P006=L000006=L001SG0000fMK00H006MK000006MK0002Ie/01@00
Je][F`00Je/00P0000=[>`00JcX00V/j00@006/j001[>P80009[>P05001[>V/j001[>P020002JcX0
1`00JcY[>P00JcX006/j0080009[>P04001[>V/j0002JcX01@00JcX006/J00000V/J00H006/JJaX0
06LJ0002IaX01`00IaYW6P00IaX006LJ0080009W6P03001W6P00009W6P06001W6P00001W6P000VLJ
00H006LJ001W6P00IaX20002IaX00`00IaX00002IaX01000IaX006LJ0P000VLJ00P006Kj001VnP00
I_X006Kj0P0000MVnP00I_YVnP00I_X00002I_X00`00I_X0000200001f;j001RnV;j001RnP00009R
nP04001RnP00H_X300001f;j001RnV;j001RnP00009RfP06001RfP00G]X005kJ0`0000ANfP00G]X0
009NfP04001NfP00G]X20002F]X03000F]X005Zj001J^P00F[X005Zj001F^P800005E[X005Jj001F
^P0>00001djK001>V`00CY/004jK00800009CY/004ZK001:V`00BY/004Yk00800003BW/004Yk00<0
0005AW/004Ik0016N`04000024Ik000004Il0012O000@W`200001T9l0000049l0012O0800005@W`0
049l0012O00200000d9l0012O00200000d9l0000000500001Sil000003il000nO0800003?W`003il
00800005?Wd003im000nW@0200000cjM000nW@0200000d:M0012W@0500007DJm0016_@00A[d004[M
001:g@00B]d004kM001>o@00C_d005;m001Bo@00D_d005LM001G7@00Ead01@0000AK7000Ga`0009O
7008001O?000Gc`005ll001S?0800004Hc`006<k0002Hc/01P00Hc/006<k001S>`800009Hc/006<k
Hc/006<k001S>`00009W>`<0000:Ic/006LKIa/006LK001W6`00Ia/2000036LK001W6fLK001W6`00
IaX006LJ001W6P800004IaX006LJ0002IaX01`00IaX006LJ001S6P00009S6P05001S6P00HaX00002
HaX3000016<J001S6P000V<J00P006<J001S6P00H_X006;j0`000V;j00L006;j001RnP00H_X00002
H_X3000016;j001RnP000V;j00P006;j001RnP00H_X006;j0`0000ANnP00G_X0009NnP0<001NfP00
G]X005kJ001NfP00G]X005kJ0`0000QNfP00G]X005kJ001JfP000U[J00H005[J001JfP00F]X20000
1U[J001J^P00F[X0009J^P04001J^P00E[X<00004eJj001F^`00E[/005Jk001F^`00E[/005:k001B
^`00D[/005:k0080000ID[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/00P0000MB^`00D[/005:k001B^`0P00005E:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`02000025Jk001Ff`00E]/005KK0002E]/01000E]/005KK0`0000UFf`00E]/0
05KK001Ff`00E]/00P0001AFf`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`0067oo
00<007ooOol0<7oo0024Ool00`00Oomoo`1MOol02P00D]`005;L001Bg000D]`005;L0P0000IBg000
D]`005;L0002D]`01000D]`005;L0P0000UBg000D]`005;L001Bg000D]`00P0000]B_000D[`005:l
001B_000D[`005:l00800009C[`004jl001>_000C[`004jl00<00009C[`004jl001>_000C[`004Zl
00T00003BY`004JL00800003AY`004JL00800004@Y`00000@Y`200000cjM000nO@0300000cYm000j
O@03000013IM0000039M0P0000D^G@00000002iM00@000069Sd00000:Ud002in100000@bWP00000f
_P<0000:@_h004Kn001;7P00Cah005<n0002Ech00`00Fcd00002Fcd01000Ged005mM0P0000MSG000
HeaSG000He`00003Ie/00`00Ie/00002Ie/01000Ie]WF`000V]K00<006/k00000V/k00D006/jJcX0
06/j0080009[>P04001[>V/j0002JcX00`00JcX00002JcX01@00JcY[>P00JcX00P000V/j00L006/j
JcX006/j001[>P020002JcX01P00JaX006/J001[6P80009W6P07001W6VLJ001W6P00IaX00P000VLJ
00<006LJ00000VLJ00H006LJIaX006LJ0002IaX00`00IaYW6P0200001FLJ000006LJ00000VLJ00L0
06LJIaX006LJ001W6P0200002VLJ001W6VLJ001VnP00I_X006Kj0P0000MVnP00I_YVnP00I_X00002
I_X01`00I_X006Kj001RnP00009RnP03001RnP00009RnP09001RnP00H_X006;j001RnP00009RnP03
001RnP00009RnP06001RfP00H]X005kJ0`0001YNfP00G]YNfP00G]X005kJ001NfP00G]X005[J001J
fP00F]X005Zj001J^P00F[X005Zj2@0000=F^P00E[X00P0000UB^`00DY/005:K001BV`00DY/02@00
00U>V`00BY/004ZK001:V`00BW/00P0000=:N`00BW/00P0000E6N`00AW/004Ik00800003AW/004Ik
00@00004AW`00000@W`200001D9l0012O000@W`00P0000=2O00000000P0000=2O000@W`00P0000U2
O000@W`0049l0012O000@W`0100000<nO000?W`00P0000<nO000?W`00P0000<nO@0000000P0000Dn
W@00?Yd003jM00800003@Yd004:M00800003@[d004:m00T0000?B]d004[M001>g@00C_d004km001B
o@00D_d005;m00L00004Fad005/L0002Fa`00`00Ga`00002Ga`200000ell001O?002000035ll001S
?6<l001S>`00Hc/006<k001S>`800009Hc/006<kHc/006<k001S>`00009S>`<0000:Hc/006LkIc/0
06LK001W6`00Ia/200002FLK001W6fLK001W6`00Ia/00002IaX300002VLJ001W6VLJ001W6P00IaX0
06LJ0`000V<J00D006<J001S6P00009S6P<00004HaX006<J0002HaX02000HaX006<J001S6P00H_X2
00002V;j001RnP00H_X006;j001RnP000V;j0`0000ARnP00H_X0009RnP08001RnP00H_X006;j001R
nP<00004G_X005kj0002G_X01`00G_X005kJ001NfP00009NfP80000:G]X00000001NfP00G]X005kJ
0002G]X02P00F]X005[J001JfP00F]X005[J0P000U[J00@005Zj001J^PL00007E[X005Jj001F^P00
E[X00P0001EF^P00E[X005Jk001F^`00E[/005Jk001F^`00D[/005:k001B^`00D[/00P0001UB^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0200007E:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P0001AB^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`000U:k00@005:k001B^`80000AD[/005Jk
001F^`00E]/005KK001Ff`00E]/005KK001Ff`0300004EKK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/00P0000eFf`00E]]Ff`00E]/005KK001Ff`00E]/0000GOol00`00Oomoo`0`Ool008Eo
o`03001oogoo05eoo`0:001Bg000D]`005;L001Bg000D]`200004E;L001Bg000D]`005;L001Bg000
D]`005;L001Bg000D]`00P0000UBg000D]`005;L001B_000D[`00P0000]B_000D[`005:l001B_000
C[`004jl00800005C[`004jl001>_00200004Djl001>_000C[`004jl001:_000B[`004Zl001:_000
B[`01@0000E6W000AY`004JL00800006@Y`00000@Yd003jM0P0000<nO@0000000`0000@fO@00000f
G@<00005<Ud00000000^G@0200000bYM000^G@0200001BYM000ZG@00;Wh00P0000<bWP0000000P00
00hf_P00000004;n0016oP00Bah004lN001C?P000ULn00@005/m001K?@@00005Gcd006=LHe`00002
He`01000He`006MK0P000VMK00L006MKIe/006MK001[F`020002Jc/01@00Jc][>`00JcX00P0000=[
>P00JcX00V/j00@006/j001[>P80009[>P04001[>V/j0002JcX00`00JcX00002JcX01@00JcY[>P00
JcX00P000V/j00<006/j00000V/J00<006/J00000VLJ00<006LJ00000VLJ00H006LJ000006LJ0002
IaX01`00IaYW6P00IaX006LJ0080009W6P03001W6P00009W6P05001W6P00IaX00002IaX01`00IaYW
6P00IaX006LJ00800005IaX006LJIaX00002IaX20002I_X00`00I_X00002I_X00`00I_X00002I_X0
1000I_X006Kj0`000V;j00<006;j00000V;j00H006;j001RnP00H_X30002H_X00`00H_X00002H_X0
1P00H_X006;J001RfP<00009G]X005kJG]X005kJ001NfP00009NfP800009G]X005[J001JfP00F]X0
05Zj00L0000EE[X005Jj001F^P00E[X005Jj001F^P00D[X005:k001BV`00DY/005:K00800003CY/0
04jK00800003CY/004jK00H00003BY/004Yk00800005BW/004Yk001:N`0200001DIk0016N`00AW/0
0P0000=6N`00AW/01`0000=2O000@W`00P0000=2O000@W`00P0000=2O000@W`0100000I2O0000012
O000@W`20000149l000003il100000DnO000?W`003il00800006?W`00000?Yd003jM100001@nW@00
0012W@00@Yd004:M0012_@00@[d004Jm0016_@00B]d004[M3`0000aBo@00Ead005LM001G7@00Fad0
05/L0002Fa`01P00Ga`005lL001O?0<00005Gc`005llGc`00002Hc`01@00Hc/00000Hc/00P0000US
>`00Hc]S>`00Hc/006<k00000V<k0`0000YS>`00Hc]S>`00Ic/006LK001W6`800009Ha/006LKIa/0
06LK001W6`00009W6`<0000:HaX006LJIaX006LJ001W6P00IaX2000026<J001S6P00HaX006<J0002
HaX3000016<J001S6P000V<J00D006<J001S6P00009S6P<00004H_X006;jH_X20002H_X01000H_X0
06;j0`0000iRnP00H_YRnP00H_X006;j001RnP00H_X006;j0`0000ANnP00G_X0009NnP07001NnP00
G_X005kJ00000UkJ1@0000ENfP00001NfP00009NfP0;001NfP00G]X005[J001JfP00F]X00002F]X2
00000e[J0000000500003eZj001J^P00E[X005Jj001F^P00E[X005Jj001F^P020002E[X04P00E[/0
05Jk001F^`00E[/005Jk001B^`00D[/005:k001B^`80000ID[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/00P0001]B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/00P0001]B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/00P0001YB^`00E[/005Jk001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK001Ff`000UKK00d005KK000005KK001Ff`00E]/005KK001Ff`0;000G
Ool00`00Oomoo`0`Ool008Eoo`03001oogoo05ioo`04001Bg000D]`200002E;L001Bg000D]`005;L
001Bg0020002D]`01000D]`005;L0P0000UBg000D]`005;L001Bg000D]`00P0000]B_000D[`005:l
001B_000D[`005:l00800009C[`004jl001>_000C[`004jl00800003C[`004jl00800005C[`004jl
001:_00200001DZl001:_000B[`00P0000=:_000AY`01`0000I2W0000012W000@Yd200001cim000n
O@00>Wd003Ym00800005=Wd00000000bG@0200001c9M00000000;Ud002YM00800003;Ud0000000<0
0007;Wh00000000fWP00=[h01@0000]2oP00A_h004/N001?7P00Dch005Ln00@00004Fcd005lm0002
Gcd01@00HeaSG000He`010000VML00L006MKIe/006MK001WF`020002Ic/01000Jc][>`000V/k00<0
06/j00000V/j00D006/jJcX006/j0080009[>P07001[>V/j001[>P00JcX00P000V/j00@006/jJcX0
009[>P03001[>P00009[>P04001[>V/j0002JaX20002IaX01000IaYW6P000VLJ00<006LJ00000VLJ
00L006LJIaX006LJ001W6P020002IaX00`00IaX00002IaX00`00IaYW6P020002IaX00`00IaX00002
IaX01P00IaYW6P00IaX0009W6P03001W6P00009W6P03001VnP000080009VnP03001VnP00009VnP04
001VnP00I_X200001V;j001RnP00H_X0009RnP06001RnP00H_X006;j0P0000IRnP00H_X006;j0002
H_X01P00H_X006;j001RfP800008G]X005kJ001NfP00G]X0009NfP04001NfP00G]X20002G]X20000
0e[J0000000200004eZj001J^P00F[X005Zj001F^P00E[X005Jj001F^P00E[X005Jj00800009D[/0
05:K001BV`00DY/005:K00800005CY/004jK001>V`0200001DjK001>V`00BY/01P0000=:N`00BW/0
0P0000E6N`00AW/004Ik00800003AW/004Ik00<00003AW`004Il00@00005@W`0049l0012O0020000
0d9l0012O00200000d9l0012O00500001T9l0000049l0012O0800003?W`003il00@00005?W`003il
000nO00200001SjM000004:M0012W@D00007@Yd004:M0012_@00@[d00P0000E6_@00A[d004[M0080
000>B]d004kM001>g@00C_d004km001Bo@00D_d0009Bo@0>001G7@00Ead005LM001K7@00Fa`005/L
001O70D00005Ga`005llGc`00002Gc`02@00Hc`006<k001S>`00Hc/00002Hc/00`00Hc]S>`020002
Hc/300002V<k001S>f<k001S>`00Ic/006LK0P0000US6`00Ha]S6`00Ia/006LK00000VLK0`0000YS
6`00HaYS6P00IaX006LJ001W6P800004HaX006<JHaX20002HaX00`00HaX00002000016<J001S6P00
0V<J00D006<J001S6P00009S6P<0000<H_X006;jH_X006;j001RnP00H_X006;j0`0000]RnP00H_YR
nP00H_X006;j001RnP00009RnP<0000<H_X006;j001NnP00G_X005kj001NnP000Ukj00<005kJ0000
0P00019NfP00G]X005kJ001NfP00G]X005kJ001NfP00G]X005[J0002F]X00`00F]X00005000035[J
001J^P00F[X005Zj001J^P00E[X0009F^P06001F^P00E[X005Jj0P0001EF^P00E[X005Jk001F^`00
E[/005Jk001F^`00D[/005:k001B^`00D[/00P0001UB^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`0200006e:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`0200007e:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k00800008E[/005KK001Ff`00E]/0009Ff`04001F
f`00E]/300001EKK001Ff`00E]/0400000YFf`00E]/005KK001Ff`00E]/001Moo`03001oogoo031o
o`00QWoo00<007ooOol0GGoo00X005;L001Bg000D]`005;L001Bg080000AD]`005;L001Bg000D]`0
05;L001Bg000D]`005;L001Bg00200002E;L001Bg000D]`005:l001B_00200002e:l001B_000D[`0
05:l001>_000C[`00P0000E>_000C[`004jl00800009C[`004jl001>_000C[`004Zl00800003B[`0
04Zl0080000;B[`004Zl0016W000AY`004JL0016W00500001D:M000nW@00?Wd00`0000@jO@00000j
O@D00006<Ud00000<Ud0039M0P0000<ZG@0000000P0000<^G@00;Wd00P0000D^OP00000003JN0080
0003>[h003kN00`00004Ecd005/m0002Fcd00`00Gcd00002Gcd02000He`00000He`006=L0003Ie`0
1000Ie/006MK0P0000=W>`00Ic/00VLk00@006/k001[>`80009[>P04001[>V/j0002JcX00`00JcX0
0003JcX01000JcX006/j0P000V/j00L006/jJcX006/j001[>P020002JcX01`00JcY[>P00JcX006/J
00800008IaX006LJIaX006LJ001W6P80009W6P03001W6P00009W6P06001W6P00001W6P000VLJ00L0
06LJIaX006LJ001W6P02000016LJ001W6P000VLJ00@006LJ001W6P80009W6P03001W6P00009W6P05
001W6P00I_X00002I_X00`00I_X00002I_X01000I_X006Kj0P0000IRnP00H_X006;j0002H_X01P00
H_X006;j001RnP800004H_X006;jH_X20002H_X01P00H_X006;j001RnP800008H]X005kJ001NfP00
G]X0009NfP08001NfP00G]X005kJ001NfPD0000MF]X005[J001J^P00F[X005Zj001J^P00E[X005Jj
001F^P00E[X005Jj001F^P00D[X005:k001BV`0200001e:K001BV`00CY/004jK00800007CY/004jK
001>V`00CY/00P0000=:V`00BY/01`0000M6N`00AW/004Ik0016N`0200000dIk0016N`02000014Il
000004Il100000E2O000@W`0049l00800005@W`0049l0012O00300001D9l00000000@W`00P0000I2
O000000nO000?W`200000cil0012O004000023il000003jM000nW@00@Yd200000d:M000000050000
2d:m0012_@00A[d004Jm0016_@00B]d00P0001]:g@00C]d004kM001>o@00C_d005;m001Bo@00D_d0
05LM001G7@00Ead005/M001K7000Fa`00P0000QK7000Ga`005lL001O70000Ull00@005ll001S?0D0
009S>`07001S>f<k001S>`00Hc/00`0000ES>`00Hc]S>`00009S>`800005Ic/00000Ha/00002Ha/0
1@00Ha/006LK00000VLK0`0000YS6`00Ha]S6`00HaX006LJ001W6P80000?HaX006<JHaX006<J001S
6P00HaX006<J001S6P00009S6P07001S6P00HaX006<J00000V<J0`0000aRnP00H_YRnP00H_X006;j
001RnP00H_X300002f;j001RnV;j001RnP00H_X006;j00000V;j0`0000aRnP00H_X006;j001NnP00
G_X005kj0002G_X500001UkJ001NfP00G]X0009NfP800006G]X005kJ001NfP000UkJ00<005[J0000
100000=JfP00F]X00P000U[J0P00019J^P00F[YJ^P00F[X005Jj001F^P00E[X005Jj001F^P00E[X2
00004eJj001F^`00E[/005Jk001F^`00E[/005:k001B^`00D[/005:k0080000ID[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P0001eB^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0080000DD[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/0009B^`04001B^`00D[/200002e:k001F^`00E[/005KK
001Ff`00E]/03`0000=Ff`00E]/00P0000aFf`00E]/005KK001Ff`00E]/005KK0002E]/01`00E]/0
05KK001Ff`0001Moo`03001oogoo02moo`00QWoo00<007ooOol0GWoo00@005;L001Bg0800009D]`0
05;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`0800000M>_000C[`004jl001>_0020000
1Djl001>_000B[`00P0000E:_000B[`004Zl00800003B[`004JL00800003AY`004JL00800003AY`0
04:L00D00003?Wd003im0080000;>Wd00000000jO@00=Wd0039M000bG@0400000biM000000040000
12iM000002in1@0000@fWP00000j_P800007@]h004Kn001:oP00Cah00P0000MC7P00EceG?@00Fcd0
0002Fcd01000Gcd005lm0P0000MS?000HeaSG000He`00002Ie`01P00Ie/00000Ic/0009W>`05001W
>fLk001[>`020002Ic/01`00JcY[>P00JcX006/j0080009[>P05001[>V/j001[>P0200001F/j001[
>V/j00000V/j00@006/j0000009[>P07001[>V/j001[>P00JcX00P000VLJ00H006LJ001W6P00IaX2
0002IaX00`00IaX00002IaX01P00IaYW6P00IaX0009W6P07001W6VLJ001W6P00IaX00P000VLJ0P00
0VLJ00@006LJ001W6P80009W6P03001W6P00009W6P04001W6P00IaX30002I_X01P00I_YVnP00I_X0
009VnP03001VnP00009RnP0:001RnP00H_X006;j001RnP00H_X200003V;j001RnV;j001RnP00H_X0
06;j001RnP00H_X2000016;J001RfP000UkJ0P000UkJ00P005kJ001NfP00G]X005kJ0`0000ANfP00
F]X0009JfP08001JfP00F[X005Zj001J^P80009F^P06001F^P00E[X005Jj0P0000eF^P00D[X005:k
001BV`00DY/005:K001BV`0200001DjK001>V`00CY/00P0000E>V`00CY/004ZK00800008BY/00000
BY/004Yk001:N`@00003AW/004Ik00800003AW/004Ik00800003AW`004Il00800003AW`004Il00@0
0003@W`0049l00800005@W`0049l0012O00300000d9l0000000200001D9l0012O000?W`00P0000<n
O000?W`00P0000=2O000@Y`00`0000lnW@00?Yd004:M0012W@00@Yd004:M0012W@00@[d01P0000e6
_@00A[d004[M001:g@00B]d004kM001>g@0200003Dkm001Bo@00D_d005;m001G7@00Ead005LM00H0
000>Fa`005/LFa`005lL001O7000Ga`005ll001O?0800006Hc`006<l001S>`000V<k00@006<k001S
>`<00005Hc/006<kHc/00002Hc/01`00Hc/006<k001S6`00009S6`05001S6`00Ha/00002Ia/30000
2V<K001S6f<K001S6`00HaX006LJ0P0000aS6P00HaYS6P00HaX006<J001S6P00HaX30002HaX01`00
HaX006<J001S6P00009S6P<00009HaX006;jH_X006;j001RnP00009RnP<0000:H_X006;j001RnP00
H_X006;j0002H_X00`00H_X00002000016;j001RnP000V;j00@006;j001NnP80009NnP<00006G]X0
05kJ001NfP000UkJ00H005kJ001NfP00G]X20002G]X00`00G]X0000400007e[J001JfP00F]X005[J
001JfP00F]X005Zj001J^P00F[X005Zj001F^P00E[X005Jj001F^P00E[X005Jj0080009F^P0B001F
^`00E[/005Jk001F^`00E[/005:k001B^`00D[/005:k0P0001UB^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`0200006e:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`0200005E:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`0D0000:5KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`005goo00<007ooOol0;goo0027
Ool00`00Oomoo`1NOolG00001E;L001Bg000D]`00P0000UBg000D]`005;L001Bg000D[`00P0000]B
_000D[`005:l001B_000C[`004jl00800003C[`0000000d00005B[`004Zl001:_00200001DZl001:
_000AY`00P0000I6W0000016W000AY`300000d:M0012W@0500001SYm000003Ym000jO@H00003<Ud0
000000800003;Ud002iM00<00007;Ud00000000bOP00<Yh00`0000<f_P00>[h00P0000M2gP00A_h0
04[n001?7P02000025<N001G?ELm001K?@00Fcd400001Ell001S?6<l00000V=L00@006=L001WG080
0005Ic/006LkIc/00002Ic/01P00Ic/00000Ic/000=W>`04001[>P00JcX20002JcX01000JcY[>P00
0V/j00<006/j00000V/j00@006/jJcX0009[>P03001[>P00009[>P05001[>V/j001[>P0200001FLJ
001W6VLJ00000VLJ00D006LJ001W6P00009W6P07001W6VLJ001W6P00IaX00P000VLJ00<006LJ0000
0VLJ00H006LJ000006LJ0002IaX01P00IaX006LJ001W6P800005IaX006LJIaX00002IaX01000IaX0
06LJ0P0000AVnP00I_X0009VnP06001VnP00I_X006Kj0P000VKj00X006;j001RnP00H_X006;j001R
nP80000>H_X006;jH_X006;j001RnP00H_X006;j001RnP80000@H_X006;JH]X006;J001NfP00G]X0
05kJ001NfP00G]X400000ekJ00000002G]X05P00F]X005[J001JfP00F[X005Zj001J^P00F[X005Jj
001F^P00E[X005Jj0P0000eF^P00D[X005:k001BV`00DY/005:K001BV`0200002djK001>V`00CY/0
04jK001>V`00CY/00P0000=:V`00BY/00P0000=:V`00BW/00P0000=:N`00BW/0100000=6N`00AW/0
0P0000=6O000AW`00P0000=6O000AW`00P0000=6O000@W`0100000I2O0000012O000@W`200001T9l
0000049l0012O0@00005?W`003il000nO00200000d9l0012O00200000d:L0000000300001D:M0012
W@00@Yd00P0000=2W@00@Yd00P0000=6_@00A[d02P0000E:g@00C]d004kM00800005C_d005;m001B
o@0800001ULM001K7000Fa`0009K700:001K7000Ga`005lL001O7000Gc`2000035lL001S?6<l001S
?000Hc/006<k001S>`800003Hc/00000009S>`07001S>f<k001S>`00Hc/00`000V<K00D006<K001S
6`00009S6`<0000:Ha/006<KHa/006<K001S6`00HaX200002F<K001S6V<J001S6P00HaX00002HaX3
00001V<J001S6P00HaX0009S6P80009S6P<00009HaX006<JHaX006;j001RnP00009RnP<0000:H_X0
06;j001RnP00H_X006;j0002H_X5000016;j001RnP000V;j00P006;j001RnP00G_X005kj0`0000IN
nP00G]X005kJ0002G]X02P00G]X005kJ001NfP00G]X005kJ1@0000QJfP00F]X005[J001JfP000U[J
00@005[J0000009JfP80000:F[X005Zj001J^P00E[X005Jj0002E[X01000E[X005Jj0P0000=F^P00
0000HP0000EB^`00D[/005:k0080000@E[/005Jk001Ff`00E]/005KK001Ff`00E]/005KK0002E]/3
00000eKK001Ff`0200006UKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/005KK000GOol00`00Oomoo`0_Ool008Qoo`03001oogoo05eoo`04001Bg000D]`200002E;L001B
g000D]`005;L001Bg00200001U;L001Bg000D]`0009Bg004001Bg000D]`200002E;L001Bg000D]`0
05;L001B_00200002e:l001B_000D[`005:l001>_000C[`00`0000M>_000C[`004jl001>_0020000
1Djl001>_000C[`02@0000=:_000AY`00P0000=6W000AY`00P0000=6W000@Y`00P0000I2W@00000n
W@00?Yd2000013Ym000003Ym0P0000DfO@00=Wd003Im00800005<Ud00000000^G@0200001BiM0000
0000;Wd00P0000DbOP00000003Zn00@00009?]h004;N0016oP00B_h004lN00800003Dah005Lm00@0
0004Fcd005lm0002Gc`01`00HcaS?000He`006=L00800005Hc`006LkIc/00002Ic/01P00Ic/00000
Ic/0009W>`05001W>fLk001[>P0200000f/j001[>P02JcX01000JcX006/j0P000V/j00L006/jJcX0
06/j001[>P020002JcX01000JcY[>P000V/j00<006Lj00000VLJ00@006LJIaX0009W6P80009W6P07
001W6VLJ001W6P00IaX00P000VLJ00<006LJ00000VLJ00H006LJIaX006LJ0002IaX00`00IaYW6P02
00001FLJ000006LJ00000VLJ00L006LJIaX006LJ001W6P02000016LJ001VnVKj0P000VKj00@006Kj
001VnP80009VnP03001VnP00009RnP800003H_X006;j00800007H_X006;jH_X006;j00000V;j00<0
06;j00001000011RnP00H_YRnP00H]X006;J001NfP00G]X005kJ001NfP80000<G]X005kJ001NfP00
G]X005kJ001JfP000U[J01D005[J000005Zj001J^P00F[X005Jj001F^P00E[X005Jj001F^P00E[X0
200000MBV`00DY/004jK001>V`0200001djK001>V`00CY/004jK00800003BY/004ZK00800007BY/0
04Yk001:N`00BW/00P0000=6N`00AW/01`0000=6O000AW`00P0000E6O000AW`004Il00800003@W`0
049l00@00004@W`00000@W`200000d9l0012O00200000d9l0012O004000033il0000049l0012O000
@Y`004:L0012W@H00005@Yd004:M0012W@0200000d:m0016_@0200002DJm0016_@00B[d004[M001:
g@0<000025;m001Fo@00E_d005LM0002Ead03000Fa`005/L001K7000Fa`005lL001O70@0000<Ga`0
05lLGa`006<l001S?000Hc/006<k0P0000AS>`00Hc]S>`80009S>`04001S>`00Hc/200001V<K001S
6`00Ha/0009S6`03001S6`000080000:Ha/006<KHa/006<K001S6`00Ha/200002F<K001S6f<K001S
6P00HaX00002HaX3000016<J001S6V<J0P000V<J00@006<J001S6P<00009HaX006<JHaX006<J001R
nP00009RnP<00004H_X006;j0002H_X01P00H_X006;j001RnP<00004H_X006;j0002H_X02P00H_X0
06;j001RnP00H_X005kj0`0000ANnP00G_X0009NfP09001NfP00G]X005kJ001NfP00009NfP80000:
G]X005kJ001NfP00F]X005[J0002F]X02P00F]X005[J001JfP00F]X005[J0P0000YJ^P00F[YJ^P00
F[X005Jj001F^PX0000CE[X005Jk001F^`00E[/005Jk001F^`00E[/005:k001B^`00D[/00P0001UB
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0200006e:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`020000;e:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00E[/005Jk001F
^`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00`0000=Ff`00E]/00P000UKK010005KK000005KK
001Ff`00E]/005KK001Ff`00E]/0009Ff`07001Ff`00E]/005KK00005Woo00<007ooOol0;goo0028
Ool00`00Oomoo`1NOol01000D]`005;L0P0000UBg000D]`005;L001Bg000D]`00P0000mBg000D]`0
05;L001Bg000D]`005;L001Bg000D]`00P0000]Bg000D]`005:l001B_000D[`005:l00800005D[`0
04jl001>_00200002Djl001>_000C[`004jl001>_00200000djl001>_00200001DZl001:_000B[`0
0P0000=:_0000000100000Q6W0000016W000AY`004:L0P0000A2W@00000nW@80000;?Wd00000000j
O@00>Wd003Im000fO@0200000cIm0000000300001BiM00000000<Wd00`0000<^OP00<Wh00`0000@j
_P00000ngPh00004Ecd005/m0002Fcd00`00Gcd00002Gc`01000Hc`006=L0P0000ES?000HcaS?000
009W>`06001W>`00001W>`000VLk00D006LkIc/006Lk00800005Ic/006/jJcX00002JcX01000JcX0
00000V/j00L006/jJcX006/j001[>P020002JcX01`00JcY[>P00JcX006/j0080009W>P07001W6VLJ
001W6P00IaX00P0000AW6P00IaX0009W6P06001W6P00001W6P000VLJ00L006LJIaX006LJ001W6P02
0002IaX00`00IaX00002IaX01@00IaX006LJ00000VLJ00<006LJ00000VLJ00H006LJIaX006LJ0002
IaX02000I_X006Kj001VnP00I_X200001FKj001VnVKj00000VKj00@006;j001RnP<00007H_X006;j
H_X006;j00000V;j00T006;j001RnP00H_X006;j00000V;j00<006;j00000V;J0P000UkJ0P0000EN
fP00001NfP00009NfP80009NfP80009NfP06001JfP00F]X005[J0P000UZj00D005Zj000005Jj00/0
0007D[/005:k001B^`00DY/03@0000E>V`00CY/004ZK00800007BY/004ZK001:V`00BW/00P0000=:
N`00BW/00P0000I6N`000016N`00AW/400001DIl0016O000AW`00P0000E6O000@W`0049l00<00003
@W`0000000@00003@W`0049l00800003@W`0049l00800003@W`0049l00D00005@W`004:L0012W003
00000d:M0012W@0600001d:M0012W@00@[d004Jm00800007A[d004Jm001:_@00B]d00P0000E:g@00
C]d004kM00800004D_d005;m0002D_d04000E_d005Km001G7@00Ead005/L001K7000Fa`005/L1000
00AO7000Ga`0009O7008001O7000Hc`006<l001S>`80000<Hc/006<kHc/006<k001S>`00Hc/006<k
0P0000AS6`00Ha]S6`80009S6`07001S6`00Ha/006<K00000V<K00H006<K001S6`00Ha/200002F<K
001S6f<K001S6`00HaX00002HaX3000036<J001S6V<J001S6P00HaX006<J001S6P<00009HaX006<J
HaX006<J001S6P00009RnP<00004H_X006;j0002H_X03@00H_X006;j001RnP00H_X006;j001RnP00
009RnP07001RnP00H_X006;j00000V;j0`0000=NnP0000000Ukj00T005kj001NfP00G]X005kJ0000
0UkJ00<005kJ00001@0000ANfP00G]X0009JfP0B001JfP00F]X005[J001JfP00F]X005[J001JfP00
F[X005Zj2@0000MF^P00E[X005Jj001F^P0200005EJj001F^`00E[/005Jk001F^`00E[/005Jk001B
^`00D[/005:k001B^`0200005e:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/00P0001]B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/00P000U:k01H005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`80
000_D[/005Jk001F^`00E[/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`09000FOol00`00Oomoo`0_Ool008Uo
o`03001oogoo05eoo`08001Bg000D]`005;L001Bg080000;D]`005;L001Bg000D]`005;L001Bg002
0002D]`01000D]`005;L0P0000UBg000D]`005;L001Bg000D[`00P0000]B_000D[`005:l001B_000
C[`004jl0080000>C[`00000C[`004jl001>_000C[`004jl001>_0800005B[`004Zl001:_0030000
1DZl001:_000AY`01@0000=6W000@Y`00P0000I2W@00000nW@00?Yd200000cim00000003000013Im
000003Im0`0000LbO@00<Wd002iM000^G@0400000c9n00000002000013:N000003Zn0`000192gP00
A]h004Kn001:oP00Cah005<N001C7P00Ecd005/m0002Fcd01000Gcd005ll100000ES?000HcaS?000
009S?006001W>`00001W>`000VLk00@006LkIc/0009W>`03001W>`00009W>`05001[>V/j001[>P02
00001FLj001[>V/j00000V/j00H006/j000006/j0003JcX01000JcX006/j0P000VLj00<006Lj0000
0VLJ00@006LJ0000009W6P05001W6P00IaX00002IaX00`00IaX00002IaX01`00IaYW6P00IaX006LJ
0080009W6P03001W6P00009W6P05001W6P00IaX00002IaX00`00IaX00002IaX01000IaX006LJ0P00
0VLJ00P006LJ001VnP00I_X006Kj0P0000EVnP00I_YVnP00009VnP09001VnP00H_X006;j001RnP00
009RnP03001RnP00009RnP04001RnP00H_X30002H_X01@00H_X006;j00000V;j00@006;J001RfPD0
000FG]X005kJG]X005kJ001NfP00G]X005kJ001NfP00F]X005[J001JfP00F[X700001eJj001F^P00
E[X005Jj00800008E[X005:kD[/005:k001B^`800003DY/005:K00800007CY/004jK001>V`00CY/0
200000Y:V`00001:V`00BW/004Yk001:N`800003AW/004Ik00800006AW/00000AW`004Il100000=6
O000AW`00P0000E2O000@W`0049l00<00003@W`0049l00@00003@W`0049l00800005@W`0049l0012
O00200000d9l0000000500001T:L000004:M0012W@800005@Yd004:M0012W@0400001d:m0016_@00
A[d004Jm0080000;B[d004[M001:g@00B]d004kM001>g@02000015;m001Bo@000U;m00@005Km001F
o@800005Ead005/L001K7004000015/L001O70000UlL00L005lL001O7000Ga`00002Hc`3000036<K
001S>f<k001S>`00Hc/006<k001S>`80000<Ha/006<KHa/006<K001S6`00Ha/006<K0`000V<K00<0
06<KHa/00P0000ES6`00001S6`00009S6`05001S6`00Ha/00002HaX3000036<J001S6V<J001S6P00
HaX006<J001S6P800003HaX00000009S6P05001S6P00HaX00002HaX300003V;j001RnV;j001RnP00
H_X006;j001RnP00H_X30002H_X02@00H_X006;j001RnP00H_X00002H_X300003Ukj001NnP00G_X0
05kj001NnP00G]X005kJ0002G]X5000055kJ001NfP00G]X005kJ001NfP00F]X005[J001JfP00F]X0
05[J0002F]X200000e[J0000000300009EZj001J^P00E[X005Jj001F^P00E[X005Jj001F^P00E[X0
05Jj001F^`00E[/005Jk001F^`00E[/005Jk001B^`00D[/005:k0080000ID[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P0001UB^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`0200007E:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P00011F^`00E[/005KK001Ff`00E]/0
05KK001Ff`00E]/0009Ff`<00003E]/005KK00800003E]/005KK00l00008E]/005KK001Ff`00E]/0
01Ioo`03001oogoo02moo`00RGoo00<007ooOol0GWoo00@005;L001Bg0800009D]`005;L001Bg000
D]`005;L0080000?D]`005;L001Bg000D]`005;L001Bg000D]`005;L0080000;D]`005;L001B_000
D[`005:l001B_00200001e:l001>_000C[`004jl00800007C[`004jl001>_000C[`00P0000=>_000
C[`00P0000M:_000B[`004Zl001:_00200000dZl001:_002000014JL000004JL1P0000A2W@00000n
W@800007?Wd003im000jO@00>Wd01@0000@fO@00000bO@H00003;Ud0000000800003<Wh003JN0080
0003=Yh003Zn00<0000E@]h004KN0016oP00B_h004lN001C7P00Dah005Lm001K?@00Fcd005lm0080
0004Gc`005ll0002Hc`01@00HcaS?000Hc`00P0000EW>`00Ic]W>`00009W>`04001W>`00Ic/20002
Ic/01000Ic]W>`000V/j00<006Lj00000VLj00@006/jJcX0009[>P03001W>P00009[>P05001[>V/j
001[>P0200001FLj001W>VLj00000VLj00H006LJIaX006LJ0002IaX01P00IaX006LJ001W6P80009W
6P07001W6VLJ001W6P00IaX00P0000EW6P00IaYW6P00009W6P04001W6P00IaX2000016LJ001W6P00
0VLJ00@006LJ001W6P80009W6P03001W6P00009W6P03001VnP0000800007I_X006KjI_X006Kj0000
0VKj00@006Kj001RnP<0009RnP03001RnP00009RnP04001RnP00H_X2000026;j001RnP00H_X006;j
0002H_X02`00H_X006;J001RfP00G]X005kJ00000UkJ010005kJ001NfP00G]X005kJ001NfP00G]X0
05[J001JfPD00006F[X005Zj001J^P000UJj00l005Jj000005Jj001F^P00E[X005:k001B^`00D[/0
0P0000]BV`00DY/005:K001>V`00CY/004jK00800003CY/004jK00800003BY/0000000@00005BW/0
04Yk001:N`0200000dIk0016N`0200001DIk0016N`00AW`00P0000=6O000AW`0100000I6O0000012
O000@W`200000d9l0012O00200000d9l0012O00400000d9l0012O00200002D9l0012O000@W`004:L
0012W00300001T:L000004:M0012W@800003@Yd004:M00800003@Yd004Jm00H0000JA[d00000B[d0
04[M001:g@00B]d004kM001>g@00C_d005;m001Bo@00D_d005Km001Fo@800003Ead0000000800004
Fa`005/L0002Fa`02P00Ga`005lL001O7000Ga`005lL100000US7000Ha]S6`00Hc/006<k00000V<k
0`0000aS6`00Ha]S6`00Ha/006<K001S6`00Ha/2000016<K001S6`000V<K00L006<K001S6`00Ha/0
0002Ha/01@00Ha/006<K00000V<K0`0000US6`00HaYS6P00HaX006<J00000V<J0`0000YS6P00HaX0
06<J001S6P00HaX0009S6P<0000;H_X006;jH_X006;j001RnP00H_X00002H_X300002V;j001RnP00
H_X006;j001RnP000V;j00<006;j00000P0000ANnP00G_X0009NnP80009NnP80009NfP03001NfP00
00800006G]X005kJ001NfP000UkJ0P0000QNfP00G]X005[J001JfP000U[J00@005[J001JfPD0000=
F]X00000F[X005Zj001J^P00E[X005Jj00000UJj00H005Jj001F^P00E[X200005EJj001F^`00E[/0
05Jk001F^`00E[/005Jk001B^`00D[/005:k001B^`0200005e:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/00P0001]B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/00P0002eB^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005Jk001F^`00E[/005KK001Ff`00E]/005KK001Ff`00E]/0
3P00011Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0009Ff`800003E]/007oo01Eoo`03001o
ogoo02moo`00RWoo00<007ooOol0GGoo00P005;L001Bg000D]`005;L0P0000]Bg000D]`005;L001B
g000D]`005;L00800005D]`005;L001Bg00K00003Tjl000004jl001>_000C[`004jl001>_000C[`2
00001DZl001:_000B[`00P0000Q:_000001:_000AY`004JL0`0000E6W000AY`004:L00<00005?Yd0
03jM000nO@0300001SYm000003Ym000jO@<00008=Wd00000<Wd0039m000bO@800005<Wd00000000b
OP0200000cJN0000000300004ckN0012gP00A]h004Kn001:oP00Cah005<N001C7P00Ecd005/m00<0
009O?@05001O?000Gc`00002Hc`01P00Hc`00000Hc`0009W>`07001W>fLk001W>`00Ic/00P000VLk
00L006LkIc/006Lk001[>P020002IcX01`00IcYW>P00JcX006/j0080009W>P04001[>V/j0002JcX0
0`00IcX00002IcX01`00IcYW>P00IcX006LJ0080009W6P08001W6VLJ001W6P00IaX0009W6P03001W
6P00009W6P06001W6P00001W6P000VLJ00L006LJIaX006LJ001W6P02000016LJ001W6P000VLJ00@0
06LJ001W6P800005IaX006LJIaX00002IaX01`00IaX006Kj001VnP00009VnP03001VnP00009VnP04
001VnP00I_X200001V;j001RnP00H_X0009RnP04001RnP00H_X200001V;j001RnP00H_X0009RnP08
001RnP00H_X006;j001RfP<0009NfP05001NfP00G]X00002G]X01000G]X000000UkJ0P0000=NfP00
00000P0000=JfP00F]X00P000UZj00`005Zj001J^P00E[X005Jj001F^P00E[X200003EJj001B^`00
D[/005:k001BV`00DY/005:K00800007CY/004jK001>V`00CY/00P0000=>V`00CY/00P0000E:V`00
BY/004ZK00H00008BW/00000AW/004Ik0016N`800005AW`004Il0016O00200000dIl0016O0040000
149l0000049l0P0000E2O000@W`0049l00800003@W`0049l00800008@W`00000@W`0049l0012O080
0004@Y`00000@Y`400001d:M0012W@00@Yd004:M00800003@Yd004:M00800005A[d004Jm0016_@09
00003D[M001>g@00C]d004km001Bo@00D_d005;m00L00004Ead005/L0002Fa`00`00Fa`00002Fa`2
00001ElL001O7000Ga`00P0000AO7000Ga`0009S7005001S6`00Hc/00002Hc/300002F<K001S6f<K
001S6`00Ha/00002Ha/300002V<K001S6f<K001S6`00Ha/006<K0`000V<K00D006<K001S6`00009S
6`<00009Ha/006<KHa/006<J001S6P00009S6P<00004HaX006<J0002HaX20002HaX00`00HaX00002
00002f;j001RnV;j001RnP00H_X006;j00000V;j0`0000IRnP00H_X006;j0002H_X20002H_X50000
15kj001NnP000Ukj00P005kj001NnP00G_X005kj1@0000INfP00G]X005kJ0002G]X01000G]X005kJ
0P0000INfP00F]YJfP00F]X700001e[J001JfP00F]X005Zj0080009J^P0@001J^P00E[X005Jj001F
^P00E[X005Jj001F^P00E[X200004eJk001F^`00E[/005Jk001F^`00E[/005:k001B^`00D[/005:k
0080000GD[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0200006e:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`020002D[/0
5P00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0P0000=B^`0000004@00
00MFf`00000005KK001Ff`0200001UKK001Ff`00E]/0009Ff`0>001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`800003E]/007oo01Eoo`03001oogoo02moo`00Rgoo00<007ooOol0G7oo00<005;L0000
6@0000EBg000D]`005;L0080000;D]`005;L001Bg000D[`005:l001B_00200001e:l001B_000C[`0
04jl01000007B[`004Zl001:_000B[`00P0000E:_000B[`004JL00800006AY`00000AY`004JL0P00
00=2W@0000000`0000<nO@00?Wd00P0000@jO@00000jO@800009>Wd00000000bO@00<Wd0039m0080
0003<Wd0000000<00007<Wh00000000jWP00>[h0500000AK?@00Fcd0009O?@06001O?000Gc`006<l
0P0000ES?000HcaS?000009W>`04001W>`00Ic/200000fLk001W>`02Ic/01000Ic/006Lk0P000VLk
00L006LjIcX006Lj001[>P020002IcX01`00IcYW>P00JcX006/j0080009W>P07001W>VLj001W>P00
IcX00P000VLJ00L006LJIaX006LJ001W6P030002IaX01000IaYW6P000VLJ00<006LJ00000VLJ00L0
06LJIaX006LJ001W6P0200002VLJ001W6VLJ001W6P00IaX006LJ0P0000EW6P00IaYW6P00009W6P03
001W6P00009W6P80009VnP03001VnP00009VnP04001VnP00I_X2000016;j001RnV;j0P000V;j00@0
06;j001RnP800004H_X006;j0002H_X02P00H_X006;j001RnP00H_X006;j0P0000QRfP00G]X005kJ
001NfP000UkJ00H005kJ001NfP00G]X5000045[J001JfP00F]X005[J001J^P00F[X005Zj001J^P00
0UJj00l005Jj000005Jj001F^P00E[X005:k001B^`00D[/00P0000]BV`00DY/005:K001>V`00CY/0
04jK00800003CY/004jK00800005BY/004ZK001:V`0200001DZK001:V`00BY/0100000Q6N`000016
N`00AW/004Il0P0000=6O000AW`00P0000A6O0000016O0H00003@W`0049l00800005@W`0049l0012
O00200000d9l000000020000149l0000049l0P0000=2W000@Y`00P0000=2W000@Yd01P0000E2W@00
@Yd004:M00800005A[d004Jm0016_@02000024Jm000004[M001:g@00B]d=00001E;m001Fo@00E_d0
0P000ULM00<005/L00000U/L00@005/L001K70800003Ga`000000080000<Ga`005lLGa`005lL001S
7000Ha/006<k100000YS6`00Ha]S6`00Ha/006<K001S6`@0000:Ha/006<KHa/006<K001S6`00Ha/2
00001V<K001S6`00Ha/0009S6`03001S6`0000800009Ha/006<KHa/006<K001S6P00009S6P<0000A
HaX006<JHaX006<J001S6P00HaX006<J001S6P00HaX00002H_X01@00H_X006;j00000V;j00<006;j
00000P0000aRnP00H_YRnP00H_X006;j001RnP00H_X3000016;j001RnP000Ukj01<005kj001NnP00
G_X005kj001NnP00G_X005kJ001NfP00G]X00002G]X03000G]X005kJ001NfP00G]X005kJ001NfPD0
000:F]X005[J001JfP00F]X005[J0002F]X200009eZj001J^P00F[X005Jj001F^P00E[X005Jj001F
^P00E[X005Jj001F^P00E[/005Jk001F^`00E[/005Jk001F^`00D[/005:k001B^`0200006E:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0080000ID[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P0000=B^`0000006P0001EF
^`00E[/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00`0001iFf`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK000EOol00`00Oomoo`0_
Ool008]oo`03001oogoo05eoo`08001Bg000D]`005;L001Bg080000;D]`005;L001Bg000D]`005;L
001Bg002000015;L001Bg0000U;L00@005;L001Bg080000;D]`005;L001Bg000D[`005:l001B_002
00001E:l001B_000C[`00P0000i>_000001>_000C[`004jl001>_000C[`004jl300000E:_000AY`0
04JL0080000<AY`00000AY`004:L0012W@00@Yd004:M100000@nO@00000jO@800005>Wd00000000f
O@020000139m0000039m0`0000<fO@00=Wd00`0000HfWP00000jWP00>[h200004D;N000004Kn001:
oP00C_h004lN001C7P00Dad005Lm00000U/m00<005/m00000Ulm00L005ll001O?000Hc`00002Hc`0
1`00HcaS?000Ic/006Lk0080009W>`03001W>`00009W>`06001W>`00001W>`000fLk00@006Lj001W
>P800003IcX006Lj009W>P04001W>P00JcX20002IcX01`00IcYW>P00IcX006Lj00800005IaX006LJ
IaX00002IaX02000IaX00000IaX006LJ0002IaX01000IaX006LJ0P000VLJ00<006LJ00000VLJ00H0
06LJ000006LJ0002IaX01P00IaX006LJ001W6P800007IaX006LJIaX006LJ00000VLJ00@006LJ001W
6P800004I_X006Kj0002I_X01000I_X006Kj0P0000aRnP00H_YRnP00H_X006;j001RnP00H_X20000
3V;j001RnV;j001RnP00H_X006;j001RnP00H_X400001V;j001RfP00G]X0009NfP0?001NfP00G]X0
05kJ001NfP00G]X005kJ001NfP00009JfP06001JfP00F]X005[J0P000UZj00P005Zj001J^P00E[X0
05Jj0P0000]F^P00E[X005Jj001B^`00D[/005:k0080000=DY/005:K001BV`00CY/004jK001>V`00
CY/00P0000=>V`00CY/00P0000E:V`00BY/004ZK00800003BY/004ZK00800003BY/0000000800009
AW/004Ik0016O000AW`004Il00800003AW`004Il00<00003AW`004Il00@00005@W`0049l0012O002
00000d9l0012O00200000d9l000000040000149l000004:L0P0000=2W000@Y`00P0000E2W@00@Yd0
04:M00@0000<@Yd00000A[d004Jm0016_@00A[d004Jm0P0000=:g@00B]d00P0000a>g@00C]d004kM
001>o@00D_d005;m0002D_d01000E_d005Km0P000ULM00P005/L001K7000Fa`005/L0`0000AO7000
Ga`0009O7003001O75lL00800003Ha`006<K00800004Ha/006<K0002Ha/01P00Ha/006<K001S6`80
0004Ha/006<K0002Ha/01P00Ha/006<K001S6`800004Ha/006<KHa/20002Ha/01`00Ha/006<K001S
6`00009S6`05001S6`00Ha/00002HaX300003V<J001S6V<J001S6P00HaX006<J001S6P00HaX30002
HaX01@00H_X006;j00000V;j1@0001=RnP00H_YRnP00H_X006;j001RnP00H_X006;j001RnP00H_X0
0002H_X01`00G_X005kj001NnP00009NnPH00004G]X005kJ0002G]X01`00G]X005kJ001NfP00009N
fP80000>G]X00000001JfP00F]X005[J001JfP00F]X0009JfP06001JfP00F]X005Zj0P0000QJ^P00
F[X005Jj001F^P000UJj00H005Jj001F^P00E[X200000eJj0000001:00005e:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P0000IF^`00E[/005Jk0002E]/03P00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/4000065KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/0009Ff`800003E]/007oo01Aoo`03001oogoo02moo`00S7oo00<007ooOol0
G7oo00T005;LD]`005;L001Bg000D]`00P0000]Bg000D]`005;L001Bg000D]`005;L0080000?D]`0
05;L001Bg000D]`005;L001Bg000D]`005;L00800009D[`005:l001B_000D[`005:l00800005C[`0
04jl001>_00200005Djl001>_000C[`004jl001>_000C[`004Zl001:_000B[`004Zl001:_0070000
0dJL0016W002000014JL000004:M0P0000I2W@00000nW@00?Yd5000013Ym000003Ym0`0000<fO@00
00000`0000@bO@00000fO@800009=Yh00000000fWP00>Yh003Zn0080000A@]h00000A_h004[n001>
oP00Cah005<N001C7@00Ecd00002Fcd01000Fcd005lm100000AO?000Hc`0009S?006001S?6<l001W
>`000VLk00L006LkIc/006Lk001W>`0200001FLk001W>fLk00000VLk00H006Lj000006Lj0002IcX0
1@00IcYW>P00IcX00P0000EW>P00IcYW>P00009W>P06001W>P00001W>P000VLJ00@006LJIaX0009W
6P03001W6P00009W6P06001W6P00IaX006LJ0P000VLJ00<006LJ00000VLJ00H006LJIaX006LJ0002
IaX01@00IaX006LJ00000VLJ00<006LJ00000VLJ00<006LJ00000VLJ00@006LJ001W6P800004I_X0
06Kj0002I_X01000I_X006Kj0P0000aRnP00H_YRnP00H_X006;j001RnP00H_X200003V;j001RnV;j
001RnP00H_X006;j001RnP00H_X200001V;j001RnP00H_X0009RfP0:001NfP00G]X005kJ001NfP00
G]X50002G]X06P00G]X005[J001JfP00F]X005[J001J^P00F[X005Zj001J^P00E[X005Jj001F^P00
E[X200003EJj001B^`00D[/005:k001BV`00DY/005:K00800007CY/004jK001>V`00CY/00P0000U>
V`00CY/004ZK001:V`00BY/00P0000E:V`00BY/004ZK00<00003BY/004Ik00H00003AW`004Il0080
0003AW`004Il00800003AW`004Il00800003AW`004Il00@00003@W`0049l00800009@W`0049l0012
O000@Y`004:L00@00005@Y`004:L0012W00200001D:M0012W@00@Yd00P0000=2W@00@Yd01@0000]6
_@00A[d004Jm0016_@00B[d004[M0080000KB]d004kM001>g@00C]d004km001Bo@00D_d005;m001F
o@00E_d005LM001G7@00Fa`005/L00@00003Fa`00000009O7003001O7000009O7005001O7000001S
7002000036<K001S6f<K001S6`00Ha/006<K001S6`80000<Ha/006<KHa/006<K001S6`00Ha/006<K
0P0000aS6`00Ha]S6`00Ha/006<K001S6`00Ha/30002Ha/01@00Ha/006<K00000V<K0`0000]S6P00
HaYS6P00HaX006<J001S6P00009S6P<00008HaX006<J001S6P00H_X0009RnP<00004H_X006;j0002
H_X02P00H_X006;j001RnP00H_X006;j0`0000]RnP00H_YRnP00H_X005kj001NnP00009NnP<0000@
G_X005kj001NnP00G]X005kJ001NfP00G]X005kJ0002G]X600001U[J001JfP00F]X0009JfP0<001J
fP00F]X005[J001JfP00F]X005Zj0P000UZj00H005Zj001F^P00E[X<00004eJk001F^`00E[/005Jk
001F^`00E[/005Jk001B^`00D[/005:k0080000GD[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`0200006E:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k0080000>D[/005:k001B^`00D[/005:k001B^`00D[/0009B^`06001B^`00D[/0
05:k0P0001UB^`00E[/005Jk001F^`00E[/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`03
00000eKK001Ff`0200001UKK001Ff`00E]/0009Ff`0<001Ff`00E]/005KK001Ff`00E]/005KK1P00
5Goo00<007ooOol0;goo002<Ool00`00Oomoo`1MOol03P00D]`005;L001Bg000D]`005;L001Bg000
D]`200002E;L001Bg000D]`005;L001Bg0020002D]`01000D]`005;L0P0000]Bg000D]`005;L001B
_000D[`005:l00800005D[`005:l001>_00200001Djl001>_000C[`00P0000M>_000C[`004jl001>
_00200001dZl001:_000B[`004Zl00<00005B[`004Zl0016W00500001DJL0012W000@Yd00P0000A2
W@00000nW@800003?Yd003im00<00003>Wd003Ym00@00003=Wd003Im00800004<Wd00000=Wd40000
0cZN0000000200001CZn000n_P00@]h00P0000m6oP00B_h004kn001?7P00Dah005<M001G?@00Fcd0
100000AO?@00Gc`0009O?003001S?000009S?006001S?000001S>`000VLk00P006LkIc/006Lk001W
>`000VLk00@006LkIc/0009W>`03001W>`00009W>P04001W>VLj0002IcX00`00IcX00002IcX01000
IcYW>P000VLj00<006Lj00000VLj00L006LJIaX006LJ001W6P020002IaX00`00IaYW6P0200001FLJ
000006LJ00000VLJ00L006LJIaX006LJ001W6P020002IaX00`00IaX00002IaX00`00IaX000020002
IaX00`00IaX00002IaX01000IaX006LJ0P0000YW6P00I_YVnP00I_X006Kj001VnP800009H_X006;j
H_X006;j001RnP00009RnP<00007H_X006;jH_X006;j00000V;j0P000V;j0`00019RnP00H_YRnP00
H_X006;j001RfP00G]X005kJ001NfP00G]X200002UkJ001NfP00G]X005kJ001NfP000U[J00l005[J
000005[J001J^P00F[X005Zj001J^P00E[X07`0000=>V`00CY/00P0000M:V`00BY/004ZK001:V`02
00000dZK001:V`0200000dZK001:V`0200001DIk0016N`00AW/0100000I6O0000016O000AW`20000
1DIl0016O000AW`00P0000=6O000@W`0100000I2O0000012O000@W`200001T:L000004:L0012W0@0
0007@Y`004:L0012W@00@Yd00P0000=2W@00@Yd00P0000=6W@0000001`0000m6_@00B[d004[M001:
g@00B]d004kM001>g@00C]d00P0000eBo@00D_d005;m001Fo@00E_d005LM001G7@04000015/L001K
70000U/L0P000UlL00H005lL001O7000Ga`3000035lL001S6f<K001S6`00Ha/006<K001S6`80000<
Ha/006<KHa/006<K001S6`00Ha/006<K0P0000aS6`00Ha]S6`00Ha/006<K001S6`00Ha/200001V<K
001S6`00Ha/0009S6`03001S6`0000800009Ha/006<JHaX006<J001S6P00009S6P03001S6P000080
0004HaX006<JHaX20002HaX00`00H_X00002000016;j001RnP000V;j00D006;j001RnP00009RnP03
001RnP000080000:H_X006;j001RnP00H_X006;j0002G_X00`00G_X0000200003Ukj001NnP00G_X0
05kj001NfP00G]X005kJ0002G]X00`00G]X0000200005UkJ001NfP00G]X005[J001JfP00F]X005[J
001JfP00F]X005[J001JfP000U[J0P0000=J^P0000001`0000UF^P00E[X005Jj001F^P00E[X00P00
01=F^`00E[/005Jk001F^`00E[/005Jk001F^`00D[/005:k001B^`020002D[/05P00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0P0001MB^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k0080000GD[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`0200006e:k001F^`00E[/005Jk001F^`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`0300002EKK001Ff`00E]/005KK001Ff`0?00001EKK000005KK00005Goo
00<007ooOol0;goo002=Ool00`00Oomoo`1MOol02000D]`005;L001Bg000D]`200002e;L001Bg000
D]`005;L001Bg000D]`00P0000mBg000D]`005;L001Bg000D]`005;L001Bg000D]`00P0000UB_000
D[`005:l001B_000D[`00P0000E>_000C[`004jl0080000;C[`004jl001>_000C[`004jl001>_002
000024Zl000004Zl001:_000B[`200000dZl001:_00200000dJL0016W00500000d:M0012W@020000
1T:M000003jM000nW@<00004>Wd00000>Wd2000013Im000003Im0P0000LfO@00000003Im000fO@03
000013ZN000003jn2@0000M:oP00C_h004lN001C7P06000015/m001K?@000Ulm00<005ll00000Ull
00@006<l001S?0800005Hc`006<kHc/00002Ic/00`00Ic/000020002Ic/01`00Ic]W>`00Ic/006Lk
0080009W>`07001W>VLj001W>P00IcX00P000VLj00L006LjIcX006Lj001W>P020002IcX01`00IcYW
>P00IaX006LJ0080009W6P03001W6P00009W6P05001W6P00IaX00002IaX01`00IaYW6P00IaX006LJ
0080009W6P03001W6P00009W6P05001W6P00IaX00002IaX00`00IaX00002IaX01000IaX006LJ0P00
00UW6P00IaYW6P00I_X006Kj00000VKj00<006;j00000V;j00<006;j00000V;j00<006;j00000P00
00MRnP00H_YRnP00H_X00002H_X01000H_X006;j0`00011RnP00H_YRnP00H_X006;j001RnP00H]X0
05kJ001NfP@00008G]X005kJ001NfP00G]X0009NfP0:001NfP00F]X005[J001JfP00F]X200000eZj
0000000400000eJj001F^P0200002eJj001F^P00E[X005Jk001B^`00D[/00P0000eBV`00DY/005:K
001BV`00CY/004jK001>V`0700001DZK001:V`00BY/00P0000E:V`00BY/004ZK00800005BY/004Ik
0016N`0200001DIk0016O000AW`0100000I6O0000016O000AW`200001DIl0016O000AW`00P0000=2
O000@Y`01@0000=2O000@Y`00P0000=2W000@Y`00P0000=2W000@Y`0100000=2W@00@Yd00P0000m2
W@00@Yd004:M0016W@00A[d004Jm0016_@00A[d0200000M:g@00C]d004kM001>g@0200000e;m001B
o@0:000015LL001K70000U/L00`005/L001K7000Ga`005lL001O7000Ga`200000elL00000002Ga`0
1@00Ha]S6`00Ha/00P0000ES6`00001S6`00009S6`08001S6`00Ha/006<K001S6`800009Ha/006<K
Ha/006<K001S6`00009S6`<00004Ha/006<KHa/20002Ha/01`00Ha/006<K001S6`00009S6`05001S
6P00HaX00002HaX500004F<J001S6V<J001S6P00HaX006<J001RnP00H_X006;j00000V;j00D006;j
001RnP00009RnPD00004H_X006;jH_X2000016;j001RnP000V;j1@0000ANnP00G_X0009NnP04001N
nP00G_X2000015kJ001NfUkJ1@0001ANfP00G]X005kJ001NfP00F]X005[J001JfP00F]X005[J001J
fP000U[J00<005[J00001@0002MJ^P00F[X005Jj001F^P00E[X005Jj001F^P00E[X005Jj001F^P00
E[/005Jk001F^`00E[/005Jk001F^`00E[/005:k001B^`00D[/00P0001MB^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k0080000GD[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`0200006e:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`0200001UJk001F^`00E[/0009Ff`0>001Ff`00E]/005KK001F
f`00E]/005KK001Ff`h0000DE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/001Ao
o`03001oogoo02moo`00SWoo00<007ooOol0G7oo00<005;LD]`00P0000UBg000D]`005;L001Bg000
D]`00P0000UBg000D]`005;L001Bg000D]`00P0000EBg000D]`005;L01D00007C[`004jl001>_000
C[`00P0000M>_000C[`004jl001>_00200001dZl001:_000B[`004Zl00800003B[`004Zl00800009
AY`004JL0016W000AY`004JL00L00003?Yd003jM00800005?Wd00000000jO@0400001CIm00000000
=Wd00P0000<fO@0000000`0000@fWP00000jWP<00007?[h004;N0012gP00A]h0200000IC7@00Ead0
05LM0002Fcd00`00Fcd00002Gcd01000Gc`005ll100000ES?000HcaS?000009S>`08001W>`00001W
>`00Ic/0009W>`04001W>`00Ic/20002Ic/01`00Ic]W>`00IcX006Lj0080009W>P07001W>VLj001W
>P00IcX00P000VLj00<006Lj00000VLj00H006LJ000006LJ0002IaX01000IaYW6P000VLJ0P000VLJ
00L006LJIaX006LJ001W6P0200001FLJ001W6VLJ00000VLJ00@006LJ001W6P<0009W6P07001W6VLJ
001W6P00IaX00P0000aW6P00IaYW6P00IaX006Kj001VnP00I_X20002H_X00`00H_X00002H_X01`00
H_X006;j001RnP00009RnP03001RnP00009RnP09001RnP00H_X006;j001RnP00009RnP03001RnP00
009RnP04001RnP000002H]X3000015kJ001NfP000UkJ010005kJ001NfP00G]X005kJ001NfP00F]X0
05[J001JfPD0000CF[X005Zj001J^P00E[X005Jj001F^P00E[X005Jj001F^P00E[/00P0000]B^`00
D[/005:K001BV`00DY/005:K00800003CY/004jK00800005CY/004jK001>V`0800000dZK001:V`02
00000dZK001:V`0200001DIk0016N`00AW/00P0000A6O0000016O0@00007AW`004Il0016O000AW`0
0P0000E6O000@W`0049l00<00003@Y`0000000@00003@Y`004:L00800003@Y`004:L00800003@Y`0
04:L00L00005@Yd004:M0016W@0200001DJm0016_@00A[d00P0000M:_@00B[d004[M001:g@0<0000
2U;m001Bo@00E_d005Km001G7@000ULL00`005/L001K7000Fa`005/L001O7000Ga`4000015lL001O
75lL0P000UlL00T006<K001S6`00Ha/006<K00000V<K00D006<K001S6`00009S6`<00009Ha/006<K
Ha/006<K001S6`00009S6`<0000<Ha/006<KHa/006<K001S6`00Ha/006<K0`000V<K00D006<K001S
6P00009S6P<00004HaX006<J0002HaX02000HaX006<J001S6P00HaX30002H_X01`00H_X006;j001R
nP00009RnP<00004H_X006;j0002H_X01000H_X006;j0P000V;j0`0000INnP00G_X005kj0002G_X0
2P00G_X005kj001NnP00G]X005kJ0`0000INfP00G]X005kJ0002G]X01P00G]X005kJ001JfP800008
F]X005[JF]X005[J001JfPD00003F]X005Zj00800008F[X005Zj001F^P00E[X0009F^P08001F^P00
E[X005Jj001F^P80000CE[/005Jk001F^`00E[/005Jk001F^`00E[/005:k001B^`00D[/00P0001MB
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0080000ID[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P0000iB^`00D[/005:k001B
^`00D[/005:k001B^`000U:k00H005:k001B^`00D[/200002E:k001F^`00E[/005Jk001F^`0D0000
35KK001Ff`00E]/005KK001Ff`00E]/0009Ff`06001Ff`00E]/005KK0P0000QFf`00E]/005KK001F
f`005Goo00<007ooOol0;Woo002>Ool00`00Oomoo`1MOol01000D]`005;L6`0000MBg000D]`005;L
001Bg00200002E;L001B_000D[`005:l001B_00200000djl0000000A000024Zl000004Zl001:_000
B[`200000dZl001:_00200000dJL0016W002000024JL000004:M0012W@00@Yd300001CjM000nW@00
?Wd0100000<jO@00>Wd00`0000<fO@00=Wd00P0000DfO@00=Yd003ZM00@00009>Yh00000000n_P00
@]h004;N00800005B_h004[n001>oP020002Dad01@00Ead005LM00000U/m00H005/m001O?@00Gc`2
000015ll001S?0000V<l00D006<lHc`006<k00800007Hc/006LkIc/006Lk00000VLk00D006Lk001W
>`0000=W>`04001W>`00IcX200001FLj001W>VLj00000VLj00H006Lj000006Lj0002IcX01000IcYW
>P000VLj00<006LJ00000VLJ00L006LJIaX006LJ001W6P02000016LJ001W6P000VLJ00H006LJ0000
06LJ0002IaX01`00IaYW6P00IaX006LJ00800004IaX006LJ0002IaX01000IaX006LJ0P0000MW6P00
IaYW6P00IaX00002IaX00`00I_X000020002I_X00`00H_X00002H_X00`00H_X00002H_X20002H_X0
0`00H_X00002H_X01P00H_X006;j001RnP<0009RnP03001RnP00009RnP06001RnP00H_X006;j0`00
01ANfP00G]YNfP00G]X005kJ001NfP00G]X005kJ001NfP00G]X005[J1@0000AJfP00F[X0009J^P08
001J^P00F[X005Jj001F^P80000;E[X005Jj001F^P00E[/005:k001B^`0200003E:K001BV`00DY/0
05:K001>V`00CY/004jK00800003CY/004jK00800005CY/004ZK001:V`0700001dZK001:V`00AW/0
04Ik00800005AW/004Il0016O00300000dIl0016O00400001DIl0016O000AW`00P0000E2O000@W`0
04:L00<00003@Y`004:L00@00005@Y`004:L0012W00200000d:L0012W00200000d:M0012W@070000
1dJM0016_@00A[d004Jm00800007A[d004Zm001:_@00B]d00P0000M>g@00C]d004kM001>o@020000
5U;m001BoE;m001Bo@00E_d005Km001G7@00Ea`005/L001K7000Fa`005/L100000AO7000Ga`0009O
7008001O7000Ga`005lL001S6`D0009S6`07001S6f<K001S6`00Ha/00`0000US6`00Ha]S6`00Ha/0
06<K00000V<K0`0000aS6`00Ha]S6`00Ha/006<K001S6`00Ha/200001V<K001S6`00Ha/0009S6`03
001S6P000080000;HaX006<JHaX006<J001S6P00HaX00002HaX300002V;j001RnP00H_X006;j001R
nP000V;j0`0000ARnP00H_X0009RnP08001RnP00H_X006;j001RnP<00004G_X005kj0002G_X03000
G_X005kj001NnP00G_X005kj001NfP<00006G]X005kJ001NfP000UkJ00`005kJ001NfP00G]X005[J
001JfP00F]X700006e[J001JfP00F]X005Zj001J^P00F[X005Zj001F^P00E[X005Jj001F^P00E[X0
05Jj001F^P0200004eJk001F^`00E[/005Jk001F^`00E[/005Jk001B^`00D[/005:k0080009B^`0F
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/200005e:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P0000mB^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/0500000mFf`00E]/005KK001Ff`00E]/005KK001Ff`00E]/010000UKK018005KK
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/2000015KK001FfeKK0P0000=Ff`00Ool057oo
00<007ooOol0;Woo002?Ool00`00Oomoo`1MOol400002E;L001Bg000D]`005;L001Bg00200002E;L
001Bg000D]`005;L001Bg002000015;L001Bg0000U;L00H005;L001Bg000D]`200002E;L001B_000
D[`005:l001B_00300001djl001>_000C[`004jl00800009C[`004jl001>_000C[`004jl00T00003
B[`004Zl00800005AY`004JL0016W00200001TJL000004:M0012W@<00003@Yd0000000800004?Wd0
0000>Wd2000013Ym000003Ym0`0000LfO@00=Wd003Im000fW@0200000cZN000jWP0500001Cjn0012
gP00@]h00P0000E:oP00B_h004kn0080009C7@08001G7@00Ead005/m001K?@@00007Gc`005llGc`0
06<l00000V<l00H006<l000006<k0002Hc/01`00Ic]W>`00Ic/006Lk00<0009W>`09001W>fLkIc/0
06Lk001W>P00009W>P04001W>VLj0002IcX00`00IcX00002IcX01`00IcYW>P00IcX006Lj0080009W
6P07001W6VLJ001W6P00IaX00P000VLJ0P000VLJ00H006LJIaX006LJ0002IaX00`00IaX00002IaX0
1P00IaX00000IaX0009W6P80009W6P06001W6P00001W6P000VLJ00<006LJ00000VLJ00L006LJ001V
nP00I_X00002I_X02@00H_YRnP00H_X006;j001RnP02000016;j001RnP000V;j00H006;j001RnP00
H_X200001V;j001RnP00H_X0009RnP06001RnP00H_X006;j0`0000UNfP00G]YNfP00G]X005kJ0000
0UkJ0P0000ENfP00G]X005kJ00@0000MF]X005[J001JfP00F]X005Zj001J^P00F[X005Zj001F^P00
E[X005Jj001F^P00E[X005Jj001F^`0200002e:k001B^`00DY/005:K001BV`00DY/00P0000=>V`00
CY/00P0000M>V`00CY/004jK001>V`02000024ZK000004ZK001:V`00BY/400000dIk0016N`020000
1DIk0016O000AW`00P0000=6O000AW`00P0000=6W000AY`0100000=6O000AW`00P0000=2O000@Y`0
0P0000=2W000@Y`00P0000=2W000@Y`0100000=2W000@Y`00P0000]2W000@Y`004:M0012W@00AYd0
04JM00H00009A[d004Jm0016_@00A[d004Zm0080000;B]d004[M001>g@00C]d004kM001>o@020000
25;m001BoE;m001Bo@00E_d200001eLM001G7000Fa`005/L00@00004Fa`005/L0002Ga`02P00Ga`0
05lL001O7000Ga`005lL0P0000IO7000Ha/006<K0002Ha/02@00Ha/006<K001S6`00Ha/00002Ha/0
1@00Ha/006<K00000V<K0`0000US6`00Ha]S6`00Ha/006<K00000V<K0`0000AS6`00Ha]S6`80009S
6`07001S6`00HaX006<K00000V<J00L006<J001S6P00HaX00002HaX3000016;j001RnV;j0P000V;j
0P000V;j0`0000ARnP00H_X0009RnP05001RnP00H_X00002H_X200001V;j001NnP00G_X0009NnP07
001NnP00G_X005kj00000Ukj00<005kj00000`0000ANfP00G]X0009NfP0>001NfP00G]X005kJ001N
fP00G]X005[J001JfP<0000:F]X005[J001JfP00F]X005[J0002F]X0:`00F[X00000F[X005Zj001F
^P00E[X005Jj001F^P00E[X005Jj001F^P00E[X005Jk001F^`00E[/005Jk001F^`00E[/005Jk001B
^`00D[/005:k04@00007D[/005:k001B^`00E[/00P0000iF^`00E[/005Jk001Ff`00E]/005KK001F
f`000UKK00H005KK001Ff`00E]/2000095KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/001Aoo`03001oogoo02ioo`00Sgoo00<0
07ooOol0GGoo00h005;L001Bg000D]`005;L001Bg000D]`005;L0P0000UBg000D]`005;L001Bg000
D]`00P0000mBg000D]`005;L001Bg000D]`005;L001Bg000D]`00P0000EB_000D[`005:l00800009
C[`004jl001>_000C[`004jl00800007C[`004jl001>_000C[`00P0000Q>_000001:_000B[`004Zl
1`0000=6W000AY`00P0000=6W000AY`00P0000=2W@00@Yd00`0000<nW@00?Yd0100000TjO@000000
03Ym000jO@00>Wd0100000@fO@00000fW@800006>Yh00000>Yh003jn1@0000U2gP00A]h004[n001:
oP00C_h00P0000=C7@00Ead01P0000AK?@00Gcd0009O?007001O?5ll001S?000Hc`00P0000ES?000
Hc]S>`00009S>`04001W>`00Ic/2000016Lk001W>`000VLk00@006LkIc]W>`80009W>P07001W>VLj
001W>P00IcX00P000VLj00L006LjIcX006Lj001W>P020002IaX00`00IaX00002IaX01P00IaX00000
IaX0009W6P06001W6P00IaX006LJ0P000VLJ00<006LJ00000VLJ00H006LJIaX006LJ0002IaX01@00
IaX006LJ00000VLJ00<006LJ00000VLJ00<006LJ00000VLJ00@006LJ001W6P<0009VnP09001VnVKj
001RnP00H_X006;j00800004H_X006;j0002H_X01P00H_X006;j001RnP800006H_X006;j001RnP00
0V;j00H006;j001RnP00H_X200000f;j00000002G]X00`00G]X00002G]X02000G]X005kJ001NfP00
G]X300003UkJ001NfP00F]X005[J001JfP00F]X005Zj0002F[X01000F[X005Zj0P0000]F^P00E[X0
05Jj001F^P00E[X005Jk0080000;D[/005:k001BV`00DY/005:K001BV`0200002DjK001>V`00CY/0
04jK001>V`0200001DjK001:V`00BY/00P0000=:V`00BY/00P0000=:V`00BY/01P0000I6N`000016
O000AW`200001DIl0016O000AY`00P0000=6W000AY`01P0000A2O0000012W0800005@Y`004:L0012
W00200000d:L0012W00500001d:L0012W000@Yd004:M00800008AYd00000AYd004Jm0016_@H00003
A[d004Zm0080000EB]d004[M001>g@00C]d004kM001>o@00D_d005;m001Bo@00D_d005Km00800003
Ead0000000@00004Fa`005/L0002Fa`02P00Fa`005lL001O7000Ga`005lL100000aO7000GaaO7000
Ha/006<K001S6`00Ha/50002Ha/00`00Ha]S6`020002Ha/300002F<K001S6f<K001S6`00Ha/00002
Ha/3000036<K001S6f<K001S6`00Ha/006<K001S6`<0009S6`07001S6P00HaX006<J00000V<J0`00
00aS6P00H_YRnP00H_X006;j001RnP00H_X300002f;j001RnV;j001RnP00H_X006;j00000V;j1P00
0Ukj00T005kj001NnP00G_X005kj00000Ukj1@0000iNfP00G]X005kJ001NfP00G]X005kJ001NfP00
0UkJ00<005kJ00001@0000QJfP00F]X005[J001JfP000U[J00P005[J001JfP00F[X005Zj0P0000IJ
^P00E[X005Jj0002E[X02000E[X005Jj001F^P00E[XG00005e:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/00P0001MB^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k0080000_D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001F^`00E[/005Jk001F^`00E[/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`020000
0eKK001Ff`03000035KK001Ff`00E]/005KK001Ff`00E]/0009Ff`06001Ff`00E]/005KK0P0000=F
f`0000001@0057oo00<007ooOol0;Woo002@Ool00`00Oomoo`1MOol01000D]`000000U;L00d005;L
000005;L001Bg000D]`005;L001Bg00200004E;L001Bg000D]`005;L001Bg000D]`005;L001Bg000
D]`00P0000UBg000D[`005:l001B_000D[`00P0000a>_000001>_000C[`004jl001>_000C[`20000
1djl001>_000C[`004jl00800003B[`004Zl00800003B[`004Zl00800003B[`0000000@00006AY`0
0000@Yd004:M0P0000A2W@00000nW@800003?Yd003jM00<00003>Wd003Ym00@00003>Wd003ZM00@0
0004=Yd00000>Yh200001cZN00000000@[h004;N00h00006Ead005LM001K?@000U/m00<005lm0000
0Ull00@005ll001S?0800005Hc`006<lHc`00002Hc/01000Hc/006Lk0P0000MW>`00Ic]W>`00Ic/0
0002Ic/01P00Ic/00000Ic/0009W>P04001W>P00IcX20002IcX01`00IcYW>P00IcX006Lj00800005
IcX006LJIaX00002IaX01P00IaYW6P00IaX0009W6P03001W6VLJ00800003IaX00000009W6P03001W
6P00009W6P04001W6P00IaX20002IaX00`00IaX00002IaX200000fLJ00000002IaX00`00IaX00002
IaX01000IaX006LJ0P0000IVnP00I_X006Kj0002I_X01000H_X006;j0P0000aRnP00H_YRnP00H_X0
06;j001RnP00H_X200003V;j001RnV;j001RnP00H_X006;j001RnP00H_X2000026;j001RnP00G]X0
05kJ0002G]X02000G]X005kJ001NfP00G]X300002UkJ001NfUkJ001NfP00F]X005[J0P000U[J00P0
05Zj001J^P00F[X005Zj0P000UJj0P0000]F^P00E[X005Jj001F^`00D[/005:k0080000=DY/005:K
001BV`00DY/004jK001>V`00CY/00P0000M>V`00CY/004jK001>V`0200002TZK000004ZK001:V`00
BY/004ZK0P0000=:V`00BY/01P0000I6O0000016O000AW`200001DJL0016W000AY`00P0000A6W000
0016W0H00003@Y`004:L00800005@Y`004:L0012W00200000d:L0012W00500001D:M0012W@00@Yd0
0P0000E6W@00AYd004Jm00800005A[d004Jm0016_@0900003DkM001>g@00C]d004km001Bo@00D_d0
05;m00L00006E_`005LL001K70000U/L00`005/L001K7000Fa`005lL001O7000Ga`2000015lL001O
70000UlL00P005lL001S6`00Ha/006<K0P0000IS6`00Ha/006<K0002Ha/01000Ha/006<K0`0000US
6`00Ha]S6`00Ha/006<K00000V<K0`0000aS6`00Ha]S6`00Ha/006<K001S6`00Ha/2000026<K001S
6`00Ha/006<J0002HaX00`00HaX0000200004F<J001S6V<J001RnP00H_X006;j001RnP00H_X006;j
00000V;j00L006;j001RnP00H_X00002H_X3000036;j001RnP00G_X005kj001NnP00G_X0009NnP03
001NnP000080000@G_X005kj001NfP00G]X005kJ001NfP00G]X005kJ0002G]X500001E[J001JfP00
F]X00P000U[J01H005[J001JfP00F]X005[J001JfP00F[X005Zj001J^P00F[X005Jj001F^P`0000C
E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00D[/00P0001MB^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k0080000_D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`0200006eJk001F^`00E[/005Jk001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`040002E]/02P00E]/005KK001Ff`00E]/005KK300000IFf`00E]/005KK000DOol0
0`00Oomoo`0^Ool0095oo`03001oogoo05aoo`0>001Bg000D]`005;L001Bg000D]`005;L001Bg080
0009D]`005;L001Bg000D]`005;L0080000?D]`005;L001Bg000D]`005;L001Bg000D]`005;L0080
0007D[`005:l001B_000D[`00P0000M>_000C[`004jl001>_00200001djl001>_000C[`004jl0080
0005C[`004Zl001:_00200001DZl001:_000B[`00`0000E6_000AY`004JL00D00003@Yd004:M0080
0006@Yd00000?Yd003jM0P0000LnW@00000003Ym000jO@0300001SYm000003ZM000jW@<00005>Yh0
03ZN000jWP0300005d:n000004KN0016gP00B_h004kn001>oP00Dah005<M001G7@00Ead005/m0000
0U/m00@005lm001O?0@00005Gc`006<lHc`00002Hc`01000Hc/006<k0P0000EW>`00Ic]W>`00009W
>`04001W>`00Ic/20002Ic/01P00Ic/006Lj001W>P800005IcX006LjIcX00002IcX01P00IcX00000
IcX0009W>P07001W6VLJ001W6P00IaX00P000VLJ00X006LJIaX006LJ001W6P00IaX0009W6P07001W
6VLJ001W6P00IaX00P000VLJ00<006LJ00000VLJ00D006LJ001W6P00009W6P03001W6P00009W6P04
001W6P00IaX2000016LJ001VnVKj0P000VKj00@006Kj001RnP80000<H_X006;jH_X006;j001RnP00
H_X006;j0P0000iRnP00H_YRnP00H_X006;j001RnP00H_X006;j0P0000IRnP00H_YRnP00H_X20002
G]X02000G]X005kJ001NfP00G]X300006UkJ001NfUkJ001NfP00G]X005[J001JfP00F]X005[J001J
^P00F[X005Zj001J^P00E[XP00001djK001>V`00CY/004jK00800007BY/004ZK001:V`00BY/00P00
00E:V`00BY/004ZK00<00003BY/004JL00@00007AW`004Il0016O000AY`00P0000E6W000AY`004JL
00<00003AY`004JL00@00005@Y`004:L0012W00200001D:L0012W000@Y`00`0000=2W00000000`00
00Q2W@000016W@00AYd004JM0P0000E6_@00A[d004Jm00800003B[d004Zm00800003B]d004[M00d0
0005D_d005;m001Fo@020002E_`01@00Ea`005/L00000U/L0P0000EK7000Fa`005lL00@0000>Ga`0
05lLGa`005lL001O7000Ga`006<K001S6`80000<Ha/006<KHa/006<K001S6`00Ha/006<K0`0000US
6`00Ha]S6`00Ha/006<K00000V<K0`0000US6`00Ha]S6`00Ha/006<K00000V<K0`0000AS6`00Ha]S
6`80009S6`03001S6P0000@00009HaX006<JHaX006<J001RnP00009RnPH0009RnP07001RnP00H_X0
06;j00000V;j0`0000ARnP00H_X0009RnP80009NnP80009NnPD00004G_X005kj0002G_X01000G]X0
05kJ0P0000INfP00G]YNfP00G]X300005UkJ001NfP00F]X005[J001JfP00F]X005[J001JfP00F]X0
05[J001JfP000U[J00D005Zj000005Zj00L0000;E[X005Jj001F^P00E[X005Jj001F^P0200003UJk
001F^`00E[/005Jk001F^`00E[/005Jk0002E[/06@00D[/00000D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k0080000GD[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`0200006E:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005Jk0080000>E[/005Jk001F^`00E]/005KK001Ff`00E]/0009Ff`06001Ff`00E]/005KK
0P0000EFf`00E]/005KK00d00007E]/005KK001Ff`00E]/00P0000AFf`00E]/0009Ff`03001Ff`00
01=oo`03001oogoo02ioo`00TGoo00<007ooOol0GGoo00P005;L001Bg000D]`005;L0P0000UBg000
D]`005;L001Bg000D]`00P0000UBg000D]`005;L001Bg000D]`00P0000=Bg000D]`0400000a>_000
001>_000C[`004jl001>_000C[`200001djl001>_000C[`004jl00800005B[`004Zl001:_0020000
0dZl001:_00200000dJl0016W002000014JL000004JM100000=2W@00@Yd00P0000PnW@00000nW@00
?Yd003jM100000@jO@00000jO@800004>Yd00000>Yd500000cZN000n_P0200006T:n000004KN0016
gP00B_h004kn001>oP00Dah005<M001G7@00Ead005/m001K?@00Gcd2000015ll001O?0000Ull00L0
06<lHc`006<l001S>`0200001F<k001W>fLk00000VLk00@006Lk001W>`800003Ic/006Lk009W>`07
001W>`00IcX006Lj00000VLj00@006LjIcX0009W>P03001W>P00009W>P07001W>VLj001W6P00IaX0
0P000VLJ00<006LJ00000VLJ00<006LJ00000P000VLJ00L006LJIaX006LJ001W6P0200001FLJ001W
6VLJ00000VLJ00@006LJ001W6P<0009W6P07001W6VLJ001W6P00IaX00P0000aW6P00IaYW6P00I_X0
06Kj001VnP00I_X2000036;j001RnV;j001RnP00H_X006;j001RnP800007H_X006;jH_X006;j0000
0V;j0P0000=RnP00H_X00P00011RnP00H_YRnP00H_X006;j001NfP00G]X005kJ001NfP@00008G]X0
05kJ001NfP00G]X0009NfP0=001NfP00001JfP00F]X005[J001J^P00F[X01`0000]F^P00E[X005Jj
001F^P00E[/005Jk0080000;D[/005:k001B^`00DY/005:K001BV`0200001DjK001>V`00CY/02000
00=:V`00BY/00P0000M:V`00BY/004ZK001:V`0200000dZK001:V`0200001TZK000004JL0016W0H0
0008AY`00000AY`004JL0016W0800003AY`004JL00800003AY`004JL00@0000:@Y`00000@Y`004:L
0012W000@Y`300000dJL0016W00600001dJM0016W@00A[d004Jm00800007A[d004Jm001:_@00B[d0
0P0000m:g@00001>g@00C]d004kM001>o@00D_d005;m00000U;m00@005;m001Fo@80009Fo006001G
7000Fa`005/L0P0000=K700000000P0000AO7000Ga`0009O7007001O7000Ga`005lL00000UlL0`00
00aS6`00Ha]S6`00Ha/006<K001S6`00Ha/200000f<K00000002Ha/00`00Ha]S6`020002Ha/30000
2F<K001S6f<K001S6`00Ha/00002Ha/300004F<K001S6f<K001S6`00Ha/006<K001S6P00HaX006<J
00000V<J00D006<J001S6P00009RnP<0000:H_X006;j001RnP00H_X006;j0002H_X00`00H_X00002
000016;j001RnP000V;j00P006;j001NnP00G_X005kj0`0000INnP00G_X005kj0002G_X02P00G_X0
05kJ001NfP00G]X005kJ1@0000INfP00G]X005kJ0002F]X01000F]X005[J0P0000IJfP00F]X005[J
0002F]X00`00F]X0000700009EZj001F^P00E[X005Jj001F^P00E[X005Jj001F^P00E[X005Jk001F
^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005:k0080000GD[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`0200005e:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/00P0002MB^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005Jk001F^`00E[/005Jk001F^`00E]/005KK001Ff`00E]/0400001iFf`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK000COol00`00Oomoo`0^
Ool0099oo`03001oogoo05aoo`06001Bg000D]`005;L7@0000MBg000D]`005;L001Bg00200001e:l
001B_000D[`005:l01@00005C[`004Zl001:_00200001DZl001:_000B[`00P0000Q:_0000016W000
AY`004JL0`0000=2W@00@Yd01@0000DnW@00?Yd003jM00@00003>Yd003ZM00D00003>Yd003ZM0080
0005>Yd003ZN000n_P0600004T:n000004KN0016gP00B_h004kn001>oP00Dah005<M001G7@800003
Fcd0000000800007Fcd005llGc`005ll00000Ull00@006<l001S?0800005Hc`006<kHc/00002Ic/0
1000Ic/006Lk0P0000EW>`00Ic]W>`00009W>`03001W>`000080009W>P07001W>VLj001W>P00IcX0
0P000VLj00L006LjIcX006Lj001W6P0200001FLJ001W6VLJ00000VLJ00P006LJIaX006LJ001W6P00
0VLJ00@006LJ001W6P800005IaX006LJIaX00002IaX01000IaX006LJ0P0000AW6P00IaX0009W6P04
001W6P00IaX2000036LJ001W6VLJ001W6P00I_X006Kj001VnP800007H_X006;jH_X006;j00000V;j
00<006;j00000P0000MRnP00H_YRnP00H_X00002H_X01000H_X006;j0`0000MRnP00H_YRnP00H_X0
0002H_X200001EkJ001NfP00G]X00P0000YNfP00G]X005kJ001NfP00G]X0009NfP08001NfP00G]X0
05[J001JfP800003F]X0000000800005F[X005Zj001J^P020002E[X01000E[X005Jj0P0000eF^`00
E[/005:k001B^`00D[/005:k001BV`0200001e:K001>V`00CY/004jK00800007CY/004jK001>V`00
CY/01`0000E:V`00BY/004ZK00800003BY/004ZK00800005BY/004JL0016W00200001DJL0016W000
AY`0100000I6W0000016W000AY`200001DJL0016W000AY`00P0000=6W000AY`0100000I2W0000012
W000@Y`200000d:L0016W00200001DJM0016W@00AYd01P0000i6_@000016_@00A[d004Zm001:_@00
B]d004[M0P0001]>g@00C]d004kM001>o@00D_d005;m001Bo@00D_d005Km001Fo@00E_`005LL001K
7000Fa`00`0000AK7000Fa`0009O700:001O7000Ga`005lL001O7000Ga`4000035lK001S6f<K001S
6`00Ha/006<K001S6`800004Ha/006<KHa/20002Ha/01000Ha/006<K0`0000US6`00Ha]S6`00Ha/0
06<K00000V<K0`0000aS6`00Ha]S6`00Ha/006<K001S6`00Ha/30002HaX01`00HaX006<J001S6P00
009S6P<00004H_X006;j0002H_X20002H_X00`00H_X0000400005F;j001RnV;j001RnP00H_X006;j
001NnP00G_X005kj001NnP00G_X00002G_X03000G_X005kj001NnP00G]X005kJ001NfP<00006G]X0
05kJ001NfP000UkJ00P005kJ001JfP00F]X005[J0P000U[J00@005[J001JfPD00007F]X005Zj001J
^P00F[X00P0000AF^P00E[X0009F^P0:001F^P00E[X005Jj001F^P00E[X200004eJk001F^`00E[/0
05Jk001F^`00E[/005Jk001F^`00D[/005:k0080000ED[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k0080000_D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0B0000
1eKK001Ff`00E]/005KK00800008E]/005KK001Ff`00E]/0009Ff`0:001Ff`00E]/005KK001Ff`00
E]/200003UKK001Ff`00E]/005KK001Ff`00E]/005KK000COol00`00Oomoo`0^Ool0099oo`03001o
ogoo05eoo`D00003D]`005;L00800009D]`005;L001Bg000D]`005;L00800009D]`005;L001Bg000
D]`005;L0080000:D]`005;LD]`005;L001Bg000D]`200001E:l001B_000D[`00P0000aB_000001>
_000C[`004jl001>_000C[`200001Djl001>_000C[`02`0000=:_000B[`00P0000E6_000AY`004JL
00800004AY`00000@Yd200000d:M0012W@0500000cjM000nW@0300001SZM000003ZM000jW@<00007
>Yd003ZM000jW@00>Yh00P0000Dn_P00?[h004:n00L00005B_h004kn001>oP09000015/M001K?@00
0U/m00T005llGc`005ll001O?000Hc`00P0000ES?000HcaS?000009S>`04001W>`00Ic/200001FLk
001W>fLk00000VLk00P006Lk000006Lk001W>`000VLj00@006Lj001W>P80009W>P07001W>VLj001W
>P00IcX00P0000EW6P00IaYW6P00009W6P04001W6P00IaX20002IaX20002IaX01P00IaX00000IaX0
009W6P07001W6VLJ001W6P00IaX00P0000AW6P00IaYW6P80009W6P06001W6VLJ001W6P000VLJ00<0
06LJ00000VLJ00<006Kj00000P0000MRnP00H_YRnP00H_X00002H_X01`00H_X006;j001RnP00009R
nP03001RnP00009RnP09001RnP00H_X006;j001RnP00009RnP03001RnP00009RnP04001RnP00H_X5
000055kJ001NfUkJ001NfP00G]X005kJ001NfP00G]X005kJ001NfP00F]X500005e[J001J^P00F[X0
05Zj001J^P00E[X005Jj001F^P00E[X005Jj001F^`00E[/00P0000]B^`00D[/005:k001BV`00DY/0
05:K00800007CY/004jK001>V`00CY/00P0000=>V`00CY/00P0000E:V`00BY/004ZK00H00003BY/0
04ZK00800003BY/004ZK00800005AY`004JL0016W00200000dJL0016W00600001TJL000004JL0016
W0800005AY`004JL0016W00200000dJL0000000400001T:L000004:L0012W0800005AY`004JM0016
W@0200001DJm0016_@00A[d01`0000m:_@00B[d004[M001:g@00B]d004kM001>g@00C]d00P0000eB
o@00D_d005;m001Bo@00E_d005Km001Fo00600000e/L00000002Fa`00`00Fa`00002Ga`01000Ga`0
00000UlL0`0000AO7000Ga`0009O6`05001S6`00Ha/00002Ha/3000036<K001S6f<K001S6`00Ha/0
06<K001S6`<00009Ha/006<KHa/006<K001S6`00009S6`<00009Ha/006<KHa/006<K001S6`00009S
6`<0000:Ha/006<K001S6P00HaX006<J0002HaX300004f;j001RnV;j001RnP00H_X006;j001RnP00
H_X006;j001RnP00009RnP07001RnP00H_X006;j00000V;j1P0000]NnP00G_YNnP00G_X005kj001N
nP00009NnP03001NfP0000<00004G]X005kJ0002G]X03P00G]X005kJ001NfP00F]X005[J001JfP00
F]X700007E[J001JfP00F]X005Zj001J^P00F[X005Zj001F^P00E[X005Jj001F^P00E[X005Jj001F
^P00E[X00P0000iF^`00E[/005Jk001F^`00E[/005Jk001F^`000UJk01T005:k000005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`0200005e:k001B^`00D[/005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/06`0003=F^`00E[/005Jk001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/00P0000AFf`00E]/0009Ff`03001Ff`00019oo`03001oogoo02ioo`00Tgoo
00<007ooOol0G7oo00D005;L001Bg000009Bg00=001Bg000001Bg000D]`005;L001Bg000D]`00P00
00UBg000D]`005;L001Bg000D]`00P0000eBg000D]`005;L001Bg000D]`005:l001B_00200001E:l
001B_000D[`00P0000U>_000C[`004jl001>_000C[`00P0000=>_000C[`00P0000E>_000C[`004Zl
00800003B[`004Zl00L00005AY`004JL0016W002000034JM000004:M0012W@00@Yd004:M000nW@@0
0004?Yd00000>Yd200001CZM00000000>Yd0100000@jW@00000jWP800003?[h003jn00800006@]h0
0000A]h004[n1@0000i>o@00Dad005<M001G7@00Ead005/M001K?@000U/m00@005ll001O?0@00005
Hc`006<lHc`00002Hc`01000Hc/006Lk0P0000EW>`00Ic]W>`00009W>`06001W>fLk001W>`000VLk
00<006Lk00000VLj00D006Lj001W>P00009W>P05001W>VLj001W>P0200001FLJ001W6VLJ00000VLJ
00@006LJ001W6P80009W6P05001W6P00IaX00002IaX00`00IaX00002IaX00`00IaX00002IaX01P00
IaX00000IaX0009W6P08001W6P00IaX006LJ001W6P80009W6P03001W6P00009W6P07001W6P00I_X0
06;j00000V;j00<006;j00000V;j00@006;j001RnP<0009RnP03001RnP00009RnP06001RnP00H_X0
06;j0`000V;j00<006;j00000V;j00/006;j001RnP00H_X005kJ001NfP00009NfP0>001NfP00G]X0
05kJ001NfP00G]X005kJ001NfPD00004F]X005[J0002F]X02000F[X005Zj001J^P00F[X20002E[X0
1000E[X005Jj0P0000eF^`00E[/005:k001B^`00D[/005:k001BV`0200001e:K001>V`00CY/004jK
00800007CY/004jK001>V`00CY/00P0000=:V`00BY/00P0000E:V`00BY/004ZK00L00005BY/004JL
0016W00200002dJL0016W000AY`004JL0016W000AY`01P0000E6W000AY`004JL00800009AY`004JL
0016W000AY`004JL00H00007@Y`004JL0016W000AYd00P0000E6W@00A[d004Jm00800004A[d00000
B[d<00001DkM001>g@00C]d00P0000=Bo@00D_d02P0000IFo000Ea`005/L0002Fa`20002Fa`02000
Fa`005lL001O7000Ga`3000035lL001O75lL001O7000Ga/006<K001S6`@0000<Ha/006<KHa/006<K
001S6`00Ha/006<K0P0000IS6`00Ha/006<K0002Ha/200000f<K0000000200002F<K001S6f<K001S
6`00Ha/00002Ha/3000016<K001S6f<K0P000V<J0P000V<J0`0000iRnP00H_YRnP00H_X006;j001R
nP00H_X006;j0`000V;j00T006;j001RnP00H_X006;j00000V;j0`0000iNnP00G_X005kj001NnP00
G_X005kj001NnP000Ukj1@00011NfP00G]X005kJ001NfP00G]X005kJ001NfP00G]X0009JfP03001J
fP0000<0000:F]X005[J001JfP00F]X005[J0002F]X01P00F[X005Zj001J^P80000OE[X005Jj001F
^P00E[X005Jj001F^P00E[X005Jj001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/0=P0001MB
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001F^`00E[/005Jk00800004E[/005Jk0002
E[/03000E]/005KK001Ff`00E]/005KK001Ff`80000UE]/005KK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/01@004Woo00<007oo
Ool0;Woo002DOol00`00Oomoo`1LOol03000D]`005;L001Bg000D]`005;L001Bg0800009D]`005;L
001Bg000D]`005;L0080000AD]`005;L001Bg000D]`005;L001Bg000D]`005;L001Bg00200001E:l
001B_000D[`00P0000EB_000C[`004jl00800009C[`004jl001>_000C[`004jl00800007C[`004jl
001>_000B[`00P0000Q:_000001:_000B[`004Zl1`0000=6W000AYd00P0000A2W@000012W@800006
@Yd00000?Yd003jM1@0000<jW@00>Yd0100000<jW@00?Yd0100000HjWP00000n_P00?[h2000014;N
000004KN0P0000A:oP00C_h0009>o@0@001C7@00Dad005LM001G7@00Fad005/m001K?@00Gc`20000
15ll001O?0000V<l00L006<lHc`006<l001S>`0200001F<k001W>fLk00000VLk00@006Lk001W>`80
009W>`07001W>fLk001W>`00IcX00`000VLj00@006LjIcX0009W>P03001W6P00009W6P07001W6VLJ
001W6P00IaX00P0000EW6P00IaYW6P00009W6P800003IaX00000009W6P03001W6P00009W6P06001W
6VLJ001W6P000VLJ00P006LJ001W6P00IaX006LJ0P000VLJ00<006LJ00000VLJ00@006LJ001W6P<0
009RnP03001RnP00009RnP04001RnP00H_X200001V;j001RnP00H_X0009RnP04001RnP00H_X40000
1V;j001RnP00H_X0009RnP06001RnP00H_X006;j0`000UkJ00D005kJ001NfP00009NfP800007G]X0
05kJ001NfP00G]X00P0001]NfP00F]X005[J001JfP00F]X005[J001J^P00F[X005Zj001J^P00E[X0
05Jj001F^P00E[X00P0000eF^`00E[/005:k001B^`00D[/005:k001BV`0200002e:K001>V`00CY/0
04jK001>V`00CY/00P0000=>V`00CY/00P0000E:V`00BY/004ZK00800003BY/004ZK00800003BY/0
04ZK00@00005AY`004JL0016W00200001DJL0016W000AY`00P0000Q6W0000016W000AY`004JL1000
00Q6W0000016W000AY`004JL0P0000Q6W0000016W000AY`004JL100000=6W000AYd00P0000U6W@00
A[d004Jm0016_@00A[d00`0000]:_@00B[d004[M001:g@00B]d004kM00X0000:D_d005;m001Bo@00
E_d005Km0002E_`03P00Ea`005/L001K7000Fa`005/L001K7000Ga`500001ElL001O75lL00000UlL
0P0000=O6`00Ha/00P0000AS6`00Ha/0009S6`05001S6`00Ha/00002Ha/3000016<K001S6f<K0P00
0V<K00T006<K001S6`00Ha/006<K00000V<K00D006<K001S6`00009S6`<0000<Ha/006<KHa/006<K
001S6`00HaX006<J0`0000]RnP00H_YRnP00H_X006;j001RnP00009RnP<0000:H_X006;j001RnP00
H_X006;j0002H_X00`00H_X00002000015kj001NnP000Ukj0P0000ANnP00G_X0009NnP03001NnP00
0080000@G]X005kJ001NfP00G]X005kJ001NfP00G]X005kJ0002G]X00`00G]X0000400002E[J0000
05[J001JfP00F]X00002F]X02P00F]X005[J001J^P00F[X005Zj0P0000AF^P00E[X0009F^P08001F
^P00E[X005Jj001F^Q800005E[/005Jk001B^`0200004e:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k0080000GD[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`0200002U:k001B^`00D[/005:k001B^`000U:k00P005:k001B^`00D[/005Jk0P0001]F^`00
E[/005Jk001F^`00E[/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00P0000QFf`00
E]/005KK001Ff`000UKK00X005KK001Ff`00E]/005KK001Ff``00004E]/005KK000BOol00`00Oomo
o`0^Ool009Aoo`03001oogoo05eoo`800006D]`005;LD]`005;L0P0000UBg000D]`005;L001Bg000
D]`00P0000UBg000D]`005;L001Bg000D]`00P0000eBg000D]`005;L001Bg000D]`005:l001B_002
00001E:l001B_000D[`00P0000U>_000C[`004jl001>_000C[`00P0000E>_000C[`004jl00800005
C[`004Zl001:_00200001DZl001:_000B[`00`0000E6_000A[`004JL00D00005@Yd004:M0012W@02
000014:M000003jM0P0000<nW@00?Yd00`0000<jW@00>Yd00`0000HjW@00000nW@00?Yd500001Cjn
0012_P00@]h00P0000M6gP00001:oP00C_h00002C_d03000Dad005<M001G7@00Ead005/M001K?@<0
009O?005001O?000Gc`00002Hc`01000Hc`006<l0P0000ES>`00Hc]S>`00009W>`04001W>`00Ic/2
0002Ic/01`00Ic]W>`00Ic/006Lk00800004Ic/006Lj0002IcX01000IcX006Lj0P000VLJ00L006LJ
IaX006LJ001W6P0200001FLJ001W6VLJ00000VLJ00D006LJ001W6P00009W6P03001W6P00009W6P04
001W6P00IaX20002IaX00`00IaX00002IaX00`00IaX0000200001FLJ001W6VLJ00000VLJ00@006LJ
001W6P800006H_X006;j001RnP000V;j00@006;j001RnP800004H_X006;jH_X20002H_X01000H_X0
06;j0P0000ARnP00H_X0009RnP80009RnP06001RnP00H_X006;j0P0000QRnP00G_X005kJ001NfP00
0UkJ00H005kJ001NfP00G]X5000015kJ001NfUkJ0P0000IJfP00F]X005[J0002F]X05@00F[X00000
F[X005Zj001F^P00E[X005Jj001F^P00E[X005Jk001F^`0200002e:k001B^`00D[/005:K001BV`00
DY/00P0000M>V`00CY/004jK001>V`0200002DjK001>V`00CY/004ZK001:V`0200001DZK001:V`00
BY/00P0000I:V`00001:V`00BY/600001TJL000004JL0016W0800007AY`004JL0016W000AY`00P00
00=6W000AY`0100000I6W0000016W000AY`200001DJL0016W000AY`00P0000=6W000AY`01`0000M6
_@00A[d004Jm0016_@0200002dZm001:_@00B[d004[M001:g@00B]d00P0000E>g@00C]d004kM0080
000HD_d005;mD_d005;m001Bo@00E_d005Km001Fo000Ea`005/L001K7000Fa`005/L100000QK7000
Ga`005lL001O70000UlL00D005lL000005lK0080000;Ga/006<KHa/006<K001S6`00Ha/00002Ha/3
000036<K001S6f<K001S6`00Ha/006<K001S6`<0009S6`07001S6`00Ha/006<K00000V<K0`0000aS
6`00Ha]S6`00Ha/006<K001S6`00HaX300002F<J001RnV;j001RnP00H_X00002H_X00`00H_X00002
000016;j001RnV;j0P000V;j0P000V;j1@0000ANnP00G_X0009NnP04001NnP00G_X20002G_X50000
15kj001NfP000UkJ00H005kJ001NfP00G]X20002G]X00`00G]X0000400007e[J001JfP00F]X005[J
001JfP00F]X005[J001JfP00F]X005[J001J^P00F[X005Zj001J^P00E[X005Jj00/0000FE[/00000
E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00D[/200004e:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k0080009B^`0D001B^`00D[/005:k001B^`00D[/005:k001B^`00
D[/005:k001B^`80000ED[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005Jk0080
000OE[/005Jk001F^`00E[/005Jk001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`00E]/00`0000=Ff`00E]/03P0000YFf`00E]/005KK001Ff`00E]/0009Ff`03001Ff`00015oo`03
001oogoo02ioo`00UGoo00<007ooOol0G7oo00`005;L001Bg000D]`005;L001Bg000D]`200002E;L
001Bg000D]`005;L001Bg00200002E;L001Bg000D]`005;L001Bg00200000e;L001Bg00<00001E:l
001>_000C[`00P0000U>_000C[`004jl001>_000C[`00P0000M>_000C[`004jl001:_002000024Zl
000004Zl001:_000B[`200000dJl0016_00200000dJL0016W@0500000d:M0012W@0200001SjM0000
03jM000nW@<00003?Yd0000000800004>Yd00000>Yd2000013jM000003jn0P0000=2_P0000001000
00=6gP00A]h00P0000]:oP00C_h004km001C7@00Dad005LM00L0009K?009001O?5ll001O?000Gc`0
06<l00@00005Hc`006<kHc/00002Hc/01000Ic/006Lk0P0000=W>`00Ic/00VLk00@006Lk001W>`80
000:Ic/006LkIc/006Lj001W>P00IcX20002IcX00`00IaX00002IaX01P00IaX00000IaX0009W6P07
001W6VLJ001W6P00IaX00`000VLJ00L006LJIaX006LJ001W6P020002IaX00`00IaX00002IaX01`00
IaX006LJ001W6P00009W6P07001W6VLJ001W6P00IaX00P0000ARnP00H_YRnP80009RnP04001RnP00
H_X2000036;j001RnV;j001RnP00H_X006;j001RnP80000@H_X006;jH_X006;j001RnP00H_X006;j
001RnP00H_X200001V;j001RnP00G_X0009NfP08001NfP00G]X005kJ001NfP<00004G]X005kJ0002
G]X05000G]X005[J001JfP00F]X005[J001JfP00F[X005Zj001J^P00F[X200000eJj0000000O0000
1DjK001>V`00CY/00P0000E:V`00BY/004ZK00800003BY/004ZK00800005BY/004ZK001:V`020000
1DZL001:W000BY`0100000=6W000AY`00P0000Y6W0000016W000AY`004JL0016W0800003AY`00000
00@00006AY`00000AY`004JL0P0000E6W000AY`004JL00800003AY`004JL00T0000;A[d004Jm001:
_@00B[d004Zm001:g@0200002D[M001>g@00C]d004kM001>g@02000025;m001BoE;m001Bo@00D_d2
00002EKm001Fo000Ea`005/L001K7004000015/L001K70000U/L00X005lL001O7000Ga`005lL001O
70<0000<Ga/005lKGa/006<K001S6`00Ha/006<K100000aS6`00Ha]S6`00Ha/006<K001S6`00Ha/2
00001V<K001S6`00Ha/0009S6`80009S6`<00009Ha/006<KHa/006<K001S6`00009S6`<00003Ha/0
0000009S6P05001RnP00H_X00002H_X5000036;j001RnV;j001RnP00H_X006;j001RnP<00004G_X0
05kj0002G_X02P00G_X005kj001NnP00G_X005kj0`0000INnP00G_X005kj0002G]X02P00G]X005kJ
001NfP00G]X005kJ1@0000QNfP00F]X005[J001JfP000U[J0P0000YJfP00F]X005[J001JfP00F]X0
009JfP04001J^P00F[X800003EJj001F^P00E[X005Jj001F^P00E[/005Jk00800008E[/005Jk001F
^`00E[/0009F^`08001F^`00E[/005Jk001B^`80000CD[/005:k001B^`00D[/005:k001B^`00D[/0
05:k001B^`00D[/00P0001EB^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
0P0001UB^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00E[/005Jk001F^`020000
15Jk001F^`000UJk00`005KK001Ff`00E]/005KK001Ff`00E]/@000075KK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`004Woo00<007ooOol0;Goo002EOol0
0`00Oomoo`1MOol200001E;L001Bg000D]`07`0000MBg000D]`005;L001Bg00200000e:l001B_00F
00001Djl001:_000B[`00P0000M:_000B[`004Zl001:_002000034Jl000004JL0016W000AYd004JM
0012W@L00003?Yd003jM00800007?Yd00000000nW@00?Yd01@0000<nW@00?Yd00P0000Tn_P000000
04:n0012gP00A]h0400000QG7@00Ead005/M001K7@000U/l00<005llGc`00P0000MO?000001S?000
Hc`00002Hc`01`00Hc]S>`00Hc/006Lk00800005Ic/006LkIc/00002Ic/01P00Ic/00000Ic/0009W
>`0:001W>fLk001W>P00IcX006Lj0002IcX01000IaYW6P000VLJ00<006LJ00000VLJ00L006LJIaX0
06LJ001W6P02000016LJ001W6P000VLJ00@006LJ001W6P800005IaX006LJIaX00002IaX01000IaX0
06LJ0`000VLJ00<006LJ00000VLJ00H006LJ000006LJ0002H_X02000H_X006;j001RnP00H_X20000
36;j001RnV;j001RnP00H_X006;j001RnP80000>H_X006;jH_X006;j001RnP00H_X006;j001RnP@0
0004H_X006;j0002H_X02P00G_X005kJ001NfP00G]X005kJ0`0000UNfP00G]YNfP00G]X005kJ0000
0UkJ0P0000]JfP00F]X005[J001JfP00F[X005Zj00L00005E[X005Jj001F^P0200003EJk001F^`00
D[/005:k001B^`00D[/005:k0080000;DY/005:K001>V`00CY/004jK001>V`0700001DZK001:V`00
BY/00P0000M:V`00BY/004ZK001:V`0200001DZK001:V`00BY`00P0000A:W0000016W0H00007AY`0
04JL0016W000AY`00P0000U6W000AY`004JL0016W000AY`01P0000E6W000AY`004JL0080000=AY`0
04JL0016W000AY`004Jm0016_@00A[d01P0000M:_@00B[d004Zm001:g@0200004d[M001>g@00C]d0
04kM001>g@00D_d005;m001Bo@00D_d005;m00800003E_d005Kl00H00004Fa`005/L0002Fa`03000
Fa`005/L001O7000Ga`005lL001O70800003Ga`00000009O6`03001O6elK00800003Ha/006<K0080
0004Ha/006<K0002Ha/01@00Ha/006<K00000V<K0`0000AS6`00Ha]S6`80009S6`04001S6`00Ha/3
00002F<K001S6f<K001S6`00Ha/00002Ha/3000016<K001S6f<K0P0000AS6P00H_X0009RnP<00004
H_X006;j0002H_X03`00H_X006;j001RnP00H_X006;j001RnP00G_X00002G_X01`00G_X005kj001N
nP00009NnP@00004G_X005kj0002G_X05`00G_X005kJ001NfP00G]X005kJ001NfP00G]X005kJ001N
fP00G]X005[J00000U[J00H005[J001JfP00F]X2000015[J001JfP000U[J00<005[J00001P00015J
^P00001F^P00E[X005Jj001F^P00E[X005Jj001F^P00009F^`80000CE[/005Jk001F^`00E[/005Jk
001F^`00E[/005Jk001F^`00D[/00P0001=B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`0200005e:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P00
00YB^`00D[/005:k001B^`00D[/0009B^`08001B^`00D[/005:k001F^`800007E[/005Jk001F^`00
E[/0400000iFf`00E]/005KK001Ff`00E]/005KK001Ff`000UKK01X005KK000005KK001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`004Woo00<007ooOol0;Goo002FOol00`00Oomo
o`1MOol600001E;L001Bg000D]`00P0000UBg000D]`005;L001Bg000D]`00P0000UBg000D]`005;L
001Bg000D]`00P0000YBg000D]aBg000D]`005;L001Bg0800008D[`00000D[`004jl001>_0800009
C[`004jl001>_000C[`004jl00800003C[`004jl00T00005B[`004Zl001:_00200001DJl0016_000
AY`00P0000A6W@000016W@800005@Yd004:M0012W@0300001CjM000nW@00?Yd00`0000HnW@00000n
W@00?Yd300001CjM000nW@00?[h00`0000=2_P00@]h00P0000=6gP00B]h00P0000Y>oP00C_d004km
001C7@00Dad0009G7@07001G7@00Fad005/M00000U/l00<005ll00000P0000MO?000HcaS?000Hc`0
0002Hc`00`00Hc/0000300001F<k001W>fLk00000VLk00H006Lk000006Lk0002Ic/01`00Ic]W>`00
Ic/006Lj00<0009W>P07001W>VLj001W6P00IaX00P000VLJ00L006LJIaX006LJ001W6P0200002VLJ
001W6VLJ001W6P00IaX006LJ0P0000EW6P00IaYW6P00009W6P04001W6P00IaX200001VLJ001W6P00
IaX0009W6P06001W6VLJ001W6P000VLJ00P006;j001RnP00H_X006;j0P0000MRnP00H_YRnP00H_X0
0002H_X00`00H_X0000200001f;j001RnV;j001RnP00009RnP80009RnP<00004H_X006;j0002H_X0
3000H_X006;j001NnP00G]X005kJ001NfP80000:G]X005kJ001NfP00G]X005kJ0002G]X02`00G]X0
0000F]X005[J001JfP00F]X01@0000IJ^P00F[X005Jj0002E[X200002eJj001F^P00E[/005Jk001B
^`00D[/00P0000]B^`00D[/005:K001BV`00DY/004jK00800003CY/004jK00800005CY/004jK001>
V`0800000dZK001:V`0200001DZK001:V`00BY/00P0000E:W000BY`004ZL00<00005AY`004JL0016
W00400000dJL0016W00200001DJL0016W000AY`00P0000Q6W0000016W000AY`004JL100000Y6W000
0016W000AY`004JL0016W0800003A[d004Jm00800005A[d004Zm001:_@0=00002dkM001>g@00C]d0
05;m001Bo@00D_d02@0000IFo000E_`005/L0002Fa`03000Fa`005/L001K7000Fa`005lL001O70@0
0004Ga`005lLGa`20002Ga/01000Ga/006<K0`0000]S6`00Ha]S6`00Ha/006<K001S6`00009S6`<0
000<Ha/006<KHa/006<K001S6`00Ha/006<K0`0000US6`00Ha]S6`00Ha/006<K00000V<K0`0000IS
6`00Ha]S6`00Ha/20002HaX00`00H_X00002000016;j001RnP000V;j00D006;j001RnP00009RnP80
0006H_X00000001RnP000Ukj00L005kj001NnP00G_X00002G_X300000ekj00000002G_X02@00G_X0
05kj001NnP00G]X00002G]X00`00G]X00005000015kJ001NfP000UkJ010005[J001JfP00F]X005[J
001JfP00F]X005[J001JfPD00007F]X005Zj001J^P00F[X00P0000AF^P00E[X0009F^P0<001F^P00
E[X005Jj001F^P00E[/005Jk0P00015F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005:k0080
000CD[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P000U:k01@005:k001B^`00
D[/005:k001B^`00D[/005:k001B^`00D[/005:k0P0000]B^`00D[/005:k001B^`00D[/005:k01@0
000=E]/005KK001Ff`00E]/005KK001Ff`00E]/00P0000QFf`00E]]Ff`00E]/005KK0`0000MFf`00
E]/005KK001Ff`0200004UKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0009Ff`03001F
f`00015oo`03001oogoo02eoo`00UWoo00<007ooOol0GGoo0P0000ABg000D]`0009Bg004001Bg000
D]`200002E;L001Bg000D]`005;L001Bg00200002E;L001Bg000D]`005;L001Bg00200003E;L001B
g000D]`005;L001Bg000D[`005:l00800005D[`004jl001>_00200002Djl001>_000C[`004jl001>
_002000024jl000004jl001>_000B[`200000dZl00000006000024Jl000004JL0016W000AYd20000
1TJM000004:M0012W@<00003@Yd0000000800004?Yd00000?Yd200000cjM000nW@0300000cjM0000
000200000cjn000n_P0200000d:n0012gP0200000dKN001:gP0200002Tkn001>o@00C_d005<M001C
7@000ULM00P005LM001K7@00Fad005/l0P0000IO?000Gc`005ll0002Hc`01000Hc`006<l0P0000AS
>`00Hc/0009S>`05001W>fLk001W>`0200001FLk001W>fLk00000VLk00@006Lk001W>`800004Ic/0
06Lj0002IcX01000IcX006LJ0P000VLJ00<006LJ00000VLJ00H006LJ000006LJ0002IaX00`00IaYW
6P0200001FLJ000006LJ00000VLJ00L006LJIaX006LJ001W6P02000016LJ001W6VLJ0P000VLJ00@0
06LJ001W6P80009W6P03001W6P00009RnP03001RnP0000800007H_X006;jH_X006;j00000V;j00L0
06;j001RnP00H_X00002H_X00`00H_X00002H_X01000H_X006;j0`00011RnP00H_YRnP00H_X006;j
001RnP00H_X005kj001NfP@00008G]X005kJ001NfP00G]X0009NfP08001NfP00G]X005kJ001JfPL0
000AF]X005[J001J^P00F[X005Zj001F^P00E[X005Jj001F^P0200003EJk001F^`00D[/005:k001B
^`00D[/005:k0080000;DY/005:K001>V`00CY/004jK001>V`0200000djK001>V`0200001DjK001>
V`00BY/01`0000M:V`00BY/004ZK001:V`0200000dZL001:W00200001DJL0016W000AY`00P0000=6
W000AY`01P0000A6W0000016W0800007AY`004JL0016W000AY`00P0000=6W000AY`01`0000M6W000
AY`004JM0016_@0200001DJm0016_@00B[d00P0000M:_@00B[d004Zm001:g@0200000dkM0000000;
00001E;m001Bo@00E_d00P00019Fo000E_aFo000E_`005/L001K7000Fa`005/L001K7000Fa`40000
15lL001O70000UlL00P005lL001O7000Ga/005lK0`0000aO6`00Ha]S6`00Ha/006<K001S6`00Ha/4
000036<K001S6f<K001S6`00Ha/006<K001S6`80000:Ha/006<K001S6`00Ha/006<K0002Ha/30000
4F<K001S6f<K001S6`00Ha/006<K001S6P00H_X006;j00000V;j00L006;j001RnP00H_X00002H_X5
00002V;j001RnP00H_X005kj001NnP000Ukj00<005kj00000P0000iNnP00G_X005kj001NnP00G_X0
05kj001NnP000UkJ1@00019NfP00G]X005kJ001NfP00G]X005kJ001JfP00F]X005[J0002F]X20000
0e[J0000000300002U[J001JfP00F]X005Zj001J^P000UZj0P00015F^P00E[X005Jj001F^P00E[X0
05Jj001F^P00E[/005Jk00800008E[/005Jk001F^`00E[/0009F^`08001F^`00E[/005Jk001B^`80
000CD[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/09@0000UF^`00E[/005Jk001F
^`00E[/00P0000aF^`00E[/005Jk001F^`00E]/005KK0002E]/01000E]/005KK0P0002UFf`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK00D0015oo`03001oogoo02eoo`00Ugoo00<007ooOol0GGoo0P0000eBg000
D]`005;L001Bg000D]`005;L001Bg00200002E;L001Bg000D]`005;L001Bg00200004E;L001Bg000
D]`005;L001Bg000D]`005;L001Bg000D]`00P0000=B_000D[`00P0000M>_000C[`004jl001>_002
00002Djl001>_000C[`004jl001>_00200001Djl001>_000B[`00`0000M:_000B[`004Zl001:_007
00001TJM000004JM0012W@800003@Yd004:M00<00003@Yd003jM00D00005?Yd003jM000nW@040000
0cjm000n_@0700001d;N0016gP00A]h004[N0080000=C_h004km001>o@00Dad005<M001G7@00Ead0
1P0000aK?000GcaO?000Gc`005ll001S?000Hc`200001f<l001S>f<k001S>`00009S>`06001W>`00
001S>`000VLk00L006LkIc/006Lk001W>`0200002VLk001W>fLk001W>P00IcX006Lj0P0000EW6P00
IaYW6P00009W6P06001W6VLJ001W6P000VLJ00<006LJ00000VLJ00D006LJ001W6P00009W6P03001W
6P00009W6P06001W6P00001W6P000VLJ00P006LJ001W6P00IaX006LJ0P000VLJ00<006LJ00000VLJ
00L006;j001RnP00H_X00002H_X00`00H_X00002H_X01000H_X006;j0`000V;j00<006;j00000V;j
00T006;j001RnP00H_X006;j00000V;j00D006;j001RnP00009RnP80009RnP<00004G]X005kJ0002
G]X03P00G]X005kJ001NfP00G]X005kJ001NfP00G]X300004U[J001JfP00F]X005[J001JfP00F[X0
05Zj001J^P00E[X0009F^P80000;E[X005Jj001F^`00E[/005:k001B^`0200002e:k001B^`00DY/0
05:K001BV`00CY/00P0000=>V`00CY/00P0000M>V`00CY/004jK001>V`02000024ZK000004ZK001:
V`00BY/600000dZK001:W00200000dZL001:W00200001dJL0016W000AY`004JL00800003AY`004JL
00H00006AY`00000AY`004JL0P0000E6W000AY`004JL00800004AY`00000AY`800001dJm0016_@00
A[d004Jm00800009B[d004Zm001:_@00B[d004[M00<0000<C]d004kM001>g@00C]d005;m001Bo@00
0U;m00@005;m001Fo@800006E_`005KlE_`005Kl0P0000EK7000Fa`005/L00@00004Fa`005lL0002
Ga`02P00Ga`005lL001O7000Ga`005lK0P0000=O6`0000000UlK00P006<K001S6`00Ha/006<K0P00
00AS6`00Ha/0009S6`05001S6`00Ha/00002Ha/3000016<K001S6f<K0P000V<K0P000V<K0`0000US
6`00Ha]S6`00Ha/006<K00000V<K0P0000AS6P000000009RnP07001RnP00H_X006;j00000V;j0`00
00ARnP00H_X0009RnP800004H_X005kj0002G_X5000015kj001NnP000Ukj0P000Ukj0P000Ukj00<0
05kj00000P0000INfP00G]X005kJ0002G]X2000025kJ001NfP00G]X005[J0002F]X00`00F]X00005
000025[J001JfP00F]X005[J0002F]X01P00F[X005Zj001J^P80000>E[X005Jj001F^P00E[X005Jj
001F^P00E[X0009F^`800009E[/005Jk001F^`00E[/005Jk0240000ED[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k0080000YD[/005:k001B^`00D[/005:k001B^`00E[/005Jk
001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005KK001Ff`00E]/005KK001Ff`0200004UKK
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0009Ff`09001Ff`00001Ff`00E]/005KK00d0
0004E]/005KK000AOol00`00Oomoo`0]Ool009Qoo`03001oogoo05aoo`04001Bg000D]`20002D]`0
1000D]`005;L0P0000UBg000D]`005;L001Bg000D]`00P0000UBg000D]`005;L001Bg000D]`00P00
00eBg000D]`005;L001Bg000D]`005:l001B_00200001E:l001>_000C[`00P0000U>_000C[`004jl
001>_000C[`00P0000=>_000C[`00P0000E>_000B[`004Zl00800005B[`004Zl001:_00200001TZl
000004Jl0016_0@00008AYd00000@Yd004:M0012W@<00006@Yd00000?Yd003jM0`0000DnW@00?Yd0
03jM00<00008?[d00000@[d004:m0012_PT00007B_h004kn001>o@00C_d01`0000IG7@00Fad005/M
0002Fc`03000GcaO?000Gc`005ll001S?000Hc`0009S?007001S>f<k001S>`00Hc/00P0000ES>`00
Hc]S>`00009W>`04001W>`00Ic/200001FLk001W>fLk00000VLk00L006Lj001W>P00IaX00002IaX0
1`00IaYW6P00IaX006LJ0080009W6P03001W6P00009W6P03001W6VLJ0080009W6P03001W6P00009W
6P06001W6VLJ001W6P000VLJ00P006LJ001W6P00IaX006LJ0P0000EW6P00IaYW6P00009W6P04001W
6P00H_X30002H_X00`00H_X00002H_X01000H_X006;j0P0000IRnP00H_X006;j0002H_X01P00H_X0
06;j001RnP<0009RnP03001RnP00009RnP06001RnP00H_X006;j0`0001ANfP00G]YNfP00G]X005kJ
001NfP00G]X005kJ001NfP00G]X005kJ0P0000=NfP0000000U[J018005[J001JfP00F]X005[J001J
^P00F[X005Zj001F^P00E[X200002eJj001F^P00E[/005Jk001B^`00D[/00P0000]B^`00D[/005:K
001BV`00DY/004jK00800009CY/004jK001>V`00CY/004jK00800005CY/004jK001:V`0200000dZK
001:V`0200001DZK001:V`00BY/01P0000Q:W0000016W000AY`004JL0P0000]6W000AY`004JL0016
W000AY`004JL00@00007AY`004JL0016W000AY`00P0000E6W000AY`004JL00<00005AY`004JL0016
_00600001DJm0016_@00B[d00P0000M:_@00B[d004Zm001:g@0200006dkM001>g@00C]d004kM001>
g@00D_d005;m001Bo@00D_d005Km001Fo@00E_`005Kl001Fo00200000e/L00000002000015/L001K
70000U/L00T005lL001O7000Ga`005lL00000UlL0`0000AO6`00Ga]O6`80009O6`04001S6`00Ha/3
00002f<K001S6f<K001S6`00Ha/006<K00000V<K0`0000aS6`00Ha]S6`00Ha/006<K001S6`00Ha/3
00002F<K001S6f<K001S6`00Ha/00002Ha/500002V;k001Rn`00H_X006;j001RnP000V;j0`0000AR
nP00H_X0009RnP04001RnP00H_X20002G_X3000015kj001NnP000Ukj00X005kj001NnP00G_X005kj
001NnPD00004G]X005kJ0002G]X01P00G]X005kJ001NfP800006G]X005kJG]X005[J1@0000EJfP00
F]X005[J0080009JfP0<001JfP00F]X005[J001J^P00F[X005Zj0P0000AF^P00E[X0009F^P08001F
^P00E[X005Jj001F^Ph00009E[/005Jk001F^`00E[/005Jk0080000CE[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/00P0002UB^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001F^`00E[/005Jk0080000IE[/005Jk
001F^`00E[/005Jk001F^`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00P0000QFf`00E]]Ff`00
E]/005KK0`0000=Ff`00E]/03000011Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0015oo`03
001oogoo02eoo`00V7oo00<007ooOol0GGoo0P0000eBg000D]`005;L001Bg000D]`005;L001Bg002
00002E;L001Bg000D]`005;L001Bg00200002e;L001Bg000D]`005;L001Bg000D]`03@0000M>_000
C[`004jl001>_00200002Djl001>_000C[`004jl001>_00200001Djl001>_000B[`00P0000Y:_000
001:_000B[`004Zl001:_0800006A[`00000AYd004JM1@0000=2W@00@Yd00P0000I2W@00000nW@00
?Yd300000cjM00000004000013jM000003jm0P0000=2_@00@[d00`0000M6gP00A]h004[N001:gP08
00001U<M001G7@00Ead0009G7@05001K7@00Fad00002Fc`01000Gc`005ll1@000V<l00L006<lHc`0
06<k001S>`0200001F<k001S>f<k00000V<k00@006Lk001W>`800005Ic/006LkIc/00002Ic/01000
Ic/006Lj0`000VLJ00L006LJIaX006LJ001W6P020002IaX00`00IaX00002IaX01000IaX006LJ0P00
00AW6P00IaX0009W6P04001W6P00IaX20002IaX00`00IaX00002IaX00`00IaX0000200001FLJ001W
6VLJ00000VLJ00@006LJ001W6P800006H_X006;j001RnP000V;j00@006;j001RnP800006H_X006;j
001RnP000V;j00H006;j001RnP00H_X200001V;j001RnP00H_X0009RnP06001RnP00H_X006;j0`00
00UNnP00G]YNfP00G]X005kJ00000UkJ0P0000ENfP00G]X005kJ00@0000MG]X005kJ001JfP00F]X0
05[J001JfP00F]X005[J001J^P00F[X005Zj001F^P00E[X005Jj001F^P0200003EJk001F^`00D[/0
05:k001B^`00D[/005:k0080000;DY/005:K001>V`00CY/004jK001>V`0200001DjK001>V`00CY/0
0P0000=>V`00BY/00P0000M:V`00BY/004ZK001:V`0200000dZK001:V`0200000dZL000000040000
1DJL0016W000AY`00P0000E6W000AY`004JL00800006AY`00000AY`004JL1P0000Q6W0000016W000
AY`004JL0P0000E6W000AY`004JL00800005A[`004Jm0016_@0700004DZm001:_@00B[d004[M001:
g@00C]d004kM001>g@00C]d00P0000mBo@00D_d005;m001Bo@00E_d005Km001Fo000E_`01@0000AK
7000Fa`0009K700<001K7000Fa`005lL001O7000Ga`005lL1000015O7000Ga]O6`00Ga/005lK001O
6`00Ha/006<K001S6`00009S6`08001S6`00Ha/006<K001S6`@0000<Ha/006<KHa/006<K001S6`00
Ha/006<K0`0000US6`00Ha]S6`00Ha/006<K00000V<K0`0000AS6`00H_/0009Rn`80009RnP04001R
nP00H_X300003V;j001RnV;j001RnP00H_X006;j001RnP00H_X3000015kj001NnP000Ukj01<005kj
001NnP00G_X005kj001NnP00G_X005kj001NfP00G]X00002G]X03000G]X005kJ001NfP00G]X005kJ
001NfPD0000HF]X005[J001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X005Zj001J^P000UZj
0P0000=F^P00E[X02`0000=F^`00E[/00P00015F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/0
05Jk00800006E[/005:k001B^`000U:k00X005:k001B^`00D[/005:k001B^`80000ED[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0080000GD[/005:k001B^`00D[/005:k001B
^`00D[/005Jk001F^`00E[/005Jk001F^`02000035Jk001F^`00E[/005Jk001Ff`00E]/0009Ff`04
001Ff`00E]/200001EKK001Ff`00E]/03@0000=Ff`00E]/00P0000QFf`00E]/005KK001Ff`000UKK
00P005KK001Ff`00E]/005KK0P0000=Ff`00Ool047oo00<007ooOol0;Goo002IOol00`00Oomoo`1L
Ool01000D]`005;L0P0000=Bg00000007`0000UBg000D]`005;L001Bg000D[`00P0000=B_0000000
500000M>_000B[`004Zl001:_00200001DZl001:_000B[`00P0000I6_0000016_000AYd2000014JM
000004:M1P0000A2W@00000nW@800009?Yd00000000nW@00?Yd003jM00D00005?[d004:m0012_@03
00001DKN0016gP00B]h00P0000i:o@00C_d004km001Bo@00Dad005LM001G7@000ULM00P005/M001K
7@00Fc`005ll0P0000IO?000Gc`005ll0002Hc`01000Hc`006<k0P0000ES>`00Hc]S>`00009S>`04
001S>`00Ic/200001FLk001W>fLk00000VLk00@006Lk001W>`800004Ic/006LJ0002IaX01000IaX0
06LJ0P0000EW6P00IaYW6P00009W6P04001W6P00IaX20002IaX20002IaX01000IaX006LJ0P000VLJ
00<006LJ00000VLJ00L006LJ001W6P00IaX00002IaX00`00IaX00002IaX01P00IaX00000H_X0009R
nP80009RnP04001RnP00H_X200003V;j001RnV;j001RnP00H_X006;j001RnP00H_X200001V;j001R
nP00H_X0009RnP06001RnP00H_X006;j0P0000=RnP0000000Ukj00<005kJ00000UkJ00H005kJ001N
fP00G]X500001UkJ001NfP00G]X0009NfP80009JfP04001JfP00F]X200002e[J001J^P00F[X005Zj
001F^P00E[X08P0000M>V`00CY/004jK001>V`0200001dZK001:V`00BY/004ZK00800007BY/004ZK
001:V`00BY/00`0000E:W000BY`004ZL00@00003AY`004JL00800003AY`004JL00800005AY`004JL
0016W00200001DJL0016W000AY`01`0000E6W000AY`004JL00800007AY`004Jl0016_000A[d00P00
00E:_@00B[d004Zm00/00007C]d004kM001>g@00C]d00P0000EBo@00D_d005;m00X00003E_`005Kl
0080009K7003001K7000009K7007001K7000001O7000Ga`0100000AO7000Ga`0009O7008001O6`00
Ga/005lK001O6`D0009S6`08001S6`00Ha/006<K001S6`800004Ha/006<K0002Ha/01@00Ha/006<K
00000V<K0`0000YS6`00Ha/006<K001S6`00Ha/0009S6`<0000>Ha/006<KHa/006;k001Rn`00H_/0
06;j001RnP<0000;H_X006;jH_X006;j001RnP00H_X00002H_X400003Ekj001NnUkj001NnP00G_X0
05kj001NnP00009NnPH0000=G_X005kJG]X005kJ001NfP00G]X005kJ00000UkJ0P0000YNfP000000
05[J001JfP00F]X0009JfP06001JfP00F]X005[J0P0000IJfP00F]X005[J0002F]X01000F[X005Zj
200000eF^P00E[X005Jj001F^P00E[X005Jk001F^`02000015Jk001F^`000UJk00`005Jk001F^`00
E[/005Jk001F^`00E[/200004EJk001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/00P0001MB
^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k0080000SD[/005:k001B
^`00D[/005:k001B^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005KK001F
f`0>0000:5KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK001Ff`0047oo00<007ooOol0;Goo002IOol00`00Oomoo`1MOol6
00002E;L001Bg000D]`005;L001Bg00200002E;L001Bg000D]`005;L001Bg00200005E;L001Bg000
D]`005;L001Bg000D]`005;L001Bg000D]`005;L001B_00300001e:l001>_000C[`004jl00800009
C[`004jl001>_000C[`004jl00800003C[`0000000L00007B[`004Zl001:_000B[`00P0000=6_000
A[`00P0000=6W@00AYd00`0000E2W@00@Yd004:M00<00005?Yd003jM000nW@0300000cjM000nW@02
00000cjM0012_@0500000d:m0012_P0200001DKN0016gP00B]h00P0001=:o@00C_d004km001Bo@00
Dad005LM001G7@00Ead005/M001K7@0400002Ell001O?5ll001O?000Gc`00002Hc`01@00Hc`006<k
00000V<k00L006<kHc/006<k001S>`0200001F<k001W>fLk00000VLk00@006Lk001W>`80000:Ic/0
06LkIc/006LJ001W6P00IaX200001FLJ001W6VLJ00000VLJ00@006LJ001W6P80000:IaX006LJIaX0
06LJ001W6P00IaX200001FLJ001W6VLJ00000VLJ00@006LJ001W6P<0009W6P03001W6P00009W6P06
001W6VLJ001S6P000V;j00P006;j001RnP00H_X006;j0P0000iRnP00H_YRnP00H_X006;j001RnP00
H_X006;j0P0000iRnP00H_YRnP00H_X006;j001RnP00H_X006;j0P0000QRnP00H_X005kj001NnP00
0UkJ00d005kJ001NfP00G]X005kJ001NfP00G]X00002G]X04P00G]X005kJ001NfP00F]X005[J001J
fP00F]X005[J001JfPT0000>E[X00000E[X005Jj001F^`00E[/005Jk001B^`80000;D[/005:k001B
^`00DY/005:K001BV`0200001DjK001>V`00CY/02P0000Y:V`00001:V`00BY/004ZK001:V`800003
BY/004ZK00800005BY`004ZL001:W00200000dZL001:W00600000dJL0016W00200002TJL000004JL
0016W000AY`004JL0P0000A6W0000016W0H00007AY`004JL0016W000A[`00P0000M6_@00A[d004Zm
001:_@0300002DZm001:_@00B]d004[M001>g@0>00002U;m001Bo@00E_d005Kl001Fo0000UKl00@0
05Kl0000009K7008001K7000Fa`005/L001K70<00004Ga`005lL0002Ga`01`00Ga`005lL001O6`00
009O6`<00006Ga/005lK001S6`000V<K00@006<K001S6`<0000;Ha/006<KHa/006<K001S6`00Ha/0
0002Ha/3000016<K001S6f<K0P000V<K0P000V<K0`0000iS6`00Ha]S6`00Ha/006;k001Rn`00H_/0
06;j0`0000]RnP00H_YRnP00H_X006;j001RnP00009RnP<00003G_X00000009NnP07001NnP00G_X0
05kj00000Ukj00<005kj00000P0000iNnP00G_X005kj001NnP00G]X005kJ001NfP000UkJ00<005kJ
00001@0000ANfP00F]X0009JfP0:001JfP00F]X005[J001JfP00F]X20002F]X01000F]X005[J1`00
00mJ^P00001F^P00E[X005Jj001F^P00E[X005Jj00000UJj00@005Jk001F^`80000AE[/005Jk001F
^`00E[/005Jk001F^`00E[/005Jk001F^`0200004eJk001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k0080000YD[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B
^`00D[/005:k001B^`00D[/005:k001B^`00E[/005Jk001F^`0B00001EKK001Ff`00E]/00P0000QF
f`00E]/005KK001Ff`000UKK00<005KK00000P0000=Ff`00E]/00P0001YFf`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`0047oo00<007ooOol0;Goo002JOol00`00
Oomoo`1LOol01000D]`005;L0P000U;L00P005;L001Bg000D]`005;L0P0000UBg000D]`005;L001B
g000D]`00P0000eBg000D]`005;L001Bg000D]`005;L001Bg00200001e;L001Bg000D[`005:l0080
0007D[`004jl001>_000C[`00P0000U>_000C[`004jl001>_000C[`00`0000M>_000B[`004Zl001:
_00900002TJl000004Jl0016W@00AYd004JM0`0000=2W@00@Yd00P0000=2W@0000000`0000<nW@00
?Yd00P0000HnW@00000nW@00?Yd300000d:m0012_@0600003TKN000004[N001:gP00B_d004km001>
o@00D_d200000eLM001G7@06000015/M001K70000Ull00T005llGc`005ll001O?000Hc`00`000V<k
00L006<kHc/006<k001S>`0200001F<k001S>f<k00000VLk00@006Lk001W>`800005Ic/006LkIc/0
0002Ic/200001FLJ000006LJ00000VLJ00L006LJIaX006LJ001W6P0200001FLJ001W6VLJ00000VLJ
0P0000EW6P00001W6P00009W6P07001W6VLJ001W6P00IaX00P0000IW6P00IaX006LJ0002IaX01000
IaX006LJ0P000V<J00P006;j001RnP00H_X006;j0P0000MRnP00H_YRnP00H_X00002H_X200000f;j
001RnP0200003V;j001RnV;j001RnP00H_X006;j001RnP00H_X2000016;j001RnP000V;j0P000Ukj
00H005kJ001NfP00G]X50002G]X05000G]X005kJ001NfP00G]X005kJ001JfP00F]X005[J001JfP00
F]X300005eZj001J^P00F[X005Jj001F^P00E[X005Jj001F^P00E[/005Jk001F^`00D[/00P0000MB
^`00D[/005:k001BV`0200001e:K001>V`00CY/004jK00800005CY/004jK001>V`0200000djK0000
000600000dZK001:V`0200001DZK001:V`00BY`00P0000M:W000BY`004ZL001:W002000014ZL0000
04ZL1P0000M6W000AY`004JL0016W00200001DJL0016W000AY`00`0000=6W000AY`01P0000E6W000
A[`004Jl00800007A[d004Zm001:_@00B[d00P0000M:_@00B[d004[M001:g@0200001dkM001>g@00
C]d004kM00800004D_d005;m0002D_d05000D_d005Km001Fo000E_`005Kl001Fo000Fa`005/L001K
7000Fa`500003UlL001O75lL001O7000Ga`005lL001O7000Ga/400004ElK001O6elK001O6`00Ha/0
06<K001S6`00Ha/006<K00000V<K00L006<K001S6`00Ha/00002Ha/3000036<K001S6f<K001S6`00
Ha/006<K001S6`<0000;Ha/006<KHa/006<K001S6`00H_/00002H_/300002V;k001Rn`00H_X006;j
001RnP000V;j00<006;j00000P0000aNnP00G_X005kj001NnP00G_X005kj0002G_X5000015kj001N
nP000Ukj0P0000INnP00G]X005kJ0002G]X500005ekJ001NfP00G]X005kJ001JfP00F]X005[J001J
fP00F]X005[J001JfP00F]X01`0000UJfP00F[X005Zj001J^P00F[X00P000UJj00h005Jj001F^P00
E[X005Jj001F^P00E[/005Jk0P00015F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk0080
0006E[/005:k001B^`000U:k00X005:k001B^`00D[/005:k001B^`80000ED[/005:k001B^`00D[/0
05:k001B^`00D[/005:k001B^`00D[/005:k01L0000SE[/005Jk001F^`00E[/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`0300001eKK001Ff`00E]/0
05KK00800008E]/005KK001Ff`00E]/0009Ff`08001Ff`00E]/005KK001Ff`@0011oo`03001oogoo
02eoo`00Vgoo00<007ooOol0G7oo00@005;L001Bg080009Bg00;001Bg000001Bg000D]`005;L001B
g00200002E;L001Bg000D]`005;L001Bg002000015;L001Bg0000U;L0P0000UBg000D]`005;L001B
g000D[`00P0000=B_000D[`00P0000M>_000C[`004jl001>_00200001djl001>_000C[`004jl0080
000?C[`004Zl001:_000B[`004Zl001:_000B[`004Zl00L00003AYd004JM0080000<@Yd00000@Yd0
04:M0012W@00@Yd004:M1`0000DnW@00?Yd003jM00<00008@[d00000@[d004Jm0016gA<00006Ead0
05LM001K7@000U/M00<005/L00000Ull00@005ll001O?0@00004Hc`006<l0002Hc/01000Hc/006<k
0P0000ES>`00Hc]S>`00009S>`04001W>`00Ic/200001FLk001W>fLk00000VLk00L006Lk001W6P00
IaX00002IaX01`00IaYW6P00IaX006LJ00800005IaX006LJIaX00002IaX01`00IaX006LJ001W6P00
009W6P07001W6VLJ001W6P00IaX00P0000AW6P00IaYW6P80009W6P04001W6P00IaX20002HaX00`00
HaX00002H_X00`00H_X0000200001f;j001RnV;j001RnP00009RnP04001RnP00H_X300001f;j001R
nV;j001RnP00009RnP800003H_X006;j0080000@H_X006;jH_X006;j001RnP00G_X005kj001NfP00
G]X200002UkJ001NfP00G]X005kJ001NfP000UkJ00@005kJ0000009NfP800003F]X0000000D00008
F]X005ZjF[X005Zj001J^P80009F^P80000;E[X005Jj001F^`00E[/005Jk001B^`0200002e:k001B
^`00D[/005:K001BV`00DY/00P0000M>V`00CY/004jK001>V`0200000djK001>V`0200001djK001>
V`00CY/004ZK00H00003BY/004ZK00800005BY`004ZL001:W00200001DZL001:W000BY`00`0000E6
W000AY`004JL00@00003AY`004JL00800005AY`004JL0016W00200000dJL0016W00200001DJL0016
W000A[`01P000116_@00001:_@00B[d004Zm001:_@00B[d004Zm001:g@800009C]d004kM001>g@00
C]d004kM00800004D_d005;m0002D_d03`00D_d00000E_`005Kl001Fo000E_`005/L001K70040000
25/L001K7000Fa`005lL0002Ga`200001ElL001O7000Ga`00P0000AO7000Ga/0009O6`08001O6`00
Ga/006<K001S6`D0009S6`08001S6`00Ha/006<K001S6`@0000<Ha/006<KHa/006<K001S6`00Ha/0
06<K0`0000US6`00Ha]S6`00Ha/006<K00000V<K00<006;k00000P0000ARn`00H_]Rn`800004H_X0
06;j0002H_X500001Ukj001NnUkj001NnP80009NnP04001NnP00G_X3000015kj001NnP000Ukj00H0
05kj001NnP00G_X20002G]X00`00G]X0000200001UkJ001NfP00G]X0009NfP800008G]X005[J001J
fP00F]X0009JfP04001JfP00F]X4000035[J001JfP00F]X005[J001J^P00F[X0009J^P80000AE[X0
05Jj001F^P00E[X005Jj001F^P00E[X005Jk001F^`02000015Jk001F^`000UJk00`005Jk001F^`00
E[/005Jk001F^`00E[/200001EJk001B^`00D[/09@0001=B^`00D[/005Jk001F^`00E[/005Jk001F
^`00E[/005Jk001F^`02000015Jk001F^`000UJk00`005Jk001Ff`00E]/005KK001Ff`00E]/20000
8eKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/0300000=Ff`00Ool03goo00<007ooOol0;Goo002KOol00`00Oomoo`1LOol04000
D]`005;L001Bg000D]`005;L001Bg000D]`005;L0P0000UBg000D]`005;L001Bg000D]`00P0000eB
g000D]`005;L001Bg000D]`005;L001Bg00200002E;L001Bg000D[`005:l001B_00200001Djl001>
_000C[`00P0000U>_000C[`004jl001>_000C[`00P0000Q>_000001:_000B[`004Zl0P0000E:_000
B[`004Zl00800006B[`00000A[`004Jm1`0000E2W@00@Yd004:M00<00008@Yd00000@Yd004:M0012
W@<00005?Yd003jM0012_@0200001T:m000004:m0016_@80000IA]d00000B]d004[m001>o@00C_d0
04km001Bo@00Dad005LM001G7@00Ead005/M00000U/M00H005/L001O?000Gc`2000015ll001O?000
0V<l00H006<l001S>`00Hc/200001F<k001S>f<k00000V<k00@006<k001W>`800005Ic/006LkIc/0
0002Ic/01000Ic/006Lk0`000VLJ00L006LJIaX006LJ001W6P0200001FLJ001W6VLJ00000VLJ00@0
06LJ001W6P<0009W6P07001W6VLJ001W6P00IaX00P0000aW6P00IaYW6P00IaX006LJ001W6P00IaX2
00001F<J001S6V<J00000V<J00L006;j001RnP00H_X00002H_X00`00H_X00002H_X02@00H_X006;j
001RnP00H_X00002H_X00`00H_X00002H_X01000H_X006;j0`00011RnP00H_YRnP00H_X006;j001R
nP00G_X005kj001NfP800004G]X005kJ0002G]X20002G]X02000G]X005kJ001NfP00G]X500007E[J
001JfP00F]X005[J001JfP00F[X005Zj001J^P00E[X005Jj001F^P00E[X005Jj001F^`00E[/00P00
00]B^`00D[/005:k001B^`00D[/005:K00800007DY/004jK001>V`00CY/00P0000E>V`00CY/004jK
00800007CY/004jK001>V`00CY/00P0000=:V`00BY/01`0000M:W000BY`004ZL001:W00200000dZL
001:W00200001DZL0016W000AY`00P0000=6W000AY`01P0000Q6W0000016W000AY`004JL0P0000E6
W000AY`004JL00800005A[`004Jl001:_00900001dZm001:_@00B[d004[M0080000CC]d004kM001>
g@00C]d004kM001Bg@00D_d005;m001Bo@00D_d00P0000EFo000E_`005Kl00H00004Fa`005/L0002
Fa`01000Fa`000000UlL00D005lL000005lL00@0000>Ga`005lLGa`005lK001O6`00Ga/005lK001S
6`800008Ga/006<K001S6`00Ha/0009S6`03001S6`0000800004Ha/006<K0002Ha/01@00Ha/006<K
00000V<K0`0000=S6`0000000V<K00D006<K001S6`00009S6`D0000<H_/006;kH_/006;k001Rn`00
H_X006;j0`0000ANnP00G_X0009NnP0:001NnP00G_X005kj001NnP00G_X3000015kj001NnP000Ukj
00X005kj001NnP00G_X005kj001NnPD00006G]X005kJ001NfP000UkJ00@005kJ001NfP800006F]X0
05[JF]X005[J1`0000UJfP00001JfP00F]X005[J00000U[J00P005Zj001J^P00F[X005Zj0P0000YF
^P00E[X005Jj001F^P00E[X0009F^P04001F^`00E[/200000eJk001F^`0F00002eJk001B^`00D[/0
05:k001B^`00D[/00P0001EB^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`00D[/0
0P0000IB^`00D[/005Jk0002E[/02P00E[/005Jk001F^`00E[/005Jk0P0001MF^`00E[/005Jk001F
^`00E[/005KK001Ff`00E]/005KK001Ff`00E]/005KK00800008E]/005KK001Ff`00E]/0009Ff`03
001Ff`0000800003E]/005KK00h00009E]/005KK001Ff`00E]/005KK0080009Ff`03001oogoo00eo
o`03001oogoo02eoo`00W7oo00<007ooOol0G7oo00@005;L001Bg080009Bg00;001Bg000001Bg000
D]`005;L001Bg00200002E;L001Bg000D]`005;L001Bg00200001E;L001Bg000D]`04`0000M>_000
C[`004jl001>_00200002Djl001>_000C[`004jl001>_00200001DZl001:_000B[`00P0000Q:_000
001:_000B[`004Zl0P0000Q6_0000016_@00A[d004Jm0`0000E2W@00@Yd004:M00800006@Yd00000
@Yd004:M0`0000=2_@000000100000Q2_@000012_@00@[d004Jm0P0001a6g@00001:g@00B_d004km
001>o@00C_d005;m001C7@00Ead005LM001G7@00Fad005/M001K70@00007Ga`005llGc`005ll0000
0V<l00L006<l001S>`00Hc/00002Hc/01`00Hc]S>`00Hc/006<k00800005Hc/006LkIc/00002Ic/0
1000Ic/006Lk0P0000AW6`00Ia/0009W6P04001W6P00IaX200001FLJ001W6VLJ00000VLJ00@006LJ
001W6P800004IaX006LJ0002IaX01000IaX006LJ0P0000MW6P00IaYW6P00IaX00002IaX200001FLJ
000006<J00000V<J00L006<JHaX006<J001RnP030002H_X00`00H_X00002H_X01P00H_X006;j001R
nP<0009RnP03001RnP00009RnP04001RnP00H_X300001f;j001RnV;j001RnP00009RnP80009RnPD0
000BG]X005kJG]X005kJ001NfP00G]X005kJ001NfP00G]X005kJ0`0000AJfP00F]X0009JfP80009J
fP800008F]X005ZjF[X005Zj001J^P80000?E[X005Jj001F^P00E[X005Jk001F^`00E[/005:k0080
0007D[/005:k001B^`00DY/00P0000]BV`00CY/004jK001>V`00CY/004jK00800003CY/004jK0080
0009CY/004jK001>V`00BY/004ZK00<00005BY/004ZK001:V`0600000dZL001:W00200000dZL001:
W00200001dJL0016W000AY`004JL00800003AY`004JL00T00007AY`004JL0016W000AY`00P0000E6
_000A[`004Jl00<00005B[d004Zm001:_@0=00003dkM001>g@00C]d004kM001Bg@00D_d005;m001B
o@0900001UKl001Fo000F_`0009K700<001K7000Fa`005/L001K7000Ga`005lL0`0000AO7000Ga`0
009O7007001O7000Ga/005lK00000UlK0`00015O6`00Ga]O6`00Ha/006<K001S6`00Ha/006<K001S
6`00009S6`07001S6`00Ha/006<K00000V<K0`0000AS6`00Ha]S6`800004Ha/006<K0002Ha/30000
16;k001Rn`000V;k00l006;k001Rn`00H_/006;j001RnP00G_X005kj00000Ukj00X005kj001NnP00
G_X005kj001NnP<0000=G_X005kjG_X005kj001NnP00G_X005kj00000Ukj100000INfP00G]X005kJ
0002G]X03000G]X005kJ001NfP00G]X005kJ001JfPD0000IF]X005[J001JfP00F]X005[J001JfP00
F]X005[J001JfP00F[X005Zj001J^P00F[X00P000UJj00P005Jj001F^P00E[X005Jj300000eF^`00
E[/005Jk001F^`00E[/005Jk001F^`0200004EJk001F^`00E[/005Jk001B^`00D[/005:k001B^`00
D[/00P0000IB^`00D[/005:k0002D[/03000D[/005:k001B^`00D[/005:k001B^`80000CD[/005:k
001B^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/00P00025F^`00E[/005Jk001F^`00E[/005KK
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0300000aFf`00E]/005KK
001Ff`00E]/005KK0002E]/03000E]/00000E]/005KK001Ff`00E]/000moo`03001oogoo02eoo`00
W7oo00<007ooOol0G7oo00P005;L001Bg000D]`005;L7@0000EBg000D]`005;L00800009D]`005;L
001Bg000D[`005:l00800003D[`0000001800007B[`004Zl001:_000B[`00P0000E:_000B[`004Zl
00800003A[`004Jl00800003A[d004Jm00<00003AYd0000000@00006@Yd00000@Yd004:M0P0000U2
W@00000004:m0012_@00@[d01@0000M2_@00A[d004KM0016g@0200003d[M001:o@00C_d004km001>
o@00D_d005<M001G7@0200000eLM00000004000015/L001O70000UlL00T005llGc`005ll001S?000
Hc`00`000V<k00L006<kHc/006<k001S>`0200001F<k001S>f<k00000VLk00@006Lk001W>`80000:
Ia/006LKIa/006LK001W6P00IaX200001FLJ001W6VLJ00000VLJ00@006LJ001W6P80000:IaX006LJ
IaX006LJ001W6P00IaX200001fLJ001W6VLJ001W6P00009W6P07001W6P00IaX006<J00000V<J00<0
06<J00000V<J00X006<J000006;j001RnP00H_X0009RnP06001RnP00H_X006;j0P0000IRnP00H_X0
06;j0002H_X01000H_X006;j0P0000=RnP0000000V;j00<006;j00000V;j00@006;j001RnP<00004
G_X005kj0002G]X03P00G]X005kJ001NfP00G]X005kJ001NfP00G]X200000ekJ00000002F]X04P00
F]X005[J001JfP00F]X005[J001JfP00F[X005Zj001J^P80009F^P800009E[X005Jj001F^`00E[/0
05Jk00h0000:DY/00000CY/004jK001>V`00CY/200002djK001>V`00CY/004jK001>V`00CY/00P00
00=:V`00BY/00P0000=:V`00BY/00P0000E:W000BY`004ZL00H00008BY`00000BY`004JL0016W080
000=AY`004JL0016W000AY`004JL0016W000AY`01P0000=6W000AY`00P0000M6_000A[`004Jl001:
_00200000dZm001:_@0200002DZm001:_@00B[d004[M001>g@0B00000e;m001Bo002000015Kl001F
o0000UKl010005Kl001Jo000Fa`005/L001K7000Fa`005/L001O70800003Ga`00000009O700:001O
7000Ga`005lL001O6`00Ga/400003UlK001O6elK001O6`00Ha/006<K001S6`00Ha/30002Ha/01`00
Ha/006<K001S6`00009S6`<0000<Ha/006<KHa/006<K001S6`00Ha/006<K0`0000]Rn`00H_]Rn`00
H_/006;k001Rn`00009Rn`H0009NnP07001NnP00G_X005kj00000Ukj00<005kj00000P0000aNnP00
G_X005kj001NnP00G_X005kj0002G_X00`00G_X0000200001Ekj000005kJ00000UkJ00T005kJ001N
fP00G]X005kJ00000UkJ0P0000aNfP00000005[J001JfP00F]X005[J0002F]X04000F]X00000F]X0
05[J001JfP00F]X005Zj001J^P000UZj0P0000=F^P0000002@0000EF^P00E[/005Jk0080000UE[/0
05Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001B^`00D[/0
05:k001B^`00D[/00P0001=B^`00D[/005:k001B^`00D[/005:k001B^`00D[/005:k001B^`020000
5E:k001B^`00D[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`02000015Jk001F^`000UJk
00`005Jk001Ff`00E]/005KK001Ff`00E]/>00002EKK001Ff`00E]/005KK001Ff`020002E]/03P00
E]/005KK001Ff`00E]/005KK001Ff`00E]/2000025KK001Ff`00E]/005KK000@Ool00`00Oomoo`0/
Ool009eoo`03001oogoo05aoo`L00003D]`005;L00800007D]`005;L001Bg000D]`00P0000UBg000
D]`005;L001Bg000D]`00P0000ABg000D]`0009Bg004001Bg000D]`200002E;L001Bg000D]`005:l
001B_00300001djl001>_000C[`004jl00800009C[`004jl001>_000C[`004jl00`00005B[`004Zl
001:_00200000dJl0016_@0200000dJm0016_@0300001DJM0012W@00@Yd01@0000E2W@00@Yd004:M
00<00003@[d004:m00800004@[d00000A[d800003T[M000004[m001>o@00C_d004km001Bo@00Dad5
00001ULM001K7@00Fa`0009K7003001O7000009O7004001O?000Gc`4000016<l001S>`000V<k00@0
06<k001S>`800005Hc/006<kHc/00002Hc/01000Ic/006Lk0P0000EW6`00Ia]W6`00009W6`07001W
6`00IaX006LJ00000VLJ00L006LJIaX006LJ001W6P0200002VLJ001W6VLJ001W6P00IaX006LJ0P00
00MW6P00IaYW6P00IaX00002IaX01000IaX006LJ0`000V<J00<006<J00000V<J00H006<JHaX006;j
0002H_X20002H_X01P00H_X006;j001RnP800004H_X006;jH_X20002H_X01000H_X006;j0P0000QR
nP00H_X006;j001RnP000V;j00T006;j001RnP00H_X005kj00000Ukj00D005kj001NfP00009NfP80
009NfP800003G]X000000080000:G]X005kJ001NfP00F]X005[J0002F]X200003E[J001JfP00F]X0
05Zj001J^P00F[X005Jj00h0000;D[/005:k001B^`00D[/005:k001B^`0?00002TjK000004jK001>
V`00CY/004jK0P0000=:V`00BY/00P0000U:V`00BY/004ZK001:W000BY`00P0000A:W000001:W0H0
0005AY`004JL0016W00200001DJL0016W000AY`00P0000=6W000AY`00P0000E6W000AY`004JL00L0
0009A[`004Jl001:_000B[`004Zm0080000LB[d004Zm001:_@00B[d004[M001>g@00C]d004kM001>
g@00C]d004kM001Bg@00D_d005;m0002D_d02000D_`00000E_`005Kl0002E_`200001e[l001K7000
Fa`005/L00H00004Fa`005lLGa`20002Ga`01000Ga`000000UlL0`0000AO6`00Ga/0009O6`08001O
6`00Ga/006<K001S6`@0000;Ha/006<K001S6`00Ha/006<K001S6`0400004F<K001S6f<K001S6`00
Ha/006<K001S6`00Ha/006<K00000V;k00L006;k001Rn`00H_/00002H_/3000036;k001Rn`00G_/0
05kj001NnP00G_X0009NnPD0000<G_X005kj001NnP00G_X005kj001NnP000Ukj1@00011NnP00G_X0
05kJ001NfP00G]X005kJ001NfP00G]X0009NfPH00006F]X005[J001JfP000U[J00P005[J001JfP00
F]X005[J0P0000AJfP00F]X0009JfP04001J^P00F[X600003eJj001F^P00E[X005Jj001F^P00E[X0
05Jk001F^`0200004UJk001F^eJk001F^`00E[/005Jk001F^`00E[/005Jk001F^`80000AE[/005Jk
001F^`00E[/005:k001B^`00D[/005:k001B^`0200005E:k001B^`00D[/005:k001B^`00D[/005:k
001B^`00D[/005:k001B^`0200001U:k001B^`00E[/0009F^`0:001F^`00E[/005Jk001F^`00E[/2
00001EJk001F^`00E[/0400000iFf`00E]/005KK001Ff`00E]/005KK001Ff`000UKK0P0001]Ff`00
E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00P000UKK00<0
07ooOol03Goo00<007ooOol0;7oo002NOol00`00Oomoo`1KOol01`00D]`005;L001Bg000009Bg00;
001Bg000001Bg000D]`005;L001Bg00200002E;L001Bg000D]`005;L001Bg00200003E;L001Bg000
D]`005;L001Bg000D]`005;L00800007D]`005:l001B_000D[`00P0000M>_000C[`004jl001>_002
00004djl001>_000C[`004jl001>_000C[`004Zl001:_000B[`004Zl00L00003A[`004Jl00800005
A[d004Jm0016_@0300000dJM0012W@02000014:M000004:M100000=2W@00@Yd00P0000=2_@00@[d0
0P0000]2_@00000004Jm0016g@00A]d004[M00h0000<Dad005LM001G7@00Ead005/M001K70000U/L
00H005lL001O7000Gc`2000015ll001O?0000V<l00H006<k001S>`00Hc/200001F<k001S>f<k0000
0V<k00@006<k001W>`800005Ha/006LKIa/00002Ia/01000Ia/006LK0`000VLJ00L006LJIaX006LJ
001W6P0200001fLJ001W6VLJ001W6P00009W6P05001W6P00IaX00002IaX00`00IaX00002IaX01000
IaX006LJ0P0000IS6P00HaX006<J0002HaX01000HaX006<J0P000V;j00X006;j001RnP00H_X006;j
001RnP80000<H_X006;jH_X006;j001RnP00H_X006;j0P0000ARnP00H_X0009RnP80009RnP04001R
nP00H_X50002G_X01@00G_X005kj00000UkJ00@005kJ001NfPD00006G]X005kJ001NfP000UkJ0P00
0U[J00@005[J001JfP80009JfP800003F]X005Zj00L0000CE[X005Jj001F^P00E[/005Jk001F^`00
E[/005:k001B^`00D[/00P0000=B^`00D[/00P0000]BV`00DY/005:K001>V`00CY/004jK00/00005
CY/004ZK001:V`0200001DZK001:V`00BY/00P0000M:W000BY`004ZL001:W00300001DZL001:W000
BY`01P0000Q6W0000016W000AY`004JL0P0000M6W000AY`004JL0016W00200000dJL001:_0090000
1dZl001:_@00B[d004Zm00800007B[d004Zm001:g@00C]d00P0001]>g@00C]d004kM001>g@00C]d0
05;M001Bo@00D_d005;m001Bo000E_`005Kl001Fo000E_`00P0000=Jo000Fa`0100000IK7000Fa`0
05/L0002Fa`02P00Ga`005lL001O7000Ga`005lL0`0000]O6`00Ga]O6`00Ga/005lK001O6`00009O
6`<00004Ga/006<K0002Ha/01P00Ha/006<K001S6`<00004Ha/006<K0002Ha/01@00Ha/006<K0000
0V<K1P000V<K00L006;k001Rn`00H_/00002H_/3000016;k001Rn`000V;k0P0000ANnP00G_X0009N
nP<00004G_X005kj0002G_X01000G_X005kj0P000Ukj00<005kj00000P0000INnP00G_X005kj0002
G_X200001UkJ001NfP00G]X0009NfP03001NfP0000800005G]X005kJ001JfP020002F]X04P00F]X0
05[J001JfP00F]X005[J001JfP00F]X005[J001JfPL00003F[X005Zj00800008E[X005Jj001F^P00
E[X0009F^P06001F^P00E[/005Jk0P00015F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk
0080000AE[/005Jk001F^`00E[/005:k001B^`00D[/005:k001B^`0200001U:k001B^`00D[/0009B
^`0<001B^`00D[/005:k001B^`00D[/005:k0P0000MB^`00D[/005:k001F^`0D00003EJk001Ff`00
E]/005KK001Ff`00E]/005KK0080009Ff`0>001Ff`00E]/005KK001Ff`00E]/005KK001Ff`80000B
E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`000UKK00T005KK000005KK001Ff`00E]/0
0`003goo00<007ooOol0;7oo002NOol00`00Oomoo`1LOol03P00D]`005;L001Bg000D]`005;L001B
g000D]`200001e;L001Bg000D]`005;L0080000AD]`005;L001Bg000D]`005;L001Bg000D]`005;L
001Bg00200002E;L001Bg000D]`005:l001B_00200000e:l001>_00200001djl001>_000C[`004jl
00800005C[`004jl001>_00200001djl001:_000B[`004Zl00<00005B[`004Zl001:_00700000dJm
0016_@0200000dJM0016W@0200000d:M0012W@0300000d:m0012_@0500001d:m0012_@00@[d004:m
00<00005A[d004KM0016g@0200001D[M001:g@00C_d00P0000I>o@00D_d005;m0002Dad03P00Ead0
05LM001G7@00Fad005/L001K7000Ga`400001elL001O?5ll001O?000009S?007001S>`00Hc/006<k
00000V<k00L006<kHc/006<k001S>`0200001F<k001S6f<K00000VLK00@006LK001W6`800006Ia/0
06LK001W6P000VLJ00H006LJ000006LJ0002IaX00`00IaX00002IaX01@00IaX006LJ00000VLJ00<0
06LJ00000VLJ00@006LJ001W6P800004HaX006<JHaX20002HaX01000HaX006<J0P000V<J00X006;j
001RnP00H_X006;j001RnP80000<H_X006;jH_X006;j001RnP00H_X006;j0P0000iRnP00H_YRnP00
H_X006;j001RnP00H_X006;j0P0000QRnP00H_X006;j001NnP000Ukj00d005kj001NfP00G]X005kJ
001NfP00G]X00002G]X04000G]X005kJ001NfP00G]X005[J001JfP00F]X005[J1`0000EJ^P00F[X0
05Zj0080009F^P04001F^P00E[X2000015Jk001F^eJk0P0000]B^`00D[/005:k001B^`00D[/005:k
00800005DY/005:K001BV`0200000djK001>V`0200002DjK001>V`00CY/004jK001>V`0900001DZK
001:V`00BY/00P0000E:W000BY`004ZL00800005BY`004ZL001:W00200001DZL001:W000BY`01P00
00Q6W0000016W000AY`004JL0P0000e6W000AY`004JL001:_000B[`004Zl001:_008000054Zm0000
04Zm001:_@00B]d004kM001>g@00C]d004kM001>g@00C]d200004E;M001Bo@00D_d005;m001Bo000
E_`005Kl001Fo000E_`01@0000AK7000Fa`0009K700<001K7000Fa`005/L001O7000Ga`005lL1@00
00aO7000Ga]O6`00Ga/005lK001O6`00Ga/400004ElK001O6elK001S6`00Ha/006<K001S6`00Ha/0
06<K00000V<K00L006<K001S6`00Ha/00002Ha/300002V<K001S6`00Ha/006<K001Rn`000V;k00<0
06;k00000P0000iRn`00H_]Rn`00H_/006;k001Nn`00G_X005kj0`0000ANnP00G_X0009NnP08001N
nP00G_X005kj001NnPD00004G_X005kj0002G_X01P00G_X005kj001NfP80009NfP03001NfP0000@0
000BG]X005kJ001NfP00F]X005[J001JfP00F]X005[J001JfP000U[J00D005[J000005[J00D0000K
F]X005Zj001J^P00F[X005Zj001F^P00E[X005Jj001F^P00E[X005Jj001F^P00E[/005Jk0080000U
E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001B^`00
D[/005:k001B^`00D[/00P0000EB^`00D[/005:k01P0000;E[/005Jk001F^`00E[/005Jk001F^`02
000025Jk001F^`00E[/005Jk0002E]/01P00E]/005KK001Ff`80000CE]/005KK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`00E]/00`0000=Ff`00E]/00P000UKK00X005KK001Ff`00E]/005KK001F
f``00003E]/007oo00ioo`03001oogoo02aoo`00Wgoo00<007ooOol0G7oo00H005;L000005;L0002
D]`02`00D]`00000D]`005;L001Bg000D]`00P0000UBg000D]`005;L001Bg000D]`00P000U;L0P00
00UBg000D]`005;L001Bg000D]`00P0000UBg000D[`005:l001B_000D[`00P0000E>_000C[`004jl
00800009C[`004jl001>_000C[`004jl00<00007B[`004Zl001:_000B[`00P0000=:_000B[`00P00
00=:_000B[`00P0000=6_@000000100000Q6W@000012W@00@Yd004:M0`0000I2_@000012_@00@[d7
00000d:m0012_@0200001DJm0016g@00A]d00P0000E:g@00B]d004km00800006C_d005;m001Bo@00
0U<M00H005LM001G7@00Ead200000e/L00000002000015lL001O70000UlL00T005llGc`005ll001S
?000Hc/00`000V<k00L006<kHc/006<k001S>`0200001F<k001S>f<k00000V<K00@006LK001W6`80
0004Ia/006LKIa/20002IaX01P00IaYW6P00IaX0009W6P03001W6P00009W6P04001W6P00IaX20000
16LJ001W6P000VLJ00@006LJ001W6P80000<HaX006<JHaX006<J001S6P00HaX006<J0P0000ES6P00
HaYS6P00009RnP05001RnP00001RnP0200002F;j001RnV;j001RnP00H_X00002H_X300003V;j001R
nV;j001RnP00H_X006;j001RnP00H_X200001V;j001RnV;j001RnP80009NnP06001NnP00G_X005kJ
1@000UkJ018005kJ001NfP00G]X005kJ001NfP00G]X005[J001JfP00F]X300001U[J001JfP00F]X0
009J^P80000GF[X005Jj001F^P00E[X005Jj001F^`00E[/005Jk001F^`00D[/005:k001B^`020000
0e:k001B^`0200002e:K001BV`00DY/004jK001>V`00CY/00P0000E>V`00CY/004jK00800003CY/0
04jK00800003CY/004ZK00H00005BY/004ZL001:W00200000dZL001:W00200002DZL001:W000BY`0
04ZL001:W00300000dZL001:W00600000dJL0016W00200001dJL0016W000AY`004Zl00800003B[`0
04Zl00800007B[`004Zl001:_000B[d02P0000Y>g@00001>g@00C]d004kM001>g@800007D]d005;m
001Bo@00D_d02P0000EFo000001Jo000009K700;001K7000Fa`005/L001K7000Fa`00002Ga`30000
25lL001O7000Ga`005lL0002Ga/200000elK001O6`02000015lK001O6`000UlK00P005lK001S6`00
Ha/006<K1@000V<K00L006<K001S6`00Ha/00002Ha/300001V<K001S6f<K001S6`80009S6`03001R
n`0000@0000>H_/006;kH_/006;k001Rn`00H_/005kk001NnP<0000GG_X005kjG_X005kj001NnP00
G_X005kj001NnP00G_X005kj001NnP00G_X00002G_X02P00G_X005kj001NnP00G]X005kJ1@0000IN
fP00G]X005kJ0002G]X01000G]X005[J0P0000AJfP00F]X0009JfP03001JfP0000L00008F]X005[J
001JfP00F[X0009J^P04001J^P00F[X200003eJj001F^P00E[X005Jj001F^P00E[X005Jk001F^`02
00004UJk001F^eJk001F^`00E[/005Jk001F^`00E[/005Jk001F^a/0000=E[/005Jk001F^`00E[/0
05Jk001F^`00E[/00P0000iF^`00E[/005Jk001F^`00E[/005Jk001F^`000UJk0P0001=F^`00E[/0
05Jk001F^`00E[/005Jk001Ff`00E]/005KK001Ff`0200004UKK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/0009Ff`800005E]/005KK001Ff`0=00000eKK001Ff`0200001UKK001Ff`00E]/0
009Ff`03001oogoo00aoo`03001oogoo02aoo`00Wgoo00<007ooOol0G7oo00h005;L001Bg000D]`0
05;L001Bg000D]`005;L0P0000MBg000D]`005;L001Bg00200002E;L001Bg000D]`005;L001Bg00J
00001djl001>_000C[`004jl00800007C[`004jl001>_000C[`00P0000M:_000B[`004Zl001:_003
00001dZl001:_000B[`004Zl00<00005A[d004Jm0016_@0500000d:M0012W@0200000d:M0012_@02
00002D:m0012_@00@[d004:m0012_@0700002dKM0016g@00B]d004[M001:g@00C_d00P0000]>o@00
D_d005;m001C7@00Ead005LM00D00004Fa`005/L0002Ga`00`00Ga`00002Ga`01000Gc`005ll1000
00AS?000Hc/0009S>`04001S>`00Hc/200001F<k001S>f<k00000V<k00@006<K001W6`80000<Ha/0
06LKIa/006LK001W6`00IaX006LJ0P000VLJ00<006LJ00000VLJ00@006LJ001W6P800004IaX006LJ
0002IaX01000IaX006LJ0P0000aS6P00HaYS6P00HaX006<J001S6P00HaX200001F<J001S6V<J0000
0V<J00@006;j001RnP<00007H_X006;jH_X006;j00000V;j00<006;j00000P0000MRnP00H_YRnP00
H_X00002H_X20002H_X3000046;j001RnV;j001RnP00H_X006;j001NnP00G_X005kj0P0000YNfP00
G]X005kJ001NfP00G]X0009NfP04001NfP000002G]X200000e[J0000000200000e[J00000002F]X0
2P00F]X005[J001J^P00F[X005Zj0P000UJj00@005Jj001F^P80000;E[/005Jk001F^`00D[/005:k
001B^`0200002e:k001B^`00D[/005:K001BV`00DY/00P0000=>V`00CY/00P0000]>V`00CY/004jK
001>V`00CY/004jK00800008CY/00000BY/004ZK001:V`P00008BY`00000BY`004ZL001:W0800005
BY`004ZL001:W002000024ZL000004ZL001:W000BY`6000024JL000004JL001:_000B[`200002DZl
001:_000B[`004Zl001:_002000024Zm000004Zm001:g@00C]dD00002U;l001Bo000E_`005Kl001F
o0000UKl0P0000AJo000FaaK70800007Fa`005/L001K7000Fa`0100000iO7000GaaO7000Ga`005lL
001O7000Ga/005lK0`0000iO6`00Ga]O6`00Ga/005lK001O6`00Ha/006<K0P0000aO6`00Ha/006<K
001S6`00Ha/006<K0002Ha/300004f<K001S6f<K001S6`00Ha/006<K001S6`00H_/006;k001Rn`00
009Rn`07001Rn`00H_/006;k00000V;k100000]Nn`00G_YNnP00G_X005kj001NnP00009NnP03001N
nP0000<0009NnP0;001NnP00G_X005kj001NnP00G_X00002G_X400001UkJ001NfP00G]X0009NfP08
001NfP00G]X005kJ001JfP80009JfP03001JfP0000@00005F]X005[J001JfP02000045[J001JfU[J
001JfP00F[X005Zj001J^P00F[X005Jj0P0000IF^P00E[X005Jj0002E[X01P00E[X005Jk001F^`80
0003E[/000000100000AE[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`02000045Jk001F
^`00E[/005Jk001F^`00E[/005Jk001F^`000UJk0P00015F^`00E[/005Jk001F^`00E[/005Jk001F
^`00E[/005Jk0080000GE[/005Jk001F^`00E[/005Jk001F^`00E]/005KK001Ff`00E]/005KK001F
f`020002E]/03000E]/005KK001Ff`00E]/005KK001Ff`X0000JE]/005KK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK001Ff`00E]/000ioo`03001oogoo02aoo`00X7oo00<007ooOol0
G7oo00L005;L000005;L001Bg00J000035;L000005;L001Bg000D]`005;L001Bg0800009D]`005;L
001B_000D[`005:l00800003C[`0000001000009B[`004Zl001:_000B[`004Zl00800005B[`004Zl
001:_00200001TJl000004Jm0016_@800004A[d00000A[d6000034:M000004:m0012_@00@[d004:m
0012_@800005A[d004Jm0016_@0I00002ULM001G7@00Fad005/L001K70000UlL00H005lL001O7000
Gc`2000015lL001O?0000V<l00<006<k00000V<k00D006<k001S>`00009S>`07001S>f<k001S>`00
Ha/00P0000MS6`00Ha]S6`00Ia/00002Ia/200000fLJ00000002Ia/00`00IaX00002IaX01000IaX0
06LJ0P0000YW6P00IaYW6P00IaX006LJ001W6P800007HaX006<JHaX006<J00000V<J00<006<J0000
0P0000ES6P00HaYS6P00009S6P04001S6P00H_X300001f;j001RnV;j001RnP00009RnP07001RnP00
H_X006;j00000V;j00<006;j00000V;j00@006;j001RnP<00007H_X006;jH_X006;j00000V;j0P00
00ERnP00G_X005kj00800004G]X005kJ0002G]X20002G]X02000G]X005kJ001NfP00G]X500003U[J
001JfP00F]X005[J001JfP00F]X005[J0002F[X200002EZj001F^P00E[X005Jj001F^P02000015Jk
001F^eJk0P0000]B^`00D[/005:k001B^`00D[/005:k00800005DY/005:K001BV`0200002djK001>
V`00CY/004jK001>V`00CY/00P0000=>V`00CY/00P0000E>V`00BY/004ZK00800003BY/004ZK0080
0003BY`004ZL00H00003BY`004ZL00800005BY`004ZL001:W00200001dZL001:W000BY`004ZL0080
0003BY`004ZL00P00008B[`00000B[`004Zl001:_0800007B[`004Zl001:_@00B[d00P0000=:_@00
B]d00P0000]>g@00C]d004kM001>g@00C]d004kM00800006D]d005;m001Bo@000U;l010005;l001F
o000E_`005Kl001Fo000E_`005[l001K7080009K70D00004Fa`005/L0002Ga`02P00Ga`005lL001O
7000Ga`005lK0`0000]O6`00Ga]O6`00Ga/005lK001O6`00009O6`<00006Ga/005lKGa/006<K0P00
0V<K00<006<K0000100000iS6`00Ha]S6`00Ha/006<K001S6`00Ha/006<K0`000V;k00L006;k001R
n`00H_/00002H_/00`00H_/00002000035kk001Nn`00G_/005kj001NnP00G_X0009NnPD0000<G_X0
05kj001NnP00G_X005kj001NnP000Ukj00<005kj00000P0000ENfP00001NfP00009NfP0>001NfP00
G]X005kJ001NfP00G]X005[J001JfPD00008F]X005[J001JfP00F]X0009JfP80000GF]X005[J001J
fP00F[X005Zj001J^P00F[X005Jj001F^P00E[X005Jj001F^P0<00003eJk001F^`00E[/005Jk001F
^`00E[/005Jk001F^`02000035Jk001F^`00E[/005Jk001F^`00E[/0009F^`04001F^`00E[/20000
4EJk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0001EF^`00E[/005Jk001F^`00E[/0
05Jk001F^`00E[/005Jk001F^`00E[/00P0000QF^`00E[/005Jk001F^`000UKK00H005KK001Ff`00
E]/200000eKK001Ff`0?00002eKK000005KK001Ff`00E]/005KK00000UKK00H005KK001Ff`00E]/2
00003UKK001Ff`00E]/005KK001Ff`00E]/005KK000>Ool00`00Oomoo`0/Ool00:5oo`03001oogoo
05aoo`H00007D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg002000025;L001Bg000D]`0
05;L0002D]`200002E;L001Bg000D]`005;L001Bg00200002E;L001Bg000D[`005:l001B_0030000
1djl001>_000C[`004jl00800007C[`004jl001>_000C[`0300000M:_000B[`004Zl001:_0020000
24Jm000004Jm0016_@00A[d300001DJm0016_@00A[d01@0000=2_@00@[d00P0000=2_@00@[d00P00
00=6_@00A[d00`0000]6g@00B]d004[M001:g@00B]d004km0080000:C_d005;m001Bo@00D_d005LM
0002Ead03000Ead005/M001K7000Fa`005lL001O70@00007Ga`005lLGa`005ll00000V<l00@006<k
001S>`<0009S>`07001S>f<k001S>`00Hc/00P0000MS6`00Ha]S6`00Ha/00002Ia/01`00Ia/006LK
001W6`00009W6`07001W6VLJ001W6P00IaX00P0000YW6P00IaYW6P00IaX006LJ001W6P800007HaX0
06<JHaX006<J00000V<J00L006<J001S6P00HaX00002HaX01`00HaYS6P00HaX006<J00800008H_X0
06;j001RnP00H_X0009RnP04001RnP00H_X30002H_X00`00H_X00002H_X02@00H_X006;j001RnP00
H_X00002H_X00`00H_X00002H_X01000H_X006;j1@00019NnP00G]YNfP00G]X005kJ001NfP00G]X0
05kJ001NfP00G]X3000015kJ001NfP000U[J0P000U[J0P000U[J00H005[J001JfP00F[X200003EZj
001F^P00E[X005Jj001F^P00E[/005Jk01L00005CY/004jK001>V`0200001DjK001>V`00CY/00P00
00M>V`00CY/004jK001>V`0200001dZK001:V`00BY/004ZK00800008BY`00000BY`004ZL001:W0H0
0003BY`004ZL00800003BY`004ZL0080000?BY`004ZL001:W000BY`004ZL001:_000B[`004Zl00H0
0003B[`004Zl0080000;B[`004Zl001:_@00B[d004Zm001:_@0200003DkM001>g@00C]d004kM001>
g@00C]d004kM0080000GD]d005;m001Bo@00D_`005;l001Fo000E_`005Kl001Fo000E_`005[l001K
7005000015/L001K70000U/L00X005/L001O7000Ga`005lL001O70@00003Ga/00000009O6`08001O
6`00Ga/005lK001O6`@0000CGa/005lKGa/005lK001S6`00Ha/006<K001S6`00Ha/006<K00000V<K
00D006<K001S6`00009S6`D0000:H_/006;k001Rn`00H_/006;k0002H_/5000015kk001Nnekk0P00
00ANn`00G_X0009NnP03001NnP0000800004G_X005kj0002G_X20002G_X2000015kj001NnUkj1@00
011NfP00G]X005kJ001NfP00G]X005kJ001NfP00G]X0009NfP03001NfP0000<00008F]X005[J001J
fP00F]X0009JfP04001JfP00F]X2000025[J001JfP00F]X005Zj0002F[X01000F[X005Zj0P0000=F
^P0000001@0000MF^P00E[X005Jk001F^`0200003UJk001F^`00E[/005Jk001F^`00E[/005Jk0002
E[/05@00E[/00000E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`0200004eJk001F^`00
E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk0080000>E[/005Jk001F^`00E[/005Jk001F^`00
E[/0009F^`80000;E[/005Jk001F^`00E[/005Jk001F^`0>00008EKK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`020002E]/02P00E]/0
0000E]/005KK001Ff`000UKK00<007ooOol02goo00<007ooOol0;7oo002QOol00`00Oomoo`1LOol0
1P00D]`00000D]`0009Bg006001Bg000D]`005;L0P0000MBg000D]`005;L001Bg00200003E;L001B
g000D]`005;L001Bg000D]`005;L00800009D]`005;L001Bg000D]`005;L00800007D[`005:l001B
_000C[`00P0000M>_000C[`004jl001>_00200004Djl001>_000C[`004jl001>_000B[`004Zl001:
_000B[`02@0000Y6_0000016_@00A[d004Jm0016_@<00003A[d004Jm00800004A[d00000@[d60000
24:m000004:m0016_@00A[d300002dKM001:g@00B]d004[M001:g@00C_d00P0000Y>o@00D_d005;m
001Bo@00Ead0009G7@04001G7@00Fad200000e/L00000002000015lL001O70000UlL00T005lLGa`0
05ll001S?000Hc/00P0000AS>`00Hc/0009S>`04001S>`00Hc/200001f<K001S6f<K001S6`00009S
6`04001W6`00Ia/30002Ia/01`00Ia]W6`00IaX006LJ00800005IaX006LJIaX00002IaX200001FLJ
000006<J00000V<J00<006<J00000V<J00@006<J001S6P<0009S6P07001S6V<J001S6P00HaX00P00
00ARnP00H_YRnP800008H_X006;jH_X006;j001RnP800006H_X006;j001RnP000V;j00@006;j001R
nPD0009RnP03001RnP00009RnP0;001RnP00H_X006;j001NnP00G_X00002G_X03P00G]X005kJ001N
fP00G]X005kJ001NfP00G]X200000ekJ00000002G]X05P00G]X005[J001JfP00F]X005[J001JfP00
F]X005[J001J^P00F[X005Zj300000UF^`00E[/005Jk001B^`00D[/00P0000]B^`00D[/005:k001B
^`00D[/005:K00/00007CY/004jK001>V`00CY/00P0000E>V`00BY/004ZK00800003BY/004ZK0080
0007BY`004ZL001:W000BY`00P0000=:W000BY`02@0000E:W000BY`004ZL00800005BY`004ZL001:
W00200000dZl001:_00200001DZl001:_000B[`0200000i:_000001:_@00B[d004Zm001:g@00C]d0
04kM0P0000m>g@00C]d004kM001>g@00D]d005;M001Bo@00D_d00P0000UBo000E_`005Kl001Fo000
E_`01P0000EJo000001K7000009K7009001K7000Fa`005/L001O7000009O70<00004Ga`005lL0002
Ga/20002Ga/01000Ga/005lK0`0000AO6`00Ga/0009O6`0:001O6`00Ga/006<K001S6`00Ha/30002
Ha/01`00Ha/006<K001S6`00009S6`<00004Ga/006;k0002H_/20002H_/20002H_/3000015kk001N
n`000Ukk00P005kk001Nn`00G_/005kj1@00011NnP00G_YNnP00G_X005kj001NnP00G_X005kj001N
nP<00006G_X005kj001NfP000UkJ0P0000INfP00G]X005kJ0002G]X00`00G]X0000400001e[J0000
05[J001JfP00009JfP08001JfP00F]X005[J001JfP800008F]X005[JF]X005[J001J^PX0000QE[X0
05Jj001F^P00E[X005Jj001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/0
05Jk0080000AE[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`02000045Jk001F^`00E[/0
05Jk001F^`00E[/005Jk001F^`000UJk0P0000mF^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/0
400000MFf`00E]/005KK001Ff`0200001UKK001Ff`00E]/0009Ff`08001Ff`00E]/005KK001Ff`80
000QE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`00E]/005KK00<000eoo`03001oogoo02aoo`00XWoo00<007ooOol0G7oo014005;L000005;L001B
g000D]`005;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P0000IBg000D]aBg000D]`2
00002E;L001Bg000D]`005;L001Bg00200002E;L001Bg000D[`005:l001B_00200001Djl001>_000
C[`00P0000=>_000C[`00P0000E>_000C[`004jl0080000AC[`004Zl001:_000B[`004Zl001:_000
B[`004Zl001:_00500001DJm0016_@00A[d00P0000=6_@00A[d00P0000=6_@00A[d00`0000E2_@00
A[d004Jm00D00005A[d004Jm0016_@0200002dKM001:g@00B]d004[M001:g@00C_d00P0000m>o@00
D_d005;m001Bo@00Ead005LM001G7@00Fad00`0000AK7000Fa`0009O7003001O7000009O7004001O
7000Gc`400002V<K001S>f<k001S>`00Hc/006<k0P0000MS6`00Ha]S6`00Ha/00002Ha/01000Ha/0
06LK0P0000AS6`00Ha/0009W6`04001W6`00IaX200001F<J001W6VLJ00000VLJ00L006LJ001W6P00
HaX00002HaX00`00HaX00002HaX01000HaX006<J0P0000AS6P00HaX0009S6P04001S6P00HaX20000
3V<J001RnV;j001RnP00H_X006;j001RnP00H_X2000016;j001RnV;j0P000V;j00@006;j001RnP80
0008H_X006;j001RnP00H_X0009RnP06001RnP00H_X006;j0`000Ukj00D005kj001NnP00009NfP80
009NfP800003G]X000000080000:G]X005kJ001NfP00G]X005kJ0002F]X200002e[J001JfP00F]X0
05[J001JfP00F[X01@0000MF^P00E[X005Jj001F^P02000025Jk001F^eJk001F^`00E[/200002E:k
001B^`00D[/005:k001B^`0200000e:k001BV`0200002DjK001>V`00CY/004jK001>V`0900001DjK
001:V`00BY/00P0000M:V`00BY/004ZL001:W00200003dZL001:W000BY`004ZL001:W000BY`004ZL
001:W00600000dZL001:W00200001DZL001:W000BY`00P0000M:_000B[`004Zl001:_00200000dZl
001:_00200000dZl0000000:00000dkM001>g@0200004DkM001>g@00C]d004kM001Bg@00D]d005;m
001Bo@00D_`02@0000IFo000E_`005[l0002F_`2000015/L001K75/L0P0000EK7000Fa`005lL00@0
000CGa`005lLGa`005lL001O6`00Ga/005lK001O6`00Ga/005lK00000UlK00L005lK001O6`00Ga/0
0002Ga/500002UlK001O6`00Ha/006<K001S6`000V<K0`0000iO6`00Ga]O6`00H_/006;k001Rn`00
H_/006;k0`0001ENn`00G_]Nn`00G_/005kk001Nn`00G_/005kk001NnP00G_/005kj00000Ukj00`0
05kj001NnP00G_X005kj001NnP00G_X3000015kj001NnP000Ukj00H005kJ001NfP00G]X20002G]X0
0`00G]X00004000055[J001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X005[J0002F]X20000
0e[J0000000500001eZj001J^P00F[X005Jj00800004E[X005Jj0002E[X02000E[X005Jj001F^`00
E[/200004EJk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000aF^`00E[/005Jk001F
^`00E[/005Jk0002E[/01000E[/005Jk0P0000mF^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/0
500002QF^`00001F^`00E[/005Jk001F^`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK001Ff`80009Ff`800008E]/005KK001Ff`00E]/0009Ff`06001F
f`00E]/005KK3P0000=Ff`00Ool037oo00<007ooOol0;7oo002ROol00`00Oomoo`1LOol03P00D]`0
05;L001Bg000D]`005;L001Bg000D]`200001e;L001Bg000D]`005;L0080000=D]`005;L001Bg000
D]`005;L001Bg000D]`00P0000UBg000D]`005;L001Bg000D]`00P0000MB_000D[`005:l001>_002
00001djl001>_000C[`004jl00800007C[`004jl001>_000C[`00P0000Q>_000001:_000B[`004Zl
0P0000E:_000B[`004Zl00800004B[`00000A[d900001dJm0016_@00A[d004Jm00<00003@[d004Jm
00800004A[d00000A[d900002d[M001:g@00B]d004[M001>o@00C_d00P0000MBo@00D_d005;m001G
7@0600000e/M00000002Fa`00`00Fa`00002Ga`01P00Ga`005lL001O70800004Ga`006<L0002Ha/0
0`00Hc]S>`0200001F<k000006<K00000V<K00T006<KHa/006<K001S6`00Ha/00P0000YS6`00Ha]S
6`00Ha/006LK001W6`800005Ha/006<JHaX00002IaX01000IaX006LJ0`000V<J00<006<J00000V<J
00@006<J001S6P80000:HaX006<JHaX006<J001S6P00HaX200003V<J001S6V<J001RnP00H_X006;j
001RnP00H_X2000036;j001RnV;j001RnP00H_X006;j001RnP800006H_X006;jH_X006;j0P000V;j
00H006;j001RnP00H_X2000025kj001NnP00G_X005kj0002G_X01000G]X005kJ1@0000INfP00G]X0
05kJ0002G]X20002G]X01000G]X005[J0P000U[J0P0000=JfP000000100000EJ^P00001J^P00009F
^P0C001F^P00001F^P00E[/005Jk001F^`00E[/005Jk001B^`00D[/00P0000]B^`00D[/005:k001B
^`00D[/005:K00800005CY/004jK001>V`0200000djK001>V`0200001DjK001>V`00CY/0200000=:
V`00BY/00P0000M:W000BY`004ZL001:W00200000dZL001:W00200000dZL001:W00200001DZL001:
W000BY`01P0000=:W000BY`00P0000E:_000B[`004Zl00800007B[`004Zl001:_000B[`00`0000]:
_000B[`004Zl001:_@00C[d004kM01L00008E_`005Kl001Fo000E_`0009Fo00<001Fo000F_`005[l
001K7000Fa`005/L0P0000=K700000000P0000AO7000Ga`0009O700:001O7000Ga`005lK001O6`00
Ga/50002Ga/01`00Ga/005lK001O6`00009O6`<00004Ga/005lK0002Ga/20002Ha/200000f<K0000
000200003UlK001O6elK001O6`00H_/006;k001Rn`00H_/300002ekk001Nnekk001Nn`00G_/005kk
00000Ukk1P000Ukk00T005kj001NnP00G_X005kj00000Ukj1P00011NnP00G_YNnP00G_X005kj001N
fP00G]X005kJ001NfPD00006G]X005kJ001JfP000U[J00`005[J000005[J001JfP00F]X005[J0002
F]X00`00F]X00005000035[J001JfP00F[X005Zj001J^P00F[X0009F^P80000?E[X005Jj001F^P00
E[X005Jj001F^`00E[/005Jk0080000<E[/005Jk001F^`00E[/005Jk001F^`000UJk00l005Jk0000
05Jk001F^`00E[/005Jk001F^`00E[/0600001AF^`00001F^`00E[/005Jk001F^`00E[/005Jk001F
^`00E[/005Jk0P000UJk00h005Jk001F^`00E[/005KK001Ff`00E]/005KK0P00025Ff`00E]/005KK
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/02P00
00aFf`00E]/005KK001Ff`00E]/005KK0002E]/00`00Oomoo`0:Ool00`00Oomoo`0/Ool00:=oo`03
001oogoo05aoo`0A001Bg000001Bg000D]`005;L001Bg000D]`005;L001Bg00200001e;L001Bg000
D]`005;L00800003D]`005;L02800003C[`004jl00800009C[`004jl001>_000C[`004jl00800005
B[`004Zl001:_002000024Zl000004Zl001:_000B[`300001dJm0016_@00A[d004Jm00D00003A[d0
04Jm00800003@[d004:m00800003A[d004Jm00<00007A[d004Jm0016g@00A]d05@0000IG7@00Ead0
05LM0002Fad20002Fa`01P00Fa`005lL001O70@00007Ga`005lLGa`006<L00000V<K00L006<k001S
>`00Ha/00002Ha/02@00Ha]S6`00Ha/006<K001S6`0200001F<K001S6f<K00000V<K0P0000EW6`00
001S6`00009S6`07001S6V<J001W6P00IaX00P0000IS6P00HaX006<J0002HaX01000HaX006<J0P00
00YS6P00HaYS6P00HaX006<J001S6P800007HaX006<JHaX006<J00000V;j00D006;j000006;j0080
000<H_X006;jH_X006;j001RnP00H_X006;j0P0000iRnP00H_YRnP00H_X006;j001RnP00H_X006;j
100000IRnP00G_X005kj0002G_X03@00G_X005kj001NfP00G]X005kJ001NfP00009NfP0@001NfP00
G]X005kJ001NfP00G]X005kJ001JfP00F]X500004e[J001JfP00F]X005Zj001J^P00F[X005Jj001F
^P00E[X005Jj00800008E[/005JkE[/005Jk001F^`800009D[/005:k001B^`00D[/005:k00800003
D[/005:K0080000;CY/004jK001>V`00CY/004jK001>V`0200000djK001>V`0200001DjK001>V`00
CY/02@0000E:W000BY`004ZL00800003BY`004ZL00800009BY`004ZL001:W000BY`004ZL00800004
BY`00000BY`800001DZl001:_000B[`00P0000E:_000B[`004Zl0080000;B[`004Zl001:_000B[`0
04Zm001>_@0200000dkM001>g@0200009dkM001>g@00C]d005;M001Bg@00D_d005;l001Bo000D_`0
05Kl001Fo000E_`005Kl001Fo000E_`005[l001Jo000Fa`005/L001K7003000015/L001K70000UlL
00X005lL001O7000Ga`005lL001O6`@00006Ga/005lK001O6`000UlK0P0000=O6`00Ga/0100001=O
6`00Ga]O6`00Ga/005lK001O6`00Ha/006<K001O6`00Ga/00002Ga/01`00Ga/005lK001Rn`00009R
n`<0000<G_/005kk001Nn`00G_/005kk001Nn`000Ukk0`0000aNn`00G_/005kk001Nn`00G_X005kj
0002G_X00`00G_X00002000045kj001NnP00G_X005kj001NnP00G_X005kj001NfP000UkJ100000IN
fP00G]X005kJ0002G]X02000F]X005[J001JfP00F]X200001U[J001JfU[J001JfPD0000;F]X00000
F]X005[J001JfP00F[X00002F[X01P00F[X005Zj001F^P80000ME[X005Jj001F^P00E[X005Jj001F
^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`0B00001EJk001F^`00E[/00P00015F
^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk00800004E[/005Jk0002E[/02P00E[/005Jk
001F^`00E[/005Jk0P0001EF^`00E[/005Jk001F^`00E[/005KK001Ff`00E]/005KK001Ff`00E]/0
0P0000IFf`00E]/005KK0002E]/02000E]/005KK001Ff`00E]/>00001eKK001Ff`00E]/005KK0080
009Ff`0=001Ff`00E]/005KK001Ff`00E]/005KK000037oo00<007ooOol0;7oo002TOol00`00Oomo
o`1KOol02000D]`005;L001Bg000D]`G00001e;L001Bg000D]`005;L00800009D]`005;L001Bg000
D]`005;L00800007D]`005;L001B_000D[`00P0000E>_000C[`004jl01000007B[`004Zl001:_000
B[`00P0000E:_000B[`004Zl00800008B[d00000A[d004Jm0016_@<00003A[d004Jm00L00007@[d0
04Jm0016_@00A[d00`0000E6_@00A[d004KM00<0000;B]d004[M001:g@00C_d004km001>o@020000
1U;m001Bo@00E_d0009G7@05001G7@00Ead00002Fad20002Fa`200001elL000005lL001O7000009O
7009001O75lL001S7000Ha/006<k00<0009S6`07001S6f<K001S6`00Ha/0100000ES6`00Ha]S6`00
009S6`07001S6`00Ha/006<K00000V<K00L006<KHa/006<J001W6P02000016<J001S6V<J0P000V<J
00@006<J001S6P800005HaX006<JHaX00002HaX200001F<J000006<J00000V<J00<006<J00000V<J
00@006;j001RnP<00007H_X006;jH_X006;j00000V;j00<006;j00000P0000MRnP00H_YRnP00H_X0
0002H_X200000f;j001RnP02000016;j001RnP000V;j00`005kj001NnP00G_X005kj001NnP00G]X3
0002G]X04P00G]X005kJ001NfP00G]X005kJ001NfP00G]X005kJ001JfP<00004F]X005[J0002F]X0
1P00F]X005[J001J^P800006F[X005JjE[X005Jj0P0000]F^P00E[/005Jk001F^`00E[/005Jk0080
0009D[/005:k001B^`00D[/005:k0080000;D[/005:K001BV`00CY/004jK001>V`0200000djK001>
V`0200002DjK001>V`00CY/004jK001>V`0300001djK001:V`00BY/004ZL00H00005BY`004ZL001:
W00200000dZL001:W00200001dZL001:W000BY`004ZL00<00007BY`004Zl001:_000B[`01P0000i:
_000001:_000B[`004Zl001:_000B[`004Zl0P0000U:_@00C[d004kM001>g@00C]d00P0000m>g@00
C]d004kM001Bg@00D]d005;m001Bo000D_`00P000UKl00@005Kl001Fo0800007E_`005Kl001Jo000
F_`01P0000=K700000000U/L00<005/L00000UlL0P0000AO7000GaaO70<00004Ga`005lK0002Ga/0
2000Ga/005lK001O6`00Ga/3000015lK001O6`000UlK00X005lK001O6`00Ga/005lK001S6`<0009O
6`07001O6`00Ga/005lK00000UlK1@0000ANn`00G_]Nn`800004G_/005kk0002G_/00`00G_/00002
000015kk001Nn`000Ukk0P0000ANn`00G_X0009NnPD00004G_X005kj0002G_X200001Ukj001NnP00
G_X0009NnP03001NfP0000800005G]X00000G]X00002G]X04000G]X005kJ001JfP00F]X005[J001J
fP00F]X005[J1@0000MJfP00F]X005[J001JfP020002F]X03000F]X005Zj001J^P00F[X005Zj001F
^P800004E[X005Jj0002E[X02000E[X005Jj001F^`00E[/200000eJk0000000;00000eJk001F^`02
00004EJk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000AF^`00E[/0009F^`0:001F
^`00E[/005Jk001F^`00E[/200004eJk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk
0080000KE[/005Jk001F^`00E[/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK
00`0000<E]/005KK001Ff`00E]/005KK001Ff`000UKK0P0001AFf`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`0037oo00<007ooOol0;7oo002TOol00`00Oomoo`1LOol800002E;L001B
g000D]`005;L001Bg00200001e;L001Bg000D]`005;L0080000:D]`005;LD]`005;L001Bg000D]`2
00002E;L001Bg000D]`005;L001Bg00200001e;L001Bg000D[`005:l00800003C[`004jl00800003
C[`004jl00800009C[`004jl001>_000C[`004jl00`00005B[`004Zl001:_00200000dJm0016_@02
00000dJm0016_@02000024Jm000004Jm0016_@00A[d500001DJm0016_@00A[d00P0000E6_@00A[d0
04KM00<0000;B]d004[M001:g@00C_d004km001>o@0200001U;m001Bo@00E_d0009G7@0:001G7@00
Ead005/M001K7000Fa`300001elL001O75lL001O7000009O7004001O7000Ha`4000016<K001S6`00
0V<K00@006<K001S6`800004Ha/006<K0002Ha/01`00Ha]S6`00Ha/006<K00<0009S6`07001S6f<K
001S6`00HaX00P0000aS6P00HaYS6P00HaX006<J001S6P00HaX200001F<J001S6V<J00000V<J00L0
06<J001S6P00HaX00002HaX00`00HaX00002HaX01000HaX006;j0`0000MRnP00H_YRnP00H_X00002
H_X01`00H_X006;j001RnP00009RnP03001RnP00009RnP04001RnP00H_X3000046;j001RnV;j001R
nP00H_X005kj001NnP00G_X005kj100000QNfP00G]X005kJ001NfP000UkJ00@005kJ0000009NfP80
0003G]X0000000800003F]X00000009JfP0B001JfP00F]X005[J001JfP00F[X005Zj001J^P00E[X0
05Jj0P0000mF^P00E[/005Jk001F^`00E[/005Jk001B^`00D[/00P0000]B^`00D[/005:k001B^`00
D[/005:K00800005CY/004jK001>V`0200002DjK001>V`00CY/004jK001>V`0200001DjK001>V`00
CY/00P0000E>V`00BY/004ZK00800005BY`004ZL001:W00700001DZL001:W000BY`00P0000E:W000
BY`004ZL00800007BY`004ZL001:_000B[`00P0000E:_000B[`004Zl00T00005B[`004Zl001:_002
00004DZm001>_@00C]d004kM001>g@00C]d004kM001>g@00C]d00P0000mBg@00D_d005;l001Bo000
D_`005Kl001Fo000E_`00P0000=Fo0000000100000IJo000F_`005/L0002Fa`20002Fa`01000Fa`0
05lL0P0000=O700000000P0000iO7000GaaO7000Ga/005lK001O6`00Ga/005lK0`0000iO6`00Ga]O
6`00Ga/005lK001O6`00Ga/005lK100000YO6`00Ga/005lK001O6`00Ga/0009O6`<00004G_/005kk
0002G_/01000G_/005kk0P000Ukk1@0000iNn`00G_]Nn`00G_/005kk001Nn`00G_/005kj0`0000AN
nP00G_X0009NnP06001NnP00G_X005kj0P000Ukj00<005kj00001000011NfP00G]X005kJ001NfP00
G]X005kJ001NfP00F]X0009JfP03001JfP0000D00008F]X005[J001JfP00F]X0009JfP80000>F]X0
05[J001JfP00F[X005Zj001J^P00F[X0009F^P800003E[X005Jj00h0000?E[/005Jk001F^`00E[/0
05Jk001F^`00E[/005Jk00800004E[/005Jk0002E[/02P00E[/005Jk001F^`00E[/005Jk0P0001=F
^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`0200004EJk001F^`00E[/005Jk001F
^`00E[/005Jk001F^`00E[/00P000UJk00h005Jk001F^`00E[/005KK001Ff`00E]/005KK300000UF
f`00E]/005KK001Ff`00E]/00P000UKK0`0000UFf`00E]/005KK001Ff`00E]/00P00019Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/005KK0002E]/00`00Oomoo`0:Ool00`00Oomoo`0[Ool00:Eo
o`03001oogoo05]oo`0B001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`005;L0P0000MBg000
D]`005;L001Bg00200003E;L001Bg000D]`005;L001Bg000D]`005;L00800007D]`005;L001Bg000
D]`00P0000UBg000D[`005:l001>_000C[`00P0000E>_000C[`004jl0080000CC[`004jl001>_000
C[`004jl001>_000B[`004Zl001:_000B[`01`0000Y:_@000016_@00A[d004Jm0016_@<00005A[d0
04Jm0016_@0300000dJm0016_@0700001dJm0016_@00A]d004KM0080000;B]d004[M001:g@00C_d0
04km001>o@0200002e;m001Bo@00E_d005LM001G7@00Ead01P0000IK7000Fa`005lL0002Ga`01P00
Ga`005lL001O70800004Ga`006<K0002Ha/01P00Ha/006<K001S6`800007Ha/006<KHa/006<K0000
0V<K00@006<K001S6`800004Ha/006<K0002Ha/01000Ha/006<K0P0000MS6`00HaYS6P00HaX00002
HaX200001F<J000006<J00000V<J00L006<JHaX006<J001S6P030002HaX00`00HaX00002HaX01000
HaX006<J0P0000QRnP00H_X006;j001RnP000V;j00@006;j001RnP<0009RnP03001RnP00009RnP09
001RnP00H_X006;j001RnP00009RnP0<001RnP00H_X006;j001NnP00G_X005kj0P0000ANnP00G]X0
009NfP80009NfP08001NfP00G]X005kJ001NfPD0000<G]X005[J001JfP00F]X005[J001JfP000U[J
014005[J000005Zj001J^P00F[X005Jj001F^P00E[X005Jj00800003E[/0000001/00007CY/004jK
001>V`00CY/00P0000E>V`00CY/004jK00800003CY/004jK0080000;CY/004ZK001:V`00BY`004ZL
001:W00300001DZL001:W000BY`01P0000=:W000BY`00P0000M:W000BY`004ZL001:W00200001dZl
001:_000B[`004Zl00<00007B[`004Zl001:_000B[`02P0000i>_@00001>g@00C]d004kM001>g@00
C]d004kM0P0000]Bg@00D_d005;l001Bo000D_`005Kl00L00006E_`005Kl001Fo0000U[l00h005[l
001K7000Fa`005/L001K7000Fa`005lL0`0000AO7000Ga`0009O700:001O7000Ga/005lK001O6`00
Ga/200000elK00000002Ga/01`00Ga/005lK001O6`00009O6`<00004Ga/005lK0002Ga/20002Ga/2
0002Ga/300003Ukk001Nnekk001Nn`00G_/005kk001Nn`00G_/3000015kk001Nn`000Ukk00X005kk
001Nn`00G_/005kk001Nn`<00004G_/005kj0002G_X02P00G_X005kj001NnP00G_X005kj1@0000IN
fP00G]X005kJ0002G]X200001UkJ001NfP00G]X0009NfP03001JfP0000@00007F]X00000F]X005[J
00000U[J00P005[J001JfP00F]X005[J0P0000IJfP00F]X005Zj0002F[X01000F[X005Zj200000]F
^P00E[X005Jk001F^`00E[/005Jk00800006E[/005Jk001F^`000UJk00P005Jk001F^`00E[/005Jk
0P00015F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk0080000AE[/005Jk001F^`00E[/0
05Jk001F^`00E[/005Jk001F^`02000015Jk001F^`000UJk00X005Jk001F^`00E[/005Jk001F^`80
0003E[/000000100000<E]/005KK001Ff`00E]/005KK001Ff`000UKK01/005KK000005KK001Ff`00
E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00P000UKK00P005KK001Ff`00E]/0
05KK1@0037oo00<007ooOol0:goo002UOol00`00Oomoo`1LOol02P00D]`005;L001Bg000D]`005;L
0P0000MBg000D]`005;L001Bg00200004E;L001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`0
0P0000UBg000D]`005;L001Bg000D]`00P0000MBg000D]`005:l001B_00200002Djl001>_000C[`0
04jl001>_002000024jl000004jl001>_000C[`200001djl001:_000B[`004Zl00<00005B[`004Zl
001:_00700001DJm0016_@00A[d00P0000=6_@00A[d00P0000A6_@000016_@800005A[d004Jm0016
_@0900000d[M001:g@0200003D[M001>o@00C_d004km001Bo@00D_d005;m00L00006Ead005/L001K
70000U/L00X005/L001O7000Ga`005lL001O70800007Ga`005lLGa`006<K00000V<K00L006<K001S
6`00Ha/00002Ha/00`00Ha/00002Ha/01000Ha/006<K0P0000YS6`00Ha]S6`00Ha/006<K001S6`80
0007Ha/006<KHa/006<J00000V<J00L006<J001S6P00HaX00002HaX01`00HaYS6P00HaX006<J0080
0006HaX006<J001S6P000V<J00@006<J001S6P800004H_X006;jH_X2000026;j001RnV;j001RnP00
H_X200001V;j001RnP00H_X0009RnP06001RnP00H_X006;j0`000V;j00<006;j00000V;j00H006;j
001RnP00G_X300004Ukj001NnUkj001NfP00G]X005kJ001NfP00G]X005kJ001NfP<00004G]X005kJ
0002G]X01000F]X005[J0P000U[J00X005[J001JfP00F]X005[J001J^P800003F[X005Jj00T00007
E[/005Jk001F^`00E[/00P0000UB^`00D[/005:k001B^`00D[/00P0000UB^`00D[/005:k001BV`00
CY/02`0000M>V`00CY/004jK001>V`0200001djK001>V`00BY/004ZK00800005BY`004ZL001:W002
00000dZL001:W00200001DZL001:W000BY`02@0000E:W000BY`004Zl00800007B[`004Zl001:_000
B[`00P0000E:_000B[`004Zl00800005B[`004Zl001:_00200000djl0000000J00001EKl001Fo000
E_`00P000UKl010005Kl001Fo000F_`005[l001K7000Fa`005/L001K70@00003Fa`00000009O700:
001O7000Ga`005lL001O6`00Ga/4000015lK001O6elK0P0000AO6`00Ga]O6`800003Ga/000000080
000>Ga/005lKGa/005lK001O6`00Ga/005lK001O6`<0000;G_/005kkG_/005kk001Nn`00G_/00002
G_/400003Ekk001Nnekk001Nn`00G_/005kk001Nn`00009Nn`@0000=G_/005kkG_/005kj001NnP00
G_X005kj00000Ukj0P0000QNnP00G_X005kJ001NfP000UkJ00H005kJ001NfP00G]X20002G]X00`00
G]X0000400001E[J001JfP00F]X00P000U[J00`005[J001JfP00F]X005[J001JfP00F]X20002F]X0
1000F]X005Zj1`0000mF^P00001F^P00E[X005Jj001F^P00E[/005Jk00000UJk01<005Jk000005Jk
001F^`00E[/005Jk001F^`00E[/005Jk001F^`0200004EJk001F^`00E[/005Jk001F^`00E[/005Jk
001F^`00E[/00P0000AF^`00E[/0009F^`0:001F^`00E[/005Jk001F^`00E[/200001EJk001F^`00
E[/0400000mF^`00E[/005KK001Ff`00E]/005KK001Ff`00E]/00P000UKK00h005KK001Ff`00E]/0
05KK001Ff`00E]/005KK0P00011Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0009Ff`800005
E]/005KK001Ff`0;000015KK001Ff`0037oo00<007ooOol0:goo002VOol00`00Oomoo`1KOol01@00
D]`005;L00000U;L0P0000UBg000D]`005;L001Bg000D]`00P0000]Bg000D]`005;L001Bg000D]`0
05;L00800009D]`005;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P0000UBg000D[`0
05:l001>_000C[`00P0000E>_000C[`004jl00800009C[`004jl001>_000C[`004jl00800008C[`0
0000B[`004Zl001:_0800003B[`004Zl00800006B[d00000B[d004Jm1`0000M6_@00A[d004Jm0016
_@02000044Jm000004Jm0016_@00A[d004Jm0016g@00B]d004[M4`0000IFo@00Ead005LM0002Ead0
1@00Fa`005/L00000U/L00D005/L000005lL00@00005Ga`005lLGa`00002Ga`01P00Ha/006<K001S
6`<0009S6`09001S6f<K001S6`00Ha/006<K00800005Ha/006<KHa/00002Ha/200001F<K000006<K
00000V<K00<006<K00000V<J00@006<J001S6P<0009S6P07001S6V<J001S6P00HaX00P0000AS6P00
HaYS6P80009S6P04001S6P00HaX200003V;j001RnV;j001RnP00H_X006;j001RnP00H_X2000016;j
001RnV;j0P000V;j00@006;j001RnP@00006H_X006;j001RnP000V;j00H006;j001RnP00H_X30000
45kj001NnUkj001NnP00G]X005kJ001NfP00G]X005kJ100000=NfP0000000UkJ01@005kJ001NfP00
F]X005[J001JfP00F]X005[J001JfP00F]X005[J1`0000=F^P00E[X00P0000AF^`00E[/0009F^`80
000;E[/005Jk001B^`00D[/005:k001B^`0200002E:k001B^`00D[/005:k001B^`0200000djK001>
V`0200001djK001>V`00CY/004jK00/00005CY/004ZK001:V`0200001DZL001:W000BY`00P0000U:
W000BY`004ZL001:W000BY`00`0000E:W000BY`004Zl00P0000<B[`00000B[`004Zl001:_000B[`0
04Zl0P0000U:_000B[`004Zl001:_000B[`00`0000m>g000C]`004kL001>g@00C]d004kM001>g@00
D]d00P0000YBg000D_`005;l001Bo000D_`0009Fo004001Fo000E_`20002E_`02`00E_`00000F_`0
05[l001K7000Fa`0100000AK7000Fa`0009K7080009O70800004Ga`005lLGa`3000015lK001O6`00
0UlK00l005lK001O6`00Ga/005lK001O6`00Ga/005lK00000UlK00X005lK001O6`00Ga/005lK001O
6`<0000;G_/005kkG_/005kk001Nn`00G_/00002G_/300000ekk00000002G_/01`00G_/005kk001N
n`00009Nn`03001Nn`000080000<G_/005kk001Nn`00G_/005kj001NnP000Ukj00<005kj00001@00
011NnP00G]YNfP00G]X005kJ001NfP00G]X005kJ001NfPD00008F]X005[J001JfP00F]X0009JfP80
000:F]X005[J001JfP00F]X005[J0002F]X200000e[J0000000500001eZj001J^P00F[X005Jj0080
000@E[X005JjE[X005Jj001F^P00E[/005Jk001F^`00E[/200003eJk001F^`00E[/005Jk001F^`00
E[/005Jk001F^`02000015Jk001F^`000UJk00X005Jk001F^`00E[/005Jk001F^`800005E[/005Jk
001F^`0D00002eJk001F^`00E[/005Jk001F^`00E[/00P0000IF^`00E[/005Jk0002E]/01P00E]/0
05KK001Ff`80000GE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`02
0002E]/300001eKK001Ff`00E]/005KK00X0000>E]/005KK001Ff`00E]/005KK001Ff`00E]/000ao
o`03001oogoo02]oo`00Ygoo00<007ooOol0Fgoo00X005;L001Bg000D]`005;L001Bg0800007D]`0
05;L001Bg000D]`00P0000MBg000D]`005;L001Bg00[00002Tjl000004jl001>_000C[`004jl0P00
00M:_000B[`004Zl001:_00300001DZl001:_000B[d00P0000Q:_@000016_@00A[d004Jm1`0000=6
_@00A[d00P0000e6_@00A[d004Jm0016_@00A[d004KM001:g@0200000d[M001:g@02000054kM001>
o@00C_d004km001Bo@00D_d005;m001Fo@00Ead005LM0002Ead02000Fa`005/L001K7000Fa`30000
15lL001O70000UlL00T005lLGa`005lL001S6`00Ha/00P0000AS6`00Ha/0009S6`06001S6`00Ha/0
06<K0P0000ES6`00Ha]S6`00009S6`07001S6`00Ha/006<K00000V<K00<006<K00000V<K00@006<J
001S6P800004HaX006<J0002HaX01000HaX006<J0P0000aS6P00HaYS6P00HaX006<J001S6P00HaX2
00003V<J001RnV;j001RnP00H_X006;j001RnP00H_X2000036;j001RnV;j001RnP00H_X006;j001R
nP800004H_X006;j0002H_X20002H_X01P00H_X006;j001RnP<00007G_X005kjG_X005kj00000Ukj
0P000UkJ0P0000mNfP00001NfP00G]X005kJ001NfP00G]X005kJ00000UkJ0P0000UJfP00F]X005[J
001JfP00F]X01@0001MJ^P00F[X005Zj001F^P00E[X005Jj001F^`00E[/005Jk001F^`00E[/005Jk
00800009D[/005:k001B^`00D[/005:k0080000;D[/005:k001B^`00DY/004jK001>V`0200001DjK
001>V`00CY/00P0000=>V`00CY/00P0000=>V`00CY/0200000E:W000BY`004ZL00800005BY`004ZL
001:W00200001DZL001:W000BY`00P0000=:W000BY`00P0000M:_000B[`004Zl001:_00600002TZl
000004Zl001:_000B[`004Zl0P0000E:_000B[`004Zl0080000AC[`004kL001>g000C]`004kM001>
g@00C]d004kM001Bg@0200005E;L001Bo000D_`005;l001Bo000E_`005Kl001Fo000E_`005Kl001F
o00200000e[l00000004000015/L001K70000U/L00P005/L001K7000Ga`005lL0P0000=O70000000
0P00011O6`00Ga]O6`00Ga/005lK001O6`00Ga/005lK001O6`<0009O6`09001O6`00Ga/005lK001O
6`00009O6`<0000:Ga/005lK001Nn`00G_/005kk0002G_/00`00G_/00002000015kk001Nnekk0P00
00INn`00G_/005kk0002G_/5000015kk001Nnekk0P0000INn`00G_/005kj0002G_X5000045kj001N
nP00G_X005kj001NfP00G]X005kJ001NfP000UkJ100000INfP00F]X005[J0002F]X01P00F]X005[J
001JfP800004F]X005[J0002F]X01000F]X005[J1P0000YJfP00F]X005Zj001J^P00F[X0009J^P0C
001F^P00001F^P00E[X005Jj001F^P00E[/005Jk001F^`00E[/00P0000IF^`00E[/005Jk0002E[/0
2000E[/005Jk001F^`00E[/200000eJk001F^`0D00002eJk001F^`00E[/005Jk001F^`00E[/00P00
00aF^`00E[/005Jk001F^`00E[/005Jk0002E[/04`00E[/00000E[/005Jk001F^`00E[/005KK001F
f`00E]/005KK0080000@E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0002E]/01`00E]/00000
E]/005KK00d00009E]/00000E]/005KK001Ff`00009Ff`06001Ff`00E]/005KK0P0000AFf`00E]/0
00aoo`03001oogoo02]oo`00Ygoo00<007ooOol0Fgoo00H005;L001Bg000D]`F00000e;L001Bg002
00002E;L001Bg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800009D]`005;L001Bg000
D[`004jl00800007C[`004jl001>_000C[`03P0000M:_000B[`004Zl001:_00200001DZl001:_000
B[d00P0000i:_@000016_@00A[d004Jm0016_@00A[d004Jm1`0000E6_@00A[d004Jm00800005A[d0
04KM001:g@0200000d[M001:g@0200006DkM001>o@00C_d004km001Bo@00D_d005;m001Fo@00Ead0
05LM001G7@00Fa`005/L00@00008Fa`005lL001O7000Ga`0009O7004001O7000Ga`400002V<K001S
6f<K001S6`00Ha/006<K100000ES6`00Ha]S6`00009S6`04001S6`00Ha/30002Ha/00`00Ha/00002
Ha/01000Ha/006<J0P0000YS6`00HaYS6P00HaX006<J001S6P80000<HaX006<JHaX006<J001S6P00
HaX006<J0P0000MS6P00HaYS6P00H_X00002H_X00`00H_X00004000036;j001RnV;j001RnP00H_X0
06;j001RnP80000@H_X006;jH_X006;j001RnP00H_X006;j001RnP00H_X2000025kj001NnP00G_X0
05kj0002G_X01000G_X005kJ1@0000ANfP00G]YNfP80009NfP80009NfP08001NfP00G]X005[J001J
fPL0000?F]X005[J001JfP00F[X005Zj001J^P00E[X005Jj00800004E[/005Jk0002E[/200002eJk
001F^`00D[/005:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[/00P0000=>V`00CY/00P00
00]>V`00CY/004jK001>V`00CY/004jK0080000:CY/00000CY/004jK001>V`00CY/900001DZL001:
W000BY`00P0000=:W000BY`00P0000]:W000BY`004Zl001:_000B[`004Zl00<00003B[`004Zl00X0
000@B[`00000B[`004Zl001:_000C[`004jl001>g000C]`200003dkM001>g@00C]d004kM001Bg@00
D]`005;L001Bo00200003E;l001Bo000E_`005Kl001Fo000E_`005Kl00D00006F_`005[l001Jo000
0U/L00`005/L001K7000Fa`005/L001O7000Ga`3000015lL001O70000UlK00L005lK001O6`00Ga/0
0002Ga/500002UlK001O6`00Ga/005lK001O6`000UlK1@0000AO6`00Ga]O6`80009Nn`80009Nn`D0
0006G_/005kkG_/005kk0P000Ukk00@005kk001Nn`<00004G_/005kk0002G_/01000G_/005kk0P00
0Ukk00<005kj00000P0000INnP00G_X005kj0002G_X200001Ukj001NfP00G]X0009NfP03001NfP00
00800005G]X00000G]X00002F]X02P00F]X005[J001JfP00F]X005[J0P000U[J00<005[J00001P00
00=JfP00F]X00P0000AJfP00F]X0009J^P08001J^P00F[X005Zj001F^P80000<E[X005Jj001F^P00
E[X005Jk001F^`000UJk00T005Jk000005Jk001F^`00E[/0400000]F^`00E[/005Jk001F^`00E[/0
05Jk0080000>E[/005Jk001F^`00E[/005Jk001F^`00E[/0009F^`80000AE[/005Jk001F^`00E[/0
05Jk001F^`00E[/005Jk001F^`0200004eJk001F^`00E[/005Jk001Ff`00E]/005KK001Ff`00E]/0
05KK0080009Ff`0:001Ff`00E]/005KK001Ff`00E]/:00007EKK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00P000UKK00<005KK00002goo00<007oo
Ool0:goo002XOol00`00Oomoo`1KOol500001E;L001Bg000D]`00P0000MBg000D]`005;L001Bg002
00001U;L001Bg000D]`0009Bg00=001Bg000001Bg000D]`005;L001Bg000D]`00P0000MBg000D]`0
05;L001Bg00200002E;L001Bg000D]`005:l001>_00200001Djl001>_000C[`00P0000Y>_000001>
_000C[`004jl001>_0800003C[`0000000L00007B[`004Zl001:_@00B[d00P0000=6_@00A[d00P00
00I6_@000016_@00A[d200000dJm0016_@0200000dJm0000000700002DKM001:g@00B]d004[M001:
g@0200003DkM001>o@00C_d004km001Bo@00D_d005;m00800003Ead005LM00H00004Fa`005/L0002
Fa`02P00Ga`005lL001O7000Ga`005lL0P0000AO7000Ga/0009S6`03001S6f<K00800007Ha/00000
Ha/006<K00000V<K00L006<KHa/006<K001S6`02000016<K001S6`000V<K00H006<K001S6`00Ha/2
00002V<K001S6f<K001S6P00HaX006<J0P0000MS6P00HaYS6P00HaX00002HaX00`00HaX000020000
1f<J001S6V<J001S6P00009RnP09001RnP00H_X006;j001RnP00009RnP03001RnP00009RnP03001R
nP000080000>H_X006;jH_X006;j001RnP00H_X006;j001RnP@00004H_X005kjG_X200003ekj001N
nUkj001NnP00G_X005kJ001NfP00G]X00002G]X04000G]X005kJ001NfP00G]X005kJ001NfP00G]X0
05[J0`0001eJfP00F]X005[J001JfP00F]X005[J001J^P00F[X005Zj001F^P00E[X005Jj001F^`00
E[/005Jk0080000;E[/005Jk001B^`00D[/005:k001B^`0200002E:k001B^`00D[/005:k001B^`02
00002djK001>V`00CY/004jK001>V`00CY/00P0000=>V`00CY/00P0000U>V`00CY/004jK001>V`00
CY/00`0000E>W000BY`004ZL00P00003BY`004ZL00800007BY`004ZL001:W000B[`00P0000E:_000
B[`004Zl0080000<B[`00000B[`004Zl001:_000B[`004Zl2`0000E>_000C]`004kL0080000?C]d0
04kM001>g@00C]d005;M001Bg000D]`005;l00800005D_`005;l001Fo00800000eKl001Fo0020002
F_`03P00F_`005[l001K7000Fa`005/L001K7000Fa`400000elL00000002Ga`02P00Ga`005lK001O
6`00Ga/005lK100000AO6`00Ga/0009O6`80009O6`80009O6`<00004Ga/005lK0002Ga/02000Ga/0
05lK001Nn`00G_/3000015kk001Nn`000Ukk00X005kk001Nn`00G_/005kk001Nn`<0000>G_/005kk
G_/005kk001Nn`00G_/005kk001Nn`D00004G_/005kj0002G_X01P00G_X005kj001NnP80009NfP03
001NfP0000@0000BG]X005kJ001NfP00G]X005[J001JfP00F]X005[J001JfP000U[J1P0001UJfP00
F]X005[J001JfP00F]X005[J001JfP00F]X005Zj001J^P00F[X005Zj001F^P02000035Jj001F^UJj
001F^P00E[X005Jk001F^``00009E[/005Jk001F^`00E[/005Jk0080000>E[/005Jk001F^`00E[/0
05Jk001F^`00E[/0009F^`80000?E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk0080000CE[/0
05Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000IF^`00E[/005Jk0002E]/01P00
E]/005KK001Ff`800003E]/005KK00d00003E]/005KK00800007E]/005KK001Ff`00E]/00P0000=F
f`00E]/00P0001YFf`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`002goo00<007ooOol0:goo002XOol00`00Oomoo`1KOol01@00D]`005;L00000U;L00@005;L001B
g0800007D]`005;L001Bg000D]`00P0000eBg000D]`005;L001Bg000D]`005;L001Bg00200001e;L
001Bg000D]`005;L00800009D]`005;L001Bg000D]`005;L00800007D]`005:l001>_000C[`00P00
00M>_000C[`004jl001>_00200001djl001>_000C[`004jl00<00007B[`004Zl001:_000B[`03000
00E6_@00A[d004Jm00800008A[d00000A[d004Jm0016_@<00007A[d004Jm0016_@00A[d02`0000Y:
g@00001>o@00C_d004km001Bo@T00006Ead005LM001K70000U/L00<005/L00000U/L00D005lL0000
05lL00@00007Ga`005lLGa`005lK00000V<K00L006<K001S6`00Ha/00002Ha/00`00Ha/00002Ha/0
1000Ha/006<K0P0000aS6`00Ha]S6`00Ha/006<K001S6`00Ha/200001F<K001S6f<K00000V<K0P00
00ES6P00001S6P00009S6P03001S6P00009S6P07001S6P00HaX006<J00000V<J00<006<J00000V<J
00@006;j001RnP<0009RnP05001RnP00H_X00002H_X01`00H_X006;j001RnP00009RnP03001RnP00
009RnP80009RnP<00004H_X006;j0002H_X03000G_X005kj001NnP00G_X005kj001NnP<0009NfP05
001NfP00G]X00002G]X200001ekJ001NfP00G]X005kJ00D0000DF]X005[JF]X005[J001JfP00F]X0
05[J001JfP00F[X005Zj001J^P80000?E[X005Jj001F^`00E[/005Jk001F^`00E[/005Jk00800009
D[/005:k001B^`00D[/005:k0080000;D[/005:k001B^`00DY/004jK001>V`0200001DjK001>V`00
CY/00P0000M>V`00CY/004jK001>V`0200001djK001>V`00CY/004jK00800003CY`004ZL00800007
BY`004ZL001:W000BY`01`0000E:W000BY`004Zl00800005B[`004Zl001:_00200002dZl001:_000
B[`004Zl001:_000B[`00P0000Q:_000001:_000C[`004jl7`0000QFo000E_`005Kl001Fo0000UKl
00@005Kl0000009Jo009001Jo000001K7000Fa`005/L00@00004Fa`005/L0002Ga`20002Ga`01000
Ga`000000UlK0`0000AO6`00Ga/0009O6`0:001O6`00Ga/005lK001O6`00Ga/300003UlK001O6elK
001O6`00Ga/005lK001O6`00G_/300002ekk001Nnekk001Nn`00G_/005kk00000Ukk0P0000INn`00
000005kk0002G_/01`00G_/005kk001Nn`00009Nn`800006G_/005kk001Nn`000Ukk00`005kj001N
nP00G_X005kj001NnP00G_X5000015kJ001NfP000UkJ00X005kJ000005kJ001JfP00F]X0009JfP04
001JfP00F]X4000025[J001JfP00F]X005[J0002F]X01000F]X005[J0P0000YJfP00F]X005Zj001J
^P00F[X0009J^P05001F^P00001F^P0;00000eJk001F^`0200008EJk001F^`00E[/005Jk001F^`00
E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`0200004EJk001F^`00
E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000aF^`00E[/005Jk001F^`00E[/005Jk0002E[/0
2`00E[/00000E[/005Jk001F^`00E[/03P0001MFf`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK00<00003E]/005KK00800004E]/005KKE]/200001UKK001Ff`00E]/0009F
f`06001Ff`00E]/005KK1P002goo00<007ooOol0:goo002YOol00`00Oomoo`1KOol03P00D]`005;L
001Bg000D]`005;L001Bg000D]`200001e;L001Bg000D]`005;L0080009Bg004001Bg000D]`20000
2E;L001Bg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800009D]`005;L001Bg000D[`0
04jl00800009C[`004jl001>_000C[`004jl00<00007C[`004jl001>_000C[`00P00015:_000B[`0
04Zl001:_000B[`004Zl001:_000B[d004Zm00D00005A[d004Jm0016_@0200001DJm0016_@00A[d0
0`0000E6_@00A[d004Jm00<00009B]d004[M001:g@00B]d004[M00X00005D_d005;m001Bo@020000
2ELM001G7ELM001G7@00Fa`00002Fa`01P00Fa`005/L001O70<00004Ga`005lL0002Ga`02@00GaaO
7000Ga/006<K001S6`030002Ha/02@00Ha]S6`00Ha/006<K001S6`0200001F<K001S6f<K00000V<K
0P0000=S6`0000000P0000ES6`00Ha]S6`00009S6`07001S6`00HaX006<J00000V<J00<006<J0000
0V<J00@006<J001S6P<0009S6P03001S6P00009S6P04001S6P00H_X2000026;j001RnP00H_X006;j
0002H_X01000H_X006;j0`000V;j00<006;j00000V;j00@006;j001RnP<0000@H_X006;jH_X006;j
001RnP00G_X005kj001NnP00G_X4000025kj001NfP00G]X005kJ0002G]X01000G]X000000UkJ1@00
01eNfP00F]X005[J001JfP00F]X005[J001JfP00F]X005[J001JfP00F[X005Zj001J^P00E[X005Jj
00800003E[/0000002H00007CY/004jK001>V`00CY/00P0000E>V`00CY/004jK00800003CY/004jK
0080000;CY`004ZL001:W000BY`004ZL001:W00300001DZL001:_000B[`0200000=:_000B[`00P00
00M:_000B[`004Zl001:_00200001dZl001:_000B[`004Zl00800003B[`004jl00800007C[`004kL
001>g000C]`00P0000m>g000C]`004kL001Bg000D]`005;L001Bg000D_`00P0000ABo000D_`0009F
o00@001Fo000E_`005Kl001Fo000E_`005Kl001Jo000F_`200000e/L00000002000015/L001K7000
0U/L00`005/L001O7000Ga`005lL001O7000Ga/3000045lK001O6elK001O6`00Ga/005lK001O6`00
Ga/005lK0`0000]O6`00Ga]O6`00Ga/005lK001O6`00009O6`<00003G_/00000009Nn`07001Nn`00
G_/005kk00000Ukk1@0000aNn`00G_/005kk001Nn`00G_/005kk0002G_/60002G_/02`00G_/005kk
001NnP00G_X005kj00000Ukj100000INfP00G]X005kJ0002G]X01P00G]X005kJ001NfP80009JfP03
001JfP0000H00007F]X00000F]X005[J00000U[J00X005[J001JfP00F]X005[J001JfP800008F]X0
05ZjF[X005Zj001J^PP0000=E[X005Jj001F^P00E[/005Jk001F^`00E[/00P00011F^`00E[]F^`00
E[/005Jk001F^`00E[/005Jk001F^`80000?E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk0080
000>E[/005Jk001F^`00E[/005Jk001F^`00E[/0009F^`80000=E[/005Jk001F^`00E[/005Jk001F
^`00E[/03P0000MFf`00E]/005KK001Ff`02000015KK001Ff`000UKK00P005KK001Ff`00E]/005KK
0P0001mFf`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`0:000015KK001Ff`002goo00<007ooOol0:goo002YOol00`00Oomoo`1LOol02P00D]`0
05;L001Bg000D]`005;L0P0000MBg000D]`005;L001Bg00200003E;L001Bg000D]`005;L001Bg000
D]`005;L00800007D]`005;L001Bg000D]`00P0000UBg000D]`005;L001Bg000D]`00P0000MBg000
D[`004jl001>_00200002Djl001>_000C[`004jl001>_00200001Djl001>_000C[`00P0000=>_000
B[`00P0000=:_000B[`00P0000M:_000B[`004Zl001:_@0300000dZm001:_@0700001DJm0016_@00
A[d00P0000M6_@00A[d004Jm0016_@0300001d[M001:g@00B]d004[M00800003C]d004kM00800004
C_d005;m0002D_d01000D_d005;m0P0000aG7@00EaeG7@00Ead005/L001K7000Fa`400000elL0000
0002Ga`00`00Ga`00002Ga`01000Ga`005lK100000AS6`00Ha/0009S6`06001S6`00Ha/006<K0P00
00ES6`00Ha]S6`00009S6`09001S6`00Ha/006<K001S6`00009S6`07001S6f<K001S6`00Ha/00`00
0V<J00<006<J00000V<J00@006<J001S6P800006HaX006<J001S6P000V<J00@006<J001S6P800004
H_X006;jH_X20002H_X01P00H_X006;j001RnP800006H_X006;j001RnP000V;j00T006;j001RnP00
H_X006;j00000V;j00D006;j001RnP00009RnP05001NnP00001NnP02000015kj001NnP000Ukj0P00
0UkJ00P005kJ001NfP00G]X005kJ0`0000aNfP00G]X005kJ001JfP00F]X005[J0002F]X01000F]X0
05[J0P0000UJfP00F]X005Zj001J^P00F[X01`0000EF^`00E[/005Jk0080000;E[/005Jk001F^`00
D[/005:k001B^`0200002E:k001B^`00D[/005:k001B^`0200002E:k001B^`00C[/004jK001>V`0;
00001djK001>V`00CY/004jK00800005CY`004jL001:W00200001dZL001:W000BY`004ZL00800003
BY`004Zl00800005B[`004Zl001:_00900001DZl001:_000B[`00P0000U:_000B[`004Zl001:_000
B[`00P0000]>_000C[`004jl001>g000C]`004kL0080000?C]`004kL001>g000D]`005;L001Bg000
D]`005;l0080000CD_`005;l001Fo000E_`005Kl001Fo000E_`005Kl001Fo000F_`01@0000AJo000
Fa`0009K700<001K7000Fa`005/L001O7000Ga`005lL1@0000iO6`00Ga]O6`00Ga/005lK001O6`00
Ga/005lK100000eO6`00Ga/005lK001O6`00Ga/005lK001O6`04000015kk001Nnekk0P0000INn`00
G_/005kk0002G_/3000015kk001Nn`000Ukk0P0000ANn`00G_/0009Nn`03001Nn`000080000>G_/0
05kk001Nn`00G_/005kk001Nn`00G_X0009NnP03001NnP0000800005G_X00000G]X00002G]X03000
G]X005kJ001NfP00G]X005kJ001NfPD0000MF]X005[J001JfP00F]X005[J001JfP00F]X005[J001J
fP00F]X005[J001JfP00F]X005[J001JfP0700000eZj001F^P0200002UJj001F^P00E[X005Jj001F
^`000UJk00@005Jk001F^`80000?E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk0080000>E[/0
05Jk001F^`00E[/005Jk001F^`00E[/0009F^`80000=E[/005Jk001F^`00E[/005Jk001F^`00E[/0
4P0000=F^`00E[/00P0000YF^`00E[/005KK001Ff`00E]/0009Ff`0C001Ff`00001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`00E]/00P000UKK00/005KK000005KK001Ff`00E]/005KK00800003E]/0
05KK00800003E]/0000000T00007E]/005KK001Ff`00E]/00P000UKK00<005KK00002Woo00<007oo
Ool0:goo002ZOol00`00Oomoo`1KOol03P00D]`005;L001Bg000D]`005;L001Bg000D]`200001e;L
001Bg000D]`005;L00800003D]`0000003000009C[`004jl001>_000C[`004jl00800005B[`004Zl
001:_002000024Zl000004Zl001:_@00B[d2000024Zm000004Zm0016_@00A[d:00001dJm0016_@00
A[d004Jm00800007B]d004[M001:g@00B]d00P0000=>g@00C]d00P0000A>o@00D_d0009Bo@04001B
o@00D_d200001eLM001G7@00Ead005/L00@00004Fa`005/L0002Ga`20002Ga`01P00Ga`005lL001O
70800004Ga/005lK0002Ha/01P00Ha/006<K001S6`@00005Ha/006<KHa/00002Ha/01000Ha/006<K
0`000V<K00<006<K00000V<K00@006<K001S6`800006Ha/006<K001S6P000V<J00@006<J001S6P80
0004HaX006<JHaX20002HaX01000HaX006<J0P0000iRnP00H_YRnP00H_X006;j001RnP00H_X006;j
0P0000ARnP00H_YRnP80009RnP06001RnP00H_X006;j0`000V;j00<006;j00000V;j00H006;j001R
nP00G_X300004Ukj001NnUkj001NnP00G_X005kJ001NfP00G]X005kJ001NfP<0000HG]X005kJG]X0
05kJ001NfP00F]X005[J001JfP00F]X005[J001JfP00F]X005[J1`0000MJ^P00001F^P00E[X00002
E[/200003eJk001F^`00E[/005Jk001F^`00D[/005:k001B^`0200002E:k001B^`00D[/005:k001B
^`0200001E:k001B^`00C[/00P0000=>V`00CY/00P0000M>V`00CY/004jK001>V`0;00001DjL001:
W000BY`00P0000E:W000BY`004ZL0080000CBY`004Zl001:_000B[`004Zl001:_000B[`004Zl001:
_000B[`02P0000a:_000001:_000B[`004Zl001>_000C[`200003DkL001>g000C]`004kL001>g000
C]`004kL0080000=D]`005;L001Bg000D_`005;l001Bo000D_`00P0000MFo000E_`005Kl001Fo006
00000e[l001Jo0020002F_`02`00Fa`005/L001K7000Fa`005/L00000UlL0`0000iO7000Ga`005lL
001O6`00Ga/005lK001O6`000UlK0`0000AO6`00Ga/0009O6`80009O6`80009O6`<00004G_/005kk
0002G_/02000G_/005kk001Nn`00G_/500002Ukk001Nnekk001Nn`00G_/005kk0P000Ukk1@0000IN
n`00G_]Nn`00G_/20002G_/20002G_/00`00G_X0000400003Ukj001NnP00G]X005kJ001NfP00G]X0
05kJ0002G]X00`00G]X00003000025[J001JfP00F]X005[J0002F]X03000F]X00000F]X005[J001J
fP00F]X0009JfP04001JfP00F]X600006eZj001J^P00F[X005Zj001F^P00E[X005Jj001F^P00E[X0
05Jj001F^`00E[/005Jk001F^`0200007eJk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/0
05Jk001F^`00E[/005Jk001F^`00E[/005Jk0180000TE[/00000E[/005Jk001F^`00E[/005Jk001F
^`00E[/005Jk001F^`00E[/005Jk001F^`00E]/005KK001Ff`00E]/005KK0P0001eFf`00E]/005KK
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK00X0000:E]/005KK
001Ff`00E]/005KK0002E]/200002UKK001Ff`00E]/005KK001Ff`002Woo00<007ooOol0:goo002[
Ool00`00Oomoo`1KOol01000D]`005;L5@0000UBg000D]`005;L001Bg000D]`00P0000MBg000D]`0
05;L001Bg00200002E;L001Bg000D]`005;L001Bg00200001e;L001Bg000D[`004jl00800009C[`0
04jl001>_000C[`004jl00h00005B[`004Zl001:_00200001dZl001:_000B[d004Zm00<0000?B[d0
04Zm0016_@00A[d004Jm0016_@00A[d004Jm00T00003B]d004[M00800009B]d004[M001:g@00C]d0
04kM0080000=C_d005;m001Bo@00D_d005;m001Fo@00Ead01@0000AK7000Fa`0009K7003001K7000
009O70800003Ga`005lL00@00007Ga`005lKGa/005lK00000V<K00T006<K001S6`00Ha/006<K0000
0V<K00L006<KHa/006<K001S6`0200001V<K001S6`00Ha/0009S6`04001S6`00Ha/2000016<K001S
6f<K0P000V<J00@006<J001S6P80000<HaX006<JHaX006<J001S6P00HaX006<J0P0000aS6P00H_YR
nP00H_X006;j001RnP00H_X4000036;j001RnV;j001RnP00H_X006;j001RnP@00006H_X006;j001R
nP000V;j00H006;j001RnP00H_X3000045kj001NnUkj001NnP00G_X005kj001NfP00G]X005kJ1000
00=NfP0000000UkJ018005kJ001NfP00G]X005[J001JfP00F]X005[J001JfP00F]X500004e[J001J
^P00F[X005Zj001F^P00E[X005Jj001F^`00E[/005Jk0080000;E[/005Jk001F^`00D[/005:k001B
^`0200002E:k001B^`00D[/005:k001B^`0200002e:k001B^`00C[/004jK001>V`00CY/00P0000E>
V`00CY/004jK00800003CY/004jK00800003CY/004jK00P00005BY`004ZL001:W00200001dZL001:
W000B[`004Zl00800003B[`004Zl00800005B[`004Zl001:_00200001DZl001:_000B[`00P0000=:
_0000000200000=>_000C[`00P0000e>g000C]`004kL001>g000C]`004kL001>g00200003e;L001B
g000D]`005;l001Bo000D_`005;l001Fo00700001UKl001Fo000E_`0009Jo004001Jo0000002F_`0
1P00Fa`00000Fa`0009K70D00006Ga`005lLGa`005lL0P000UlK0P000UlK1@0000iO6`00Ga]O6`00
Ga/005lK001O6`00Ga/005lK0`0001EO6`00G_]Nn`00G_/005kk001Nn`00G_/005kk001Nn`00G_/0
05kk00000Ukk00X005kk001Nn`00G_/005kk001Nn`<00004G_/005kk0002G_/02P00G_/005kk001N
n`00G_/005kk1@0000ANn`00G_X0009NnP0:001NnP00001NfP00G]X005kJ0002G]X500001e[J0000
05[J001JfP00009JfP08001JfP00F]X005[J001JfP800006F]X005[JF]X005[J1`0000]JfP00001J
fP00F[X005Zj001J^P00009J^P0C001F^P00001F^P00E[X005Jj001F^P00E[/005Jk001F^`00E[/0
0P00011F^`00E[]F^`00E[/005Jk001F^`00E[/005Jk001F^a00000BE[/00000E[/005Jk001F^`00
E[/005Jk001F^`00E[/005Jk0P0000iF^`00E[]F^`00E[/005Jk001F^`00E[/005Jk0P0001=F^`00
E[/005Jk001F^`00E]/005KK001Ff`00E]/005KK001Ff`02000015KK001Ff`000UKK00P005KK001F
f`00E]/005KK3P0000EFf`00E]/005KK0080000>E]/005KKE]/005KK001Ff`00E]/005KK001Ff`80
000:E]/005KK001Ff`00E]/005KK000:Ool00`00Oomoo`0[Ool00:]oo`03001oogoo05aoo`@00009
D]`005;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P000U;L00P005;L001Bg000D]`0
05;L0P0000MBg000D]`005;L001Bg00200002E;L001Bg000D]`005;L001Bg00200001e;L001Bg000
D[`004jl0080000CC[`004jl001>_000C[`004jl001>_000C[`004jl001>_000C[`00P0000=>_000
00001`0000M:_000B[d004Zm001:_@0200001DZm001:_@00A[d00`0000E6_@00A[d004Jm00<00007
B[d004Zm001:g@00B]d07P0000AG7@00Ea`0009K7003001K7000009K7004001K7000Ga`200001elL
000005lL001O7000009O7009001O6elK001O6`00Ha/006<K00<0009S6`03001S6`00009S6`04001S
6`00Ha/2000016<K001S6f<K0P000V<K00@006<K001S6`80000<Ha/006<KHa/006<K001S6`00HaX0
06<J0P0000MS6P00HaYS6P00HaX00002HaX200001F<J000006<J00000V<J00<006;j00000V;j00<0
06;j00000P0000ARnP00H_X0009RnP08001RnP00H_X006;j001RnP800004H_X006;j0002H_X20002
H_X01P00H_X006;j001RnP800008G_X005kj001NnP00G_X0009NnP80009NnP80000=G]X00000G]X0
05kJ001NfP00G]X005kJ00000UkJ00/005kJ000005[J001JfP00F]X005[J00@00005F]X00000F]X0
0002F]X01P00F[X005Zj001J^P800004E[X005Jj0002E[/200002EJk001F^`00E[/005Jk001F^`02
00002e:k001B^`00D[/005:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00C[/00P0000=>V`00
CY/00P0000]>V`00CY/004jK001>V`00CY/004jK0080000:CY/00000CY/004jL001>W000CY`90000
1DZL001:_000B[`00P0000E:_000B[`004Zl0080000;B[`004Zl001:_000B[`004Zl001:_0030000
2DZl001:_000C[`004jl001>_00T00001UKl001Fo000E_`0009Fo00@001Fo000E_`005[l001Jo000
F_`005[l001K7000Fa`5000015/L001K70000UlL00X005lL001O7000Ga`005lK001O6`<00004Ga/0
05lK0002Ga/02P00Ga/005lK001O6`00Ga/005lK0`0000]O6`00Ga]O6`00G_/005kk001Nn`00009N
n`H0009Nn`09001Nn`00G_/005kk001Nn`00009Nn`@0000GG_/005kkG_/005kk001Nn`00G_/005kk
001Nn`00G_/005kk001Nn`00G_/00002G_/02000G_X005kj001NnP00G]X20002G]X00`00G]X00002
00006EkJ001NfP00F]X005[J001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X005[J00D00007
F]X005[J001JfP00F]X00P000U[J00`005Zj001J^P00F[X005Zj001F^P00E[X2000025Jj001F^P00
E[X005Jk0002E[/01000E[/005Jk0P0000=F^`0000003P0000mF^`00E[/005Jk001F^`00E[/005Jk
001F^`00E[/00P0000AF^`00E[/0009F^`08001F^`00E[/005Jk001F^`80000CE[/005Jk001F^`00
E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000YF^`00E[/005KK001Ff`00E]/0009Ff`09001F
f`00001Ff`00E]/005KK00`0000=E]/005KK001Ff`00E]/005KK001Ff`00E]/00`0001MFf`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0080009Ff`03001Ff`0000Yoo`03
001oogoo02Yoo`00[7oo00<007ooOol0Fgoo00h005;L001Bg000D]`005;L001Bg000D]`005;L0P00
00MBg000D]`005;L001Bg0020002D]`200001e;L001Bg000D]`005;L00800009D]`005;L001Bg000
D]`005;L00800007D]`005;L001Bg000D]`00P0000UBg000D[`004jl001>_000C[`00P0000E>_000
C[`004jl00800009C[`004jl001>_000C[`004jl00<00005B[`004Zl001:_00200000dZl00000007
00001dZm001:_@00A[d004Jm00800005A[d004Jm0016_@0300001DZm001:_@00B]d00P0000=:g@00
B]d00P0000U:g@00B]d004kM001>g@00C_d00P00019Bo@00D_d005;m001Bo@00D_d005Km001G7@00
Ead005LL0002Fa`02000Fa`005/L001K7000Ga`300001elL001O75lL001O7000009O7006001O6`00
Ga/006<K0P0000AS6`00Ha/0009S6`06001S6`00Ha/006<K0P0000aS6`00Ha]S6`00Ha/006<K001S
6`00Ha/200001F<K001S6f<K00000V<K00D006<K000006<J00800007Ha/006<JHaX006<J00000V<J
00L006<J001S6P00HaX00002HaX00`00HaX00002H_X01`00H_X006;j001RnP00009RnP05001RnP00
H_X00002H_X00`00H_X00002000046;j001RnV;j001RnP00H_X006;j001RnP00H_X006;j0P0000QN
nP00G_X005kj001NnP000Ukj00@005kj001NnPD00008G]X005kJG]X005kJ001NfP80009NfP08001N
fP00G]X005kJ001JfPD0000IF]X005[J001JfP00F]X005[J001JfP00F[X005Zj001J^P00E[X005Jj
001F^P00E[/00P0000mF^`00E[/005Jk001F^`00E[/005:k001B^`00D[/00P0000UB^`00D[/005:k
001B^`00D[/00P0000EB^`00D[/004jk0080000;CY/004jK001>V`00CY/004jK001>V`0200000djK
001>V`0200002DjK001>V`00CY/004jL001>W00300001Djl001>_000C[`02P0000=:_000B[`00P00
00E:_000B[`004Zl00800005B[`004Zl001:_00200002DZl001:_000B[`004jl001>_00200000djl
001>_00200003DkL001>g000C]`004kL001>g000C]`005;L0080000SD]`005;L001Bg000D_`005;l
001Bo000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Jo000F_`005[l001Jo005000015/L
001K70000U/L00`005/L001O7000Ga`005lL001O7000Ga/300003UlK001O6elK001O6`00Ga/005lK
001O6`00Ga/4000035lK001O6`00Ga/005lK001Nn`00G_/0009Nn`<0000<G_/005kk001Nn`00G_/0
05kk001Nn`000Ukk00<005kk00000P0000=Nn`0000000Ukk00L005kk001Nn`00G_/00002G_/00`00
G_/00005000045kk001Nnekk001Nn`00G_X005kj001NnP00G]X005kJ1@0000ANfP00G]X0009NfP0<
001JfP00001JfP00F]X005[J001JfP000U[J00<005[J00001@0000QJfP00F]X005[J001JfP000U[J
01/005[J000005[J001J^P00F[X005Zj001J^P00E[X005Jj001F^P00E[X005Jj001F^P00E[/02P00
00eF^`00E[/005Jk001F^`00E[/005Jk001F^`0200001UJk001F^`00E[/0009F^`06001F^`00E[/0
05Jk0P00015F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk0080000ME[/005Jk001F^`00
E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E]/005KK001Ff`0<00002EKK001Ff`00
E]/005KK001Ff`02000035KK001FfeKK001Ff`00E]/005KK001Ff`@0000@E]/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK0002E]/200001EKK001Ff`00E]/01@002Woo00<007ooOol0:Woo002/Ool0
0`00Oomoo`1LOol01P00D]`005;L001Bg0800007D]`005;L001Bg000D]`00P0000ABg000D]`0009B
g0800009D]`005;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P0000UBg000D]`005;L
001Bg000D]`00P0000MBg000D]`005:l001>_00200002Djl001>_000C[`004jl001>_00200000djl
001>_00200001Djl001>_000C[`00P0000E:_000B[`004Zl00<00007B[`004Zl001:_@00B[d02@00
00Q6_@000016_@00A[d004Jm0P0000E:_@00B[d004[M00800003B]d004[M00800009B]d004[M001>
g@00C]d004km0080000GD_d005;m001Bo@00D_d005;m001Fo@00Ead005LM001G7000Fa`005/L001K
700400001U/L001O7000Ga`0009O7006001O7000Ga`005lK100000aS6`00Ha]S6`00Ha/006<K001S
6`00Ha/200001F<K001S6f<K00000V<K00D006<K000006<K00800005Ha/006<KHa/00002Ha/02@00
Ha/006<K001S6`00Ha/00002Ha/02@00HaYS6P00HaX006<J001S6P030002HaX00`00HaX00002HaX0
1000H_X006;j0`000V;j00<006;j00000V;j00T006;j001RnP00H_X006;j00000V;j00X006;j001R
nP00H_X006;j001RnP@0000EG_X005kjG_X005kj001NnP00G_X005kj001NnP00G_X005kJ001NfP00
009NfP0@001NfP00G]X005kJ001NfP00G]X005kJ001NfP00G]X300001U[J001JfP00F]X0009JfP06
001JfP00001JfP000U[J014005Zj000005Zj001F^P00E[X005Jj001F^`00E[/005Jk00800005E[/0
05Jk001F^`0C00002e:k001B^`00C[/004jK001>V`00CY/00P0000E>V`00CY/004jK00800007CY/0
04jK001>V`00CY/00P0000M>V`00CY`004jL001>W00200000djl001>_00200001djl001>_000B[`0
04Zl00T00003B[`004Zl0080000=B[`004Zl001:_000B[`004Zl001:_000B[`00P0000M>_000C[`0
04jl001>_00200003DkL001>g000C]`004kL001>g000C]`005;L0080000ED]`005;L001Bg000D_`0
05;l001Bo000E_`005Kl001Fo000E_`005Kl00800004E_`005Kl0002F_`5000045[l001Jo000Fa`0
05/L001K7000Fa`005/L001O70000UlL1@0000aO6`00Ga/005lK001O6`00Ga/005lK0002Ga/30000
15lK001O6`000UlK0P0000AO6`00Ga/0009Nn`D00006G_/005kkG_/005kk0P0000ANn`00G_/0009N
n`D00004G_/005kkG_/200001Ukk001Nn`00G_/0009Nn`D0000>G_/005kk001Nn`00G_/005kk001N
n`00G_X0009NnP03001NnP0000<00004G]X005kJ0002G]X02000G]X005kJ001JfP00F]X200001U[J
001JfU[J001JfPD00007F]X00000F]X005[J00000U[J00P005[J001JfP00F]X005[J0P0000QJfP00
F[X005Zj001J^P000UZj00D005Jj000005Jj00T00005E[/005Jk001F^`0200002UJk001F^`00E[/0
05Jk001F^`000UJk01D005Jk000005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/00P00
00mF^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000iF^`00E[]F^`00E[/005Jk001F^`00
E[/005Jk0P0000=F^`0000002`0000=Ff`00E]/00P0000QFf`00E]/005KK001Ff`000UKK01T005KK
000005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`02000035KK001FfeKK
001Ff`00E]/005KK001Ff`X00004E]/005KK000:Ool00`00Oomoo`0ZOol00:eoo`03001oogoo05]o
o`03001Bg5;L00800009D]`005;L001Bg000D]`005;L0080000;D]`005;L001Bg000D]`005;L001B
g00200001e;L001Bg000D]`005;L00800009D]`005;L001Bg000D]`005;L00800007D]`005;L001B
g000D]`00P0000UBg000D[`004jl001>_000C[`00P0000M>_000C[`004jl001>_00200001djl001>
_000C[`004jl00800005C[`004Zl001:_00200004TZl000004Zl001:_000B[d004Zm001:_@00B[d0
04Zm001:_@T0000<A[d00000B[d004[M001:g@00B]d004[M0P0000U:g@00B]d004kM001>g@00C_d0
0P0000eBo@00D_d005;m001Bo@00D_d005Km001G7@0200000eLL00000004000015/L001K70000U/L
00X005lL001O7000Ga`005lL001O70800004Ga`005lK0002Ha/00`00Ha]S6`0200000f<K00000002
00001F<K001S6f<K00000V<K00T006<K001S6`00Ha/006<K00000V<K00L006<KHa/006<K001S6`05
0002Ha/02@00Ha]S6`00HaX006<J001S6P0200001V<J001S6P00HaX0009S6P04001S6P00H_X20000
1V;j001RnP00H_X0009RnP06001RnP00H_X006;j0`000V;j00<006;j00000V;j00@006;j001RnP<0
0004H_X006;j0002G_X02P00G_X005kj001NnP00G_X005kj1@000UkJ00D005kJ001NfP00009NfP80
0007G]X005kJ001NfP00G]X01@0001QJfP00F]YJfP00F]X005[J001JfP00F]X005[J001JfP00F]X0
05Zj001J^P00F[X200000eJj001F^P0=00003UJk000005:k001B^`00D[/005:k001B^`00D[/20000
0e:k001B^`0A00001djK001>V`00CY/004jK00800005CY/004jK001>V`0200000djL001>W0020000
5Djl001>_000C[`004jl001>_000B[`004Zl001:_000B[`004Zl001:_00:000024Zl000004Zl001:
_000B[`200003Djl001>_000C[`004jl001>g000C]`004kL0080000=C]`004kL001>g000D]`005;L
001Bg000D]`00P00015Bo000D_`005;l001Fo000E_`005Kl001Fo000E_`005Kl00L00004F_`005[l
0002F_`01000F_`000000U/L0P0000EK7000Fa`005lL00@00004Ga`005lL0002Ga/20002Ga/20000
0elK001O6`0400002UlK001O6elK001O6`00Ga/005lK0P000UlK0`0000ANn`00G_/0009Nn`08001N
n`00G_/005kk001Nn`D00004G_/005kk0002G_/01000G_/000000Ukk00@005kk001Nn`<00004G_/0
05kk0002G_/02000G_/00000G_/005kk0002G_/00`00G_X0000400000ekJ00000002G]X04000G]X0
05kJ001NfP00G]X005[J001JfP00F]X005[J1@0001EJfP00F]X005[J001JfP00F]X005[J001JfP00
F]X005[J001JfP00F]X00P000U[J00H005Zj001J^P00F[X800007EJj001F^P00E[X005Jk001F^`00
E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/00P00015F^`00E[/005Jk001F^`00
E[/005Jk001F^`00E[/005Jk00800004E[/005Jk0002E[/02000E[/005Jk001F^`00E[/200000eJk
001F^`0@00007EJk001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/00P00015Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK00<00005E]/005KK
001Ff`0;00002EKK000005KK001Ff`00E]/00002E]/00`00E]/00009Ool00`00Oomoo`0ZOol00:io
o`03001oogoo05]oo`06001Bg000D]`005;L0P0000MBg000D]`005;L001Bg00200001E;L001Bg000
D]`0>`0000E>_000C[`004jl00800005B[`004Zl001:_00200001DZl001:_000B[`00P0000Q:_@00
001:_@00B[d004Zm0P0000Q:_@00001:_@00B[d004Zm2@0000E:g@00B]d004[M00800009B]d004kM
001>g@00C_d004km00800009D_d005;m001Bo@00D_d005Km00D00006Ea`005/L001K70000U/L00<0
05/L00000U/L00D005lL000005lL00@00007Ga`005lLGa`005lK00000V<K00T006<K001S6`00Ha/0
06<K00000V<K00L006<KHa/006<K001S6`050002Ha/01`00Ha]S6`00Ha/006<K00800006Ha/006<K
001S6`000V<K00@006<K001S6P@00004HaX006<JHaX20002HaX01000HaX006<J0P0000ARnP00H_YR
nP80009RnP04001RnP00H_X400001V;j001RnP00H_X0009RnP09001RnP00H_X006;j001RnP00009R
nP0<001RnP00G_X005kj001NnP00G_X005kj0P0000YNnP00G_X005kj001NfP00G]X0009NfP06001N
fP00G]X005kJ1@0001]NfP00G]X005[J001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X005[J
001J^P00F[X01`0000=F^`00E[/00P00015F^`00E[/005Jk001F^`00E[/005Jk001B^`00D[/005:k
00800007D[/005:k001B^`00D[/00P0000EB^`00D[/005:k00800009C[/004jk001>^`00C[/004jk
00/00007CY/004jK001>W000CY`00P0000M>_000C[`004jl001>_00200001Djl001:_000B[`00P00
00E:_000B[`004Zl00800003B[`004Zl00800003C[`004jl00`0000<C[`00000C[`004jl001>g000
C]`004kL0P0000e>g000C]`004kL001Bg000D]`005;L001Bg00200002E;l001Bo000D_`005Kl001F
o00900001UKl001Fo000F_`0009Jo00:001Jo000F_`005[l001K7000Fa`200000e/L000000020000
15/L001O70000UlL00X005lL001O6`00Ga/005lK001O6`<00004Ga/005lK0002Ga/02P00Ga/005lK
001O6`00Ga/005lK0`0001ENn`00G_]Nn`00G_/005kk001Nn`00G_/005kk001Nn`00G_/005kk0000
0Ukk00`005kk001Nn`00G_/005kk001Nn`00G_/3000015kk001Nn`000Ukk00H005kk001Nn`00G_/2
0002G_/5000045kk001NfP00G]X005kJ001NfP00G]X005kJ001NfP000UkJ00<005[J00001@0000IJ
fP00F]X005[J0002F]X03P00F]X00000F]X005[J001JfP00F]X005[J0002F]X00`00F]X000090000
1EZj001F^P00E[X00P0000IF^P00E[X005Jj0002E[/01P00E[/005Jk001F^`80000?E[/005Jk001F
^`00E[/005Jk001F^`00E[/005Jk00800006E[/005Jk001F^`000UJk00H005Jk001F^`00E[/20000
1EJk001F^`00E[/0400000]F^`00E[/005Jk001F^`00E[/005Jk00800004E[/005Jk0002E]/02000
E]/005KK001Ff`00E]/200004eKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0080
000<E]/005KKE]/005KK001Ff`00E]/005KK2P0001QFf`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK0009Ool00`00Oomoo`0ZOol00:ioo`03001oogoo05]oo`03001Bg000
01<00005D]`005;L001Bg00200001e;L001Bg000D]`005;L00800009D]`005;L001Bg000D]`005;L
00800007D]`005;L001Bg000D]`00P0000UBg000D]`005;L001>g000C[`00P0000M>_000C[`004jl
001>_00200000djl001>_00=00002TZl000004Zl001:_000B[d004Zm0P0000=:_@00B[d00P0000=:
_@00B[d00P0000=:_@00B[d00P0000Q:_@00001:g@00B]d004[M6`0000aFo@00E_d005LM001G7000
Fa`005/L0002Fa`01P00Fa`005/L001O70<00004Ga`005lL0002Ga`02@00GaaO7000Ga/006<K001S
6`030002Ha/00`00Ha/00002Ha/01000Ha/006<K0P0000IS6`00Ha/006<K0002Ha/01000Ha/006<K
0P0000aS6`00Ha]S6`00Ha/006<K001S6`00Ha/2000016<K001S6P000V<J00P006<J001S6P00HaX0
06<J0P0000aRnP00H_YRnP00H_X006;j001RnP00H_X2000016;j001RnP000V;j0P000V;j00H006;j
001RnP00H_X30002H_X01@00H_X006;j00000Ukj00@005kj001NnP<00006G_X005kjG_X005kj0P00
0UkJ00P005kJ001NfP00G]X005kJ0`0000INfP00G]X005kJ0002G]X200001U[J001JfU[J001JfP80
009JfP05001JfP00001JfP0700005EZj001F^P00E[X005Jk001F^`00E[/005Jk001F^`00E[/005Jk
001F^`0200002e:k001B^`00D[/005:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[/00P00
00E>^`00C[/004jk00800003C[/004jk00800007C[/004jk001>^`00C[/02`0000E>_000C[`004jl
00800007C[`004Zl001:_000B[`00P0000U:_000B[`004Zl001:_000B[`00P0000a>_000001>_000
C[`004jl001>_000C[`X00006eKl001Fo000E_`005Kl001Fo000E_`005Kl001Jo000F_`005[l001J
o000F_`005/L001K7003000015/L001K70000U/L00`005lL001O7000Ga`005lK001O6`00Ga/30000
3ElK001O6elK001O6`00Ga/005lK001O6`00009O6`@0000;G_/005kkG_/005kk001Nn`00G_/00002
G_/60002G_/02@00G_/005kk001Nn`00G_/00002G_/200001Ukk00000000G_/0009Nn`0<001Nn`00
G_/005kk001Nn`00G_/005kk0`0000INn`00G_/005kk0002G]X02000G]X00000G]X005kJ0002G]X0
0`00G]X0000400001e[J000005[J001JfP00009JfP08001JfP00F]X005[J001JfP800008F]X005[J
F]X005[J001JfPH0000<F]X005Zj001J^P00F[X005Zj001F^P000UJj0P0000eF^P00E[X005Jj001F
^`00E[/005Jk001F^`0200002UJk001F^`00E[/005Jk001F^`000UJk00/005Jk000005Jk001F^`00
E[/005Jk01000009E[/005Jk001F^`00E[/005Jk00800008E[/005Jk001F^`00E[/0009F^`04001F
^`00E[/200004eJk001F^`00E[/005KK001Ff`00E]/005KK001Ff`00E]/005KK00800008E]/005KK
001Ff`00E]/0009Ff`09001Ff`00001Ff`00E]/005KK00h00006E]/005KK001Ff`000UKK00@005KK
001Ff`80000@E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0009Ool00`00Oomoo`0ZOol00:mo
o`03001oogoo05]oo`06001Bf`00D]/005;L0P0000MBg000D]`005;L001Bg002000015;L001Bg000
0U;L00@005;L001Bg0800007D]`005;L001Bg000D]`00P0000UBg000D]`005;L001Bg000D]`00P00
00MBg000D]`005;L001Bg00200002E;L001Bg000D]`004kL001>_00200001djl001>_000C[`004jl
00800008C[`00000C[`004jl001>_0800005C[`004jl001:_00900000dZm001:_@0200001dZm001:
_@00B[d004Zm00800006B[d00000B[d004Zm0P0000=:g@00B]d00P0000E:g@00B]d004[M00800009
C]d004kM001>g@00C_d004km00800008D_d005;m001Bo@00E_d0009Fo@0>001Fo@00Ead005LL001K
7000Fa`005/L001K70@00003Ga`00000009O7003001O7000009O7004001O7000Ga/400001V<K001S
6`00Ha/0009S6`04001S6`00Ha/2000036<K001S6f<K001S6`00Ha/006<K001S6`80000<Ha/006<K
Ha/006<K001S6`00Ha/006<K0P0000MS6`00Ha]S6`00HaX00002HaX200000f<J001S6P02000036;j
001RnV;j001RnP00H_X006;j001RnP80000>H_X006;jH_X006;j001RnP00H_X006;j001RnP@00006
H_X006;j001RnP000V;j00H006;j001NnP00G_X300004Ukj001NnUkj001NnP00G_X005kj001NfP00
G]X005kJ001NfP<0000DG]X005kJG]X005kJ001NfP00G]X005[J001JfP00F]X005[J001JfPL0000A
F]X005[J001J^P00F[X005Zj001F^P00E[X005Jk001F^`0200004EJk001F^`00E[/005Jk001F^`00
E[/005:k001B^`00D[/00P0000MB^`00D[/005:k001B^`0200001E:k001B^`00D[/00P0000]>^`00
C[/004jk001>^`00C[/004jk00800005C[/004jk001>^`0200000djk001>^`0200000djl001>_00:
00001Djl001:_000B[`00P0000=:_000B[`00P0000E:_000B[`004Zl0080000KC[`004jl001>_000
C[`004jl001>_000C[`004jl001>_000C]`004kL001>g000C]`004kL0080000=C]`004kL001Bg000
D]`005;L001Bg000D]`00P0000QBo000D_`005;l001Fo0000UKl00H005Kl001Fo000E_`20002E_`2
00001e[l001Jo000F_`005[l00H00003Fa`00000009K700<001K7000Fa`005lL001O7000Ga`005lK
100000aO6`00Ga/005lK001O6`00Ga/005lK0002Ga/5000035kk001Nn`00G_/005kk001Nn`00G_/0
009Nn`<0000>G_/005kk001Nn`00G_/005kk001Nn`00G_/0009Nn`D0000<G_/005kk001Nn`00G_/0
05kk001Nn`000Ukk00<005kk00000`0000ANn`00G_/0009Nn`0<001Nn`00G]X005kJ001NfP00G]X0
05kJ1@0000EJfP00F]X005[J0080009JfP0@001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X7
00000e[J001JfP0200001U[J001J^P00F[X0009J^P06001J^P00E[X005Jj0P0001UF^P00E[X005Jj
001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`0>00001eJk001F^`00E[/005Jk
0080000<E[/005Jk001F^`00E[/005Jk001F^`000UJk0P0000mF^`00E[/005Jk001F^`00E[/005Jk
001F^`00E[/00P0001eF^`00E[/005Jk001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/005KK00`0000IE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/00P0000AFf`00E]]Ff`800006E]/005KK001Ff`000UKK00<005KK000027oo00<007oo
Ool0:Woo002_Ool00`00Oomoo`1KOol01`00D]]Bf`00D]/005;L00800007D]`005;L001Bg000D]`0
0P0000]Bg000D]`005;L001Bg000D]`005;L00800009D]`005;L001Bg000D]`005;L0080000?D]`0
05;L001Bg000D]`005;L001Bg000D]`005;L00800005D]`005;L001Bg00200000djl001>_0020000
1djl001>_000C[`004jl00800007C[`004jl001>_000C[`00P0000=>_000C[`00P0000Q:_000001:
_000B[`004Zm2@0000E:_@00B[d004Zm00800005B[d004Zm001:_@0200000d[M001:g@0200001D[M
001:g@00B]d00P0000U>g@00C]d004kM001>o@00C_d00P0000QBo@00D_d005;m001Fo@000UKm00@0
05Km001G7@800003Fa`005/L00@00004Fa`005/L0002Ga`20002Ga`01P00Ga`005lL001O70800004
Ga/005lK0002Ha/02000Ha/006<K001S6`00Ha/2000036<K001S6f<K001S6`00Ha/006<K001S6`80
0007Ha/006<KHa/006<K00000V<K0P0000ES6`00001S6`00009S6`03001S6`00009S6P04001S6P00
HaX300001f<J001RnV;j001RnP00009RnP03001RnP000080000>H_X006;jH_X006;j001RnP00H_X0
06;j001RnP800004H_X006;j0002H_X20002H_X01P00H_X006;j001NnP<00007G_X005kjG_X005kj
00000Ukj0P0000ENnP00G]X005kJ00@0000EG]X005kJ001NfP00G]X005kJ001NfP00G]X005[J001J
fP00F]X005[J00<0000:F]X005[J001JfP00F]X005[J0002F[X200004EZj001F^P00E[X005Jk001F
^`00E[/005Jk001F^`00E[/00P0000UF^`00E[/005:k001B^`00D[/00P0000UB^`00D[/005:k001B
^`00D[/00P0000]B^`00D[/005:k001>^`00C[/004jk00800003C[/004jk0080000;C[/004jk001>
^`00C[/004jk001>^`0200002Tjl000004jl001>_000C[`004jl2`0000=:_000B[`00P0000]:_000
B[`004Zl001>_000C[`004jl00800005C[`004jl001>_00200003Djl001>_000C]`004kL001>g000
C]`004kL0080000=C]`004kL001Bg000D]`005;L001Bg000D]`00P0001=Bo000D_`005;l001Fo000
E_`005Kl001Fo000E_`005Kl001Fo00200000e[l001Jo00400001U[l001Jo000F_`0009K7080009K
7007001K7000001O7000Ga`0100000AO7000Ga/0009O6`80009O6`800003Ga/005lK00@00004Ga/0
05kk0002G_/20002G_/20002G_/500001Ukk001Nnekk001Nn`80009Nn`80009Nn`D00004G_/005kk
0002G_/200001Ukk001Nn`00G_/0009Nn`D00003G_/00000009Nn`0>001Nn`00G_/005kk001NfP00
G]X005kJ001NfP<00006F]X005[J001JfP000U[J00`005[J000005[J001JfP00F]X005[J0002F]X0
1@00F]X00000F]X00`0001UJfP00F]X005[J001JfP00F]X005[J001JfP00F[X005Zj001J^P00F[X0
05Jj001F^P0200001UJj001F^P00E[X0009F^`06001F^`00E[/005Jk300000=F^`00E[/00P0001mF
^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F
^`0200004EJk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000AF^`00E[/0009Ff`08
001Ff`00E]/005KK001Ff`h00003E]/005KK00800006E]/005KK001Ff`000UKK00H005KK001Ff`00
E]/200006eKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`070008Ool00`00Oomoo`0ZOol00;1oo`03001oogoo05]oo`0:001Bf`00D]/005;L001Bg000D]`2
00003e;L001Bg000D]`005;L001Bg000D]`005;L001Bg00200001e;L001Bg000D]`005;L0080000;
D]`005;L001Bg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007D]`005;L001>g000
C[`00P0000M>_000C[`004jl001>_00200001djl001>_000C[`004jl00800008C[`00000C[`004Zl
001:_0800003B[`004Zl00800003B[d004Zm00800003B[d004Zm00T00005B[d004Zm001:_@020000
2D[M001:g@00B]d004[M001:g@0200002DkM001>g@00C]d004km001>o@0200003E;m001Bo@00D_d0
05Km001Fo@00E_d005LM00D00004Fa`005/L0002Fa`00`00Fa`00002Ga`200000elL001O70040000
1elL001O6elK001O6`00009S6`800003Ha/006<K00800005Ha/006<KHa/00002Ha/01@00Ha/00000
Ha/00P0000MS6`00Ha]S6`00Ha/00002Ha/01`00Ha/006<K001S6`00009S6`03001S6`00009S6`04
001S6P00HaX300001F<J001S6V<J00000V;j00T006;j001RnP00H_X006;j00000V;j00<006;j0000
0V;j0P000V;j0`00011RnP00H_YRnP00H_X006;j001RnP00H_X006;j001RnP800008G_X005kj001N
nP00G_X0009NnP04001NnP00G_X5000015kJ001NfP000UkJ0P0000INfP00G]YNfP00G]X20002G]X2
00000e[J0000000200000e[J00000002F]X04P00F]X005[J001JfP00F]X005Zj001J^P00F[X005Jj
001F^P80000=E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000]B^`00D[/005:k001B^`00D[/0
05:k00800009D[/005:k001B^`00D[/005:k00800005C[/004jk001>^`0200002djk001>^`00C[/0
04jk001>^`00C[/00P0000=>^`00C[/00P0001E>_000C[`004jl001>_000C[`004jl001>_000C[`0
04jl001>_000C[`02`0000E>_000C[`004jl0080000;C[`004jl001>_000C[`004jl001>_0020000
1dkL001>g000C]`004kL0080000CC]`004kL001Bg000D]`005;L001Bg000D]`005;L001Bo000D_`0
0P0000eFo000E_`005Kl001Fo000E_`005Kl001Fo005000015[l001Jo0000U[l00h005[l001Jo000
Fa`005/L001K7000Fa`005/L0`0000AO7000Ga`0009O700:001O6`00Ga/005lK001O6`00Ga/30000
15lK001O6`000UlK00X005kk001Nn`00G_/005kk001Nn`<00004G_/005kk0002G_/02P00G_/005kk
001Nn`00G_/005kk0`0000ANn`00G_/0009Nn`06001Nn`00G_/005kk0P000Ukk00<005kk00000P00
00ANn`00G_/0009Nn`800008G_/005kk001Nn`00G_/0009NfP03001NfP0000<00004G]X005[J0002
F]X01P00F]X005[J001JfP800004F]X005[J0002F]X00`00F]X0000700001U[J001JfP00F]X0009J
fP04001JfP00F]X2000035[J001J^P00F[X005Zj001J^P00E[X0009F^P800005E[X005Jj001F^P0:
00003EJk001F^`00E[/005Jk001F^`00E[/005Jk0080000>E[/005JkE[/005Jk001F^`00E[/005Jk
001F^`80000AE[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`02000025Jk001F^`00E[/0
05Jk0002E[/01000E[/005Jk0P0000EF^`00E[/005Jk00`0000OE]/005KK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00P0000YFf`00000005KK001F
f`00E]/0009Ff`04001Ff`00E]/200000eKK0000000700001UKK001Ff`00E]/000Qoo`03001oogoo
02Yoo`00/Goo00<007ooOol0Fgoo00H005;K001Bf`00D]`200001e;L001Bg000D]`005;L0080009B
g0800007D]`005;L001Bg000D]`00P0000UBg000D]`005;L001Bg000D]`00P0000MBg000D]`005;L
001Bg00A00000djl001>_00200001djl001>_000C[`004jl00800007C[`004jl001>_000C[`00P00
00M>_000C[`004Zl001:_00300001dZl001:_@00B[d004Zm00800008B[d00000B[d004Zm001:_@80
0003B[d0000000T00007B]d004[M001:g@00C]d00P0000U>g@00C]d004km001>o@00D_d00P0000=B
o@00D_d0200000EG7000001K7000009K7003001K7000009K7004001K7000Ga`200001elL000005lL
001O7000009O7009001O6elK001O6`00Ha/006<K00<00005Ha/006<KHa/00002Ha/02@00Ha/006<K
001S6`00Ha/00002Ha/02@00Ha]S6`00Ha/006<K001S6`030002Ha/00`00Ha/00002Ha/01000Ha/0
06<J0P0000IS6`00HaX006<J0002HaX01P00H_X006;j001RnP<0009RnP03001RnP00009RnP04001R
nP00H_X300003V;j001RnV;j001RnP00H_X006;j001RnP00H_X4000015kj001NnUkj0P0000mNnP00
G_YNnP00G_X005kj001NnP00G]X005kJ00000UkJ00h005kJ001NfP00G]X005kJ001NfP00G]X005kJ
1@0001mJfP00F]X005[J001JfP00F]X005[J001JfP00F]X005[J001J^P00F[X005Zj001F^P00E[X0
05Jk001F^`0200000eJk001F^`0T00001djk001>^`00C[/004jk00800005C[/004jk001>^`020000
1djk001>^`00C[`004jl00800007C[`004jl001>_000C[`00P0000M>_000C[`004jl001>_0020000
24jl000004jl001>_000C[`<00000djl001>_00200000djl001>_00200003DkL001>g000C]`004kL
001>g000C]`004kL0080000=D]`005;L001Bg000D]`005;L001Bo000D_`00P0000=Fo000E_`02P00
00EFo000001Jo000009Jo00>001Jo000F_`005[l001Jo000Fa`005/L001K70D0000@Fa`005lLGa`0
05lL001O7000Ga/005lK001O6`00Ga/3000045lK001O6elK001O6`00Ga/005kk001Nn`00G_/005kk
0`00011Nn`00G_]Nn`00G_/005kk001Nn`00G_/005kk001Nn`<0000@G_/005kkG_/005kk001Nn`00
G_/005kk001Nn`00G_/5000025kk001Nnekk001Nn`00G_/2000015kk001Nn`000Ukk00<005kk0000
100000=Nf`0000000UkJ00X005[J001JfP00F]X005[J001JfP80009JfP03001JfP0000@00005F]X0
05[J001JfP020002F]X02P00F]X005[J001JfP00F]X005[J0P0000IJfP00F[X005Zj0002F[X01000
F[X005Jj2P0000MF^`00E[/005Jk001F^`0200001UJk001F^`00E[/0009F^`06001F^`00E[/005Jk
0P0000mF^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000aF^`00E[/005Jk001F^`00E[/0
05Jk0002E[/200002EJk001F^`00E[/005Jk001F^`0>00002EKK001Ff`00E]/005KK001Ff`020000
35KK001FfeKK001Ff`00E]/005KK001Ff`80000ME]/005KK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`0:00003UKK001Ff`00E]/005KK001Ff`00E]/005KK
0008Ool00`00Oomoo`0ZOol00;5oo`03001oogoo05]oo`0:001Bf`00D]/005;L001Bg000D]`20000
1e;L001Bg000D]`005;L01d0000:D]`00000D]`005;L001Bg000D]`200001E;L001Bg000D]`05P00
00Y>_000001>_000B[`004Zl001:_0800007B[`004Zm001:_@00B[d00`0000M:_@00B[d004Zm001:
_@0300001DZm001:g@00B]d00P0000=:g@00B]d05`0000QBo@00E_d005Km001Fo@000ULL0P0000aK
7000FaaK7000Fa`005/L001K7000Ga`300001elL001O75lL001O7000009O7006001O6`00Ga/006<K
0`0000ES6`00Ha]S6`00009S6`04001S6`00Ha/50002Ha/02@00Ha]S6`00Ha/006<K001S6`020000
1V<K001S6`00Ha/0009S6`04001S6`00Ha/2000016<K001S6f<K0P000V<J00@006<J001RnP@00006
H_X006;j001RnP000V;j00@006;j001RnP<00007H_X006;jH_X006;j00000V;j00@006;j001RnP<0
0004G_X005kj0002G_X02P00G_X005kj001NnP00G_X005kj1@000UkJ010005kJ001NfP00G]X005kJ
001NfP00G]X005kJ001NfP<00004F]X005[J0002F]X01000F]X005[J0P000U[J00@005[J001JfP80
0004F]X005ZjF[X200001EZj001F^P00E[X02@0000=F^`00E[/00P0000UF^`00E[/005Jk001B^`00
D[/00P0000UB^`00D[/005:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[/03`0000E>^`00
C[/004jk00800003C[`004jl00800005C[`004jl001>_00200002djl001>_000C[`004jl001>_000
C[`00P0000=>_000C[`00P0000M>_000C[`004jl001>_00200000djl0000000@000034kL000004kL
001>g000D]`005;L001Bg0h0000:E_`005Kl001Fo000E_`005Kl0002E_`2000015[l001Jo5[l0P00
00MJo000F_`005[l001K700400004E/L001K7000Fa`005/L001O7000Ga`005lL001O6`00Ga/01000
00=O6`0000000UlK00X005lK001O6`00Ga/005kk001Nn`@00003G_/00000009Nn`07001Nn`00G_/0
05kk00000Ukk00<005kk00000P0000=Nn`0000000Ukk00T005kk001Nn`00G_/005kk00000Ukk1000
00ANn`00G_/0009Nn`0<001Nn`00G_/005kk001Nn`00G_/005kk1@0000ANf`00G]/0009Nf`800008
G]X005[J001JfP00F]X0009JfP03001JfP0000D00008F]X005[J001JfP00F]X0009JfP80000CF]X0
05[J001JfP00F]X005[J001JfP00F]X005[J001J^P00F[X01`0000mF^P00001F^P00E[X005Jj001F
^`00E[/005Jk00000UJk0P0000eF^`00E[/005Jk001F^`00E[/005Jk001F^`0200007EJk001F^`00
E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/03P0000EF^`00
E[/005Jk00800008E[/005KK001Ff`00E]/0009Ff`0G001Ff`00001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`0200001UKK001Ff`00E]/0009Ff`06001Ff`00E]/005KK300000EF
f`00E]/005KK0080000:E]/005KKE]/005KK001Ff`00E]/2000015KK001Ff`0027oo00<007ooOol0
:Woo002bOol00`00Oomoo`1KOolB00002U;L000005;L001Bg000D]`005;L0P0000UBg000D]`005;L
001Bg000D]`00P0000IBg000D]`005;L0002D]`200001e;L001Bg000D]`005;L00800003D]`005;L
00800003C]`004kL00800007C[`004jl001>_000C[`00P0000M>_000C[`004jl001>_00<00002DZl
001:_@00B[d004Zm001:_@0200003dZm001:_@00B[d004Zm001:_@00B[d004[M001:g@0200002T[M
000004[M001:g@00C]d004kM0P0000U>g@00C_d004km001Bo@00D_d00P0000]Bo@00D_eBo@00E_d0
05Km001Fo@00009G70800007Fa`005/L001K7000Fa`0100000=O700000000UlL00T005lLGa`005lL
001O7000Ga/0100000IO6`00Ga/006<K0002Ha/01000Ha/006<K0P0000IS6`00Ha/006<K0002Ha/0
1000Ha/006<K100000aS6`00Ha]S6`00Ha/006<K001S6`00Ha/2000036<K001S6f<K001S6`00HaX0
06<J001S6P800004H_X006;j0002H_X20002H_X01000H_X006;j0P0000=RnP0000000V;j00<006;j
00000V;j00T006;j001RnP00H_X005kj00000Ukj00`005kj001NnP00G_X005kj001NnP00G_X20000
2Ukj001NnP00G_X005kJ001NfP000UkJ0P000UkJ0P0000=NfP0000000P0000=NfP0000000U[J01@0
05[J001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X005[J2@00019F^P00001F^`00E[/005Jk
001F^`00E[/005Jk001F^`00E[/200003e:k001B^`00D[/005:k001B^`00D[/005:k001B^`020000
1E:k001B^`00D[/00P0000=B^`00C[/00P0000]>^`00C[/004jk001>^`00C[/004jk00/00007C[`0
04jl001>_000C[`00P0000=>_000C[`00P0000E>_000C[`004jl0080000=C[`004jl001>_000C[`0
04jl001>_000C[`00`0000U>_000C[`004jl001>_000C]`00P0000E>g000C]`004kL00h00009D]`0
05;L001Bo000D_`005;l0080000DE_`005KlE_`005Kl001Fo000E_`005Kl001Fo000E_`005[l001J
o080009Jo0D00004F_`005[l0002Fa`01000Fa`000000U/L0P0000=O7000Ga`0100000AO6`00Ga/0
009O6`80009O6`800004Ga/005lKGa/3000015kk001Nn`000Ukk0P0000INn`00G_/005kk0002G_/5
000015kk001Nnekk0P0000INn`00G_/005kk0002G_/500000ekk00000002G_/02@00G_/005kk001N
n`00G_/00002G_/2000025kk00000000G]/005kK0002G]/01000G]/005kK0P0000ANfP00F]X0009J
fP03001JfP0000D00006F]X005[J001JfP000U[J00H005[J001JfP00F]X200001U[J001JfP00F]X0
009JfP04001JfP00F]X800001eZj001J^P00E[X005Jj0080000>E[X005JjE[X005Jj001F^`00E[/0
05Jk001F^`80000=E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000iF^`00E[]F^`00E[/005Jk
001F^`00E[/005Jk4000021F^`00001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F
^`00E]/005KK001Ff`00E]/005KK0P0001]Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`00E]/02P00029Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/000Moo`03001oogoo02Yoo`00/Woo00<007oo
Ool0Fgoo00X005;K001Bf`00D]/005;L001Bg0800006D]`005;L001Bg0000U;L0P0000MBg000D]`0
05;L001Bg00200002E;L001Bg000D]`005;L001Bg00200002E;L001Bg000D]`005;L001Bg0020000
2E;L001Bg000D]`005;L001Bg00200001E;L001>g000C]`00P0000M>_000C[`004jl001>_0020000
1Djl001>_000C[`00P0000Y>_000001>_000C[`004jl001:_0`00007B[d004Zm001:_@00B[d00P00
00M:_@00B[d004[M001:g@0200002T[M000004[M001:g@00C]d004kM0P0000U>g@00C_d004km001B
o@00D_d00P0000aBo@00D_eBo@00E_d005Km001Fo@00Ea`200000e/L001K7004000015/L001K7000
0UlL0P000UlL00H005lL001O7000Ga`2000015lK001O6`000UlK00P005lK001S6`00Ha/006<K0P00
00aS6`00Ha]S6`00Ha/006<K001S6`00Ha/2000016<K001S6`000V<K00<006<KHa/00P0000=S6`00
Ha/00P0000aS6`00Ha]S6`00Ha/006<K001S6P00HaX200003V;j001RnV;j001RnP00H_X006;j001R
nP00H_X2000016;j001RnV;j0P0000QRnP00H_YRnP00H_X006;j1@000Ukj00L005kj001NnP00G_X0
0002G_X200001ekj000005kj001NnP00009NnP80009NfP06001NfP00G]X005kJ1@0000aNfP00G]X0
05kJ001NfP00F]X005[J0002F]X200002E[J001JfP00F]X005[J001JfP0500005E[J001J^P00E[X0
05Jj001F^P00E[/005Jk001F^`00E[/005Jk001F^`0200002EJk001F^`00E[/005:k001B^`020000
2E:k001B^`00D[/005:k001B^`0200002e:k001B^`00D[/005:k001B^`00C[/00P0000M>^`00C[/0
04jk001>^`02000034jk000004jk001>^`00C[/004jl001>_0T00007C[`004jl001>_000C[`00P00
00U>_000C[`004jl001>_000C[`00P0000E>_000C[`004jl0080000;C[`004jl001>_000C[`004jl
001>g00200000dkL001>g00200001dkL001>g000C]`005;L00800004D]`005;L0002D]`02000D]`0
05;l001Bo000D_`200004eKl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000F_`005[l00D00004
F_`005[l0002F_`03000F_`005/L001K7000Fa`005/L001O70<00004Ga`005lK0002Ga/02P00Ga/0
05lK001O6`00Ga/005lK1@0000iNn`00G_]Nn`00G_/005kk001Nn`00G_/005kk1@0000ANn`00G_/0
009Nn`04001Nn`00G_/20002G_/00`00G_/00002000015kk001Nn`000Ukk0P0000INn`00G_/005kk
0002G_/00`00G_/00005000035kk001NfekK001Nf`00G]/005kK001Nf`80009NfP03001JfP0000@0
0003F]X005[J0080000>F]X005[JF]X005[J001JfP00F]X005[J001JfP80009JfP04001JfP00F]X8
00002U[J001J^P00F[X005Zj001J^P000UJj014005Jj000005Jj001F^P00E[X005Jk001F^`00E[/0
05Jk00800006E[/005Jk001F^`000UJk00H005Jk001F^`00E[/200000eJk0000000<00003eJk001F
^`00E[/005Jk001F^`00E[/005Jk001F^`0200003UJk001F^eJk001F^`00E[/005Jk001F^`00E[/2
00004EJk001F^`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00P0000aFf`00E]]Ff`00E]/005KK
001Ff`00E]/<00001eKK001Ff`00E]/005KK0080009Ff`08001Ff`00E]/005KK001Ff`80000FE]/0
05KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0007Ool00`00Oomoo`0ZOol00;=o
o`03001oogoo05]oo`0:001Bf`00D]/005;K001Bg000D]`200002E;L001Bg000D]`005;L001Bg002
00002E;L001Bg000D]`005;L001Bg002000015;L001Bg0000U;L0P0000MBg000D]`005;L001Bg002
00001e;L001Bg000D]`005;L00800009D]`005;L001Bg000C]`004kL00800005C[`004jl001>_002
00002Tjl000004jl001>_000C[`004jl0P00015>_000C[`004jl001:_000B[`004Zl001:_@00B[d0
04Zm00X00009B[d004Zm001:g@00B]d004[M00800009B]d004[M001:g@00C]d004kM00800009C]d0
04km001>o@00D_d005;m0080000;D_d005;m001Fo@00E_d005Km001G7005000015/L001K70000U/L
00<005/L00000UlL0P0000=O7000Ga`0100000MO7000Ga]O6`00Ga/00002Ga/200000f<K001S6`02
00001f<K001S6f<K001S6`00009S6`800005Ha/00000Ha/00002Ha/00`00Ha/00002Ha/01000Ha/0
06<K0`0000MS6`00Ha]S6`00Ha/00002Ha/00`00Ha/0000200001f<K001RnV;j001RnP00009RnP80
0003H_X006;j00800006H_X006;jH_X006;j0P000V;j00@006;j001RnP800008H_X006;j001NnP00
G_X0009NnP04001NnP00G_X500005ekj001NnUkj001NnP00G_X005kj001NfP00G]X005kJ001NfP00
G]X005kJ00000UkJ00@005kJ001NfP80009JfP08001JfP00F]X005[J001JfP800003F]X000000080
0005F]X00000F]X00002F]X01000F[X000000UJj01<005Jj000005Jk001F^`00E[/005Jk001F^`00
E[/005Jk001F^`0200002e:k001B^`00D[/005:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00
D[/00P0000=B^`00C[/00P0000]>^`00C[/004jk001>^`00C[/004jk00800007C[/004jk001>^`00
C[`00`0000M>_000C[`004jl001>_00=00001Djl001>_000C[`00P0000]>_000C[`004jl001>_000
C[`004jl00800005C[`004jl001>g00200003DkL001>g000C]`004kL001>g000C]`005;L0080000C
D]`005;L001Bg000D]`005;l001Bo000D_`005Kl001Fo000E_`00P0000MFo000E_`005Kl001Fo006
00001E[l000005[l00000U[l00h005[l001Jo000F_`005/L001K7000Fa`005/L0`00011O7000GaaO
7000Ga/005lK001O6`00Ga/005lK001O6`<00004G_/005kk0002G_/04@00G_/005kk001Nn`00G_/0
05kk001Nn`00G_/005kk00000Ukk00X005kk001Nn`00G_/005kk001Nn`D00008G_/005kkG_/005kk
001Nn`800004G_/005kk0002G_/5000045kk001Nn`00G_/005kk001Nf`00G]/005kK001Nf`000UkK
1P0000IJfP00F]X005[J0002F]X2000035[J001JfP00F]X005[J001JfP00F]X0009JfPP00007F]X0
05[J001JfP00F]X00P000UZj00X005Zj001J^P00F[X005Jj001F^P80000<E[X005Jj001F^P00E[/0
05Jk001F^`000UJk0P0000EF^`00E[/005Jk00`0000;E[/005Jk001F^`00E[/005Jk001F^`020000
1UJk001F^`00E[/0009F^`06001F^`00E[/005Jk0P00015F^`00E[/005Jk001F^`00E[/005Jk001F
^`00E[/005Jk00800008E[/005KK001Ff`00E]/0009Ff`09001Ff`00001Ff`00E]/005KK00`0000:
E]/005KK001Ff`00E]/005KK0002E]/200005EKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`0200002UKK001FfeKK001Ff`00E]/005KK1P0027oo00<007ooOol0:Goo002dOol0
0`00Oomoo`1KOol02`00D]/00000D]/005;L001Bg000D]`00P000U;L00@005;L001Bg0800007D]`0
05;L001Bg000D]`00P0000]Bg000D]`005;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`0
0P0000UBg000D]`005;L001Bg000D]`00P0000MBg000C]`004kL001>_00200001Djl001>_000C[`0
0P0000U>_000C[`004jl001>_000C[`00P0000I>_000001>_000B[`200004DZl001:_000B[d004Zm
001:_@00B[d004Zm001:_@00B[d03P0000M:g@00B]d004kM001>g@0200003DkM001>o@00C_d005;m
001Bo@00D_d005;m00T00005E_`00000Fa`00002Fa`00`00Fa`00002Fa`03@00Fa`005lL001O7000
Ga`005lL001O7000009O7009001O6elK001O6`00Ga/005lK00<00005Ha/006<KHa/00002Ha/02@00
Ha/006<K001S6`00Ha/00002Ha/00`00Ha/00002Ha/01000Ha/006<K0`0000ES6`00Ha]S6`00009S
6`09001S6`00Ha/006<K001S6`00009S6`03001RnP00009RnP04001RnP00H_X300003V;j001RnV;j
001RnP00H_X006;j001RnP00H_X200001V;j001RnV;j001RnP80009NnP0;001NnP00G_X005kj001N
nP00G_X00002G_X03000G_X005kj001NnP00G_X005kJ001NfPD0009NfP0B001NfP00G]X005kJ001N
fP00G]X005[J001JfP00F]X005[J1@0001UJfP00F]X005[J001JfP00F]X005[J001J^P00E[X005Jj
001F^P00E[/005Jk001F^`0200002EJk001F^`00E[/005Jk001F^`0200003e:k001B^`00D[/005:k
001B^`00D[/005:k001B^`0200001E:k001B^`00D[/00P0000UB^`00C[/004jk001>^`00C[/00P00
00E>^`00C[/004jk00800009C[/004jk001>^`00C[`004jl00800005C[`004jl001>_00200000djl
001>_00200001Djl001>_000C[`03P0000I>_000001>_000C[`200003Djl001>_000C]`004kL001>
g000C]`004kL0080000;C]`004kL001Bg000D]`005;L001Bg00200003e;L001Bo000D_`005;l001F
o000E_`005Kl001Fo00700001UKl001Fo000F_`0009Jo080000;F_`005[l001Jo000F_`005[l001K
700600000e/L00000002Ga`02@00Ga`005lK001O6`00Ga/00002Ga/300000ekk00000002G_/02@00
G_/005kk001Nn`00G_/00002G_/60002G_/02@00G_/005kk001Nn`00G_/00002G_/4000015kk001N
n`000Ukk00`005kk001Nn`00G_/005kk001Nn`00G_/3000015kk001Nn`000Ukk00X005kk000005kk
001Nf`00G]/0009Nf`03001Nf`0000<00006F]/005[J001JfP000U[J00@005[J001JfP800006F]X0
05[J001JfP000U[J00@005[J001JfP@0000:F]X005[J001JfP00F]X005[J0002F]X200003E[J001J
^P00F[X005Zj001J^P00E[X005Jj0080000<E[X005JjE[X005Jj001F^`00E[/005Jk2P0000MF^`00
E[/005Jk001F^`0200002UJk001F^`00E[/005Jk001F^`000UJk01<005Jk000005Jk001F^`00E[/0
05Jk001F^`00E[/005Jk001F^`0200006EJk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/0
05Jk001Ff`00E]/005KK00`00009E]/005KK001Ff`00E]/005KK0080009Ff`0:001Ff`00E]/005KK
001Ff`00E]/200005eKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0
300000AFf`00E]/000Qoo`03001oogoo02Uoo`00]7oo00<007ooOol0Fgoo00X005;K001Bf`00D]/0
05;L001Bg0800009D]`005;L001Bg000D]`005;L00800009D]`005;L001Bg000D]`005;L00800005
D]`005;L001Bg00W000034jl000004jl001>_000C[`004jl001>_0800005C[`004jl001:_0020000
1DZl001:_000B[d00P0001A:_@00001:_@00B[d004Zm001:_@00B]d004[M001:g@00B]d004[M0P00
00=:g@0000005@0000QBo@00E_d005Km001Fo0000UKl0P0000aK7000FaaK7000Fa`005/L001K7000
Ga`50002Ga`00`00Ga`00002Ga`01P00Ga/005lK001O6`<00005Ga/006<KHa/00002Ha/01P00Ha/0
06<K001S6`<0009S6`03001S6`00009S6`04001S6`00Ha/200001V<K001S6`00Ha/0009S6`06001S
6`00Ha/006<K0`000V<K00<006<K00000V;j00@006;j001RnP<00007H_X006;jH_X006;j00000V;j
00D006;j000006;j0080000>H_X006;jH_X006;j001RnP00G_X005kj001NnPD0009NnP05001NnP00
G_X00002G_X20002G_X500002UkJ001NfP00G]X005kJ001NfP000UkJ0P0000MNfP00G]X005[J001J
fP05000015[J001JfP000U[J00@005[J001JfP800006F]X005[JF]X005Zj0P0000mF^P00E[X005Jk
001F^`00E[/005Jk001F^`00E[/00P0000UF^`00E[/005Jk001B^`00D[/03@0000]B^`00D[/005:k
001B^`00D[/004jk00800007C[/004jk001>^`00C[/00P0000M>^`00C[/004jk001>^`0200000djl
001>_00200002djl001>_000C[`004jl001>_000C[`00P0000=>_000C[`00P0000M>_000C[`004jl
001>_00200000djl001>_00A00001DkL001>g000C]`00P0000e>g000C]`005;L001Bg000D]`005;L
001Bg00@00001UKl001Fo000E_`0009Fo00:001Fo000F_`005[l001Jo000F_`200000e[l001Jo004
00001U[l001Jo000F_`0009K7080009O70800004Ga/005lKGa/5000015kk001Nnekk0P0000INn`00
G_/005kk0002G_/500003Ukk001Nn`00G_/005kk001Nn`00G_/005kk0002G_/300000ekk00000002
G_/02@00G_/005kk001Nn`00G_/00002G_/2000025kk00000000G_/005kk0002G_/01P00G_/005kk
001Nn`80009Nf`03001Nf`0000@00005F]/00000F]/00002F]X02P00F]X005[J001JfP00F]X005[J
0P000U[J00<005[J00001P0000MJfP00001JfP00F]X00002F]X02000F]X005[J001JfP00F]X20000
25Zj001J^P00F[X005Zj0002E[X01@00E[X00000E[X02`0000mF^`00001F^`00E[/005Jk001F^`00
E[/005Jk00000UJk0P0000eF^`00E[/005Jk001F^`00E[/005Jk001F^`0200003eJk001F^`00E[/0
05Jk001F^`00E[/005Jk001F^`0200003UJk001F^eJk001F^`00E[/005Jk001F^`00E[/<00000eKK
001Ff`0200001UKK001Ff`00E]/0009Ff`06001Ff`00E]/005KK0P0001=Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK001Ff`02000025KK000005KK001Ff`00E]/:000045KK001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`001goo00<007ooOol0:Goo002eOol00`00Oomoo`1KOol02`00D]/0
0000D]/005;L001Bg000D]`00P0000=Bg00000005P0000=Bg000D]`00P0000MBg000D]`005;L001B
g00200002E;L001Bg000D]`005;L001Bg00200001e;L001Bg000D]`004kL00800005C]`004kL001>
_00@00001Djl001:_000B[`00P0000M:_000B[d004Zm001:_@0200001DZm001:_@00B[d00`0000U:
g@00B]d004[M001:g@00B]d00`0000M>g@00C]d004kM001>g@0200005TkM001>o@00D_d005;m001B
o@00D_d005;m001Bo@00E_d005Km001Fo0000UKl0P0000EK7000Fa`005/L00H00006Fa`005lL001O
70000UlL00H005lL001O7000Ga/400001UlK001O6`00Ga/0009S6`04001S6`00Ha/4000016<K001S
6`000V<K00H006<K001S6`00Ha/2000016<K001S6f<K0P000V<K00@006<K001S6`@00006Ha/006<K
001S6`000V<K00@006;j001RnP800003H_X00000009RnP03001RnP00009RnP04001RnP00H_X30000
3V;j001RnV;j001RnP00H_X006;j001NnP00G_X200002Ukj001NnP00G_X005kj001NnP000Ukj00@0
05kj001NnP<00006G]X005kJ001NfP000UkJ0P000UkJ00P005kJ001NfP00G]X005kJ1@0001MJfP00
F]X005[J001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X005Zj0080009F^P07001F^P00001F
^`00E[/04P0000MB^`00D[/005:k001B^`0200000e:k001B^`0G00002Tjk000004jk001>^`00C[/0
04jl0P0000M>_000C[`004jl001>_00200000djl001>_00200003Djl001>_000C[`004jl001>_000
C[`004jl0080000:C[`00000C[`004jl001>_000C[`200001Djl001>g000C]`05`0002=Bg000D_`0
05;l001Bo000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000F_`005[l001Jo000F_`0
05[l00<00004F_`005[l0002F_`03000F_`005[l001K7000Fa`005lL001O70D00004G_/005kk0002
G_/01P00G_/005kk001Nn`80009Nn`<00004G_/005kk0002G_/02000G_/00000G_/005kk0002G_/5
000015kk001Nnekk0P0000INn`00G_/005kk0002G_/00`00G_/00005000045kk001Nnekk001Nn`00
G_/005kk001Nn`00G_/005kk1@00019Nf`00F]/005[K001Jf`00F]/005[J001JfP00F]X005[J0002
F]X200000e[J0000000300005e[J001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X005[J001J
fP00F]X00P000UZj00H005Zj001J^P00F[X800002eJj001F^`00E[/005Jk001F^`00E[/00P0000iF
^`00E[]F^`00E[/005Jk001F^`00E[/005Jk0P0000eF^`00E[/005Jk001F^`00E[/005Jk001F^`02
00001UJk001F^`00E[/0009F^`06001F^`00E[/005Jk0P0000=F^`00E[/03P0001eFf`00E]/005KK
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0080000<E]/005KK
001Ff`00E]/005KK001Ff`000UKK0P0000EFf`00E]/005KK00T00009E]/00000E]/005KK001Ff`00
009Ff`04001Ff`00E]/2000025KK001Ff`00E]/005KK0007Ool00`00Oomoo`0YOol00;Eoo`03001o
ogoo05aoo`d00007D]`005;L001Bg000D]`00P0000UBg000D]`005;L001Bg000D]`00P0000ABg000
D]`0009Bg00;001Bg000001Bg000D]`005;L001Bg00200002E;L001Bg000D]`005;L001Bg0020000
1e;L001Bg000D]`004kL00800003C]`004kL0080000<C[`00000C[`004jl001>_000C[`004jl0P00
00=>_00000002`0000=:_@00B[d00P0000E:_@00B[d004Zm00800009B]d004[M001:g@00B]d004[M
00<00007C]d004kM001>g@00C]d00P0001]>g@00C_d005;m001Bo@00D_d005;m001Bo@00D_d005Km
001Fo@00E_`005Kl001G7000Fa`00`0000IK7000Fa`005/L0002Fa`02P00Ga`005lL001O7000Ga`0
05lL0P0000AO7000Ga/0009O6`08001O6`00Ga/006<K001S6`800004Ha/006<K0002Ha/02000Ha/0
06<K001S6`00Ha/2000036<K001S6f<K001S6`00Ha/006<K001S6`800004Ha/006<K0002Ha/02000
Ha/006<K001S6`00H_X2000016;k001RnV;j0P000V;j00H006;j001RnP00H_X300001f;j001RnV;j
001RnP00009RnP04001RnP00H_X300001Ukj001NnUkj001NnP80009NnP06001NnP00G_X005kj0`00
01ANnP00G]YNfP00G]X005kJ001NfP00G]X005kJ001NfP00G]X005kJ0`0000IJfP00F]X005[J0002
F]X2000015[J001JfP000U[J0P0000]JfP00F]X005[J001JfP00F[X005Jj00T0000<E[/00000E[/0
05Jk001F^`00E[/005Jk0P0000AB^`00D[/0009B^`800007D[/005:k001B^`00D[/00P0000EB^`00
D[/005:k00800009D[/005:k001B^`00D[/004jk00800003C[/004jk00l00005C[`004jl001>_002
00002djl001>_000C[`004jl001>_000C[`00P0000E>_000C[`004jl0080000;C[`004jl001>_000
C[`004jl001>_00200000djl001>g00200001dkL001>g000C]`004kL0080000;D]`005;L001Bg000
D]`005;L001Bg0020002D]`04P00D_`005;l001Bo000E_`005Kl001Fo000E_`005Kl001Fo0800007
E_`005Kl001Jo000F_`01`00019Jo000F_aJo000F_`005[l001Jo000F_`005/L001K7000Ga`30000
15kl001Nn`000Ukk00`005kk001Nn`00G_/005kk001Nn`00G_/300003Ukk001Nnekk001Nn`00G_/0
05kk001Nn`00G_/5000015kk001Nn`000Ukk00P005kk000005kk001Nn`000Ukk1@0000iNn`00G_/0
05kk001Nn`00G_/005kk001Nn`000Ukk00<005kk00000`0000INf`00G]/005kK0002F]/02P00F]/0
0000F]/005[J001JfP000U[J00<005[J00001@0000QJfP00F]X005[J001JfP000U[J00h005[J0000
05[J001JfP00F]X005[J001JfP000U[J0P0000=JfP0000001`0000=F^P00E[X00P0000QF^P00E[X0
05Jk001F^`000UJk00@005Jk001F^`80000=E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000YF
^`00E[/005Jk001F^`00E[/0009F^`09001F^`00001F^`00E[/005Jk00h0000;E[/005Jk001F^`00
E[/005Jk001F^`020002E]/02P00E]/005KK001Ff`00E]/005KK0P00015Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK0080009Ff`08001Ff`00E]/005KK001Ff`X0000GE]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`020002E]/2000015KK001Ff`001goo00<0
07ooOol0:Goo002fOol00`00Oomoo`1KOol02`00D]/00000D]/005;K001Bg000D]`00P000U;L00H0
05;L001Bg000D]`200002E;L001Bg000D]`005;L001Bg00200002E;L001Bg000D]`005;L001Bg002
00001e;L001Bg000D]`005;L00800009D]`005;L001Bg000D]`005;L00800007D]`005;L001>g000
C]`00P0000E>g000C[`004jl00800009C[`004jl001>_000C[`004jl00<00005C[`004jl001>_002
00001DZl001:_000B[d02`0000a:_@00001:g@00B]d004[M001:g@00B]d200001dkM001>g@00C]d0
04kM0080000;C]d004km001Bo@00D_d005;m001Bo@0200001e;m001Fo@00E_d005Kl00L00009Fa`0
05/LFa`005/L001K7000009K7005001O7000001O700400001elL001O75lL001O6`00009O6`800003
Ga/006<K00800007Ha/006<KHa/006<K00000V<K0P0000=S6`0000000P0000ES6`00Ha]S6`00009S
6`800003Ha/006<K0080000>Ha/006<KHa/006<K001S6`00Ha/006<K001S6`80000>H_/006;kH_/0
06;j001RnP00H_X006;j001RnP800008H_X006;j001RnP00H_X0009RnP04001RnP00H_X3000045kj
001NnUkj001NnP00G_X005kj001NnP00G_X005kj0P0000=NnP0000000Ukj00h005kJ001NfP00G]X0
05kJ001NfP00G]X005kJ1@0001INfP00F]YJfP00F]X005[J001JfP00F]X005[J001JfP00F]X005[J
001JfP800003F]X0000000D0000EE[X005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/0
05Jk0080000;D[/005:k001B^`00D[/005:k001B^`0200002E:k001B^`00D[/005:k001B^`020000
2E:k001B^`00D[/005:k001>^`0200002Tjk000004jk001>^`00C[/004jk0P0000=>^`00C[`03`00
00E>_000C[`004jl0080000;C[`004jl001>_000C[`004jl001>_00200001Djl001>_000C[`00P00
00e>_000C]`004kL001>g000C]`004kL001>g00200002e;L001Bg000D]`005;L001Bg000D]`00P00
00ABg000D_aBo080000=D_`005Kl001Fo000E_`005Kl001Fo000E_`00P0000=Fo0000000100001EJ
o000F_`005[l001Jo000F_`005[l001Jo000F_`005[l001Jo000Fa`0100000=Jo00000000Ukl00T0
05kk001Nn`00G_/005kk00000Ukk1P0001ENn`00G_]Nn`00G_/005kk001Nn`00G_/005kk001Nn`00
G_/005kk00000Ukk00`005kk001Nn`00G_/005kk001Nn`00G_/3000015kk001Nn`000Ukk00X005kk
000005kk001Nn`00G_/0009Nn`D00005G]/00000G]/00002G]/02000G]/005[K001Jf`00F]/20002
F]X00`00F]X0000400000e[J001JfP0200003U[J001JfU[J001JfP00F]X005[J001JfP00F]X20000
25[J001JfU[J001JfP00F]X600002eZj001J^P00F[X005Zj001F^P00E[X00P000UJj00`005Jj001F
^`00E[/005Jk001F^`00E[/2000035Jk001F^`00E[/005Jk001F^`00E[/0009F^`800009E[/005Jk
001F^`00E[/005Jk00`00007E[/005Jk001F^`00E[/00P0000IF^`00E[/005Jk0002E[/01P00E[/0
05Jk001F^`80000?E[/005KK001Ff`00E]/005KK001Ff`00E]/005KK00800006E]/005KK001Ff`00
0UKK00H005KK001Ff`00E]/200000eKK0000000900002UKK000005KK001Ff`00E]/005KK0P0000=F
f`00E]/00P0001YFf`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`001Woo00<007ooOol0:Goo002gOol00`00Oomoo`1KOol02`00D]/00000D]/005;K001Bg000D]`0
0P000U;L0P0000MBg000D]`005;L001Bg002000015;L001Bg0000U;L0P0000MBg000D]`005;L001B
g00200001e;L001Bg000D]`005;L00800009D]`005;L001Bg000D]`005;L00800007D]`005;L001B
g000C]`00P0000M>g000C]`004jl001>_00200000djl001>_00200001Djl001>_000C[`00P0000E>
_000C[`004jl00800003B[`004Zl00800003B[d004Zm00800005B[d004[M001:g@0>00002DkM001>
g@00C]d004kM001>g@0200001dkm001Bo@00D_d005;m00/0000:E_`005Kl001G7000Fa`005/L0002
Fa`02000Fa`005/L001K7000Ga`3000015lL001O70000UlL00T005lLGa`005lK001O6`00Ga/00`00
00EO6`00Ha]S6`00009S6`0;001S6`00Ha/006<K001S6`00Ha/00002Ha/01`00Ha]S6`00Ha/006<K
00<00007Ha/006<KHa/006<K00000V<K0P0000=S6`0000000P0000aRn`00H_]Rn`00H_/006;j001R
nP00H_X4000016;j001RnV;j0P000V;j00H006;j001RnP00H_X300001ekj001NnUkj001NnP00009N
nP800003G_X005kj00@00008G_X005kj001NnP00G_X0009NfP04001NfP000002G]X500006EkJ001N
fP00G]X005kJ001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X005[J00D00005F]X005[J001J
^P020002E[X02000E[/005Jk001F^`00E[/200002EJk001F^`00E[/005Jk001F^`02000015:k001B
^`000U:k0P0000MB^`00D[/005:k001B^`0200001E:k001B^`00D[/00P0000UB^`00D[/005:k001B
^`00C[/00P0000]>^`00C[/004jk001>^`00C[/004jk0080000:C[/00000C[`004jl001>_000C[`2
00000djl001>_00>00001Tjl000004jl001>_080000;C[`004jl001>_000C[`004jl001>g0020000
3DkL001>g000C]`004kL001>g000D]`005;L0080000;D]`005;L001Bg000D]`005;L001Bo0020000
2E;l001Fo000E_`005Kl001Fo00700001UKl001Fo000E_`0009Jo008001Jo000F_`005[l001Jo080
0004F_`005[lF_`5000015[l001Jo0000U[l0P000Ukl0P0000ENn`00G_/005kk00@0000>G_/005kk
001Nn`00G_/005kk001Nn`00G_/0009Nn`H0009Nn`09001Nn`00G_/005kk001Nn`00009Nn`800006
G_/00000001Nn`000Ukk00P005kk001Nn`00G_/005kk0P000Ukk00<005kk00000P0001ENn`00G_/0
05kK001Nf`00G]/005kK001Nf`00F]/005[K001Jf`00F]/01@0001]JfP00F]X005[J001JfP00F]X0
05[J001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X01`0000=JfP00F]X00P0000IJ^P00F[X0
05Zj0002F[X01000E[X005Jj0P0000eF^P00E[X005Jk001F^`00E[/005Jk001F^`02000035Jk001F
^eJk001F^`00E[/005Jk001F^`h00003E[/005Jk0080000:E[/005Jk001F^`00E[/005Jk0002E[/2
00003eJk001F^`00E[/005Jk001F^`00E[/005Jk001F^`0200005eJk001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK001Ff`00E]/0300001UFf`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK001Ff`020002E]/200001UKK001Ff`00E]/0009Ff`04001Ff`00E]/:
0006Ool00`00Oomoo`0YOol00;Moo`03001oogoo05]oo`04001Bf`00D]/200003e;K001Bg000D]`0
05;L001Bg000D]`005;L001Bg00200002e;L001Bg000D]`005;L001Bg000D]`00P0000MBg000D]`0
05;L001Bg00200001e;L001Bg000D]`005;L00800009D]`005;L001Bg000D]`005;L00800007D]`0
05;L001>g000C]`00P0000M>g000C[`004jl001>_00200001djl001>_000C[`004jl00800007C[`0
04jl001>_000C[`00`0000M:_000B[d004Zm001:_@0200000dZm001:g@02000034[M000004[M001:
g@00B]d004kM001>gA<00003D_d005;m00800006E_d005Km001Fo@000UKl00h005Kl001G7000Fa`0
05/L001K7000Fa`005/L100000=O700000000UlL00<005lL00000UlL00H005lL001O6`00Ga/30000
1ElK001O6elK00000V<K00H006<K001S6`00Ha/30002Ha/00`00Ha/00002Ha/01000Ha/006<K0`00
00MS6`00Ha]S6`00Ha/00002Ha/02@00Ha/006<K001S6`00H_/00002H_/00`00H_/00002H_/00`00
H_X00002000016;j001RnP000V;j00X006;j001RnP00H_X006;j001RnP800008G_X005kj001NnP00
G_X0009NnP04001NnP00G_X3000015kj001NnP000Ukj00@005kj0000009NnP06001NfP00G]X005kJ
0`0000INfP00G]X005kJ0002G]X200001UkJ001JfU[J001JfP80009JfP800003F]X005[J00D00004
F]X005[J0002F]X20002F[X200004EJj001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/00P00
00UF^`00E[/005:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[/00P0000UB^`00D[/005:k
001B^`00D[/00P0000MB^`00C[/004jk001>^`0200001djk001>^`00C[/004jk0080000;C[/004jl
001>_000C[`004jl001>_00200002Tjl000004jl001>_000C[`004jl0P0000=>_000C[`04@0000=>
_000C]`00P0000e>g000C]`004kL001>g000C]`005;L001Bg00200002e;L001Bg000D]`005;L001B
g000D_`02`0000EFo000E_`005Kl0080009Fo00@001Fo000E_`005[l001Jo000F_`005[l001Jo000
F_`5000015[l001Jo0000U[l00P005[l001Jo000G_`005kl0P0000=Nn`0000000P0000ANn`00G_/0
009Nn`08001Nn`00001Nn`00G_/0009Nn`D0000>G_/005kk001Nn`00G_/005kk001Nn`00G_/0009N
n`H0000@G_/005kkG_/005kk001Nn`00G_/005kk001Nn`00G_/5000015kk001Nn`000Ukk00X005kK
000005kK001Nf`00G]/0009Jf`03001Jf`0000<00006F]/005[K001JfP000U[J00@005[J001JfP80
0008F]X005[J001JfP00F]X0009JfP03001JfP0000D0000GF]X005[J001JfP00F]X005[J001JfP00
F[X005Zj001J^P00F[X005Jj001F^P02000025Jj001F^P00E[/005Jk0002E[/01000E[/005Jk0P00
00=F^`0000002@0001iF^`00001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00
E[/005Jk001F^`00E[/200004EJk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/00P000UKK
00X005KK001Ff`00E]/005KK001Ff`X00007E]/005KK001Ff`00E]/00P0000YFf`00E]]Ff`00E]/0
05KK001Ff`80000KE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/005KK00P00008E]/005KK001Ff`00E]/000Ioo`03001oogoo02Uoo`00^7oo00<007ooOol0Fgoo
00l005;K000005;K001Bf`00D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg00200001E;L
001Bg000D]`0=`0000E>_000C[`004jl00800007C[`004jl001>_000C[`00P0000M:_000B[d004Zm
001:_@0200001TZm000004[M001:g@80000CB]d004[M001:g@00C]d004kM001>g@00C]d004kM001>
g@00C]d00P0000IBo@00D_d005;m0002D_d02P00D_d00000E_d005Km001Fo@000UKl00@005Kl001G
70800003Fa`005/L00@00004Fa`005/L0002Ga`20002Ga`01P00Ga`005lL001O70@00006Ga/005lK
001O6`000UlK00@006<K001S6`@00006Ha/006<K001S6`000V<K00@006<K001S6`800003Ha/00000
009S6`09001S6f<K001S6`00Ha/006<K00<0009S6`03001Rn`00009Rn`09001Rn`00H_/006;j001R
n`00009RnP0:001RnP00H_X006;j001RnP00H_X4000015kj001NnUkj0P0000eNnP00G_YNnP00G_X0
05kj001NnP00G_X00002G_X03P00G_X005kj001NnP00G_X005kj001NfP00G]X3000055kJ001NfUkJ
001NfP00G]X005kJ001NfP00G]X005[J001JfP00F]X700003e[J001JfP00F]X005[J001JfP00F]X0
05[J001J^P020002E[X01000E[/005Jk0P0000eF^`00E[/005Jk001F^`00E[/005Jk001F^`020000
2e:k001B^`00D[/005:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[/00P0000UB^`00D[/0
05:k001B^`00C[/00P0000E>^`00C[/004jk00800007C[/004jk001>^`00C[/00P0000M>_000C[`0
04jl001>_00200002djl001>_000C[`004jl001>_000C[`00P0000Y>_000001>_000C[`004jl001>
_0800005C[`004jl001>_00Q00002e;l000005Kl001Fo000E_`005Kl00000UKl00@005Kl001Fo080
009Fo0800009E_`005[l001Jo000F_`005[l00D00004F_`005[l0002F_`03000F_`005[l001Jo000
F_`005kl001No0<00004G_/005kk0002G_/02000G_/005kk001Nn`00G_/200000ekk000000020000
15kk001Nn`000Ukk00P005kk000005kk001Nn`000Ukk1@0000iNn`00G_/005kk001Nn`00G_/005kk
001Nn`000Ukk00<005kk00000`0000ANn`00G_/0009Nn`06001Nn`00G_/005kK0P0000INf`00G]]N
f`00G]/500001E[K000005[K00000U[K00X005[J001JfP00F]X005[J001JfP80009JfP04001JfP00
F]X500002E[J000005[J001JfP00F]X00002F]X01000F]X005[J0P0000]J^P00F[X005Zj001J^P00
E[X005Jj0080009F^P06001F^P00E[/005Jk2P0000]F^`00E[/005Jk001F^`00E[/005Jk0080000<
E[/005JkE[/005Jk001F^`00E[/005Jk0P0000mF^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/0
0P0000IF^`00E[/005Jk0002E[/01P00E[/005Jk001F^`800003E[/0000000`0000:E]/005KK001F
f`00E]/005KK0002E]/200003EKK001Ff`00E]/005KK001Ff`00E]/005KK0080009Ff`800007E]/0
05KK001Ff`00E]/00P0000=Ff`00E]/0300000EFf`00E]/005KK0080009Ff`07001Ff`00E]/005KK
00001Goo00<007ooOol0:Goo002hOol00`00Oomoo`1KOol01000D]/005;K0P0000MBf`00D]`005;L
001Bg00B00000e;L001Bg00200001e;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P00
00UBg000D]`005;L001Bg000D]`00P0000MBg000D]`005;L001>g00200001dkL001>g000C]`004kL
00800003C]`004jl01000007B[`004Zm001:_@00B[d00P0000M:_@00B]d004[M001:g@0200004d[M
001:g@00B]d004kM001>g@00C]d004kM001>g@00C]d004kM00800006D_d005;m001Bo@000U;m00l0
05;m000005Km001Fo@00E_d005Kl001Fo000Ea`01@0000AK7000Fa`0009K7003001K7000009O7080
0005Ga`005lL001O7002000015lL001O6`000UlK00P005lK001O6`00Ga/006<K0P0000AO6`00Ha/0
009S6`08001S6`00Ha/006<K001S6`800004Ha/006<KHa/20002Ha/01P00Ha/006<K001S6`800006
Ha/006<K001S6`000V;k00H006;k001Rn`00H_/30002H_/00`00H_X00002H_X01000H_X006;j0`00
00ANnP00G_X0009NnP0:001NnP00G_X005kj001NnP00G_X50002G_X03000G_X005kj001NnP00G_X0
05kj001NnP@00003G]X00000009NfP0@001NfP00G]X005kJ001NfP00G]X005kJ001JfP00F]X30000
25[J001JfP00F]X005[J0002F]X2000015[J001JfP000U[J0P0000eJ^P00E[X005Jj001F^`00E[/0
05Jk001F^`0200001EJk001F^`00E[/0:@0000]>^`00C[/004jk001>^`00C[/004jk00800003C[/0
04jl0080000;C[`004jl001>_000C[`004jl001>_00200001Djl001>_000C[`00P0000]>_000C[`0
04jl001>_000C[`004jl00800003C[`004jl00800005C]`004kL001>g00200003DkL001>g000C]`0
05;L001Bg000D]`005;L0080000:D]`005;L001Bg000D]`005;L0002D_`200004EKl001Fo000E_`0
05Kl001Fo000E_`005Kl001Fo000E_`00P0000=Fo000F_`01P0001=Jo000F_`005[l001Jo000F_`0
05[l001Jo000F_`005[l001Jo00400000e[l00000002G_/04`00G_/005kk001Nn`00G_/005kk001N
n`00G_/005kk001Nn`00009Nn`0<001Nn`00G_/005kk001Nn`00G_/005kk0`0000ANn`00G_/0009N
n`08001Nn`00001Nn`00G_/0009Nn`03001Nn`0000@00003G_/00000009Nn`0>001Nn`00G_/005kk
001Nn`00G]/005kK001Nf`D0000GF]/005[K001Jf`00F]/005[K001Jf`00F]X005[J001JfP00F]X0
05[J001JfP0700001E[J001JfP00F]X00P000U[J00X005[J001JfP00F]X005[J001JfP800006F[X0
05Zj001J^P000UZj00@005Jj001F^PX00005E[/005Jk001F^`02000025Jk001F^`00E[/005Jk0002
E[/04`00E[/00000E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk0080000:E[/005Jk001F^`00
E[/005Jk0002E[/200001eJk001F^`00E[/005Jk00`0000;E]/005KK001Ff`00E]/005KK001Ff`02
0002E]/02P00E]/005KK001Ff`00E]/005KK0P0001MFf`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK00X0000JE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/000Eoo`03001oogoo02Uoo`00^Goo00<007ooOol0Fgoo300000=Bg000D]`0
0P0000MBg000D]`005;L001Bg002000015;L001Bg0000U;L00/005;L000005;L001Bg000D]`005;L
00800007D]`005;L001Bg000D]`00P0000UBg000D]`005;L001Bg000D]`00P0000MBg000D]`005;L
001>g00200001dkL001>g000C]`004kL00800008C]`00000C[`004jl001>_0800007C[`004jl001>
_000C[`03P0000E:g@00B]d004[M00800007B]d004[M001>g@00C]d00P0000U>g@00C]d004kM001>
g@00C]d00P0000]Bo@00D_d005;m001Bo@00D_d005;m00800003E_d005Km00H00005E_`00000Fa`0
0002Fa`00`00Fa`00002Fa`01000Fa`005lL0P0000=O700000000P0000MO7000GaaO7000Ga/00002
Ga/200000elK001O6`0200003UlK001O6elK001S6`00Ha/006<K001S6`00Ha/2000036<K001S6f<K
001S6`00Ha/006<K001S6`@00004Ha/006<KHa/20002Ha/01000H_/006;k100000IRn`00H_/006;k
0002H_X02@00H_X006;j001RnP00G_X00002G_X03000G_X005kj001NnP00G_X005kj001NnP800008
G_X005kj001NnP00G_X0009NnP06001NnP00G_X005kj0`0000YNfP00G]X005kJ001NfP00G]X0009N
fP04001NfP000002G]X200000ekJ0000000200000e[J00000002F]X04000F]X005[J001JfP00F]X0
05[J001JfP00F]X005[J0P000UZj0P0000EF^P00E[/005Jk00/0000<E[/00000E[/005Jk001F^`00
D[/005:k0P0000UB^`00D[/005:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[/00P0000EB
^`00D[/005:k01400007C[`004jl001>_000C[`00P0000=>_000C[`00P0000]>_000C[`004jl001>
_000C[`004jl00800005C[`004jl001>_00200002djl001>_000C[`004kL001>g000C]`00P0000e>
g000C]`004kL001Bg000D]`005;L001Bg00200004E;L001Bg000D]`005;L001Bg000D_`005;l001F
o000E_`00P0000]Fo000E_`005Kl001Fo000E_`005Kl00D00006F_`005[l001Jo0000U[l00@005[l
0000009Jo0800005F_`005[l001Jo004000015[l001Jo0000U[l0P0000QNn`00G_/005kk001Nn`00
0Ukk1P000Ukk00h005kk001Nn`00G_/005kk001Nn`00G_/005kk0`0000aNn`00G_]Nn`00G_/005kk
001Nn`00G_/20002G_/5000015kk001Nn`000Ukk0P0000QNn`00G_/005kk001Nn`000Ukk00<005kK
00000`0000AJf`00F]/0009Jf`04001Jf`00F]/200001U[K001Jf`00F]X0009JfP04001JfP00F]X4
000025[J001JfP00F]X005[J0002F]X05`00F]X00000F]X005[J001JfP00F]X005[J001JfP00F]X0
05Zj001J^P00F[X0200001eF^P00E[X005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/0
05Jk001F^`00E[/005Jk0080000IE[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/0
05Jk001F^`00E[/0300000MF^`00E[/005Jk001Ff`02000015KK001Ff`000UKK00H005KK001Ff`00
E]/200004EKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00P0000YFf`00E]]Ff`00E]/0
05KK001Ff`X00007E]/005KK001Ff`00E]/00P000UKK00P005KK001Ff`00E]/005KK0P0000iFf`00
E]/005KK001Ff`00E]/005KK001Ff`001Goo00<007ooOol0:Goo002jOol00`00Oomoo`1JOol01000
E]/005KK0P0000IFf`00E]/005;L0002D]`02`00D]`00000D]`005;L001Bg000D]`00P0000UBg000
D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L0080009B
g006001Bg000D]`005;L0P0000=Bg000D]`00P0000=>g000C]`00P0000M>g000C]`004kL001>g002
00001djl001>_000C[`004jl0080000?C[`004jl001>_000C[`004jl001>_000C]d004kM00800003
C]d004kM01800009C]d004kM001>g@00C]d004kM00800003D_d0000000/00006E_`005Kl001Fo000
0UKl0P0000aK7000FaaK7000Fa`005/L001K7000Ga`3000015lL001O70000UlL00T005lLGa`005lK
001O6`00Ga/00`0000MO6`00Ga]O6`00Ga/00002Ha/200000f<K00000002000036<K001S6f<K001S
6`00Ha/006<K001S6`800004Ha/006<K0002Ha/02000Ha/006<K001S6`00H_/2000016;k001Rn`00
0V;k0P000V;k00@006;j001RnPD0009NnP05001NnP00G_X00002G_X00`00G_X0000400001Ukj001N
nUkj001NnP80009NnP06001NnP00G_X005kj0`0000QNnP00G]YNfP00G]X005kJ0P000UkJ00H005kJ
001NfP00G]X500006e[J001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X0
05[J001JfP0900004UJk000005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`800004D[/005:k
D[/200002E:k001B^`00D[/005:k001B^`0200002E:k001B^`00D[/005:k001B^`0200000e:k001B
^`0200001E:k001B^`00C[/00P0000U>^`00C[/004jk001>^`00C[`03`0000E>_000C[`004jl0080
0003C[`004jl0080000;C[`004jl001>_000C[`004jl001>_00200002dkL001>g000C]`004kL001>
g000C]`00P0000]Bg000D]`005;L001Bg000D]`005;L0080000=D]`005;L001Bg000D_`005;l001F
o000E_`00P0000=Fo000E_`0200000EFo000001Fo000009Jo00<001Jo000F_`005[l001Jo000F_`0
05[l0P0000=Jo00000000P0000AJo000F_`0009Jo006001Jo000F_`005kk0P0000ANn`00G_]Nn`D0
000>G_/005kk001Nn`00G_/005kk001Nn`00G_/0009Nn`H0000@G_/005kkG_/005kk001Nn`00G_/0
05kk001Nn`00G_/3000015kk001Nn`000Ukk00@005kk001Nn`800004G_/005kk0002G_/00`00G_/0
000500003U[K001Jfe[K001Jf`00F]/005[K001Jf`00F]/20002F]/00`00F]X0000600001E[J0000
05[J00000U[J00P005[J001JfP00F]X005[J0P0000IJfP00F]X005[J0002F]X01000F]X005[J2000
00EF^P00E[X005Jj00800004E[X005Jj0002E[/02000E[/005Jk001F^`00E[/200003EJk001F^`00
E[/005Jk001F^`00E[/005Jk0080000<E[/005JkE[/005Jk001F^`00E[/005Jk3P00021F^`00001F
^`00E[/005Jk001F^`00E[/005Jk001F^`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0P00
00aFf`00E]/005KK001Ff`00E]/005KK0002E]/200001EKK001Ff`00E]/02P0000QFf`00E]/005KK
001Ff`000UKK0P0001EFf`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00P00
0UKK00L005KK001Ff`00E]/00004Ool00`00Oomoo`0YOol00;Yoo`03001oogoo05]oo`04001Ff`00
E]/200002eKK001Ff`00D]`005;L001Bg000D]`00P0000mBg000D]`005;L001Bg000D]`005;L001B
g000D]`00P0000MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L0080000;D]`005;L001B
g000D]`005;L001Bg00200001E;L001Bg000C]`00P0000M>g000C]`004kL001>g00200002DkL001>
_000C[`004jl001>_00200001Tjl000004jl001>_0800007C[`004jl001>g@00C]d00P0000Q>g@00
001>g@00C]d004kM0P0000U>g@00C]d004kM001>g@00C]d03@0000UBo@00D_d005;m001Bo@00D_d0
0P0000UFo@00E_aFo000E_`005Kl00000UKl0P0000MK7000Fa`005/L001K700400000e/L00000002
Ga`00`00Ga`00002Ga`01P00Ga`005lK001O6`<00005Ga/005lKGa/00002Ga/02`00Ga/006<K001S
6`00Ha/006<K00000V<K00L006<KHa/006<K001S6`0300001f<K001S6f<K001S6`00009S6`800003
Ha/006<K0080000>H_/006;kH_/006;k001Rn`00H_/006;k001RnP800008H_/005kj001NnP00G_X0
009NnP0;001NnP00G_X005kj001NnP00G_X00002G_X03000G_X005kj001NnP00G_X005kj001NnP<0
000BG_X005kjG_X005kJ001NfP00G]X005kJ001NfP00G]X005kJ0`0000ANfP00G]X0009JfP04001J
fP00F]X20002F]X01000F]X005[J0P000U[J0P0000=JfP00F]X01@0001EJ^P00E[X005Jj001F^`00
E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000UF^`00E[/005Jk001B^`00D[/00P0000UB^`00
D[/005:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[/00P0000]B^`00D[/005:k001B^`00
D[/004jk00800007C[/004jk001>^`00C[/00`0000]>_000C[`004jl001>_000C[`004jl01H00003
C[`004jl0080000;C]`004kL001>g000C]`004kL001>g00200002e;L001Bg000D]`005;L001Bg000
D]`00P0000MBg000D]`005;L001Bo00;000025Kl001Fo000E_`005Kl0002E_`200003eKl001Jo000
F_`005[l001Jo000F_`005[l001Jo003000015[l001Jo0000U[l00`005[l001Jo000F_`005[l001N
n`00G_/5000015kk001Nn`000Ukk00H005kk001Nn`00G_/20002G_/500003Ukk001Nn`00G_/005kk
001Nn`00G_/005kk0002G_/600004Ukk001Nnekk001Nn`00G_/005kk001Nn`00G_/005kk001Nn`D0
000EF]/005[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/005[K00D0000EF]/005[K001J
fP00F]X005[J001JfP00F]X005[J001JfP00F]X005[J0080009JfP04001JfP00F]X800002UZj001J
^P00F[X005Jj001F^P000UJj0P0000eF^P00E[X005Jk001F^`00E[/005Jk001F^`02000025Jk001F
^`00E[/005Jk0002E[/01`00E[/00000E[/005Jk00`0000=E[/005Jk001F^`00E[/005Jk001F^`00
E[/00P000UJk00X005Jk001F^`00E[/005Jk001F^`80000AE]/005KK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`020002E]/02000E]/005KK001Ff`00E]/:00001eKK001Ff`00E]/005KK0080009F
f`08001Ff`00E]/005KK001Ff`80000GE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`090004Ool00`00Oomoo`0YOol00;]oo`03001oogoo05Yoo`0@001Ff`00E]/005KK
001Ff`00E]/005;L001Bg000D]`200001e;L001Bg000D]`005;L00800009D]`005;L001Bg000D]`0
05;L00800007D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg00200000e;L0000000<0000
0dkL001>g00200001dkL001>g000C]`004kL00800007C[`004jl001>_000C[`00P0000M>_000C[`0
04jl001>_00200001djl001>_000C]d004kM00<00007C]d004kM001>g@00C]d00P0000M>g@00C]d0
04kM001>g@0300002DkM001>g@00C]d004kM001Bo@020002D_d02000D_d005;m001Bo@00D_d20000
2UKm001Fo5Kl001Fo000E_`005Kl0P0000=K70000000100000AK7000Fa`0009K7080009O7006001O
7000Ga`005lL100000IO6`00Ga/005lK0002Ga/01P00Ga/005lK001S6`<0009S6`03001S6`00009S
6`09001S6`00Ha/006<K001S6`00009S6`03001S6`00009S6`04001S6`00Ha/300003V;k001Rnf;k
001Rn`00H_/006;k001Rn`00H_/200001V;k001Rnf;k001NnP80009NnP06001NnP00G_X005kj0`00
0Ukj00`005kj001NnP00G_X005kj001NnP00G_X4000025kj001NnP00G_X005kj0002G]X01`00G]X0
0000G]X005kJ00@00003G]X00000009NfP0B001NfP00F]X005[J001JfP00F]X005[J001JfP00F]X0
05[J1`0000=JfP00F]X00P000UZj00P005Jj001F^P00E[/005Jk0P0000mF^`00E[/005Jk001F^`00
E[/005Jk001F^`00E[/00P0000UB^`00D[/005:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00
D[/00P0000UB^`00D[/005:k001B^`00D[/00P0000EB^`00D[/004jk00800009C[/004jk001>^`00
C[/004jl0080000GC[`004jl001>_000C[`004jl001>_000C[`004jl001>_000C[`004jl001>_002
00001Djl001>_000C[`0:00000MBo000D_`005Kl001Fo002000045Kl001Fo5Kl001Fo000E_`005Kl
001Fo000E_`005Kl0P0000EJo000F_`005[l00H00003F_`00000009Jo00;001Jo000F_`005[l001J
o000F_`00002F_`4000015[k001Nn`000Ukk00`005kk001Nn`00G_/005kk001Nn`00G_/3000015kk
001Nn`000Ukk00P005kk000005kk001Nn`000Ukk00<005kk00000P00011Nn`00G_/005kk001Nn`00
G_/005kk001Nn`00G_/0009Nn`800008G_/00000001Jn`00F_/0009Jf`0:001Jf`00001Jf`00F]/0
05[K0002F]/01000F]/005[K100000IJf`00F]/005[K0002F]/01000F]X005[J0P0000QJfP00F]X0
05[J001JfP000U[J00<005[J00001`0000EJfP00F]X005[J0080000<F[X005ZjF[X005Zj001F^P00
E[X005Jj0P0001MF^P00E[X005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk00X0
0009E[/005Jk001F^`00E[/005Jk00800006E[/005Jk001F^`000UJk00@005Jk001F^`80000AE[/0
05Jk001F^`00E[/005Jk001F^`00E[/005Jk001Ff`02000015KK001Ff`000UKK00H005KK001Ff`00
E]/200000eKK0000000900002EKK000005KK001Ff`00E]/00002E]/05`00E]/00000E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00P000UKK00H005KK001Ff`00E]/:000025KK001F
f`00E]/005KK0005Ool00`00Oomoo`0XOol00;]oo`03001oogoo05]oo`04001Ff`00E]/200002eKK
001Ff`00D]`005;L001Bg000D]`00P0000UBg000D]`005;L001Bg000D]`0700000UBg000D]`005;L
001Bg000D]`00P0000=Bg000D]`06`0000E>_000C[`004jl00800007C[`004kM001>g@00C]d00P00
00M>g@00C]d004kM001>g@0200001dkM001>g@00C]d004kM00<00009C]d004kM001>g@00C]d005;m
0080009Bo@08001Bo@00D_d005;m001Bo@800009E_d005Kl001Fo000E_`005Kl00<00006Fa`005/L
001K70000U/L00<005/L00000U/L0P0000=O7000Ga`0100000AO7000Ga/0009O6`08001O6`00Ga/0
05lK001O6`@00006Ga/005lK001S6`000V<K00@006<K001S6`D0009S6`03001S6`00009S6`04001S
6`00Ha/300001f;k001Rnf;k001Rn`00009Rn`80009Rn`<0000>H_/006;kH_/006;k001NnP00G_X0
05kj001NnP@00008G_X005kj001NnP00G_X0009NnP04001NnP00G_X3000015kj001NnP000Ukj0P00
00YNnP00G_YNnP00G]X005kJ001NfP<0000<G]X005kJ001NfP00G]X005kJ001NfP000U[J0P0000UJ
fP00F]X005[J001JfP00F]X00`0001]JfP00F]X005[J001JfP00F]X005[J001J^P00E[X005Jj001F
^`00E[/005Jk001F^`00E[/00P0000UF^`00E[/005Jk001F^`00E[/00P0000AB^`00D[]B^`800009
D[/005:k001B^`00D[/005:k00800009D[/005:k001B^`00D[/005:k00800005D[/005:k001B^`02
00002E:k001>^`00C[/004jk001>^`0200000djk001>_00200002djl001>_000C[`004jl001>_000
C[`00P0000]>_000C[`004jl001>_000C[`004jl00800003C[`004jl00800005C[`004jl001>g002
00002dkL001>g000C]`004kL001>g000D]`00P0000]Bg000D]`005;L001Bg000D]`005;L00800006
D]`005;L001Bo0000U;l00H005;l001Fo000E_`200004EKl001Fo000E_`005Kl001Fo000E_`005Kl
001Fo000F_`01@0000IJo000F_`005[l0002F_`20002F_`2000015[l001Jo0000U[l1@0000=Jo000
00000U[k00`005kk001Nn`00G_/005kk001Nn`00G_/5000035kk001Nnekk001Nn`00G_/005kk001N
n`80009Nn`D00006G_/005kkG_/005kk0P0000INn`00G_/005kk0002G_/00`00G_/00005000035kk
001Jne[k001Jn`00F]/005[K001Jf`80009Jf`03001Jf`0000H00005F]/00000F]/00002F]/02000
F]/005[K001JfP00F]X2000025[J001JfU[J001JfP00F]X600002U[J001JfP00F]X005[J001JfP00
0U[J0P0000]J^P00F[X005Zj001F^P00E[X005Jj00800004E[X005Jj0002E[/02000E[/005Jk001F
^`00E[/:00000eJk001F^`0200002UJk001F^`00E[/005Jk001F^`000UJk014005Jk000005Jk001F
^`00E[/005Jk001F^`00E[/005Jk0080000EE[/005Jk001F^`00E[/005Jk001F^`00E[/005KK001F
f`00E]/005KK00`0000GE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`02000035KK001Ff`00E]/005KK001Ff`00E]/0009Ff`800005E]/005KK001Ff`0900002EKK0000
05KK001Ff`00E]/00002E]/01P00E]/00000E]/000Eoo`03001oogoo02Qoo`00_7oo00<007ooOol0
FWoo00X005KK001Ff`00E]/005KK001Ffa<00007D]`005;L001Bg000D]`00P0000MBg000D]`005;L
001Bg00200001e;L001Bg000D]`005;L0080009Bg008001Bg000D]`005;L001Bg0800006D]`00000
D]`005;L0P0000M>g000C]`004kL001>g00200001dkL001>g000C]`004kL00800003C]`004kL0100
0009C]d004kM001>g@00C]d004kM00800007C]d004kM001>g@00C]d00P0000U>g@00C]d004kM001>
g@00D_d00P0000UBo@00D_d005;m001Bo@00D_d00P0000=Fo@0000001P0000=Fo00000000U/L00D0
05/L001K7000009K7004001K7000Fa`200001elL000005lL001O7000009O7003001O6`00009O6`80
0003Ga/005lK00800004Ga/005lK0002Ga/02000Ga/006<K001S6`00Ha/200001V<K001S6`00Ha/0
009S6`06001S6`00Ha/006<K0P0000=S6`0000000V;k00<006;k00000V;k00@006;k001Rn`<0000>
H_/006;kH_/006;k001Rn`00G_X005kj001NnP800004G_X005kj0002G_X20002G_X01P00G_X005kj
001NnP<0000BG_X005kjG_X005kj001NnP00G_X005kj001NnP00G]X005kJ0`0000QNfP00G]YNfP00
G]X005kJ0P000UkJ00P005kJ001JfP00F]X005[J1`0000=JfP0000000U[J00P005[J001JfP00F]X0
05[J0P000UZj00@005Jj001F^P80000=E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000MF^`00
E[/005Jk001B^`0J00002e:k001B^`00D[/005:k001B^`00C[/00P0000M>^`00C[/004jk001>^`02
00001djl001>_000C[`004jl00800009C[`004jl001>_000C[`004jl00800005C[`004jl001>_002
00002djl001>_000C[`004jl001>_000C]`00P0000]>g000C]`004kL001>g000C]`005;L0080000;
D]`005;L001Bg000D]`005;L001Bg00200004E;L001Bg000D_`005;l001Bo000E_`005Kl001Fo000
E_`00P0000MFo000E_`005Kl001Fo007000015[l001Jo0000U[l00X005[l001Jo000F_`005[l001J
o080009Jo0D00004F_`005[l0002F_`20002F_/200001Ekk001Nn`00G_/0100001=Nn`00G_/005kk
001Nn`00G_/005kk001Nn`00G_/005kk001Nn`03000015kk001Nn`000Ukk00H005kk001Nn`00G_/2
0002G_/00`00G_/0000400004ekk001Nn`00G_/005kk001Jn`00F_/005[K001Jf`00F]/005[K00D0
0006F]/005[K001Jf`000U[K0P0000mJf`00F]/005[K001Jf`00F]X005[J001JfP00F]X01`0000=J
fP00F]X00P0000AJfP00F]X0009JfP06001JfP00F]X005[J0P0000YJ^P00F[X005Zj001F^P00E[X0
009F^P800003E[X005Jj00`0000;E[/005Jk001F^`00E[/005Jk001F^`020002E[/03000E[/005Jk
001F^`00E[/005Jk001F^`80000=E[/005Jk001F^`00E[/005Jk001F^`00E[/00P000UJk00X005Jk
001F^`00E[/005Jk001F^`X00007E]/005KK001Ff`00E]/00P0000YFf`00E]]Ff`00E]/005KK001F
f`80000AE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`020002E]/01P00E]/005KK001F
f`X0000EE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0080009Ff`03001o
ogoo009oo`03001oogoo02Qoo`00_Goo00<007ooOol0FWoo2P0000MFf`00E]`005KL001Bg0020000
4E;L001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg0020000
1e;L001Bg000D]`005;L0080000;D]`005;L001Bg000D]`005;L001Bg00200001E;L001Bg000D]`0
0P0000M>g000C]`004kL001>g00200001dkL001>g000C]`004kL00800008C]`00000C]`004kL001>
g0800007C]`004kL001>g@00C]d05@0000U>g@00C]d004kM001>g@00D_d03P0000QFo000E_`005Kl
001Fo0000UKl0P000U/L00X005/L001K7000Fa`005/L001K70<00007Ga`005lLGa`005lL00000UlL
00H005lK001O6`00Ga/300001elK001O6elK001O6`00009O6`800003Ha/006<K0080000>Ga/006<K
Ha/006<K001S6`00Ha/006<K001S6`800004Ha/006<KHa/20002H_/01P00H_/006;k001Rn`<00007
H_/006;kH_/006;k00000V;k00@006;k001NnP<0000@G_X005kjG_X005kj001NnP00G_X005kj001N
nP00G_X3000045kj001NnUkj001NnP00G_X005kj001NnP00G_X005kj100000=NfP0000000UkJ0100
05kJ001NfP00G]X005kJ001NfP00G]X005[J001JfP<0000OF]X005[J001JfP00F]X005[J001JfP00
F]X005[J001JfP00F]X005[J001J^P00E[X005Jj001F^`00E[/00P0000=F^`00E[/0400000MF^`00
D[/005:k001B^`0200002E:k001B^`00D[/005:k001B^`0200001E:k001B^`00D[/0600000]>_000
C[`004jl001>_000C[`004jl00800003C[`004jl0080000;C[`004jl001>_000C[`004jl001>_002
00002djl001>_000C]`004kL001>g000C]`00P0000]>g000C]`005;L001Bg000D]`005;L0080000;
D]`005;L001Bg000D]`005;L001Bg00200003E;l001Bo000E_`005Kl001Fo000E_`005Kl00L0000G
E_`005Kl001Fo000F_`005[l001Jo000F_`005[l001Jo000F_`005[l001Jo005000015[l001Jo000
0U[l00P005[l001Jo000F_/005[k0P0000=Nn`0000000P0000ANn`00G_/0009Nn`0:001Nn`00001N
n`00G_/005kk0002G_/6000045kk001Nnekk001Nn`00G_/005kk001Nn`00G_/005kk1@0000ANn`00
G_/0009Nn`0:001Nn`00001Nn`00F_/005[k0002F]/00`00F]/0000300001U[K001Jf`00F]/0009J
f`04001Jf`00F]/200001U[K001Jf`00F]/0009Jf`04001JfP00F]X400005e[J001JfP00F]X005[J
001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X00P0000YJ^P00F[YJ^P00F[X005Jj001F^PP0
0009E[/005Jk001F^`00E[/005Jk00800004E[/005Jk0002E[/01P00E[/005Jk001F^`80000=E[/0
05Jk001F^`00E[/005Jk001F^`00E[/00P0000IF^`00E[/005Jk0002E[/01000E[/005Jk0P0000=F
^`000000300000YFf`00E]/005KK001Ff`00E]/0009Ff`80000=E]/005KK001Ff`00E]/005KK001F
f`00E]/00P000UKK0P0000IFf`00E]/005KK0002E]/01`00E]/00000E]/005KK00T00003E]/00000
00800004E]/005KK0002E]/06000E]/00000E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`00E]/000Aoo`03001oogoo02Qoo`00_Goo00<007ooOol0FWoo018005KK001Ff`00E]/005KK001F
f`00E]/005KL001Fg000D]`200002E;L001Bg000D]`005;L001Bg00200001e;L001Bg000D]`005;L
00800006D]`005;LD]`005;L0P0000MBg000D]`005;L001Bg00200002E;L001Bg000D]`005;L001B
g00200001e;L001Bg000D]`005;L00800007C]`004kL001>g000C]`00P0000=>g000C]`00P0000=>
g000C]`00P0000M>g000C]`004kL001>g00200004DkL001>g000C]d004kM001>g@00C]d004kM001>
g@00C]d00P0000M>g@00C]d004kM001>g@0:000035;m000005;m001Bo@00D_d005;m001Fo@80009F
o007001Fo000E_`005Kl00000UKl0P0000EK7000Fa`005/L00H00003Fa`00000009O700;001O75lL
001O7000Ga`005lK001O6`0300001ElK001O6elK00000UlK00H005lK001O6`00Ga/300001elK001O
6elK001S6`00009S6`800003Ha/000000080000>Ha/006<KHa/006<K001S6`00H_/006;k001Rn`80
0006H_/006;k001Rn`000V;k00H006;k001Rn`00H_/300003Ukk001NnUkj001NnP00G_X005kj001N
nP00G_X4000025kj001NnP00G_X005kj0002G_X01000G_X005kj0P0000MNnP00001NfP00G]X00002
G]X200001UkJ001NfUkJ001NfP800005G]X005kJ001NfP0500002U[J001JfU[J001JfP00F]X005[J
0P000U[J00@005[J001JfP80000;F]X005[J001J^P00E[X005Jj001F^`07000035Jk000005Jk001F
^`00E[/005Jk001F^`800006E[/005JkE[/005:k0P0000UB^`00D[/005:k001B^`00D[/00P0000MB
^`00D[/005:k001B^`0200001E:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[/00P0000E>
^`00C[/004jl01D00003C[`004jl00800003C[`004jl0080000;C[`004jl001>g000C]`004kL001>
g00200002dkL001>g000D]`005;L001Bg000D]`00P0000]Bg000D]`005;L001Bg000D]`005;L0080
009Bo0`00006E_`005Kl001Fo0000UKl00P005Kl001Fo000F_`005[l0P0000MJo000F_`005[l001J
o00400001E[l000005[l00000U[l00`005[l001Jo000F_`005[l001Jn`00F_/3000015[k001Jn`00
0Ukk00P005kk001Nn`00G_/005kk0P000Ukk1@0000iNn`00G_/005kk001Nn`00G_/005kk001Nn`00
0Ukk00<005kk00000`0000ANn`00G_/0009Nn`08001Nn`00G_/005kk001Nn`80009Jn`03001Jn`00
00@00005F]/00000F]/00002F]/02000F]/005[K001Jf`00F]/200001U[K001Jfe[K001Jf`P00006
F]X005[J001JfP000U[J00@005[J001JfP80000:F]X005[J001JfP00F]X005[J0002F]X200000eZj
0000000700003EJj000005Jj001F^P00E[/005Jk001F^`00009F^`0?001F^`00001F^`00E[/005Jk
001F^`00E[/005Jk0080000:E[/005Jk001F^`00E[/005Jk0002E[/02@00E[/00000E[/005Jk001F
^`0:00002eJk001F^`00E[/005Jk001F^`00E]/00P000UKK00X005KK001Ff`00E]/005KK001Ff`80
000IE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/02P0001EF
f`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00P0000AFf`00E]]Ff`800006
E]/005KK001Ff`000UKK00<005KK00000`0017oo00<007ooOol0:7oo002nOol00`00Oomoo`1JOol0
2P00E]/005KK001Ff`00E]/005KK0P0000MFg000E]`005;L001Bg0020002D]`01000D]`005;L0P00
00MBg000D]`005;L001Bg00200002E;L001Bg000D]`005;L001Bg00200001e;L001Bg000D]`005;L
00800009D]`005;L001Bg000D]`005;L00800007D]`005;L001Bg000C]`00P0000M>g000C]`004kL
001>g00200001DkL001>g000C]`00P0000U>g000C]`004kL001>g000C]`00P0000=>g000C]`00P00
00a>g@00001>g@00C]d004kM001>g@00C]d200001dkM001>g@00C]d004kM00<00006C]d004kM001B
g@000U;m0P0000UBo@00D_d005;m001Bo@00E_d00P000UKl00`005Kl001Fo000E_`005Kl001K7000
Fa`300001U/L001K7000Fa`0009K7080009O7006001O7000Ga`005lL100000IO6`00Ga/005lK0002
Ga/01P00Ga/005lK001O6`<00005Ga/005lKGa/00002Ga/02`00Ha/006<K001S6`00Ga/006<K0000
0V<K00P006<K001S6`00Ha/006;k100000ANn`00H_]Rn`80009Rn`06001Rn`00H_/006;k0`0000MN
n`00G_]Nn`00G_X00002G_X20002G_X3000015kj001NnP000Ukj0P0000YNnP00G_YNnP00G_X005kj
001NnP<00008G_X005kJG]X005kJ001NfP80009NfP06001NfP00G]X005kJ1@0001]JfP00F]X005[J
001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X02P0001=F^`00E[/005Jk
001F^`00E[/005Jk001F^`00E[/005Jk001F^`0200002EJk001F^`00D[/005:k001B^`0200002E:k
001B^`00D[/005:k001B^`0200002e:k001B^`00D[/005:k001B^`00D[/00P0000UB^`00D[/005:k
001B^`00D[/00P0000=>^`00C[/00P0000E>_000C[`004jl00800009C[`004jl001>_000C[`004jl
00800003C[`0000003<0000KE_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl
001Fo000F_`005[l00800003F_`0000000@00004F_`005[l0002F_`200002e[l001Jo000F_`005[l
001Jo000F_`0100000=Jn`0000000U[k00h005[k001Nn`00G_/005kk001Nn`00G_/005kk0`0000AN
n`00G_/0009Nn`04001Nn`000002G_/2000015kk001Nnekk1@0000=Nn`0000000Ukk00h005kk001N
n`00G_/005kk001Nn`00G_/005kk1@0000AJf`00F]/0009Jf`80000:F]/005[K001Jf`00F]/005[K
0002F]/200000e[K0000000300004e[K001Jf`00F]/005[J001JfP00F]X005[J001JfP00F]X005[J
00800004F]X005[J0002F]X01000F]X005[J1P0000UJ^P00F[X005Jj001F^P00E[X00P0000iF^P00
E[YF^P00E[/005Jk001F^`00E[/005Jk0P0000]F^`00E[/005Jk001F^`00E[/005Jk0080009F^`08
001F^`00E[/005Jk001F^``00005E[/005Jk001F^`0200001UJk001F^`00E[/0009F^`04001F^`00
E[/200004EKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00P0000YFf`00E]]Ff`00E]/0
05KK001Ff``00003E]/005KK00800004E]/005KK0002E]/01000E]/005KK0P0001UFf`00E]/005KK
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`0800000eKK001oo`03Ool00`00
Oomoo`0XOol00;ioo`03001oogoo05]oo`800006E]/005KKE]/005KK0P0000MFf`00E]`005KL001B
g00200002E;L001Bg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800003D]`005;L0300
0003C]`004kL00800007C]`004kL001>g000C]`00P0000M>g000C]`004kM001>g@0200002DkM001>
g@00C]d004kM001>g@0200001dkM001>g@00C]d004kM00<00006C]d004kM001Bg@000U;m0P0000UB
o@00D_d005;m001Bo@00E_d00P0000MFo000E_`005Kl001Fo00700002E/L001K75/L001K7000Fa`0
0002Fa`200000elL001O7004000015lL001O70000UlK00P005lK001O6`00Ga/005lK100000IO6`00
Ga/005lK0002Ga/01P00Ga/006<K001S6`<0009O6`03001S6`00009S6`04001S6`00Ha/3000015kk
001Nn`000Ukk00P006;k001Rn`00H_/006;k100000QNn`00G_/005kk001Nn`000Ukj00@005kj001N
nP<0000@G_X005kjG_X005kj001NnP00G_X005kj001NnP00G_X500004Ukj001NnUkj001NfP00G]X0
05kJ001NfP00G]X005kJ001NfP<00006G]X005[J001JfP000U[J0P0000IJfP00F]YJfP00F]X20000
2E[J001JfP00F]X005[J001JfP0500004E[J001J^P00E[X005Jk001F^`00E[/005Jk001F^`00E[/0
0P0000UF^`00E[/005Jk001F^`00E[/00P0000IF^`00E[]F^`00D[/200002E:k001B^`00D[/005:k
001B^`0200001e:k001B^`00D[/005:k00800005D[/005:k001B^`0200002E:k001B^`00D[/005:k
001B^`0200002djk001>^`00C[`004jl001>_000C[`00P0000U>_000C[`004jl001>_000C[`00`00
00U>_000C[`004jl001>_000C[`00P0000]>g000C]`004kL001>g000C]`005;L0080000;D]`005;L
001Bg000D]`005;L001Bg00200002e;L001Bg000D]`005;L001Bg000D]`00P00011Bo000E_aFo000
E_`005Kl001Fo000E_`005Kl001Fo0800009E_`005Kl001Fo000E_`005[l00D00006F_`005[l001J
o0000U[l00P005[l001Jo000F_`005[l0P0000=Jo000F_`0100000AJo000F_`0009Jn`800008F_/0
05[k001Nn`00G_/0009Nn`H0000@G_/005kkG_/005kk001Nn`00G_/005kk001Nn`00G_/5000015kk
001Nn`000Ukk0P0000QNn`00G_/005kk001Nn`000Ukk00<005kk00000`0000AJf`00F]/0009Jf`04
001Jf`00F]/200001U[K001Jf`00F]/0009Jf`03001Jf`0000D00006F]/005[K001Jf`000U[K01D0
05[K000005[J001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X01`0000]JfP00001J^P00F[X0
05Zj001F^P00009F^P0A001F^P00001F^P00E[X005Jk001F^`00E[/005Jk001F^`02000015Jk001F
^`000UJk00H005Jk001F^`00E[/<00000eJk001F^`0200002UJk001F^`00E[/005Jk001F^`000UJk
0P0000]F^`00E[/005Jk001F^`00E[/005Jk0080000<E]/005KK001Ff`00E]/005KK001Ff`000UKK
0P0000EFf`00E]/005KK00X0000IE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/00P000UKK0P0000IFf`00E]/005KK0002E]/01@00E]/00000E]/02@0000EFf`00
E]/005KK0080009Ff`05001oogooOol0000ZOol00;moo`03001oogoo05Yoo`0:001Ff`00E]/005KK
001Ff`00E]/200001eKL001Fg000D]`005;L00800003D]`0000001800005D]`005;L001Bg0020000
1e;L001Bg000D]`005;L00800009D]`005;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`0
0P0000M>g000C]`004kL001>g00200000dkL001>g00D00000dkM001>g@0200001dkM001>g@00C]d0
04kM00800009C]d004kM001>g@00C]d004kM00800007C]d004kM001Bg@00D_d00P0000]Bo@00D_d0
05;m001Bo@00E_d005Km00L0000:E_`005Kl001Jo000Fa`005/L0002Fa`02000Fa`005/L001K7000
Ga`3000015lL001O70000UlL00X005lL001O6`00Ga/005lK001O6`800004Ga/005lK0002Ga/02000
Ga/005lK001O6`00Ga/400001UlK001O6`00Ga/0009S6`09001S6`00Ha/006<K001Nn`00009Nn`03
001Nn`00009Nn`800003H_/006;k00800004G_/005kk0002G_/20002G_/01P00G_/005kj001NnP<0
000@G_X005kjG_X005kj001NnP00G_X005kj001NnP00G_X200002Ukj001NnP00G_X005kj001NnP00
0UkJ0P000UkJ0P0000=NfP0000000P0000=NfP0000000UkJ018005[J001JfP00F]X005[J001JfP00
F]X005[J001JfP00F]X700001E[J000005[J00000U[J0P000UJj01<005Jk000005Jk001F^`00E[/0
05Jk001F^`00E[/005Jk001F^`0200002EJk001F^`00E[/005Jk001B^`0200002E:k001B^`00D[/0
05:k001B^`0200002E:k001B^`00D[/005:k001B^`0200002E:k001B^`00D[/005:k001B^`020000
2E:k001B^`00D[/004jk001>^`0200001Djl001>_000C[`00P0000U>_000C[`004jl001>_000C[`0
0P0000]>_000C[`004jl001>_000C[`004jl0080000;C]`004kL001>g000C]`004kL001Bg0020000
2e;L001Bg000D]`005;L001Bg000D]`00P0000]Bg000D]`005;L001Bg000D]`005;L0080000?D_`0
05Kl001Fo000E_`005Kl001Fo000E_`005Kl00800003E_`005Kl00H00003F_`005[l0080009Jo00@
001Jo000F_`005[l001Jo000F_`005[l001Jo000F_`3000015[l001Jo0000U[l00H005[l001Jn`00
F_/2000015[k001Nnekk1@0001=Jn`00G_/005kk001Nn`00G_/005kk001Nn`00G_/005kk001Nn`03
000015kk001Nn`000Ukk00@005kk001Nn`800004G_/005kk0002G_/00`00G_/0000400000e[k0000
0002F]/02P00F]/005[K001Jf`00F]/005[K0P000U[K00<005[K0000100000MJf`00001Jf`00F]/0
0002F]/02000F]/005[K001Jf`00F]X2000015[J001JfP000U[J00@005[J001JfPH00007F]X005[J
001JfP00F]X00P000UZj00X005Zj001J^P00E[X005Jj001F^P80000:E[X005Jj001F^`00E[/005Jk
0002E[/01`00E[/00000E[/005Jk00X0000KE[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F
^`00E[/005Jk001F^`00E[/005Jk0080000=E[/005Jk001F^`00E[/005Jk001F^`00E]/00P000UKK
00P005KK001Ff`00E]/005KK2P0000MFf`00E]/005KK001Ff`020002E]/02000E]/005KK001Ff`00
E]/200005eKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/02P00019F
f`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0003Ool00`00Oomoo`0XOol00;moo`03001o
ogoo05]oo`800003E]/005KK01000007D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg002
000025;L001Bg5;L001Bg000D]`200001e;L001Bg000D]`005;L00800009D]`005;L001Bg000D]`0
05;L00800007D]`005;L001Bg000D]`00P0000M>g000C]`004kL001>g00200001TkL000004kL001>
g0800007C]`004kL001>g000C]`00P0000E>g000C]`004kL02h00006E_`005Kl001Fo0000UKl00h0
05Kl001Jo000Fa`005/L001K7000Fa`005/L1@0000MO7000GaaO7000Ga`00002Ga`01@00Ga`00000
Ga/0100000iO6`00Ga]O6`00Ga/005lK001O6`00Ga/005lK0P0000AO6`00Ga/0009O6`08001O6`00
Ga/006<K001S6`D0009Nn`03001Nn`00009Nn`04001Nn`00H_/3000045kk001Nnekk001Nn`00G_/0
05kk001Nn`00G_/005kj0P0000=Nn`0000000Ukj00<005kj00000Ukj00@005kj001NnPD00004G_X0
05kj0002G_X2000025kj001NnUkj001NfP00G]X500005ekJ001NfP00G]X005kJ001NfP00F]X005[J
001JfP00F]X005[J001JfP00F]X01@0001UJfP00F]X005[J001JfP00F]X005[J001JfP00F[X005Jj
001F^`00E[/005Jk001F^`0200003EJk001F^`00E[/005Jk001F^`00E[/005Jk00800009E[/005Jk
001B^`00D[/005:k00800009D[/005:k001B^`00D[/005:k0080000;D[/005:k001B^`00D[/005:k
001B^`0200002E:k001B^`00D[/005:k001B^`0200000djk001>^`0200002Djl001>_000C[`004jl
001>_00200002djl001>_000C[`004jl001>_000C[`00P0000M>_000C[`004jl001>_00200002DkL
001>g000C]`004kL001Bg00200003e;L001Bg000D]`005;L001Bg000D]`005;L001Bg00200002e;L
001Bg000D]`005;L001Bo000D_`00P0000UFo000E_`005Kl001Fo000E_`01`0000IFo000E_`005Kl
0002F_`01000F_`000000U[l0P0000IJo000F_`005[l0002F_`6000045[l001Jo5[l001Jo000F_`0
05[l001Jn`00F_/005[k1@0000AJn`00F_/0009Jn`0:001Nn`00001Nn`00G_/005kk0002G_/50000
0ekk00000002G_/03P00G_/005kk001Nn`00G_/005kk001Nn`00G_/5000015[k001Jn`000U[k0P00
00QJf`00F]/005[K001Jf`000U[K0P0000=Jf`0000000`0001]Jf`00F]/005[K001Jf`00F]/005[K
001Jf`00F]/005[K001Jf`00F]X005[J001JfP00F]X0200000QJfP00F]X005[J001JfP000U[J00l0
05[J000005Zj001J^P00F[X005Jj001F^P00E[X00P0000YF^P00E[YF^P00E[/005Jk001F^`X00007
E[/005Jk001F^`00E[/00P0000AF^`00E[/0009F^`06001F^`00E[/005Jk0P0000eF^`00E[/005Jk
001F^`00E[/005Jk001F^`0200001UJk001F^`00E[/0009F^`04001F^`00E[/200000eKK00000009
00002eKK000005KK001Ff`00E]/005KK00000UKK0P00015Ff`00E]/005KK001Ff`00E]/005KK001F
f`00E]/005KK00800004E]/005KK0002E]/01000E]/005KK2P0000EFf`00E]/005KK0080000:E]/0
05KKE]/005KK001Ff`00E]/2000025KK001Ff`00E]/005KK0003Ool00`00Oomoo`0XOol00<1oo`03
001oogoo05]oo`@00005E]/005KK001Ff`0200001eKK001Fg000E]`005KL0080009Bg006001Bg000
D]`005;L0P0000MBg000D]`005;L001Bg00200002E;L001Bg000D]`005;L001Bg00200001e;L001B
g000D]`005;L00800007D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg00200002DkL001>
g000C]`004kL001>g00200001DkL001>g000C]`00P0000M>g000C]`004kL001>g00200000dkL001>
g00200000dkM001>g@0200001dkM001>g@00C]d004kM00800009C]d004kM001>g@00C]d004kM0080
0007C]d005;M001Bo@00D_d00P00019Bo@00D_d005;m001Bo@00E_d005Kl001Fo000E_`005Kl0002
E_`01000E_`005[l0P0000=K7000Fa`0100000QK7000Fa`005/L001O70000UlL00d005lL001O7000
Ga`005lK001O6`00Ga/00002Ga/01@00Ga]O6`00Ga/00P0000=O6`0000000P0000iO6`00Ga]O6`00
Ga/005lK001O6`00Ga/006<K0P0000QO6`00Ga/005kk001Nn`000Ukk00@005kk001Nn`<00007G_/0
05kkG_/005kk00000Ukk0P0000=Nn`00G_/0100000ANn`00G_]Nn`80000?G_X005kjG_X005kj001N
nP00G_X005kj001NnP00009NnP0C001NnP00G_X005kj001NnP00G_X005kJ001NfP00G]X005kJ0000
0UkJ00@005kJ001NfP80009NfP04001JfP000002F]X200000e[J0000000200001E[J000005[J0000
0U[J00H005[J001JfP00F]X2000015[J001JfU[J0P0000eF^P00E[/005Jk001F^`00E[/005Jk001F
^`0200001EJk001F^`00E[/0?P0000a>_000001>_000C[`004jl001>_000C[`200000djl001>_002
00002djl001>_000C[`004jl001>g000C]`00P0000U>g000C]`005;L001Bg000D]`00P0000]Bg000
D]`005;L001Bg000D]`005;L0080000=D]`005;L001Bg000D]`005;l001Bo000E_`02@0000=Fo000
E_`00P00011Fo000E_aFo000E_`005Kl001Jo000F_`005[l001Jo0800003F_`005[l00H0000@F_`0
05[l001Jo000F_`005[l001Jo000F_`005[l0002F_/4000015[k001Jn`000U[k00P005[k001Jn`00
G_/005kk0P000Ukk1@0000AJn`00F_/0009Nn`800008G_/005kk001Nn`00G_/0009Nn`800008G_/0
0000001Jn`00F_/0009Jn`04001Jn`00F_/2000015[K001Jf`000U[K00<005[K00001@0000IJf`00
F]/005[K0002F]/03000F]/00000F]/005[K001Jf`00F]/0009Jf`05001Jf`00001JfP0500004e[J
001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X005[J00800008F[X005Zj001J^P00E[X0009F
^P05001F^P00001F^P0900000eJk001F^`02000025Jk001F^`00E[/005Jk0002E[/04@00E[/00000
E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000YF^`00E[/005Jk001F^`00E[/0009F^`800005
E[/005Jk001F^`0:00005eKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/00P0001EFf`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/02P0000QFf`00
E]/005KK001Ff`000UKK0P0001=Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`02
0002E]/01000Oomoo`00:Woo0031Ool00`00Oomoo`1JOol2000025KK001FfeKK001Ff`00E]/20000
1eKK001Fg000E]`005KL00800009D]`005;L001Bg000D]`005;L00800006D]`005;LD]`005;L0P00
00MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800009D]`005;L001Bg000D]`005;L
00800007D]`005;L001Bg000D]`00P0000M>g000C]`004kL001>g00200001dkL001>g000C]`004kL
00800007C]`004kL001>g000C]`00`0000M>g000C]`004kM001>g@0200001dkM001>g@00C]d004kM
00800009C]d004kM001>g@00C]d004kM00800007C]d005;M001Bo@00D_d00P0001MBo@00D_d005;m
001Bo@00E_d005Kl001Fo000E_`005Kl001Fo000E_`005[l00D00004Fa`005/L0002Fa`03000Fa`0
05/L001O7000Ga`005lL001O70D0009O6`03001O6`00009O6`0;001O6`00Ga/005lK001O6`00Ga/0
0002Ga/00`00Ga/00002Ga/200000elK0000000200003UlK001O6elK001O6`00G_/005kk001Nn`00
G_/200000ekk00000002G_/00`00G_/00002G_/01000G_/005kk0`0000ANn`00G_/0009Nn`0:001N
n`00G_X005kj001NnP00G_X50002G_X03P00G_X005kj001NnP00G_X005kj001NnP00G_X50002G]X0
4000G]X005kJ001NfP00G]X005kJ001NfP00F]X005[J1@0001MJfP00F]X005[J001JfP00F]X005[J
001JfP00F]X005[J001JfP00F]X005[J0080009F^P07001F^`00001F^`00E[/02`0000aF^`00001F
^`00E[/005Jk001F^`00E[/200002E:k001B^`00D[/005:k001B^`0200002E:k001B^`00D[/005:k
001B^`0200002E:k001B^`00D[/005:k001B^`0200002E:k001B^`00D[/005:k001B^`0200000e:l
001B_00N00002DkL001>g000C]`004kL001Bg00200002E;L001Bg000D]`005;L001Bg00E000025Kl
001Fo000E_`005Kl0002E_`04`00E_`00000E_`005Kl001Fo000E_`005[l001Jo000F_`005[l00D0
0006F_`005[l001Jo0000U[l00H005[l001Jo000F_`2000015[l001Jo5[l1@0000=Jn`0000000U[k
00h005[k001Jn`00F_/005[k001Nn`00G_/005kk0`0000AJn`00F_/0009Jn`06001Jn`00G_/005kk
0P0000INn`00G_]Nn`00G_/6000035[k001Jne[k001Jn`00F_/005[k001Jn`80009Jf`03001Jf`00
00@00003F]/005[K0080009Jf`0:001Jf`00F]/005[K001Jf`00F]/200001U[K001Jfe[K001Jf`P0
0006F]/005[J001JfP000U[J00l005[J000005[J001JfP00F]X005[J001JfP00F]X00P000UZj00H0
05Zj001J^P00E[X800002eJk001F^`00E[/005Jk001F^`00E[/00P000UJk00X005Jk001F^`00E[/0
05Jk001F^`80000IE[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00
E[/02P0000EFf`00E]/005KK00800004E]/005KK0002E]/01P00E]/005KK001Ff`80000?E]/005KK
001Ff`00E]/005KK001Ff`00E]/005KK0080009Ff`08001Ff`00E]/005KK001Ff`P00007E]/005KK
001Ff`00E]/00P000UKK00P005KK001Ff`00E]/005KK0P0001=Ff`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`050002Ool00`00Oomoo`0XOol00<5oo`03001oogoo05]oo`800009E]/0
05KK001Ff`00E]/005KK00800006E]`005KLE]`005KL0P0000MBg000D]`005;L001Bg00200002E;L
001Bg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P00
00MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800009C]`004kL001>g000C]`004kL
00800007C]`004kL001>g000C]`00P0000E>g000C]`004kL00800009C]`004kL001>g000C]d004kM
00800007C]d004kM001>g@00C]d00P0000U>g@00C]d004kM001>g@00C]d00P0000M>g@00D]d005;m
001Bo@0200002e;m001Bo@00D_d005;m001Fo@00E_`00P0000=Fo000E_`01P0000EJo000001K7000
009K7003001K7000009K7007001K7000001O7000Ga`0100000IO7000Ga`005lK0002Ga/01P00Ga/0
05lK001O6`D0009O6`03001O6`00009O6`0;001O6`00Ga/005lK001O6`00Ga/00002Ga/02P00Ga/0
05lK001Nn`00G_/005kk0P0000ANn`00G_]Nn`800008G_/005kkG_/005kk001Nn`<0000@G_/005kk
G_/005kk001Nn`00G_/005kj001NnP00G_X200002Ukj001NnP00G_X005kj001NnP000Ukj0P000Ukj
1@0000YNfP00G]X005kJ001NfP00G]X0009NfP800007G]X005kJ001NfP00F]X00`0000AJfP00F]X0
009JfP04001JfP00F]X200001U[J001JfU[J001JfP800009F]X005[J001JfP00F]X005Zj00T0000H
E[/00000E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk0P0000UB^`00D[/0
05:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[/0
0P0000UB^`00D[/005:k001B^`00D[/00P0000QB_000001B_000D[`005:l0P0000]B_000D[`005:l
001>_000C[`005:l00800009D[`005:l001Bg000D]`005;L01D00005D]`005;L001Bg00200007E;L
001Bg000D]`005;l001Bo000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`00P00
00EFo000E_`005[l00H00005F_`00000F_`00002F_`03P00F_`005[l001Jo000F_`005[l001Jo000
F_`5000015[l001Jn`000U[k0P0000QJn`00F_/005[k001Jn`000U[k1P00011Jn`00F_]Jn`00F_/0
05[k001Jn`00G_/005kk001Nn`L0000@F_/005[k001Jn`00F_/005[k001Jn`00F_/005[k0002F_/6
00001U[K001Jf`00F]/0009Jf`80000?F]/005[K001Jf`00F]/005[K001Jf`00F]/005[K00D00005
F]/005[K001Jf`020002F]/02P00F]X005[J001JfP00F]X005[J0P0000IJfP00F]X005[J0002F]X0
0`00F]X0000900000eJj001F^P0200001UJj001F^`00E[/0009F^`04001F^`00E[/200003EJk001F
^`00E[/005Jk001F^`00E[/005Jk00800004E[/005Jk0002E[/01P00E[/005Jk001F^`h0000;E[/0
0000E[/005Jk001F^`00E]/00002E]/200003eKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`02
000025KK001Ff`00E]/005KK0002E]/200000eKK001Ff`0<00001UKK001Ff`00E]/0009Ff`0E001F
f`00001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK00800008E]/005KKE]/005KK001F
f`P00004E]/005KK0002Ool00`00Oomoo`0XOol00<9oo`03001oogoo05Yoo`0:001Ff`00E]/005KK
001Ff`00E]/200002EKK001Fg000E]`005KL001Bg00200001e;L001Bg000D]`005;L00800003D]`0
05;L04L00007C]`004kL001>g@00C]d00P0000U>g@00C]d004kM001>g@00C]d00P0000M>g@00C]d0
04kM001>g@0200002DkM001Bg@00D_d005;m001Bo@0200001e;m001Bo@00D_d005Km00L00006E_`0
05Kl001Fo0000U[l0P0000aK7000FaaK7000Fa`005/L001K7000Fa`3000015lL001O70000UlL00X0
05lL001O6`00Ga/005lK001O6`800008Ga/005lK001O6`00Ga/0009O6`06001O6`00Ga/005lK0`00
0UlK00<005lK00000UlK00D005lK000005kk00@0000>G_/005kkG_/005kk001Nn`00G_/005kk001N
n`800003G_/00000009Nn`03001Nn`00009Nn`04001Nn`00G_/500001Ukj001NnUkj001NnP80009N
nP06001NnP00G_X005kj0`0000ANnP00G_X0009NfP04001NfP000002G]X02000G]X005kJ001NfP00
G]X500000e[J00000002F]X05000F]X005[J001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X8
00005EJk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`0200002EJk001F^`00
E[/005Jk001F^`0200002E:k001B^`00D[/005:k001B^`0200002E:k001B^`00D[/005:k001B^`02
00002E:k001B^`00D[/005:k001B^`0200002E:k001B^`00D[/005:k001B^`0200002E:l001B_000
D[`005:l001B_00200002e:l001B_000D[`004jl001>_000D[`00P0000MB_000D[`005;L001Bg002
000035;L000005;L001Bg000D]`005;L001Bg0800006D]`005;L001Bg0000U;L00@005;L001Bg080
000AD]`005;L001Bg000D_`005;l001Fo000E_`005Kl001Fo00200002eKl001Fo000E_`005Kl001F
o000E_`01@0000IFo000F_`005[l0002F_`200003E[l001Jo000F_`005[l001Jo000F_`005[l00D0
0004F_`005[l0002F_`02000F_/005[k001Jn`00F_/20002F_/5000045[k001Jn`00F_/005[k001J
n`00F_/005[k001Jn`000Ukk100000IJn`00F_/005[k0002F_/02P00F_/00000F_/005[k001Jn`00
0U[k00<005[k00000`0000AJf`00F]/0009Jf`06001Jf`00F]/005[K0P0000IJf`00F]/005[K0002
F]/00`00F]/0000500001U[K001Jf`00F]/0009Jf`0G001Jf`00001Jf`00F]X005[J001JfP00F]X0
05[J001JfP00F]X005[J001JfP0600006eZj001J^P00F[X005Jj001F^P00E[X005Jj001F^P00E[/0
05Jk001F^`00E[/005Jk001F^`02000025Jk001F^`00E[/005Jk0002E[/01`00E[/00000E[/005Jk
00X0000IE[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001Ff`00E]/00P00
01UFf`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`0800005EKK
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`02000035KK001Ff`00E]/005KK
001Ff`00E]/0009Ff`800003E]/005KK00T00007E]/00000E]/005KK00000UKK00<005KK00000Woo
00<007ooOol09goo0032Ool00`00Oomoo`1KOol02`00E]/00000E]/005KK001Ff`00E]/00P0000=F
g000E]`04P0000EBg000D]`005;L00800007D]`005;L001Bg000D]`00P0000MBg000D]`005;L001B
g00200001e;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P0000UBg000C]`004kL001>
g000C]`00P0000M>g000C]`004kL001>g00200001dkL001>g000C]`004kL03000003E_`005Kl0080
0009E_`005KlE_`005Kl001Fo000009Jo0800007Fa`005/L001K7000Fa`01@0000MK7000GaaO7000
Ga`00002Ga`01@00Ga`00000Ga/0100000iO6`00Ga]O6`00Ga/005lK001O6`00Ga/005lK100000IO
6`00Ga/005lK0002Ga/02`00Ga/005lK001O6`00G_/005kk00000Ukk00X005kk001Nn`00G_/005kk
001Nn`800004G_/005kkG_/200003ekk001Nnekk001Nn`00G_/005kk001Nn`00G_/00002G_X03000
G_X005kj001NnP00G_X005kj001NnP<0000DG_X005kjG_X005kj001NfP00G]X005kJ001NfP00G]X0
05kJ001NfP<0000<F]X005[J001JfP00F]X005[J001JfP000U[J0P0000UJfP00F]X005[J001JfP00
F]X01@0000EJfP00F]X005[J0080009F^`08001F^`00E[/005Jk001F^`80000?E[/005Jk001F^`00
E[/005Jk001F^`00E[/005Jk00800009E[/005Jk001B^`00D[/005:k00800009D[/005:k001B^`00
D[/005:k00800009D[/005:k001B^`00D[/005:k00800009D[/005:k001B^`00D[/005:k00800009
D[/005:k001B^`00D[`005:l00800003D[`005:l0080000;D[`005:l001B_000C[`004jl001B_002
00002e:l001B_000D]`005;L001Bg000D]`00P0000UBg000D]`005;L001Bg000D]`00P00015Bg000
D]`005;L001Bg000D]`005;L001Bg000D]`005;L0080000;D_`005;l001Fo000E_`005Kl001Fo002
00000eKl001Fo009000015Kl001Fo0000UKl00X005[l001Jo000F_`005[l001Jo0800005F_`005[l
001Jo00400000e[l001Jo0020002F_`03P00F_`005[l001Jn`00F_/005[k001Jn`00F_/3000015[k
001Jn`000U[k00X005[k000005[k001Jn`00F_/0009Jn`D00003F_/00000009Jn`0:001Jn`00F_/0
05[k001Jn`00F_/20002F_/00`00F_/0000400000e[K00000002F]/02P00F]/005[K001Jf`00F]/0
05[K0P000U[K00@005[K001Jf`D00007F]/00000F]/005[K00000U[K00H005[K001Jf`00F]/20000
1U[K001JfP00F]X0009JfP05001JfP00001JfP0700000e[J001JfP02000015Zj001J^P000UZj00H0
05Jj001F^P00E[X200003EJj001F^`00E[/005Jk001F^`00E[/005Jk0080009F^`06001F^`00E[/0
05Jk2P0000MF^`00E[/005Jk001F^`02000015Jk001F^`000UJk00H005Jk001F^`00E[/200003EJk
001F^`00E[/005Jk001Ff`00E]/005KK00800004E]/005KK0002E]/01P00E]/005KK001Ff``00007
E]/00000E]/005KK00000UKK00@005KK001Ff`80000AE]/005KK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`020002E]/300000eKK001Ff`08000055KK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`00E]/005KK0002Ool00`00Oomoo`0WOol00<=oo`03001oogoo05Yoo`03001Ff`0000d00005E]`0
05KL001Fg00200001e;L001Bg000D]`005;L00800008D]`005;LD]`005;L001Bg0800007D]`005;L
001Bg000D]`00P0000MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007D]`005;L
001Bg000D]`00P0000UBg000C]`004kL001>g000C]`00P0000M>g000C]`004kL001>g00200001DkL
001>g000C]`00`0000M>g000C]`004kL001>g00200002DkM001>g@00C]d004kM001>g@0200001dkM
001>g@00C]d004kM00800009D]d005;M001Bo@00D_d005;m00800006D_d005;m001Bo0000UKl00H0
05Kl000005Kl0002E_`01P00E_`005Kl001Jo0800003Fa`0000000@00008Fa`005/L001K7000Fa`0
009O7006001O7000Ga`005lL0`0000AO6`00Ga/0009O6`05001O6elK001O6`0200000elK001O6`02
000015lK001O6`000UlK00P005lK001O6`00Ga/005lK1@000Ukk00<005kk00000Ukk00@005kk001N
n`D0000>G_/005kkG_/005kk001Nn`00G_/005kk001Nn`D0009Nn`0<001Nn`00G_X005kj001NnP00
G_X005kj100000=NnP0000000Ukj00h005kj001NnP00G]X005kJ001NfP00G]X005kJ1@0000QNfP00
F]YJfP00F]X005[J0P000U[J00P005[J001JfP00F]X005[J0P0000=JfP0000000P0000EJfP00001J
fP00009JfP80009JfP80000?E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk0080000?E[/005Jk
001F^`00E[/005Jk001F^`00E[/005Jk00800009D[/005:k001B^`00D[/005:k00800009D[/005:k
001B^`00D[/005:k00800009D[/005:k001B^`00D[/005:k00800009D[/005:k001B^`00D[/005:k
00800003D[`005:l00800009D[`005:l001B_000D[`005:l0080000;C[`004jl001B_000D[`005:l
001B_00200002E;L001Bg000D]`005;L001Bg00200002e;L001Bg000D]`005;L001Bg000D]`00P00
00]Bg000D]`005;L001Bg000D]`005;L00800007D_`005;l001Fo000E_`02@0001]Fo000E_`005Kl
001Fo000E_`005Kl001Fo000E_`005[l001Jo000F_`005[l001Jo000F_`01@0000AJo000F_`0009J
o00<001Jo000001Jo000F_`005[l001Jn`000U[k1P0000aJn`00F_]Jn`00F_/005[k001Jn`00F_/2
0002F_/5000015[k001Jn`000U[k0P0000eJn`00F_/005[k001Jn`00F_/005[k001Jn`05000015[k
001Jn`000U[K0P0000YJf`00F]/005[K001Jf`00F]/0009Jf`P0000CF]/005[K001Jf`00F]/005[K
001Jf`00F]/005[K001Jf`00F]/00P000U[K00@005[J001JfPP00008F]X005[J001JfP00F]X0009J
fP80000;F[X005Zj001J^P00E[X005Jj001F^P0200001UJj001F^`00E[/0009F^`04001F^`00E[/2
00000eJk0000000700000eJk001F^`02000025Jk001F^`00E[/005Jk0002E[/200003eJk001F^`00
E[/005Jk001F^`00E[/005Jk001F^`02000025Jk001F^`00E[/005KK0002E]/200001EKK001Ff`00
E]/02P0001MFf`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0080000:
E]/005KK001Ff`00E]/005KK0002E]/01@00E]/00000E]/02`0000MFf`00001Ff`00E]/00002E]/0
4P00E]/00000E]/005KK001Ff`00E]/005KK001Ff`00E]/0009oo`03001oogoo02Moo`00a7oo00<0
07ooOol0FWoo00/005KK000005KK001Ff`00E]/005KK00800008E]/005KLE]`005KL001Fg0800007
D]`005;L001Bg000D]`00P0000UBg000D]`005;L001Bg000D]`00P0000mBg000D]`005;L001Bg000
D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800009
D]`004kL001>g000C]`004kL00800007C]`004kL001>g000C]`00`0000E>g000C]`004kL00800007
C]`004kL001>g000C]`00P0000U>g@00C]d004kM001>g@00C]d00P0000M>g@00C]d004kM001>g@02
00002E;M001Bg@00D_d005;m001Bo@0200001U;m001Bo@00D_`0009Fo00=001Fo000001Fo000E_`0
05Kl001Fo000F_`00`0000IK7000Fa`005/L0002Fa`03000Fa`005/L001K7000Ga`005lL001O7080
0003Ga`00000009O6`03001O6`00009O6`06001O6`00Ga/005lK0`0000iO6`00Ga]O6`00Ga/005lK
001O6`00Ga/005lK0P0000QO6`00G_/005kk001Nn`000Ukk00/005kk001Nn`00G_/005kk001Nn`00
009Nn`0:001Nn`00G_/005kk001Nn`00G_/200002Ukk001Nn`00G_/005kk001Nn`000Ukj00@005kj
001NnP<00004G_X005kj0002G_X200002Ukj001NnUkj001NnP00G]X005kJ1@0001MNfP00G]X005kJ
001NfP00F]X005[J001JfP00F]X005[J001JfP00F]X005[J00D0000?F]X005[J001JfP00F]X005[J
001JfP00F]X005[J0080009F^`04001F^`00E[/200003EJk001F^`00E[/005Jk001F^`00E[/005Jk
00800005E[/005Jk001F^`0m00002e:l001B_000D[`004jl001>_000D[`00P0000MB_000D[`005;L
001Bg00200001E;L001Bg000D]`00P0000]Bg000D]`005;L001Bg000D]`005;L0080009Bg003001B
g00000l00005E_`005Kl001Fo00200003UKl001Fo5Kl001Fo000E_`005Kl001Fo000E_`200001UKl
001Jo000F_`0009Jo0H00004F_`005[l0002F_`02000F_`005[l001Jo000F_`200000e[l001Jo006
00004e[k001Jn`00F_/005[k001Jn`00F_/005[k001Jn`00F_/005[k00<00004F_/005[k0002F_/0
1000F_/005[k0P0000IJn`00F_/005[k0002F_/6000015[k001Jn`000U[k00@005[k001Jf`800004
F]/005[K0002F]/01000F]/005[K100000IJf`00F]/005[K0002F]/01000F]/005[K0P0000QJf`00
F]/005[K001Jf`000U[K00<005[K00001`0000EJfP00F]X005[J0080000:F]X005[JF]X005[J001J
fP00F]X200004eZj001J^P00F[X005Jj001F^P00E[X005Jj001F^P00E[/005Jk00X0000;E[/005Jk
001F^`00E[/005Jk001F^`020002E[/02000E[/005Jk001F^`00E[/200006EJk001F^`00E[/005Jk
001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005KK00X00007E]/005KK001Ff`00E]/00P00
0UKK00P005KK001Ff`00E]/005KK0P0001MFf`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/005KK00P0000EE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK
0080009Ff`08001Ff`00001Ff`00E]/0009Ff`05001Ff`00Ool0000YOol00<Aoo`03001oogoo05Yo
o`03001FfeKK00800007E]/005KK001Ff`00E]/00P0000UFf`00E]`005KL001Fg000E]`00P0000AB
g000D]`0009Bg0800007D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg00200002E;L001B
g000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P0000M>
g000C]`004kL001>g00200001dkL001>g000C]`004kL00800007C]`004kL001>g000C]`00P0000M>
g000C]`004kL001>g00200002DkM001>g@00C]d004kM001>g@0200001dkM001>g@00C]d004kM0080
0009D]d005;M001Bo@00D_d005;m00800009D_d005;m001Bo000E_`005Kl00800003E_`0000000H0
0003F_`00000009K7005001K7000Fa`00002Fa`01`00Fa`00000Fa`005lL00@00004Ga`005lLGa`2
0002Ga/01P00Ga/005lK001O6`D00005Ga/005lKGa/00002Ga/01@00Ga/00000Ga/0100000iO6`00
Ga]O6`00G_/005kk001Nn`00G_/005kk1@000Ukk00<005kk00000Ukk00@005kk001Nn`D00006G_/0
05kkG_/005kk0P000Ukk00H005kk001NnP00G_X3000025kj001NnUkj001NnP00G_X20002G_X01P00
G_X005kj001NfP<00004G]X005kJ0002G]X01P00G]X00000G]X0009JfP800007F]X005[J001JfP00
F]X01@0000IJfP00F]X005[J0002F]X01P00F]X00000F]X0009JfP80000=F]X005Zj001F^`00E[/0
05Jk001F^`00E[/00P0000=F^`00E[/03P0000UF^`00E[/005Jk001F^`00D[/00P0000UB^`00D[/0
05:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[/0
0P0000UB^`00D[/005:k001B^`00D[`00P0000EB_000D[`005:l02l00007D]`005;L001Bg000D]`0
0P0000IBo000E_`005Kl0002E_`01000E_`005Kl0P0000eFo000E_`005Kl001Fo000E_`005Kl001F
o0020002E_`700005E[l001Jo000F_`005[l001Jo000F_`005[l001Jo000F_`005[l001Jo0030000
1U[l001Jo000F_/0009Jn`0:001Jn`00001Jn`00F_/005[k0002F_/600004U[k001Jne[k001Jn`00
F_/005[k001Jn`00F_/005[k001Jn`D0000EF_/005[k001Jn`00F_/005[k001Jn`00F_/005[K001J
f`00F]/005[K00L00005F]/00000F]/00002F]/02000F]/005[K001Jf`00F]/2000015[K001Jf`00
0U[K00<005[K00001@0000YJf`00F]/005[K001JfP00F]X0009JfP80000;F]X005[J001JfP00F]X0
05[J001J^P0200002UZj001J^UZj001F^P00E[X005Jj200000EF^`00E[/005Jk00800006E[/005Jk
001F^`000UJk00@005Jk001F^`80000=E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000AF^`00
E[/0009F^`06001F^`00E[/005Jk300000]Ff`00001Ff`00E]/005KK001Ff`00009Ff`80000?E]/0
05KK001Ff`00E]/005KK001Ff`00E]/005KK00800004E]/005KK0002E]/01000E]/005KK0P0000=F
f`0000001`0000=Ff`00E]/00P0000IFf`00E]]Ff`00E]/3000065KK000005KK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`L00003Ool007oo02Qoo`00aGoo00<007ooOol0FWoo
00H005KK001Ff`00E]/200003EKK001Ff`00E]/005KK001Fg000E]`005KL00800009D]`005;L001B
g000D]`005;L00800007D]`005;L001Bg000D]`00P0000UBg000D]`005;L001Bg000D]`0;`0000E>
g000C]`004kL00800009C]`004kL001>g000C]`004kM00800007C]d004kM001>g@00C]d00P0000M>
g@00C]d004kM001>g@0200002E;M001Bg@00D_d005;m001Bo@0200001E;m001Bo@00D_`01`0000QF
o000E_`005Kl001Fo0000U[l0P000U/L00X005/L001K7000Fa`005/L001K70<00004Ga`005lL0002
Ga`02P00Ga`005lK001O6`00Ga/005lK0P0000QO6`00Ga/005lK001O6`000UlK00/005lK001O6`00
Ga/005lK001O6`00009O6`0:001O6`00G_/005kk001Nn`00G_/2000025kk001Nn`00G_/005kk0002
G_/02`00G_/005kk001Nn`00G_/005kk00000Ukk00`005kk001Nn`00G_/005kk001Nn`00G_X30000
4Ukk001NnUkj001NnP00G_X005kj001NnP00G_X005kj001NnP<0000DG]X005kJG]X005kJ001NfP00
G]X005kJ001NfP00F]X005[J001JfPD0000EF]X005[J001JfP00F]X005[J001JfP00F]X005[J001J
fP00F]X005[J0080009JfP800005E[/005Jk001F^`0900004UJk000005Jk001F^`00E[/005Jk001F
^`00E[/005Jk001F^`80009F^`0=001B^`00001B^`00D[/005:k001B^`00D[/00P0000UB^`00D[/0
05:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[`0
0P0000=B_000D[`00P0000=B_000D[`00P0000]B_000D[`005:l001Bg000D]`005;L00800009D]`0
05;L001Bg000D]`005;L0080000;D]`005;L001Bg000D]`005;L001Bg002000015;L001Bg0000U;L
00H005;L001Bg000D]`200003e;l001Fo000E_`005Kl001Fo000E_`005Kl001Fo00200001eKl001F
o000E_`005Kl00L00006F_`005[l001Jo0000U[l00`005[l000005[l001Jo000F_`005[l0002F_`6
00003U[l001Jo5[l001Jo000F_/005[k001Jn`00F_/20002F_/5000045[k001Jn`00F_/005[k001J
n`00F_/005[k001Jn`000U[k0P0000QJn`00000005[k001Jn`000U[k00`005[k000005[k001Jn`00
F_/005[k0002F]/200002U[K00000000F]/005[K001Jf`000U[K0P00015Jf`00F]/005[K001Jf`00
F]/005[K001Jf`00F]/005[K00D00003F]/005[K00800004F]/005[K0002F]/01P00F]X005[J001J
fP800008F]X005[J001JfP00F]X0009JfP800003F[X005Zj00X0000:E[X005Jk001F^`00E[/005Jk
0002E[/200003EJk001F^`00E[/005Jk001F^`00E[/005Jk00800008E[/005Jk001F^`00E[/0009F
^`800005E[/005Jk001F^`0:00005eKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/00P0001EFf`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/02P00
01]Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00P00
00AFf`00E]/0009Ff`03001Ff`0000T00008E]/005KK001Ff`00Ool002Uoo`00aGoo00<007ooOol0
Fgoo00d005KK000005KK001Ff`00E]/005KK001Ff`0200001eKL001Fg000E]`005KL00800005D]`0
05;L001Bg00G00001e;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P0000MBg000D]`0
05;L001Bg00200001e;L001Bg000D]`004kL00800007C]`004kL001>g000C]`00P0000=>g0000000
<P0000EFo000E_`005Kl0080009Fo007001Fo000E_`005Kl00000U[l0P0000EK7000Fa`005/L00L0
0007Fa`005lLGa`005lL00000UlL0P0000=O6`00Ga/0100000iO6`00Ga]O6`00Ga/005lK001O6`00
Ga/005lK1@000UlK00<005lK00000UlK00D005lK000005kk00@0000>G_/005kkG_/005kk001Nn`00
G_/005kk001Nn`D0009Nn`0<001Nn`00G_/005kk001Nn`00G_/005kk100000QNn`00G_/005kk001N
nP000Ukj0P000Ukj0P0000=NnP0000000P0001=NfP00G]X005kJ001NfP00G]X005kJ001NfP00G]X0
05kJ001JfP0500001U[J001JfP00F]X0009JfP80000AF]X005[J001JfP00F]X005[J001JfP00F]X0
05[J001JfP0900005UJk000005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk0P00
00UF^`00E[/005Jk001F^`00D[/00P0000UB^`00D[/005:k001B^`00D[/00P0000UB^`00D[/005:k
001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[`00P00
00UB_000D[`005:l001B_000D[`00P0000]B_000D[`005:l001Bg000D]`005;L00800009D]`005;L
001Bg000D]`005;L0080000;D]`005;L001Bg000D]`005;L001Bg00200003e;L001Bg000D]`005;L
001Bg000D]`005;L001Bo00200003EKl001Fo000E_`005Kl001Fo000E_`005Kl00L00003E_`005Kl
0080000>E_`005[lF_`005[l001Jo000F_`005[l001Jo0800003F_`005[l00H0000EF_`005[l001J
o000F_`005[l001Jo000F_/005[k001Jn`00F_/005[k00<00004F_/005[k0002F_/02P00F_/00000
F_/005[k001Jn`000U[k00<005[k00001@0000aJn`00F_]Jn`00F_/005[k001Jn`00F_/200001U[k
001Jne[k001Jn`H0000:F]/005[KF]/005[K001Jf`00F]/200001U[K001Jf`00F]/0009Jf`04001J
f`00F]/600001U[K001Jf`00F]/0009Jf`80000;F]/005[K001Jf`00F]X005[J001JfP02000025[J
001JfU[J001JfP00F]X800001eJj001F^P00E[X005Jj0080000<E[X005JkE[/005Jk001F^`00E[/0
05Jk0P0000eF^`00E[/005Jk001F^`00E[/005Jk001F^`020002E[/01P00E[/005Jk001F^`X00007
E[/005Jk001F^`00E[/00P0000YFf`00E]]Ff`00E]/005KK001Ff`80000?E]/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK0080009Ff`08001Ff`00E]/005KK001Ff`P00005E]/005KK001Ff`020000
2UKK001FfeKK001Ff`00E]/005KK0P0001EFf`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/02000011Ff`00E]/005KK001Ff`00E]/005KK001Ff`00Ool002Uoo`00aWoo00<007oo
Ool0FWoo00H005KK001Ff`00E]/200001EKK001Ff`00E]/0400000=Bg000D]`00P0000MBg000D]`0
05;L001Bg00200004E;L001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`00P0000MBg000D]`0
05;L001Bg00200001e;L001Bg000D]`005;L00800007D]`005;L001Bg000C]`00P0000M>g000C]`0
04kL001>g00300001DkL001>g000C]`00P0000U>g000C]`004kL001>g000C]`00P0000M>g@00C]d0
04kM001>g@0200001dkM001>g@00C]d005;M00800009D]d005;m001Bo@00D_d005;m00800004D_d0
05;l0002E_`01000E_`005Kl0P000UKl00P005Kl001Fo000E_`005[l0P0000=K700000000P0000YK
7000Fa`005/L001K7000Fa`0009O7006001O7000Ga`005lL0`0000AO6`00Ga/0009O6`0:001O6`00
Ga/005lK001O6`00Ga/2000025lK001O6`00Ga/005lK0002Ga/02`00Ga/005lK001Nn`00G_/005kk
00000Ukk00X005kk001Nn`00G_/005kk001Nn`800008G_/005kk001Nn`00G_/0009Nn`06001Nn`00
G_/005kk0`0000ANn`00G_/0009Nn`800008G_/005kjG_X005kj001NnPD00004G_X005kj0002G]X2
00002UkJ001NfUkJ001NfP00G]X005kJ1@0000EJfP00001JfP00009JfP0<001JfP00F]X005[J001J
fP00F]X005[J0P000U[J00D005[J000005[J00D0000CF]X005Zk001F^`00E[/005Jk001F^`00E[/0
05Jk001F^`00E[/00P0000mF^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000UF^`00D[/0
05:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[/0
0P0000UB^`00D[/005:k001B^`00D[/00P0000UB^`00D[`005:l001B_000D[`00P0000UB_000D[`0
05:l001B_000D[`00P0000UBg000D]`005;L001Bg000D]`00P0000]Bg000D]`005;L001Bg000D]`0
05;L00800009D]`005;L001Bg000D]`005;L0080000;D]`005;L001Bg000D]`005;L001Bo0020000
0eKl001Fo00;00001UKl001Fo000E_`0009Fo00C001Fo000001Fo000F_`005[l001Jo000F_`005[l
001Jo000F_`00`0000IJo000F_`005[l0002F_`03@00F_`00000F_`005[l001Jo000F_/005[k00L0
000<F_/005[kF_/005[k001Jn`00F_/005[k0P000U[k1`0001=Jn`00F_/005[k001Jn`00F_/005[k
001Jn`00F_/005[k001Jn`0700004E[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/00P00
0U[K00<005[K00001`0000AJf`00F]/0009Jf`06001Jf`00F]/005[K0P0000YJf`00F]/005[K001J
fP00F]X0009JfP800003F]X0000000D00003F]X005Zj00800006F[X005Jj001F^P000UJj00l005Jj
000005Jj001F^`00E[/005Jk001F^`00E[/00P0000IF^`00E[/005Jk0002E[/01000E[/005Jk0P00
00=F^`0000001`0000eF^`00001F^`00E[/005Jk001F^`00E[/00002E[/200003EJk001Ff`00E]/0
05KK001Ff`00E]/005KK00800008E]/005KK001Ff`00E]/0009Ff`800003E]/005KK00`00006E]/0
05KK001Ff`000UKK01<005KK000005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`0200001UKK
001FfeKK001Ff`<00003E]/0000000H00005E]/005KK001Ff`020002E]/01P00E]/005KK001Ff`80
0006E]/005KK001oo`00:Goo0037Ool00`00Oomoo`1JOol<00002UKK000005KK001Fg000E]`005KL
0P0000AFg000E]`0009Bg00;001Bg000001Bg000D]`005;L001Bg00200002E;L001Bg000D]`005;L
001Bg00200001e;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P0000MBg000D]`005;L
001Bg00200001e;L001Bg000C]`004kL00800007C]`004kL001>g000C]`00P0000E>g000C]`004kL
00800009C]`004kL001>g000C]`004kL00800007C]d004kM001>g@00C]d00P0000M>g@00C]d004kM
001Bg@0200002E;M001Bo@00D_d005;m001Bo@02000015;m001Bo0000UKl00@005Kl001Fo0800007
E_`005Kl001Fo000E_`01@0000AJo000Fa`0009K700<001K7000Fa`005/L001K7000Ga`005lL1@00
00MO7000Ga]O6`00Ga/00002Ga/01@00Ga/00000Ga/0100000iO6`00Ga]O6`00Ga/005lK001O6`00
Ga/005lK1@000Ukk00<005kk00000Ukk00D005kk000005kk00@00006G_/005kkG_/005kk0P000Ukk
00H005kk001Nn`00G_/3000045kk001Nnekk001Nn`00G_/005kk001Nn`00G_X005kj0`0000ANnP00
G_X0009NnP0>001NnP00G]X005kJ001NfP00G]X005kJ001NfP<0000IF]X005[J001JfP00F]X005[J
001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X01`0000=JfP00F]X00P000U[J00P005Zk001F
^`00E[/005Jk0P0000eF^`00E[/005Jk001F^`00E[/005Jk001F^`0200002EJk001F^`00E[/005Jk
001F^`020002E[/03@00D[/00000D[/005:k001B^`00D[/005:k00800009D[/005:k001B^`00D[/0
05:k00800009D[/005:k001B^`00D[/005:k00800009D[/005:k001B^`00D[/005:l00800003D[`0
05:l00800009D[`005:l001B_000D[`005:l00800009D]`005;L001Bg000D]`005;L0080000;D]`0
05;L001Bg000D]`005;L001Bg00200002E;L001Bg000D]`005;L001Bg0020002D]`>00006EKl001F
o000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl00800005F_`005[l001J
o00700003U[l001Jo5[l001Jo000F_`005[l001Jo000F_`20002F_`500005E[k001Jn`00F_/005[k
001Jn`00F_/005[k001Jn`00F_/005[k001Jn`0300001U[k001Jn`00F_/0009Jn`0:001Jn`00001J
n`00F_/005[k0002F_/00`00F_/0000300001U[K001Jf`00F]/0009Jf`0<001Jf`00001Jf`00F]/0
05[K001Jf`000U[K0P0000=Jf`0000000`0001=Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/0
05[K001Jf`02000015[K001Jf`000U[K00@005[J001JfPH0000EF]X005[J001JfP00F]X005Zj001J
^P00F[X005Jj001F^P00E[X005Jj0080000:E[X005Jk001F^`00E[/005Jk0002E[/200001EJk001F
^`00E[/02P0000UF^`00E[/005Jk001F^`00E[/00P000UJk00X005Jk001F^`00E[/005Jk001F^`80
000GE[/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`0800005EKK001F
f`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`0200004eKK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK00X00006E]/005KK001Ff`000UKK0P00015Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK008002Uoo`00agoo00<007ooOol0FWoo00H005KK001Ff`00E]/2
000015KK001Ff`000UKK0P0000MFf`00E]`005KL001Fg00200002EKL001Fg000D]`005;L001Bg002
000015;L001Bg0000U;L0P0000MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007
D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg00200001e;L001Bg000D]`004kL00800007
C]`004kL001>g000C]`00P0000M>g000C]`004kL001>g00200002DkL001>g000C]`004kL001>g002
00001dkM001>g@00C]d004kM00800007C]d004kM001>g@00D]d00P0000UBg@00D_d005;m001Bo@00
D_d00P0000]Bo@00D_`005Kl001Fo000E_`005Kl00L00003E_`005[l0080009Jo003001K7000009K
7009001K7000001K7000Fa`005lL00800008Ga`005lL001O7000Ga`0009O6`0=001O6`00Ga/005lK
001O6`00Ga/005lK00000UlK00X005lK001O6`00Ga/005lK001O6`800008G_/005kk001Nn`00G_/0
009Nn`0;001Nn`00G_/005kk001Nn`00G_/00002G_/02P00G_/005kk001Nn`00G_/005kk1@0000MN
n`00G_]Nn`00G_/00002G_/200001Ekk001Nn`00G_X00P0000=Nn`0000000Ukj00h005kj001NnP00
G_X005kJ001NfP00G]X005kJ1@0000QNfP00F]YJfP00F]X005[J0P0000IJfP00F]YJfP00F]X20002
F]X200000e[J00000003000025[J001JfP00F]X005[J0002F]X200003e[J001J^`00E[/005Jk001F
^`00E[/005Jk001F^`0200003EJk001F^`00E[/005Jk001F^`00E[/005Jk00800005E[/005Jk001F
^`1X00002E;L001Bg000D]`005;l001Fo00200003UKl001Fo5Kl001Fo000E_`005Kl001Fo000E_`2
00003EKl001Fo000E_`005Kl001Fo000E_`005[l00D0000GF_`005[l001Jo000F_`005[l001Jo000
F_`005[l001Jo000F_`005[l001Jo003000015[l001Jo0000U[k00H005[k001Jn`00F_/2000015[k
001Jn`000U[k1P0000aJn`00F_]Jn`00F_/005[k001Jn`00F_/200001U[k001Jne[k001Jn`D00003
F_/00000009Jf`0:001Jf`00F]/005[K001Jf`00F]/20002F]/01000F]/005[K1P0000IJf`00F]/0
05[K0002F]/03P00F]/00000F]/005[K001Jf`00F]/005[K0002F]/200000e[K001Jf`0700002E[K
000005[J001JfP00F]X00002F]X01000F]X005Zj0P0000UJ^P00E[X005Jj001F^P00E[X00P0000YF
^P00E[]F^`00E[/005Jk001F^`X00005E[/005Jk001F^`0200001UJk001F^`00E[/0009F^`04001F
^`00E[/200003EJk001F^`00E[/005Jk001F^`00E[/005Jk0080000:E]/005KKE]/005KK001Ff`00
E]/<00002EKK000005KK001Ff`00E]/00002E]/04`00E]/00000E]/005KK001Ff`00E]/005KK001F
f`00E]/005KK0080000:E]/005KKE]/005KK001Ff`00E]/800004EKK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/00P00015Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK008002Uo
o`00b7oo00<007ooOol0FWoo00H005KK001Ff`00E]/200001eKK001Ff`00E]/005KK0080000?E]`0
05KL001Fg000E]`005KL001Fg000D]`005;L00800009D]`005;L001Bg000D]`005;L00800007D]`0
05;L001Bg000D]`00P0000MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007D]`0
05;L001Bg000D]`00P0000MBg000D]`004kL001>g00200001dkL001>g000C]`004kL00800007C]`0
04kL001>g000C]`00P0000M>g000C]`004kL001>g00200001dkM001>g@00C]d004kM00800009C]d0
04kM001>g@00D]d005;M00800007D_d005;m001Bo@00D_d00P0000=Bo@0000002@0000IFo000E_`0
05Kl0002E_`01000F_`000000U[l00P005/L001K7000Fa`005/L1@00011K7000GaaO7000Ga`005lL
001O7000Ga/005lK001O6`D0009O6`03001O6`00009O6`05001O6`00001O6`0400003Ukk001Nnekk
001Nn`00G_/005kk001Nn`00G_/50002G_/01@00G_/005kk00000Ukk0P0000=Nn`00G_/00P0000YN
n`00G_/005kk001Nn`00G_/0009Nn`04001Nn`00G_/5000015kk001Nnekk0P0000ANnP00G_X0009N
nP80009NfP80000JG]X00000G]X005kJ001NfP00G]X005[J001JfP00F]X005[J001JfP00F]X005[J
001JfPD00003F]X005[J0080009JfP08001JfP00F]X005[J001JfP80009JfP0A001J^`00001F^`00
E[/005Jk001F^`00E[/005Jk001F^`0200000eJk0000000>00002EJk001F^`00E[/005:k001B^`02
00002E:k001B^`00D[/005:k001B^`0200002E:k001B^`00D[/005:k001B^`0200002E:k001B^`00
D[/005:k001B^`0200002E:k001B^`00D[`005:l001B_00200002E:l001B_000D[`005;L001Bg002
00002E;L001Bg000D]`005;L001Bg00200002e;L001Bg000D]`005;L001Bg000D]`00P0000UBg000
D]`005;L001Bg000D]`00P0000aBg000D]aBg000D]`005;L001Bo000E_`200003EKl001Fo000E_`0
05Kl001Fo000E_`005Kl00800005E_`005Kl001Fo009000015[l001Jo0000U[l00P005[l001Jo000
F_`005[l0P0000EJo000F_`005[l00L0000>F_`005[lF_`005[l001Jn`00F_/005[k001Jn`80009J
n`D0000CF_/005[k001Jn`00F_/005[k001Jn`00F_/005[k001Jn`00F_/01`0000AJn`00F_/0009J
n`80000=F]/005[K001Jf`00F]/005[K001Jf`00F]/01`0000=Jf`00F]/00P000U[K00X005[K001J
f`00F]/005[K001Jf`800008F]/005[KF]/005[K001Jf`P0000EF]/005[K001Jf`00F]/005[J001J
fP00F]X005[J001JfP00F]X005Zj00800006F[X005Jj001F^P000UJj00D005Jj000005Jj00T0000=
E[/00000E[/005Jk001F^`00E[/005Jk00000UJk0P0000]F^`00E[/005Jk001F^`00E[/005Jk0080
000:E[/005Jk001F^`00E[/005Jk0002E[/200000eJk001Ff`0:00005eKK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00P0000YFf`00E]/005KK001Ff`00E]/0009Ff`05
001Ff`00001Ff`0<00001UKK001Ff`00E]/0009Ff`80000AE]/005KK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`020002E]/01000E]/005KK2@00:Goo0038Ool00`00Oomoo`1JOol03P00E]/005KK
001Ff`00E]/005KK001Ff`00E]/200002EKK001Fg000E]`005KL001Fg00200001eKL001Bg000D]`0
05;L00800005D]`005;L001Bg01Z00004U;l001Bo000E_`005Kl001Fo000E_`005Kl001Fo000E_`0
009Fo009001Jo000001Jo000Fa`005/L00D00004Fa`005/L0002Fa`01@00GaaO7000Ga`00P0000=O
7000Ga/0100000IO6`00Ga/005lK0002Ga/03@00Ga/005lK001O6`00Ga/005lK001O6`00009Nn`0:
001Nn`00G_/005kk001Nn`00G_/2000025kk001Nn`00G_/005kk0002G_/01P00G_/005kk001Nn`<0
0006G_/005kkG_/005kk0P000Ukk00H005kk001Nn`00G_/3000015kk001Nn`000Ukk00@005kk0000
009NnP06001NnP00G_X005kj1@0000ANfP00G]X0009NfP800004G]X005[JF]X200001e[J001JfP00
F]X005[J00D00006F]X005[J001JfP000U[J0P0001EJfP00F]X005[J001JfP00F]X005[J001JfP00
F[/005Jk001F^`00E[/00P0000=F^`0000001`0000=F^`00E[/00P0000UF^`00E[/005Jk001F^`00
E[/00P000UJk00H005Jk000005:k0002D[/200002E:k001B^`00D[/005:k001B^`0200002E:k001B
^`00D[/005:k001B^`0200002E:k001B^`00D[/005:k001B^`0200002E:k001B^`00D[`005:l001B
_00200002E:l001B_000D[`005;L001Bg00200002E;L001Bg000D]`005;L001Bg00200002e;L001B
g000D]`005;L001Bg000D]`00P0000UBg000D]`005;L001Bg000D]`00P0000mBg000D]`005;L001B
g000D_`005Kl001Fo000E_`00P0000UFo000E_`005Kl001Fo000E_`01`0001UFo000E_`005Kl001F
o000E_`005[l001Jo000F_`005[l001Jo000F_`005[l001Jo00500005E[l001Jo000F_`005[l001J
o000F_`005[l001Jn`00F_/005[k001Jn`05000015[k001Jn`000U[k00`005[k000005[k001Jn`00
F_/005[k0002F_/400001U[k001Jn`00F_/0009Jn`04001Jn`00F_/200001U[K001Jf`00F]/0009J
f`03001Jf`0000<00006F]/005[K001Jf`000U[K01<005[K000005[K001Jf`00F]/005[K001Jf`00
F]/005[K001Jf`0700002E[K000005[K001Jf`00F]/00002F]/01000F]/005[K0P0001=JfP00F]X0
05[J001JfP00F]X005Zj001J^P00F[X005Jj001F^P0800002EJk001F^`00E[/005Jk001F^`020000
35Jk001F^eJk001F^`00E[/005Jk001F^`80000;E[/005Jk001F^`00E[/005Jk001F^`020002E[/0
2000E[/005Jk001F^`00E[/800001eKK001Ff`00E]/005KK0080000:E]/005KKE]/005KK001Ff`00
E]/200005eKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/0200001=F
f`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`02000015KK001FfeKK0P0000IFf`00
E]/005KK0002E]/200000eKK0000000700001UKK000005KK001Ff`8002Uoo`00bGoo00<007ooOol0
FWoo00H005KK001Ff`00E]/200001eKK001Ff`00E]/005KK00800007E]`005KL001Fg000E]`04000
00=Bg000D]`00P0000MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007D]`005;L
001Bg000D]`00P0000MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007C]`004kL
001>g000C]`00P0000M>g000C]`004kL001>g00200001dkL001>g000C]`004kL00800007C]`004kL
001>g@00C]d00P0000U>g@00D]d005;M001Bg@00D]d00P0000MBo@00D_d005;m001Bo@020002D_`0
5P00D_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000F_`005[l1@0000YK7000Fa`005/L
001K7000Fa`0009K7006001O7000Ga`005lL0`0000AO6`00Ga/0009O6`0:001O6`00Ga/005lK001O
6`00Ga/50002Ga/00`00Ga/00002G_/01@00G_/00000G_/0100000INn`00G_]Nn`00G_/20002G_/0
1P00G_/005kk001Nn`<0000@G_/005kkG_/005kk001Nn`00G_/005kk001Nn`00G_/200000ekk0000
0002G_/03P00G_/005kk001Nn`00G_/005kj001NnP00G_X3000015kJ001NfP000UkJ00h005kJ001N
fP00G]X005kJ001JfP00F]X005[J1@0000=JfP00F]X00P000U[J00H005[J001JfP00F]X20002F]X0
1000F]X005[J0P000U[J0P0000EJfP00F[/005Jk00L00003E[/005Jk0080000CE[/005Jk001F^`00
E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000UF^`00E[/005Jk001B^`00D[/00P0000UB^`00
D[/005:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00
D[/00P0000UB^`00D[/005:l001B_000D[`00P0000UB_000D[`005:l001Bg000D]`00P0000UBg000
D]`005;L001Bg000D]`00P0000mBg000D]`005;L001Bg000D]`005;L001Bg000D]`00P0000UBg000
D]`005;L001Bg000D]`00P0000eBg000D]`005;l001Fo000E_`005Kl001Fo00900001eKl000005Kl
001Fo000009Fo00:001Fo000E_`005Kl001Fo000F_`200001e[l001Jo000F_`005[l00D00004F_`0
05[l0002F_`02000F_`005[l001Jo000F_`2000015[l001Jne[k1@0000EJn`00001Jn`00009Jn`08
001Jn`00F_/005[k001Jn`80009Jn`03001Jn`0000@00003F_/00000009Jn`0:001Jn`00F_/005[k
001Jn`00F_/20002F]/01000F]/005[K1@0000EJf`00001Jf`00009Jf`06001Jf`00F]/005[K0P00
00IJf`00F]/005[K0002F]/01@00F]/00000F]/00`0001EJf`00F]/005[K001Jf`00F]/005[K001J
f`00F]/005[K001Jf`00F]/00P0000IJfP00F]X005[J0002F]X01000F]X005Zj200000=F^P00E[X0
0P0000IF^P00E[/005Jk0002E[/01000E[/005Jk0P0000]F^`00E[/005Jk001F^`00E[/005Jk0080
0006E[/005Jk001F^`000UJk00@005Jk001F^``00009E]/00000E]/005KK001Ff`00009Ff`0A001F
f`00001Ff`00E]/005KK001Ff`00E]/005KK001Ff`0200001UKK001Ff`00E]/0009Ff`05001Ff`00
001Ff`0900000eKK001Ff`02000025KK001FfeKK001Ff`00E]/200005eKK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK001Ff`00E]/02000011Ff`00E]/005KK001Ff`00E]/005KK001F
f`00E]/002Uoo`00bWoo00<007ooOol0FGoo00X005KK001Ff`00E]/005KK001Ff`h0000:E]`00000
E]`005KL001Fg000D]`2000015;L001Bg0000U;L00/005;L000005;L001Bg000D]`005;L00800007
D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007
D]`005;L001Bg000D]`00P0000M>g000C]`004kL001>g00200001dkL001>g000C]`004kL00800007
C]`004kL001>g000C]`00P0000M>g000C]`004kM001>g@0200002DkM001Bg@00D]d005;M001Bg@02
00001e;m001Bo@00D_d005;m0080009Bo008001Bo000E_`005Kl001Fo0800005E_`005Kl001Fo007
000015[l001Jo0000U/L00`005/L001K7000Fa`005/L001K7000Ga`500001elL001O6elK001O6`00
009O6`800003Ga/005lK00@00008Ga/005lK001O6`00Ga/0009O6`0;001Nn`00G_/005kk001Nn`00
G_/00002G_/02P00G_/005kk001Nn`00G_/005kk100000QNn`00G_/005kk001Nn`000Ukk0P0000=N
n`00G_/0100000ANn`00G_]Nn`800004G_/005kk0002G_/01@00G_/00000G_X0100000=NfP000000
0UkJ010005kJ001NfP00G]X005kJ001NfP00G]X005[J001JfP<00006F]X005[J001JfP000U[J0P00
015JfP00F]X005[J001JfP00F]X005[J001JfP00F]X005[J00X0000CE[/005Jk001F^`00E[/005Jk
001F^`00E[/005Jk001F^`00E[/00P0000UF^`00E[/005Jk001F^`00E[/00P000UJk00d005Jk0000
05:k001B^`00D[/005:k001B^`0200001e:k001B^`00D[/005:k00800009D[/005:k001B^`00D[/0
05:k00800009D[/005:k001B^`00D[/005:k00800009D[`005:l001B_000D[`005:l00800009D[`0
05;L001Bg000D]`005;L0080000;D]`005;L001Bg000D]`005;L001Bg00200002E;L001Bg000D]`0
05;L001Bg00200002e;L001Bg000D]`005;L001Bg000D]`03P0000QFo000E_`005Kl001Fo0000UKl
0P0000mFo000E_`005Kl001Fo000E_`005Kl001Fo000F_`00P0000=Jo0000000100001EJo000F_`0
05[l001Jo000F_`005[l001Jo000F_`005[l001Jo000F_`01@0000AJn`00F_/0009Jn`80000=F_/0
05[k001Jn`00F_/005[k001Jn`00F_/01@0000AJn`00F_/0009Jn`80000:F_/005[k001Jn`00F_/0
05[k0002F_/8000015[K001Jf`000U[K0P00015Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/0
05[K00P00006F]/005[K001Jf`000U[K01L005[K000005[K001Jf`00F]/005[K001Jf`00F]/005[J
001JfP00F]X005[J00P0000GF[X005Jj001F^P00E[X005Jj001F^P00E[X005Jk001F^`00E[/005Jk
001F^`0200002UJk001F^`00E[/005Jk001F^`000UJk0P0000EF^`00E[/005Jk00P0000GE[/005Jk
001F^`00E[/005Jk001Ff`00E]/005KK001Ff`00E]/005KK001Ff`0200005EKK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`0800005EKK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/005KK001Ff`020002E]/200001UKK001Ff`00E]/0009Ff`800003E]/0000000L00003
E]/005KK00800008E]/005KKE]/005KK001Ff`800007E]/005KK001Ff`00E]/00P00:7oo003:Ool0
0`00Oomoo`1JOol:00001EKK001Ff`00E]/00P0000IFf`00E]`005KL0002E]`200001eKL001Fg000
E]`005;L00800009D]`005;L001Bg000D]`005;L0080000?D]`005;L001Bg000D]`005;L001Bg000
D]`005;L00800007D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg00200001e;L001Bg000
D]`005;L00800007C]`004kL001>g000C]`00P0000M>g000C]`004kL001>g00200001dkL001>g000
C]`004kL00800007C]`004kL001>g@00C]d00P0000U>g@00D]d005;M001Bg@00D]d00P0000MBo@00
D_d005;m001Bo@0200002e;l001Bo000E_`005Kl001Fo000E_`01@0000aFo000E_`005[l001Jo000
F_`005[l0002Fa`01`00Fa`00000Fa`005/L00@00008Fa`005lL001O7000Ga`0009O6`04001O6`00
Ga/200001elK000005lK001O6`00009O6`0:001O6`00Ga/005lK001O6`00G_/50002G_/00`00G_/0
0002G_/01`00G_/00000G_/005kk00800004G_/005kk0002G_/20002G_/01P00G_/005kk001Nn`<0
0004G_/005kk0002G_/01000G_/000000Ukk00H005kk001Nn`00G_/3000015kk001Nn`000UkJ0P00
00ANfP00G]X0009NfP80009NfP800003G]X0000000<0000:F]X005[JF]X005[J001JfP00F]X20002
F]X01000F]X000000U[J0P0000=JfP00F]X01@0001=JfP00F]X005[K001J^`00E[/005Jk001F^`00
E[/005Jk001F^`0200003EJk001F^`00E[/005Jk001F^`00E[/005Jk00800009E[/005Jk001F^`00
E[/005Jk00800004D[/005:kD[/200002E:k001B^`00D[/005:k001B^`0200002E:k001B^`00D[/0
05:k001B^`0200002E:k001B^`00D[/005:k001B^`0200002E:k001B^`00D[`005:l001B_0020000
2E:l001B_000D[`005;L001Bg00200002E;L001Bg000D]`005;L001Bg00200001E;L001Bg000D]`0
5`0001]Bg000D]`005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`0
0P0000UFo000E_`005Kl001Fo000E_`01@0000IJo000F_`005[l0002F_`03`00F_`00000F_`005[l
001Jo000F_`005[l001Jo005000015[l001Jo0000U[k00H005[k001Jn`00F_/2000015[k001Jn`00
0U[k1P0000AJn`00F_/0009Jn`04001Jn`00F_/200001U[k001Jn`00F_/0009Jn`03001Jn`0000<0
0006F]/005[K001Jf`000U[K00@005[K001Jf`800006F]/005[K001Jf`000U[K00D005[K000005[K
00D0000CF]/005[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/00P0000AJf`00F]/0009J
f`04001Jf`00F]/800001E[J001J^P00F[X00P0000YJ^P00E[YF^P00E[X005Jj001F^P80000;E[X0
05Jk001F^`00E[/005Jk001F^`0200002UJk001F^eJk001F^`00E[/005Jk2P0000EF^`00E[/005Jk
00800004E[/005Jk0002E[/01000E[/005Jk0P0000eFf`00E]/005KK001Ff`00E]/005KK001Ff`02
00002UKK001FfeKK001Ff`00E]/005KK2P0000=Ff`00E]/00P0000YFf`00E]]Ff`00E]/005KK001F
f`80000EE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK00P0000IE]/005KK
001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00P0000=Ff`00E]/00P00
:7oo003;Ool00`00Oomoo`1IOol04000E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0P0000UF
f`00E]`005KL001Fg000E]`00P0000AFg000E]`0009Bg0800007D]`005;L001Bg000D]`00P0000MB
g000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P0000MB
g000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007C]`004kL001>g000C]`00P0000M>
g000C]`004kL001>g00200001dkL001>g000C]`004kL00800009C]`004kL001>g@00C]d004kM0080
0007D]d005;M001Bg@00D]d00P0000UBo@00D_d005;m001Bo@00D_`0300000AFo000E_`0009Fo00@
001Fo000F_`005[l001Jo000F_`005/L001K7000Fa`3000015/L001K70000U/L00`005lL001O7000
Ga`005lK001O6`00Ga/300001elK001O6elK001O6`00009O6`800005Ga/005lK001O6`02000025kk
001Nn`00G_/005kk0002G_/01P00G_/005kk001Nn`<0000@G_/005kkG_/005kk001Nn`00G_/005kk
001Nn`00G_/300004Ukk001Nnekk001Nn`00G_/005kk001Nn`00G_/005kk001Nn`<00008G_/005kk
G_/005kk001NfP80009NfP06001NfP00G]X005kJ1@0001MJfP00F]X005[J001JfP00F]X005[J001J
fP00F]X005[J001JfP00F]X005[J00L00003F]X005[J0080009JfP06001JfP00F]/005Zk0P0000mF
^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000eF^`00E[/005Jk001F^`00E[/005Jk001F
^`0200001eJk001F^`00E[/005:k04`00009D]`005;L001Bg000D]`005;L00800009D]`005;L001B
g000D]`005;L0080009Bg00>001Bg000E_`005Kl001Fo000E_`005Kl001Fo0800009E_`005Kl001F
o000E_`005Kl00800003E_`0000000H00003E_`005[l0080009Jo00:001Jo000F_`005[l001Jo000
F_`200000e[l001Jo00600000e[l001Jo0020002F_`02P00F_`005[k001Jn`00F_/005[k0P000U[k
1@0001EJn`00F_/005[k001Jn`00F_/005[k001Jn`00F_/005[k001Jn`00F_/01`0000=Jf`000000
0U[K00X005[K001Jf`00F]/005[K001Jf`800006F]/005[KF]/005[K200000AJf`00F]/0009Jf`04
001Jf`00F]/200004E[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/0200000YJf`00F]X0
05[J001JfP00F[X0009J^P800009F[X005Jj001F^P00E[X005Jj00800006E[X005Jk001F^`000UJk
00@005Jk001F^`800003E[/0000000L0000;E[/00000E[/005Jk001F^`00E[/00002E[/200003EJk
001F^`00E[/005Jk001F^`00E[/005KK00800006E]/005KK001Ff`000UKK00L005KK000005KK001F
f`0:000025KK001Ff`00E]/005KK0002E]/200003eKK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`02000025KK001FfeKK001Ff`00E]/:00000eKK001Ff`0200002UKK000005KK001Ff`00E]/005KK
0P0001=Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`03000XOol00<]oo`03001o
ogoo05Yoo`0:001Ff`00E]/005KK001Ff`00E]/200003EKK001Ff`00E]/005KK001Fg000E]`005KL
00800009E]`005KL001Fg000D]`005;L00800007D]`005;L001Bg000D]`00P0000UBg000D]`005;L
001Bg000D]`0F`00011Bo000E_`005Kl001Fo000E_`005Kl001Fo000E_`0009Fo00;001Fo000001J
o000F_`005[l001K700500001e/L001K75/L001K7000009K70800005Ga`005lL001O6`0400000elK
00000002Ga/00`00Ga/00002Ga/01@00Ga/00000Ga/0100000iNn`00G_]Nn`00G_/005kk001Nn`00
G_/005kk1@0000iNn`00G_]Nn`00G_/005kk001Nn`00G_/005kk100000=Nn`0000000Ukk00<005kk
00000Ukk0P000Ukk0P0000=Nn`0000000P0001=Nn`00G_/005kk001Nn`00G_/005kJ001NfP00G]X0
05kJ001NfP03000015[J001JfP000U[J00H005[J000005[J0002F]X01000F]X000000U[J0P0000=J
fP00F]X00`0000QJfP00F]X005[J001JfP000U[J0P0000eJfP00F]X005[K001J^`00E[/005Jk001F
^`0200003EJk001F^`00E[/005Jk001F^`00E[/005Jk00800003E[/0000001000007E[/005:k001B
^`00D[/00P0000MB^`00D[/005:k001B^`0200002E:k001B^`00D[/005:k001B^`0200002E:k001B
^`00D[/005:k001B^`0200002E:k001B_000D[`005:l001Bg00200002E;L001Bg000D]`005;L001B
g00200002e;L001Bg000D]`005;L001Bg000D]`00P000U;L00P005;L001Bg000D]`005;L0P0000UB
g000D]`005;L001Bg000D]`00P0000mBg000D]`005Kl001Fo000E_`005Kl001Fo000E_`00P0000EF
o000E_`005Kl00L00008E_`005Kl001Fo000E_`0009Fo00A001Jo000001Jo000F_`005[l001Jo000
F_`005[l001Jo00300001U[l001Jo000F_`0009Jo00<001Jo000001Jo000F_`005[k001Jn`000U[k
1P0000AJn`00F_/0009Jn`0<001Jn`00001Jn`00F_/005[k001Jn`000U[k0P0000YJn`00000005[k
001Jn`00F_/0009Jf`80000:F]/005[K001Jf`00F]/005[K0002F]/200000e[K0000000300004E[K
001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/00P0000IJf`00F]/005[K0002F]/01@00F]/0
0000F]/01@0000EJf`00F]/005[K0080000<F]/005[JF]X005[J001JfP00F[X005Zj0P00015J^P00
E[X005Jj001F^P00E[X005Jj001F^P00E[/005Jk00X00009E[/005Jk001F^`00E[/005Jk0080009F
^`08001F^`00E[/005Jk001F^`80000EE[/005Jk001F^`00E[/005Jk001F^`00E]/005KK001Ff`00
E]/005KK00X00007E]/005KK001Ff`00E]/00P000UKK00P005KK001Ff`00E]/005KK0P0001=Ff`00
E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`0800006eKK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`02000025KK001FfeKK001Ff`00E]/80000
0goo001oo`0WOol00<aoo`03001oogoo05Yoo`80009Ff`04001Ff`00E]/200001EKK001Ff`00E]/0
0P0000UFf`00E]`005KL001Fg000E]`00P0000EFg000E]`005;L01L00005D]`005;L001Bg0020000
1e;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg0020000
1e;L001Bg000D]`005;L00800007C]`004kL001>g000C]`00P0000M>g000C]`004kL001>g0020000
2DkL001>g000D]`005;L001Bg00200001e;L001Bg@00D]d005;M0080000MD_`005;l001Bo000D_`0
05;l001Bo000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo00200000e[l000000040000
25[l001Jo000Fa`005/L0002Fa`01000Fa`005/L0P0000=O700000000P0000AO7000Ga/0009O6`80
009O6`06001O6`00Ga/005lK0`0000ANn`00G_/0009Nn`0:001Nn`00G_/005kk001Nn`00G_/20000
25kk001Nn`00G_/005kk0002G_/01000G_/000000Ukk0`0000ANn`00G_/0009Nn`800008G_/005kk
G_/005kk001Nn`D00004G_/005kk0002G_/2000015kk001Nnekk0P000UkJ0P0000=NfP0000000P00
00=NfP0000000U[J010005[J001JfP00F]X005[J001JfP00F]X005[J001JfPL00003F]X00000009J
fP08001JfP00F]X005[J001JfP80009JfP0A001JfP00001J^`00E[/005Jk001F^`00E[/005Jk001F
^`0<00000eJk001F^`0200002EJk001F^`00E[/005Jk001F^`02000015Jk001F^eJk0P0000AB^`00
D[]B^`800007D[/005:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[/00P0000UB^`00D[/0
05:k001B^`00D[/00P0000UB^`00D[`005:l001B_000D]`00P0000UBg000D]`005;L001Bg000D]`0
0P0000]Bg000D]`005;L001Bg000D]`005;L0080000=D]`005;L001Bg000D]`005;L001Bg000D]`0
0P0000UBg000D]`005;L001Bg000D]`00P0000UFo000E_`005Kl001Fo000E_`02@0000EFo000E_`0
05Kl0080009Fo00<001Fo000E_`005Kl001Fo000F_`005[l0P0000EJo000F_`005[l00L0000>F_`0
05[lF_`005[l001Jo000F_`005[l001Jo0800004F_`005[kF_/500001E[k000005[k00000U[k00P0
05[k001Jn`00F_/005[k0P0000AJn`00F_]Jn`P0000:F_/005[kF_/005[k001Jn`00F]/200001U[K
001Jf`00F]/0009Jf`03001Jf`0000D00006F]/005[K001Jf`000U[K01D005[K000005[K001Jf`00
F]/005[K001Jf`00F]/005[K001Jf`00F]/0200000IJf`00F]/005[K0002F]/03`00F]/00000F]/0
05[J001JfP00F]X005Zj001J^P0200002UZj001F^UJj001F^P00E[X005Jj200000EF^`00E[/005Jk
00800006E[/005Jk001F^`000UJk014005Jk000005Jk001F^`00E[/005Jk001F^`00E[/005Jk0080
0004E[/005Jk0002E[/01000E[/005Jk2P0000=Ff`00E]/00P0000AFf`00E]/0009Ff`04001Ff`00
E]/200003EKK001Ff`00E]/005KK001Ff`00E]/005KK0080000:E]/005KKE]/005KK001Ff`00E]/8
00001EKK001Ff`00E]/00P000UKK00H005KK001Ff`00E]/200004eKK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK00T000Qoo`03001oogoo02Ioo`00cGoo00<007ooOol0FGoo00X005KK
001Ff`00E]/005KK001Ff`800007E]/005KK001Ff`00E]/03P0000=Fg000E]`00P0000MBg000D]`0
05;L001Bg00200003e;L001Bg000D]`005;L001Bg000D]`005;L001Bg00200001e;L001Bg000D]`0
05;L00800007D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg00200001e;L001Bg000D]`0
05;L00800007C]`004kL001>g000C]`00P0000M>g000C]`004kL001>g00200002DkL001>g000D]`0
05;L001Bg00200001e;L001Bg@00D]d005;M0080000CD_`005;l001Bo000D_`005;l001Bo000E_`0
05Kl001Fo000E_`00P0000EFo000E_`005Kl00D00006F_`005[l001Jo0000U[l00`005[l001K7000
Fa`005/L001K7000Fa`3000015lL001O70000UlL00<005lK00000UlK0P0000EO6`00Ga/005lK0080
0003Ga/00000009Nn`03001Nn`00009Nn`05001Nn`00001Nn`0400001Ukk001Nnekk001Nn`80009N
n`06001Nn`00G_/005kk0`00011Nn`00G_]Nn`00G_/005kk001Nn`00G_/005kk001Nn`<00004G_/0
05kk0002G_/03000G_/005kk001Nn`00G_/005kk001Nn`D00004G]/005kJ0002G]X200003e[J001J
fP00F]X005[J001JfP00F]X005[J001JfP0300007E[J001JfP00F]X005[J001JfP00F]X005[J001J
fP00F]X005[J001JfP00F]X005[J001Jf`00F[/00P0000=F^`00E[/01`0000EF^`00E[/005Jk0080
000CE[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000UF^`00E[/005:k001B
^`00D[/00P0000MB^`00D[/005:k001B^`0200002E:k001B^`00D[/005:k001B^`0200002E:k001B
^`00D[/005:k001B^`0200003e:k001B_000D[`005:l001Bg000D]`005;L001Bg00200002E;L001B
g000D]`005;L001Bg00200002E;L001Bg000D]`005;L001Bg00200002E;L001Bg000D]`005;L001B
g00200002e;L001Bg000D]`005;L001Bg000D]`02@0000=Fo000E_`00P0000AFo000E_`0009Fo004
001Fo000E_`20002E_`200002eKl001Fo000E_`005[l001Jo000F_`01@0001MJo000F_`005[l001J
o000F_`005[l001Jo000F_`005[l001Jo000F_`005[l00D00004F_/005[k0002F_/200003E[k001J
n`00F_/005[k001Jn`00F_/005[k00D0000GF_/005[k001Jn`00F_/005[k001Jn`00F_/005[k001J
f`00F]/005[K001Jf`0700001E[K000005[K00000U[K00P005[K001Jf`00F]/005[K0P0000AJf`00
F]/0009Jf`04001Jf`00F]/800001E[K001Jf`00F]/00P000U[K00P005[K001Jf`00F]/005[K0P00
00YJf`00F]X005[J001JfP00F[X0009J^P800003F[X0000000P0000:E[X005Jk001F^`00E[/005Jk
0002E[/200002eJk001F^`00E[/005Jk001F^`00E[/00P0000QF^`00E[/005Jk001F^`000UJk0P00
00EF^`00E[/005Jk00P0000GE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`0200002UKK001Ff`00E]/005KK001Ff`000UKK0P0000=Ff`00E]/02P0000IFf`00E]/005KK
0002E]/200003eKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`0200002UKK000005KK001Ff`00
E]/005KK1P0047oo00<007ooOol09Woo003=Ool00`00Oomoo`1JOol200000eKK0000000>00001eKK
001Fg000E]`005KL00800004E]`005KL0002E]`02`00E]`00000D]`005;L001Bg000D]`00P0000MB
g000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800004D]`005;L0002D]`200001e;L001B
g000D]`005;L00800007D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg00200001dkL001>
g000C]`004kL00800007C]`004kL001>g000C]`00P0000U>g000C]`005;L001Bg000D]`00P0000MB
g000D]d005;M001Bg@0200001e;l001Bo000D_`005;l00800009D_`005Kl001Fo000E_`005Kl00L0
0003E_`005Kl0080009Jo005001Jo000F_`00002F_`01`00F_`00000Fa`005/L00@00003Fa`00000
009O7003001O7000009O7004001O6`00Ga/200000elK00000002000015lK001O6elK0P000Ukk00d0
05kk001Nn`00G_/005kk001Nn`00G_/00002G_/02P00G_/005kk001Nn`00G_/005kk1@0000MNn`00
G_]Nn`00G_/00002G_/200001Ekk001Nn`00G_/00P0000=Nn`0000000Ukk00h005kk001Nn`00G_/0
05kk001Nn`00G_/005kk0`0000ANf`00G]/0009Nf`04001NfP00G]X20002F]X01P00F]X005[J001J
fPL00003F]X00000009JfP06001JfP00F]X005[J0P000U[J00@005[J001JfP80009JfP800005F]X0
05[J001Jf`0700002eJk000005Jk001F^`00E[/005Jk00000UJk0P0000MF^`00E[/005Jk001F^`02
00002EJk001F^`00E[/005Jk001F^`02000015Jk001F^eJk0P0000MB^`00D[/005:k001B^`020000
2E:k001B^`00D[/005:k001B^`0200002E:k001B^`00D[/005:k001B^`0200002E:k001B^`00D[/0
05:k001B_00200002E:l001Bg000D]`005;L001Bg00200002E;L001Bg000D]`005;L001Bg0020000
3e;L001Bg000D]`005;L001Bg000D]`005;L001Bg00C000025Kl001Fo000E_`005Kl0002E_`04@00
E_`00000E_`005Kl001Fo000E_`005Kl001Fo000E_`00P0000EFo000E_`005Kl00L00004F_`005[l
0002F_`02000F_`005[l001Jo000F_`200001E[l001Jo000F_`01`0000AJo000F_`0009Jn`06001J
n`00F_/005[k0P0000AJn`00F_/0009Jn`H00004F_/005[k0002F_/01000F_/005[k0P0000QJn`00
F_/005[k001Jn`000U[K0P0000YJf`00000005[K001Jf`00F]/0009Jf`80000AF]/005[K001Jf`00
F]/005[K001Jf`00F]/005[K001Jf`08000025[K001Jf`00F]/005[K0002F]/03@00F]/00000F]/0
05[K001Jf`00F]/005[K0080000:F]/005[JF]X005[J001JfP00F[X600001eJj001F^P00E[X005Jj
0080000<E[X005JkE[/005Jk001F^`00E[/005Jk0P0000]F^`00E[/005Jk001F^`00E[/005Jk0080
009F^`06001F^`00E[/005Jk2P0000EFf`00E]/005KK0080000:E]/005KKE]/005KK001Ff`00E]/2
00003EKK001Ff`00E]/005KK001Ff`00E]/005KK0080009Ff`06001Ff`00E]/005KK2000015Ff`00
E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0080000CE]/005KK001Ff`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/02@005Goo00<007ooOol09Woo003>Ool00`00Oomoo`1JOol200001eKK001F
f`00E]/005KK0080000?E]/005KK001Ff`00E]/005KK001Fg000E]`005KL00800009E]`005KL001F
g000E]`005;L00800004D]`005;L0002D]`200001e;L001Bg000D]`005;L00800005D]`005;L001B
g00200002E;L001Bg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007D]`005;L001B
g000D]`00P0000MBg000D]`005;L001>g00200001dkL001>g000C]`004kL00800007C]`004kL001>
g000C]`00P0000M>g000D]`005;L001Bg00200001e;L001Bg@00D]d005;M00800007D_`005;l001B
o000D_`02`0000MFo000001Fo000E_`00002E_`01000E_`000000U[l00X005[l001Jo000F_`005[l
001K70<00004Fa`005/L0002Fa`20002Ga`02000Ga`005lL001O6`00Ga/3000015lK001O6`000UlK
00X005lK001Nn`00G_/005kk001Nn`D0009Nn`03001Nn`00009Nn`07001Nn`00001Nn`00G_/00P00
00YNn`00G_/005kk001Nn`00G_/0009Nn`04001Nn`00G_/5000015kk001Nnekk0P0000ANn`00G_/0
009Nn`80009Nn`D00003G_/00000009Nf`0@001Nf`00G]/005kJ001NfP00G]X005[J001JfP00F]X3
00001U[J001JfP00F]X0009JfP80000AF]X005[J001JfP00F]X005[J001JfP00F]X005[J001JfP0:
00004e[K001F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk0080000=E[/005Jk001F^`00
E[/005Jk001F^`00E[/00P0000UF^`00E[/005Jk001F^`00E[/00P0000AB^`00D[]B^`800007D[/0
05:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[/00P0000UB^`00D[/005:k001B^`00D[/0
0P0000EB^`00D[`005:l02H00005D]`005;L001Bg00200006e;L001Bg000D]`005KL001Fg000E_`0
05Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo00200002EKl001Fo000E_`005Kl001Fo0070000
5eKl001Fo000F_`005[l001Jo000F_`005[l001Jo000F_`005[l001Jo000F_`01@0001=Jo000F_`0
05[l001Jo000F_`005[l001Jn`00F_/005[k001Jn`020002F_/500000e[k001Jn`020002F_/02P00
F_/005[k001Jn`00F_/005[k0P000U[k00<005[k00001`0000YJf`00F]]Jf`00F]/005[K001Jf`80
0008F]/005[K001Jf`00F]/0009Jf`03001Jf`0000D0000CF]/005[K001Jf`00F]/005[K001Jf`00
F]/005[K001Jf`00F]/00P0000IJf`00F]/005[K0002F]/01@00F]/00000F]/02@0000UJ^P00001F
^P00E[X005Jj00000UJj00l005Jj000005Jj001F^`00E[/005Jk001F^`00E[/00P0000IF^`00E[/0
05Jk0002E[/01@00E[/00000E[/02@0000]F^`00001F^`00E[/005Jk001Ff`00009Ff`80000=E]/0
05KK001Ff`00E]/005KK001Ff`00E]/00P0000AFf`00E]/0009Ff`04001Ff`00E]/200000eKK0000
000700001eKK000005KK001Ff`00009Ff`0C001Ff`00001Ff`00E]/005KK001Ff`00E]/005KK001F
f`00E]/00P000UKK00H005KK001Ff`00E]/8000MOol00`00Oomoo`0VOol00<ioo`03001oogoo05Yo
o`80009Ff`06001Ff`00E]/005KK0P0000MFf`00E]/005KK001Ff`0200003eKL001Fg000E]`005KL
001Fg000E]`005KL001Fg00200001e;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P00
00MBg000D]`005;L001Bg00200001E;L001Bg000D]`0BP0000]Bo000001Fo000E_`005Kl001Fo000
009Fo0800004E_`005Kl0002E_`02@00E_`00000F_`005[l001Jo00700001e[l001K75/L001K7000
009K70800005Ga`005lL001O700400000elK00000002Ga/00`00Ga/00002Ga/200000ekk001Nn`04
000025kk001Nn`00G_/005kk0002G_/01P00G_/005kk001Nn`<00006G_/005kkG_/005kk0P000Ukk
00H005kk001Nn`00G_/3000015kk001Nn`000Ukk00@005kk0000009Nn`06001Nn`00G_/005kk0`00
00ANn`00G_/0009Nn`800004G]/005kK0002G]/20002G]X200000e[J0000000300002U[J001JfU[J
001JfP00F]X005[J0P000U[J00/005[J000005[J001JfP00F]X005[J00D0000AF]X005[J001JfP00
F]/005[K001Jf`00E[/005Jk001F^`0200003eJk001F^`00E[/005Jk001F^`00E[/005Jk001F^`02
00003EJk001F^`00E[/005Jk001F^`00E[/005Jk00800007E[/005Jk001B^`00D[/0:@0000UBg000
D]`005;L001Bg000D]`00P0000UBg000D]`005;L001Bg000D]`00P0000UBg000D]`005;L001Bg000
D]`00P0000ABg000D]`0009Bg004001Bg000D]`200003E;L001Bg000D]`005KL001Fg000E_`005Kl
0080000;E_`005Kl001Fo000E_`005Kl001Fo00200000eKl0000000600001eKl000005Kl001Fo000
009Fo006001Fo000F_`005[l0P0000UJo000F_`005[l001Jo000F_`01@0000AJo000F_`0009Jo004
001Jo000F_`2000025[l001Jo000F_/005[k0002F_/6000015[k001Jn`000U[k014005[k000005[k
001Jn`00F_/005[k001Jn`00F_/005[k00D0000CF]/005[K001Jf`00F]/005[K001Jf`00F]/005[K
001Jf`00F]/00P000U[K00@005[K001Jf`H00006F]/005[K001Jf`000U[K00l005[K000005[K001J
f`00F]/005[K001Jf`00F]/00P000U[K00@005[K001Jf`P0000EF]/005[K001J^P00F[X005Zj001F
^P00E[X005Jj001F^P00E[X005Jj0080000:E[X005Jk001F^`00E[/005Jk0002E[/200001EJk001F
^`00E[/0200000UF^`00E[/005Jk001F^`00E[/00P000UJk00P005Jk001F^`00E]/005KK0P0001=F
f`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`0:00004eKK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK0080000:E]/005KK001Ff`00E]/005KK0002E]/200000eKK001F
f`090006Ool00`00Oomoo`0KOol00`00Oomoo`0VOol00<moo`03001oogoo05Yoo`800007E]/005KK
001Ff`00E]/00P000UKK00@005KK001Ff`800009E]/005KL001Fg000E]`005KL00800007E]`005KL
001Fg000D]`00P0000EBg000D]`005;L01T00003D]`005;L00800007D]`005;L001Bg000D]`00P00
00MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P00
00MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007D]`005;L001Bg000D_`00P00
00IBo000D_`005;l0002D_`2000025Kl001Fo000E_`005Kl0002E_`200002EKl001Fo000E_`005Kl
001Jo00500002U[l001Jo000F_`005[l001Jo0000U/L00@005/L001K70800003Ga`0000000800004
Ga`005lL0002Ga/20002Ga/01P00Ga/005lK001O6`<00004G_/005kk0002G_/02P00G_/005kk001N
n`00G_/005kk1@00011Nn`00G_]Nn`00G_/005kk001Nn`00G_/005kk001Nn`800003G_/00000009N
n`0>001Nn`00G_/005kk001Nn`00G_/005kk001Nn`<00008G_/005kkG_/005kk001Nn`80009Nf`06
001Nf`00G]/005kJ1@0001UJf`00F]X005[J001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X0
05[J001JfP0500000e[J001JfP020002F]X01P00F]X005[J001Jf`80000=F]/005Jk001F^`00E[/0
05Jk001F^`00E[/00P0000AF^`00E[]F^`800007E[/005Jk001F^`00E[/00P0000=F^`0000004000
00EF^`00E[/005:k00800009D[/005:k001B^`00D[/005:k00800009D[/005:k001B^`00D[/005:k
00800009D[/005:k001B^`00D[/005;K0080009Bg008001Bg000D]`005;L001Bg0800009D]`005;L
001Bg000D]`005;L00800009D]`005;L001Bg000D]`005;L0080000=D]`005;L001Bg000D]`005;L
001Bg000D]`00P0000UBg000E]`005KL001Fo000E_`00P0000EFo000E_`005Kl00T00008E_`005Kl
001Fo000E_`0009Fo080000;E_`005Kl001Fo000E_`005[l001Jo00200000e[l001Jo00600000e[l
001Jo0020002F_`02P00F_`005[l001Jo000F_`005[l0P0000=Jo000F_/01P0000EJn`00001Jn`00
009Jn`08001Jn`00F_/005[k001Jn`800006F_/005[kF_/005[k1P0000AJf`00F]/0009Jf`04001J
f`00F]/2000025[K001Jf`00F]/005[K0002F]/200000e[K0000000500000e[K001Jf`020002F]/0
2P00F]/005[K001Jf`00F]/005[K0P0000IJf`00F]/005[K0002F]/00`00F]/0000700000e[K001J
f`0200001U[K001Jf`00F]/0009J^P04001J^P00F[X200002EJj001F^P00E[X005Jj001F^P020000
2UJj001F^eJk001F^`00E[/005Jk2P0000=F^`00E[/00P0000IF^`00E[/005Jk0002E[/04@00E[/0
0000E[/005Jk001F^`00E[/005KK001Ff`00E]/00P0000YFf`00E]]Ff`00E]/005KK001Ff`P00005
E]/005KK001Ff`02000025KK001FfeKK001Ff`00E]/200005eKK001Ff`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/020003goo00<007ooOol06Woo00<007ooOol09Woo003@Ool0
0`00Oomoo`1JOol200001eKK001Ff`00E]/005KK00800007E]/005KK001Ff`00E]/00P0000MFg000
E]`005KL001Fg00@00002U;L000005;L001Bg000D]`005;L0P0000MBg000D]`005;L001Bg0020000
15;L001Bg0000U;L00/005;L000005;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P00
00MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P00
00MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;l00800006D_`005;l001Bo0000U;l0P00
00UFo000E_`005Kl001Fo000E_`00P0000=Fo000E_`01`0000AJo000F_`0009Jo00>001Jo000F_`0
05[l001Jo000Fa`005/L001K70<00004Fa`005/L0002Ga`03000Ga`005lK001O6`00Ga/005lK001O
6`<00007G_/005kkG_/005kk00000Ukk0P0000ENn`00G_/005kk0080000:G_/005kk001Nn`00G_/0
05kk0002G_/200000ekk001Nn`04000015kk001Nnekk0P0000QNn`00G_]Nn`00G_/005kk0P0000=N
n`0000000P0001=Nn`00G_/005kk001Nn`00G_/005kk001Nf`00G]/005kK001Nf`03000015[K001J
f`000U[K00H005[J000005[J0002F]X01000F]X000000U[J0P0000=JfP00F]X01@0001MJfP00F]X0
05[J001JfP00F]X005[J001JfP00F]X005[K001Jf`00F]/005Jk0080000;E[/005Jk001F^`00E[/0
05Jk001F^`0>00000eJk001F^`0200002EJk001F^`00E[/005Jk001F^`02000025Jk001F^eJk001F
^`00D[/200002E:k001B^`00D[/005:k001B^`0200002E:k001B^`00D[/005:k001B^`0200002E:k
001B^`00D[/005:k001Bf`0200002E;L001Bg000D]`005;L001Bg00200003E;L001Bg000D]`005;L
001Bg000D]`005;L00800009D]`005;L001Bg000D]`005;L00800009D]`005;L001Bg000D]`005;L
00800007D]`005KL001Fg000E_`02@0000MFo000E_`005Kl001Fo0020002E_`02P00E_`005Kl001F
o000E_`005Kl0P0000UFo000E_`005Kl001Jo000F_`01@0000IJo000F_`005[l0002F_`04@00F_`0
0000F_`005[l001Jo000F_`005[l001Jo000F_`00`0000IJo000F_/005[k0002F_/200003E[k001J
n`00F_/005[k001Jn`00F_/005[k00L0000AF_/005[k001Jn`00F]/005[K001Jf`00F]/005[K001J
f`020002F]/01000F]/005[K1P0000IJf`00F]/005[K0002F]/05`00F]/00000F]/005[K001Jf`00
F]/005[K001Jf`00F]/005[K001Jf`00F]/01P0001MJf`00F]/005[K001Jf`00F]/005[K001Jf`00
F]/005[K001J^P00F[X005Zj00800006E[X005Jj001F^P000UJj00D005Jj000005Jj00T0000;E[/0
0000E[/005Jk001F^`00E[/00002E[/200002eJk001F^`00E[/005Jk001F^`00E[/00P0000QF^`00
E[/005Jk001Ff`000UKK0P0000=Ff`00E]/02P0000QFf`00E]/005KK001Ff`000UKK0P0000UFf`00
E]/005KK001Ff`00E]/00P000UKK0P0000AFf`00E]/0009Ff`05001Ff`00001Ff`09000FOol00`00
Oomoo`0JOol00`00Oomoo`0VOol00=1oo`03001oogoo05Yoo`09001Ff`00001Ff`00E]/005KK0080
0003E]/0000000d0000:E]`00000E]`005KL001Fg000E]`2000015;L001Bg0000U;L0P0000MBg000
D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P0000MBg000
D]`005;L001Bg00200001U;L001Bg000D]`0009Bg0800007D]`005;L001Bg000D]`00P0000MBg000
D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P0000MBg000
D]`005;L001Bo00200001e;l001Bo000D_`005;l00800007E_`005Kl001Fo000E_`01`0000aFo000
E_`005Kl001Jo000F_`005[l0002F_`02@00F_`00000F_`005[l001K700400000e/L00000002Fa`0
0`00Fa`00002Ga`01`00Ga`00000Ga/005lK00@00006G_/005kk001Nn`000Ukk00@005kk001Nn`80
0003G_/0000000800006G_/005kkG_/005kk0P000Ukk00H005kk001Nn`00G_/3000015kk001Nn`00
0Ukk00`005kk001Nn`00G_/005kk001Nn`00G_/3000015kk001Nn`000Ukk0P0000QNn`00G_]Nn`00
G_/005kk0P0000=Nf`0000000P0000=Jf`0000000U[K010005[K001Jf`00F]X005[J001JfP00F]X0
05[J001JfPL00005F]X00000F]X00002F]X01P00F]X005[J001JfP80009JfP0?001JfP00001Jf`00
F]/005[K001F^`00E[/005Jk00800003E[/0000000D00007E[/005Jk001F^`00E[/00P0001=F^`00
E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`0200001eJk001F^`00E[/005:k00800009
D[/005:k001B^`00D[/005:k0080000=D[/005:k001B^`00D[/005:k001B^`00D[/00P0000UB^`00
D[/005;K001Bg000D]`00P0000UBg000D]`005;L001Bg000D]`00P0000UBg000D]`005;L001Bg000
D]`00P0000UBg000D]`005;L001Bg000D]`00P000U;L400000=Fo000E_`00P0000AFo000E_`0009F
o006001Fo000E_`005Kl0P0000]Fo000E_`005Kl001Fo000E_`005Kl00800003E_`005Kl00H00005
F_`00000F_`00002F_`02P00F_`005[l001Jo000F_`005[l0P0000AJo000F_aJo0P0000<F_`005[l
F_`005[k001Jn`00F_/005[k0P0000AJn`00F_/0009Jn`H00006F_/005[k001Jn`000U[k014005[k
000005[K001Jf`00F]/005[K001Jf`00F]/005[K00L00003F]/005[K0080009Jf`08001Jf`00F]/0
05[K001Jf`800006F]/005[K001Jf`000U[K00D005[K000005[K00L00003F]/005[K0080000:F]/0
05[KF]/005[K001Jf`00F]/200004e[K001Jf`00F]/005Zj001J^P00F[X005Jj001F^P00E[X005Jj
00P00009E[/005Jk001F^`00E[/005Jk0080009F^`08001F^`00E[/005Jk001F^`80000;E[/005Jk
001F^`00E[/005Jk001F^`020002E[/01P00E[/005Jk001Ff`P00007E]/005KK001Ff`00E]/00P00
0UKK00P005KK001Ff`00E]/005KK0P0001=Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK
001Ff`08000NOol00`00Oomoo`0JOol00`00Oomoo`0VOol00=5oo`03001oogoo05Yoo`/00007E]/0
05KK001Ff`00E]/00P0000IFf`00E]`005KL0002E]`200001eKL001Fg000E]`005KL00800007D]`0
05;L001Bg000D]`00P0000mBg000D]`005;L001Bg000D]`005;L001Bg000D]`00P0000MBg000D]`0
05;L001Bg00200001e;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P0000MBg000D]`0
05;L001Bg00200001e;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P0000MBg000D]`0
05;L001Bg00200001e;L001Bg000D]`005;l00800003D_`005;l00d00003E_`005Kl0080000DE_`0
05KlE_`005Kl001Fo000F_`005[l001Jo000F_`005[l001Jo0D00004F_`005[l0002Fa`20002Fa`0
2000Fa`005lL001O7000Ga/3000015kk001Nn`000Ukk0P000Ukk00H005kk001Nn`00G_/3000015kk
001Nn`000Ukk00`005kk001Nn`00G_/005kk001Nn`00G_/3000045kk001Nnekk001Nn`00G_/005kk
001Nn`00G_/005kk1@00019Nn`00G_]Nn`00G_/005kk001Nn`00G_/005kk001Nn`00G_/3000015kK
001Nf`000U[K0P0000AJf`00F]/0009Jf`800007F]X005[J001JfP00F]X00`0001eJfP00F]X005[J
001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X005[K00800003F]/00000
00L00003E[/005Jk00800004E[/005JkE[/20002E[/02`00E[/00000E[/005Jk001F^`00E[/00P00
00UF^`00E[/005Jk001F^`00E[/00P0000AF^`00E[]F^`800007D[/005:k001B^`00D[/00P0000UB
^`00D[/005:k001B^`00D[/00P0000MB^`00D[/005:k001B^`0200004E:k001B^`00D]/005;L001B
g000D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg00E00001e;L001Bg000D]`005;L0080
0006E]`005KL001Fo0000UKl014005Kl000005Kl001Fo000E_`005Kl001Fo000E_`005Kl00800007
E_`005Kl001Fo000E_`01`0000IFo000E_`005Kl0002F_`200003e[l001Jo000F_`005[l001Jo000
F_`005[l001Jo00500004e[l001Jo000F_`005[l001Jo000F_`005[k001Jn`00F_/005[k0080009J
n`D00003F_/005[k0080009Jn`0:001Jn`00F_/005[k001Jn`00F_/200001U[K001Jfe[K001Jf`H0
0006F]/005[K001Jf`000U[K00d005[K000005[K001Jf`00F]/005[K001Jf`020002F]/01000F]/0
05[K200000QJf`00F]/005[K001Jf`000U[K0P0000UJf`00F]/005[K001Jf`00F]/00P0000IJf`00
F]/005[K0002F[X01000F[X005Zj200000=F^P00E[X00P0000IF^P00E[/005Jk0002E[/03`00E[/0
0000E[/005Jk001F^`00E[/005Jk001F^`0200001UJk001F^`00E[/0009F^`05001F^`00001F^`09
00002EKK000005KK001Ff`00E]/00002E]/04@00E]/00000E]/005KK001Ff`00E]/005KK001Ff`00
E]/00P0000QFf`00E]]Ff`00E]/005KK2P009Woo00<007ooOol06Goo00<007ooOol09Woo003AOol0
0`00Oomoo`1JOol02@00E]/00000E]/005KK001Ff`020002E]/01P00E]/005KK001Ff`800009E]/0
05KL001Fg000E]`005KL00800004E]`005KL0002E]`200001E;L001Bg000D]`00P0000UBg000D]`0
05;L001Bg000D]`00P0000MBg000D]`005;L001Bg00200001E;L001Bg000D]`00P0000MBg000D]`0
05;L001Bg00200001e;L001Bg000D]`005;L03800005D_`005;l001Bo00200001UKl001Fo000E_`0
009Fo006001Fo000001Fo0000UKl00@005Kl001Fo0800005F_`005[l001Jo005000015[l001Jo000
0U[l00`005[l001K7000Fa`005/L001K7000Ga`500001ekk001Nnekk001Nn`00009Nn`800003G_/0
05kk00@00003G_/00000009Nn`03001Nn`00009Nn`07001Nn`00001Nn`00G_/0100000QNn`00G_/0
05kk001Nn`000Ukk0P000Ukk1@0001=Nn`00G_/005kk001Nn`00G_/005kk001Nn`00G_/005kk001N
n`05000025kK001NfekK001Nf`00F]/20002F]/01P00F]/005[K001JfP800003F]X0000000800003
F]X00000009JfP06001JfP00F]X005[J0P0000AJfP00F]YJfP80000;F]X005[J001JfP00F]X005[J
001JfP0500000e[K001F^`0200001UJk001F^`00E[/0009F^`800009E[/005Jk001F^`00E[/005Jk
0080000=E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000eF^`00E[/005Jk001F^`00E[/005Jk
001B^`0200002E:k001B^`00D[/005:k001B^`0200002E:k001B^`00D[/005:k001B^`0P00001E;L
001Bg000D]`00P0000UBg000D]`005;L001Bg000D]`00P0000YBg000D]aBg000D]`005;L001Bg080
000=E]`005KL001Fo000E_`005Kl001Fo000E_`00P0000]Fo000E_`005Kl001Fo000E_`005Kl00L0
0003E_`005Kl0080000>E_`005KlE_`005Kl001Fo000F_`005[l001Jo0800005F_`005[l001Jo007
000015[l001Jo0000U[l00H005[l001Jo000F_`200001U[l001Jn`00F_/0009Jn`H00004F_/005[k
0002F_/04@00F_/00000F_/005[k001Jn`00F_/005[k001Jn`00F]/01`0000=Jf`00F]/00P000U[K
00P005[K001Jf`00F]/005[K0P0000IJf`00F]/005[K0002F]/00`00F]/0000700001E[K001Jf`00
F]/00P000U[K00P005[K001Jf`00F]/005[K0P00015Jf`00F]/005[K001Jf`00F]/005[K001Jf`00
F]/005[K00P0000GE[X005Jj001F^P00E[X005Jj001F^P00E[X005Jk001F^`00E[/005Jk001F^`02
000025Jk001F^`00E[/005Jk0002E[/200001EJk001F^`00E[/0200001EFf`00E]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK001Ff`00E]/00P0000YFf`00E]/005KK001Ff`00E]/0009Ff`800003
E]/005KK00P002ioo`03001oogoo01Yoo`03001oogoo02Eoo`00dWoo00<007ooOol0FWoo00T005KK
000005KK001Ff`00E]/00P00015Ff`00E]/005KK001Ff`00E]/005KK001Fg000E]`005KL00800007
E]`005KL001Fg000E]`00P0000MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L0280000:
D]`00000D]`005;L001Bg000D]`200001e;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`0
0P0000MBg000D]`005;L001Bg00200001e;L001Bg000D_`005;l00800008D_`005;lD_`005;l001B
o0800006E_`005Kl001Fo0000UKl0P0000]Fo000E_`005Kl001Fo000E_`005[l00D0000:F_`005[l
001Jo000F_`005[l0002F_`01`00F_`00000Fa`005/L00@00008F_`005kl001Nn`00G_/0009Nn`04
001Nn`00G_/200001ekk000005kk001Nn`00009Nn`80009Nn`08001Nn`00G_/005kk001Nn`<00004
G_/005kk0002G_/20002G_/01P00G_/005kk001Nn`<00004G_/005kk0002G_/01000G_/000000Ukk
00@005kk0000009Nn`D0000EG_/005kK001Nf`00G]/005kK001Nf`00F]/005[K001Jf`00F]/005[K
00D0000KF]/005[K001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X005[J001JfP00F]X005[J
00P0000AF]/005[K001Jf`00E[/005Jk001F^`00E[/005Jk001F^`02000015Jk001F^eJk0P0000UF
^`00E[/005Jk001F^`00E[/00P0000eF^`00E[/005Jk001F^`00E[/005Jk001F^`0200001EJk001F
^`00E[/06@0000=B^`00D]/00P0000UBf`00D]/005;K001Bf`00D]`00P0000UBg000D]`005;L001B
g000D]`00P0000ABg000D]`0009Bg004001Bg000D]`200002E;L001Bg000D]`005;L001Bg0020000
3E;L001Bg000D]`005;L001Bg000E]`005KL00800009E_`005Kl001Fo000E_`005Kl00800003E_`0
000000T00006E_`005Kl001Fo0000UKl01<005Kl000005Kl001Fo000E_`005Kl001Jo000F_`005[l
001Jo00500004e[l001Jo000F_`005[l001Jo000F_`005[l001Jo000F_`005[l0080009Jo0L00005
F_/00000F_/00002F_/02000F_/005[k001Jn`00F_/2000015[k001Jn`000U[k1P0000IJf`00F]/0
05[K0002F]/03@00F]/00000F]/005[K001Jf`00F]/005[K0080009Jf`04001Jf`00F]/6000025[K
001Jf`00F]/005[K0002F]/03@00F]/00000F]/005[K001Jf`00F]/005[K0080000:F]/005[KF]/0
05[K001Jf`00F]/800001EZk001F^`00E[X00P0000YF^P00E[YF^P00E[X005Jj001F^P80000;E[X0
05Jk001F^`00E[/005Jk001F^`020002E[/01P00E[/005Jk001F^`X00003E[/005Jk00800004E]/0
05KK0002E]/01000E]/005KK0P0000eFf`00E]/005KK001Ff`00E]/005KK001Ff`020002E]/01P00
E]/005KK001Ff`P003Eoo`03001oogoo01Yoo`03001oogoo02Eoo`00dWoo00<007ooOol0FWoo00@0
05KK001Ff`800004E]/005KKE]/200001eKK001Ff`00E]/005KK00800009E]/005KL001Fg000E]`0
05KL00800005E]`005KL001Fg00B00002U;L000005;L001Bg000D]`005;L0P0000EBg000D]`005;L
00800007D]`005;L001Bg000D]`00P0000IBg000D]`005;L0002D]`200001e;L001Bg000D]`005;L
00800007D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L
00800007D]`005;L001Bo000D_`00P0000QBo000D_aBo000D_`005;l0P0000MFo000E_`005Kl001F
o00200000eKl001Fo009000015[l001Jo0000U[l00h005[l001Jo000F_`005[l001Jo000F_`005/L
0`0000AJo000F_`0009Jo00<001No000G_/005kk001Nn`00G_/005kk0`00011Nn`00G_]Nn`00G_/0
05kk001Nn`00G_/005kk001Nn`D0000@G_/005kkG_/005kk001Nn`00G_/005kk001Nn`00G_/30000
4Ukk001Nnekk001Nn`00G_/005kk001Nn`00G_/005kk001Nn`<00004G_/005kk0002G_/01P00G]/0
0000G]/0009Nf`80009Jf`800003F]/0000000800005F]/00000F]/00002F]/01000F]/005[J0P00
0U[J00d005[J000005[J001JfP00F]X005[J001JfP0500003e[J001Jf`00F]/005[K001Jf`00F]/0
05[K001F^`0200003EJk001F^`00E[/005Jk001F^`00E[/005Jk0080009F^`0;001F^`00001F^`00
E[/005Jk001F^`0C00001eJk001F^`00E[/005Jk00800009D[/005:k001B^`00D[/005:k00800004
D[/005:k0002D[/03@00D]/00000D]/005;K001Bf`00D]/005;L00800009D]`005;L001Bg000D]`0
05;L00800009D]`005;L001Bg000D]`005;L0080009Bg0800009D]`005;L001Bg000D]`005;L0080
0009D]`005;L001Bg000E]`005KL00800003E_`005Kl00T0000IE_`005Kl001Fo000E_`005Kl001F
o000E_`005Kl001Fo000E_`005Kl001Fo000E_`00P0000EFo000E_`005[l00L00004F_`005[l0002
F_`01P00F_`005[l001Jo0800009F_`005[l001Jo000F_`005[l00D00006F_`005[k001Jn`000U[k
0P0000mJn`00F_/005[k001Jn`00F_/005[k001Jn`00F_/01@0000=Jf`00F]/00P000U[K00P005[K
001Jf`00F]/005[K0P0000IJf`00F]/005[K0002F]/00`00F]/0000700000e[K001Jf`020002F]/0
2P00F]/005[K001Jf`00F]/005[K0P0000QJf`00F]/005[K001Jf`000U[K0P0000=Jf`0000002000
00QJf`00F[/005Zk001J^`000UJk0P0000]F^P00E[X005Jj001F^P00E[X005Jj00800006E[X005Jk
001F^`000UJk00D005Jk000005Jk00T0000;E[/00000E[/005Jk001F^`00E[/00002E[/200002eKK
001Ff`00E]/005KK001Ff`00E]/00P0000IFf`00E]/005KK0002E]/01@00E]/00000E]/02@00?7oo
00<007ooOol06Woo00<007ooOol09Goo003COol00`00Oomoo`1JOol02`00E]/00000E]/005KK001F
f`00E]/00P0000UFf`00E]/005KK001Ff`00E]/03P0000YFg000001Fg000E]`005;L001Bg0800006
D]`005;L001Bg0000U;L0P0000MBg000D]`005;L001Bg00200001E;L001Bg000D]`00P0000MBg000
D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P0000ABg000
D]`0009Bg00;001Bg000001Bg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007D]`0
05;L001Bo000D_`00P0000MBo000D_`005;l001Bo00200001EKl001Fo000E_`01`0000iFo000E_`0
05Kl001Fo000E_`005[l001Jo0000U[l00L005[l000005[l001Jo00700001e[l001Jo5[l001Jo000
009Jo0800005G_/005kk001Nn`0400000ekk00000002G_/00`00G_/00002G_/200000ekk001Nn`04
000025kk001Nn`00G_/005kk0002G_/01`00G_/00000G_/005kk00@00003G_/00000009Nn`0<001N
n`00G_/005kk001Nn`00G_/005kk1@00019Nn`00G_]Nn`00G_/005kk001Nf`00G]/005kK001Nf`00
G]/500006E[K001Jf`00F]/005[K001Jf`00F]/005[K001JfP00F]X005[J001JfP00F]X005[J00P0
0006F]X005[J001JfP000U[K014005[K000005[K001Jf`00F]/005Jk001F^`00E[/005Jk0080009F
^`800005E[/005Jk001F^`0>00001EJk001F^`00E[/00P0001=F^`00E[/005Jk001F^`00E[/005Jk
001F^`00E[/005Jk001F^`0200002E:k001B^`00D[/005:k001B^`0200001e:k001B^`00D[/005;K
00800009D]/005;K001Bf`00D]/005;L00800004D]`005;LD]`200001e;L001Bg000D]`005;L0080
0009D]`005;L001Bg000D]`005;L0080000;D]`005;L001Bg000D]`005;L001Bg00>00001eKl001F
o000E_`005Kl0080009Fo00<001Fo000E_`005Kl001Fo000E_`005Kl0P0000UFo000E_`005Kl001F
o000E_`01`0001=Fo000E_`005[l001Jo000F_`005[l001Jo000F_`005[l001Jo00200000e[l001J
o00600001E[l000005[l00000U[l00P005[k001Jn`00F_/005[k0P0000AJn`00F_/0009Jn`03001J
n`0000D00004F_/005[k0002F]/03@00F]/00000F]/005[K001Jf`00F]/005[K0080009Jf`04001J
f`00F]/600001U[K001Jf`00F]/0009Jf`0?001Jf`00001Jf`00F]/005[K001Jf`00F]/005[K0080
009Jf`06001Jf`00F]/005[K1P0000MJf`00F]/005[K001Jf`020002F]/02000F[/005Zk001J^`00
E[/200004eJj001F^P00E[X005Jj001F^P00E[X005Jj001F^P00E[/005Jk00P00009E[/005Jk001F
^`00E[/005Jk0080009F^`08001F^`00E[/005Jk001F^`80000CE]/005KK001Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/02000AGoo00<007ooOol06Goo00<007ooOol09Goo003DOol00`00Oomo
o`1IOol01000E]/005KK0P0000=Ff`00E]/03P0000MFf`00E]`005KL001Fg002000015KL001Fg000
0UKL0P0000MFg000E]`005;L001Bg00200001e;L001Bg000D]`005;L00800006D]`005;L001Bg000
0U;L0P0000EBg000D]`005;L00800007D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg002
00001e;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg002
00001e;L001Bg000D]`005;L00800007D]`005;L001Bo000D_`00P0000=Bo00000002`0000=Fo000
E_`00P0001IFo000E_aFo000E_`005Kl001Fo000E_`005[l001Jo000F_`005[l001Jo0<0000:F_`0
05[l001Jo000F_`005[l0002F_`01000F_`005[l0P0000=Nn`0000000P0000ANn`00G_/0009Nn`80
009Nn`06001Nn`00G_/005kk0`0000ANn`00G_/0009Nn`04001Nn`000002G_/01P00G_/005kk001N
n`<00004G_/005kk0002G_/200002Ukk001Nnekk001Nn`00G_/005kk0`0001ENn`00G_/005kk001N
n`00G_/005kk001Nn`00G]/005kK001Nf`00G]/00`0000AJf`00F]/0009Jf`04001Jf`00F]/20000
15[K001Jfe[K0P0000MJfP00F]X005[J001JfP0500005e[J001JfP00F]X005[J001JfP00F]X005[J
001Jf`00F]/005[K001Jf`00F]/00P0000UF^`00E[/005Jk001F^`00E[/02P0000UF^`00E[/005Jk
001F^`00E[/00P0000IF^`00E[/005Jk0002E[/200002EJk001F^`00E[/005Jk001F^`0200001eJk
001F^`00E[/005Jk00800009D[/005:k001B^`00D[/005:k0080009B^`800009D[/005;K001Bf`00
D]/005;K00800009D]/005;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P000U;L00@0
05;L001Bg0800003D]`0000000`00009E]`005KL001Fg000E]`005KL0080000:E_`005KlE_`005Kl
001Fo000E_`20002E_`200002EKl001Fo000E_`005Kl001Fo00200000eKl001Fo00600001eKl0000
05Kl001Fo000009Fo006001Fo000F_`005[l0P0000UJo000F_`005[l001Jo000F_`01@0000IJo000
F_`005[l0002F_`200002e[l001Jo000F_/005[k001Jn`00F_/00P000U[k1`0000EJn`00001Jn`00
009Jn`06001Jn`00F]/005[K0P0000IJf`00F]/005[K0002F]/00`00F]/0000700000e[K001Jf`02
0002F]/02000F]/005[K001Jf`00F]/2000025[K001Jf`00F]/005[K0002F]/00`00F]/000090000
2E[K000005[K001Jf`00F]/00002F]/03`00F]/00000F]/005Zk001J^`00F[/005Jk001F^P020000
2UJj001F^UJj001F^P00E[X005Jj200000=F^`00E[/00P0000IF^`00E[/005Jk0002E[/03`00E[/0
0000E[/005Jk001F^`00E[/005Jk001F^`02000015KK001Ff`000UKK00@005KK001Ff`X004aoo`03
001oogoo01Uoo`03001oogoo02Eoo`00e7oo00<007ooOol0FWoo200000=Ff`00E]/00P00015Ff`00
E]/005KK001Ff`00E]/005KK001Fg000E]`005KL00800007E]`005KL001Fg000E]`00P0000AFg000
D]`0009Bg0800007D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg00200001e;L001Bg000
D]`005;L00800005D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007D]`005;L001Bg000
D]`00P0000EBg000D]`005;L02000007D_`005;l001Bo000D_`00P0000AFo000E_`0009Fo006001F
o000001Fo0000UKl00@005Kl001Fo0800005E_`005[l001Jo00700004U[l001Jo5[l001Jo000F_`0
05[l001Jo000F_`005[l001Jo0<00004F_`005kk0002G_/03000G_/005kk001Nn`00G_/005kk001N
n`<0000@G_/005kkG_/005kk001Nn`00G_/005kk001Nn`00G_/500004Ukk001Nnekk001Nn`00G_/0
05kk001Nn`00G_/005kk001Nn`<00006G_/005kkG_/005kk0P0000YNn`00G_]Nn`00G_/005kk001N
f`D00003F]/00000009Jf`0B001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/005[J1@0000EJ
f`00001JfP00009JfP04001JfP00F]X200004e[J001JfP00F]X005[K001Jf`00F]/005[K001Jf`00
F]/005Jk00P00007E[/005Jk001F^`00E[/00P000UJk00P005Jk001F^`00E[/005Jk0P0000MF^`00
E[/005Jk001F^`0200003EJk001F^`00E[/005Jk001F^`00E[/005Jk00800009E[/005Jk001B^`00
D[/005:k00800007D[/005:k001B^`00D[/00P000U:k00d005;K000005;K001Bf`00D]/005;K001B
g00200000e;L001Bg00D000035;L000005;L001Bg000D]`005;L001Fg080009Fg008001Fg000E]`0
05KL001Fg080000=E_`005Kl001Fo000E_`005Kl001Fo000E_`00P0000MFo000E_`005Kl001Fo007
00001UKl001Fo000E_`0009Fo080000;E_`005Kl001Fo000E_`005[l001Jo00200000e[l001Jo006
00001E[l000005[l00000U[l00P005[l001Jo000F_`005[l0P0000IJo000F_/005[k0002F_/60000
1U[k001Jn`00F_/0009Jn`800009F_/005[k001Jn`00F]/005[K0080009Jf`03001Jf`0000L00006
F]/005[K001Jf`000U[K01L005[K000005[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/0
05[K00H0000EF]/005[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/005[K00800008F]/0
05Zk001J^`00F[/0009F^`800003E[X005Jj00X0000GE[X005Jj001F^`00E[/005Jk001F^`00E[/0
05Jk001F^`00E[/005Jk001F^`02000025Jk001F^`00E[/005Jk0002E[/200000eKK001Ff`08001D
Ool00`00Oomoo`0IOol00`00Oomoo`0UOol00=Eoo`03001oogoo05Uoo`04001Ff`00E]/200001UKK
001FfeKK001Ff`800009E]/005KK001Ff`00E]/005KK00800004E]`005KL0002E]`200001EKL001F
g000E]`00P0000UFg000E]`005;L001Bg000D]`00P0000EBg000D]`005;L00800007D]`005;L001B
g000D]`0:@0000=Bg000D]`00P0000MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L0080
0007D]`005;l001Bo000D_`00P000U;l00H005;l001Bo000D_`2000015Kl001Fo0000UKl00d005Kl
000005Kl001Fo000E_`005Kl001Fo00500002U[l001Jo000F_`005[l001Jo0000U[l00@005[l001J
o0800003F_`005[l00@00003F_`00000009Jo003001Nn`00009Nn`07001Nn`00001Nn`00G_/01000
00=Nn`0000000Ukk00<005kk00000Ukk0P0000ENn`00G_/005kk0080000:G_/005kk001Nn`00G_/0
05kk0002G_/200001Ekk001Nn`00G_/01@00019Nn`00G_]Nn`00G_/005kk001Nn`00G_/005kk001N
n`00G_/3000015[K001Jf`000U[K0P0000AJf`00F]/0009Jf`800007F]/005[K001Jf`00F]/01@00
01EJf`00F]/005[K001Jf`00F]X005[J001JfP00F]X005[J001JfP00F]X00P000U[K00D005[K0000
05[K00L00005E[/005Jk001F^`020002E[/01P00E[/005Jk001F^`800009E[/005Jk001F^`00E[/0
05Jk0080000=E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000eF^`00E[/005Jk001F^`00E[/0
05Jk001F^`0200002E:k001B^`00D[/005:k001B^`0200000e:k0000000D00002U;L000005;L001B
g000D]`005;L0P0000QBg000D]`005;L001Bg0000U;L0P0000UBg000D]`005;L001Bg000E]`00P00
00eFg000E]`005KL001Fg000E]`005Kl001Fo00200002EKl001Fo000E_`005Kl001Fo00900000eKl
001Fo002000035Kl001Fo5Kl001Fo000E_`005Kl001Fo0800009E_`005Kl001Fo000F_`005[l00D0
0006F_`005[l001Jo0000U[l0P0000]Jo000F_`005[l001Jo000F_`005[l0080009Jo0L00005F_/0
0000F_/00002F_/01P00F_/005[k001Jn`800006F_/005[k001Jn`000U[K00<005[K00001@00015J
f`00F]/005[K001Jf`00F]/005[K001Jf`00F]/005[K00800006F]/005[K001Jf`000U[K00D005[K
000005[K00L00003F]/005[K0080000:F]/005[KF]/005[K001Jf`00F]/200002E[K001Jf`00F]/0
05[K001Jf`020002F]/01P00F[/005Zk001J^`P00007E[X005Jj001F^P00E[X00P0000YF^P00E[YF
^P00E[/005Jk001F^`80000;E[/005Jk001F^`00E[/005Jk001F^`020002E[/01P00E[/005Jk001F
^`P005aoo`03001oogoo01Qoo`03001oogoo02Eoo`00eGoo00<007ooOol0FWoo00@005KK001Ff`80
0007E]/005KK001Ff`00E]/00P000UKK00@005KK001Ff`800007E]/005KL001Fg000E]`00P0000MF
g000E]`005KL001Fg00200001EKL001Bg000D]`04P0000YBg000001Bg000D]`005;L001Bg0800005
D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P0000ABg000
D]`0009Bg00;001Bg000001Bg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007D]`0
05;l001Bo000D_`00P000U;l00H005;l001Bo000D_`200001eKl001Fo000E_`005Kl00800003E_`0
000000L00004E_`005[l0002F_`03P00F_`005[l001Jo000F_`005[l001Jo000F_`5000015[l001J
o0000U[l0P000U[l00P005kk001Nn`00G_/005kk0`0000ANn`00G_/0009Nn`80009Nn`06001Nn`00
G_/005kk1@0000INn`00G_]Nn`00G_/20002G_/01P00G_/005kk001Nn`D0000:G_/005kk001Nn`00
G_/005kk0002G_/200001Ekk001Nn`00G_/01@0000QJf`00F]]Jf`00F]/005[K0P000U[K00P005[K
001Jf`00F]/005[K1@0000EJf`00001Jf`00009Jf`04001Jf`00F]/2000015[J001JfU[J0P0000UJ
fP00F]X005[J001JfP00F]X01`0000=Jf`00F]/00P0000AF^`00E[/0009F^`0;001F^`00001F^`00
E[/005Jk001F^`020002E[/02`00E[/00000E[/005Jk001F^`00E[/00P0000AF^`00E[]F^`800009
E[/005Jk001F^`00E[/005Jk00800003E[/000000180000<E]/00000D]/005;K001Bf`00D]/005;K
0P0000QBf`00D]/005;L001Bg0000U;L0P0000MBg000D]`005;L001Bg00200002E;L001Bg000D]`0
05;L001Bg0020002D]`200002E;L001Bg000E]`005KL001Fg00200002eKL001Fg000E]`005Kl001F
o000E_`02@0000UFo000001Fo000E_`005Kl00000UKl00l005Kl000005Kl001Fo000E_`005Kl001F
o000E_`00P0000=Fo000E_`01P0000EJo000001Jo000009Jo008001Jo000F_`005[l001Jo0800006
F_`005[l001Jo0000U[l1P0000IJo000F_/005[k0002F_/200002E[k001Jn`00F_/005[k001Jn`02
000015[k001Jne[k200000AJf`00F]/0009Jf`04001Jf`00F]/200004E[K001Jf`00F]/005[K001J
f`00F]/005[K001Jf`00F]/0200000IJf`00F]/005[K0002F]/03@00F]/00000F]/005[K001Jf`00
F]/005[K00800006F]/005[K001Jf`000U[K00<005[K00002@0000]F^`00001F^`00E[X005Jj001F
^P00009F^P0=001F^P00001F^P00E[X005Jk001F^`00E[/00P0000IF^`00E[/005Jk0002E[/01@00
E[/00000E[/02@00Hgoo00<007ooOol067oo00<007ooOol09Goo003FOol00`00Oomoo`1IOol00`00
E]/00002E]/200001EKK001Ff`00E]/00P0000UFf`00E]/005KK001Ff`00E]/00P0000EFg000E]`0
05KL01000003E]`005;L00800005D]`005;L001Bg00200001U;L001Bg000D]`0009Bg0800007D]`0
05;L001Bg000D]`00P0000EBg000D]`005;L00800007D]`005;L001Bg000D]`00P0000MBg000D]`0
05;L001Bg00200004E;L001Bg000D]`005;L001Bg000D]`005;L001Bg000D]`00P0000MBg000D]`0
05;L001Bg00200001e;L001Bo000D_`005;l00800007D_`005;l001Bo000D_`00P0000=Fo0000000
1`0000iFo000E_`005Kl001Fo000E_`005Kl001Jo0000U[l00T005[l000005[l001Jo000F_`01000
00EJo000001Jo000009Jo00<001Jo000F_`005[l001Jo000G_/005kk1@00011Nn`00G_]Nn`00G_/0
05kk001Nn`00G_/005kk001Nn`<00004G_/005kk0002G_/03000G_/005kk001Nn`00G_/005kk001N
n`<00004G_/005kk0002G_/01000G_/000000Ukk00H005kk001Nn`00G_/500005E[k001Jn`00F]/0
05[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`05000015[K001Jf`000U[K0P00015Jf`00F]/0
05[K001Jf`00F]/005[J001JfP00F]X005[J00800003F]X0000000<00008F]/005[K001Jf`00F]/0
009Jf`800007E[/005Jk001F^`00E[/00P000UJk014005Jk000005Jk001F^`00E[/005Jk001F^`00
E[/005Jk00800005E[/005Jk001F^`0@000035Jk000005Jk001F^`00E[/005Jk001F^`800006E[/0
05Jk001Ff`000UKK0P0000UBf`00D]/005;K001Bf`00D]/00P0000UBf`00D]/005;L001Bg000D]`0
0P0000]Bg000D]`005;L001Bg000D]`005;L00800009D]`005;L001Bg000D]`005;L0080000;D]`0
05;L001Fg000E]`005KL001Fg00<000025Kl001Fo000E_`005Kl0002E_`200002eKl001Fo000E_`0
05Kl001Fo000E_`00P0000MFo000E_`005Kl001Fo00700001UKl001Fo000E_`0009Jo080000;F_`0
05[l001Jo000F_`005[l001Jo0020002F_`700001E[l000005[l00000U[l00H005[k001Jn`00F_/2
000025[k001Jn`00F_/005[k0002F_/600004e[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00
F]/005[K00800004F]/005[K0002F]/01@00F]/00000F]/01@0000EJf`00F]/005[K0080009Jf`08
001Jf`00F]/005[K001Jf`80000AF]/005[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`060000
2EJk001F^`00E[/005Jk001F^`020002E[/02P00E[X005Jj001F^P00E[X005Jj0P00015F^P00E[X0
05Jk001F^`00E[/005Jk001F^`00E[/005Jk00P006]oo`03001oogoo01Qoo`03001oogoo02Eoo`00
egoo00<007ooOol0FGoo00H005KK001Ff`00E]/200001EKK001Ff`00E]/00P0000=Ff`0000002`00
00YFg000001Fg000E]`005KL001Fg0800004E]`005KL0002E]`02@00D]`00000D]`005;L001Bg002
00001e;L001Bg000D]`005;L00800006D]`005;L001Bg0000U;L0P0000EBg000D]`005;L00800007
D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800007
D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg00200002E;L001Bo000D_`005;l001Bo00:
00001eKl001Fo000E_`005Kl0080009Fo00B001Fo000E_`005Kl001Fo000E_`005[l001Jo000F_`0
05[l1@0000AJo000F_`0009Jo0800006F_`005[lF_`005[l0P0000=Jo000F_`0100000QJn`00G_/0
05kk001Nn`000Ukk00L005kk000005kk001Nn`0400000ekk00000002G_/00`00G_/00002G_/20000
1Ekk001Nn`00G_/0100000=Nn`0000000Ukk00h005kk001Nn`00G_/005kk001Nn`00G_/005kk0`00
00ANn`00G_/0009Jn`06001Jn`00001Jf`000U[K0P000U[K0P0000=Jf`0000000P0000EJf`00001J
f`00009Jf`04001Jf`00F]/2000015[K001Jfe[K0P0000UJf`00F]/005[J001JfP00F]X01@0000=J
f`00F]/00P000U[K00P005[K001Jf`00F]/005[K0P00015F^`00E[/005Jk001F^`00E[/005Jk001F
^`00E[/005Jk00800005E[/005Jk001F^`0<00001eJk001F^`00E[/005Jk00800006E[/005Jk001F
^`000UJk0P0000UF^`00E[/005Jk001F^`00E[/00P0000MF^`00E[/005KK001Ff`0200003E;K001B
f`00D]/005;K001Bf`00D]/005;K00800009D]`005;L001Bg000D]`005;L00800007D]`005;L001B
g000D]`00P0000ABg000D]`0009Bg0800003D]`0000000`0000GE]`005Kl001Fo000E_`005Kl001F
o000E_`005Kl001Fo000E_`005Kl001Fo00200002EKl001Fo000E_`005Kl001Fo00200000eKl0000
000400000eKl001Fo002000035Kl001Fo5Kl001Fo000E_`005[l001Jo0800006F_`005[l001Jo000
0U[l1P0000IJo000F_`005[l0002F_`200002E[l001Jo000F_/005[k001Jn`02000015[k001Jne[k
200000AJf`00F]/0009Jf`04001Jf`00F]/200003e[K001Jf`00F]/005[K001Jf`00F]/005[K001J
f`0:000015[K001Jf`000U[K00@005[K001Jf`800009F]/005[K001Jf`00F]/005[K0080000:F]/0
05[KF]/005[K001Jf`00F]/800000eKK001Ff`02000015Jk001F^`000UJk00@005Jk001F^`80000;
E[/005Jj001F^P00E[X005Jj001F^P0200002UJj001F^UJj001F^`00E[/005Jk2000Lgoo00<007oo
Ool05goo00<007ooOol09Goo003GOol00`00Oomoo`1IOol01000E]/005KK300000MFf`00E]/005KK
001Ff`02000015KK001Fg0000UKL0P0000MFg000E]`005KL001Fg00200001eKL001Fg000E]`005;L
00800006D]`005;LD]`005;L0P0000MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L0080
0007D]`005;L001Bg000D]`00P0000EBg000D]`005;L00800007D]`005;L001Bg000D]`00P0000UB
g000D]`005;L001Bg000D]`0700000MBo000D_`005;l001Fo0020002E_`01P00E_`005Kl001Fo080
009Fo006001Fo000E_`005Kl0P0000=Fo000F_`01`0000AJo000F_`0009Jo00>001Jo000F_`005[l
001Jo000F_`005[l001Jo0<00004F_`005[l0002F_/03000G_/005kk001Nn`00G_/005kk001Nn`<0
0004G_/005kk0002G_/20002G_/01P00G_/005kk001Nn`D00004G_/005kk0002G_/200001Ukk001N
nekk001Nn`800003G_/005kk00@00003G_/00000009Nn`0>001Nn`00F_/005[k001Jf`00F]/005[K
001Jf`D0000IF]/005[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/0
200000IJf`00F]/005[K0002F]/200003E[K001Jf`00F]/005[K001Jf`00E]/005Jk0080009F^`09
001F^`00001F^`00E[/005Jk00X00007E[/005Jk001F^`00E[/00P0000YF^`00E[]F^`00E[/005Jk
001F^`800007E[/005Jk001F^`00E[/00P0000UF^`00E[/005Jk001F^`00E[/00P0000]F^`00E[/0
05KK001Ff`00D]/005;K00800009D]/005;K001Bf`00D]/005;K00800004D]`005;L0002D]`20000
1E;L001Bg000D]`0400001YFg000001Fg000E]`005KL001Fg000E]`005KL001Fg000E_`005Kl001F
o000E_`005Kl0P0000UFo000E_`005Kl001Fo000E_`00P0000=Fo000E_`02@0000IFo000E_`005Kl
0002E_`03`00E_`00000E_`005Kl001Fo000E_`005[l001Jo0020002F_`700001E[l000005[l0000
0U[l00P005[l001Jo000F_`005[l0P0000IJo000F_/005[k0002F_/600004e[k001Jn`00F_/005[k
001Jf`00F]/005[K001Jf`00F]/005[K00800008F]/005[KF]/005[K001Jf`H0000CF]/005[K001J
f`00F]/005[K001Jf`00F]/005[K001Jf`00F]/00P0000IJf`00F]/005[K0002F]/01@00F]/00000
F]/02P0000QFf`00E]/005KK001Ff`000UKK0P0000UF^`00E[/005Jk001F^`00E[/00P0000QF^`00
E[X005Jj001F^P000UJj00D005Jj000005Jj00T007Yoo`03001oogoo01Moo`03001oogoo02Eoo`00
f7oo00<007ooOol0FGoo0`0000=Ff`00E]/00P0000EFf`00E]/005KK0080009Ff`06001Ff`00E]/0
05KK0P0000MFf`00E]`005KL001Fg00200001UKL001Fg5KL001Fg0800007E]`005KL001Fg000D]`0
0P0000MBg000D]`005;L001Bg00200001E;L001Bg000D]`00P0000MBg000D]`005;L001Bg00U0000
1e;L001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P00015Bo000D_`005;l001Bo000D_`0
05;l001Bo000D_`005Kl0080009Fo006001Fo000E_`005Kl0P0000MFo000E_`005Kl001Fo0050000
35[l001Jo000F_`005[l001Jo000F_`0009Jo007001Jo000001Jo000F_`01`0000MJo000F_aJo000
F_`00002F_/200001Ekk001Nn`00G_/01@00011Nn`00G_]Nn`00G_/005kk001Nn`00G_/005kk001N
n`<00004G_/005kk0002G_/03P00G_/005kk001Nn`00G_/005kk001Nn`00G_/3000015kk001Nn`00
0Ukk0P0000ANn`00G_]Nn`800007F_/005[K001Jf`00F]/00`0000AJf`00F]/0009Jf`04001Jf`00
F]/2000015[K001Jfe[K0P000U[K0P0000=Jf`00F]/01@0000mJf`00F]/005[K001Jf`00F]/005[K
001Jf`00F]/00P000U[K00H005[K000005[K0002F]/200000eJk001F^`0<00004EJk001F^`00E[/0
05Jk001F^`00E[/005Jk001F^`00E[/00P0000UF^`00E[/005Jk001F^`00E[/00P0000eF^`00E[/0
05Jk001F^`00E[/005Jk001F^`0200001eJk001F^`00E[/005Jk00800004E]/005KKE]/200002E;K
001Bf`00D]/005;K001Bf`0C00001EKL001Fg000E]`00P0000QFg000E]`005KL001Fg0000UKL0P00
00UFg000E]`005KL001Fg000E]`00P000UKL0P0000MFo000E_`005Kl001Fo00200001eKl001Fo000
E_`005Kl00L00007E_`005Kl001Fo000E_`00P000UKl00X005Kl001Fo000E_`005Kl001Fo0800007
E_`005Kl001Fo000F_`01`0000IJo000F_`005[l0002F_`200002e[l001Jo000F_`005[l001Jo000
F_`00P000U[l200000AJn`00F_/0009Jn`04001Jn`00F_/200003E[K001Jf`00F]/005[K001Jf`00
F]/005[K00T00005F]/00000F]/00002F]/01P00F]/005[K001Jf`800009F]/005[K001Jf`00F]/0
05[K0080009Jf`04001Jf`00F]/800001e[K001Jf`00F]/005[K0080009Ff`08001Ff`00E]/005KK
001Ff`800009E[/005Jk001F^`00E[/005Jk0080009F^`06001F^P00E[X005Jj2000PWoo00<007oo
Ool05goo00<007ooOol09Goo003HOol00`00Oomoo`1IOol00`00E]/00002E]/02@00E]/00000E]/0
05KK001Ff`0200003eKK001Ff`00E]/005KK001Ff`00E]/005KL001Fg00200001eKL001Fg000E]`0
05KL00800007E]`005KL001Fg000D]`00P0000=Bg000D]`0500000YBg000001Bg000D]`005;L001B
g0800005D]`005;L001Bg00200001e;L001Bg000D]`005;L0080000AD]`005;L001Bg000D]`005;L
001Bg000D]`005;L001Bg00200001e;L001Bg000D]`005;L0080000AD_`005;l001Bo000D_`005;l
001Bo000D_`005;l001Fo00200002EKl001Fo000E_`005Kl001Fo00700001EKl000005Kl00000U[l
010005[l001Jo000F_`005[l001Jo000F_`005[l001Jo0<0000:F_`005[l001Jo000F_`005[l0002
F_`01000F_`005[k0P0000=Nn`0000000P0000QNn`00G_/005kk001Nn`000Ukk00L005kk000005kk
001Nn`0400000ekk00000002G_/03P00G_/005kk001Nn`00G_/005kk001Nn`00G_/500004Ukk001N
nekk001Nn`00G_/005kk001Nn`00G_/005[k001Jn`D00003F]/00000009Jf`0@001Jf`00F]/005[K
001Jf`00F]/005[K001Jf`00F]/700001E[K000005[K00000U[K00@005[K001Jf`80000AF]/005[K
001Jf`00F]/005[K001Jf`00F]/005[K001Jf`0800004eJk001F^`00E[/005Jk001F^`00E[/005Jk
001F^`00E[/005Jk00800007E[/005Jk001F^`00E[/00P0000AF^`00E[]F^`800007E[/005Jk001F
^`00E[/00P0000AF^`00E[]F^`800009E[/005Jk001F^`00E[/005Jk00800003E[/005Jk01000003
E]/005KK00800009E]/005KL001Fg000E]`005KL00800008E]`005KLE]`005KL001Fg0800009E]`0
05KL001Fg000E]`005KL0080009Fg0800009E]`005KL001Fg000E]`005KL00800007E_`005Kl001F
o000E_`02@0000=Fo000E_`00P0000YFo000E_aFo000E_`005Kl001Fo080000;E_`005Kl001Fo000
E_`005Kl001Fo00200000eKl0000000400000eKl001Fo002000035[l001Jo5[l001Jo000F_`005[l
001Jo0800006F_`005[l001Jo0000U[l1P0001=Jo000F_/005[k001Jn`00F_/005[k001Jn`00F_/0
05[k001Jn`0200001U[K001Jfe[K001Jf`H00008F]/005[K001Jf`00F]/0009Jf`800009F]/005[K
001Jf`00F]/005[K00800004F]/005[K0002F]/01000F]/005[K200000=Jf`00F]/00P0000AJf`00
F]/0009Jf`04001Jf`00F]/200002EKK001Ff`00E]/005KK001Ff`02000015Jk001F^`000UJk00@0
05Jk001F^`X008Uoo`03001oogoo01Moo`03001oogoo02Eoo`00fGoo00<007ooOol0FGoo00H005KK
001Ff`00E]/200001UKK001FfeKK001Ff`800007E]/005KK001Ff`00E]/00P0000MFf`00E]`005KL
001Fg00200000eKL001Fg00@00001E;L001Bg000D]`00P0000EBg000D]`005;L00800006D]`005;L
001Bg0000U;L0P0000MBg000D]`005;L001Bg00200001E;L001Bg000D]`00P0000MBg000D]`005;L
001Bg00200001e;L001Bg000D]`005;L0080009Bg006001Bg000D]`005;L0P0000MBg000D]`005;L
001Bg00200001e;l001Bo000D_`005;l00800009D_`005;l001Bo000E_`005Kl00X00006E_`005Kl
001Fo0000UKl0P0000QFo000F_aJo000F_`005[l0P0000EJo000F_`005[l00D0000BF_`005[lF_`0
05[l001Jo000F_`005[l001Jo000F_`005[k0`0000AJn`00F_/0009Nn`0<001Nn`00G_/005kk001N
n`00G_/005kk0`0000ANn`00G_/0009Nn`800006G_/005kkG_/005kk0P000Ukk1@0001=Nn`00G_/0
05kk001Nn`00G_/005kk001Nn`00G_/005kk001Nn`05000015[K001Jf`000U[K0P0000AJf`00F]/0
009Jf`800007F]/005[K001Jf`00F]/00`0001MJf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/0
05[K001Jf`00F]/005[K0080009Jf`800003F]/005[K00D00005F]/005KK001F^`020002E[/02000
E[/005Jk001F^`00E[/200003EJk001F^`00E[/005Jk001F^`00E[/005Jk0080000=E[/005Jk001F
^`00E[/005Jk001F^`00E[/00P0000EF^`00E[/005Jk01<00007E]/005KK001Ff`00E]/00P0000IF
f`00E]/005KK0002E]/03@00E]/00000E]/005KL001Fg000E]`005KL0080000;E]`005KL001Fg000
E]`005KL001Fg00200002EKL001Fg000E]`005KL001Fg00200002EKL001Fg000E]`005KL001Fg009
00002EKl000005Kl001Fo000E_`00002E_`03`00E_`00000E_`005Kl001Fo000E_`005Kl001Fo002
00001EKl001Fo000E_`01`0000IFo000E_`005Kl0002E_`03`00E_`00000F_`005[l001Jo000F_`0
05[l001Jo00200000e[l0000000600001E[l000005[l00000U[l00@005[k001Jn`80000=F_/005[k
001Jn`00F_/005[k001Jn`00F]/01`0000=Jf`00F]/00P000U[K00P005[K001Jf`00F]/005[K0P00
00mJf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/0200000QJf`00F]/005[K001Jf`000U[K0P00
00UJf`00F]/005[K001Jf`00F]/00P0000QFf`00E]/005KK001Ff`000UKK0P0000=F^`00E[/02000
TWoo00<007ooOol05goo00<007ooOol097oo003JOol00`00Oomoo`1IOol01P00E]/005KK001Ff`80
0007E]/005KK001Ff`00E]/00P0000MFf`00E]/005KK001Ff`0<00000eKL001Fg00200001eKL001F
g000E]`005KL00800008E]`005;LD]`005;L001Bg0800005D]`005;L001Bg00200001e;L001Bg000
D]`005;L00800004D]`005;L0002D]`02@00D]`00000D]`005;L001Bg00200001e;L001Bg000D]`0
05;L00800007D]`005;L001Bg000D]`00P0000MBg000D]`005;L001Bg00200001e;L001Bg000D]`0
05;L00800005D_`005;l001Bo00>000045Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo0000UKl
0P0000UFo000F_`005[l001Jo000F_`01@0000QJo000F_`005[l001Jo0000U[l00T005[l000005[l
001Jo000F_`0100000=Jo00000000U[k00<005[k00000Ukk0P0000ENn`00G_/005kk00D0000BG_/0
05kkG_/005kk001Nn`00G_/005kk001Nn`00G_/005kk0`0000ANn`00G_/0009Nn`04001Nn`000002
G_/01000G_/000000Ukk1@0000EJn`00001Jf`00009Jf`04001Jf`00F]/20002F]/02000F]/005[K
001Jf`00F]/500000e[K00000002F]/01P00F]/005[K001Jf`800004F]/005[KF]/200002E[K001J
f`00F]/005[K001Jf`0700001E[K000005[K00000U[K0P000UJk0P0000eF^`00E[/005Jk001F^`00
E[/005Jk001F^`0200003EJk001F^`00E[/005Jk001F^`00E[/005Jk00800005E[/005Jk001F^`0<
00001eJk001F^`00E[/005Jk0080000AE[/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`02
00002EKK001Ff`00E]/005KK001Ff`0200003EKK001Fg000E]`005KL001Fg000E]`005KL00800007
E]`005KL001Fg000E]`00P0000AFg000E]`0009Fg0800003E]`0000000T00009E_`00000E_`005Kl
001Fo000009Fo080000=E_`005Kl001Fo000E_`005Kl001Fo000E_`00P0000MFo000E_`005Kl001F
o00700001EKl001Fo000E_`00P000UKl00X005Kl001Fo000E_`005Kl001Fo0800007F_`005[l001J
o000F_`01@0000QJo000F_`005[l001Jo0000U[l0P0000UJo000F_`005[k001Jn`00F_/00P0000AJ
n`00F_]Jn`P00006F]/005[K001Jf`000U[K00d005[K000005[K001Jf`00F]/005[K001Jf`020000
25[K001Jfe[K001Jf`00F]/800001E[K001Jf`00F]/00P000U[K00P005[K001Jf`00F]/005[K0P00
00UJf`00F]/005[K001Jf`00F]/00P000UKK00H005KK001Ff`00E]/8002IOol00`00Oomoo`0GOol0
0`00Oomoo`0TOol00=Yoo`03001oogoo05Uoo`06001Ff`00E]/005KK0P0000=Ff`00E]/03P0000MF
f`00E]/005KL001Fg00200001UKL001Fg5KL001Fg0800007E]`005KL001Fg000E]`00P0000MFg000
D]`005;L001Bg0020002D]`01000D]`005;L0P0000MBg000D]`005;L001Bg00200001e;L001Bg000
D]`005;L00800007D]`005;L001Bg000D]`00P0000EBg000D]`005;L00800007D]`005;L001Bg000
D]`00P0000=Bg0000000500000=Bo000D_`00P0001]Bo000D_`005Kl001Fo000E_`005Kl001Fo000
E_`005Kl001Fo000E_`005Kl001Fo000E_`00P0000=Fo000F_`01`0000AJo000F_`0009Jo00:001J
o000F_`005[l001Jo000F_`200000e[l00000002000015[l001Jo0000U[l0P000U[k00@005[k001N
n`800003G_/000000080000:G_/005kk001Nn`00G_/005kk0002G_/200001Ekk001Nn`00G_/01@00
019Nn`00G_]Nn`00G_/005kk001Nn`00G_/005kk001Nn`00G_/3000015[k001Jn`000U[k0P0000mJ
f`00F]/005[K001Jf`00F]/005[K001Jf`00F]/01@0000AJf`00F]/0009Jf`80000AF]/005[K001J
f`00F]/005[K001Jf`00F]/005[K001Jf`0800004E[K001Jf`00F]/005[K001Jf`00F]/005[K001F
f`00E[/00P000UJk014005Jk000005Jk001F^`00E[/005Jk001F^`00E[/005Jk00800003E[/005Jk
00`00007E[/005Jk001F^`00E[/00P0000YF^`00E[]F^`00E[/005Jk001F^`800007E[/005KK001F
f`00E]/00P0000MFf`00E]/005KK001Ff`020002E]/02`00E]/00000E]/005KK001Ff`00E]/00P00
00mFg000E]`005KL001Fg000E]`005KL001Fg000E]`03P0000]Fg000001Fg000E]`005KL001Fg000
009Fo080000;E_`005Kl001Fo000E_`005Kl001Fo00200002eKl001Fo000E_`005Kl001Fo000E_`0
1`0000MFo000001Fo000E_`00002E_`01000E_`005Kl0P0000]Fo000E_`005Kl001Fo000E_`005Kl
00800003F_`0000000@00003E_`005[l0080009Jo008001Jo000F_`005[l001Jo080000;F_`005[l
001Jn`00F_/005[k001Jn`0500001E[K001Jf`00F]/00P000U[K00P005[K001Jf`00F]/005[K0P00
00QJf`00F]/005[K001Jf`000U[K0P0000=Jf`0000001@0000MJf`00001Jf`00F]/00002F]/01000
F]/005[K0P0000UJf`00F]/005[K001Jf`00F]/00P0000AJf`00F]/0009Jf`04001Jf`00F]/:002P
Ool00`00Oomoo`0GOol00`00Oomoo`0TOol00=]oo`03001oogoo05Uoo`X00005E]/005KK001Ff`02
00003eKK001Ff`00E]/005KK001Ff`00E]/005KL001Fg00200001eKL001Fg000E]`005KL0080009F
g004001Fg000E]`200001eKL001Bg000D]`005;L00800007D]`005;L001Bg000D]`00P0000EBg000
D]`005;L00800005D]`005;L001Bg00N00001e;L001Bg000D]`005;L00800007D]`005;L001Bg000
D]`00P0000ABo000D_`0009Bo00C001Bo000001Bo000D_`005Kl001Fo000E_`005Kl001Fo000E_`0
0P0000MFo000E_`005Kl001Fo007000035[l001Jo000F_`005[l001Jo000F_`0009Jo0800005F_`0
05[l001Jo005000015[l001Jo0000U[l00`005[l001Jo000F_/005[k001Jn`00G_/3000015[k001J
n`000Ukk00@005kk0000009Nn`06001Nn`00G_/005kk1@0000YNn`00G_/005kk001Nn`00G_/0009N
n`800005G_/005kk001Nn`05000025[k001Jne[k001Jn`00F_/20002F]/01P00F]/005[K001Jf`80
0003F]/0000000800005F]/00000F]/00002F]/01000F]/005[K0P000U[K00/005[K000005[K001J
f`00F]/005[K00D00005F]/005[K001Jf`020002F]/01P00F]/005[K001Jf`800004F]/005[KF]/2
00003EJk001F^`00E[/005Jk001F^`00E[/005Jk00800003E[/0000000T0000DE[/00000E[/005Jk
001F^`00E[/005Jk001F^`00E[/005Jk001F^`800009E[/005Jk001F^`00E[/005Jk0080000;E[/0
05KK001Ff`00E]/005KK001Ff`0200002EKK001Ff`00E]/005KK001Ff`020002E]/01`00E]/00000
E]/005KL01000003E]`005KL00800008E]`005KL001Fg000E]`0009Fg080000;E]`005KL001Fg000
E]`005Kl001Fo00200002EKl001Fo000E_`005Kl001Fo00200000eKl001Fo00900001UKl001Fo000
E_`0009Fo080000;E_`005Kl001Fo000E_`005Kl001Fo00200001EKl001Fo000E_`01`0000IFo000
E_`005Kl0002E_`03@00F_`00000F_`005[l001Jo000F_`005[l00800004F_`005[lF_`8000015[k
001Jn`000U[K00@005[K001Jf`800009F]/005[K001Jf`00F]/005[K0080009Jf`04001Jf`00F]/8
00001UKK001Ff`00F]/0009Jf`800009F]/005[K001Jf`00F]/005[K00800008F]/005[K001Jf`00
F]/0009Jf`800003F]/005[K00P00:Uoo`03001oogoo01Ioo`03001oogoo02Aoo`00fgoo00<007oo
Ool0FGoo00H005KK001Ff`00E]/2000025KK001FfeKK001Ff`00E]/200001eKK001Ff`00E]/005KK
00800004E]/005KL0002E]`200001EKL001Fg000E]`00P0000MFg000E]`005KL001Fg00200001eKL
001Bg000D]`005;L00800003D]`0000001800003D]`005;L00800007D]`005;L001Bg000D]`00P00
00EBg000D]`005;L00800007D]`005;L001Bg000D]`00P000U;L00H005;L001Bg000D]`200001e;L
001Bg000D]`005;L00800004D_`005;l0002D_`02@00D_`00000D_`005;l001Fo00200002EKl001F
o000E_`005Kl001Fo00700000eKl001Fo002000045Kl001Jo5[l001Jo000F_`005[l001Jo000F_`0
05[l0P0000=Jo00000000P0000=Jo000F_`00P000U[l00<005[l00000U[l00L005[l000005[k001J
n`0400000e[k00000002F_/03P00F_/005kk001Nn`00G_/005kk001Nn`00G_/3000015kk001Nn`00
0Ukk00@005kk0000009Nn`06001Nn`00G_/005kk1@0001MJn`00F_/005[k001Jn`00F_/005[k001J
n`00F]/005[K001Jf`00F]/005[K00<00004F]/005[K0002F]/200004E[K001Jf`00F]/005[K001J
f`00F]/005[K001Jf`00F]/01@0000EJf`00001Jf`00009Jf`04001Jf`00F]/200003E[K001Jf`00
F]/005[K001Jf`00F]/005[K0080009F^`800005E[/005Jk001F^`0700005UJk000005Jk001F^`00
E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk0P0000MF^`00E[/005Jk001F^`02000015Jk001F
^eJk0P0000MF^`00E[/005Jk001F^`0200003EKK001Ff`00E]/005KK001Ff`00E]/005KK00800003
E]/0000000`00009E]/005KL001Fg000E]`005KL00800004E]`005KL0002E]`04@00E]`00000E]`0
05KL001Fg000E]`005KL001Fg000E]`00P0000MFg000E]`005Kl001Fo00200001EKl001Fo000E_`0
2@0001EFo000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`00P0000UFo000E_`0
05Kl001Fo000E_`01@0000EFo000E_`005Kl0080009Fo00:001Fo000E_`005Kl001Jo000F_`20000
1e[l001Jo000F_`005[l00L0000AF_`005[k001Jn`00F_/005[k001Jn`00F]/005[K001Jf`020000
1U[K001Jf`00F]/0009Jf`03001Jf`0000L00003E]/005KK0080000:E]/005KKE]/005KK001Jf`00
F]/200002E[K001Jf`00F]/005[K001Jf`020002F]/01P00F]/005[K001Jf`P00;1oo`03001oogoo
01Ioo`03001oogoo02Aoo`00g7oo00<007ooOol0FGoo00H005KK001Ff`00E]/200001eKK001Ff`00
E]/005KK0080009Ff`04001Ff`00E]/200001eKK001Ff`00E]`005KL00800007E]`005KL001Fg000
E]`00P0000=Fg00000003P0000MBg000D]`005;L001Bg00200001E;L001Bg000D]`00P0000ABg000
D]`0009Bg00;001Bg000001Bg000D]`005;L001Bg00200001E;L001Bg000D]`00P0000MBg000D]`0
05;L001Bg0020002D]`01P00D]`005;L001Bg0800007D]`005;L001Bg000D]`00P0000MBo000D_`0
05;l001Bo00200001e;l001Bo000E_`005Kl00X00006E_`005Kl001Fo0000UKl00H005Kl000005Kl
0002F_`02@00F_`00000F_`005[l001Jo005000015[l001Jo0000U[l00@005[l0000009Jo008001J
o000F_`005[l001Jo0<00004F_/005[k0002F_/200001U[k001Jne[k001Nn`800003G_/005kk00@0
0003F_/00000009Nn`0>001Nn`00G_/005kk001Nn`00G_/005kk001Nn`<00004F_/005[k0002F_/0
1P00F_/00000F_/0009Jn`04001Jn`00F_/200000e[K00000005000025[K001Jfe[K001Jf`00F]/2
000015[K001Jfe[K0P000U[K0P0000=Jf`00F]/01@0000mJf`00F]/005[K001Jf`00F]/005[K001J
f`00F]/00P000U[K00d005[K000005[K001Jf`00F]/005[K001Ff`0:00004eJk001F^`00E[/005Jk
001F^`00E[/005Jk001F^`00E[/005Jk0080000;E[/005Jk001F^`00E[/005Jk001F^`0200003eJk
001F^`00E[/005Jk001F^`00E[/005Jk001F^`0200001EJk001Ff`00E]/03P0000=Ff`00E]/00P00
00MFf`00E]/005KK001Ff`020002E]/02000E]`005KL001Fg000E]`200002eKL001Fg000E]`005KL
001Fg000E]`00P0000UFg000E]`005KL001Fg000E]`00P0000EFg000E]`005Kl00T00005E_`005Kl
001Fo002000035Kl001Fo5Kl001Fo000E_`005Kl001Fo0800009E_`005Kl001Fo000E_`005Kl0080
0003E_`0000000L00004E_`005Kl0002E_`01000E_`005Kl0P0000eFo000E_`005Kl001Fo000F_`0
05[l001Jo00700001eKl000005Kl001Jo000009Jo004001Jn`00F_/200002E[k001Jn`00F]/005[K
001Jf`020002F]/00`00F]/0000700001UKK001Ff`00E]/0009Ff`0=001Ff`00001Ff`00E]/005KK
001Jf`00F]/00P0000AJf`00F]/0009Jf`04001Jf`00F]/:002gOol00`00Oomoo`0FOol00`00Oomo
o`0TOol00=eoo`03001oogoo05Qoo`0@001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/20000
1eKK001Ff`00E]/005KK00800005E]/005KL001Fg00<00001EKL001Fg000E]`00P0000MFg000E]`0
05KL001Fg0020002D]`01P00D]`005;L001Bg0800005D]`005;L001Bg00200001e;L001Bg000D]`0
05;L0080009Bg006001Bg000D]`005;L0P0000EBg000D]`005;L00800007D]`005;L001Bg000D]`0
0P0000MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800003D_`005;l00h0000@E_`0
05Kl001Fo000E_`005Kl001Fo000E_`005Kl0002E_`200002EKl001Fo000F_`005[l001Jo0050000
0e[l001Jo0020002F_`00`00F_`00002F_`02@00F_`00000F_`005[l001Jo00500004U[l001Jne[k
001Jn`00F_/005[k001Jn`00F_/005kk001Nn`<00004F_/005[k0002F_/200001Ukk001Nnekk001N
n`800003G_/005kk00@00003F_/00000009Jn`0@001Jn`00F_/005[k001Jn`00F_/005[k001Jn`00
F_/300005e[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/01`0000EJ
f`00001Jf`00009Jf`04001Jf`00F]/2000015[K001Jfe[K0P0000]Jf`00F]/005[K001Jf`00F]/0
05[K00P0000AE[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk001F^`0200003EJk001F^`00E[/0
05Jk001F^`00E[/005Jk0080000=E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000=F^`00E[/0
3P0000EFf`00E]/005KK00800006E]/005KK001Ff`000UKK00/005KK000005KK001Ff`00E]/005KK
0080000=E]/005KL001Fg000E]`005KL001Fg000E]`00P0000MFg000E]`005KL001Fg00200001EKL
001Fg000E]`02`0000=Fo000E_`00P0000AFo000E_`0009Fo004001Fo000E_`200002eKl001Fo000
E_`005Kl001Fo000E_`00P0000EFo000E_`005Kl00L0000EE_`005Kl001Fo000E_`005Kl001Fo000
E_`005Kl001Fo000E_`005Kl00800005E_`005Kl001Fo00700001UKl001Fo000E_`0009Fo080000;
E_`005[l001Jo000F_/005[k001Jn`0200001U[k001Jfe[K001Jf`P0000AE]/005KK001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`02000025KK001Ff`00E]/005[K0002F]/200000e[K001Jf`08002o
Ool00`00Oomoo`0FOol00`00Oomoo`0TOol00=eoo`03001oogoo05Uoo`08001Ff`00E]/005KK001F
f`800005E]/005KK001Ff`0200000eKK0000000;00002UKL000005KL001Fg000E]`005KL0P000UKL
00@005KL001Fg0800007E]`005KL001Fg000E]`00P0000IBg000D]`005;L0002D]`200001E;L001B
g000D]`00P0000MBg000D]`005;L001Bg00200001e;L001Bg000D]`005;L00800005D]`005;L001B
g00200001e;L001Bg000D]`005;L00800003D]`0000001800005D_`005;l001Bo00200006E;l001F
o000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl00800003E_`005Kl00L0
0004F_`005[l0002F_`01000F_`000000U[l00P005[l001Jo000F_`005[l1@0000QJo000F_`005[l
001Jo0000U[k00T005[k000005[k001Jn`00F_/01@00019Jn`00F_]Jn`00F_/005[k001Jn`00G_/0
05kk001Nn`00G_/3000015[k001Jn`000U[k0P0000IJn`00F_]Jn`00F_/200001E[k001Jn`00F_/0
1@0000QJf`00F]]Jf`00F]/005[K0P0000AJf`00F]]Jf`80009Jf`800003F]/005[K00<00006F]/0
05[K001Jf`000U[K0P00015Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/005[K00800003F]/0
000000D00005F]/005[K001Jf`020002E[/01P00E[/005Jk001F^`80000=E[/005Jk001F^`00E[/0
05Jk001F^`00E[/00P0000eF^`00E[/005Jk001F^`00E[/005Jk001F^`0200000eJk000000090000
2UJk000005KK001Ff`00E]/005KK0P0000QFf`00E]]Ff`00E]/005KK0P0000UFf`00E]/005KK001F
f`00E]/00P0000]Ff`00E]/005KK001Ff`00E]/005KK00800009E]`005KL001Fg000E]`005KL0080
009Fg0`00005E]`005KL001Fg002000015Kl001Fo0000UKl00l005Kl000005Kl001Fo000E_`005Kl
001Fo000E_`00P0000UFo000E_`005Kl001Fo000E_`01`0000EFo000E_`005Kl0080009Fo008001F
o000E_`005Kl001Fo080000;E_`005Kl001Fo000E_`005Kl001Fo00500001EKl001Fo000E_`00P00
0UKl00P005Kl001Fo000E_`005Kl0P0000]Jo000F_`005[k001Jn`00F_/005[k00L00007E]/00000
E]/005KK00000UKK00@005KK001Ff`800009E]/005KK001Ff`00E]/005KK00800008E]/005KKE]/0
05KK001Jf`P00<Moo`03001oogoo01Eoo`03001oogoo02Aoo`00gWoo00<007ooOol0F7oo00P005KK
001Ff`00E]/005KK2P0000MFf`00E]/005KK001Ff`02000015KK001Ff`000UKL0P0000MFg000E]`0
05KL001Fg00200003eKL001Fg000E]`005KL001Fg000E]`005KL001Fg00200001e;L001Bg000D]`0
05;L00800005D]`005;L001Bg00200001e;L001Bg000D]`005;L00800003D]`0000001L00007D]`0
05;L001Bg000D]`00P0000MBg000D]`005;L001Bo002000025;l001Bo5;l001Bo000D_`200003e;l
001Fo000E_`005Kl001Fo000E_`005Kl001Fo00200001EKl001Fo000E_`01`0000aFo000E_`005[l
001Jo000F_`005[l0002F_`200001e[l001Jo000F_`005[l00D00004F_`005[l0002F_`03000F_`0
05[l001Jo000F_/005[k001Jn`D00008F_/005[k001Jn`00F_/0009Jn`09001Jn`00001Jn`00G_/0
05kk00D0000BF_/005[kF_/005[k001Jn`00F_/005[k001Jn`00F_/005[k1@0001EJn`00F]/005[K
001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/01`0000=Jf`0000000U[K00H005[K001Jf`00
F]/2000015[K001Jfe[K0P0000UJf`00F]/005[K001Jf`00F]/01@0000=Jf`00F]/00P0000QJf`00
F]]Jf`00F]/005[K0P0000eF^`00E[/005Jk001F^`00E[/005Jk001F^`0200003EJk001F^`00E[/0
05Jk001F^`00E[/005Jk00`0000;E[/00000E[/005Jk001F^`00E[/00002E[/200001eKK001Ff`00
E]/005KK00800007E]/005KK001Ff`00E]/00P0000eFf`00E]/005KK001Ff`00E]/005KK001Ff`02
00002eKK001Ff`00E]/005KK001Fg000E]`0300000EFg000E]`005KL00800004E]`005KL0002E]`0
1000E]`005KL0P0000]Fo000E_`005Kl001Fo000E_`005Kl00800007E_`005Kl001Fo000E_`00P00
00=Fo00000001P0000MFo000001Fo000E_`00002E_`01000E_`005Kl0P0000UFo000E_`005Kl001F
o000E_`00P0000=Fo000E_`02@0000AFo000E_`0009Fo004001Fo000E_`200002EKl001Fo000E_`0
05Kl001Fo002000015[l001Jo5[l200000IFf`00E]/005KK0002E]/200002eKK001Ff`00E]/005KK
001Ff`00E]/00P0000AFf`00E]/0009Ff`03001Ff`0000T00<ioo`03001oogoo01Eoo`03001oogoo
02Aoo`00gWoo00<007ooOol0FGoo1`0000QFf`00001Ff`00E]/005KK0P000UKK00H005KK001Ff`00
E]/200001eKK001Ff`00E]`005KL0080009Fg004001Fg000E]`200001EKL001Fg000E]`00P0000MF
g000E]`005KL001Fg00200001e;L001Bg000D]`005;L01<00007D]`005;L001Bg000D]`00P0000EB
g000D]`005;L00800007D]`005;L001Bg000D]`00P000U;L00H005;L001Bg000D]`200001e;L001B
g000D]`005;l00800006D_`005;lD_`005;l0P0000MBo000D_`005Kl001Fo00200001eKl001Fo000
E_`005Kl00L00003E_`005Kl0080000@E_`005KlE_`005Kl001Jo000F_`005[l001Jo000F_`20000
0e[l0000000400002U[l001Jo000F_`005[l001Jo0000U[l0P0000EJo000F_`005[k00D00004F_/0
05[k0002F_/03000F_/005[k001Jn`00F_/005[k001Jn`D0000:F_/005[k001Jn`00F_/005[k0002
F_/200001E[k001Jn`00F_/01@0000AJn`00F_/0009Jn`06001Jf`00001Jf`000U[K0P0000MJf`00
F]/005[K001Jf`0300001U[K001Jf`00F]/0009Jf`80000AF]/005[K001Jf`00F]/005[K001Jf`00
F]/005[K001Jf`0800001U[K001Jf`00F]/0009Jf`800007F]/005[K001Jf`00F]/00P000UJk00l0
05Jk000005Jk001F^`00E[/005Jk001F^`00E[/00P0000=F^`0000001`0000=F^`00E[/00P0000IF
^`00E[/005Jk0002E[/200002EJk001F^`00E[/005Jk001F^`0200001eKK001Ff`00E]/005KK0080
009Ff`800007E]/005KK001Ff`00E]/00P0000IFf`00E]]Ff`00E]/200000eKK001Ff`0<00001eKL
001Fg000E]`005KL00800008E]`005KLE]`005KL001Fg080000;E]`005KL001Fg000E]`005KL001F
g00200002EKl001Fo000E_`005Kl001Fo00200000eKl00000007000025Kl001Fo000E_`005Kl0002
E_`200002eKl001Fo000E_`005Kl001Fo000E_`00P0000EFo000E_`005Kl00L0000CE_`005Kl001F
o000E_`005Kl001Fo000E_`005Kl001Fo000E_`00P0000IFo000E_`005Kl0002E_`800003eKl001F
o000E_/005KK001Ff`00E]/005KK001Ff`0200003eKK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`08003FOol00`00Oomoo`0EOol00`00Oomoo`0TOol00=moo`03001oogoo05Qoo`07001Ff`00E]/0
05KK00000UKK0P0000EFf`00E]/005KK0080000?E]/005KK001Ff`00E]/005KK001Ff`00E]/005KL
00800007E]`005KL001Fg000E]`00P0000UFg000E]`005KL001Fg000E]`03P0000QBg000001Bg000
D]`005;L0P0000MBg000D]`005;L001Bg0020002D]`01P00D]`005;L001Bg0800005D]`005;L001B
g00200001e;L001Bg000D]`005;L0080009Bg006001Bg000D]`005;L0P0000EBg000D]`005;L0080
0007D_`005;l001Bo000D_`00P0000MBo000D_`005Kl001Fo00900001eKl000005Kl001Fo000009F
o006001Fo000001Fo0000UKl00T005Kl000005[l001Jo000F_`01@0000IJo000F_`005[l0002F_`0
2P00F_`005[l001Jo000F_`005[l0P0000=Jo00000000P0000YJo000F_/005[k001Jn`00F_/0009J
n`800005F_/005[k001Jn`05000015[k001Jn`000U[k00@005[k0000009Jn`06001Jn`00F_/005[k
1@0000=Jn`00F_/00P000U[k00h005[k001Jn`00F]/005[K001Jf`00F]/005[K1`0000=Jf`000000
0U[K00H005[K001Jf`00F]/20002F]/01000F]/000000U[K0P0000=Jf`00F]/01@0000mJf`00F]/0
05[K001Jf`00F]/005[K001Jf`00F]/00P0000AJf`00F]]Jf`80000;F]/005KK001F^`00E[/005Jk
001F^`0200000eJk0000000700000eJk001F^`0200001UJk001F^`00E[/0009F^`800007E[/005Jk
001F^`00E[/00P0000eF^`00E[/005Jk001F^`00E[/005Jk001Ff`0200003EKK001Ff`00E]/005KK
001Ff`00E]/005KK00800003E]/005KK00`00007E]/005KK001Ff`00E]/00P0000YFg000E]aFg000
E]`005KL001Fg080000;E]`005KL001Fg000E]`005KL001Fg00200001eKL001Fg000E]`005KL0080
0003E_`005Kl00T00007E_`005Kl001Fo000E_`00P000UKl00X005Kl001Fo000E_`005Kl001Fo080
0009E_`005Kl001Fo000E_`005Kl00L00003E_`005Kl0080000<E_`005KlE_`005Kl001Fo000E_`0
05Kl0P0000MFo000E_`005Kl001Fo00200000eKl0000000600001eKl000005Kl001Fo000009Fo004
001Fo000E_/200002EKK001Ff`00E]/005KK001Ff`0200001UKK001FfeKK001Ff`P00=ioo`03001o
ogoo01Aoo`03001oogoo02Aoo`00h7oo00<007ooOol0F7oo00X005KK001Ff`00E]/005KK001Ff`80
009Ff`0;001Ff`00001Ff`00E]/005KK001Ff`0200001eKK001Ff`00E]`005KL00800003E]`00000
00h00005E]`005KL001Fg00200001UKL001Fg000D]`0009Bg0800005D]`005;L001Bg00200001e;L
001Bg000D]`005;L00800004D]`005;L0002D]`02@00D]`00000D]`005;L001Bg00200001e;L001B
g000D]`005;L00800007D]`005;L001Bg000D]`00P0000EBg000D]`005;L00800003D_`005;l00d0
0009E_`00000E_`005Kl001Fo000009Fo0800004E_`005Kl0002E_`02`00E_`00000E_`005Kl001F
o000F_`01@0000=Jo000F_`00P000U[l00D005[l001Jo000009Jo0800007F_`005[l001Jo000F_`0
0`0000AJo000F_`0009Jo004001Jn`000002F_/01000F_/005[k0P0000=Jn`0000000P0001EJn`00
F_/005[k001Jn`00F_/005[k001Jn`00F_/005[k001Jn`00F_/00`0000AJn`00F_/0009Jn`06001J
n`00001Jn`000U[k0P0000MJf`00F]/005[K001Jf`0300001U[K001Jf`00F]/0009Jf`80000?F]/0
05[K001Jf`00F]/005[K001Jf`00F]/005[K00L00005F]/00000F]/00002F]/01000F]/005[K0P00
015Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/005[K00800003E[/005Jk00L00003E[/005Jk
00800006E[/005Jk001F^`000UJk0P0000MF^`00E[/005Jk001F^`0200003EJk001F^`00E[/005Jk
001F^`00E[/005Jk00800004E[/005JkE[/200001eKK001Ff`00E]/005KK00800003E]/0000000X0
0009E]/005KK001Ff`00E]/005KK0080009Ff`06001Ff`00E]/005KK0P0000]Fg000E]`005KL001F
g000E]`005KL00800009E]`005KL001Fg000E]`005KL0080009Fg0X00007E_`005Kl001Fo000E_`0
0P000UKl00H005Kl001Fo000E_`20002E_`200001eKl001Fo000E_`005Kl00800003E_`0000000H0
0007E_`00000E_`005Kl00000UKl00l005Kl000005Kl001Fo000E_`005Kl001Fo000E_`00P0000AF
o000E_aFo0H00008E_`005Kl001Fo000E_`0009Fo0800009E_`005Kl001Fo000E_`005Kk00800006
E]/005KK001Ff`000UKK0P0000=Ff`0000001@00iGoo00<007ooOol057oo00<007ooOol097oo003P
Ool00`00Oomoo`1IOol02000E]/005KK001Ff`00E]/200001eKK001Ff`00E]/005KK00800007E]/0
05KK001Ff`00E]/02P0000EFg000E]`005KL0080000?E]`005KL001Fg000E]`005KL001Fg000E]`0
05KL00800007E]`005KL001Bg000D]`00P0000IBg000D]aBg000D]`200001e;L001Bg000D]`005;L
00800007D]`005;L001Bg000D]`00P0000EBg000D]`005;L00800007D]`005;L001Bg000D]`00P00
00=Bg0000000400000EBo000D_`005;l00800006E_`005Kl001Fo0000UKl0P0000IFo000E_`005Kl
0002E_`200001eKl001Fo000E_`005Kl00800003E_`0000000D00004F_`005[l0002F_`01000F_`0
00000U[l00H005[l001Jo000F_`200000e[l0000000400000e[l00000002F_`00`00F_`00002F_`2
00001e[k001Jn`00F_/005[k00<00004F_/005[k0002F_/01000F_/000000U[k00T005[k000005[k
001Jn`00F_/0100000=Jn`0000000U[k00h005[k001Jn`00F_/005[k001Jn`00F_/005[k1`0000=J
f`0000000U[K00H005[K001Jf`00F]/20002F]/01000F]/000000U[K0P0000=Jf`0000000`0000IJ
f`00F]/005[K0002F]/200003E[K001Jf`00F]/005[K001Jf`00F]/005[K0080009Jf`800005F]/0
05[K001Jf`0700002EJk000005Jk001F^`00E[/00002E[/200001eJk001F^`00E[/005Jk0080000;
E[/005Jk001F^`00E[/005Jk001F^`02000015Jk001F^eJk0P0000MF^`00E[/005Jk001F^`0>0000
5UKK000005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0P0000]Ff`00E]/005KK
001Ff`00E]/005KL00800007E]`005KL001Fg000E]`00P000UKL00<005KL00002@0000EFg000E_`0
05Kl0080000:E_`005KlE_`005Kl001Fo000E_`200002eKl001Fo000E_`005Kl001Fo000E_`00P00
00=Fo000E_`01`0000QFo000E_`005Kl001Fo0000UKl0P0000UFo000E_`005Kl001Fo000E_`00P00
00UFo000E_`005Kl001Fo000E_`01`0000=Fo000E_`00P000UKl00X005Kl001Fo000E_`005Kl001F
o080000;E_`005Kl001Fo000E_/005KK001Ff`09003/Ool00`00Oomoo`0EOol00`00Oomoo`0SOol0
0>5oo`03001oogoo05Qoo`0:001Ff`00E]/005KK001Ff`00E]/200000eKK0000000<00001eKK001F
f`00E]/005KL0080009Fg004001Fg000E]`200001eKL001Fg000E]`005KL00800004E]`005KL0002
E]`200001eKL001Fg000D]`005;L00800007D]`005;L001Bg000D]`00P0000EBg000D]`005;L0080
0005D]`005;L001Bg00E00001e;L001Bg000D]`005;L00800005D]`005;L001Bo002000025;l001B
o5;l001Bo000D_`200001UKl001Fo000E_`0009Fo0800007E_`005Kl001Fo000E_`00P0000=Fo000
E_`01`0000aFo000E_`005Kl001Jo000F_`005[l0002F_`02`00F_`00000F_`005[l001Jo000F_`0
0`0000IJo000F_`005[l0002F_`20002F_`01000F_`005[l0P0000=Jn`00F_/0100000=Jn`000000
0U[k00h005[k001Jn`00F_/005[k001Jn`00F_/005[k1@0000AJn`00F_/0009Jn`800004F_/005[k
F_/200001e[k001Jn`00F_/005[k00<00006F]/005[K001Jf`000U[K0P0000mJf`00F]/005[K001J
f`00F]/005[K001Jf`00F]/01@0000=Jf`00F]/00P000U[K00H005[K001Jf`00F]/2000015[K001J
fe[K0P0000UJf`00F]/005[K001Jf`00F]/02P00015Ff`00E]/005KK001F^`00E[/005Jk001F^`00
E[/005Jk0080000;E[/005Jk001F^`00E[/005Jk001F^`02000015Jk001F^eJk0P0000EF^`00E[/0
05Jk00`00005E]/005KK001Ff`0200001UKK001Ff`00E]/0009Ff`800007E]/005KK001Ff`00E]/0
0P0000eFf`00E]/005KK001Ff`00E]/005KK001Ff`0200002eKK001Ff`00E]/005KL001Fg000E]`0
300000EFg000E]`005KL00800008E]`005KLE]`005Kl001Fo080000;E_`005Kl001Fo000E_`005Kl
001Fo00200001eKl001Fo000E_`005Kl00L00005E_`005Kl001Fo0020002E_`02P00E_`005Kl001F
o000E_`005Kl0P0000MFo000E_`005Kl001Fo00200000eKl0000000600001eKl000005Kl001Fo000
009Fo00?001Fo000001Fo000E_`005Kl001Fo000E_`005Kl00800004E_`005KlE_`8003eOol00`00
Oomoo`0DOol00`00Oomoo`0SOol00>5oo`03001oogoo05Uoo`03001Ff`0000T00005E]/005KK001F
f`0200003eKK001Ff`00E]/005KK001Ff`00E]/005KK001Fg00200003eKL001Fg000E]`005KL001F
g000E]`005KL001Fg00200001eKL001Fg000E]`005KL00800005E]`005;L001Bg00200000e;L001B
g00B00000e;L001Bg00200001E;L001Bg000D]`00P0000MBg000D]`005;L001Bg0020002D]`01P00
D]`005;L001Bg0800005D]`005;L001Bo002000025;l001Bo5;l001Bo000D_`200001eKl001Fo000
E_`005Kl00800005E_`005Kl001Fo00700001EKl001Fo000E_`00P000UKl00h005Kl001Fo000F_`0
05[l001Jo000F_`005[l0P0000=Jo0000000100000=Jo00000000U[l00h005[l001Jo000F_`005[l
001Jo000F_`005[l1@0000AJn`00F_/0009Jn`80009Jn`04001Jn`00F_/200000e[k001Jn`050000
15[k001Jn`000U[k00h005[k001Jn`00F_/005[k001Jn`00F_/005[k1@0000=Jf`0000000U[K00H0
05[K001Jf`00F]/20002F]/01000F]/000000U[K0P0000=Jf`0000000`0000AJf`00F]/0009Jf`0E
001Jf`00001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/005[K00800003F]/0000000<0000A
F]/005[K001Jf`00F]/005[K001Ff`00E]/005KK001F^`0200002eJk001F^`00E[/005Jk001F^`00
E[/00P0000AF^`00E[]F^`800005E[/005Jk001F^`0:00001eJk001F^`00E[/005KK00800008E]/0
05KKE]/005KK001Ff`800007E]/005KK001Ff`00E]/00P0000]Ff`00E]/005KK001Ff`00E]/005KK
0080000=E]/005KK001Ff`00E]/005KK001Ff`00E]/02P0000EFg000E]`005KL00800004E]`005KL
0002E]`01000E]`005KL0P0000]Fg000E]`005Kl001Fo000E_`005Kl00800009E_`005Kl001Fo000
E_`005Kl00L00003E_`005Kl00800008E_`005KlE_`005Kl001Fo080000;E_`005Kl001Fo000E_`0
05Kl001Fo00200000eKl001Fo007000025Kl001Fo000E_`005Kl0002E_`200002EKl001Fo000E_`0
05Kl001Fo00200001UKl001Fo000E_`0009Fo0P00?aoo`03001oogoo01Aoo`03001oogoo02=oo`00
hWoo00<007ooOol0FGoo0P0000MFf`00E]/005KK001Ff`020002E]/01000E]/005KK0P0000MFf`00
E]/005KK001Ff`0200001UKK001FfeKK001Fg0800007E]`005KL001Fg000E]`00P0000EFg000E]`0
05KL00800005E]`005KL001Fg00>00001E;L001Bg000D]`00P0000EBg000D]`005;L00800004D]`0
05;L0002D]`02@00D]`00000D]`005;L001Bg00200001e;L001Bg000D]`005;L0080009Bg006001B
g000D]`005;L0P0000EBg000D]`005;l00800007D_`005;l001Bo000D_`00P0000EFo000E_`005Kl
00T00003E_`005Kl00800008E_`005KlE_`005Kl001Fo080009Fo004001Fo000E_`200001E[l001J
o000F_`01@0000IJo000F_`005[l0002F_`20002F_`01000F_`005[l0P0000=Jo000F_`0100000EJ
o000001Jn`00009Jn`0>001Jn`00F_/005[k001Jn`00F_/005[k001Jn`<0000EF_/005[k001Jn`00
F_/005[k001Jn`00F_/005[k001Jn`00F_/005[k00D00004F_/005[k0002F]/200003e[K001Jf`00
F]/005[K001Jf`00F]/005[K001Jf`0500000e[K001Jf`020002F]/01P00F]/005[K001Jf`80009J
f`04001Jf`000002F]/200001E[K001Jf`00F]/01@0000=Jf`00F]/00P000U[K00H005[K001Jf`00
F]/200002eKK001Ff`00E]/005Jk001F^`00E[/00P0000AF^`00E[]F^`800005E[/005Jk001F^`0:
00001EJk001F^`00E[/00P0000YF^`00E[]F^`00E[/005Jk001Ff`800007E]/005KK001Ff`00E]/0
0P0000]Ff`00E]/005KK001Ff`00E]/005KK0080000;E]/005KK001Ff`00E]/005KK001Ff`0<0000
1EKK001Ff`00E]/00P0000QFg000E]aFg000E]`005KL0P0000]Fg000E]`005KL001Fg000E]`005KL
0080000;E]`005Kl001Fo000E_`005Kl001Fo00:00001UKl001Fo000E_`0009Fo00=001Fo000001F
o000E_`005Kl001Fo000E_`00P0000MFo000E_`005Kl001Fo00700001EKl001Fo000E_`00P000UKl
00X005Kl001Fo000E_`005Kl001Fo0800009E_`005Kl001Fo000E_`005Kl00T00?moo`Aoo`03001o
ogoo01Aoo`03001oogoo02=oo`00hgoo00<007ooOol0F7oo00X005KK001Ff`00E]/005KK001Ff`80
000=E]/005KK001Ff`00E]/005KK001Ff`00E]/00P0000MFf`00E]/005KK001Fg00200001eKL001F
g000E]`005KL00h00003E]`005KL00800005E]`005KL001Fg002000025;L001Bg5;L001Bg000D]`2
00001E;L001Bg000D]`00P0000mBg000D]`005;L001Bg000D]`005;L001Bg000D]`00P0000MBg000
D]`005;L001Bg00200001e;L001Bg000D]`005;L00800005D]`005;L001Bo00200000e;l0000000;
00000eKl001Fo002000015Kl001Fo0000UKl00H005Kl000005Kl0002E_`03@00E_`00000E_`005Kl
001Fo000E_`005[l00D00003F_`005[l0080009Jo00>001Jo000F_`005[l001Jo000F_`005[l001J
o0D00004F_`005[l0002F_`200001U[k001Jne[k001Jn`800003F_/005[k00L00006F_/005[kF_/0
05[k0P000U[k00@005[k001Jn`80009Jn`D00005F_/00000F_/00002F_/01000F_/005[K0P000U[K
00@005[K0000009Jf`800003F]/0000000<00004F]/005[K0002F]/04`00F]/00000F]/005[K001J
f`00F]/005[K001Jf`00F]/005[K00X00006F]/005[K001Jf`000U[K0P0000]Jf`00F]/005[K001J
f`00F]/005KK0080000;E]/005Jk001F^`00E[/005Jk001F^`0:00001EJk001F^`00E[/00P0000QF
^`00E[]F^`00E[/005Jk0P0000UF^`00E[/005Jk001F^`00E]/00P0000]Ff`00E]/005KK001Ff`00
E]/005KK00800004E]/005KKE]/200000eKK001Ff`0<00001eKK001Ff`00E]/005KK00800008E]/0
05KKE]/005KK001Ff`80000;E]`005KL001Fg000E]`005KL001Fg00200001eKL001Fg000E]`005KL
0080009Fg0X0000EE_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl00800009
E_`005Kl001Fo000E_`005Kl00L00003E_`005Kl00800008E_`005KlE_`005Kl001Fo080000;E_`0
05Kl001Fo000E_`005Kl001Fo00200000eKl001Fo007003oOol<Ool00`00Oomoo`0DOol00`00Oomo
o`0SOol00>=oo`03001oogoo05Uoo`06001Ff`00001Ff`000UKK00T005KK000005KK001Ff`00E]/0
0P0000MFf`00E]/005KK001Ff`0200000eKK001Ff`0;000025KL000005KL001Fg000E]`2000015KL
001Fg0000UKL00T005KL000005KL001Fg000E]`00P0000IBg000D]`005;L0002D]`200001E;L001B
g000D]`00P0000MBg000D]`005;L001Bg00200001E;L001Bg000D]`00P0000MBg000D]`005;L001B
g00200000e;L0000000>00001e;l001Bo000D_`005Kl00800004E_`005Kl0002E_`02000E_`00000
E_`005Kl0002E_`200001eKl001Fo000E_`005Kl00800003E_`0000000L00004F_`005[l0002F_`0
1000F_`000000U[l00@005[l001Jo0800003F_`005[l00@00005F_`00000F_`00002F_`03P00F_`0
05[l001Jo000F_/005[k001Jn`00F_/300005e[k001Jn`00F_/005[k001Jn`00F_/005[k001Jn`00
F_/005[k001Jn`00F_/00`0000AJn`00F_/0009Jn`80000?F_/005[k001Jn`00F]/005[K001Jf`00
F]/005[K00D0000=F]/005[K001Jf`00F]/005[K001Jf`00F]/00P000U[K00H005[K001Jf`00F]/2
00000e[K0000000300004E[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/00P000U[K0P00
00eJf`00F]/005[K001Ff`00E]/005KK001F^`0800001EJk001F^`00E[/00P0000QF^`00E[]F^`00
E[/005Jk0P0000MF^`00E[/005Jk001F^`02000015Jk001F^eJk0P0000eF^`00E]/005KK001Ff`00
E]/005KK001Ff`0200000eKK001Ff`0:00001eKK001Ff`00E]/005KK0080000:E]/005KKE]/005KK
001Ff`00E]/200002eKK001Ff`00E]/005KK001Fg000E]`00P0000MFg000E]`005KL001Fg0020002
E]`:00004eKl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl00800009E_`005Kl001F
o000E_`005Kl00800003E_`0000000L00006E_`005Kl001Fo0000UKl00d005Kl000005Kl001Fo000
E_`005Kl001Fo00200001eKl001Fo000E_`005Kl00L00?mooaAoo`03001oogoo01=oo`03001oogoo
02=oo`00i7oo00<007ooOol0FGoo0P0000MFf`00E]/005KK001Ff`0200001eKK001Ff`00E]/005KK
00`00003E]/005KK00800006E]`005KL001Fg0000UKL0P0000EFg000E]`005KL0080000?E]`005KL
001Fg000E]`005KL001Fg000E]`005KL00800007D]`005;L001Bg000D]`00P0000EBg000D]`005;L
00800009D]`005;L001Bg000D]`005;L01400007D]`005;L001Bg000D]`00P0000EBo000D_`005;l
0080009Bo006001Bo000D_`005Kl0P0000AFo000E_`0009Fo0800007E_`005Kl001Fo000E_`00P00
00=Fo000E_`01`0000iFo000E_`005Kl001Fo000E_`005[l001Jo0000U[l0P0000MJo000F_`005[l
001Jo005000015[l001Jo0000U[l0P0000IJo000F_aJo000F_`200001E[l001Jn`00F_/01@0000iJ
n`00F_]Jn`00F_/005[k001Jn`00F_/005[k0P0000=Jn`00F_/01`0000QJn`00F_]Jn`00F_/005[k
0P000U[k00@005[k0000009Jf`800003F]/0000000<00004F]/005[K0002F]/04`00F]/00000F]/0
05[K001Jf`00F]/005[K001Jf`00F]/005[K00D00003F]/005[K0080009Jf`06001Jf`00F]/005[K
0P00015Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/005[K00800003E]/0000000D00003E[/0
05Jk00800008E[/005JkE[/005Jk001F^`800007E[/005Jk001F^`00E[/00P0000AF^`00E[]F^`80
000=E[/005Jk001F^`00E[/005Jk001F^`00E]/00P0000=Ff`00E]/02P0000MFf`00E]/005KK001F
f`020002E]/01P00E]/005KK001Ff`80000=E]/005KK001Ff`00E]/005KK001Ff`00E]/00P0000]F
f`00E]/005KL001Fg000E]`005KL00X00005E]`005KL001Fg002000035Kl001Fo5Kl001Fo000E_`0
05Kl001Fo0800007E_`005Kl001Fo000E_`00P0000EFo000E_`005Kl00L0000EE_`005Kl001Fo000
E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl00800009E_`005Kl001Fo000E_`005Kl00L00?mo
oa]oo`03001oogoo01=oo`03001oogoo02=oo`00i7oo00<007ooOol0FGoo00L005KK000005KK001F
f`0<00001eKK001Ff`00E]/005KK00800006E]/005KKE]/005KK0P0000MFg000E]`005KL001Fg002
00001UKL001Fg5KL001Fg0800007E]`005KL001Fg000E]`00P0000EFg000E]`005KL00800007D]`0
05;L001Bg000D]`04`0000EBg000D]`005;L00800007D]`005;L001Bg000D]`00P000U;L00H005;L
001Bg000D]`200001E;l001Bo000D_`00P000U;l00H005;l001Bo000E_`200001EKl001Fo000E_`0
0P0000EFo000E_`005Kl00L00005E_`005Kl001Fo0020002E_`03P00E_`005Kl001Fo000E_`005[l
001Jo000F_`200000e[l0000000400001E[l000005[l00000U[l00h005[l001Jo000F_`005[l001J
o000F_`005[l1@0001EJn`00F_/005[k001Jn`00F_/005[k001Jn`00F_/005[k001Jn`00F_/00`00
01MJn`00F_/005[k001Jn`00F_/005[k001Jn`00F_/005[k001Jn`00F_/005[k00D0000GF]/005[K
001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`0200000e[K0000000300001U[K
001Jf`00F]/0009Jf`80000=F]/005[K001Jf`00F]/005[K001Jf`00F]/00P000U[K0P0000=Jf`00
F]/01`0000UFf`00001Ff`00E[/005Jk00000UJk0P0000MF^`00E[/005Jk001F^`02000015Jk001F
^eJk0P0000]F^`00E[/005Jk001F^`00E[/005Jk00800005E[/005Jk001F^`0:00001eKK001Ff`00
E]/005KK0080009Ff`06001Ff`00E]/005KK0P0000]Ff`00E]/005KK001Ff`00E]/005KK0080000=
E]/005KK001Ff`00E]/005KK001Ff`00E]/02P0000EFg000E]`005KL00800008E]`005KLE]`005KL
001Fg080000;E_`005Kl001Fo000E_`005Kl001Fo00200001eKl001Fo000E_`005Kl00L00005E_`0
05Kl001Fo0020002E_`02000E_`005Kl001Fo000E_`200002EKl001Fo000E_`005Kl001Fo0020000
0eKl00000006003oOolROol00`00Oomoo`0COol00`00Oomoo`0SOol00>Eoo`03001oogoo05Uoo`H0
0003E]/005KK0080000?E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK0080000?E]/005KK001F
f`00E]`005KL001Fg000E]`005KL00800005E]`005KL001Fg00200002EKL001Fg000E]`005KL001F
g00>000025KL000005;L001Bg000D]`200003e;L001Bg000D]`005;L001Bg000D]`005;L001Bg002
00001e;L001Bg000D]`005;L0080009Bg004001Bg000D]`200001e;L001Bo000D_`005;l00800007
D_`005;l001Bo000E_`00P0000=Fo00000002@0000=Fo000E_`00P0000QFo000E_aFo000E_`005Kl
0P000UKl00@005Kl001Fo0800005E_`005[l001Jo00500001U[l001Jo000F_`0009Jo0800006F_`0
05[lF_`005[l0P0000EJo000F_`005[l00D00004F_`005[l0002F_/02000F_/005[k001Jn`00F_/2
00000e[k001Jn`07000025[k001Jne[k001Jn`00F_/20002F_/01000F_/000000U[k0P0000=Jn`00
00000`0000AJf`00F]/0009Jf`06001Jf`00001Jf`000U[K0P0000UJf`00F]/005[K001Jf`00F]/0
1@0000eJf`00F]/005[K001Jf`00F]/005[K001Jf`020002F]/03@00F]/00000F]/005[K001Jf`00
F]/005[K00P0000AF]/005[K001Jf`00E]/005KK001Ff`00E[/005Jk001F^`02000015Jk001F^eJk
0P0000]F^`00E[/005Jk001F^`00E[/005Jk00800005E[/005Jk001F^`0:00004EKK001Ff`00E]/0
05KK001Ff`00E]/005KK001Ff`00E]/00P0000]Ff`00E]/005KK001Ff`00E]/005KK0080000=E]/0
05KK001Ff`00E]/005KK001Ff`00E]/02P0000EFf`00E]/005KL00800008E]`005KLE]`005KL001F
g080000;E]`005KL001Fg000E]`005Kl001Fo00200001eKl001Fo000E_`005Kl00T00007E_`00000
E_`005Kl00000UKl00@005Kl001Fo0800009E_`005Kl001Fo000E_`005Kl00800005E_`005Kl001F
o007003oOol[Ool00`00Oomoo`0BOol00`00Oomoo`0SOol00>Ioo`03001oogoo05Qoo`06001Ff`00
001Ff`000UKK00/005KK000005KK001Ff`00E]/005KK00800006E]/005KKE]/005KK0P0000MFf`00
E]/005KK001Fg00200001EKL001Fg000E]`00P0000=Fg000E]`03P0000EFg000E]`005KL00800006
E]`005KL001Fg0000UKL0P0000EBg000D]`005;L0080000?D]`005;L001Bg000D]`005;L001Bg000
D]`005;L00800007D]`005;L001Bg000D]`00P0000EBg000D]`005;L00800009D]`005;l001Bo000
D_`005;l00X00005E_`005Kl001Fo002000015Kl001Fo0000UKl00H005Kl000005Kl0002E_`03@00
E_`00000E_`005Kl001Fo000E_`005Kl00D00003F_`005[l0080009Jo00@001Jo000F_`005[l001J
o000F_`005[l001Jo000F_`500005E[l001Jo000F_`005[l001Jo000F_/005[k001Jn`00F_/005[k
001Jn`03000035[k001Jn`00F_/005[k001Jn`00F_/0009Jn`800007F_/005[k001Jn`00F_/01@00
01MJn`00F]/005[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/005[K00P00004F]/005[K
0002F]/05@00F]/00000F]/005[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`0800003e[K001J
f`00F]/005[K001Jf`00F]/005[K001Ff`0200004EKK001F^`00E[/005Jk001F^`00E[/005Jk001F
^`00E[/00P0000EF^`00E[/005Jk00X0000AE[/005KK001Ff`00E]/005KK001Ff`00E]/005KK001F
f`0200002eKK001Ff`00E]/005KK001Ff`00E]/00P0000eFf`00E]/005KK001Ff`00E]/005KK001F
f`0:00001EKK001Ff`00E]/00P0000QFf`00E]]Ff`00E]/005KL0P0000]Fg000E]`005KL001Fg000
E]`005KL00800009E]`005KL001Fo000E_`005Kl00L00009E_`00000E_`005Kl001Fo000009Fo080
000;E_`005Kl001Fo000E_`005Kl001Fo00200001EKl001Fo000E_`02@00ogoo<Woo00<007ooOol0
4Woo00<007ooOol08goo003VOol00`00Oomoo`1IOol04@00E]/00000E]/005KK001Ff`00E]/005KK
001Ff`00E]/00P0000MFf`00E]/005KK001Ff`0200001eKK001Ff`00E]/005KL00`00003E]`005KL
0080000?E]`005KL001Fg000E]`005KL001Fg000E]`005KL00800007E]`005KL001Fg000E]`00P00
0U;L00@005;L001Bg0800007D]`005;L001Bg000D]`00P0000EBg000D]`005;L00800009D]`005;L
001Bg000D]`005;L01400007E_`005Kl001Fo000E_`00P000UKl00@005Kl001Fo0800004E_`005Kl
0002E_`02@00E_`00000E_`005Kl001Fo00200000eKl00000007000015Kl001Fo0000U[l00@005[l
0000009Jo004001Jo000F_`200000e[l001Jo007000015[l001Jo0000U[l00P005[l001Jo000F_`0
05[l0P0000=Jn`00F_/01`00011Jn`00F_]Jn`00F_/005[k001Jn`00F_/005[k001Jn`800003F_/0
05[k00D00004F_/005[k0002F_/01P00F]/00000F]/0009Jf`800007F]/005[K001Jf`00F]/01@00
01EJf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/00P000U[K0P0000=Jf`00
F]/01@0000EJf`00F]/005[K0080009Jf`04001Jf`00F]/200003E[K001Jf`00F]/005KK001Ff`00
E]/005Jk0080009F^`800005E[/005Jk001F^`0:00004EJk001F^`00E[/005Jk001F^`00E[/005KK
001Ff`00E]/00P0000]Ff`00E]/005KK001Ff`00E]/005KK0080000=E]/005KK001Ff`00E]/005KK
001Ff`00E]/02P0000=Ff`00E]/00P0000AFf`00E]/0009Ff`04001Ff`00E]/200002EKK001Ff`00
E]/005KL001Fg00200002eKL001Fg000E]`005KL001Fg000E]`02P0000IFo000E_`005Kl0002E_`2
00002eKl001Fo000E_`005Kl001Fo000E_`00P0000MFo000E_`005Kl001Fo007003oOolkOol00`00
Oomoo`0BOol00`00Oomoo`0SOol00>Moo`03001oogoo05Qoo`0:001Ff`00E]/005KK001Ff`00E]/2
00001eKK001Ff`00E]/005KK00800003E]/005KK00/00008E]/00000E]`005KL001Fg0800006E]`0
05KLE]`005KL0P0000MFg000E]`005KL001Fg00200001UKL001Fg5KL001Fg0800007E]`005KL001F
g000E]`00P0000EBg000D]`005;L00800009D]`005;L001Bg000D]`005;L01400005D]`005;L001B
g00200004E;l001Bo000D_`005;l001Bo000E_`005Kl001Fo000E_`00P000UKl00@005Kl001Fo080
0007E_`005Kl001Fo000E_`00P0000=Fo00000001@0000iFo000E_`005Kl001Fo000E_`005Kl001F
o0000U[l0P0000UJo000F_`005[l001Jo000F_`00`0000aJo000F_`005[l001Jo000F_`005[l0002
F_`200001e[l001Jo000F_`005[k00<0000<F_/005[k001Jn`00F_/005[k001Jn`000U[k0P0000MJ
n`00F_/005[k001Jn`0500005E[k001Jn`00F_/005[k001Jn`00F_/005[K001Jf`00F]/005[K001J
f`0700001E[K000005[K00000U[K00@005[K001Jf`800004F]/005[KF]/200002E[K001Jf`00F]/0
05[K001Jf`0700001e[K000005[K001Jf`00009Jf`0?001Jf`00001Jf`00F]/005[K001Jf`00F]/0
05[K00800009E]/005KK001Ff`00E[/005Jk00X0000AE[/005Jk001F^`00E[/005Jk001F^`00E[/0
05Jk001F^`0200002eJk001Ff`00E]/005KK001Ff`00E]/00P0000eFf`00E]/005KK001Ff`00E]/0
05KK001Ff`0:00000eKK001Ff`02000015KK001Ff`000UKK00l005KK000005KK001Ff`00E]/005KK
001Ff`00E]/00P0000MFf`00E]/005KL001Fg0020002E]`:00005EKl001Fo000E_`005Kl001Fo000
E_`005Kl001Fo000E_`005Kl001Fo00200002EKl001Fo000E_`005Kl001Fo007003oOom2Ool00`00
Oomoo`0BOol00`00Oomoo`0SOol00>Moo`03001oogoo05Uoo`0=001Ff`00001Ff`00E]/005KK001F
f`00E]/02P0000=Ff`00E]/00P0000IFf`00E]/005KK0002E]/200001EKL001Fg000E]`00P0000mF
g000E]`005KL001Fg000E]`005KL001Fg000E]`00P0000EFg000E]`005KL00800007E]`005KL001F
g000E]`00P0000=Bg00000003P0000EBg000D]`005;L0080000?D]`005;L001Bg000D]`005;L001B
g000D]`005;L0080000?D_`005;l001Bo000D_`005;l001Fo000E_`005Kl00800007E_`005Kl001F
o000E_`00P0000=Fo000E_`01`0000EFo000E_`005Kl0080009Fo00>001Fo000E_`005Kl001Fo000
E_`005Kl001Jo0800003F_`005[l00L0000@F_`005[lF_`005[l001Jo000F_`005[l001Jo000F_`2
00000e[l00000005000045[k001Jne[k001Jn`00F_/005[k001Jn`00F_/005[k0P0000=Jn`000000
100000EJn`00001Jn`00009Jn`04001Jn`000002F_/01000F_/005[k0P0000EJf`00F]/005[K00<0
0006F]/005[K001Jf`000U[K0P00015Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/005[K0080
0003F]/0000000<00006F]/005[K001Jf`000U[K0P0000MJf`00F]/005[K001Jf`020002F]/20000
2e[K001Jf`00F]/005[K001Jf`00E]/02000015F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/0
05Jk0080000;E[/005Jk001F^`00E[/005Jk001F^`0200003EKK001Ff`00E]/005KK001Ff`00E]/0
05KK00X00003E]/005KK00800004E]/005KK0002E]/02`00E]/00000E]/005KK001Ff`00E]/00P00
0UKK0P0000MFf`00E]/005KK001Ff`020002E]/00`00E]/0000700004eKL001Fg000E]`005KL001F
o000E_`005Kl001Fo000E_`005Kl00800009E_`005Kl001Fo000E_`005Kl00800003E_`0000000H0
0?moodYoo`03001oogoo015oo`03001oogoo02=oo`00j7oo00<007ooOol0F7oo00@005KK001Ff`X0
0005E]/005KK001Ff`0200001UKK001FfeKK001Ff`800007E]/005KK001Ff`00E]/00P0000IFg000
E]aFg000E]`200001eKL001Fg000E]`005KL00800005E]`005KL001Fg00200000eKL001Fg00>0000
1EKL001Fg000E]`00P0000mBg000D]`005;L001Bg000D]`005;L001Bg000D]`00P0000mBg000D]`0
05;L001Bg000D]`005;L001Bg000D]`00P0000MBo000D_`005;l001Bo00200001EKl001Fo000E_`0
0P0000=Fo00000002@0000EFo000E_`005Kl0080009Fo004001Fo000E_`20002E_`01000E_`005Kl
0P0000EFo000E_`005Kl00L0000:F_`005[l001Jo000F_`005[l0002F_`02`00F_`00000F_`005[l
001Jo000F_`00`0000aJo000F_`005[l001Jo000F_/005[k0002F_/200001e[k001Jn`00F_/005[k
00<00006F_/005[k001Jn`000U[k0P0000mJn`00F_/005[k001Jn`00F_/005[k001Jn`00F]/01@00
00=Jf`0000000U[K00H005[K001Jf`00F]/20002F]/02`00F]/00000F]/005[K001Jf`00F]/01`00
00=Jf`00F]/00P000U[K00H005[K001Jf`00F]/200003e[K001Jf`00F]/005[K001Jf`00F]/005[K
001Jf`0200000e[K0000000500001EKK001Ff`00E[/00P000UJk00H005Jk001F^`00E[/200002eJk
001F^`00E[/005Jk001F^`00E[/00P0000eF^`00E[/005Jk001F^`00E]/005KK001Ff`0:00000eKK
001Ff`02000015KK001Ff`000UKK00/005KK000005KK001Ff`00E]/005KK0080009Ff`800007E]/0
05KK001Ff`00E]/00P000UKK00<005KK00002@0000=Ff`00E]/00P0000YFg000E]aFg000E]`005KL
001Fg0800009E_`005Kl001Fo000E_`005Kl00800005E_`005Kl001Fo007003oOomBOol00`00Oomo
o`0BOol00`00Oomoo`0ROol00>Qoo`03001oogoo05Uoo`@0000?E]/005KK001Ff`00E]/005KK001F
f`00E]/005KK0080000?E]/005KK001Ff`00E]/005KK001Ff`00E]/005KK00800005E]`005KL001F
g00200001eKL001Fg000E]`005KL00`00003E]`005KL00800007E]`005KL001Fg000E]`00P000UKL
00@005KL001Fg0800007D]`005;L001Bg000D]`00P000U;L00@005;L001Bg0800007D]`005;L001B
g000D]`00P0000EBg000D]`005;L00800007D_`005;l001Bo000D_`02P0000MFo000E_`005Kl001F
o002000025Kl001Fo5Kl001Fo000E_`20002E_`01000E_`005Kl0P0000MFo000E_`005Kl001Fo005
00000eKl001Jo002000045[l001Jo5[l001Jo000F_`005[l001Jo000F_`005[l0P0000=Jo0000000
100000=Jo00000000U[l00`005[l001Jo000F_`005[k001Jn`00F_/200000e[k0000000400000e[k
00000002F_/03000F_/005[k001Jn`00F_/005[k001Jn`800003F_/005[k00L00004F]/005[K0002
F]/200003e[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`0700001e[K000005[K001Jf`00009J
f`0?001Jf`00001Jf`00F]/005[K001Jf`00F]/005[K0080009Jf`05001Jf`00001Jf`0700000e[K
001Ff`02000015KK001Ff`000UKK00l005Jk000005Jk001F^`00E[/005Jk001F^`00E[/00P0000eF
^`00E[/005Jk001F^`00E[/005Jk001F^`0:00000eKK001Ff`02000015KK001Ff`000UKK00/005KK
000005KK001Ff`00E]/005KK0080000;E]/005KK001Ff`00E]/005KK001Ff`020002E]/01@00E]/0
0000E]/01`0000=Ff`00E]/00P0000AFf`00E]/0009Ff`0?001Ff`00001Fg000E]`005KL001Fg000
E]`005Kl00800007E_`005Kl001Fo000E_`01`00ogooFGoo00<007ooOol04Woo00<007ooOol08Woo
003YOol00`00Oomoo`1HOol03000E]/005KK001Ff`00E]/005KK001Ff`800004E]/005KK0002E]/2
00001EKK001Ff`00E]/00P0000MFf`00E]/005KK001Ff`0200000eKL001Fg00;000025KL000005KL
001Fg000E]`200001UKL001Fg5KL001Fg0800007E]`005KL001Fg000E]`00P0000IFg000E]aFg000
E]`200001e;L001Bg000D]`005;L00800005D]`005;L001Bg00200002E;L001Bg000D]`005;L001B
g00>000025Kl000005Kl001Fo000E_`20002E_`01P00E_`005Kl001Fo0800006E_`005KlE_`005Kl
0P0000UFo000E_`005Kl001Fo000E_`0200000AFo000E_`0009Fo006001Jo000001Jo0000U[l00T0
05[l000005[l001Jo000F_`01@0000IJo000F_`005[l0002F_`20002F_`02`00F_`00000F_`005[k
001Jn`00F_/00`0000IJn`00F_/005[k0002F_/2000015[k001Jne[k0P0000UJn`00F_/005[k001J
n`00F_/00`0000eJn`00F]/005[K001Jf`00F]/005[K001Jf`020002F]/01000F]/000000U[K0P00
00=Jf`0000000`0000IJf`00F]/005[K0002F]/200001e[K001Jf`00F]/005[K0080009Jf`04001J
f`000002F]/200000e[K001Jf`0700002E[K000005[K001Jf`00F]/00002E]/200001eKK001Ff`00
E]/005Jk0080009F^`80000=E[/005Jk001F^`00E[/005Jk001F^`00E[/00P0000=F^`0000001@00
00=Ff`00E]/00P0000AFf`00E]/0009Ff`0;001Ff`00001Ff`00E]/005KK001Ff`0200002eKK001F
f`00E]/005KK001Ff`00E]/00P000UKK00D005KK000005KK00T00007E]/00000E]/005KK00000UKK
00l005KK000005KK001Ff`00E]/005KK001Fg000E]`00P0000UFg000E]`005KL001Fo000E_`01`00
ogooHGoo00<007ooOol04Goo00<007ooOol08Woo003ZOol00`00Oomoo`1HOol01000E]/005KK0P00
00IFf`00E]]Ff`00E]/200001EKK001Ff`00E]/00P0000UFf`00E]/005KK001Ff`00E]/02P0000=F
g000E]`00P0000IFg000E]`005KL0002E]`200001EKL001Fg000E]`00P0000mFg000E]`005KL001F
g000E]`005KL001Fg000E]`00P0000EFg000E]`005KL00800007D]`005;L001Bg000D]`00P0000=B
g00000003P0000EBg000D]`005;l00800006E_`005Kl001Fo0000UKl0P0000EFo000E_`005Kl0080
009Fo004001Fo000E_`200001eKl001Fo000E_`005Kl00800003E_`0000000L0000<E_`005Kl001F
o000E_`005Kl001Fo0000UKl0P0000UJo000F_`005[l001Jo000F_`01@0000=Jo000F_`00P000U[l
00`005[l001Jo000F_`005[l001Jo000F_`200000e[l0000000400000e[k00000002F_/03000F_/0
05[k001Jn`00F_/005[k001Jn`80009Jn`P00008F_/005[kF_/005[K001Jf`800004F]/005[KF]/2
00001e[K001Jf`00F]/005[K00D00003F]/005[K0080009Jf`06001Jf`00F]/005[K0P0000mJf`00
F]/005[K001Jf`00F]/005[K001Jf`00F]/02000015Jf`00F]/005[K001Jf`00F]/005[K001Jf`00
F]/005KK0080000AE]/005KK001Ff`00E[/005Jk001F^`00E[/005Jk001F^`0200000eJk00000007
00002EKK000005KK001Ff`00E]/00002E]/200001eKK001Ff`00E]/005KK0080000;E]/005KK001F
f`00E]/005KK001Ff`020002E]/01`00E]/00000E]/005KK00L00009E]/00000E]/005KK001Ff`00
009Ff`80000;E]/005KK001Ff`00E]/005KK001Ff`0200002EKK001Ff`00E]`005KL001Fg009003o
OomXOol00`00Oomoo`0AOol00`00Oomoo`0ROol00>Yoo`03001oogoo05Uoo`0;001Ff`00001Ff`00
E]/005KK001Ff`0200001EKK001Ff`00E]/0300000EFf`00E]/005KK00800006E]`005KLE]`005KL
0P0000MFg000E]`005KL001Fg0020002E]`01000E]`005KL0P0000EFg000E]`005KL00800007E]`0
05KL001Fg000E]`00P0000=Fg000E]`03P0000EFg000E]`005KL0080000?D]`005;L001Bg000D]`0
05;L001Bg000D]`005;l0080000?E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl00800005E_`0
05Kl001Fo00200000eKl0000000700005eKl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`0
05Kl001Fo000E_`00P0000=Jo000F_`01`0000AJo000F_`0009Jo004001Jo0000002F_`02@00F_`0
0000F_`005[l001Jo00500001U[l001Jo000F_/0009Jn`800004F_/005[kF_/200001e[k001Jn`00
F_/005[k00D0000GF_/005[k001Jn`00F_/005[k001Jn`00F]/005[K001Jf`00F]/005[K001Jf`02
00000e[K00000003000015[K001Jf`000U[K01D005[K000005[K001Jf`00F]/005[K001Jf`00F]/0
05[K001Jf`00F]/00P0000=Jf`0000000`0000EJf`00F]/005[K0080009Jf`06001Jf`00F]/005[K
0P0000]Jf`00F]/005[K001Ff`00E]/005KK0080009Ff`07001F^`00001F^`00E[/01`0000UF^`00
001F^`00E[/005Jk00000UKK0P0000MFf`00E]/005KK001Ff`0200002eKK001Ff`00E]/005KK001F
f`00E]/00P000UKK00L005KK000005KK001Ff`0:00001UKK001Ff`00E]/0009Ff`800007E]/005KK
001Ff`00E]/00P000UKK0P0000MFf`00E]/005KK001Ff`020002E]/8003oOom`Ool00`00Oomoo`0A
Ool00`00Oomoo`0ROol00>]oo`03001oogoo05Qoo`04001Ff`00E]/200000eKK001Ff`0900004UKK
000005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`80000?E]`005KL001Fg000E]`005KL001F
g000E]`005KL00800005E]`005KL001Fg00200001eKL001Fg000E]`005KL00`00003E]`005KL0080
0007E]`005KL001Fg000E]`00P000UKL00@005KL001Fg080000?D]`005;L001Bg000D]`005;L001B
g000D]`005;l00800005E_`005Kl001Fo00200002EKl001Fo000E_`005Kl001Fo00800001eKl001F
o000E_`005Kl0080009Fo00>001Fo000E_`005Kl001Fo000E_`005Kl001Fo0800005E_`005Kl001F
o005000035[l001Jo000F_`005[l001Jo000F_`0009Jo0800007F_`005[l001Jo000F_`01@0000=J
o000F_`00P000U[l00`005[l001Jn`00F_/005[k001Jn`00F_/200000e[k0000000400001E[k0000
05[k00000U[k00@005[k001Jn`80009Jn`0;001Jn`00001Jf`00F]/005[K001Jf`0500003E[K001J
f`00F]/005[K001Jf`00F]/005[K0080009Jf`04001Jf`000002F]/200001E[K001Jf`00F]/01@00
00=Jf`00F]/00P000U[K00@005[K001Jf`80000=F]/005[K001Jf`00F]/005[K001Jf`00F]/00P00
0UKK0P0000=Ff`00E]/02P00015F^`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005KK0080000;
E]/005KK001Ff`00E]/005KK001Ff`020002E]/01`00E]/00000E]/005KK00X0000AE]/005KK001F
f`00E]/005KK001Ff`00E]/005KK001Ff`0200002eKK001Ff`00E]/005KK001Ff`00E]/00P000UKK
00<005KK00001`00ogooN7oo00<007ooOol047oo00<007ooOol08Woo003[Ool00`00Oomoo`1IOol8
00000eKK001Ff`02000015KK001Ff`000UKK0P0000MFf`00E]/005KK001Ff`0200001UKK001FfeKK
001Ff`800005E]`005KL001Fg00200001eKL001Fg000E]`005KL00800003E]`0000000`00007E]`0
05KL001Fg000E]`00P0000IFg000E]aFg000E]`200001eKL001Fg000E]`005KL0080009Fg004001F
g000E]`200001E;L001Bg000D]`00P0000MBg000D]`005;L001Bo00200001EKl001Fo000E_`03000
00EFo000E_`005Kl0080009Fo006001Fo000E_`005Kl0P000UKl00@005Kl001Fo0800007E_`005Kl
001Fo000E_`01`0000EFo000001Fo000009Jo00<001Jo000F_`005[l001Jo000F_`005[l0P0000=J
o000F_`01@0000AJo000F_`0009Jo004001Jo0000002F_`01000F_`005[k0P0000EJn`00F_/005[k
00<00006F_/005[k001Jn`000U[k0P0000mJn`00F_/005[k001Jn`00F_/005[k001Jn`00F]/01`00
00EJf`00001Jf`00009Jf`0C001Jf`00001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/02P00
00AJf`00F]/0009Jf`09001Jf`00001Jf`00F]/005[K0080009Jf`0=001Jf`00001Jf`00F]/005[K
001Jf`00F]/02000015Ff`00E[/005Jk001F^`00E[/005Jk001F^`00E[/005Jk0080000;E[/005Jk
001F^`00E]/005KK001Ff`02000015KK001FfeKK0P0000=Ff`00E]/02P00015Ff`00E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK0080000;E]/005KK001Ff`00E]/005KK001Ff`02000015KK001F
feKK0P0000=Ff`0000001@00ogooOgoo00<007ooOol047oo00<007ooOol08Woo003/Ool00`00Oomo
o`1HOol01000E]/005KK0P0000IFf`00E]]Ff`00E]/200001eKK001Ff`00E]/005KK0080009Ff`04
001Ff`00E]/200001EKK001Ff`00E]/00P0000MFg000E]`005KL001Fg00:00001EKL001Fg000E]`0
0P0000mFg000E]`005KL001Fg000E]`005KL001Fg000E]`00P0000AFg000E]`0009Fg0800005E]`0
05KL001Fg00200001eKL001Fg000E]`005KL00800005D]`005;L001Bg00200000e;L0000000;0000
4UKl000005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo080009Fo004001Fo000E_`200002EKl
001Fo000E_`005Kl001Fo00700001eKl000005Kl001Fo000009Fo0800006E_`005[lF_`005[l0P00
00EJo000F_`005[l00L0000:F_`005[l001Jo000F_`005[l0002F_`200002E[l001Jo000F_`005[k
001Jn`0500000e[k00000002F_/03000F_/005[k001Jn`00F_/005[k001Jn`800005F_/005[k001J
n`0500001U[K001Jf`00F]/0009Jf`80000?F]/005[K001Jf`00F]/005[K001Jf`00F]/005[K0080
0003F]/0000000<0000AF]/005[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`020002F]/20000
2e[K001Jf`00F]/005[K001Jf`00F]/0200000EFf`00E]/005KK0080009Ff`06001F^`00E[/005Jk
0P0000]F^`00E[/005Jk001F^`00E[/005Jk00800004E[/005KKE]/200001EKK001Ff`00E]/02000
00MFf`00E]/005KK001Ff`020002E]/01P00E]/005KK001Ff`80000;E]/005KK001Ff`00E]/005KK
001Ff`02000015KK001FfeKK0P0000=Ff`00E]/01`00ogooQWoo00<007ooOol047oo00<007ooOol0
8Woo003]Ool00`00Oomoo`1HOol01000E]/005KK0P0000eFf`00E]/005KK001Ff`00E]/005KK001F
f`0200001eKK001Ff`00E]/005KK00800003E]/005KK00`00007E]`005KL001Fg000E]`00P000UKL
00@005KL001Fg0800005E]`005KL001Fg0020002E]`01P00E]`005KL001Fg0800005E]`005KL001F
g00200001EKL001Fg000E]`00P0000=Fg000E]`03P0000MFg000E_`005Kl001Fo002000015Kl001F
o0000UKl0P0000mFo000E_`005Kl001Fo000E_`005Kl001Fo000E_`00P0000EFo000E_`005Kl0080
0003E_`0000000L00006E_`005Kl001Fo0000UKl0P0000mFo000E_`005Kl001Fo000E_`005[l001J
o000F_`01@0000=Jo000F_`00P0000iJo000F_aJo000F_`005[l001Jo000F_`005[l0P0000=Jo000
F_`01`0000AJn`00F_/0009Jn`800006F_/005[kF_/005[k0P0000MJn`00F_/005[k001Jn`050000
0e[K001Jf`020002F]/03000F]/005[K001Jf`00F]/005[K001Jf`800007F]/005[K001Jf`00F]/0
1@0000=Jf`00F]/00P000U[K00H005[K001Jf`00F]/200003e[K001Jf`00F]/005[K001Jf`00F]/0
05[K001Jf`0200000e[K0000000500001E[K001Jf`00E]/00P000UKK00@005KK001Ff`80000=E]/0
05Jk001F^`00E[/005Jk001F^`00E[/00P0000UF^`00E[/005Jk001F^`00E[/02P0000EFf`00E]/0
05KK0080009Ff`06001Ff`00E]/005KK0P0000]Ff`00E]/005KK001Ff`00E]/005KK00800009E]/0
05KK001Ff`00E]/005KK00T00?mooheoo`03001oogoo011oo`03001oogoo029oo`00kGoo00<007oo
Ool0F7oo00<005KK00000UKK0P0000EFf`00E]/005KK00800007E]/005KK001Ff`00E]/00P0000=F
f`0000001`0000=Ff`00E]/00P0000mFf`00E]`005KL001Fg000E]`005KL001Fg000E]`00P0000AF
g000E]`0009Fg0800005E]`005KL001Fg00200001eKL001Fg000E]`005KL00800005E]`005KL001F
g00<00001EKL001Fg000E]`00P0000EFg000E]`005KL0080009Fg006001Fo000E_`005Kl0P0000AF
o000E_`0009Fo0800005E_`005Kl001Fo00200002EKl001Fo000E_`005Kl001Fo00800005eKl001F
o000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`00P0000=Fo000E_`01`0000AJ
o000F_`0009Jo006001Jo000001Jo0000U[l0P0000MJo000F_`005[l001Jo00500005e[l001Jo000
F_`005[l001Jn`00F_/005[k001Jn`00F_/005[k001Jn`00F_/0200000AJn`00F_/0009Jf`06001J
f`00001Jf`000U[K0P0000UJf`00F]/005[K001Jf`00F]/0200000AJf`00F]/0009Jf`0?001Jf`00
001Jf`00F]/005[K001Jf`00F]/005[K0080009Jf`07001Jf`00001Jf`00F]/01@0000=Jf`00F]/0
0P0000AJf`00F]/0009Jf`09001Ff`00001Ff`00E]/005KK0080009Ff`0?001F^`00001F^`00E[/0
05Jk001F^`00E[/005Jk00P00005E]/005KK001Ff`02000025KK001FfeKK001Ff`00E]/200002eKK
001Ff`00E]/005KK001Ff`00E]/00P0000UFf`00E]/005KK001Ff`00E]/02P00ogooUWoo00<007oo
Ool03goo00<007ooOol08Woo003^Ool00`00Oomoo`1HOol01000E]/005KK0P0000MFf`00E]/005KK
001Ff`0:00001EKK001Ff`00E]/00P0000IFf`00E]]Ff`00E]/200001eKK001Fg000E]`005KL0080
009Fg004001Fg000E]`200001EKL001Fg000E]`00P0000EFg000E]`005KL00800003E]`0000000/0
0008E]`00000E]`005KL001Fg0800008E]`005KLE]`005KL001Fg0800005E]`005KL001Fg0020002
E]`01000E_`005Kl0P0000MFo000E_`005Kl001Fo00200001EKl001Fo000E_`0300000EFo000E_`0
05Kl0080009Fo00>001Fo000E_`005Kl001Fo000E_`005Kl001Fo0800005E_`005Kl001Fo0050000
35Kl001Fo000F_`005[l001Jo000F_`0009Jo0800005F_`005[l001Jo00200000e[l000000040000
1E[l000005[l00000U[l00X005[l001Jo000F_`005[k001Jn`800005F_/005[k001Jn`0500005E[k
001Jn`00F_/005[k001Jn`00F_/005[K001Jf`00F]/005[K001Jf`020002F]/800003e[K001Jf`00
F]/005[K001Jf`00F]/005[K001Jf`020002F]/02`00F]/00000F]/005[K001Jf`00F]/02P0000IJ
f`00F]/005[K0002F]/200001e[K001Jf`00F]/005KK0080009Ff`80000;E]/005KK001Ff`00E[/0
05Jk001F^`0200000eJk0000000500000eKK001Ff`02000025KK001FfeKK001Ff`00E]/200001eKK
001Ff`00E]/005KK0080009Ff`80000;E]/005KK001Ff`00E]/005KK001Ff`08003oOonOOol00`00
Oomoo`0?Ool00`00Oomoo`0ROol00>ioo`03001oogoo05Qoo`04001Ff`00E]/:00001eKK001Ff`00
E]/005KK0080009Ff`04001Ff`00E]/200003EKK001Ff`00E]/005KK001Ff`00E]`005KL00800007
E]`005KL001Fg000E]`00P0000EFg000E]`005KL00X00007E]`005KL001Fg000E]`00P0000AFg000
E]`0009Fg0800005E]`005KL001Fg002000025KL001Fg5KL001Fg000E]`200001EKL001Fg000E]`0
0P0000EFg000E_`005Kl00800005E_`005Kl001Fo00900004UKl000005Kl001Fo000E_`005Kl001F
o000E_`005Kl001Fo080009Fo004001Fo000E_`200001eKl001Fo000E_`005Kl00L00005E_`00000
E_`00002E_`03000E_`005[l001Jo000F_`005[l001Jo0800003F_`005[l00D00006F_`005[l001J
o0000U[l0P0000AJo000F_aJo0800009F_`005[l001Jn`00F_/005[k00D00003F_/005[k0080009J
n`04001Jn`00F_/20002F_/02`00F_/00000F]/005[K001Jf`00F]/01@0000EJf`00F]/005[K0080
009Jf`04001Jf`00F]/2000015[K001Jfe[K0P0000UJf`00F]/005[K001Jf`00F]/02000015Jf`00
F]/005[K001Jf`00F]/005[K001Jf`00F]/005[K0080000?F]/005[K001Jf`00E]/005KK001Ff`00
E]/005KK00800003E]/005Jk00L00003E[/005Jk00800004E]/005KK0002E]/200001eKK001Ff`00
E]/005KK0080000AE]/005KK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`08003oOonVOol00`00
Oomoo`0?Ool00`00Oomoo`0ROol00>moo`03001oogoo05Qoo`<0000BE]/00000E]/005KK001Ff`00
E]/005KK001Ff`00E]/005KK0P0000AFf`00E]/0009Ff`800005E]/005KK001Ff`0200001eKK001F
g000E]`005KL00800003E]`0000000T00008E]`00000E]`005KL001Fg080009Fg006001Fg000E]`0
05KL0P0000eFg000E]`005KL001Fg000E]`005KL001Fg00200001eKL001Fg000E]`005KL00800007
E]`005KL001Fg000E]`0300000=Fo000E_`00P0000AFo000E_`0009Fo080000?E_`005Kl001Fo000
E_`005Kl001Fo000E_`005Kl00800007E_`005Kl001Fo000E_`01`0000MFo000001Fo000E_`00002
E_`200001UKl001Fo5Kl001Fo0800007F_`005[l001Jo000F_`01@0000=Jo000F_`00P000U[l00`0
05[l001Jo000F_`005[l001Jo000F_`200000e[l001Jo007000015[k001Jn`000U[k00H005[k0000
05[k0002F_/200001e[k001Jn`00F_/005[K00L00005F]/00000F]/00002F]/01000F]/005[K0P00
00mJf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/00P0000=Jf`0000000`0000EJf`00F]/005[K
0080009Jf`06001Jf`00F]/005[K0P0000]Jf`00F]/005[K001Jf`00F]/005[K0080009Jf`07001F
f`00001Ff`00E]/01`0000UFf`00001F^`00E[/005Jk00000UJk0P0000EFf`00E]/005KK00800004
E]/005KKE]/200002eKK001Ff`00E]/005KK001Ff`00E]/00P0000=Ff`0000001@00ogoo[Woo00<0
07ooOol03Woo00<007ooOol08Woo003`Ool00`00Oomoo`1GOol00`00E]/00002E]/200001eKK001F
f`00E]/005KK00800006E]/005KKE]/005KK0P0000EFf`00E]/005KK00800007E]/005KK001Ff`00
E]/02P0000EFg000E]`005KL00800004E]`005KL0002E]`200001EKL001Fg000E]`00P0000AFg000
E]`0009Fg009001Fg000001Fg000E]`005KL00800005E]`005KL001Fg00200000eKL001Fg00>0000
1EKl001Fo000E_`00P0000AFo000E_`0009Fo008001Fo000001Fo000E_`0009Fo0800005E_`005Kl
001Fo00200001eKl001Fo000E_`005Kl00X00006E_`005Kl001Fo0000UKl0P0000AFo000E_`0009F
o0800005E_`005Kl001Fo00200000e[l0000000400001E[l000005[l00000U[l00@005[l0000009J
o004001Jo000F_`200001E[l001Jo000F_`01@0001EJo000F_`005[k001Jn`00F_/005[k001Jn`00
F_/005[k001Jn`00F_/00P0000=Jn`00F_/01@0000IJf`00F]/005[K0002F]/200002e[K001Jf`00
F]/005[K001Jf`00F]/00P0000MJf`00F]/005[K001Jf`0700000e[K001Jf`020002F]/01000F]/0
05[K0P0000eJf`00F]/005[K001Jf`00F]/005[K001Jf`020002F]/200000e[K001Jf`0:00004EKK
001Ff`00E]/005KK001F^`00E[/005Jk001F^`00E[/00P0000mFf`00E]/005KK001Ff`00E]/005KK
001Ff`00E]/00P0000=Ff`00E]/01`00ogoo]Goo00<007ooOol03goo00<007ooOol08Goo003`Ool0
0`00Oomoo`1HOol03000E]/005KK001Ff`00E]/005KK001Ff`800007E]/005KK001Ff`00E]/00P00
00EFf`00E]/005KK00X00007E]/005KK001Fg000E]`00P000UKL00@005KL001Fg0800005E]`005KL
001Fg0020002E]`01000E]`005KL0P0000MFg000E]`005KL001Fg00200001eKL001Fg000E]`005KL
00X00005E]`005KL001Fg00200003EKL001Fg000E_`005Kl001Fo000E_`005Kl00800004E_`005Kl
0002E_`200001eKl001Fo000E_`005Kl00800007E_`005Kl001Fo000E_`01`0001YFo000001Fo000
E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl0P0000=Fo00000001@0000IF
o000F_`005[l0002F_`2000015[l001Jo5[l0P0000UJo000F_`005[l001Jo000F_`01@0000EJo000
001Jo000009Jo00:001Jo000F_/005[k001Jn`00F_/200001e[k001Jn`00F_/005[k00D00003F]/0
05[K0080009Jf`06001Jf`00F]/005[K0P000U[K00/005[K000005[K001Jf`00F]/005[K00L00007
F]/00000F]/005[K00000U[K00T005[K000005[K001Jf`00F]/00P000U[K00d005[K000005[K001J
f`00F]/005[K001Jf`0800004EKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00E]/00P0000]F
^`00E[/005Jk001F^`00E]/005KK0080009Ff`800005E]/005KK001Ff`07003oOonlOol00`00Oomo
o`0?Ool00`00Oomoo`0QOol00?5oo`03001oogoo05Qoo`04001Ff`00E]/200001eKK001Ff`00E]/0
05KK00800003E]/005KK00T0000BE]/00000E]/005KK001Ff`00E]/005KK001Ff`00E]`005KL0P00
00AFg000E]`0009Fg0800005E]`005KL001Fg00200001EKL001Fg000E]`00P0000EFg000E]`005KL
00`00005E]`005KL001Fg002000025KL001Fg5KL001Fg000E]`200003EKL001Fg000E_`005Kl001F
o000E_`005Kl00800005E_`005Kl001Fo00200001EKl001Fo000E_`0300000IFo000E_`005Kl0002
E_`200003EKl001Fo000E_`005Kl001Fo000E_`005Kl00800003E_`005Kl00L00005E_`005Kl001F
o0020002E_`03000F_`005[l001Jo000F_`005[l001Jo0800003F_`005[l00L00004F_`005[l0002
F_`2000015[l001Jo5[l0P0000UJn`00F_/005[k001Jn`00F_/01`0000EJn`00001Jn`00009Jf`0C
001Jf`00001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/0200000IJf`00F]/005[K0002F]/2
00001e[K001Jf`00F]/005[K0080009Jf`80000;F]/005[K001Jf`00F]/005[K001Jf`0800001EKK
001Ff`00E]/00P000UKK00H005KK001Ff`00E]/200002eKK001Ff`00E]/005KK001F^`00E[/00P00
00AF^`00E[]F^`800003E]/005KK00T00?moolAoo`03001oogoo00ioo`03001oogoo025oo`00lGoo
00<007ooOol0F7oo00P005KK001Ff`00E]/005KK2P0000=Ff`00E]/00P0000AFf`00E]/0009Ff`80
0005E]/005KK001Ff`02000025KK001FfeKK001Fg000E]`200001EKL001Fg000E]`00P0000EFg000
E]`005KL00800003E]`0000000T00003E]`005KL0080000=E]`005KL001Fg000E]`005KL001Fg000
E]`00P0000IFg000E]aFg000E]`200001eKL001Fg000E]`005Kl00800005E_`005Kl001Fo0020000
0eKl001Fo00900000eKl001Fo00200005EKl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`0
05Kl001Fo00200001eKl001Fo000E_`005Kl00D00005E_`005Kl001Fo0020002E_`01000E_`005Kl
0P000UKl00@005[l001Jo0800005F_`005[l001Jo00500004e[l001Jo000F_`005[l001Jo000F_`0
05[l001Jo000F_`005[l00800003F_/005[k00L00006F_/005[k001Jn`000U[k0P0000]Jn`00F]/0
05[K001Jf`00F]/005[K0080009Jf`800003F]/0000000<00005F]/005[K001Jf`020002F]/01P00
F]/005[K001Jf`800004F]/005[KF]/200002E[K001Jf`00F]/005[K001Jf`0200000e[K00000005
00001EKK001Ff`00E]/00P000UKK00@005KK001Ff`80000;E]/005KK001Ff`00E]/005KK001Ff`02
00002eKK001Ff`00E[/005Jk001F^`00E[/02000ogooc7oo00<007ooOol03Woo00<007ooOol08Goo
003bOol00`00Oomoo`1HOol800001EKK001Ff`00E]/00P0000IFf`00E]]Ff`00E]/200001EKK001F
f`00E]/00P000UKK00@005KK001Ff`800007E]/005KK001Fg000E]`00P0000EFg000E]`005KL00X0
0005E]`005KL001Fg002000015KL001Fg0000UKL014005KL000005KL001Fg000E]`005KL001Fg000
E]`005KL00800005E]`005KL001Fg00200002EKL001Fg000E]`005Kl001Fo00:00000eKl001Fo002
000015Kl001Fo0000UKl014005Kl000005Kl001Fo000E_`005Kl001Fo000E_`005Kl00800005E_`0
05Kl001Fo00900001EKl000005Kl00000UKl00@005Kl001Fo080009Fo00;001Fo000001Fo000E_`0
05[l001Jo00700001E[l000005[l00000U[l00X005[l001Jo000F_`005[l001Jo0800005F_`005[l
001Jo00500001E[l001Jn`00F_/00P000U[k00`005[k001Jn`00F_/005[k001Jn`00F]/200001e[K
001Jf`00F]/005[K00D00003F]/005[K0080009Jf`04001Jf`00F]/200004E[K001Jf`00F]/005[K
001Jf`00F]/005[K001Jf`00F]/00P0000=Jf`0000001@0000=Ff`00E]/00P0000QFf`00E]]Ff`00
E]/005KK0P0000EFf`00E]/005KK0080009Ff`0?001Ff`00001Ff`00E]/005KK001Ff`00E]/005KK
00P00?moom=oo`03001oogoo00ioo`03001oogoo025oo`00lgoo00<007ooOol0Egoo00h005KK001F
f`00E]/005KK001Ff`00E]/005KK0P0000eFf`00E]/005KK001Ff`00E]/005KK001Ff`0200001EKK
001Ff`00E]/00P0000=Ff`00E]/02`0000QFg000001Fg000E]`005KL0P000UKL00@005KL001Fg080
0004E]`005KL0002E]`200001eKL001Fg000E]`005KL00800005E]`005KL001Fg00200000eKL001F
g00>00001EKl001Fo000E_`00P0000IFo000E_aFo000E_`2000015Kl001Fo0000UKl0P0000MFo000
E_`005Kl001Fo00200001EKl001Fo000E_`01`0000UFo000001Fo000E_`005Kl00000UKl0P0000IF
o000E_aFo000E_`200001EKl001Fo000E_`00P0000=Fo0000000100000MFo000001Jo000F_`00002
F_`2000015[l001Jo5[l0P0000UJo000F_`005[l001Jo000F_`01@0000EJo000001Jo000009Jo004
001Jn`00F_/20002F_/03@00F_/00000F_/005[k001Jn`00F]/005[K00P00004F]/005[K0002F]/0
3`00F]/00000F]/005[K001Jf`00F]/005[K001Jf`020002F]/200000e[K001Jf`0700001e[K0000
05KK001Ff`00009Ff`0;001Ff`00001Ff`00E]/005KK001Ff`020002E]/200002eKK001Ff`00E]/0
05KK001Ff`00E]/00P0000=Ff`0000001@00ogoofWoo00<007ooOol03Woo00<007ooOol08Goo003c
Ool00`00Oomoo`1HOol01P00E]/005KK001Ff`800004E]/005KK0002E]/200001EKK001Ff`00E]/0
0P0000EFf`00E]/005KK00800003E]/0000000L00005E]/005KK001Ff`02000015KL001Fg0000UKL
0P0000EFg000E]`005KL00800006E]`005KLE]`005KL0P0000EFg000E]`005KL00800009E]`005KL
001Fg000E]`005KL00X00003E]`005KL0080000?E]`005Kl001Fo000E_`005Kl001Fo000E_`005Kl
00800006E_`005KlE_`005Kl0P0000EFo000E_`005Kl00800005E_`005Kl001Fo00900001eKl0000
05Kl001Fo000009Fo080000?E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl00800003E_`00000
00D00006E_`005Kl001Fo0000UKl0P0000]Jo000F_`005[l001Jo000F_`005[l00800003F_`005[l
00L00004F_`005[l0002F_`2000015[l001Jo0000U[k0P0000EJn`00F_/005[k0080009Jn`P0000E
F]/005[K001Jf`00F]/005[K001Jf`00F]/005[K001Jf`00F]/005[K00800007F]/005[K001Jf`00
F]/01`0000MJf`00001Jf`00F]/00002F]/200001eKK001Ff`00E]/005KK0080000?E]/005KK001F
f`00E]/005KK001Ff`00E]/005KK00800003E]/0000000L00?moon9oo`03001oogoo00eoo`03001o
ogoo025oo`00m7oo00<007ooOol0Egoo00L005KKE]/005KK001Ff`0200001EKK001Ff`00E]/00P00
00MFf`00E]/005KK001Ff`0800001EKK001Ff`00E]/00P0000QFf`00E]]Ff`00E]/005KK0P0000eF
g000E]`005KL001Fg000E]`005KL001Fg00200001EKL001Fg000E]`00P0000EFg000E]`005KL00`0
0005E]`005KL001Fg00200001UKL001Fg5KL001Fg080000?E]`005Kl001Fo000E_`005Kl001Fo000
E_`005Kl00800005E_`005Kl001Fo00200000eKl001Fo00900000eKl001Fo002000015Kl001Fo000
0UKl0P0000AFo000E_`0009Fo0800005E_`005Kl001Fo00200000eKl001Fo00700001EKl001Fo000
E_`00P000UKl00`005Kl001Fo000E_`005Kl001Jo000F_`200000e[l001Jo00700005E[l001Jo000
F_`005[l001Jo000F_`005[l001Jo000F_`005[l001Jn`0200000e[k001Jn`0700003E[K001Jf`00
F]/005[K001Jf`00F]/005[K0080009Jf`0=001Jf`00001Jf`00F]/005[K001Jf`00F]/0200000IJ
f`00F]/005[K0002F]/200001E[K001Jf`00F]/00P00015Ff`00E]/005KK001Ff`00E]/005KK001F
f`00E]/005KK00800003E]/0000000D00?moon]oo`03001oogoo00eoo`03001oogoo025oo`00m7oo
00<007ooOol0F7oo00H005KK001Ff`00E]/200001EKK001Ff`00E]/02P0000EFf`00E]/005KK0080
009Ff`04001Ff`00E]/200001UKK001Ff`00E]/0009Ff`800005E]`005KL001Fg00200001EKL001F
g000E]`00P0000=Fg000E]`02@00019Fg000001Fg000E]`005KL001Fg000E]`005KL001Fg000E]`2
00001UKL001Fg5KL001Fg0800005E]`005Kl001Fo00200001eKl001Fo000E_`005Kl00800003E_`0
000000L00003E_`005Kl00800004E_`005Kl0002E_`04@00E_`00000E_`005Kl001Fo000E_`005Kl
001Fo000E_`00P0000=Fo000E_`01`0000EFo000E_`005Kl0080009Fo004001Fo000E_`20002E_`0
2`00E_`00000E_`005Kl001Jo000F_`01@0000=Fo000E_`00P0000iJo000F_aJo000F_`005[l001J
o000F_`005[l0P0000MJo000F_`005[l001Jn`0500000e[k001Jn`02000025[K001Jfe[K001Jf`00
F]/2000015[K001Jfe[K0P0000UJf`00F]/005[K001Jf`00F]/0200000EFf`00E]/005KK0080009J
f`06001Jf`00F]/005[K0P0000mJf`00F]/005[K001Jf`00E]/005KK001Ff`00E]/00P0000=Ff`00
E]/01`00ogoolWoo00<007ooOol03Goo00<007ooOol08Goo003eOol00`00Oomoo`1GOol00`00E]/0
000:000045KK000005KK001Ff`00E]/005KK001Ff`00E]/005KK0P0000AFf`00E]/0009Ff`800007
E]/005KK001Ff`00E]/00P0000MFg000E]`005KL001Fg00:00000eKL001Fg002000015KL001Fg000
0UKL0P0000MFg000E]`005KL001Fg0020002E]`01000E]`005KL0P0000EFg000E]`005KL00800007
E]`005Kl001Fo000E_`02P0000EFo000E_`005Kl00800006E_`005KlE_`005Kl0P0000AFo000E_`0
009Fo0800005E_`005Kl001Fo00200001EKl001Fo000E_`01`0000=Fo000E_`00P0000QFo000E_aF
o000E_`005Kl0P000UKl00/005Kl000005Kl001Fo000E_`005Kl00L00005E_`00000E_`00002E_`0
1P00E_`00000F_`0009Jo00;001Jo000001Jo000F_`005[l001Jo00700001E[l000005[k00000U[k
014005[k000005[K001Jf`00F]/005[K001Jf`00F]/005[K00800003F]/005[K00L00005E]/005KK
001Ff`020002E]/01000E]/005KK0P0000]Jf`00F]/005[K001Jf`00F]/005[K0080009Jf`800005
E]/005KK001Ff`07003oOoojOol00`00Oomoo`0<Ool00`00Oomoo`0QOol00?Ioo`03001oogoo05Mo
o`06001Ff`00E]/005KK0P0000AFf`00E]/0009Ff`800005E]/005KK001Ff`0200001UKK001FfeKK
001Ff`800007E]/005KK001Ff`00E]/00P0000EFf`00E]/005KK00X00005E]`005KL001Fg0020000
1UKL001Fg5KL001Fg080000=E]`005KL001Fg000E]`005KL001Fg000E]`00P0000MFg000E]`005KL
001Fg00200000eKL001Fg00<00001eKl001Fo000E_`005Kl0080009Fo004001Fo000E_`200001UKl
001Fo5Kl001Fo0800005E_`005Kl001Fo00200000eKl001Fo00900000eKl001Fo00200001UKl001F
o5Kl001Fo0800006E_`005KlE_`005Kl0P0000EFo000E_`005Kl00800003E_`0000000D00006E_`0
05Kl001Fo0000UKl0P0000AFo000E_aFo0800007F_`005[l001Jo000F_`00P0000=Jo00000001@00
00IJo000F_`005[l0002F_`200002e[k001Jn`00F_/005[k001Jf`00F]/00P0000MJf`00F]/005[K
001Jf`0500000eKK001Ff`02000025KK001FfeKK001Ff`00E]/200002eKK001Ff`00E]/005KK001J
f`00F]/00P000U[K0P0000=Jf`00F]/02@00ogooogoo0Woo00<007ooOol037oo00<007ooOol08Goo
003fOol00`00Oomoo`1GOol01`00E]]Ff`00E]/005KK00800005E]/005KK001Ff`020002E]/01000
E]/005KK0P0000EFf`00E]/005KK00800005E]/005KK001Ff`09000045KK000005KL001Fg000E]`0
05KL001Fg000E]`005KL0P0000AFg000E]`0009Fg0800005E]`005KL001Fg00200001EKL001Fg000
E]`00P0000=Fg000E]`02@0000=Fg000E]`00P0000mFo000E_`005Kl001Fo000E_`005Kl001Fo000
E_`00P000UKl00/005Kl000005Kl001Fo000E_`005Kl00800003E_`005Kl00L00003E_`005Kl0080
0004E_`005Kl0002E_`01P00E_`00000E_`0009Fo0800007E_`005Kl001Fo000E_`00P0000=Fo000
00001@0001EFo000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`00P0000=Jo000
F_`01`0001EFo000E_`005Kl001Fo000F_`005[l001Jo000F_`005[k001Jn`00F_/00P0000MJn`00
F]/005[K001Jf`0700001EKK000005KK00000UKK00l005KK000005KK001Ff`00E]/005KK001Ff`00
E]/00P0000UFf`00E]/005[K001Jf`00F]/02000ogooogoo2Woo00<007ooOol037oo00<007ooOol0
8Goo003gOol00`00Oomoo`1GOol03P00E]/005KK001Ff`00E]/005KK001Ff`00E]/200001EKK001F
f`00E]/00P0000=Ff`00E]/02@0000=Ff`00E]/00P0000AFf`00E]/0009Ff`800005E]`005KL001F
g00200001UKL001Fg5KL001Fg0800005E]`005KL001Fg00200001eKL001Fg000E]`005KL00X00005
E]`005KL001Fg00200001UKL001Fg5KL001Fg080000=E_`005Kl001Fo000E_`005Kl001Fo000E_`0
0P0000EFo000E_`005Kl00800003E_`005Kl00T00003E_`005Kl00800006E_`005KlE_`005Kl0P00
00AFo000E_`0009Fo0800005E_`005Kl001Fo00200000eKl001Fo00700001EKl001Fo000E_`00P00
0UKl00`005Kl001Fo000E_`005Kl001Fo000E_`200001EKl001Fo000E_`01@0000EFo000E_`005Kl
0080009Fo004001Fo000E_`20002F_`03@00F_`00000F_`005[k001Jn`00F_/005[k00P00006E]/0
05KK001Ff`000UKK0P0000]Ff`00E]/005KK001Ff`00E]/005KK00800009E]/005KK001Ff`00E]/0
05KK00P00?mooomooa5oo`03001oogoo00eoo`03001oogoo021oo`00mgoo00<007ooOol0F7oo00H0
05KK001Ff`00E]/200001EKK001Ff`00E]/00P0000=Ff`0000001`0000=Ff`00E]/00P0000AFf`00
E]/0009Ff`0A001Ff`00001Ff`00E]/005KK001Ff`00E]`005KL001Fg00200001EKL001Fg000E]`0
0P0000EFg000E]`005KL00X00005E]`005KL001Fg002000025KL001Fg5KL001Fg000E]`200001UKL
001Fg5KL001Fg0800005E_`005Kl001Fo00200001EKl001Fo000E_`00P0000=Fo00000001`0000EF
o000E_`005Kl00800006E_`005KlE_`005Kl0P0000IFo000E_aFo000E_`200001EKl001Fo000E_`0
0P0000=Fo000E_`01`0000EFo000E_`005Kl0080009Fo004001Fo000E_`20002E_`02`00E_`00000
E_`005Kl001Fo000E_`01`0000EFo000001Fo000009Fo004001Fo000E_`20002E_`02@00E_`00000
E_`005[l001Jo00200000e[l0000000700004eKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`00
E]/005KK00800009E]/005KK001Ff`00E]/005KK00X00?mooomooaUoo`03001oogoo00aoo`03001o
ogoo021oo`00n7oo00<007ooOol0Egoo00P005KK001Ff`00E]/005KK200000EFf`00E]/005KK0080
0006E]/005KKE]/005KK0P0000IFf`00E]/005KK0002E]/200001EKK001Ff`00E]/00P0000EFg000
E]`005KL00800003E]`005KL00T0000@E]`00000E]`005KL001Fg000E]`005KL001Fg000E]`20000
1UKL001Fg5KL001Fg0800007E]`005KL001Fg000E]`00P0000EFo000E_`005Kl00X00005E_`005Kl
001Fo002000025Kl001Fo5Kl001Fo000E_`2000015Kl001Fo5Kl0P0000MFo000E_`005Kl001Fo002
00000eKl001Fo00700000eKl001Fo002000025Kl001Fo5Kl001Fo000E_`20002E_`02`00E_`00000
E_`005Kl001Fo000E_`01`0000MFo000001Fo000E_`00002E_`2000015Kl001Fo5Kl0P0000MFo000
E_`005Kl001Fo00200000eKl001Jo00500003eKl001Fo000E_`005Kk001Ff`00E]/005KK001Ff`02
0002E]/03@00E]/00000E]/005KK001Ff`00E]/005KK00P00?mooomoob9oo`03001oogoo00aoo`03
001oogoo021oo`00nGoo00<007ooOol0Egoo200000EFf`00E]/005KK0080009Ff`04001Ff`00E]/2
000015KK001Ff`000UKK0P0000MFf`00E]/005KK001Ff`0200001eKK001Ff`00E]/005KK00X00003
E]`005KL00800004E]`005KL0002E]`200001EKL001Fg000E]`00P000UKL00@005KL001Fg0800005
E]`005KL001Fg00200001EKL001Fg000E]`02@0000QFo000001Fo000E_`005Kl0P000UKl00@005Kl
001Fo0800006E_`005KlE_`005Kl0P0000EFo000E_`005Kl00800003E_`005Kl00T00003E_`005Kl
00800006E_`005KlE_`005Kl0P0000IFo000E_aFo000E_`200001eKl001Fo000E_`005Kl00P00006
E_`005Kl001Fo0000UKl0P0000]Fo000E_`005Kl001Fo000E_`005Kl00800005E_`005Kl001Fo007
00000eKl001Fo0020002E_`01P00E_`005Kl001Fn`80009Ff`800007E]/005KK001Ff`00E]/00P00
0UKK2000ogooogoo:Goo00<007ooOol037oo00<007ooOol087oo003iOol00`00Oomoo`1GOol03P00
E]/005KK001Ff`00E]/005KK001Ff`00E]/2000015KK001Ff`000UKK0P0000EFf`00E]/005KK0080
0007E]/005KK001Ff`00E]/02P0000EFf`00E]`005KL00800006E]`005KLE]`005KL0P0000eFg000
E]`005KL001Fg000E]`005KL001Fg00200001EKL001Fg000E]`00P0000=Fg000E]`02@0000=Fo000
E_`00P0000AFo000E_`0009Fo0800005E_`005Kl001Fo0020002E_`01000E_`005Kl0P0000EFo000
E_`005Kl00800003E_`0000000L00005E_`005Kl001Fo00200001UKl001Fo5Kl001Fo0800004E_`0
05KlE_`200001eKl001Fo000E_`005Kl00800003E_`0000000D0000EE_`005Kl001Fo000E_`005Kl
001Fo000E_`005Kl001Fo000E_`005Kl00800005E_`005Kl001Fo00700000eKl001Fo00200001UKl
001Fo5Kl001Fo0800004E_`005KlE_`200001EKk001Ff`00E]/00P0000EFf`00E]/005KK00L00?mo
oomooc5oo`03001oogoo00]oo`03001oogoo021oo`00nWoo00<007ooOol0Egoo00H005KK001Ff`00
E]/200001UKK001FfeKK001Ff`800005E]/005KK001Ff`0200001EKK001Ff`00E]/02@00011Ff`00
001Ff`00E]/005KK001Ff`00E]/005KL001Fg0800006E]`005KLE]`005KL0P0000EFg000E]`005KL
00800005E]`005KL001Fg00200000eKL0000000700000eKL001Fg002000015KL001Fo0000UKl0140
05Kl000005Kl001Fo000E_`005Kl001Fo000E_`005Kl00800005E_`005Kl001Fo00200000eKl0000
000500001EKl001Fo000E_`00P0000QFo000E_aFo000E_`005Kl0P0000AFo000E_aFo0800005E_`0
05Kl001Fo00200000eKl0000000700005EKl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`0
05Kl001Fo00200001EKl001Fo000E_`01`0000MFo000001Fo000E_`00002E_`01P00E_`00000E_`0
009Fo0800005E_`005Kl001Fo00200001EKk001Ff`00E]/01`00ogooogoo>7oo00<007ooOol02goo
00<007ooOol087oo003jOol00`00Oomoo`1GOol01`00E]]Ff`00E]/005KK00800005E]/005KK001F
f`0200001EKK001Ff`00E]/01`0000UFf`00001Ff`00E]/005KK00000UKK0P0000EFf`00E]/005KK
00800006E]/005KLE]`005KL0P0000EFg000E]`005KL00800007E]`005KL001Fg000E]`0200000EF
g000E]`005KL00800006E]`005KLE]`005KL0P0000AFg000E_`0009Fo0800005E_`005Kl001Fo002
00002EKl001Fo000E_`005Kl001Fo00800001EKl001Fo000E_`00P000UKl00@005Kl001Fo0800006
E_`005KlE_`005Kl0P0000EFo000E_`005Kl00800003E_`0000000D00007E_`005Kl001Fo000E_`0
0P000UKl00X005Kl001Fo000E_`005Kl001Fo0800007E_`005Kl001Fo000E_`01`0000MFo000001F
o000E_`00002E_`200003EKl001Fo000E_`005Kl001Fo000E_`005Kl00800005E_`005Kl001Fo007
003oOoooOoloOol00`00Oomoo`0;Ool00`00Oomoo`0POol00?]oo`03001oogoo05Moo`06001Ff`00
E]/005KK0P0000=Ff`00E]/02@0000MFf`00001Ff`00E]/00002E]/200001eKK001Ff`00E]/005KK
0080009Ff`04001Ff`00E]/200001EKK001Fg000E]`00P0000=Fg000E]`0300000EFg000E]`005KL
0080009Fg004001Fg000E]`200001UKL001Fg5KL001Fg0800005E]`005Kl001Fo00200001eKl001F
o000E_`005Kl00X00005E_`005Kl001Fo0020002E_`01000E_`005Kl0P000UKl00@005Kl001Fo080
0005E_`005Kl001Fo00200000eKl0000000500001EKl001Fo000E_`00P000UKl00H005Kl001Fo000
E_`20002E_`02`00E_`00000E_`005Kl001Fo000E_`01`0000MFo000001Fo000E_`00002E_`20000
2eKl001Fo000E_`005Kl001Fo000E_`00P0000MFo000E_`005Kl001Fo007003oOoooOom7Ool00`00
Oomoo`0:Ool00`00Oomoo`0POol00?]oo`03001oogoo05Moo`03001Ff`0000P00003E]/005KK0080
0004E]/005KK0002E]/200003eKK001Ff`00E]/005KK001Ff`00E]/005KK001Ff`0200001EKK001F
f`00E]/00P0000=Ff`00E]`01`0000=Fg000E]`00P0000eFg000E]`005KL001Fg000E]`005KL001F
g0020002E]`01000E]`005KL0P0000EFg000E]`005KL00800005E]`005Kl001Fo00:00003eKl001F
o000E_`005Kl001Fo000E_`005Kl001Fo0020002E_`02`00E_`00000E_`005Kl001Fo000E_`00P00
00=Fo00000001@0000EFo000E_`005Kl0080009Fo004001Fo000E_`20002E_`01000E_`005Kl0P00
00MFo000E_`005Kl001Fo00800001UKl001Fo000E_`0009Fo080000;E_`005Kl001Fo000E_`005Kl
001Fo00200001EKl001Fo000E_`02@00ogooogooCWoo00<007ooOol02Woo00<007ooOol087oo003l
Ool00`00Oomoo`1GOol01P00E]/005KK001Ff`800006E]/005KKE]/005KK0P0000eFf`00E]/005KK
001Ff`00E]/005KK001Ff`0200001eKK001Ff`00E]/005KK00800003E]/0000000L00003E]/005KK
00800006E]`005KLE]`005KL0P0000eFg000E]`005KL001Fg000E]`005KL001Fg00200001EKL001F
g000E]`00P0000=Fg000E]`02@0001QFo000001Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`0
05Kl001Fo000E_`200001EKl001Fo000E_`00P0000=Fo00000001`0000EFo000E_`005Kl0080009F
o004001Fo000E_`20002E_`03@00E_`00000E_`005Kl001Fo000E_`005Kl00P0000EE_`005Kl001F
o000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl00800005E_`005Kl001Fo007003oOoooOomG
Ool00`00Oomoo`0:Ool00`00Oomoo`0POol00?eoo`03001oogoo05Ioo`07001FfeKK001Ff`00E]/0
0P0000AFf`00E]/0009Ff`800005E]/005KK001Ff`0200002EKK001Ff`00E]/005KK001Ff`080000
1EKK001Ff`00E]/00P0000IFf`00E]]Ff`00E]/2000015KL001Fg0000UKL0P0000EFg000E]`005KL
00800005E]`005KL001Fg00200000eKL0000000700000eKL001Fo002000015Kl001Fo0000UKl0P00
00eFo000E_`005Kl001Fo000E_`005Kl001Fo00200001EKl001Fo000E_`00P0000=Fo00000001@00
00MFo000E_`005Kl001Fo0020002E_`01000E_`005Kl0P000UKl00T005Kl000005Kl001Fo000E_`0
0P0000=Fo00000001`0001=Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo0020000
1eKl001Fo000E_`005Kl00L00?mooomooeioo`03001oogoo00Yoo`03001oogoo021oo`00oGoo00<0
07ooOol0Egoo00D005KK001Ff`00009Ff`800005E]/005KK001Ff`0200001eKK001Ff`00E]/005KK
00X00005E]/005KK001Ff`020002E]/01000E]/005KK0P0000AFf`00E]/0009Ff`800005E]`005KL
001Fg00200001eKL001Fg000E]`005KL00P00005E]`005KL001Fg00200001UKL001Fg5KL001Fo080
0004E_`005Kl0002E_`200001EKl001Fo000E_`00P0000MFo000E_`005Kl001Fo00800001EKl001F
o000E_`00P000UKl00H005Kl001Fo000E_`20002E_`02@00E_`00000E_`005Kl001Fo00200000eKl
0000000500005EKl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo00200001eKl
001Fo000E_`005Kl00L00?mooomoofIoo`03001oogoo00Uoo`03001oogoo021oo`00oWoo00<007oo
Ool0Egoo00H005KK001Ff`00E]/200001EKK001Ff`00E]/02P0000mFf`00E]/005KK001Ff`00E]/0
05KK001Ff`00E]/00P0000IFf`00E]]Ff`00E]/200001EKK001Ff`00E]/00P0000EFg000E]`005KL
00X00005E]`005KL001Fg0020002E]`01000E]`005KL0P0000IFg000E]aFg000E_`200001EKl001F
o000E_`00P0000EFo000E_`005Kl00X00005E_`005Kl001Fo0020002E_`01000E_`005Kl0P000UKl
00@005Kl001Fo0800007E_`005Kl001Fo000E_`0200000EFo000E_`005Kl0080009Fo00<001Fo000
E_`005Kl001Fo000E_`005Kl0P0000MFo000E_`005Kl001Fo007003oOoooOom]Ool00`00Oomoo`09
Ool00`00Oomoo`0POol00?ioo`03001oogoo05Qoo`800003E]/005KK00L0000BE]/00000E]/005KK
001Ff`00E]/005KK001Ff`00E]/005KK0P000UKK00/005KK000005KK001Ff`00E]/005KK00800005
E]/005KK001Ff`07000045KL000005KL001Fg000E]`005KL001Fg000E]`005KL0P000UKL00@005KL
001Fg0800005E]`005KL001Fo00200001EKl001Fo000E_`01`00011Fo000001Fo000E_`005Kl001F
o000E_`005Kl001Fo080009Fo004001Fo000E_`200001eKl001Fo000E_`005Kl00P00005E_`005Kl
001Fo0020002E_`01000E_`005Kl0P000UKl00@005Kl001Fo0800007E_`005Kl001Fo000E_`01`00
ogooogooM7oo00<007ooOol02Woo00<007ooOol07goo003oOol00`00Oomoo`1HOol400001eKK0000
05KK001Ff`00009Ff`800007E]/005KK001Ff`00E]/00P000UKK00@005KK001Ff`800003E]/005KK
00800005E]/005KK001Ff`0900001eKK000005KL001Fg000009Fg0800005E]`005KL001Fg0020002
E]`02`00E]`00000E]`005KL001Fg000E]`00P0000=Fg000E]`02@0000MFo000001Fo000E_`00002
E_`200003EKl001Fo000E_`005Kl001Fo000E_`005Kl00800007E_`005Kl001Fo000E_`0200000eF
o000E_`005Kl001Fo000E_`005Kl001Fo0020002E_`01000E_`005Kl0P0000EFo000E_`005Kl00T0
0?mooomoogaoo`03001oogoo00Uoo`03001oogoo01moo`00ogoo0Goo00<007ooOol0Egoo0P0000AF
f`00E]]Ff`80000=E]/005KK001Ff`00E]/005KK001Ff`00E]/00P0000MFf`00E]/005KK001Ff`02
00000eKK0000000700000eKK001Ff`02000015KK001Ff`000UKK0P0000]Fg000E]`005KL001Fg000
E]`005KL00800005E]`005KL001Fg00200000eKL001Fg00900000eKl001Fo002000015Kl001Fo000
0UKl0P0000]Fo000E_`005Kl001Fo000E_`005Kl00800007E_`005Kl001Fo000E_`02P0001=Fo000
E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo00200001eKl001Fo000E_`005Kl00L00?mo
oomoohEoo`03001oogoo00Uoo`03001oogoo01moo`00ogoo0Goo00<007ooOol0F7oo0P0000]Ff`00
E]/005KK001Ff`00E]/005KK00800007E]/005KK001Ff`00E]/00P0000=Ff`0000001@0000=Ff`00
E]/00P0000AFf`00E]/0009Ff`0?001Ff`00001Ff`00E]/005KK001Ff`00E]`005KL00800005E]`0
05KL001Fg00200000eKL001Fg00700001EKL001Fg000E]`00P0000IFo000E_aFo000E_`200002eKl
001Fo000E_`005Kl001Fo000E_`00P0000MFo000E_`005Kl001Fo00700005UKl000005Kl001Fo000
E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl0P0000MFo000E_`005Kl001Fo007003oOoooOon<
Ool00`00Oomoo`09Ool00`00Oomoo`0OOol00?moo`9oo`03001oogoo05Qoo`800005E]/005KK001F
f`0200001eKK001Ff`00E]/005KK00P00005E]/005KK001Ff`020002E]/04@00E]/00000E]/005KK
001Ff`00E]/005KK001Ff`00E]/00P0000MFf`00E]`005KL001Fg00:00000eKL001Fg002000025KL
001Fg5KL001Fg000E]`2000015Kl001Fo5Kl0P0000EFo000E_`005Kl00800007E_`005Kl001Fo000
E_`0200000IFo000E_`005Kl0002E_`200002eKl001Fo000E_`005Kl001Fo000E_`00P0000MFo000
E_`005Kl001Fo007003oOoooOonCOol00`00Oomoo`09Ool00`00Oomoo`0OOol00?moo`9oo`03001o
ogoo05Qoo`800005E]/005KK001Ff`0:00001EKK001Ff`00E]/00P000UKK00@005KK001Ff`800004
E]/005KKE]/200001EKK001Ff`00E]/00P0000MFf`00E]/005KK001Ff`0800001EKL001Fg000E]`0
0P0000IFg000E]aFg000E]`200001UKL001Fg5KL001Fg0800005E]`005Kl001Fo00200001EKl001F
o000E_`02P0001EFo000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`00P0000MF
o000E_`005Kl001Fo007003oOoooOonKOol00`00Oomoo`08Ool00`00Oomoo`0OOol00?moo`=oo`03
001oogoo05Qoo`H0000@E]/00000E]/005KK001Ff`00E]/005KK001Ff`00E]/2000015KK001FfeKK
0P0000EFf`00E]/005KK00800007E]/005KK001Ff`00E]/0200000EFf`00E]/005KK0080009Fg004
001Fg000E]`200001UKL001Fg5KL001Fg0800005E]`005KL001Fg00200001EKL001Fo000E_`01`00
01QFo000001Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`005Kl001Fo000E_`200001eKl001F
o000E_`005Kl00L00?mooomooj9oo`03001oogoo00Qoo`03001oogoo01moo`00ogoo17oo00<007oo
Ool0Egoo0P0000AFf`00E]/0009Ff`800005E]/005KK001Ff`020002E]/01000E]/005KK0P0000=F
f`00E]/00P0000EFf`00E]/005KK00X0000=E]/005KK001Ff`00E]/005KK001Ff`00E]/00P0000IF
g000E]aFg000E]`200001EKL001Fg000E]`00P0000=Fg000E]`02@0000MFo000001Fo000E_`00002
E_`200003EKl001Fo000E_`005Kl001Fo000E_`005Kl00800005E_`005Kl001Fo009003oOoooOonY
Ool00`00Oomoo`08Ool00`00Oomoo`0OOol00?moo`Aoo`03001oogoo05Qoo`800005E]/005KK001F
f`020002E]/01000E]/005KK0P0000EFf`00E]/005KK00800003E]/005KK00L0000@E]/00000E]/0
05KK001Ff`00E]/005KK001Ff`00E]/20002E]/01000E]/005KK0P0000EFg000E]`005KL00800003
E]`005KL00L00003E]`005Kl00800004E_`005Kl0002E_`2000015Kl001Fo0000UKl0P0000EFo000
E_`005Kl00800005E_`005Kl001Fo007003oOoooOoncOol00`00Oomoo`07Ool00`00Oomoo`0OOol0
0?moo`Eoo`03001oogoo05Moo`80009Ff`04001Ff`00E]/200001EKK001Ff`00E]/00P0000=Ff`00
00001`0000MFf`00001Ff`00E]/00002E]/200001EKK001Ff`00E]/00P000UKK00@005KK001Ff`80
0005E]/005KK001Ff`0200000eKL001Fg00700000eKL001Fg00200001UKL001Fg5KL001Fo0800004
E_`005Kl0002E_`200001EKl001Fo000E_`00P0000EFo000E_`005Kl00L00?mooomookYoo`03001o
ogoo00Moo`03001oogoo01moo`00ogoo1Goo00<007ooOol0F7oo0P0000EFf`00E]/005KK00800003
E]/0000000D00005E]/005KK001Ff`02000015KK001FfeKK0P0000eFf`00E]/005KK001Ff`00E]/0
05KK001Ff`0200001EKK001Ff`00E]/00P0000=Ff`0000001`0000=Fg000E]`00P0000IFg000E]aF
g000E]`200001UKL001Fg5KL001Fo0800005E_`005Kl001Fo00200001EKl001Fo000E_`01`00ogoo
ogoo`Goo00<007ooOol01goo00<007ooOol07goo003oOol6Ool00`00Oomoo`1GOol200000eKK0000
000500001EKK001Ff`00E]/00P000UKK00@005KK001Ff`80000;E]/005KK001Ff`00E]/005KK001F
f`0200001EKK001Ff`00E]/00P0000=Ff`0000001@0000EFf`00E]/005KK00800006E]`005KLE]`0
05KL0P0000IFg000E]aFg000E]`200001EKL001Fg000E_`00P0000EFo000E_`005Kl00L00?mooomo
olUoo`03001oogoo00Ioo`03001oogoo01moo`00ogoo1goo00<007ooOol0Egoo0P0000EFf`00E]/0
05KK0080009Ff`04001Ff`00E]/200002eKK001Ff`00E]/005KK001Ff`00E]/00P0000MFf`00E]/0
05KK001Ff`0800001EKK001Ff`00E]/00P000UKK00@005KK001Ff`800006E]`005KLE]`005KL0P00
00EFg000E]`005KL00800003E]`005KL00T00?mooomoom1oo`03001oogoo00Ioo`03001oogoo01mo
o`00ogoo1goo00<007ooOol0Egoo0P000UKK00@005KK001Ff`800006E]/005KKE]/005KK0P0000=F
f`00E]/00P0000MFf`00E]/005KK001Ff`0800001EKK001Ff`00E]/00P000UKK00@005KK001Ff`80
0006E]/005KKE]/005KK0P0000EFg000E]`005KL00800003E]`005KL00L00?mooomoomUoo`03001o
ogoo00Moo`03001oogoo01ioo`00ogoo27oo00<007ooOol0Egoo0P0000IFf`00E]]Ff`00E]/20000
1EKK001Ff`00E]/00P0000EFf`00E]/005KK00P0000=E]/005KK001Ff`00E]/005KK001Ff`00E]/0
0P0000IFf`00E]]Ff`00E]/200001EKK001Ff`00E]/00P0000=Fg000E]`01`00ogooogooh7oo00<0
07ooOol01goo00<007ooOol07Woo003oOol8Ool00`00Oomoo`1HOol200001EKK001Ff`00E]/00P00
00=Ff`00E]/02P0000eFf`00E]/005KK001Ff`00E]/005KK001Ff`020002E]/01000E]/005KK0P00
00EFf`00E]/005KK00800003E]/005KK00L00?mooomoonQoo`03001oogoo00Ioo`03001oogoo01io
o`00ogoo2Goo00<007ooOol0Egoo0P0000=Ff`00E]/01`0000=Ff`00E]/00P0000]Ff`00E]/005KK
001Ff`00E]/005KK0080009Ff`04001Ff`00E]/200001EKK001Ff`00E]/00P0000=Ff`00E]/01`00
ogooogookgoo00<007ooOol01Woo00<007ooOol07Woo003oOol:Ool00`00Oomoo`1GOol400000eKK
001Ff`0200001UKK001FfeKK001Ff`800003E]/005KK0080009Ff`04001Ff`00E]/200001EKK001F
f`00E]/00P0000=Ff`0000001`00ogooogoomWoo00<007ooOol01Woo00<007ooOol07Woo003oOol:
Ool00`00Oomoo`1GOol200001UKK001FfeKK001Ff`80000;E]/005KK001Ff`00E]/005KK001Ff`02
00001EKK001Ff`00E]/00P0000=Ff`0000001@00ogooogooogoo0Goo00<007ooOol01Goo00<007oo
Ool07Woo003oOol;Ool00`00Oomoo`1GOol2000015KK001Ff`000UKK0P0000=Ff`00E]/00P0000EF
f`00E]/005KK00800003E]/0000000D00?mooomooomoo`Qoo`03001oogoo00Eoo`03001oogoo01io
o`00ogoo2goo00<007ooOol0F7oo0P0000EFf`00E]/005KK00800005E]/005KK001Ff`08003oOooo
OoooOol?Ool00`00Oomoo`05Ool00`00Oomoo`0NOol00?moo`aoo`03001oogoo05Moo`800005E]/0
05KK001Ff`08003oOoooOoooOolGOol00`00Oomoo`04Ool00`00Oomoo`0NOol00?moo`eoo`03001o
ogoo05Moo`H00?mooomooomooamoo`03001oogoo00Aoo`03001oogoo01ioo`00ogoo3Goo00<007oo
Ool0Egoo00<007ooOol0ogooogooogoo8Woo00<007ooOol017oo00<007ooOol07Woo003oOol>Ool0
0`00Oomoo`1FOol00`00Oomoo`3oOoooOoooOolROol00`00Oomoo`04Ool00`00Oomoo`0NOol00?mo
o`ioo`03001oogoo05Ioo`03001oogoo0?mooomooomoob=oo`03001oogoo00Aoo`03001oogoo01eo
o`00ogoo3goo00<007ooOol0E7oo00<007ooOol0ogooogooogoo97oo00<007ooOol017oo00<007oo
Ool07Goo003oOol?Ool00`00Oomoo`1DOol00`00Oomoo`3oOoooOoooOolTOol00`00Oomoo`04Ool0
0`00Oomoo`0MOol00?mooa1oo`03001oogoo05=oo`03001oogoo0?mooomooomoobEoo`03001oogoo
00=oo`03001oogoo01eoo`00ogoo4Goo00<007ooOol0DWoo00<007ooOol0ogooogooogoo9Goo00<0
07ooOol00goo00<007ooOol07Goo003oOolAOol00`00Oomoo`1BOol00`00Oomoo`3oOoooOoooOolU
Ool00`00Oomoo`03Ool00`00Oomoo`0MOol00?mooa9oo`03001oogoo055oo`03001oogoo0?mooomo
oomoobEoo`03001oogoo00=oo`03001oogoo01eoo`00ogoo4Woo00<007ooOol0DGoo00<007ooOol0
ogooogooogoo9Woo00<007ooOol00Woo00<007ooOol07Goo003oOolCOol00`00Oomoo`1@Ool00`00
Oomoo`3oOoooOoooOolVOol00`00Oomoo`02Ool00`00Oomoo`0MOol00?mooaAoo`03001oogoo04mo
o`03001oogoo0?mooomooomoobIoo`03001oogoo009oo`03001oogoo01eoo`00ogoo57oo00<007oo
Ool0Cgoo00<007ooOol0ogooogooogoo9goo00D007ooOomoo`0001moo`00ogoo5Goo00<007ooOol0
CWoo00<007ooOol0ogooogooogoo9goo00D007ooOomoo`0001moo`00ogoo5Goo00<007ooOol0CWoo
00<007ooOol0ogooogooogoo9goo00D007ooOomoo`0001moo`00ogoo5Woo00<007ooOol0CGoo00<0
07ooOol0ogooogooogoo:7oo00D007ooOomoo`0001ioo`00ogoo5goo00<007ooOol0C7oo00<007oo
Ool0ogooogooogoo:7oo00D007ooOomoo`0001ioo`00ogoo5goo00<007ooOol0C7oo00<007ooOol0
ogooogooogoo:7oo00D007ooOomoo`0001ioo`00ogoo67oo00<007ooOol0Bgoo00<007ooOol0ogoo
ogooogoo:7oo00D007ooOomoo`0001ioo`00ogoo67oo00<007ooOol0Bgoo00<007ooOol0ogooogoo
ogoo:Goo00@007ooOol001ioo`00ogoo6Goo00<007ooOol0BWoo00<007ooOol0ogooogooogoo:Goo
00@007ooOol001ioo`00ogoo6Woo00<007ooOol0BGoo00<007ooOol0ogooogooogoo:Goo00@007oo
Ool001ioo`00ogoo6Woo00<007ooOol0BGoo00<007ooOol0ogooogooogoo:Woo00<007oo00007Woo
003oOolKOol00`00Oomoo`18Ool00`00Oomoo`3oOoooOoooOolZOol00`00Ool0000NOol00?mooa]o
o`03001oogoo04Moo`03001oogoo0?mooomooomoob]oo`03001oo`0001ioo`00ogoo77oo00<007oo
Ool0AWoo00<007ooOol0ogooogooogoo:goo00<007oo00007Woo003oOolMOol00`00Oomoo`15Ool0
0`00Oomoo`3oOoooOoooOol/Ool2000NOol00?mooaeoo`03001oogoo04Eoo`03001oogoo0?mooomo
oomoobaoo`8001ioo`00ogoo7Woo00<007ooOol0A7oo00<007ooOol0ogooogooogoo;7oo00<007oo
00007Goo003oOolNOol00`00Oomoo`14Ool00`00Oomoo`3oOoooOoooOol]Ool2000MOol00?mooamo
o`03001oogoo04=oo`03001oogoo0?mooomooomoobeoo`8001eoo`00ogoo87oo00<007ooOol0@Woo
00<007ooOol0ogooogooogoo;Goo0P007Goo003oOolPOol00`00Oomoo`12Ool00`00Oomoo`3oOooo
OoooOol^Ool00`00Oomoo`0KOol00?moob5oo`03001oogoo045oo`03001oogoo0?mooomooomoobYo
o`D001eoo`00ogoo8Goo00<007ooOol0@Goo00<007ooOol0ogooogooogoo8Woo20008Woo003oOolR
Ool00`00Oomoo`10Ool00`00Oomoo`3oOoooOoooOolKOol7000ZOol00?moob=oo`03001oogoo03mo
o`03001oogoo0?mooomooomooa=oo`P0035oo`00ogoo8goo00<007ooOol0?goo00<007ooOol0ogoo
ogooogoo2goo2000>Goo003oOolTOol00`00Oomoo`0nOol00`00Oomoo`3oOoooOoooOol4Ool70011
Ool00?moobAoo`03001oogoo03ioo`03001oogoo0?mooomooo]oo`P004Qoo`00ogoo9Goo00<007oo
Ool0?Goo00<007ooOol0ogooogoolgoo2000D7oo003oOolUOol00`00Oomoo`0mOol00`00Oomoo`3o
OoooOoo[Ool8001HOol00?moobIoo`03001oogoo03aoo`03001oogoo0?mooomoonAoo`L0061oo`00
ogoo9goo00<007ooOol0>goo00<007ooOol0ogooogoog7oo2000Igoo003oOolWOol00`00Oomoo`0k
Ool00`00Oomoo`3oOoooOooDOol8001_Ool00?moobQoo`03001oogoo03Uoo`03001oogoo0?mooomo
oleoo`P007Moo`00ogoo:7oo00<007ooOol0>Goo00<007ooOol0ogooogooaWoo1`00Ogoo003oOolY
Ool00`00Oomoo`0hOol00`00Oomoo`3oOoooOonnOol80026Ool00?moobYoo`03001oogoo03Moo`03
001oogoo0?mooomookIoo`P008ioo`00ogoo:Woo00<007ooOol0=goo00<007ooOol0ogooogoo[goo
1`00UWoo003oOol[Ool00`00Oomoo`0fOol00`00Oomoo`3oOoooOonWOol8002MOol00?moob]oo`03
001oogoo03Ioo`03001oogoo0?mooomooimoo`P00:Eoo`00ogoo;7oo00<007ooOol0=Goo00<007oo
Ool0ogooogooUgoo2000[Goo003oOol]Ool00`00Oomoo`0dOol00`00Oomoo`3oOoooOon@Ool7002e
Ool00?moobeoo`03001oogoo03Aoo`03001oogoo0?mooomoohQoo`P00;aoo`00ogoo;Woo00<007oo
Ool0<goo00<007ooOol0ogooogooP7oo2000a7oo003oOol^Ool00`00Oomoo`0cOol00`00Oomoo`3o
OoooOomhOol8003<Ool00?moobmoo`03001oogoo039oo`03001oogoo0?mooomoog5oo`L00=Aoo`00
ogoo<7oo00<007ooOol0<Goo00<007ooOol0ogooogooJGoo2000fgoo003oOol`Ool00`00Oomoo`0a
Ool00`00Oomoo`3oOoooOomQOol8003SOol00?mooc5oo`03001oogoo031oo`03001oogoo0?mooomo
oeYoo`L00>]oo`00ogoo<Goo00<007ooOol0<7oo00<007ooOol0ogooogooDWoo2000lWoo003oOolb
Ool00`00Oomoo`0_Ool00`00Oomoo`3oOoooOom:Ool8003jOol00?mooc=oo`03001oogoo02ioo`03
001oogoo0?mooomood9oo`P00?moo`=oo`00ogoo<goo00<007ooOol0;Woo00<007ooOol0ogooogoo
>goo1`00ogoo2goo003oOoldOol00`00Oomoo`0]Ool00`00Oomoo`3oOoooOolcOol8003oOolBOol0
0?moocAoo`03001oogoo02aoo`03001oogoo0?mooomoobaoo`P00?mooaYoo`00ogoo=Goo00<007oo
Ool0:goo00<007ooOol0ogooogoo97oo2000ogoo8Woo003oOolfOol00`00Oomoo`0ZOol00`00Oomo
o`3oOoooOolMOol7003oOolZOol00?moocIoo`03001oogoo02Yoo`03001oogoo0?mooomooaEoo`P0
0?mooc5oo`00ogoo=goo00<007ooOol0:Goo00<007ooOol0ogooogoo3Goo2000ogoo>Goo003oOolg
Ool00`00Oomoo`0YOol00`00Oomoo`3oOoooOol6Ool7003oOom1Ool00?moocQoo`03001oogoo02Qo
o`03001oogoo0?moooeoo`P00?moodQoo`00ogoo>7oo00<007ooOol0:7oo00<007ooOol0ogoomGoo
2000ogooD7oo003oOoliOol00`00Oomoo`0WOol00`00Oomoo`3oOoo]Ool8003oOomHOol00?moocYo
o`03001oogoo02Ioo`03001oogoo0?moonIoo`L00?moof1oo`00ogoo>Woo00<007ooOol09Woo00<0
07ooOol0ogoogWoo2000ogooIgoo003oOolkOol00`00Oomoo`0UOol00`00Oomoo`3oOooFOol8003o
Oom_Ool00?mooc]oo`03001oogoo02Eoo`03001oogoo0?moolioo`P00?moogMoo`00ogoo?7oo00<0
07ooOol097oo00<007ooOol0ogooagoo1`00ogooOgoo003oOolmOol00`00Oomoo`0SOol00`00Oomo
o`3oOonoOol8003oOon6Ool00?mooceoo`03001oogoo02=oo`03001oogoo0?mookMoo`P00?moohio
o`00ogoo?Woo00<007ooOol08Woo00<007ooOol0ogoo/7oo1`00ogooUWoo003oOolnOol00`00Oomo
o`0ROol00`00Oomoo`3oOonXOol8003oOonMOol00?moocmoo`03001oogoo025oo`03001oogoo0?mo
oj1oo`P00?moojEoo`00ogoo@7oo00<007ooOol087oo00<007ooOol0ogooV7oo2000ogoo[Goo003o
Oom0Ool00`00Oomoo`0POol00`00Oomoo`3oOonAOol7003oOoneOol00?mood5oo`03001oogoo01io
o`03001oogoo0?moohYoo`P00?mookaoo`00ogoo@Goo00<007ooOol07Woo00<007ooOol0ogooPWoo
2000ogooa7oo003oOom2Ool00`00Oomoo`0MOol00`00Oomoo`3oOomjOol8003oOoo<Ool00?mood=o
o`03001oogoo01aoo`03001oogoo0?moog=oo`L00?moomAoo`00ogoo@goo00<007ooOol077oo00<0
07ooOol0ogooJgoo2000ogoofgoo003oOom4Ool00`00Oomoo`0KOol00`00Oomoo`3oOomSOol8003o
OooSOol00?moodAoo`03001oogoo01]oo`03001oogoo0?mooeaoo`L00?moon]oo`00ogooAGoo00<0
07ooOol06Woo00<007ooOol0ogooE7oo2000ogoolWoo003oOom6Ool00`00Oomoo`0IOol00`00Oomo
o`3oOom<Ool8003oOoojOol00?moodIoo`03001oogoo01Uoo`03001oogoo0?moodAoo`P00?mooomo
o`=oo`00ogooAgoo00<007ooOol067oo00<007ooOol0ogoo?Goo1`00ogooogoo2goo003oOom7Ool0
0`00Oomoo`0HOol00`00Oomoo`3oOoleOol8003oOoooOolBOol00?moodQoo`03001oogoo01Moo`03
001oogoo0?moobeoo`P00?mooomooaYoo`00ogooBGoo00<007ooOol05Woo00<007ooOol0ogoo9Goo
2000ogooogoo8Woo003oOom9Ool00`00Oomoo`0FOol00`00Oomoo`3oOolNOol7003oOoooOolZOol0
0?moodYoo`03001oogoo01Eoo`03001oogoo0?mooaIoo`P00?mooomooc5oo`00ogooBWoo00<007oo
Ool05Goo00<007ooOol0ogoo3Woo2000ogooogoo>Goo003oOom;Ool00`00Oomoo`0DOol00`00Oomo
o`3oOol7Ool7003oOoooOom1Ool00?moodaoo`03001oogoo01=oo`03001oogoo0?ioo`P00?mooomo
odQoo`00ogooC7oo00<007ooOol04goo00<007ooOol0mWoo2000ogooogooD7oo003oOom=Ool00`00
Oomoo`0BOol00`00Oomoo`3^Ool8003oOoooOomHOol00?moodeoo`03001oogoo015oo`03001oogoo
0>Qoo`L00?mooomoof1oo`00ogooCWoo00<007ooOol047oo00<007ooOol0h7oo2000ogooogooIgoo
003oOom>Ool00`00Oomoo`0@Ool00`00Oomoo`3HOol8003oOoooOom_Ool00?moodmoo`03001oogoo
00moo`03001oogoo0=1oo`P00?mooomoogMoo`00ogooD7oo00<007ooOol03Woo00<007ooOol0bGoo
1`00ogooogooOgoo003oOom@Ool00`00Oomoo`0>Ool00`00Oomoo`31Ool8003oOoooOon6Ool00?mo
oe5oo`03001oogoo00eoo`03001oogoo0;Uoo`P00?mooomoohioo`00ogooDGoo00<007ooOol03Goo
00<007ooOol0/Woo1`00ogooogooUWoo003oOomBOol00`00Oomoo`0<Ool00`00Oomoo`2ZOol8003o
OoooOonMOol00?mooe=oo`03001oogoo00]oo`03001oogoo0:9oo`P00?mooomoojEoo`00ogooDgoo
00<007ooOol02goo00<007ooOol0VWoo2000ogooogoo[Goo003oOomDOol00`00Oomoo`0:Ool00`00
Oomoo`2COol7003oOoooOoneOol00?mooeAoo`03001oogoo00Yoo`03001oogoo08]oo`P00?mooomo
okaoo`00ogooEGoo00<007ooOol02Goo00<007ooOol0Pgoo2000ogooogooa7oo003oOomFOol00`00
Oomoo`08Ool00`00Oomoo`1kOol8003oOoooOoo<Ool00?mooeIoo`03001oogoo00Qoo`03001oogoo
07Aoo`L00?mooomoomAoo`00ogooEgoo00<007ooOol01goo00<007ooOol0K7oo2000ogooogoofgoo
003oOomGOol00`00Oomoo`07Ool00`00Oomoo`1TOol8003oOoooOooSOol00?mooeQoo`03001oogoo
00Ioo`03001oogoo05eoo`L00?mooomoon]oo`00ogooFGoo00<007ooOol01Goo00<007ooOol0EGoo
2000ogooogoolWoo003oOomIOol00`00Oomoo`05Ool00`00Oomoo`1=Ool8003oOoooOoojOol00?mo
oeYoo`03001oogoo00=oo`03001oogoo04Ioo`P00?mooomooomoo`=oo`00ogooFWoo00<007ooOol0
0goo00<007ooOol0?goo1`00ogooogooogoo2goo003oOomKOol00`00Oomoo`02Ool00`00Oomoo`0g
Ool8003oOoooOoooOolBOol00?mooeaoo`05001oogooOol0000aOol8003oOoooOoooOolJOol00?mo
oeaoo`05001oogooOol0000YOol8003oOoooOoooOolROol00?mooeeoo`04001oogoo000ROol7003o
OoooOoooOolZOol00?mooeeoo`04001oogoo000JOol8003oOoooOoooOolaOol00?mooeioo`03001o
o`00019oo`P00?mooomooomoocUoo`00ogooGgoo0P002goo1`00ogooogooogoo@Goo003oOomOOol2
0003Ool8003oOoooOoooOom8Ool00?moof1oo`@00?mooomooomooe1oo`00ogooogooogooogoo]7oo
003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOooo
OoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol0
0?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomo
oomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00
ogooogooogooogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogoo
ogoo]7oo003oOoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003o
OoooOoooOoooOondOol00?mooomooomooomookAoo`00ogooogooogooogoo]7oo003oOoooOoooOooo
OondOol00?mooomooomooomookAoo`00\
\>"], "Graphics",
  CellLabel->"From In[107]:=",
  Evaluatable->False,
  ImageSize->{391.625, 327.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
Vector potential of the pigtail, a current of strength 1 is flowing \
back and forth in both circuits.\
\>", "Text",
  PageBreakBelow->Automatic],

Cell[BoxData[{
    \(\(g = 
        Table[{u[\([i, j + 1]\)] - u[\([i, j]\)], 
            u[\([i + 1, j]\)] - u[\([i, j]\)]}, {i, 1, nz - 1}, {j, 1, 
            ns - 1}];\)\), "\n", 
    \(\(lrow = 
        Table[{u[\([nz, j + 1]\)] - u[\([nz, j]\)], 
            u[\([nz, j]\)] - u[\([nz - 1, j]\)]}, {j, 1, 
            ns - 1}];\)\ \), "\[IndentingNewLine]", 
    \(\(g = Append[g, lrow];\)\), "\[IndentingNewLine]", 
    \(\(lcol = 
        Append[Table[{u[\([i, ns]\)] - u[\([i, ns - 1]\)], 
              u[\([i + 1, ns]\)] - u[\([i, ns]\)]}, {i, 1, 
              nz - 1}], {u[\([nz, ns]\)] - u[\([nz, ns - 1]\)], 
            u[\([nz, ns]\)] - 
              u[\([nz - 1, ns]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(g = Transpose[Append[Transpose[g], lcol]];\)\)}], "Input",
  CellFrame->True,
  PageBreakAbove->Automatic,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(\[Mu]\_0 = 4.  \[Pi]*10\^\(-7\);\)\)], "Input",
  CellLabel->"In[123]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  "The shape of the conductors now suggests an elliptic contour to calculate \
the current. The elliptic path of the line integral has to run completely \
outside of the current. Adjust the half axes a and b accordingly; for high \
accuracy  it is necessary to control ",
  StyleBox["all",
    FontSlant->"Italic"],
  " 4 currents precisely :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dphi = \[Pi]/100;\)\), "\[IndentingNewLine]", 
    \(\({xr, yr} = {91, 
          12.5};\) (*center\ point\ for\ contour\ integral\ 1\ *) \), "\
\[IndentingNewLine]", 
    \(i = 
      Table[\ Sum[\(-dphi\) \((\[IndentingNewLine]g[\([Round[
                        yr + b*Sin[phi]], Round[xr + a*Cos[phi]], 2]\)]*a*
                  Sin[phi] + 
                g[\([Round[yr + b*Sin[phi]], Round[xr + a*Cos[phi]], 1]\)]*b*
                  Cos[phi])\), \[IndentingNewLine]{phi, 0, 2  \[Pi], 
            dphi}], {a, 13, 20}, {b, 5, 10}]\), "\[IndentingNewLine]", 
    \(iMean1 = Apply[Plus, Flatten[i]]/Length[Flatten[i]]\)}], "Input",
  CellLabel->"In[124]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \({{1.0086300393409398`, 1.0016138010116236`, 1.004541203459823`, 
        1.0003888043455733`, 0.9986611839016896`, 
        0.999782900391568`}, {1.0028078676208876`, 1.004648526865905`, 
        1.002122200514111`, 1.0004746695136975`, 0.9990563574766372`, 
        0.9999500503116501`}, {0.9988637481726881`, 1.0006192647955652`, 
        1.0001450804082248`, 0.9981300505905364`, 0.9977828323759473`, 
        0.9986370142833205`}, {1.0011551798626719`, 1.0014329162033524`, 
        1.0012578018181877`, 0.9993586013908905`, 1.000266446997519`, 
        1.0003132457650337`}, {1.0039404669327645`, 1.003435706862999`, 
        1.002050984053594`, 0.9999368744724125`, 1.0006017554137348`, 
        0.9998434324990672`}, {1.0024166147737783`, 1.0010285111033268`, 
        0.9987067599413505`, 0.9973143433165751`, 0.9984034995777609`, 
        0.9975500941041617`}, {0.996740893210438`, 1.00119430064056`, 
        0.9993943721437394`, 0.9982528801861099`, 0.9990200295185259`, 
        0.9982976962678284`}, {0.9958729621278183`, 0.9992323844497789`, 
        0.997195411007099`, 0.9959864317321725`, 0.9968479626386871`, 
        0.996144930980008`}}\)], "Output",
  CellLabel->"Out[126]="],

Cell[BoxData[
    \(1.0000010226119234`\)], "Output",
  CellLabel->"Out[127]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dphi = \[Pi]/100;\)\), "\[IndentingNewLine]", 
    \(\({xr, yr} = {179, 
          12.5};\) (*center\ point\ for\ contour\ integral\ 2\ *) \), "\
\[IndentingNewLine]", 
    \(i = 
      Table[\ Sum[\(-dphi\) \((\[IndentingNewLine]g[\([Round[
                        yr + b*Sin[phi]], Round[xr + a*Cos[phi]], 2]\)]*a*
                  Sin[phi] + 
                g[\([Round[yr + b*Sin[phi]], Round[xr + a*Cos[phi]], 1]\)]*b*
                  Cos[phi])\), \[IndentingNewLine]{phi, 0, 2  \[Pi], 
            dphi}], {a, 13, 20}, {b, 5, 10}]\), "\[IndentingNewLine]", 
    \(iMean2 = Apply[Plus, Flatten[i]]/Length[Flatten[i]]\)}], "Input",
  CellLabel->"In[128]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \({{\(-1.0086678967356462`\), \(-1.0016096708428386`\), \
\(-1.0045397048433502`\), \(-1.000353307094333`\), \(-0.9986147447063354`\), \
\(-0.9997341504467653`\)}, {\(-1.0028318035914499`\), \
\(-1.0046504212915113`\), \(-1.002129123206402`\), \(-1.0004600748518249`\), \
\(-0.9990328818781903`\), \(-0.9999267497559879`\)}, \
{\(-0.9988845487742206`\), \(-1.000625295088487`\), \(-1.0001475240310387`\), \
\(-0.9981211496389829`\), \(-0.9977663731565145`\), \(-0.99862305050438`\)}, \
{\(-1.0011614479166429`\), \(-1.0014407004770838`\), \
\(-1.0012614522834953`\), \(-0.9993494750732013`\), \(-1.0002503977561563`\), \
\(-1.0002994356775103`\)}, {\(-1.0039521456853027`\), \
\(-1.003446407041435`\), \(-1.0020562443862773`\), \(-0.9999285662230475`\), \
\(-1.0005887727134253`\), \(-0.9998312047788847`\)}, \
{\(-1.0024294527652005`\), \(-1.001039009645611`\), \(-0.9987157463954808`\), \
\(-0.9973094993045533`\), \(-0.9983968633435607`\), \(-0.997544484707001`\)}, \
{\(-0.996768517421727`\), \(-1.0012115186407113`\), \(-0.9994046620020289`\), \
\(-0.9982490793622083`\), \(-0.9990145472064769`\), \
\(-0.9982935716743421`\)}, {\(-0.9958978667366918`\), \
\(-0.9992523076832174`\), \(-0.9972088762500655`\), \(-0.995986269645112`\), \
\(-0.9968483061261258`\), \(-0.9961469380167327`\)}}\)], "Output",
  CellLabel->"Out[130]="],

Cell[BoxData[
    \(\(-1.000000046612033`\)\)], "Output",
  CellLabel->"Out[131]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dphi = \[Pi]/100;\)\), "\[IndentingNewLine]", 
    \(\({xr, yr} = {267, 
          12.5};\) (*center\ point\ for\ contour\ integral\ 3\ *) \), "\
\[IndentingNewLine]", 
    \(i = 
      Table[\ Sum[\(-dphi\) \((\[IndentingNewLine]g[\([Round[
                        yr + b*Sin[phi]], Round[xr + a*Cos[phi]], 2]\)]*a*
                  Sin[phi] + 
                g[\([Round[yr + b*Sin[phi]], Round[xr + a*Cos[phi]], 1]\)]*b*
                  Cos[phi])\), \[IndentingNewLine]{phi, 0, 2  \[Pi], 
            dphi}], {a, 13, 20}, {b, 5, 10}]\), "\[IndentingNewLine]", 
    \(iMean3 = Apply[Plus, Flatten[i]]/Length[Flatten[i]]\)}], "Input",
  CellLabel->"In[132]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \({{1.0086668120018736`, 1.001609363598657`, 1.0045396311151826`, 
        1.0003540760333371`, 0.9986158113552847`, 
        0.9997356031146206`}, {1.002831029305853`, 1.0046503577808306`, 
        1.002128983265912`, 1.0004604792530398`, 0.9990335831213172`, 
        0.9999277391053742`}, {0.9988836778744637`, 1.000624972340252`, 
        1.0001474487539879`, 0.9981213562234235`, 0.9977669335650405`, 
        0.9986238614761712`}, {1.0011607624471135`, 1.0014402469440435`, 
        1.0012612673571397`, 0.999349592101835`, 1.0002509351428062`, 
        1.000300209205937`}, {1.003951585994468`, 1.0034460972215884`, 
        1.002056211780975`, 0.9999288480151867`, 1.000589425655256`, 
        0.9998321067726954`}, {1.0024289941792555`, 1.0010388106118255`, 
        0.9987157764723744`, 0.9973098701108551`, 0.9983975921245075`, 
        0.9975454953156434`}, {0.996767869017139`, 1.0012113625205799`, 
        0.9994048095588413`, 0.9982495824592311`, 0.9990154035847212`, 
        0.9982947331722216`}, {0.9958973599011021`, 0.9992522562018303`, 
        0.9972091666626499`, 0.9959869209922967`, 0.9968493176623245`, 
        0.9961482819134629`}}\)], "Output",
  CellLabel->"Out[134]="],

Cell[BoxData[
    \(1.000000262716344`\)], "Output",
  CellLabel->"Out[135]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dphi = \[Pi]/100;\)\), "\[IndentingNewLine]", 
    \(\({xr, yr} = {355, 
          12.5};\) (*center\ point\ for\ contour\ integral\ 4\ *) \), "\
\[IndentingNewLine]", 
    \(i = 
      Table[\ Sum[\(-dphi\) \((\[IndentingNewLine]g[\([Round[
                        yr + b*Sin[phi]], Round[xr + a*Cos[phi]], 2]\)]*a*
                  Sin[phi] + 
                g[\([Round[yr + b*Sin[phi]], Round[xr + a*Cos[phi]], 1]\)]*b*
                  Cos[phi])\), \[IndentingNewLine]{phi, 0, 2  \[Pi], 
            dphi}], {a, 13, 20}, {b, 5, 10}]\), "\[IndentingNewLine]", 
    \(iMean4 = Apply[Plus, Flatten[i]]/Length[Flatten[i]]\)}], "Input",
  CellLabel->"In[136]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \({{\(-1.008697728934588`\), \(-1.001645680921838`\), \
\(-1.0045617829407332`\), \(-1.0003709164541712`\), \(-0.9986292676868811`\), \
\(-0.9997332242153977`\)}, {\(-1.0028610951795507`\), \
\(-1.0046690078699394`\), \(-1.0021449117445178`\), \(-1.0004721274173207`\), \
\(-0.9990397169281897`\), \(-0.9999198931962624`\)}, \
{\(-0.9989204894575551`\), \(-1.0006503661528863`\), \
\(-1.0001639361079346`\), \(-0.9981352027191772`\), \(-0.9977712690667705`\), \
\(-0.9986134969871463`\)}, {\(-1.0012029501496003`\), \
\(-1.0014689523521463`\), \(-1.0012805239845384`\), \(-0.9993665967693908`\), \
\(-1.0002546794558898`\), \(-1.0002900259993712`\)}, \
{\(-1.0039818763941388`\), \(-1.0034643895969293`\), \
\(-1.0020657710848895`\), \(-0.9999362184762789`\), \(-1.000583373749032`\), \
\(-0.9998128675420924`\)}, {\(-1.0024524657818825`\), \
\(-1.0010509851390528`\), \(-0.9987172746709185`\), \(-0.9973080887353579`\), \
\(-0.9983799546047941`\), \(-0.9975127476233154`\)}, \
{\(-0.9967839367565744`\), \(-1.0012135492932226`\), \
\(-0.9993981423298454`\), \(-0.9982390291987605`\), \(-0.9989889021203633`\), \
\(-0.9982515638014464`\)}, {\(-0.9959083566201437`\), \
\(-0.9992453607028365`\), \(-0.9971909624449274`\), \(-0.9959638903254456`\), \
\(-0.9968076269409665`\), \(-0.9960881720448475`\)}}\)], "Output",
  CellLabel->"Out[138]="],

Cell[BoxData[
    \(\(-1.000004361430622`\)\)], "Output",
  CellLabel->"Out[139]="]
}, Open  ]],

Cell["\<\
If all currents have their required values, then the inductance is:\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ind = \[Mu]\_0*
        Sum[g[\([i, j]\)] . g[\([i, j]\)], {i, 1, nz}, {j, 1, ns}]\)], "Input",\

  CellLabel->"In[140]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(9.823967016943998`*^-7\)], "Output",
  CellLabel->"Out[140]="]
}, Open  ]],

Cell[TextData[{
  "Results for the external inductances from the three pairs of currents \
{1,0},{0,1},and {1,1}:\n",
  Cell[BoxData[
      \(TraditionalForm\`L\_1'\)]],
  "    = 0.493248  [\[Mu]H/m]  (v1 = 0.196541,  v2 = - 0.196598,   v3 = - \
0.0018,       v4 = - 0.00004)\n",
  Cell[BoxData[
      \(TraditionalForm\`L\_2'\)]],
  "    = 0.493260  [\[Mu]H/m]  (v1 = 0.000039,  v2 =   0.001824,   v3 =   \
0.196572,    v4 = - 0.196572)\n",
  Cell[BoxData[
      \(TraditionalForm\`LL\_12'\)]],
  "= 0.982397  [\[Mu]H/m]  (v1 = 0.196581,  v2 = - 0.1947736, v3 =   \
0.1947728,  v4 = - 0.196612)\n\nThe internal inductance amounts to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_0\/\(8  \[Pi]\)\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`5*10\^\(-8\)\)]],
  " [H/m] per conductor (",
  StyleBox["Ref. 7",
    FontWeight->"Bold"],
  ", p.320) and the complete result is:\n",
  Cell[BoxData[
      \(TraditionalForm\`L\_1'\)]],
  "= 0.593248  [\[Mu]H/m], ",
  Cell[BoxData[
      \(TraditionalForm\`L\_2'\)]],
  " = 0.593260  [\[Mu]H/m], ",
  Cell[BoxData[
      \(TraditionalForm\`LL\_12'\)]],
  "= 1.182397  [\[Mu]H/m]\n\nWith (37) there is then the mutual inductance",
  StyleBox[" that is responsible for the crosstalk",
    FontSlant->"Italic"],
  ":\n\n",
  Cell[BoxData[
      \(TraditionalForm\`L\_12'\)]],
  "= - 3.34  [nH/m].\n\nThe negative sign can be understood from the \
following argument: conductor 1 generates with current +1 a certain amount of \
flux between conductors 3 and 4. The flux originating from conductor 2 with \
current in opposite direction is closer to the region between conductor 3 and \
4 and has therefore (because it depends logarithmically on the distance) in \
this place a bigger impact, so that the addition of these two fluxes will \
give a negative number.\n\tThe obtained values for the capacities and \
inductances will now be used in the following code to calculate the \
propagating pulse."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Code  (Animation of Double Pulse including Crosstalk)"
}], "Subsection",
  PageBreakAbove->True],

Cell["RAM requirements: Front End 60 MB, Kernel 20 MB", "Text"],

Cell[BoxData[{
    \(\(npl = 300;\) (*\ number\ of\ plots\ *) \), "\[IndentingNewLine]", 
    \(\(dt = 1. *10\^\(-12\);\)\  (*\ 1\ psec\ *) \), "\[IndentingNewLine]", 
    \(\(dx = 0.004;\)\  (*\ 
      4\ mm\ *) \[IndentingNewLine] (*dx\/dt \[GreaterGreater] 
        speed\ of\ propagation\ for\ stability, \ 
      trade - off\ with\ computational\ speed*) \), "\[IndentingNewLine]", 
    \(\(m = 250;\)\  (*\ 
      array\ dimension\  \[Rule] \ space\ distance\ m*dx\  = \ 
        1\ m\ *) \), "\[IndentingNewLine]", 
    \(\(nmax = 50000;\)\ \  (*\ 
      time\ \(considered : \ nmax\ *\ dt\)\ \ *) \), "\[IndentingNewLine]", 
    \(\(pl = Round[nmax/npl];\)\  (*\ 
      snapshot\ after\ every\ pl\ timesteps\ *) \), "\[IndentingNewLine]", 
    \(k = 2; \  (*\ number\ of\ circuits\ *) \[IndentingNewLine] (*\ 
      define\ input\ pulse\ *) \[IndentingNewLine]rise = 
      Round[1. *10\^\(-9\)/dt];\), "\[IndentingNewLine]", 
    \(\(width = Round[10.5*10\^\(-9\)/dt];\)\), "\[IndentingNewLine]", 
    \(\(fall = Round[1. *10\^\(-9\)/dt];\)\), "\[IndentingNewLine]", 
    \(\(emp = Round[12.5*10\^\(-9\)/dt];\)\), "\[IndentingNewLine]", 
    \(\(len = 
        rise + width + fall + emp + rise + width + 
          fall;\)\), "\[IndentingNewLine]", 
    \(\(uin = Table[1. *j/rise, {j, 1, rise}];\)\), "\[IndentingNewLine]", 
    \(\(uin = 
        Append[uin, Table[1. , {j, 1, width}]];\)\), "\[IndentingNewLine]", 
    \(\(uin = 
        Append[uin, 
          Table[1.  - j/fall, {j, 1, fall}]];\)\), "\[IndentingNewLine]", 
    \(\(uin = 
        Append[uin, Table[0. , {j, 1, emp}]];\)\), "\[IndentingNewLine]", 
    \(\(uin = 
        Append[uin, 
          Table[1. *j/rise, {j, 1, rise}]];\)\), "\[IndentingNewLine]", 
    \(\(uin = 
        Append[uin, Table[1. , {j, 1, width}]];\)\), "\[IndentingNewLine]", 
    \(\(uin = 
        Append[uin, 
          Table[1.  - j/fall, {j, 1, fall}]];\)\), "\[IndentingNewLine]", 
    \(\(uin = 
        Append[uin, 
          Table[0. , {j, 1, nmax - len}]];\)\), "\[IndentingNewLine]", 
    \(\(uin = Flatten[uin];\)\)}], "Input",
  CellLabel->"In[1]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell["Parameters per Unit Length:", "Text"],

Cell[BoxData[{
    RowBox[{\(res = 8. ;\), 
      "   ", \( (*\ 
        resistance\ in\ \[CapitalOmega]\ per\ meter\ *) \)}], "\
\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"rm", "=", 
          RowBox[{"(", GridBox[{
                {"res", "0"},
                {"0", "res"}
                }], ")"}]}], ";"}], "\[IndentingNewLine]", 
      " ", \( (*\ 
        capacitance\ in\ F\ per\ meter\ \ *) \)}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"cm", "=", 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"65.", \(-0.117\)},
                  {\(-0.117\), "65."}
                  }], ")"}], "*", \(10\^\(-12\)\)}]}], 
        ";", \( (*\ now\ incl\ crosstalk\ *) \), 
        "\[IndentingNewLine]", \(ci = Inverse[cm]\), ";"}], 
      "\[IndentingNewLine]", 
      " ", \( (*\ 
        inductance\ in\ H\ per\ meter\ \ *) \)}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"lm", "=", 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"0.59325", \(-0.00334\)},
                  {\(-0.00334\), "0.59326"}
                  }], ")"}], "*", \(10\^\(-6\)\)}]}], ";"}], \( (*\ 
        now\ incl\ crosstalk\ *) \)}], "\[IndentingNewLine]", \(li = 
        Inverse[lm];\), "\[IndentingNewLine]", 
    RowBox[{\(zl = 220;\), 
      " ", \( (*\ Termination\ left\ \ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(zr = 220;\), \( (*\ Termination\ right\ \ *) \)}]}], "Input",
  CellLabel->"In[22]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell["Initialization and Setup of Coefficient Matrices:", "Text",
  PageBreakAbove->True],

Cell[BoxData[{
    \(\(id = IdentityMatrix[k];\)\), "\[IndentingNewLine]", 
    \(u1 = \(u0 = Table[0. , {m}, {k}]\); \ 
    i1 = \(i0 = Table[0. , {m}, {k}]\);\), "\[IndentingNewLine]", 
    \(m1 = \((id - \(\((dt\/dx)\)\^2\) ci . li)\); 
    m2 = \(1\/2\) \(\((dt\/dx)\)\^2\) \((ci . li)\); 
    m3 = \(-\(1\/2\)\) \((dt\/dx)\) ci;\), "\[IndentingNewLine]", 
    \(m4 = \((id - dt\ li . rm)\) . \((id - \(\((dt\/dx)\)\^2\) li . ci)\); 
    m5 = \(1\/2\) \(\((dt\/dx)\)\^2\) \((id - dt\ li . rm)\) . \((li . 
              ci)\);\), "\[IndentingNewLine]", 
    \(\(m6 = \(-\(1\/2\)\) \((dt\/dx)\) \((id - dt\ li . rm)\) . 
            li;\)\), "\[IndentingNewLine]", 
    \(\(m8 = 
        Inverse[id - \(\((dt\/dx)\)\^2\) 
                ci . li] . \((id + \(\((dt\/dx)\)\^2\) 
                ci . li)\);\)\), "\[IndentingNewLine]", 
    \(\(m9 = 
        2 \( dt\/dx\) 
          Inverse[id - \(\((dt\/dx)\)\^2\) ci . li] . 
            ci;\)\), "\[IndentingNewLine]", 
    \(\(m10 = id - dt\ li . rm;\)\), "\[IndentingNewLine]", 
    \(\(m11 = 
        2 \( dt\/dx\) \((id - dt\ li . rm\ )\) . \ 
            Inverse[id - \(\((dt\/dx)\)\^2\) li . ci] . 
            li\ ;\)\), "\[IndentingNewLine]", 
    \(\(m12 = \((id - dt\ li . rm\ )\) . 
          Inverse[id - \(\((dt\/dx)\)\^2\) 
                li . ci] . \((id + \(\((dt\/dx)\)\^2\) 
                li . ci)\);\)\[IndentingNewLine] (*\ 
      output\ main\ and\ 2\ adjacent\ wires\ *) \), "\[IndentingNewLine]", 
    \(uout = {0, 0}; uout1 = {0, 0}; uout2 = {0, 0};\)}], "Input",
  CellLabel->"In[30]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell["Static Initial Condition:", "Text",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[uin, PlotJoined \[Rule] True, 
        AxesLabel -> {\*"\"\<\!\(10\^\(-12\)\)sec\>\"", "\<Ampl\>"}];\)\)], \
"Input",
  CellLabel->"In[43]:=",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P00025A000`40O003h00OogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00ogooogooogooHgoo003oOoooOoooOomSOol0099oo`X000]oo`@000ioo`@000ioo`@000io
o`@002aoo``000]oo`@000ioo`@000ioo`@000ioo`@0031oo`D000ioo`@000ioo`@000ioo`@000io
o`@0039oo`L000Yoo`@000ioo`@000ioo`@000ioo`@0031oo`H000ioo`@000ioo`@000ioo`@000io
o`@008Yoo`00TWoo2P002Goo20002Woo20002Woo20002Woo2000:Woo30002Goo20002Woo20002Woo
20002Woo2000;7oo2@002Woo20002Woo20002Woo20002Woo2000<7oo1`0027oo20002Woo20002Woo
20002Woo2000;7oo2P002Woo20002Woo20002Woo20002Woo2000R7oo002FOol2000=Ool20004Ool2
000:Ool20004Ool2000:Ool20004Ool2000:Ool20004Ool2000[Ool30006Ool20009Ool20004Ool2
000:Ool20004Ool2000:Ool20004Ool2000:Ool20004Ool2000[Ool40004Ool30009Ool20004Ool2
000:Ool20004Ool2000:Ool20004Ool2000:Ool20004Ool2000cOol2000:Ool20004Ool2000:Ool2
0004Ool2000:Ool20004Ool2000:Ool20004Ool2000/Ool30005Ool30009Ool20004Ool2000:Ool2
0004Ool2000:Ool20004Ool2000:Ool20004Ool20028Ool009Ioo`8000aoo`8000Ioo`8000Qoo`80
00Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8002]oo`<000moo`8000Ioo`8000Qoo`8000Ioo`80
00Qoo`8000Ioo`8000Qoo`8000Ioo`8002Yoo`8000Moo`<000Moo`8000Ioo`8000Qoo`8000Ioo`80
00Qoo`8000Ioo`8000Qoo`8000Ioo`80039oo`8000Uoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`80
00Ioo`8000Qoo`8000Ioo`8003Aoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`80
00Qoo`8000Ioo`8008Moo`00UWoo0P0037oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P00
27oo0P001Woo0P00;7oo0`003Woo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P00
1Woo0P00=7oo0P001goo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P00
<Woo0P002Goo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P00=Goo0P00
1goo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P00Qgoo002FOol2000;
Ool20008Ool20006Ool20008Ool20006Ool20008Ool20006Ool20008Ool2000/Ool3000<Ool20008
Ool20006Ool20008Ool20006Ool20008Ool20006Ool20008Ool2000cOol20006Ool20008Ool20006
Ool20008Ool20006Ool20008Ool20006Ool20008Ool2000YOol<0006Ool20008Ool20006Ool20008
Ool20006Ool20008Ool20006Ool20008Ool2000dOol20006Ool20008Ool20006Ool20008Ool20006
Ool20008Ool20006Ool20008Ool20026Ool009Ioo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8000Io
o`8000Qoo`8000Ioo`8000Qoo`8002eoo`<000]oo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qo
o`8000Ioo`8000Qoo`8003=oo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Io
o`8000Qoo`8002Uoo``000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qo
o`8003Aoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8008Io
o`00UWoo0P002goo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P00;Woo
0`002Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P00<Woo0`001Woo
0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P00:Goo0P001Woo0P0000=o
o`00Ool01Goo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P00=7oo0P00
1Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P00QWoo002FOol2000;
Ool20008Ool20006Ool20008Ool20006Ool20008Ool20006Ool20008Ool2000_Ool30009Ool20008
Ool20006Ool20008Ool20006Ool20008Ool20006Ool20008Ool2000aOol30007Ool20008Ool20006
Ool20008Ool20006Ool20008Ool20006Ool20008Ool2000ZOol20005Ool20008Ool20008Ool20006
Ool20008Ool20006Ool20008Ool20006Ool20008Ool2000dOol20006Ool20008Ool20006Ool20008
Ool20006Ool20008Ool20006Ool20008Ool20026Ool009Ioo`8000]oo`8000Qoo`8000Ioo`8000Qo
o`8000Ioo`8000Qoo`8000Ioo`8000Qoo`80031oo`<000Qoo`8000Qoo`8000Ioo`8000Qoo`8000Io
o`8000Qoo`8000Ioo`8000Qoo`8002ioo`D000Qoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qo
o`8000Ioo`8000Qoo`8002Yoo`<000Aoo`8000Qoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qo
o`8000Ioo`8000Qoo`8003=oo`8000Moo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Io
o`8000Qoo`8008Ioo`00UWoo0P002goo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo
0P0027oo0P00<Goo0P0027oo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo
0P00;Woo10002Goo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P00:goo
0P0017oo0P0027oo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P00:goo
0P001Goo0`001goo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P00QWoo
002FOol2000;Ool20008Ool20006Ool20008Ool20006Ool20008Ool20006Ool20008Ool2000bOol2
0007Ool20008Ool20006Ool20008Ool20006Ool20008Ool20006Ool20008Ool2000aOol20008Ool2
0008Ool20006Ool20008Ool20006Ool20008Ool20006Ool20008Ool2000/Ool20003Ool20008Ool2
0008Ool20006Ool20008Ool20006Ool20008Ool20006Ool20008Ool2000[Ool90008Ool20008Ool2
0006Ool20008Ool20006Ool20008Ool20006Ool20008Ool20026Ool009Ioo`8000]oo`8000Qoo`80
00Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`80039oo`8000Moo`8000Qoo`8000Ioo`80
00Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`80039oo`8000Moo`8000Qoo`8000Ioo`8000Qoo`80
00Ioo`8000Qoo`8000Ioo`8000Qoo`8002aoo`<0009oo`8000Qoo`8000Qoo`8000Ioo`8000Qoo`80
00Ioo`8000Qoo`8000Ioo`8000Qoo`8002]oo`800003Ool0000000<000Uoo`8000Qoo`8000Ioo`80
00Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8008Ioo`00UWoo0P0037oo0P001Woo0P0027oo0P00
1Woo0P0027oo0P001Woo0P0027oo0P001Woo0P00:Woo0P001goo0P0027oo0P001Woo0P0027oo0P00
1Woo0P0027oo0P001Woo0P0027oo0P001Woo0P00<goo0P0027oo0P001Woo0P0027oo0P001Woo0P00
27oo0P001Woo0P0027oo0P001Woo0P00;Woo0P000Woo0P002Goo0P001Woo0P0027oo0P001Woo0P00
27oo0P001Woo0P0027oo0P001Woo0P00;7oo0P0047oo0P001Woo0P0027oo0P001Woo0P0027oo0P00
1Woo0P0027oo0P001Woo0P00Qgoo002FOol2000<Ool20006Ool20008Ool20006Ool20008Ool20006
Ool20008Ool20006Ool2000ZOol30006Ool20008Ool20006Ool20008Ool20006Ool20008Ool20006
Ool20008Ool20006Ool2000[Ool20006Ool20008Ool20006Ool20008Ool20006Ool20008Ool20006
Ool20008Ool20006Ool2000_Ool200000goo00000009Ool20006Ool20008Ool20006Ool20008Ool2
0006Ool20008Ool20006Ool2000/Ool2000@Ool20006Ool20008Ool20006Ool20008Ool20006Ool2
0008Ool20006Ool20027Ool0099oo`<00003Ool0000000eoo`8000Aoo`8000Yoo`8000Aoo`8000Yo
o`8000Aoo`8000Yoo`8000Aoo`8002]oo`@000Aoo`8000Yoo`8000Aoo`8000Yoo`8000Aoo`8000Yo
o`8000Aoo`8000Yoo`8000Aoo`8002aoo`<000Aoo`<000Uoo`8000Aoo`8000Yoo`8000Aoo`8000Yo
o`8000Aoo`8000Yoo`8000Aoo`80035oo`@000Yoo`8000Aoo`8000Yoo`8000Aoo`8000Yoo`8000Ao
o`8000Yoo`8000Aoo`8002eoo`80015oo`8000Aoo`8000Yoo`8000Aoo`8000Yoo`8000Aoo`8000Yo
o`8000Aoo`8008Qoo`00TWoo1P003Goo20002Woo20002Woo20002Woo2000;7oo20002goo20002Woo
20002Woo20002Woo2000;Goo20002Woo20002Woo20002Woo20002Woo2000<Goo10002Woo20002Woo
20002Woo20002Woo2000;Goo2P002Goo20002Woo20002Woo20002Woo2000R7oo002EOol3000?Ool4
000>Ool4000>Ool4000>Ool4000`Ool5000>Ool4000>Ool4000>Ool4000>Ool4000`Ool5000>Ool4
000>Ool4000>Ool4000>Ool4000dOol3000<Ool4000>Ool4000>Ool4000>Ool4000_Ool:000;Ool4
000>Ool4000>Ool4000>Ool4002:Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOooo
OomSOol003ioo`03001oogoo0?mooomooi]oo`X000]oo`@0039oo`800003Ool0000000D000Yoo`P0
00Yoo`H000moo`00?Woo00<007ooOol0ogooogooVgoo2P002Goo2000<7oo30001goo2`001goo2P00
37oo000nOol00`00Oomoo`3oOoooOonOOol2000=Ool20004Ool2000`Ool40006Ool30005Ool20007
Ool40005Ool30005Ool4000;Ool003ioo`03001oogoo0?mooomooimoo`8000aoo`8000Ioo`8002mo
o`8000Uoo`8000Aoo`80011oo`8000Uoo`8000]oo`00?Woo00<007ooOol0ogooogooWgoo0P0037oo
0P001Woo0P00;goo0P002Goo0P000goo0P0047oo0`005Woo000nOol00`00Oomoo`3oOoooOonOOol2
000;Ool20008Ool2000hOol30003Ool2000@Ool2000GOol003ioo`03001oogoo0?mooomooimoo`80
00]oo`8000Qoo`80035oo`T000Aoo`l000=oo`8001Moo`00?Woo00<007ooOol0ogooogooWgoo0P00
2goo0P0027oo0P00;goo2P001Goo3`000goo0P005goo000nOol00`00Oomoo`3oOoooOonOOol2000;
Ool20008Ool2000^Ool4000<Ool2000;Ool20003Ool2000:Ool2000;Ool002ioool00?l009@001io
o`8000]oo`8000Qoo`8002ioo`8000Qoo`8000Aoo`<000Yoo`8000=oo`<000Uoo`8000]oo`00?Woo
00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05Woo
00<007ooOol05Woo00<007ooOol00gooWP002goo00<007ooOol05Woo00<007ooOol05Woo00<007oo
Ool05Woo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol047ooWP00;Goo0P002goo0P0027oo
0P00;Woo0P001goo0`001Goo0P002Goo0P001Goo0P0027oo0`002goo000nOol00`00Oomoo`0FOol0
0`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol0
0`00Oomoo`03Ool00`00Oomoo`0@Ool00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol0
0`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0FOol0
0`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0@Ool0
0`00Oomoo`03Ool00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol0
0`00Oomoo`0GOol00`00Oomoo`0FOol00`00Oomoo`0[Ool2000;Ool20008Ool2000^Ool30005Ool4
0006Ool30005Ool30007Ool30004Ool5000;Ool003ioo`03001oogoo01Ioo`03001oogoo01Ioo`03
001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo00=oo`03
001oogoo011oo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03
001oogoo01Ioo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo01Ioo`03001oogoo01Ioo`03
001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo011oo`03001oogoo00=oo`03
001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Moo`03
001oogoo01Ioo`03001oogoo02]oo`8000]oo`8000Qoo`8002moo`/000Moo`T000Uoo`/000]oo`00
?Woo00<007ooOol0NWoo00<007ooOol077oo00<007ooOol0Fgoo00<007ooOol0?7oo00<007ooOol0
>goo00<007ooOol0Fgoo00<007ooOol077oo00<007ooOol0Ngoo00<007ooOol0:goo0P0037oo0P00
1Woo0P004goo200017oo20002goo1P0000=oo`0000002Goo1P002goo1`0000=oo`0000002goo000n
Ool00`00Oomoo`2IOol00`00Oomoo`2JOol00`00Oomoo`2IOol00`00Oomoo`38Ool2000<Ool20006
Ool2000FOol20007Ool30004Ool00`00Oomoo`11Ool003ioo`03001oogoo09Uoo`03001oogoo09Yo
o`03001oogoo09Uoo`03001oogoo0<Aoo`<00003Ool0000000eoo`8000Aoo`8001Moo`8000Qoo`80
04Qoo`00?Woo00<007ooOol0VGoo00<007ooOol0VWoo00<007ooOol0VGoo00<007ooOol0a7oo1P00
3Goo20005goo0P002Goo0P00Agoo000nOol00`00Oomoo`2IOol00`00Oomoo`2JOol00`00Oomoo`2I
Ool00`00Oomoo`37Ool3000?Ool40009Ool90007Ool2000:Ool20016Ool003ioo`03001oogoo09Uo
o`03001oogoo09Yoo`03001oogoo09Uoo`03001oogoo0?Ioo`8000]oo`8004Eoo`00?Woo00<007oo
Ool0VGoo00<007ooOol0VWoo00<007ooOol0VGoo00<007ooOol0mWoo0P0037oo0P00A7oo000nOol0
0`00Oomoo`2IOol00`00Oomoo`2JOol00`00Oomoo`2IOol00`00Oomoo`3fOol2000<Ool20014Ool0
03ioo`03001oogoo09Uoo`03001oogoo09Yoo`03001oogoo09Uoo`03001oogoo0?Ioo`8000eoo`80
04=oo`00?Woo00<007ooOol0VGoo00<007ooOol0VWoo00<007ooOol0VGoo00<007ooOol0mWoo0P00
3Goo0P00@goo000nOol00`00Oomoo`2IOol00`00Oomoo`2JOol00`00Oomoo`2IOol00`00Oomoo`3f
Ool20008Ool00`00Oomoo`02Ool20013Ool003ioo`03001oogoo09Uoo`03001oogoo09Yoo`03001o
ogoo09Uoo`03001oogoo0?=oo`D000Qoo`80009oo`8004Aoo`00?Woo00<007ooOol0VGoo00<007oo
Ool0VWoo00<007ooOol0VGoo00<007ooOol0mGoo0`002Goo1000AGoo000nOol00`00Oomoo`2IOol0
0`00Oomoo`2JOol00`00Oomoo`2IOol00`00Oomoo`3oOom;Ool003ioo`03001oogoo09Uoo`03001o
ogoo09Yoo`03001oogoo09Uoo`03001oogoo0?mood]oo`00?Woo00<007ooOol0VGoo00<007ooOol0
VWoo00<007ooOol0V7oo00<007ooOol0ogooC7oo000nOol3002IOol00`00Oomoo`2JOol00`00Oomo
o`2HOol00`00Oomoo`3oOom<Ool003ioo`03001oogoo09Uoo`03001oogoo09Yoo`03001oogoo09Qo
o`03001oogoo0?moodaoo`00?Woo00<007ooOol0V7oo00<007ooOol0Vgoo00<007ooOol0V7oo00<0
07ooOol0ogooC7oo000nOol00`00Oomoo`2HOol00`00Oomoo`2KOol00`00Oomoo`2HOol00`00Oomo
o`3oOom<Ool003ioo`03001oogoo09Qoo`03001oogoo09]oo`03001oogoo09Qoo`03001oogoo0?mo
odaoo`00?Woo0P00VGoo00<007ooOol0Vgoo00<007ooOol0V7oo00<007ooOol0ogooC7oo000nOol2
002IOol00`00Oomoo`2KOol00`00Oomoo`2HOol00`00Oomoo`3oOom<Ool003ioo`8009Uoo`03001o
ogoo09]oo`8009Uoo`03001oogoo0?moodaoo`00?Woo0P00VGoo00<007ooOol0W7oo00<007ooOol0
Ugoo00<007ooOol0ogooC7oo000nOol2002IOol00`00Oomoo`2LOol00`00Oomoo`2GOol00`00Oomo
o`3oOom<Ool003ioo`8009Uoo`03001oogoo09aoo`03001oogoo09Moo`03001oogoo0?moodaoo`00
?Woo0P00VGoo00<007ooOol0W7oo00<007ooOol0Ugoo00<007ooOol0ogooC7oo000nOol2002IOol0
0`00Oomoo`2LOol00`00Oomoo`2GOol00`00Oomoo`3oOom<Ool003ioo`8009Uoo`03001oogoo09ao
o`03001oogoo09Moo`03001oogoo0?moodaoo`00?Woo0P00VGoo00<007ooOol0W7oo00<007ooOol0
Ugoo00<007ooOol0ogooC7oo000nOol2002IOol00`00Oomoo`2LOol00`00Oomoo`2GOol00`00Oomo
o`3oOom<Ool003ioo`8009Uoo`03001oogoo09aoo`03001oogoo09Moo`03001oogoo0?moodaoo`00
?Woo0P00VGoo00<007ooOol0W7oo00<007ooOol0Ugoo00<007ooOol0ogooC7oo000nOol2002IOol0
0`00Oomoo`2LOol00`00Oomoo`2GOol00`00Oomoo`3oOom<Ool003ioo`<009Qoo`03001oogoo09ao
o`03001oogoo09Moo`03001oogoo0?moodaoo`00?Woo0P00VGoo00<007ooOol0W7oo00<007ooOol0
Ugoo00<007ooOol0ogooC7oo000nOol2002IOol00`00Oomoo`2LOol00`00Oomoo`2GOol00`00Oomo
o`3oOom<Ool003ioo`8009Uoo`03001oogoo09aoo`03001oogoo09Moo`03001oogoo0?moodaoo`00
?Woo0P00VGoo00<007ooOol0W7oo00<007ooOol0Ugoo00<007ooOol0ogooC7oo000nOol2002IOol0
0`00Oomoo`2LOol00`00Oomoo`2GOol00`00Oomoo`3oOom<Ool003ioo`8009Uoo`03001oogoo09ao
o`03001oogoo09Moo`03001oogoo0?moodaoo`00?Woo0P00VGoo00<007ooOol0W7oo00<007ooOol0
Ugoo00<007ooOol0ogooC7oo000nOol2002IOol00`00Oomoo`2LOol00`00Oomoo`2GOol00`00Oomo
o`3oOom<Ool003ioo`8009Uoo`03001oogoo09aoo`03001oogoo09Moo`03001oogoo0?moodaoo`00
?Woo0P00VGoo00<007ooOol0W7oo00<007ooOol0Ugoo00<007ooOol0ogooC7oo000nOol2002IOol0
0`00Oomoo`2LOol00`00Oomoo`2FOol00`00Oomoo`3oOom=Ool003ioo`8009Uoo`03001oogoo09ao
o`03001oogoo09Ioo`03001oogoo0?moodeoo`00?Woo0P00V7oo0P00WWoo00<007ooOol0UWoo00<0
07ooOol0ogooCGoo000nOol2002HOol00`00Oomoo`2MOol00`00Oomoo`2FOol00`00Oomoo`3oOom=
Ool003ioo`8009Qoo`03001oogoo09eoo`03001oogoo09Ioo`03001oogoo0?moodeoo`00?Woo0P00
V7oo00<007ooOol0WGoo00<007ooOol0UWoo00<007ooOol0ogooCGoo000nOol00`00Ool0002GOol0
0`00Oomoo`2MOol00`00Oomoo`2FOol00`00Oomoo`3oOom=Ool003ioo`03001oo`0009Moo`03001o
ogoo09eoo`03001oogoo09Ioo`03001oogoo0?moodeoo`00?Woo0`00Ugoo00<007ooOol0WGoo0P00
Ugoo00<007ooOol0ogooCGoo000nOol00`00Ool0002GOol00`00Oomoo`2NOol00`00Oomoo`2EOol0
0`00Oomoo`3oOom=Ool003ioo`03001oo`0009Moo`03001oogoo09ioo`03001oogoo09Eoo`03001o
ogoo0?moodeoo`00?Woo00<007oo0000Ugoo00<007ooOol0WWoo00<007ooOol0UGoo00<007ooOol0
ogooCGoo000nOol00`00Ool0002GOol00`00Oomoo`2NOol00`00Oomoo`2EOol00`00Oomoo`3oOom=
Ool003ioo`03001oo`0009Moo`03001oogoo09ioo`03001oogoo09Eoo`03001oogoo0?moodeoo`00
?Woo00<007oo0000Ugoo00<007ooOol0WWoo00<007ooOol0UGoo00<007ooOol0ogooCGoo000nOol0
0`00Ool0002GOol00`00Oomoo`2NOol00`00Oomoo`2EOol00`00Oomoo`3oOom=Ool003ioo`03001o
o`0009Moo`03001oogoo09ioo`03001oogoo09Eoo`03001oogoo0?moodeoo`00?Woo00<007oo0000
Ugoo00<007ooOol0WWoo00<007ooOol0UGoo00<007ooOol0ogooCGoo000nOol00`00Ool0002GOol0
0`00Oomoo`2NOol00`00Oomoo`2EOol00`00Oomoo`3oOom=Ool003ioo`03001oo`0009Moo`03001o
ogoo09ioo`03001oogoo09Eoo`03001oogoo0?moodeoo`00?Woo00<007oo0000Ugoo00<007ooOol0
WWoo00<007ooOol0UGoo00<007ooOol0ogooCGoo0007Ool4000>Ool3000:Ool<000<Ool00`00Ool0
002GOol00`00Oomoo`2NOol00`00Oomoo`2EOol00`00Oomoo`3oOom=Ool000Eoo`P000]oo`D000Uo
o``000aoo`03001oo`0009Moo`03001oogoo09ioo`03001oogoo09Eoo`03001oogoo0?moodeoo`00
1Goo0P0017oo0P002goo1@002Woo0`001Woo0P0037oo00<007oo0000Ugoo00<007ooOol0WWoo00<0
07ooOol0UGoo00<007ooOol0ogooCGoo0004Ool20006Ool2000:Ool5000;Ool3000COol00`00Ool0
002GOol00`00Oomoo`2NOol00`00Oomoo`2EOol00`00Oomoo`3oOom=Ool000Aoo`8000Ioo`8000]o
o`<000eoo`<0019oo`03001oo`0009Moo`03001oogoo09ioo`03001oogoo09Eoo`03001oogoo0?mo
odeoo`000goo0P0027oo0P006goo0`004Goo00<007oo0000Ugoo00<007ooOol0WWoo00<007ooOol0
UGoo00<007ooOol0ogooCGoo0003Ool20008Ool2000LOol3000@Ool00`00Ool0002GOol00`00Oomo
o`2NOol00`00Oomoo`2EOol00`00Oomoo`3oOom=Ool000=oo`8000Qoo`8001eoo`<000moo`D009Eo
o`03001oogoo09ioo`03001oogoo09Eoo`03001oogoo0?moodeoo`000goo0P0027oo0P007Woo0`00
3Woo00<007oo0000Ugoo00<007ooOol0WWoo00<007ooOol0UGoo00<007ooOol0ogooCGoo0003Ool2
0008Ool2000OOol3000=Ool00`00Ool0002GOol00`00Oomoo`2NOol00`00Oomoo`2DOol2003oOom?
Ool000=oo`8000Qoo`80021oo`8000eoo`03001oo`0009Moo`03001oogoo09ioo`03001oogoo09Ao
o`03001oogoo0?moodioo`000goo0P0027oo0P008Goo0P0037oo00<007oo0000Ugoo00<007ooOol0
WWoo00<007ooOol0U7oo00<007ooOol0ogooCWoo0003Ool20008Ool2000QOol2000<Ool00`00Ool0
002FOol2002POol00`00Oomoo`2DOol00`00Oomoo`3oOom>Ool000Aoo`8000Ioo`8001Uoo`8000Mo
o`8000aoo`03001oo`0009Ioo`03001oogoo09moo`03001oogoo09Aoo`03001oogoo0?moodioo`00
17oo0P001Woo0P006Goo0`001Woo0P0037oo00<007oo0000UWoo00<007ooOol0Wgoo00<007ooOol0
U7oo00<007ooOol0ogooCWoo0005Ool20004Ool2000JOol40004Ool2000=Ool00`00Ool0002FOol0
0`00Oomoo`2OOol00`00Oomoo`2DOol00`00Oomoo`3oOom>Ool000Eoo`P001]oo`P000ioo`04001o
ogoo002EOol00`00Oomoo`2OOol00`00Oomoo`2DOol00`00Oomoo`3oOom>Ool000Moo`@001moo`D0
00moo`04001oogoo002EOol00`00Oomoo`2OOol00`00Oomoo`2DOol00`00Oomoo`3oOom>Ool003io
o`04001oogoo002EOol00`00Oomoo`2OOol2002EOol00`00Oomoo`3oOom>Ool003ioo`04001oogoo
002EOol00`00Oomoo`2POol00`00Oomoo`2COol00`00Oomoo`3oOom>Ool003ioo`04001oogoo002E
Ool00`00Oomoo`2POol00`00Oomoo`2COol00`00Oomoo`3oOom>Ool003ioo`04001oogoo002EOol0
0`00Oomoo`2POol00`00Oomoo`2COol00`00Oomoo`3oOom>Ool003ioo`04001oogoo002EOol00`00
Oomoo`2POol00`00Oomoo`2COol00`00Oomoo`3oOom>Ool003ioo`04001oogoo002EOol00`00Oomo
o`2POol00`00Oomoo`2COol00`00Oomoo`3oOom>Ool003ioo`04001oogoo002EOol00`00Oomoo`2P
Ool00`00Oomoo`2COol00`00Oomoo`3oOom>Ool003ioo`04001oogoo002EOol00`00Oomoo`2POol0
0`00Oomoo`2COol00`00Oomoo`3oOom>Ool003ioo`@009Eoo`03001oogoo0:1oo`03001oogoo09=o
o`03001oogoo0?moodioo`00?Woo00@007ooOol009Eoo`03001oogoo0:1oo`03001oogoo09=oo`03
001oogoo0?moodioo`00?Woo00@007ooOol009Eoo`03001oogoo0:1oo`03001oogoo09=oo`03001o
ogoo0?moodioo`00?Woo00@007ooOol009Eoo`03001oogoo0:1oo`03001oogoo09=oo`03001oogoo
0?moodioo`00?Woo00@007ooOol009Eoo`03001oogoo0:1oo`03001oogoo09=oo`03001oogoo0?mo
odioo`00?Woo00@007ooOol009Eoo`03001oogoo0:1oo`03001oogoo09=oo`03001oogoo0?moodio
o`00?Woo00@007ooOol009Eoo`03001oogoo0:1oo`03001oogoo09=oo`03001oogoo0?moodioo`00
?Woo00@007ooOol009Eoo`03001oogoo0:1oo`03001oogoo09=oo`03001oogoo0?moodioo`00?Woo
00@007ooOol009Eoo`03001oogoo0:1oo`03001oogoo09=oo`03001oogoo0?moodioo`00?Woo00@0
07ooOol009Eoo`03001oogoo0:1oo`03001oogoo09=oo`03001oogoo0?moodioo`00?Woo00@007oo
Ool009Eoo`03001oogoo0:1oo`03001oogoo09=oo`03001oogoo0?moodioo`00?Woo00@007ooOol0
09Eoo`03001oogoo0:1oo`03001oogoo09=oo`03001oogoo0?moodioo`00?Woo00@007ooOol009Eo
o`03001oogoo0:1oo`03001oogoo09=oo`03001oogoo0?moodioo`00?Woo00@007ooOol009Eoo`03
001oogoo0:1oo`03001oogoo09=oo`03001oogoo0?moodioo`00?Woo00@007ooOol009Eoo`03001o
ogoo0:1oo`03001oogoo09=oo`03001oogoo0?moodioo`00?Woo00@007ooOol009Eoo`03001oogoo
0:1oo`03001oogoo099oo`03001oogoo0?moodmoo`00?Woo00@007ooOol009Eoo`03001oogoo0:1o
o`03001oogoo099oo`03001oogoo0?moodmoo`00?Woo00@007ooOol009Aoo`800:9oo`03001oogoo
099oo`03001oogoo0?moodmoo`00?Woo00@007ooOol009Aoo`03001oogoo0:5oo`03001oogoo099o
o`03001oogoo0?moodmoo`00?Woo1000U7oo00<007ooOol0XGoo00<007ooOol0TWoo00<007ooOol0
ogooCgoo000nOol00`00Oomoo`02002COol00`00Oomoo`2QOol00`00Oomoo`2BOol00`00Oomoo`3o
Oom?Ool003ioo`05001oogooOol0002COol00`00Oomoo`2QOol00`00Oomoo`2BOol00`00Oomoo`3o
Oom?Ool003ioo`05001oogooOol0002COol00`00Oomoo`2QOol00`00Oomoo`2BOol00`00Oomoo`3o
Oom?Ool003ioo`05001oogooOol0002COol00`00Oomoo`2ROol00`00Oomoo`2AOol00`00Oomoo`3o
Oom?Ool003ioo`05001oogooOol0002COol00`00Oomoo`2ROol00`00Oomoo`2AOol00`00Oomoo`3o
Oom?Ool003ioo`05001oogooOol0002COol00`00Oomoo`2ROol00`00Oomoo`2AOol00`00Oomoo`3o
Oom?Ool003ioo`05001oogooOol0002COol00`00Oomoo`2ROol00`00Oomoo`2AOol00`00Oomoo`3o
Oom?Ool003ioo`05001oogooOol0002COol00`00Oomoo`2ROol00`00Oomoo`2AOol00`00Oomoo`3o
Oom?Ool003ioo`05001oogooOol0002COol00`00Oomoo`2ROol00`00Oomoo`2AOol00`00Oomoo`3o
Oom?Ool003ioo`05001oogooOol0002COol00`00Oomoo`2ROol00`00Oomoo`2AOol00`00Oomoo`3o
Oom?Ool003ioo`05001oogooOol0002COol00`00Oomoo`2ROol00`00Oomoo`2AOol00`00Oomoo`3o
Oom?Ool003ioo`05001oogooOol0002COol00`00Oomoo`2ROol00`00Oomoo`2AOol00`00Oomoo`3o
Oom?Ool003ioo`05001oogooOol0002COol00`00Oomoo`2ROol00`00Oomoo`2AOol00`00Oomoo`3o
Oom?Ool003ioo`05001oogooOol0002COol00`00Oomoo`2ROol00`00Oomoo`2AOol00`00Oomoo`3o
Oom?Ool003ioo`05001oogooOol0002COol00`00Oomoo`2ROol00`00Oomoo`2AOol00`00Oomoo`3o
Oom?Ool003ioo`05001oogooOol0002COol00`00Oomoo`2ROol00`00Oomoo`2AOol00`00Oomoo`3o
Oom?Ool003ioo`05001oogooOol0002COol00`00Oomoo`2ROol00`00Oomoo`2AOol00`00Oomoo`3o
Oom?Ool003ioo`05001oogooOol0002COol00`00Oomoo`2ROol00`00Oomoo`2AOol00`00Oomoo`3o
Oom?Ool003ioo`05001oogooOol0002COol00`00Oomoo`2ROol00`00Oomoo`2AOol00`00Oomoo`3o
Oom?Ool003ioo`<00003Ool007oo099oo`03001oogoo0:9oo`03001oogoo095oo`03001oogoo0?mo
odmoo`00?Woo00D007ooOomoo`0009=oo`03001oogoo0:9oo`03001oogoo095oo`03001oogoo0?mo
odmoo`00?Woo00D007ooOomoo`0009=oo`03001oogoo0:9oo`03001oogoo095oo`03001oogoo0?mo
odmoo`00?Woo00D007ooOomoo`0009=oo`03001oogoo0:9oo`03001oogoo095oo`03001oogoo0?mo
odmoo`00?Woo00D007ooOomoo`0009=oo`03001oogoo0:9oo`03001oogoo095oo`03001oogoo0?mo
odmoo`00?Woo00D007ooOomoo`0009=oo`03001oogoo0:9oo`03001oogoo095oo`03001oogoo0?mo
odmoo`00?Woo00D007ooOomoo`0009=oo`03001oogoo0:9oo`03001oogoo091oo`800?mooe5oo`00
?Woo00D007ooOomoo`0009=oo`03001oogoo0:9oo`03001oogoo091oo`03001oogoo0?mooe1oo`00
?Woo00D007ooOomoo`0009=oo`03001oogoo0:9oo`03001oogoo091oo`03001oogoo0?mooe1oo`00
?Woo00D007ooOomoo`00099oo`800:Aoo`03001oogoo091oo`03001oogoo0?mooe1oo`00?Woo00D0
07ooOomoo`00099oo`03001oogoo0:=oo`03001oogoo091oo`03001oogoo0?mooe1oo`00?Woo00D0
07ooOomoo`00099oo`03001oogoo0:=oo`03001oogoo091oo`03001oogoo0?mooe1oo`001goo1000
3Woo0`0047oo1`002goo00@007ooOomoo`80095oo`03001oogoo0:=oo`03001oogoo091oo`03001o
ogoo0?mooe1oo`001Goo20002goo1@003goo1`002goo00<007ooOol00Woo00<007ooOol0Sgoo00<0
07ooOol0Xgoo00<007ooOol0T7oo00<007ooOol0ogooD7oo0005Ool20004Ool2000;Ool5000BOol2
000=Ool00`00Oomoo`02Ool00`00Oomoo`2?Ool00`00Oomoo`2SOol00`00Oomoo`2@Ool00`00Oomo
o`3oOom@Ool000Aoo`8000Ioo`8000Yoo`D0019oo`8000eoo`03001oogoo009oo`03001oogoo08mo
o`03001oogoo0:Aoo`03001oogoo08moo`03001oogoo0?mooe1oo`0017oo0P001Woo0P002goo0`00
4goo0P003Goo00<007ooOol00Woo00<007ooOol0Sgoo00<007ooOol0Y7oo00<007ooOol0Sgoo00<0
07ooOol0ogooD7oo0003Ool20008Ool2000HOol<000;Ool00`00Oomoo`02Ool00`00Oomoo`2?Ool0
0`00Oomoo`2TOol00`00Oomoo`2?Ool00`00Oomoo`3oOom@Ool000=oo`8000Qoo`8001Qoo``000]o
o`03001oogoo009oo`03001oogoo08moo`03001oogoo0:Aoo`03001oogoo08moo`03001oogoo0?mo
oe1oo`000goo0P0027oo0P0067oo0P001Woo0P0000=oo`00Ool02Woo1P00TGoo00<007ooOol0Y7oo
00<007ooOol0Sgoo00<007ooOol0ogooD7oo0003Ool20008Ool2000IOol20005Ool2000=Ool00`00
Oomoo`02Ool00`00Oomoo`2?Ool00`00Oomoo`2TOol00`00Oomoo`2?Ool00`00Oomoo`3oOom@Ool0
00=oo`8000Qoo`8001Uoo`<000Aoo`8000eoo`03001oogoo009oo`03001oogoo08moo`03001oogoo
0:Aoo`03001oogoo08moo`03001oogoo0?mooe1oo`000goo0P0027oo0P006Woo0P0017oo0P003Goo
00<007ooOol00Woo00<007ooOol0Sgoo00<007ooOol0Y7oo00<007ooOol0Sgoo00<007ooOol0ogoo
D7oo0003Ool20008Ool2000KOol20003Ool2000=Ool00`00Oomoo`02Ool00`00Oomoo`2?Ool00`00
Oomoo`2TOol00`00Oomoo`2?Ool00`00Oomoo`3oOom@Ool000=oo`8000Qoo`8001]oo`<0009oo`80
00eoo`03001oogoo009oo`03001oogoo08moo`03001oogoo0:Aoo`03001oogoo08moo`03001oogoo
0?mooe1oo`0017oo0P001Woo0P007Goo0P000Woo0P003Goo00<007ooOol00Woo00<007ooOol0Sgoo
00<007ooOol0Y7oo00<007ooOol0Sgoo00<007ooOol0ogooD7oo0004Ool20006Ool2000NOol20000
0goo0000000=Ool00`00Oomoo`02Ool00`00Oomoo`2?Ool00`00Oomoo`2TOol00`00Oomoo`2?Ool0
0`00Oomoo`3oOom@Ool000Eoo`8000Aoo`80021oo`@000eoo`03001oogoo009oo`03001oogoo08mo
o`03001oogoo0:Aoo`03001oogoo08moo`03001oogoo0?mooe1oo`001Goo200087oo10003Goo00<0
07ooOol00Woo00<007ooOol0Sgoo00<007ooOol0Y7oo00<007ooOol0Sgoo00<007ooOol0ogooD7oo
0007Ool4000SOol3000=Ool00`00Oomoo`02Ool00`00Oomoo`2?Ool00`00Oomoo`2TOol00`00Oomo
o`2?Ool00`00Oomoo`3oOom@Ool003ioo`03001oogoo009oo`03001oogoo08moo`03001oogoo0:Ao
o`03001oogoo08moo`03001oogoo0?mooe1oo`00?Woo00<007ooOol00Woo00<007ooOol0Sgoo00<0
07ooOol0Y7oo00<007ooOol0Sgoo00<007ooOol0ogooD7oo000nOol00`00Oomoo`02Ool00`00Oomo
o`2?Ool00`00Oomoo`2TOol00`00Oomoo`2?Ool00`00Oomoo`3oOom@Ool003ioo`03001oogoo009o
o`03001oogoo08moo`03001oogoo0:Aoo`03001oogoo08moo`03001oogoo0?mooe1oo`00?Woo00<0
07ooOol00Woo00<007ooOol0Sgoo00<007ooOol0Y7oo00<007ooOol0Sgoo00<007ooOol0ogooD7oo
000nOol00`00Oomoo`02Ool00`00Oomoo`2?Ool00`00Oomoo`2TOol00`00Oomoo`2?Ool00`00Oomo
o`3oOom@Ool003ioo`03001oogoo009oo`03001oogoo08moo`03001oogoo0:Aoo`03001oogoo08mo
o`03001oogoo0?mooe1oo`00?Woo00<007ooOol00Woo00<007ooOol0Sgoo00<007ooOol0Y7oo00<0
07ooOol0SWoo0P00ogooDWoo000nOol30002Ool00`00Oomoo`2?Ool00`00Oomoo`2TOol00`00Oomo
o`2>Ool00`00Oomoo`3oOomAOol003ioo`03001oogoo009oo`03001oogoo08moo`03001oogoo0:Ao
o`03001oogoo08ioo`03001oogoo0?mooe5oo`00?Woo00<007ooOol00Woo00<007ooOol0SWoo00<0
07ooOol0YGoo00<007ooOol0SWoo00<007ooOol0ogooDGoo000nOol00`00Oomoo`02Ool00`00Oomo
o`2>Ool00`00Oomoo`2UOol00`00Oomoo`2>Ool00`00Oomoo`3oOomAOol003ioo`03001oogoo009o
o`03001oogoo08ioo`03001oogoo0:Eoo`03001oogoo08ioo`03001oogoo0?mooe5oo`00?Woo00<0
07ooOol00Woo0P00Sgoo00<007ooOol0YGoo00<007ooOol0SWoo00<007ooOol0ogooDGoo000nOol0
0`00Oomoo`03Ool00`00Oomoo`2=Ool00`00Oomoo`2UOol00`00Oomoo`2>Ool00`00Oomoo`3oOomA
Ool003ioo`03001oogoo00=oo`03001oogoo08eoo`03001oogoo0:Eoo`03001oogoo08ioo`03001o
ogoo0?mooe5oo`00?Woo00<007ooOol00goo00<007ooOol0SGoo00<007ooOol0YWoo00<007ooOol0
SGoo00<007ooOol0ogooDGoo000nOol00`00Oomoo`03Ool00`00Oomoo`2=Ool00`00Oomoo`2VOol0
0`00Oomoo`2=Ool00`00Oomoo`3oOomAOol003ioo`03001oogoo00=oo`03001oogoo08eoo`03001o
ogoo0:Ioo`03001oogoo08eoo`03001oogoo0?mooe5oo`00?Woo00<007ooOol00goo00<007ooOol0
SGoo00<007ooOol0YWoo00<007ooOol0SGoo00<007ooOol0ogooDGoo000nOol00`00Oomoo`03Ool0
0`00Oomoo`2=Ool00`00Oomoo`2VOol00`00Oomoo`2=Ool00`00Oomoo`3oOomAOol003ioo`03001o
ogoo00=oo`03001oogoo08eoo`03001oogoo0:Ioo`03001oogoo08eoo`03001oogoo0?mooe5oo`00
?Woo00<007ooOol00goo00<007ooOol0SGoo00<007ooOol0YWoo00<007ooOol0SGoo00<007ooOol0
ogooDGoo000nOol00`00Oomoo`03Ool00`00Oomoo`2=Ool00`00Oomoo`2VOol00`00Oomoo`2=Ool0
0`00Oomoo`3oOomAOol003ioo`03001oogoo00=oo`03001oogoo08eoo`03001oogoo0:Ioo`03001o
ogoo08eoo`03001oogoo0?mooe5oo`00?Woo00<007ooOol00goo00<007ooOol0SGoo00<007ooOol0
YWoo00<007ooOol0SGoo00<007ooOol0ogooDGoo000nOol00`00Oomoo`03Ool00`00Oomoo`2=Ool0
0`00Oomoo`2VOol00`00Oomoo`2=Ool00`00Oomoo`3oOomAOol003ioo`03001oogoo00=oo`03001o
ogoo08eoo`03001oogoo0:Ioo`03001oogoo08eoo`03001oogoo0?mooe5oo`00?Woo0`000goo00<0
07ooOol0SGoo00<007ooOol0YWoo00<007ooOol0SGoo00<007ooOol0ogooDGoo000nOol00`00Oomo
o`03Ool00`00Oomoo`2=Ool00`00Oomoo`2VOol00`00Oomoo`2=Ool00`00Oomoo`3oOomAOol003io
o`03001oogoo00=oo`03001oogoo08eoo`03001oogoo0:Ioo`03001oogoo08eoo`03001oogoo0?mo
oe5oo`00?Woo00<007ooOol00goo00<007ooOol0SGoo00<007ooOol0YWoo00<007ooOol0SGoo00<0
07ooOol0ogooDGoo000nOol00`00Oomoo`03Ool00`00Oomoo`2=Ool00`00Oomoo`2VOol00`00Oomo
o`2=Ool00`00Oomoo`3oOomAOol003ioo`03001oogoo00=oo`03001oogoo08eoo`03001oogoo0:Io
o`03001oogoo08eoo`03001oogoo0?mooe5oo`00?Woo00<007ooOol00goo00<007ooOol0SGoo00<0
07ooOol0YWoo00<007ooOol0SGoo00<007ooOol0ogooDGoo000nOol00`00Oomoo`03Ool00`00Oomo
o`2=Ool00`00Oomoo`2VOol00`00Oomoo`2=Ool00`00Oomoo`3oOomAOol003ioo`03001oogoo00=o
o`03001oogoo08eoo`03001oogoo0:Ioo`03001oogoo08eoo`03001oogoo0?mooe5oo`00?Woo00<0
07ooOol00goo00<007ooOol0SGoo00<007ooOol0YWoo00<007ooOol0SGoo00<007ooOol0ogooDGoo
000nOol00`00Oomoo`03Ool00`00Oomoo`2=Ool00`00Oomoo`2VOol00`00Oomoo`2<Ool2003oOomC
Ool003ioo`03001oogoo00=oo`03001oogoo08eoo`03001oogoo0:Ioo`03001oogoo08aoo`03001o
ogoo0?mooe9oo`00?Woo00<007ooOol00goo00<007ooOol0SGoo00<007ooOol0YWoo00<007ooOol0
S7oo00<007ooOol0ogooDWoo000nOol00`00Oomoo`03Ool00`00Oomoo`2<Ool00`00Oomoo`2WOol0
0`00Oomoo`2<Ool00`00Oomoo`3oOomBOol003ioo`03001oogoo00=oo`03001oogoo08aoo`03001o
ogoo0:Moo`03001oogoo08aoo`03001oogoo0?mooe9oo`00?Woo00<007ooOol00goo00<007ooOol0
S7oo00<007ooOol0Ygoo00<007ooOol0S7oo00<007ooOol0ogooDWoo000nOol00`00Oomoo`03Ool2
002=Ool00`00Oomoo`2WOol00`00Oomoo`2<Ool00`00Oomoo`3oOomBOol003ioo`03001oogoo00Ao
o`03001oogoo08]oo`03001oogoo0:Moo`03001oogoo08aoo`03001oogoo0?mooe9oo`00?Woo00<0
07ooOol017oo00<007ooOol0Rgoo00<007ooOol0Ygoo00<007ooOol0S7oo00<007ooOol0ogooDWoo
000nOol30004Ool00`00Oomoo`2;Ool00`00Oomoo`2XOol00`00Oomoo`2;Ool00`00Oomoo`3oOomB
Ool003ioo`03001oogoo00Aoo`03001oogoo08]oo`03001oogoo0:Qoo`03001oogoo08]oo`03001o
ogoo0?mooe9oo`00?Woo00<007ooOol017oo00<007ooOol0Rgoo00<007ooOol0Z7oo00<007ooOol0
Rgoo00<007ooOol0ogooDWoo000nOol00`00Oomoo`04Ool00`00Oomoo`2;Ool00`00Oomoo`2XOol0
0`00Oomoo`2;Ool00`00Oomoo`3oOomBOol003ioo`03001oogoo00Aoo`03001oogoo08]oo`03001o
ogoo0:Qoo`03001oogoo08]oo`03001oogoo0?mooe9oo`00?Woo00<007ooOol017oo00<007ooOol0
Rgoo00<007ooOol0Z7oo00<007ooOol0Rgoo00<007ooOol0ogooDWoo000nOol00`00Oomoo`04Ool0
0`00Oomoo`2;Ool00`00Oomoo`2XOol00`00Oomoo`2;Ool00`00Oomoo`3oOomBOol003ioo`03001o
ogoo00Aoo`03001oogoo08]oo`03001oogoo0:Qoo`03001oogoo08]oo`03001oogoo0?mooe9oo`00
?Woo00<007ooOol017oo00<007ooOol0Rgoo00<007ooOol0Z7oo00<007ooOol0Rgoo00<007ooOol0
ogooDWoo000nOol00`00Oomoo`04Ool00`00Oomoo`2;Ool00`00Oomoo`2XOol00`00Oomoo`2;Ool0
0`00Oomoo`3oOomBOol003ioo`03001oogoo00Aoo`03001oogoo08]oo`03001oogoo0:Qoo`03001o
ogoo08]oo`03001oogoo0?mooe9oo`00?Woo00<007ooOol017oo00<007ooOol0Rgoo00<007ooOol0
Z7oo00<007ooOol0Rgoo00<007ooOol0ogooDWoo0007Ool4000>Ool3000?Ool5000>Ool00`00Oomo
o`04Ool00`00Oomoo`2;Ool00`00Oomoo`2XOol00`00Oomoo`2;Ool00`00Oomoo`3oOomBOol000Eo
o`P000]oo`D000aoo`P000eoo`03001oogoo00Aoo`03001oogoo08]oo`03001oogoo0:Qoo`03001o
ogoo08]oo`03001oogoo0?mooe9oo`001Goo0P0017oo0P002goo1@0037oo0P0017oo0`0037oo00<0
07ooOol017oo00<007ooOol0Rgoo00<007ooOol0Z7oo00<007ooOol0Rgoo00<007ooOol0ogooDWoo
0004Ool20006Ool2000:Ool5000;Ool20006Ool3000;Ool00`00Oomoo`04Ool00`00Oomoo`2;Ool0
0`00Oomoo`2XOol00`00Oomoo`2;Ool00`00Oomoo`3oOomBOol000Aoo`8000Ioo`8000]oo`<000]o
o`8000Qoo`8000]oo`03001oogoo00Aoo`03001oogoo08]oo`03001oogoo0:Qoo`03001oogoo08]o
o`03001oogoo0?mooe9oo`000goo0P0027oo0P0067oo0P0027oo0P002goo00<007ooOol017oo00<0
07ooOol0Rgoo00<007ooOol0Z7oo00<007ooOol0Rgoo00<007ooOol0ogooDWoo0003Ool20008Ool2
000HOol20008Ool2000;Ool00`00Oomoo`04Ool00`00Oomoo`2;Ool00`00Oomoo`2XOol00`00Oomo
o`2;Ool00`00Oomoo`3oOomBOol000=oo`8000Qoo`8001Qoo`8000Qoo`8000]oo`D0009oo`03001o
ogoo08]oo`03001oogoo0:Qoo`03001oogoo08]oo`03001oogoo0?mooe9oo`000goo0P0027oo0P00
67oo0`001Woo0`002goo00<007ooOol017oo00<007ooOol0Rgoo00<007ooOol0Z7oo00<007ooOol0
Rgoo00<007ooOol0ogooDWoo0003Ool20008Ool2000HOol40004Ool3000<Ool00`00Oomoo`04Ool0
0`00Oomoo`2;Ool00`00Oomoo`2XOol00`00Oomoo`2;Ool00`00Oomoo`3oOomBOol000=oo`8000Qo
o`8001Qoo`800003Ool0000000D000eoo`03001oogoo00Aoo`03001oogoo08]oo`03001oogoo0:Qo
o`03001oogoo08Yoo`800?mooeAoo`000goo0P0027oo0P006Goo00<007ooOol01@003Woo00<007oo
Ool017oo00<007ooOol0Rgoo00<007ooOol0Z7oo00<007ooOol0RWoo00<007ooOol0ogooDgoo0003
Ool20008Ool2000IOol2000DOol00`00Oomoo`04Ool00`00Oomoo`2;Ool00`00Oomoo`2XOol00`00
Oomoo`2:Ool00`00Oomoo`3oOomCOol000Aoo`8000Ioo`8001Yoo`<001=oo`03001oogoo00Aoo`03
001oogoo08Yoo`03001oogoo0:Uoo`03001oogoo08Yoo`03001oogoo0?mooe=oo`0017oo0P001Woo
0P006goo0`004Woo00<007ooOol017oo00<007ooOol0RWoo00<007ooOol0ZGoo00<007ooOol0RWoo
00<007ooOol0ogooDgoo0005Ool20004Ool2000MOol3000AOol00`00Oomoo`04Ool00`00Oomoo`2:
Ool00`00Oomoo`2YOol00`00Oomoo`2:Ool00`00Oomoo`3oOomCOol000Eoo`P001ioo`P000]oo`03
001oogoo00Eoo`03001oogoo08Uoo`03001oogoo0:Uoo`03001oogoo08Yoo`03001oogoo0?mooe=o
o`001goo10008Woo1P002goo00<007ooOol01Goo00<007ooOol0RGoo00<007ooOol0ZGoo00<007oo
Ool0RWoo00<007ooOol0ogooDgoo000nOol00`00Oomoo`05Ool00`00Oomoo`29Ool00`00Oomoo`2Y
Ool00`00Oomoo`2:Ool00`00Oomoo`3oOomCOol003ioo`03001oogoo00Eoo`03001oogoo08Uoo`03
001oogoo0:Yoo`03001oogoo08Uoo`03001oogoo0?mooe=oo`00?Woo00<007ooOol01Goo00<007oo
Ool0RGoo00<007ooOol0ZWoo00<007ooOol0RGoo00<007ooOol0ogooDgoo000nOol00`00Oomoo`05
Ool00`00Oomoo`29Ool00`00Oomoo`2ZOol00`00Oomoo`29Ool00`00Oomoo`3oOomCOol003ioo`03
001oogoo00Eoo`03001oogoo08Uoo`03001oogoo0:Yoo`03001oogoo08Uoo`03001oogoo0?mooe=o
o`00?Woo00<007ooOol01Goo00<007ooOol0RGoo00<007ooOol0ZWoo00<007ooOol0RGoo00<007oo
Ool0ogooDgoo000nOol00`00Oomoo`05Ool00`00Oomoo`29Ool00`00Oomoo`2ZOol00`00Oomoo`29
Ool00`00Oomoo`3oOomCOol003ioo`03001oogoo00Eoo`03001oogoo08Uoo`03001oogoo0:Yoo`03
001oogoo08Uoo`03001oogoo0?mooe=oo`00?Woo00<007ooOol01Goo00<007ooOol0RGoo00<007oo
Ool0ZWoo00<007ooOol0RGoo00<007ooOol0ogooDgoo000nOol30005Ool00`00Oomoo`29Ool00`00
Oomoo`2ZOol00`00Oomoo`29Ool00`00Oomoo`3oOomCOol003ioo`03001oogoo00Eoo`03001oogoo
08Uoo`03001oogoo0:Yoo`03001oogoo08Uoo`03001oogoo0?mooe=oo`00?Woo00<007ooOol01Goo
00<007ooOol0RGoo00<007ooOol0ZWoo00<007ooOol0RGoo00<007ooOol0ogooDgoo000nOol00`00
Oomoo`05Ool00`00Oomoo`29Ool00`00Oomoo`2ZOol00`00Oomoo`29Ool00`00Oomoo`3oOomCOol0
03ioo`03001oogoo00Eoo`03001oogoo08Uoo`03001oogoo0:Yoo`03001oogoo08Uoo`03001oogoo
0?mooe=oo`00?Woo00<007ooOol01Goo00<007ooOol0RGoo00<007ooOol0ZWoo00<007ooOol0RGoo
00<007ooOol0ogooDgoo000nOol00`00Oomoo`05Ool00`00Oomoo`29Ool00`00Oomoo`2ZOol00`00
Oomoo`29Ool00`00Oomoo`3oOomCOol003ioo`03001oogoo00Eoo`03001oogoo08Uoo`03001oogoo
0:Yoo`03001oogoo08Uoo`03001oogoo0?mooe=oo`00?Woo00<007ooOol01Goo00<007ooOol0RGoo
00<007ooOol0ZWoo00<007ooOol0RGoo00<007ooOol0ogooDgoo000nOol00`00Oomoo`05Ool00`00
Oomoo`29Ool00`00Oomoo`2ZOol00`00Oomoo`29Ool00`00Oomoo`3oOomCOol003ioo`03001oogoo
00Eoo`03001oogoo08Uoo`03001oogoo0:Yoo`03001oogoo08Uoo`03001oogoo0?mooe=oo`00?Woo
00<007ooOol01Goo00<007ooOol0RGoo00<007ooOol0ZWoo00<007ooOol0RGoo00<007ooOol0ogoo
Dgoo000nOol00`00Oomoo`05Ool00`00Oomoo`29Ool00`00Oomoo`2ZOol00`00Oomoo`29Ool00`00
Oomoo`3oOomCOol003ioo`03001oogoo00Eoo`03001oogoo08Uoo`03001oogoo0:Yoo`03001oogoo
08Uoo`03001oogoo0?mooe=oo`00?Woo00<007ooOol01Goo00<007ooOol0RGoo00<007ooOol0ZWoo
00<007ooOol0R7oo0P00ogooEGoo000nOol00`00Oomoo`05Ool00`00Oomoo`29Ool00`00Oomoo`2Z
Ool00`00Oomoo`28Ool00`00Oomoo`3oOomDOol003ioo`03001oogoo00Eoo`03001oogoo08Qoo`80
0:aoo`03001oogoo08Qoo`03001oogoo0?mooeAoo`00?Woo00<007ooOol01Goo00<007ooOol0R7oo
00<007ooOol0Zgoo00<007ooOol0R7oo00<007ooOol0ogooE7oo000nOol00`00Oomoo`05Ool00`00
Oomoo`28Ool00`00Oomoo`2[Ool00`00Oomoo`28Ool00`00Oomoo`3oOomDOol003ioo`<000Eoo`03
001oogoo08Qoo`03001oogoo0:]oo`03001oogoo08Qoo`03001oogoo0?mooeAoo`00?Woo00<007oo
Ool01Woo00<007ooOol0Qgoo00<007ooOol0Zgoo00<007ooOol0R7oo00<007ooOol0ogooE7oo000n
Ool00`00Oomoo`06Ool00`00Oomoo`27Ool00`00Oomoo`2[Ool00`00Oomoo`28Ool00`00Oomoo`3o
OomDOol003ioo`03001oogoo00Ioo`03001oogoo08Moo`03001oogoo0:]oo`8008Uoo`03001oogoo
0?mooeAoo`00?Woo00<007ooOol01Woo00<007ooOol0Qgoo00<007ooOol0[7oo00<007ooOol0Qgoo
00<007ooOol0ogooE7oo000nOol00`00Oomoo`06Ool00`00Oomoo`27Ool00`00Oomoo`2/Ool00`00
Oomoo`27Ool00`00Oomoo`3oOomDOol003ioo`03001oogoo00Ioo`03001oogoo08Moo`03001oogoo
0:aoo`03001oogoo08Moo`03001oogoo0?mooeAoo`00?Woo00<007ooOol01Woo00<007ooOol0Qgoo
00<007ooOol0[7oo00<007ooOol0Qgoo00<007ooOol0ogooE7oo000nOol00`00Oomoo`06Ool00`00
Oomoo`27Ool00`00Oomoo`2/Ool00`00Oomoo`27Ool00`00Oomoo`3oOomDOol003ioo`03001oogoo
00Ioo`03001oogoo08Moo`03001oogoo0:aoo`03001oogoo08Moo`03001oogoo0?mooeAoo`00?Woo
00<007ooOol01Woo00<007ooOol0Qgoo00<007ooOol0[7oo00<007ooOol0Qgoo00<007ooOol0ogoo
E7oo000nOol00`00Oomoo`06Ool00`00Oomoo`27Ool00`00Oomoo`2/Ool00`00Oomoo`27Ool00`00
Oomoo`3oOomDOol003ioo`03001oogoo00Ioo`03001oogoo08Moo`03001oogoo0:aoo`03001oogoo
08Moo`03001oogoo0?mooeAoo`00?Woo00<007ooOol01Woo00<007ooOol0Qgoo00<007ooOol0[7oo
00<007ooOol0Qgoo00<007ooOol0ogooE7oo000nOol00`00Oomoo`06Ool00`00Oomoo`27Ool00`00
Oomoo`2/Ool00`00Oomoo`27Ool00`00Oomoo`3oOomDOol003ioo`03001oogoo00Ioo`03001oogoo
08Moo`03001oogoo0:aoo`03001oogoo08Moo`03001oogoo0?mooeAoo`00?Woo00<007ooOol01Woo
00<007ooOol0Qgoo00<007ooOol0[7oo00<007ooOol0Qgoo00<007ooOol0ogooE7oo000nOol00`00
Oomoo`06Ool00`00Oomoo`27Ool00`00Oomoo`2/Ool00`00Oomoo`27Ool00`00Oomoo`3oOomDOol0
03ioo`03001oogoo00Ioo`03001oogoo08Moo`03001oogoo0:aoo`03001oogoo08Moo`03001oogoo
0?mooeAoo`00?Woo0`001Woo00<007ooOol0Qgoo00<007ooOol0[7oo00<007ooOol0Qgoo00<007oo
Ool0ogooE7oo000nOol00`00Oomoo`06Ool00`00Oomoo`27Ool00`00Oomoo`2/Ool00`00Oomoo`27
Ool00`00Oomoo`3oOomDOol003ioo`03001oogoo00Ioo`03001oogoo08Moo`03001oogoo0:aoo`03
001oogoo08Moo`03001oogoo0?mooeAoo`00?Woo00<007ooOol01Woo00<007ooOol0Qgoo00<007oo
Ool0[7oo00<007ooOol0Qgoo00<007ooOol0ogooE7oo000nOol00`00Oomoo`06Ool00`00Oomoo`27
Ool00`00Oomoo`2/Ool00`00Oomoo`27Ool00`00Oomoo`3oOomDOol003ioo`03001oogoo00Ioo`03
001oogoo08Moo`03001oogoo0:aoo`03001oogoo08Moo`03001oogoo0?mooeAoo`00?Woo00<007oo
Ool01Woo00<007ooOol0Qgoo00<007ooOol0[7oo00<007ooOol0Qgoo00<007ooOol0ogooE7oo000n
Ool00`00Oomoo`06Ool00`00Oomoo`27Ool00`00Oomoo`2/Ool00`00Oomoo`26Ool2003oOomFOol0
03ioo`03001oogoo00Ioo`03001oogoo08Moo`03001oogoo0:aoo`03001oogoo08Ioo`03001oogoo
0?mooeEoo`00?Woo00<007ooOol01Woo00<007ooOol0Qgoo00<007ooOol0[7oo00<007ooOol0QWoo
00<007ooOol0ogooEGoo000nOol00`00Oomoo`06Ool00`00Oomoo`26Ool00`00Oomoo`2]Ool00`00
Oomoo`26Ool00`00Oomoo`3oOomEOol003ioo`03001oogoo00Ioo`03001oogoo08Ioo`03001oogoo
0:eoo`03001oogoo08Ioo`03001oogoo0?mooeEoo`00?Woo00<007ooOol01Woo00<007ooOol0QWoo
00<007ooOol0[Goo00<007ooOol0QWoo00<007ooOol0ogooEGoo0007Ool4000>Ool3000>Ool6000>
Ool00`00Oomoo`07Ool00`00Oomoo`25Ool00`00Oomoo`2]Ool00`00Oomoo`26Ool00`00Oomoo`3o
OomEOol000Eoo`P000]oo`D000aoo`P000eoo`03001oogoo00Moo`03001oogoo08Eoo`03001oogoo
0:eoo`03001oogoo08Ioo`03001oogoo0?mooeEoo`001Goo0P0017oo0P002goo1@002goo0`0017oo
0`0037oo00<007ooOol01goo00<007ooOol0QGoo00<007ooOol0[Goo0P00Qgoo00<007ooOol0ogoo
EGoo0004Ool20006Ool2000:Ool5000:Ool30006Ool3000;Ool00`00Oomoo`07Ool00`00Oomoo`25
Ool00`00Oomoo`2^Ool00`00Oomoo`25Ool00`00Oomoo`3oOomEOol000Aoo`8000Ioo`8000]oo`<0
00]oo`8000Qoo`8000]oo`03001oogoo00Moo`03001oogoo08Eoo`03001oogoo0:ioo`03001oogoo
08Eoo`03001oogoo0?mooeEoo`000goo0P0027oo0P0067oo0P0027oo0P002goo00<007ooOol01goo
00<007ooOol0QGoo00<007ooOol0[Woo00<007ooOol0QGoo00<007ooOol0ogooEGoo0003Ool20008
Ool2000HOol20008Ool2000;Ool00`00Oomoo`07Ool00`00Oomoo`25Ool00`00Oomoo`2^Ool00`00
Oomoo`25Ool00`00Oomoo`3oOomEOol000=oo`8000Qoo`8001Qoo`<000Ioo`<000]oo`D000Eoo`03
001oogoo08Eoo`03001oogoo0:ioo`03001oogoo08Eoo`03001oogoo0?mooeEoo`000goo0P0027oo
0P006Goo0`0017oo0`0037oo00<007ooOol01goo00<007ooOol0QGoo00<007ooOol0[Woo00<007oo
Ool0QGoo00<007ooOol0ogooEGoo0003Ool20008Ool2000JOol8000=Ool00`00Oomoo`07Ool00`00
Oomoo`25Ool00`00Oomoo`2^Ool00`00Oomoo`25Ool00`00Oomoo`3oOomEOol000=oo`8000Qoo`80
01Yoo`P000eoo`03001oogoo00Moo`03001oogoo08Eoo`03001oogoo0:ioo`03001oogoo08Eoo`03
001oogoo0?mooeEoo`000goo0P0027oo0P006Goo0`0017oo0`0037oo00<007ooOol01goo00<007oo
Ool0QGoo00<007ooOol0[Woo00<007ooOol0QGoo00<007ooOol0ogooEGoo0003Ool20008Ool2000H
Ool20008Ool2000;Ool00`00Oomoo`07Ool00`00Oomoo`25Ool00`00Oomoo`2^Ool00`00Oomoo`25
Ool00`00Oomoo`3oOomEOol000Aoo`8000Ioo`8001Uoo`8000Qoo`8000]oo`03001oogoo00Moo`03
001oogoo08Eoo`03001oogoo0:ioo`03001oogoo08Eoo`03001oogoo0?mooeEoo`0017oo0P001Woo
0P006Goo0P0027oo0P002goo00<007ooOol01goo00<007ooOol0QGoo00<007ooOol0[Woo00<007oo
Ool0QGoo00<007ooOol0ogooEGoo0005Ool20004Ool2000KOol30004Ool4000;Ool00`00Oomoo`07
Ool00`00Oomoo`25Ool00`00Oomoo`2^Ool00`00Oomoo`25Ool00`00Oomoo`3oOomEOol000Eoo`P0
01]oo`X000aoo`03001oogoo00Moo`03001oogoo08Eoo`03001oogoo0:ioo`03001oogoo08Eoo`03
001oogoo0?mooeEoo`001goo10007goo1P003Woo00<007ooOol01goo00<007ooOol0QGoo00<007oo
Ool0[Woo00<007ooOol0QGoo00<007ooOol0ogooEGoo000nOol00`00Oomoo`07Ool00`00Oomoo`25
Ool00`00Oomoo`2^Ool00`00Oomoo`25Ool00`00Oomoo`3oOomEOol003ioo`03001oogoo00Moo`03
001oogoo08Eoo`03001oogoo0:ioo`03001oogoo08Eoo`03001oogoo0?mooeEoo`00?Woo00<007oo
Ool01goo00<007ooOol0QGoo00<007ooOol0[Woo00<007ooOol0QGoo00<007ooOol0ogooEGoo000n
Ool00`00Oomoo`07Ool00`00Oomoo`25Ool00`00Oomoo`2^Ool00`00Oomoo`25Ool00`00Oomoo`3o
OomEOol003ioo`03001oogoo00Moo`03001oogoo08Eoo`03001oogoo0:ioo`03001oogoo08Eoo`03
001oogoo0?mooeEoo`00?Woo00<007ooOol01goo00<007ooOol0QGoo00<007ooOol0[Woo00<007oo
Ool0QGoo00<007ooOol0ogooEGoo000nOol00`00Oomoo`07Ool00`00Oomoo`25Ool00`00Oomoo`2^
Ool00`00Oomoo`25Ool00`00Oomoo`3oOomEOol003ioo`03001oogoo00Moo`03001oogoo08Eoo`03
001oogoo0:ioo`03001oogoo08Aoo`03001oogoo0?mooeIoo`00?Woo0`001goo00<007ooOol0QGoo
00<007ooOol0[Woo00<007ooOol0Q7oo00<007ooOol0ogooEWoo000nOol00`00Oomoo`07Ool00`00
Oomoo`25Ool00`00Oomoo`2^Ool00`00Oomoo`24Ool00`00Oomoo`3oOomFOol003ioo`03001oogoo
00Moo`03001oogoo08Aoo`03001oogoo0:moo`03001oogoo08Aoo`03001oogoo0?mooeIoo`00?Woo
00<007ooOol01goo00<007ooOol0Q7oo00<007ooOol0[goo00<007ooOol0Q7oo00<007ooOol0ogoo
EWoo000nOol00`00Oomoo`07Ool00`00Oomoo`24Ool00`00Oomoo`2_Ool00`00Oomoo`24Ool00`00
Oomoo`3oOomFOol003ioo`03001oogoo00Qoo`03001oogoo08=oo`03001oogoo0:moo`03001oogoo
08Aoo`03001oogoo0?mooeIoo`00?Woo00<007ooOol027oo00<007ooOol0Pgoo00<007ooOol0[goo
00<007ooOol0Q7oo00<007ooOol0ogooEWoo000nOol00`00Oomoo`08Ool00`00Oomoo`23Ool00`00
Oomoo`2_Ool20025Ool00`00Oomoo`3oOomFOol003ioo`03001oogoo00Qoo`03001oogoo08=oo`03
001oogoo0;1oo`03001oogoo08=oo`03001oogoo0?mooeIoo`00?Woo00<007ooOol027oo00<007oo
Ool0Pgoo00<007ooOol0/7oo00<007ooOol0Pgoo00<007ooOol0ogooEWoo000nOol00`00Oomoo`08
Ool00`00Oomoo`23Ool00`00Oomoo`2`Ool00`00Oomoo`23Ool00`00Oomoo`3oOomFOol003ioo`03
001oogoo00Qoo`03001oogoo08=oo`03001oogoo0;1oo`03001oogoo08=oo`03001oogoo0?mooeIo
o`00?Woo00<007ooOol027oo00<007ooOol0Pgoo00<007ooOol0/7oo00<007ooOol0Pgoo00<007oo
Ool0ogooEWoo000nOol00`00Oomoo`08Ool00`00Oomoo`23Ool00`00Oomoo`2`Ool00`00Oomoo`23
Ool00`00Oomoo`3oOomFOol003ioo`03001oogoo00Qoo`03001oogoo08=oo`03001oogoo0;1oo`03
001oogoo08=oo`03001oogoo0?mooeIoo`00?Woo00<007ooOol027oo00<007ooOol0Pgoo00<007oo
Ool0/7oo00<007ooOol0Pgoo00<007ooOol0ogooEWoo000nOol00`00Oomoo`08Ool00`00Oomoo`23
Ool00`00Oomoo`2`Ool00`00Oomoo`23Ool00`00Oomoo`3oOomFOol003ioo`03001oogoo00Qoo`03
001oogoo08=oo`03001oogoo0;1oo`03001oogoo08=oo`03001oogoo0?mooeIoo`00?Woo00<007oo
Ool027oo00<007ooOol0Pgoo00<007ooOol0/7oo00<007ooOol0Pgoo00<007ooOol0ogooEWoo000n
Ool30008Ool00`00Oomoo`23Ool00`00Oomoo`2`Ool00`00Oomoo`23Ool00`00Oomoo`3oOomFOol0
03ioo`03001oogoo00Qoo`03001oogoo08=oo`03001oogoo0;1oo`03001oogoo08=oo`03001oogoo
0?mooeIoo`00?Woo00<007ooOol027oo00<007ooOol0Pgoo00<007ooOol0/7oo00<007ooOol0Pgoo
00<007ooOol0ogooEWoo000nOol00`00Oomoo`08Ool00`00Oomoo`23Ool00`00Oomoo`2`Ool00`00
Oomoo`23Ool00`00Oomoo`3oOomFOol003ioo`03001oogoo00Qoo`03001oogoo08=oo`03001oogoo
0;1oo`03001oogoo08=oo`03001oogoo0?mooeIoo`00?Woo00<007ooOol027oo00<007ooOol0Pgoo
00<007ooOol0/7oo00<007ooOol0Pgoo00<007ooOol0ogooEWoo000nOol00`00Oomoo`08Ool00`00
Oomoo`23Ool00`00Oomoo`2`Ool00`00Oomoo`23Ool00`00Oomoo`3oOomFOol003ioo`03001oogoo
00Qoo`03001oogoo08=oo`03001oogoo0;1oo`03001oogoo08=oo`03001oogoo0?mooeIoo`00?Woo
00<007ooOol027oo00<007ooOol0Pgoo00<007ooOol0/7oo00<007ooOol0Pgoo00<007ooOol0ogoo
EWoo000nOol00`00Oomoo`08Ool00`00Oomoo`23Ool00`00Oomoo`2`Ool00`00Oomoo`23Ool00`00
Oomoo`3oOomFOol003ioo`03001oogoo00Qoo`03001oogoo08=oo`03001oogoo0;1oo`03001oogoo
08=oo`03001oogoo0?mooeIoo`00?Woo00<007ooOol027oo00<007ooOol0Pgoo00<007ooOol0/7oo
00<007ooOol0PWoo00<007ooOol0ogooEgoo000nOol00`00Oomoo`08Ool00`00Oomoo`23Ool00`00
Oomoo`2`Ool00`00Oomoo`22Ool00`00Oomoo`3oOomGOol003ioo`03001oogoo00Qoo`03001oogoo
089oo`800;9oo`03001oogoo089oo`03001oogoo0?mooeMoo`00?Woo00<007ooOol027oo00<007oo
Ool0PWoo00<007ooOol0/Goo00<007ooOol0PWoo00<007ooOol0ogooEgoo000nOol00`00Oomoo`08
Ool00`00Oomoo`22Ool00`00Oomoo`2aOol00`00Oomoo`22Ool00`00Oomoo`3oOomGOol003ioo`03
001oogoo00Qoo`03001oogoo089oo`03001oogoo0;5oo`03001oogoo089oo`03001oogoo0?mooeMo
o`00?Woo00<007ooOol02Goo00<007ooOol0PGoo00<007ooOol0/Goo00<007ooOol0PWoo00<007oo
Ool0ogooEgoo000nOol00`00Oomoo`09Ool00`00Oomoo`21Ool00`00Oomoo`2aOol00`00Oomoo`22
Ool00`00Oomoo`3oOomGOol003ioo`03001oogoo00Uoo`03001oogoo085oo`03001oogoo0;5oo`80
08=oo`03001oogoo0?mooeMoo`00?Woo0`002Goo00<007ooOol0PGoo00<007ooOol0/Woo00<007oo
Ool0PGoo00<007ooOol0ogooEgoo000nOol00`00Oomoo`09Ool00`00Oomoo`21Ool00`00Oomoo`2b
Ool00`00Oomoo`21Ool00`00Oomoo`3oOomGOol003ioo`03001oogoo00Uoo`03001oogoo085oo`03
001oogoo0;9oo`03001oogoo085oo`03001oogoo0?mooeMoo`00?Woo00<007ooOol02Goo00<007oo
Ool0PGoo00<007ooOol0/Woo00<007ooOol0PGoo00<007ooOol0ogooEgoo000nOol00`00Oomoo`09
Ool00`00Oomoo`21Ool00`00Oomoo`2bOol00`00Oomoo`21Ool00`00Oomoo`3oOomGOol003ioo`03
001oogoo00Uoo`03001oogoo085oo`03001oogoo0;9oo`03001oogoo085oo`03001oogoo0?mooeMo
o`00?Woo00<007ooOol02Goo00<007ooOol0PGoo00<007ooOol0/Woo00<007ooOol0PGoo00<007oo
Ool0ogooEgoo000nOol00`00Oomoo`09Ool00`00Oomoo`21Ool00`00Oomoo`2bOol00`00Oomoo`21
Ool00`00Oomoo`3oOomGOol003ioo`03001oogoo00Uoo`03001oogoo085oo`03001oogoo0;9oo`03
001oogoo085oo`03001oogoo0?mooeMoo`00?Woo00<007ooOol02Goo00<007ooOol0PGoo00<007oo
Ool0/Woo00<007ooOol0PGoo00<007ooOol0ogooEgoo000nOol00`00Oomoo`09Ool00`00Oomoo`21
Ool00`00Oomoo`2bOol00`00Oomoo`21Ool00`00Oomoo`3oOomGOol003ioo`03001oogoo00Uoo`03
001oogoo085oo`03001oogoo0;9oo`03001oogoo085oo`03001oogoo0?mooeMoo`00:7oo2P0037oo
00<007ooOol02Goo00<007ooOol0PGoo00<007ooOol0/Woo00<007ooOol0PGoo00<007ooOol0ogoo
Egoo000XOol:000<Ool00`00Oomoo`09Ool00`00Oomoo`21Ool00`00Oomoo`2bOol00`00Oomoo`21
Ool00`00Oomoo`3oOomGOol002aoo`80011oo`03001oogoo00Uoo`03001oogoo085oo`03001oogoo
0;9oo`03001oogoo085oo`03001oogoo0?mooeMoo`00;7oo0P0047oo00<007ooOol02Goo00<007oo
Ool0PGoo00<007ooOol0/Woo00<007ooOol0PGoo00<007ooOol0ogooEgoo000/Ool2000@Ool00`00
Oomoo`09Ool00`00Oomoo`21Ool00`00Oomoo`2bOol00`00Oomoo`21Ool00`00Oomoo`3oOomGOol0
02aoo`80011oo`03001oogoo00Uoo`03001oogoo085oo`03001oogoo0;9oo`03001oogoo085oo`03
001oogoo0?mooeMoo`00;7oo0P0047oo00<007ooOol02Goo00<007ooOol0PGoo00<007ooOol0/Woo
00<007ooOol0PGoo00<007ooOol0ogooEgoo000/Ool2000@Ool50007Oon5002dOon5003oOomIOol0
02aoo`80011oo`03001oogoo0?mooomooomoob9oo`00;7oo0P0047oo00<007ooOol0ogooogooogoo
8Woo000/Ool2000@Ool00`00Oomoo`3oOoooOoooOolROol002aoo`80011oo`03001oogoo0?mooomo
oomoob9oo`00;7oo0P0047oo00<007ooOol0ogooogooogoo8Woo000/Ool2000@Ool00`00Oomoo`3o
OoooOoooOolROol002aoo`80011oo`03001oogoo0?mooomooomoob9oo`00:7oo0`0000=oo`000000
47oo00<007ooOol0ogooogooogoo8Woo000XOol6000@Ool00`00Oomoo`3oOoooOoooOolROol002]o
o`<0011oo`03001oogoo0?mooomooomoob9oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo0010Ool9
003oOoooOoooOolJOol0041oo`T00?mooomooomooaYoo`00@Woo0P00ogooogooogoo7goo0012Ool2
003oOoooOoooOolOOol0049oo`800?mooomooomooamoo`00@Woo0P00ogooogooogoo7goo000JOol7
0004Ool=0002Ool40002Ool40004Ool20002Ool60007Ool=003oOoooOoooOol3Ool001Yoo`L000Ao
o`d0009oo`@0009oo`@000Aoo`800003Ool0000000L000Eoo`d00?mooomooomoo`=oo`0077oo0P00
2Woo0P0017oo0P0017oo0P0017oo0P001Woo1@0017oo10002Goo0P00ogooogooogoo2Goo000LOol2
000:Ool20004Ool20004Ool20004Ool20006Ool30008Ool20009Ool2003oOoooOoooOol9Ool001eo
o`8000Qoo`8000Eoo`8000Aoo`8000Aoo`8000Ioo`<000Qoo`<000Qoo`800?mooomooomoo`Uoo`00
7Goo0P0027oo0P001Goo0P0017oo0P0017oo0P001Woo0P002Woo0P0027oo0P00ogooogooogoo2Goo
000MOol<0005Ool20004Ool20004Ool20006Ool2000:Ool20008Ool2003oOoooOoooOol9Ool001io
o`X000Ioo`8000Aoo`8000Aoo`8000Ioo`8000Yoo`8000Qoo`800?mooomooomoo`Uoo`007Woo0P00
1Woo0P001Woo0P0017oo0P0017oo0P001Woo0P002Woo0P0027oo0P00ogooogooogoo2Goo000OOol2
0004Ool20007Ool20004Ool20004Ool20006Ool30008Ool30008Ool2003oOoooOoooOol9Ool001mo
o`8000Aoo`8000Moo`8000Aoo`8000Aoo`8000Ioo`<000Qoo`8000Uoo`800?mooomooomoo`Uoo`00
7goo0P000goo0`001goo0`000Woo10000Woo0`001Woo1@0017oo0`002Woo0P00ogooogooogoo2Goo
000POol20002Ool20006Ool?0005Ool400000goo00000006000;Ool2003oOoooOoooOol9Ool0021o
o`80009oo`8000Ioo`@00003Ool000000080009oo`<000Ioo`@0009oo`H000aoo`800?mooomooomo
o`Uoo`0087oo1@00<goo0P00ogooogooogoo2Goo000MOol8000cOol2003oOoooOoooOol9Ool001eo
o`L003Aoo`800?mooomooomoo`Uoo`00Dgoo1`00ogooogooogoo2Goo001COol7003oOoooOoooOol9
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo0000\
\>"], "Graphics",
  CellLabel->"From In[43]:=",
  Evaluatable->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]],

Cell["\<\
Input Pulse on the left side of the pigtail,two pulses of 12.5 nsec \
length and 12.5 nsec separation.\
\>", "Text"],

Cell["\<\
Calculate evolution in time and produce animation of the \
propagating pulses:\
\>", "Text",
  CellFrame->False,
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Timing[\[IndentingNewLine]Do[\[IndentingNewLine]{ (*\ main\ loop, \ 
            calculate\ line\ n + 
              1\ in\ u\ and\ i\ grid\ *) \[IndentingNewLine]Do[{jp1 = j + 1; 
              jm1 = j - 1; \[IndentingNewLine]u1[\([j]\)] = 
                m1 . u0[\([j]\)] + \ 
                  m2 . \((u0[\([jp1]\)] + u0[\([jm1]\)])\) + 
                  m3 . \((i0[\([jp1]\)] - i0[\([jm1]\)])\); 
              i1[\([j]\)] = 
                m4 . i0[\([j]\)] + \ 
                  m5 . \((i0[\([jp1]\)] + i0[\([jm1]\)])\) + 
                  m6 . \((u0[\([jp1]\)] - u0[\([jm1]\)])\)}, {j, 2, 
              m - 1}]; \[IndentingNewLine] (*\ 
            edges\ *) \[IndentingNewLine]u1[\([m]\)] = 
            u0[\([m - 1]\)] + m8 . \((u0[\([m]\)] - u1[\([m - 1]\)])\) - 
              m9 . \((i0[\([m]\)] - 
                    i1[\([m - 1]\)])\); \[IndentingNewLine]i1[\([m]\)] = 
            m10 . i0[\([m - 1]\)] - 
              m11 . \((u0[\([m]\)] - u1[\([m - 1]\)])\) + 
              m12 . \((i0[\([m]\)] - 
                    i1[\([m - 1]\)])\); \[IndentingNewLine]u1[\([1]\)] = 
            u0[\([2]\)] + m8 . \((u0[\([1]\)] - u1[\([2]\)])\) + 
              m9 . \((i0[\([1]\)] - 
                    i1[\([2]\)])\); \[IndentingNewLine]i1[\([1]\)] = 
            m10 . i0[\([2]\)] + m11 . \((u0[\([1]\)] - u1[\([2]\)])\) + 
              m12 . \((i0[\([1]\)] - i1[\([2]\)])\); \[IndentingNewLine] (*\ 
            static\ boundary\ conditions\ \ \(open : \ set\ i\) = 0, \ 
            short : \ set\ u = 0\ *) \[IndentingNewLine]u1[\([m]\)] = 
            zr\ i1[\([m]\)];  (*\ 
            termination\ right\ with\ z\ *) \[IndentingNewLine]u1[\([1]\)] = \
\(-zl\)\ i1[\([1]\)]; \  (*\ 
            termination\ left\ with\  - 
              z\ *) \[IndentingNewLine]u1[\([1, 1]\)] = 
            uin[\([n]\)]; \[IndentingNewLine] (*\ 
            build\ output\ *) \[IndentingNewLine]uout = 
            Append[uout, u1[\([m, 1]\)]];  (*\ 
            seen\ on\ diff\ line\ 1\ after\ 1  
              m\ *) \[IndentingNewLine]uout1 = 
            Append[uout1, u1[\([m, 2]\)]];  (*\ 
            crosstalk\ on\ diff\ line\ 2\ after\ 1\ m\ \
*) \[IndentingNewLine]uout2 = 
            Append[uout2, Max[\(Transpose[u1]\)[\([2]\)]]];  (*\ 
            max\ ampl\ of\ crosstalk\ *) \[IndentingNewLine]u0 = u1; 
          i0 = i1;  (*\ 
            advance\ one\ step\ in\ time\ *) \[IndentingNewLine] (*\ 
            do\ a\ snapshot\ of\ the\ voltages\ *) \[IndentingNewLine]If[
            Mod[n, pl] \[Equal] 
              0, \[IndentingNewLine]{ (*\ 
                plot\ voltage\ wire\ 1\ *) \[IndentingNewLine]p1 = 
                ListPlot[\(Transpose[u1]\)[\([1]\)], 
                  PlotRange \[Rule] {{0, m}, {\(-0.6\), 1.7}}, 
                  PlotJoined \[Rule] True, 
                  DisplayFunction \[Rule] Identity]; \[IndentingNewLine] (*\ 
                plot\ current\ wire\ 1\ *) \[IndentingNewLine]p2 = 
                ListPlot[\(Transpose[i1]\)[\([1]\)], 
                  PlotRange \[Rule] {{0, m}, {\(-0.015\), 0.015}}, 
                  PlotJoined \[Rule] True, 
                  DisplayFunction \[Rule] Identity]; \[IndentingNewLine] (*\ 
                plot\ voltage\ wire\ 2\ *) \[IndentingNewLine]p3 = 
                ListPlot[\(Transpose[u1]\)[\([2]\)], 
                  PlotRange \[Rule] {{0, m}, {\(-0.039\), 0.039}}, 
                  PlotJoined \[Rule] True, 
                  DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[
                GraphicsArray[{{p1}, {p2}, {p3}}], 
                DisplayFunction \[Rule] $DisplayFunction]; \
\[IndentingNewLine] (*\ 
                get\ rid\ of\ small\ numbers\ to\ accelerate\ calculation\ \
*) \[IndentingNewLine]u0 = Chop[u0]; i0 = Chop[i0]; Print[n]}]}, {n, 
          nmax}]\[IndentingNewLine]]\), "\[IndentingNewLine]", 
    \(Print["\<Fertig !\>"]\)}], "Input",
  CellLabel->"In[44]:=",
  CellFrame->True,
  AnimationDisplayTime->0.287328,
  Background->GrayLevel[0.849989]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30611 m
.008 .30792 L
.012 .30952 L
.016 .31096 L
.02 .31212 L
.024 .31209 L
.028 .31102 L
.032 .31015 L
.036 .30955 L
.04 .30922 L
.044 .30909 L
.048 .30904 L
.052 .30902 L
.056 .30902 L
.06 .30902 L
.064 .30902 L
.068 .30902 L
.072 .30902 L
.076 .30902 L
.08 .30902 L
.084 .30902 L
.088 .30902 L
.092 .30902 L
.096 .30902 L
.1 .30902 L
.104 .30902 L
.108 .30902 L
.112 .30902 L
.116 .30902 L
.12 .30902 L
.124 .30902 L
.128 .30902 L
.132 .30902 L
.136 .30902 L
.14 .30902 L
.144 .30902 L
.148 .30902 L
.152 .30902 L
.156 .30902 L
.16 .30902 L
.164 .30902 L
.168 .30902 L
.172 .30902 L
.176 .30902 L
.18 .30902 L
.184 .30902 L
.188 .30902 L
.192 .30902 L
.196 .30902 L
.2 .30902 L
Mistroke
.204 .30902 L
.208 .30902 L
.212 .30902 L
.216 .30902 L
.22 .30902 L
.224 .30902 L
.228 .30902 L
.232 .30902 L
.236 .30902 L
.24 .30902 L
.244 .30902 L
.248 .30902 L
.252 .30902 L
.256 .30902 L
.26 .30902 L
.264 .30902 L
.268 .30902 L
.272 .30902 L
.276 .30902 L
.28 .30902 L
.284 .30902 L
.288 .30902 L
.292 .30902 L
.296 .30902 L
.3 .30902 L
.304 .30902 L
.308 .30902 L
.312 .30902 L
.316 .30902 L
.32 .30902 L
.324 .30902 L
.328 .30902 L
.332 .30902 L
.336 .30902 L
.34 .30902 L
.344 .30902 L
.348 .30902 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .34448 m
.008 .33971 L
.012 .33452 L
.016 .32889 L
.02 .32294 L
.024 .31691 L
.028 .31285 L
.032 .31075 L
.036 .30962 L
.04 .30924 L
.044 .30908 L
.048 .30904 L
.052 .30902 L
.056 .30902 L
.06 .30902 L
.064 .30902 L
.068 .30902 L
.072 .30902 L
.076 .30902 L
.08 .30902 L
.084 .30902 L
.088 .30902 L
.092 .30902 L
.096 .30902 L
.1 .30902 L
.104 .30902 L
.108 .30902 L
.112 .30902 L
.116 .30902 L
.12 .30902 L
.124 .30902 L
.128 .30902 L
.132 .30902 L
.136 .30902 L
.14 .30902 L
.144 .30902 L
.148 .30902 L
.152 .30902 L
.156 .30902 L
.16 .30902 L
.164 .30902 L
.168 .30902 L
.172 .30902 L
.176 .30902 L
.18 .30902 L
.184 .30902 L
.188 .30902 L
.192 .30902 L
.196 .30902 L
.2 .30902 L
Mistroke
.204 .30902 L
.208 .30902 L
.212 .30902 L
.216 .30902 L
.22 .30902 L
.224 .30902 L
.228 .30902 L
.232 .30902 L
.236 .30902 L
.24 .30902 L
.244 .30902 L
.248 .30902 L
.252 .30902 L
.256 .30902 L
.26 .30902 L
.264 .30902 L
.268 .30902 L
.272 .30902 L
.276 .30902 L
.28 .30902 L
.284 .30902 L
.288 .30902 L
.292 .30902 L
.296 .30902 L
.3 .30902 L
.304 .30902 L
.308 .30902 L
.312 .30902 L
.316 .30902 L
.32 .30902 L
.324 .30902 L
.328 .30902 L
.332 .30902 L
.336 .30902 L
.34 .30902 L
.344 .30902 L
.348 .30902 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .2061 m
.008 .19723 L
.012 .1932 L
.016 .18682 L
.02 .17807 L
.024 .17109 L
.028 .16617 L
.032 .16324 L
.036 .16205 L
.04 .16147 L
.044 .16131 L
.048 .16125 L
.052 .16123 L
.056 .16123 L
.06 .16123 L
.064 .16123 L
.068 .16123 L
.072 .16123 L
.076 .16123 L
.08 .16123 L
.084 .16123 L
.088 .16123 L
.092 .16123 L
.096 .16123 L
.1 .16123 L
.104 .16123 L
.108 .16123 L
.112 .16123 L
.116 .16123 L
.12 .16123 L
.124 .16123 L
.128 .16123 L
.132 .16123 L
.136 .16123 L
.14 .16123 L
.144 .16123 L
.148 .16123 L
.152 .16123 L
.156 .16123 L
.16 .16123 L
.164 .16123 L
.168 .16123 L
.172 .16123 L
.176 .16123 L
.18 .16123 L
.184 .16123 L
.188 .16123 L
.192 .16123 L
.196 .16123 L
.2 .16123 L
Mistroke
.204 .16123 L
.208 .16123 L
.212 .16123 L
.216 .16123 L
.22 .16123 L
.224 .16123 L
.228 .16123 L
.232 .16123 L
.236 .16123 L
.24 .16123 L
.244 .16123 L
.248 .16123 L
.252 .16123 L
.256 .16123 L
.26 .16123 L
.264 .16123 L
.268 .16123 L
.272 .16123 L
.276 .16123 L
.28 .16123 L
.284 .16123 L
.288 .16123 L
.292 .16123 L
.296 .16123 L
.3 .16123 L
.304 .16123 L
.308 .16123 L
.312 .16123 L
.316 .16123 L
.32 .16123 L
.324 .16123 L
.328 .16123 L
.332 .16123 L
.336 .16123 L
.34 .16123 L
.344 .16123 L
.348 .16123 L
.352 .16123 L
.356 .16123 L
.36 .16123 L
.364 .16123 L
.368 .16123 L
.372 .16123 L
.376 .16123 L
.38 .16123 L
.384 .16123 L
.388 .16123 L
.392 .16123 L
.396 .16123 L
.4 .16123 L
Mistroke
.404 .16123 L
.408 .16123 L
.412 .16123 L
.416 .16123 L
.42 .16123 L
.424 .16123 L
.428 .16123 L
.432 .16123 L
.436 .16123 L
.44 .16123 L
.444 .16123 L
.448 .16123 L
.452 .16123 L
.456 .16123 L
.46 .16123 L
.464 .16123 L
.468 .16123 L
.472 .16123 L
.476 .16123 L
.48 .16123 L
.484 .16123 L
.488 .16123 L
.492 .16123 L
.496 .16123 L
.5 .16123 L
.504 .16123 L
.508 .16123 L
.512 .16123 L
.516 .16123 L
.52 .16123 L
.524 .16123 L
.528 .16123 L
.532 .16123 L
.536 .16123 L
.54 .16123 L
.544 .16123 L
.548 .16123 L
.552 .16123 L
.556 .16123 L
.56 .16123 L
.564 .16123 L
.568 .16123 L
.572 .16123 L
.576 .16123 L
.58 .16123 L
.584 .16123 L
.588 .16123 L
.592 .16123 L
.596 .16123 L
.6 .16123 L
Mistroke
.604 .16123 L
.608 .16123 L
.612 .16123 L
.616 .16123 L
.62 .16123 L
.624 .16123 L
.628 .16123 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017b000`400?l00000o`00003oT@3oool0
0940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3o
ool00940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00
T@3oool00280oooo00<000000?ooo`3oool0K03oool00280oooo0P00001]0?ooo`008P3oool00`00
0000oooo0?ooo`1/0?ooo`008P3oool2000006d0oooo000R0?ooo`800000K@3oool000/0oooo0P00
00040?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<000000`3oool00`000000oooo0?oo
o`1/0?ooo`002P3oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool0
00000`3oool00`000000oooo0?ooo`02000006d0oooo00030?ooo`D000000P3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00P00001]0?oo
o`002P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0P000003
0?ooo`030000003oool0oooo06`0oooo000:0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`02000006d0oooo000:0?ooo`040000003oool0
oooo000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo0080
0000K@3oool000/0oooo0P00000:0?ooo`8000000`3oool3000000<0oooo00<000000?ooo`3oool0
K03oool00280oooo0P00001]0?ooo`002`3oool2000000@0oooo00<000000?ooo`3oool00`3oool2
00000080oooo1@0000020?ooo`030000003oool0oooo06`0oooo000:0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`800000
K@3oool000<0oooo1@0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`020?ooo`800000K@3oool000X0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000KP3oool0
00X0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo
00<000000?ooo`3oool00P00001]0?ooo`002P3oool010000000oooo0?ooo`0000080?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`02000006d0oooo000;0?ooo`80
00002P3oool2000000<0oooo0`0000030?ooo`030000003oool0oooo06`0oooo000;0?ooo`800000
103oool00`000000oooo0?ooo`030?ooo`8000000`3oool3000000<0oooo0P00001]0?ooo`002P3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool00P3oool2000000d0oooo0`0000040?ooo`8000001`3oool3000000@0oooo0P0000040?ooo`80
00001@3oool3000000<0oooo0`0000040?ooo`8000000`3oool5000000<0oooo0P0000040?ooo`80
0000103oool500000080oooo0`0000040?ooo`8000001P3oool000<0oooo1@0000020?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo
00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000
003oool000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo000:
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`020?ooo`800000403oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00<0oooo000:0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`020?ooo`800000403oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool01@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool000X0oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`800000103oool00`000000
oooo0?ooo`0;0?ooo`@000000`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`040000003o
ool0oooo0?ooo`@000000`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00H0
00000?ooo`3oool0oooo0000003oool4000000<0oooo00@000000?ooo`3oool000001@3oool000/0
oooo0P00000:0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`800000303oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo000000H0oooo0P0000040?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool2000000<0oooo00<000000?ooo`3oool0103o
ool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`3oool0oooo0000
003oool0000000H0oooo00@000000?ooo`3oool000001@3oool00280oooo0P00000<0?ooo`D00000
0`3oool2000000P0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000060?ooo`040000
003oool0oooo0?ooo`D000000`3oool2000000@0oooo0`0000040?ooo`800000103oool2000000D0
oooo0`0000020?ooo`D000000`3oool2000000H0oooo000R0?ooo`030000003oool0oooo06`0oooo
000R0?ooo`800000K@3oool00280ooooH`00000<0?ooo`008P3oool600000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?oo
o`0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo0000000<0?ooo`008P3oool2000006d0oooo000R0?ooo`030000003oool0oooo
06`0oooo000R0?ooo`800000K@3oool00280oooo0P00001]0?ooo`002`3oool2000000@0oooo00<0
00000?ooo`3oool00`3oool2000000<0oooo0`0000030?ooo`030000003oool0oooo06`0oooo000:
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`020?ooo`800000K@3oool000X0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo0080oooo0P00001]0?ooo`002P3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1/0?ooo`002P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool00P3oool2000006d0oooo000:0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool2000000@0oooo0P00001]0?ooo`002`3oool2
000000X0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0K03oool0
00/0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`D000000P3oool20000
06d0oooo000:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`800000K@3oool000X0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
K03oool000X0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0oooo0?ooo`800000K@3oool000X0oooo00@000000?ooo`3oool00000203oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P00001]0?ooo`002P3oool0
10000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool000000`3oool010000000
oooo0?ooo`00001^0?ooo`002`3oool2000000X0oooo0P0000030?ooo`<000000`3oool2000006d0
oooo000R0?ooo`030000003oool0oooo06`0oooo000;0?ooo`800000103oool00`000000oooo0?oo
o`030?ooo`8000000`3oool3000000<0oooo0P00001]0?ooo`002P3oool010000000oooo0?ooo`00
00080?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`02000006d0
oooo000:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool01000
0000oooo0?ooo`00001^0?ooo`002P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000<0oooo0P0000030?ooo`800000K@3oool000X0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00800000K@3oool000X0oooo00@0
00000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00@000000?oo
o`3oool00000KP3oool000/0oooo0P00000:0?ooo`8000000`3oool3000000<0oooo0P00001]0?oo
o`008P3oool2000006d0oooo000R0?ooo`030000003oool0oooo06`0oooo000R0?ooo`800000K@3o
ool00280oooo00<000000?ooo`3oool0K03oool00940oooo002A0?ooo`00T@3oool00940oooo002A
0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo
002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940
oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool0
0940oooo000;0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000000`3oool3000000<0
oooo0`00001/0?ooo`002P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo06T0oooo00030?oo
o`D000000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1Y0?ooo`002P3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`02000006L0oooo000:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000`3oool010000000oooo0?ooo`3oool4000000<0oooo00<000000?ooo`3oool0IP3oool000X0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`8000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo06H0oooo000;0?ooo`8000002P3oool20000
00@0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`030000003oool0oooo06H0oooo000X0?oo
o`030000003oool0oooo06H0oooo000X0?ooo`030000003oool0oooo06H0oooo000X0?ooo`030000
003oool0oooo06H0oooo000A0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000000`3o
ool3000000<0oooo00<000000?ooo`3oool0IP3oool00100oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
IP3oool000T0oooo1@0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`020?ooo`800000I`3oool00100oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0IP3oool00100oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0IP3oool00100oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000020?ooo`800000103oool00`000000oooo0?oo
o`1V0?ooo`004@3oool2000000X0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0IP3oool002P0oooo00<000000?ooo`3oool0IP3oool002P0oooo00<000000?ooo`3o
ool0IP3oool000/0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`800000
0`3oool3000000<0oooo00<000000?ooo`3oool0IP3oool000X0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool0
10000000oooo0?ooo`00001X0?ooo`000`3oool500000080oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3o
ool00000J03oool000X0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00P00000;0?ooo`<00000103o
ool2000000L0oooo0`0000040?ooo`800000103oool2000000<0oooo0`0000030?ooo`<00000103o
ool200000080oooo1@0000030?ooo`800000103oool2000000<0oooo1@0000020?ooo`<00000103o
ool2000000H0oooo000:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0P3oool01@000000oooo0?ooo`000000oooo00@000000`3oool00`000000oooo0?ooo`090?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00`3oool000X0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000001P3oool00`000000oooo
0?ooo`0=0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo
000000040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool0
00/0oooo0P00000:0?ooo`800000103oool200000080oooo1@0000020?ooo`030000003oool0oooo
00d0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00<0oooo000X0?ooo`030000003oool0oooo00T0oooo100000030?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000<0oooo00@000000?ooo`3oool0oooo100000030?ooo`060000003oool0oooo
0000003oool000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000`3oool00`000000oooo00000003000000<0oooo00@000000?oo
o`3oool000001@3oool002P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?oo
o`040000003oool0oooo000000H0oooo0P0000040?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool2000000<0oooo00<000000?ooo`3oool0103oool01P000000oooo
0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000001P3oool010000000oooo
0?ooo`0000050?ooo`00:03oool00`000000oooo0?ooo`090?ooo`D000000`3oool2000000P0oooo
00<000000?ooo`3oool00`3oool2000000@0oooo0P0000040?ooo`040000003oool0oooo0?ooo`D0
00000`3oool2000000<0oooo0`0000040?ooo`800000103oool2000000@0oooo0`0000020?ooo`D0
00000`3oool2000000H0oooo000X0?ooo`030000003oool0oooo06H0oooo000X0?ooo`030000003o
ool0oooo06H0oooo000X0?oooed00000303oool002P0oooo00<000000?ooo`0000003`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00X0oooo000X0?ooo`<00000IP3oool002P0oooo
0P00001W0?ooo`00:03oool00`000000oooo0?ooo`1V0?ooo`00:03oool00`000000oooo0?ooo`1V
0?ooo`00:03oool00`000000oooo0?ooo`1V0?ooo`002`3oool2000000@0oooo00<000000?ooo`3o
ool00`3oool2000000@0oooo0P0000030?ooo`<000000`3oool00`000000oooo0?ooo`1V0?ooo`00
2P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`040000003oool0oooo000006P0oooo000:0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?oo
o`040000003oool0oooo000006P0oooo000:0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00800000
I`3oool000X0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`05
0000003oool0oooo0000003oool0100000030?ooo`030000003oool0oooo06H0oooo000:0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`00
0000oooo000000H0oooo00<000000?ooo`3oool0IP3oool000/0oooo0P00000:0?ooo`800000103o
ool200000080oooo1@0000020?ooo`030000003oool0oooo06H0oooo000X0?ooo`030000003oool0
oooo06H0oooo000X0?ooo`030000003oool0oooo06H0oooo000A0?ooo`800000103oool00`000000
oooo0?ooo`030?ooo`8000000`3oool3000000<0oooo00<000000?ooo`3oool0IP3oool00100oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0IP3oool00100oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0IP3oool0
0100oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo0080oooo0P00001W0?ooo`00403oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1V0?ooo`00403o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo0P0000040?ooo`03
0000003oool0oooo06H0oooo000A0?ooo`8000002P3oool2000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1V0?ooo`00:03oool00`000000oooo0?ooo`1V0?ooo`00:03oool0
0`000000oooo0?ooo`1V0?ooo`00:03oool00`000000oooo0?ooo`1V0?ooo`002`3oool2000000@0
oooo00<000000?ooo`3oool00`3oool2000000<0oooo0`0000030?ooo`<000000`3oool00`000000
oooo0?ooo`1V0?ooo`002P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000006P0oooo000:
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00800000I`3oool000X0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0J@3oool000X0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?oo
o`040000003oool0oooo0?ooo`@00000K03oool000X0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000020?ooo`8000000`3oool00`000000oooo0?ooo`1]0?ooo`002`3oool2
000000X0oooo0P0000040?ooo`040000003oool0oooo0?ooo`D00000J`3oool00940oooo002A0?oo
o`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo002A
0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo
002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940
oooo002A0?ooo`00T@3oool000/0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`000003
0?ooo`030000003oool0oooo0780oooo000:0?ooo`040000003oool0oooo000000L0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0780oooo00030?ooo`D000000P3oool0
10000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00800000L`3oool000X0oooo00@00000
0?ooo`3oool000002`3oool010000000oooo0?ooo`00001d0?ooo`002P3oool010000000oooo0?oo
o`0000070?ooo`@000000`3oool00`000000oooo0?ooo`1b0?ooo`002P3oool010000000oooo0?oo
o`0000070?ooo`030000003oool0oooo00@0oooo0P00001c0?ooo`002`3oool2000000P0oooo1@00
00020?ooo`030000003oool0oooo0780oooo000L0?ooo`030000003oool0oooo00d0oooo0`000004
0?ooo`8000002@3oool3000000@0oooo0P0000040?ooo`8000001@3oool3000000<0oooo0`000004
0?ooo`8000001@3oool5000000<0oooo0P0000040?ooo`8000001@3oool500000080oooo0`000004
0?ooo`8000001P3oool001`0oooo0P00000=0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`0000000`3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3o
ool001`0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00<0oooo000L0?ooo`030000003oool0oooo0100oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
00D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0
oooo000L0?ooo`8000003@3oool4000000<0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`3oool4000000<0oooo00@000000?ooo`3oool00000103oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`060000003oool0oooo0?ooo`000000oooo100000030?ooo`040000003oool0oooo000000D0
oooo000L0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`0000080?ooo`800000103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo0P0000030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000103o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`040000003o
ool0oooo000000D0oooo000L0?ooo`8000003@3oool5000000<0oooo0P00000:0?ooo`030000003o
ool0oooo00<0oooo0P0000040?ooo`8000001P3oool010000000oooo0?ooo`3oool5000000<0oooo
0P0000060?ooo`<00000103oool2000000@0oooo0P0000060?ooo`<000000P3oool5000000<0oooo
0P0000060?ooo`00703oool00`000000oooo0?ooo`1b0?ooo`00703oool00`000000oooo0?ooo`1b
0?ooo`00703ooomY000000`0oooo000L0?ooo`030000003oool0oooo008000000`3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool001`0oooo
00<000000?ooo`000000LP3oool001`0oooo0`00001b0?ooo`00703oool2000007<0oooo000L0?oo
o`800000L`3oool001`0oooo0P00001c0?ooo`00703oool00`000000oooo0?ooo`1b0?ooo`00703o
ool00`000000oooo0?ooo`1b0?ooo`00703oool2000007<0oooo000L0?ooo`030000003oool0oooo
0780oooo000L0?ooo`800000L`3oool000/0oooo0P0000040?ooo`030000003oool0oooo0080oooo
0`0000030?ooo`030000003oool0oooo0780oooo000:0?ooo`040000003oool0oooo000000L0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0780oooo000:0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool00P00001c0?ooo`002P3oool010000000oooo
0?ooo`00000;0?ooo`040000003oool0oooo000007@0oooo000:0?ooo`040000003oool0oooo0000
00L0oooo100000030?ooo`030000003oool0oooo0780oooo000:0?ooo`040000003oool0oooo0000
00L0oooo00<000000?ooo`3oool0103oool2000007<0oooo000;0?ooo`800000203oool500000080
oooo00<000000?ooo`3oool0LP3oool001`0oooo00<000000?ooo`3oool0LP3oool001`0oooo0P00
001c0?ooo`00703oool00`000000oooo0?ooo`1b0?ooo`00703oool2000007<0oooo000L0?ooo`03
0000003oool0oooo0780oooo000L0?ooo`030000003oool0oooo0780oooo000L0?ooo`800000L`3o
ool001H0oooo0`0000030?ooo`030000003oool0oooo0780oooo000G0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0LP3oool001L0oooo00<000000?ooo`3oool00P3oool2000007<0
oooo000G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0LP3oool001L0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1b0?ooo`005P3oool2000000@0oooo0P00001c
0?ooo`005`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0780oooo000L0?ooo`03
0000003oool0oooo0780oooo000L0?ooo`800000L`3oool001`0oooo00<000000?ooo`3oool0LP3o
ool001`0oooo0P00001c0?ooo`00703oool00`000000oooo0?ooo`1b0?ooo`00703oool00`000000
oooo0?ooo`1b0?ooo`002P3oool3000000@0oooo00<000000?ooo`3oool00P3oool3000000<0oooo
0P00001c0?ooo`002`3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`1b0?ooo`002`3oool00`000000oooo0?ooo`0;0?ooo`040000003o
ool0oooo000007@0oooo000;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P00
001c0?ooo`002`3oool00`000000oooo0?ooo`070?ooo`@000000`3oool00`000000oooo0?ooo`1b
0?ooo`002P3oool2000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1b0?oo
o`002`3oool00`000000oooo0?ooo`070?ooo`D000000P3oool2000007<0oooo000L0?ooo`030000
003oool0oooo0780oooo000L0?ooo`030000003oool0oooo0780oooo002A0?ooo`00T@3oool00940
oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool0
0940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(167\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30545 m
.008 .30685 L
.012 .30723 L
.016 .30836 L
.02 .31012 L
.024 .31064 L
.028 .31022 L
.032 .31152 L
.036 .31443 L
.04 .3165 L
.044 .31724 L
.048 .31648 L
.052 .3146 L
.056 .31275 L
.06 .3112 L
.064 .31017 L
.068 .30958 L
.072 .30926 L
.076 .30912 L
.08 .30906 L
.084 .30903 L
.088 .30902 L
.092 .30902 L
.096 .30902 L
.1 .30902 L
.104 .30902 L
.108 .30902 L
.112 .30902 L
.116 .30902 L
.12 .30902 L
.124 .30902 L
.128 .30902 L
.132 .30902 L
.136 .30902 L
.14 .30902 L
.144 .30902 L
.148 .30902 L
.152 .30902 L
.156 .30902 L
.16 .30902 L
.164 .30902 L
.168 .30902 L
.172 .30902 L
.176 .30902 L
.18 .30902 L
.184 .30902 L
.188 .30902 L
.192 .30902 L
.196 .30902 L
.2 .30902 L
Mistroke
.204 .30902 L
.208 .30902 L
.212 .30902 L
.216 .30902 L
.22 .30902 L
.224 .30902 L
.228 .30902 L
.232 .30902 L
.236 .30902 L
.24 .30902 L
.244 .30902 L
.248 .30902 L
.252 .30902 L
.256 .30902 L
.26 .30902 L
.264 .30902 L
.268 .30902 L
.272 .30902 L
.276 .30902 L
.28 .30902 L
.284 .30902 L
.288 .30902 L
.292 .30902 L
.296 .30902 L
.3 .30902 L
.304 .30902 L
.308 .30902 L
.312 .30902 L
.316 .30902 L
.32 .30902 L
.324 .30902 L
.328 .30902 L
.332 .30902 L
.336 .30902 L
.34 .30902 L
.344 .30902 L
.348 .30902 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .38438 m
.008 .3756 L
.012 .36913 L
.016 .36495 L
.02 .35986 L
.024 .3539 L
.028 .34871 L
.032 .34418 L
.036 .33879 L
.04 .33241 L
.044 .32604 L
.048 .32013 L
.052 .31566 L
.056 .31267 L
.06 .31082 L
.064 .30987 L
.068 .30937 L
.072 .30917 L
.076 .30907 L
.08 .30904 L
.084 .30902 L
.088 .30902 L
.092 .30902 L
.096 .30902 L
.1 .30902 L
.104 .30902 L
.108 .30902 L
.112 .30902 L
.116 .30902 L
.12 .30902 L
.124 .30902 L
.128 .30902 L
.132 .30902 L
.136 .30902 L
.14 .30902 L
.144 .30902 L
.148 .30902 L
.152 .30902 L
.156 .30902 L
.16 .30902 L
.164 .30902 L
.168 .30902 L
.172 .30902 L
.176 .30902 L
.18 .30902 L
.184 .30902 L
.188 .30902 L
.192 .30902 L
.196 .30902 L
.2 .30902 L
Mistroke
.204 .30902 L
.208 .30902 L
.212 .30902 L
.216 .30902 L
.22 .30902 L
.224 .30902 L
.228 .30902 L
.232 .30902 L
.236 .30902 L
.24 .30902 L
.244 .30902 L
.248 .30902 L
.252 .30902 L
.256 .30902 L
.26 .30902 L
.264 .30902 L
.268 .30902 L
.272 .30902 L
.276 .30902 L
.28 .30902 L
.284 .30902 L
.288 .30902 L
.292 .30902 L
.296 .30902 L
.3 .30902 L
.304 .30902 L
.308 .30902 L
.312 .30902 L
.316 .30902 L
.32 .30902 L
.324 .30902 L
.328 .30902 L
.332 .30902 L
.336 .30902 L
.34 .30902 L
.344 .30902 L
.348 .30902 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .25098 m
.008 .24384 L
.012 .23765 L
.016 .2311 L
.02 .22399 L
.024 .21725 L
.028 .21107 L
.032 .20487 L
.036 .19824 L
.04 .1906 L
.044 .18229 L
.048 .17513 L
.052 .16953 L
.056 .16573 L
.06 .16352 L
.064 .16226 L
.068 .16169 L
.072 .1614 L
.076 .1613 L
.08 .16125 L
.084 .16123 L
.088 .16123 L
.092 .16123 L
.096 .16123 L
.1 .16123 L
.104 .16123 L
.108 .16123 L
.112 .16123 L
.116 .16123 L
.12 .16123 L
.124 .16123 L
.128 .16123 L
.132 .16123 L
.136 .16123 L
.14 .16123 L
.144 .16123 L
.148 .16123 L
.152 .16123 L
.156 .16123 L
.16 .16123 L
.164 .16123 L
.168 .16123 L
.172 .16123 L
.176 .16123 L
.18 .16123 L
.184 .16123 L
.188 .16123 L
.192 .16123 L
.196 .16123 L
.2 .16123 L
Mistroke
.204 .16123 L
.208 .16123 L
.212 .16123 L
.216 .16123 L
.22 .16123 L
.224 .16123 L
.228 .16123 L
.232 .16123 L
.236 .16123 L
.24 .16123 L
.244 .16123 L
.248 .16123 L
.252 .16123 L
.256 .16123 L
.26 .16123 L
.264 .16123 L
.268 .16123 L
.272 .16123 L
.276 .16123 L
.28 .16123 L
.284 .16123 L
.288 .16123 L
.292 .16123 L
.296 .16123 L
.3 .16123 L
.304 .16123 L
.308 .16123 L
.312 .16123 L
.316 .16123 L
.32 .16123 L
.324 .16123 L
.328 .16123 L
.332 .16123 L
.336 .16123 L
.34 .16123 L
.344 .16123 L
.348 .16123 L
.352 .16123 L
.356 .16123 L
.36 .16123 L
.364 .16123 L
.368 .16123 L
.372 .16123 L
.376 .16123 L
.38 .16123 L
.384 .16123 L
.388 .16123 L
.392 .16123 L
.396 .16123 L
.4 .16123 L
Mistroke
.404 .16123 L
.408 .16123 L
.412 .16123 L
.416 .16123 L
.42 .16123 L
.424 .16123 L
.428 .16123 L
.432 .16123 L
.436 .16123 L
.44 .16123 L
.444 .16123 L
.448 .16123 L
.452 .16123 L
.456 .16123 L
.46 .16123 L
.464 .16123 L
.468 .16123 L
.472 .16123 L
.476 .16123 L
.48 .16123 L
.484 .16123 L
.488 .16123 L
.492 .16123 L
.496 .16123 L
.5 .16123 L
.504 .16123 L
.508 .16123 L
.512 .16123 L
.516 .16123 L
.52 .16123 L
.524 .16123 L
.528 .16123 L
.532 .16123 L
.536 .16123 L
.54 .16123 L
.544 .16123 L
.548 .16123 L
.552 .16123 L
.556 .16123 L
.56 .16123 L
.564 .16123 L
.568 .16123 L
.572 .16123 L
.576 .16123 L
.58 .16123 L
.584 .16123 L
.588 .16123 L
.592 .16123 L
.596 .16123 L
.6 .16123 L
Mistroke
.604 .16123 L
.608 .16123 L
.612 .16123 L
.616 .16123 L
.62 .16123 L
.624 .16123 L
.628 .16123 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017b000`400?l00000o`00003oT@3oool0
0940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3o
ool00940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00
T@3oool00280oooo00<000000?ooo`3oool0K03oool00280oooo0P00001]0?ooo`008P3oool00`00
0000oooo0?ooo`1/0?ooo`008P3oool2000006d0oooo000R0?ooo`800000K@3oool000/0oooo0P00
00040?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<000000`3oool00`000000oooo0?oo
o`1/0?ooo`002P3oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool0
00000`3oool00`000000oooo0?ooo`02000006d0oooo00030?ooo`D000000P3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00P00001]0?oo
o`002P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0P000003
0?ooo`030000003oool0oooo06`0oooo000:0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`02000006d0oooo000:0?ooo`040000003oool0
oooo000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo0080
0000K@3oool000/0oooo0P00000:0?ooo`8000000`3oool3000000<0oooo00<000000?ooo`3oool0
K03oool00280oooo0P00001]0?ooo`002`3oool2000000@0oooo00<000000?ooo`3oool00`3oool2
00000080oooo1@0000020?ooo`030000003oool0oooo06`0oooo000:0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`800000
K@3oool000<0oooo1@0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`020?ooo`800000K@3oool000X0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000KP3oool0
00X0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo
00<000000?ooo`3oool00P00001]0?ooo`002P3oool010000000oooo0?ooo`0000080?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`02000006d0oooo000;0?ooo`80
00002P3oool2000000<0oooo0`0000030?ooo`030000003oool0oooo06`0oooo000;0?ooo`800000
103oool00`000000oooo0?ooo`030?ooo`8000000`3oool3000000<0oooo0P00001]0?ooo`002P3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool00P3oool2000000d0oooo0`0000040?ooo`8000001`3oool3000000@0oooo0P0000040?ooo`80
00001@3oool3000000<0oooo0`0000040?ooo`8000000`3oool5000000<0oooo0P0000040?ooo`80
0000103oool500000080oooo0`0000040?ooo`8000001P3oool000<0oooo1@0000020?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo
00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000
003oool000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo000:
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`020?ooo`800000403oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00<0oooo000:0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`020?ooo`800000403oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool01@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool000X0oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`800000103oool00`000000
oooo0?ooo`0;0?ooo`@000000`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`040000003o
ool0oooo0?ooo`@000000`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00H0
00000?ooo`3oool0oooo0000003oool4000000<0oooo00@000000?ooo`3oool000001@3oool000/0
oooo0P00000:0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`800000303oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo000000H0oooo0P0000040?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool2000000<0oooo00<000000?ooo`3oool0103o
ool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`3oool0oooo0000
003oool0000000H0oooo00@000000?ooo`3oool000001@3oool00280oooo0P00000<0?ooo`D00000
0`3oool2000000P0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000060?ooo`040000
003oool0oooo0?ooo`D000000`3oool2000000@0oooo0`0000040?ooo`800000103oool2000000D0
oooo0`0000020?ooo`D000000`3oool2000000H0oooo000R0?ooo`030000003oool0oooo06`0oooo
000R0?ooo`800000K@3oool00280ooooH`00000<0?ooo`008P3oool00`000000oooo000000060000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@00000
0?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool02P3oool00280oooo0P00001]0?ooo`008P3oool00`000000
oooo0?ooo`1/0?ooo`008P3oool2000006d0oooo000R0?ooo`800000K@3oool000/0oooo0P000004
0?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<000000`3oool00`000000oooo0?ooo`1/
0?ooo`002P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00P3oool2000006d0oooo000:0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`800000K@3oool000X0oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0K03oool000X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo0P00001]0?ooo`002P3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo0P0000040?ooo`800000K@3oool0
00/0oooo0P00000:0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
06`0oooo000;0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000000P3oool500000080
oooo0P00001]0?ooo`002P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool2000006d0oooo000:0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo06`0oooo000:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
103oool010000000oooo0?ooo`3oool2000006d0oooo000:0?ooo`040000003oool0oooo000000P0
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00800000K@3oool0
00X0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo
00@000000?ooo`3oool00000KP3oool000/0oooo0P00000:0?ooo`8000000`3oool3000000<0oooo
0P00001]0?ooo`008P3oool00`000000oooo0?ooo`1/0?ooo`002`3oool2000000@0oooo00<00000
0?ooo`3oool00`3oool2000000<0oooo0`0000030?ooo`800000K@3oool000X0oooo00@000000?oo
o`3oool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0
0P00001]0?ooo`002P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000D0
oooo00@000000?ooo`3oool00000KP3oool000X0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000030?ooo`8000000`3oool2000006d0oooo000:0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`02000006d0oooo000:
0?ooo`040000003oool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`04
0000003oool0oooo000006h0oooo000;0?ooo`8000002P3oool2000000<0oooo0`0000030?ooo`80
0000K@3oool00280oooo0P00001]0?ooo`008P3oool00`000000oooo0?ooo`1/0?ooo`008P3oool2
000006d0oooo000R0?ooo`030000003oool0oooo06`0oooo002A0?ooo`00T@3oool00940oooo002A
0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo
002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940
oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool0
0940oooo002A0?ooo`002`3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000<0oooo
0`0000030?ooo`<00000K03oool000X0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`1Y0?oo
o`000`3oool500000080oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0J@3oool000X0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P00001W0?ooo`002P3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000<0oooo00@000000?ooo`3oool0oooo100000030?ooo`030000003oool0oooo06H0
oooo000:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool20000
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1V0?ooo`002`3oool2000000X0
oooo0P0000040?ooo`040000003oool0oooo0?ooo`D000000P3oool00`000000oooo0?ooo`1V0?oo
o`00:03oool00`000000oooo0?ooo`1V0?ooo`00:03oool00`000000oooo0?ooo`1V0?ooo`00:03o
ool00`000000oooo0?ooo`1V0?ooo`004@3oool2000000@0oooo00<000000?ooo`3oool00`3oool2
000000<0oooo0`0000030?ooo`030000003oool0oooo06H0oooo000@0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo06H0oooo00090?ooo`D000000P3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool00P3oool2000006L0oooo000@0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo06H0oooo000@0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06H0oooo000@0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool2000000@0oooo00<00000
0?ooo`3oool0IP3oool00140oooo0P00000:0?ooo`800000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo06H0oooo000X0?ooo`030000003oool0oooo06H0oooo000X0?ooo`030000
003oool0oooo06H0oooo000;0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`800000103o
ool2000000<0oooo0`0000030?ooo`030000003oool0oooo06H0oooo000:0?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00@000000?ooo`3oool00000J03oool000<0oooo1@0000020?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`040000
003oool0oooo000006P0oooo000:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo008000002`3oool3
000000@0oooo0P0000070?ooo`<00000103oool2000000@0oooo0P0000030?ooo`<000000`3oool3
000000@0oooo0P0000020?ooo`D000000`3oool2000000@0oooo0P0000030?ooo`D000000P3oool3
000000@0oooo0P0000060?ooo`002P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo00000080oooo00D000000?ooo`3oool000000?ooo`04000000<0oooo00<000000?ooo`3oool0
2@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000001`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00<0oooo000:0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000H0oooo00<0
00000?ooo`3oool03@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`050000003oool0
oooo0?ooo`000000103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00<0oooo000;0?ooo`8000002P3oool2000000@0oooo0P0000020?ooo`D000000P3oool00`000000
oooo0?ooo`0=0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`090?ooo`@000000`3oool01000
0000oooo0?ooo`0000070?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo0?ooo`@000000`3oool01P000000
oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`0000030?ooo`04
0000003oool0oooo000000D0oooo000X0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0103oool010000000oooo0?ooo`0000060?ooo`800000103oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo0P0000030?ooo`030000003oool0oooo00@0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000H0oooo00@0
00000?ooo`3oool000001@3oool002P0oooo00<000000?ooo`3oool02@3oool5000000<0oooo0P00
00080?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`800000103oool010000000oooo0?oo
o`3oool5000000<0oooo0P0000030?ooo`<00000103oool2000000@0oooo0P0000040?ooo`<00000
0P3oool5000000<0oooo0P0000060?ooo`00:03oool00`000000oooo0?ooo`1V0?ooo`00:03oool0
0`000000oooo0?ooo`1V0?ooo`00:03ooomM000000`0oooo000X0?ooo`040000003oool0oooo0?oo
o`800000303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00X0oooo000X0?ooo`05
0000003oool0oooo0?ooo`000000I03oool002P0oooo00@000000?ooo`3oool00000I@3oool002P0
oooo00@000000?ooo`0000000000I@3oool002P0oooo00<000000?ooo`000000IP3oool002P0oooo
0P00001W0?ooo`002`3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P00
00030?ooo`<000000`3oool00`000000oooo0?ooo`1V0?ooo`002P3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`040000003oool0oooo000006P0oooo000:0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000006P0
oooo000:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo00800000I`3oool000X0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0000003oool0
100000030?ooo`030000003oool0oooo06H0oooo000:0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000H0oooo00<00000
0?ooo`3oool0IP3oool000/0oooo0P00000:0?ooo`800000103oool200000080oooo1@0000020?oo
o`030000003oool0oooo06H0oooo000X0?ooo`030000003oool0oooo06H0oooo000X0?ooo`030000
003oool0oooo06H0oooo000A0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000000`3o
ool3000000<0oooo00<000000?ooo`3oool0IP3oool00100oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
IP3oool00100oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0IP3oool00100oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo0P00001W0?oo
o`00403oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`1V0?ooo`00403oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo0P0000040?ooo`030000003oool0oooo06H0oooo000A
0?ooo`8000002P3oool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1V
0?ooo`00:03oool00`000000oooo0?ooo`1V0?ooo`00:03oool00`000000oooo0?ooo`1V0?ooo`00
:03oool00`000000oooo0?ooo`1V0?ooo`002`3oool2000000@0oooo00<000000?ooo`3oool00`3o
ool2000000<0oooo0`0000030?ooo`<000000`3oool00`000000oooo0?ooo`1V0?ooo`002P3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`040000003oool0oooo000006P0oooo000:0?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00800000I`3oool000X0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0J@3oool000X0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo0?ooo`@0
0000K03oool000X0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?oo
o`8000000`3oool00`000000oooo0?ooo`1]0?ooo`002`3oool2000000X0oooo0P0000040?ooo`04
0000003oool0oooo0?ooo`D00000J`3oool00940oooo002A0?ooo`00T@3oool00940oooo002A0?oo
o`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo002A
0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo
002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool000/0
oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000030?ooo`030000003oool0oooo0780
oooo000:0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0780oooo00030?ooo`D000000P3oool010000000oooo0?ooo`00000;0?oo
o`030000003oool0oooo00800000L`3oool000X0oooo00@000000?ooo`3oool000002`3oool01000
0000oooo0?ooo`00001d0?ooo`002P3oool010000000oooo0?ooo`0000070?ooo`@000000`3oool0
0`000000oooo0?ooo`1b0?ooo`002P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0
oooo00@0oooo0P00001c0?ooo`002`3oool2000000P0oooo1@0000020?ooo`030000003oool0oooo
0780oooo000L0?ooo`030000003oool0oooo00d0oooo0`0000040?ooo`8000002@3oool3000000@0
oooo0P0000040?ooo`8000001@3oool3000000<0oooo0`0000040?ooo`8000001@3oool5000000<0
oooo0P0000040?ooo`8000001@3oool500000080oooo0`0000040?ooo`8000001P3oool001`0oooo
0P00000=0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00050?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000D0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool001`0oooo00<000000?ooo`3o
ool0403oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00<0oooo000L0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo000L0?ooo`8000003@3oool4
000000<0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`3oool40000
00<0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`060000003oool0oooo0?oo
o`000000oooo100000030?ooo`040000003oool0oooo000000D0oooo000L0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000080?ooo`800000103o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0P0000030?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`070000
003oool0oooo0?ooo`000000oooo000000060?ooo`040000003oool0oooo000000D0oooo000L0?oo
o`8000003@3oool5000000<0oooo0P00000:0?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`8000001P3oool010000000oooo0?ooo`3oool5000000<0oooo0P0000060?ooo`<00000103oool2
000000@0oooo0P0000060?ooo`<000000P3oool5000000<0oooo0P0000060?ooo`00703oool00`00
0000oooo0?ooo`1b0?ooo`00703oool00`000000oooo0?ooo`1b0?ooo`00703ooomY000000`0oooo
000L0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000@0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`00703oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo06d0oooo000L0?ooo`8000000P3oool00`000000oooo0?ooo`1^0?ooo`00703o
ool01@000000oooo0?ooo`3oool000000700oooo000L0?ooo`030000003oool0oooo00800000L03o
ool001`0oooo0P0000000`3oool000000?ooo`1`0?ooo`00703oool00`000000oooo0000001b0?oo
o`00703oool2000007<0oooo000L0?ooo`800000L`3oool001`0oooo0P00001c0?ooo`00703oool2
000007<0oooo000;0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<000000`3oool00`00
0000oooo0?ooo`1b0?ooo`002P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`1b0?ooo`002P3oool010000000oooo0?ooo`00000;
0?ooo`030000003oool0oooo00800000L`3oool000X0oooo00@000000?ooo`3oool000002`3oool0
10000000oooo0?ooo`00001d0?ooo`002P3oool010000000oooo0?ooo`0000070?ooo`@000000`3o
ool00`000000oooo0?ooo`1b0?ooo`002P3oool010000000oooo0?ooo`0000070?ooo`030000003o
ool0oooo00@0oooo0P00001c0?ooo`002`3oool2000000P0oooo1@0000020?ooo`030000003oool0
oooo0780oooo000L0?ooo`030000003oool0oooo0780oooo000L0?ooo`800000L`3oool001`0oooo
00<000000?ooo`3oool0LP3oool001`0oooo0P00001c0?ooo`00703oool00`000000oooo0?ooo`1b
0?ooo`00703oool00`000000oooo0?ooo`1b0?ooo`00703oool2000007<0oooo000F0?ooo`<00000
0`3oool00`000000oooo0?ooo`1b0?ooo`005`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0780oooo000G0?ooo`030000003oool0oooo0080oooo0P00001c0?ooo`005`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0780oooo000G0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0LP3oool001H0oooo0P0000040?ooo`800000L`3oool001L0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1b0?ooo`00703oool00`000000oooo0?ooo`1b
0?ooo`00703oool2000007<0oooo000L0?ooo`030000003oool0oooo0780oooo000L0?ooo`800000
L`3oool001`0oooo00<000000?ooo`3oool0LP3oool001`0oooo00<000000?ooo`3oool0LP3oool0
00X0oooo0`0000040?ooo`030000003oool0oooo0080oooo0`0000030?ooo`800000L`3oool000/0
oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0LP3oool000/0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`00001d0?oo
o`002`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00800000L`3oool000/0oooo
00<000000?ooo`3oool01`3oool4000000<0oooo00<000000?ooo`3oool0LP3oool000X0oooo0P00
00090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0LP3oool000/0oooo00<00000
0?ooo`3oool01`3oool500000080oooo0P00001c0?ooo`00703oool00`000000oooo0?ooo`1b0?oo
o`00703oool00`000000oooo0?ooo`1b0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940
oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool00940oooo002A0?ooo`00T@3oool0
0940oooo002A0?ooo`00T@3oool00940oooo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(334\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30516 m
.008 .30531 L
.012 .30502 L
.016 .30604 L
.02 .30835 L
.024 .30927 L
.028 .30886 L
.032 .30992 L
.036 .3125 L
.04 .3139 L
.044 .3137 L
.048 .31336 L
.052 .31377 L
.056 .31598 L
.06 .31941 L
.064 .32186 L
.068 .32265 L
.072 .3216 L
.076 .31919 L
.08 .31648 L
.084 .31396 L
.088 .31204 L
.092 .31073 L
.096 .30992 L
.1 .30947 L
.104 .30923 L
.108 .30911 L
.112 .30906 L
.116 .30903 L
.12 .30902 L
.124 .30902 L
.128 .30902 L
.132 .30902 L
.136 .30902 L
.14 .30902 L
.144 .30902 L
.148 .30902 L
.152 .30902 L
.156 .30902 L
.16 .30902 L
.164 .30902 L
.168 .30902 L
.172 .30902 L
.176 .30902 L
.18 .30902 L
.184 .30902 L
.188 .30902 L
.192 .30902 L
.196 .30902 L
.2 .30902 L
Mistroke
.204 .30902 L
.208 .30902 L
.212 .30902 L
.216 .30902 L
.22 .30902 L
.224 .30902 L
.228 .30902 L
.232 .30902 L
.236 .30902 L
.24 .30902 L
.244 .30902 L
.248 .30902 L
.252 .30902 L
.256 .30902 L
.26 .30902 L
.264 .30902 L
.268 .30902 L
.272 .30902 L
.276 .30902 L
.28 .30902 L
.284 .30902 L
.288 .30902 L
.292 .30902 L
.296 .30902 L
.3 .30902 L
.304 .30902 L
.308 .30902 L
.312 .30902 L
.316 .30902 L
.32 .30902 L
.324 .30902 L
.328 .30902 L
.332 .30902 L
.336 .30902 L
.34 .30902 L
.344 .30902 L
.348 .30902 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .41804 m
.008 .41158 L
.012 .40585 L
.016 .40078 L
.02 .39556 L
.024 .39 L
.028 .38469 L
.032 .37965 L
.036 .37428 L
.04 .36845 L
.044 .36288 L
.048 .35781 L
.052 .35307 L
.056 .34829 L
.06 .34268 L
.064 .33625 L
.068 .32973 L
.072 .32362 L
.076 .31864 L
.08 .31493 L
.084 .3124 L
.088 .31086 L
.092 .30994 L
.096 .30947 L
.1 .30922 L
.104 .30911 L
.108 .30905 L
.112 .30903 L
.116 .30902 L
.12 .30902 L
.124 .30902 L
.128 .30902 L
.132 .30902 L
.136 .30902 L
.14 .30902 L
.144 .30902 L
.148 .30902 L
.152 .30902 L
.156 .30902 L
.16 .30902 L
.164 .30902 L
.168 .30902 L
.172 .30902 L
.176 .30902 L
.18 .30902 L
.184 .30902 L
.188 .30902 L
.192 .30902 L
.196 .30902 L
.2 .30902 L
Mistroke
.204 .30902 L
.208 .30902 L
.212 .30902 L
.216 .30902 L
.22 .30902 L
.224 .30902 L
.228 .30902 L
.232 .30902 L
.236 .30902 L
.24 .30902 L
.244 .30902 L
.248 .30902 L
.252 .30902 L
.256 .30902 L
.26 .30902 L
.264 .30902 L
.268 .30902 L
.272 .30902 L
.276 .30902 L
.28 .30902 L
.284 .30902 L
.288 .30902 L
.292 .30902 L
.296 .30902 L
.3 .30902 L
.304 .30902 L
.308 .30902 L
.312 .30902 L
.316 .30902 L
.32 .30902 L
.324 .30902 L
.328 .30902 L
.332 .30902 L
.336 .30902 L
.34 .30902 L
.344 .30902 L
.348 .30902 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29585 m
.008 .29166 L
.012 .2825 L
.016 .27498 L
.02 .26899 L
.024 .26257 L
.028 .25577 L
.032 .24916 L
.036 .24255 L
.04 .23554 L
.044 .22835 L
.048 .22196 L
.052 .21628 L
.056 .21015 L
.06 .20314 L
.064 .19527 L
.068 .18698 L
.072 .17946 L
.076 .17322 L
.08 .16858 L
.084 .16547 L
.088 .1635 L
.092 .16239 L
.096 .16178 L
.1 .16148 L
.104 .16133 L
.108 .16127 L
.112 .16124 L
.116 .16123 L
.12 .16123 L
.124 .16123 L
.128 .16123 L
.132 .16123 L
.136 .16123 L
.14 .16123 L
.144 .16123 L
.148 .16123 L
.152 .16123 L
.156 .16123 L
.16 .16123 L
.164 .16123 L
.168 .16123 L
.172 .16123 L
.176 .16123 L
.18 .16123 L
.184 .16123 L
.188 .16123 L
.192 .16123 L
.196 .16123 L
.2 .16123 L
Mistroke
.204 .16123 L
.208 .16123 L
.212 .16123 L
.216 .16123 L
.22 .16123 L
.224 .16123 L
.228 .16123 L
.232 .16123 L
.236 .16123 L
.24 .16123 L
.244 .16123 L
.248 .16123 L
.252 .16123 L
.256 .16123 L
.26 .16123 L
.264 .16123 L
.268 .16123 L
.272 .16123 L
.276 .16123 L
.28 .16123 L
.284 .16123 L
.288 .16123 L
.292 .16123 L
.296 .16123 L
.3 .16123 L
.304 .16123 L
.308 .16123 L
.312 .16123 L
.316 .16123 L
.32 .16123 L
.324 .16123 L
.328 .16123 L
.332 .16123 L
.336 .16123 L
.34 .16123 L
.344 .16123 L
.348 .16123 L
.352 .16123 L
.356 .16123 L
.36 .16123 L
.364 .16123 L
.368 .16123 L
.372 .16123 L
.376 .16123 L
.38 .16123 L
.384 .16123 L
.388 .16123 L
.392 .16123 L
.396 .16123 L
.4 .16123 L
Mistroke
.404 .16123 L
.408 .16123 L
.412 .16123 L
.416 .16123 L
.42 .16123 L
.424 .16123 L
.428 .16123 L
.432 .16123 L
.436 .16123 L
.44 .16123 L
.444 .16123 L
.448 .16123 L
.452 .16123 L
.456 .16123 L
.46 .16123 L
.464 .16123 L
.468 .16123 L
.472 .16123 L
.476 .16123 L
.48 .16123 L
.484 .16123 L
.488 .16123 L
.492 .16123 L
.496 .16123 L
.5 .16123 L
.504 .16123 L
.508 .16123 L
.512 .16123 L
.516 .16123 L
.52 .16123 L
.524 .16123 L
.528 .16123 L
.532 .16123 L
.536 .16123 L
.54 .16123 L
.544 .16123 L
.548 .16123 L
.552 .16123 L
.556 .16123 L
.56 .16123 L
.564 .16123 L
.568 .16123 L
.572 .16123 L
.576 .16123 L
.58 .16123 L
.584 .16123 L
.588 .16123 L
.592 .16123 L
.596 .16123 L
.6 .16123 L
Mistroke
.604 .16123 L
.608 .16123 L
.612 .16123 L
.616 .16123 L
.62 .16123 L
.624 .16123 L
.628 .16123 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(501\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30263 m
.008 .3029 L
.012 .30363 L
.016 .30475 L
.02 .30634 L
.024 .30728 L
.028 .30743 L
.032 .3084 L
.036 .31042 L
.04 .31172 L
.044 .31183 L
.048 .31195 L
.052 .31294 L
.056 .31515 L
.06 .31763 L
.064 .31824 L
.068 .31711 L
.072 .31643 L
.076 .31733 L
.08 .32017 L
.084 .32408 L
.088 .32707 L
.092 .32825 L
.096 .32729 L
.1 .32463 L
.104 .32125 L
.108 .31783 L
.112 .31493 L
.116 .31272 L
.12 .3112 L
.124 .31024 L
.128 .30966 L
.132 .30934 L
.136 .30917 L
.14 .30909 L
.144 .30905 L
.148 .30903 L
.152 .30902 L
.156 .30902 L
.16 .30902 L
.164 .30902 L
.168 .30902 L
.172 .30902 L
.176 .30902 L
.18 .30902 L
.184 .30902 L
.188 .30902 L
.192 .30902 L
.196 .30902 L
.2 .30902 L
Mistroke
.204 .30902 L
.208 .30902 L
.212 .30902 L
.216 .30902 L
.22 .30902 L
.224 .30902 L
.228 .30902 L
.232 .30902 L
.236 .30902 L
.24 .30902 L
.244 .30902 L
.248 .30902 L
.252 .30902 L
.256 .30902 L
.26 .30902 L
.264 .30902 L
.268 .30902 L
.272 .30902 L
.276 .30902 L
.28 .30902 L
.284 .30902 L
.288 .30902 L
.292 .30902 L
.296 .30902 L
.3 .30902 L
.304 .30902 L
.308 .30902 L
.312 .30902 L
.316 .30902 L
.32 .30902 L
.324 .30902 L
.328 .30902 L
.332 .30902 L
.336 .30902 L
.34 .30902 L
.344 .30902 L
.348 .30902 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .4495 m
.008 .44741 L
.012 .44317 L
.016 .43669 L
.02 .43097 L
.024 .4259 L
.028 .42072 L
.032 .41541 L
.036 .41001 L
.04 .40445 L
.044 .39903 L
.048 .39385 L
.052 .38878 L
.056 .38355 L
.06 .37789 L
.064 .37197 L
.068 .36655 L
.072 .36173 L
.076 .35712 L
.08 .35227 L
.084 .34665 L
.088 .34028 L
.092 .33368 L
.096 .32735 L
.1 .32189 L
.104 .31755 L
.108 .31436 L
.112 .3122 L
.116 .31081 L
.12 .30998 L
.124 .30951 L
.128 .30926 L
.132 .30913 L
.136 .30907 L
.14 .30904 L
.144 .30903 L
.148 .30902 L
.152 .30902 L
.156 .30902 L
.16 .30902 L
.164 .30902 L
.168 .30902 L
.172 .30902 L
.176 .30902 L
.18 .30902 L
.184 .30902 L
.188 .30902 L
.192 .30902 L
.196 .30902 L
.2 .30902 L
Mistroke
.204 .30902 L
.208 .30902 L
.212 .30902 L
.216 .30902 L
.22 .30902 L
.224 .30902 L
.228 .30902 L
.232 .30902 L
.236 .30902 L
.24 .30902 L
.244 .30902 L
.248 .30902 L
.252 .30902 L
.256 .30902 L
.26 .30902 L
.264 .30902 L
.268 .30902 L
.272 .30902 L
.276 .30902 L
.28 .30902 L
.284 .30902 L
.288 .30902 L
.292 .30902 L
.296 .30902 L
.3 .30902 L
.304 .30902 L
.308 .30902 L
.312 .30902 L
.316 .30902 L
.32 .30902 L
.324 .30902 L
.328 .30902 L
.332 .30902 L
.336 .30902 L
.34 .30902 L
.344 .30902 L
.348 .30902 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .34072 m
.008 .3351 L
.012 .32746 L
.016 .32035 L
.02 .31382 L
.024 .30729 L
.028 .30057 L
.032 .29392 L
.036 .28727 L
.04 .28045 L
.044 .2735 L
.048 .26699 L
.052 .26082 L
.056 .25423 L
.06 .24704 L
.064 .23982 L
.068 .23299 L
.072 .22691 L
.076 .22127 L
.08 .21515 L
.084 .20812 L
.088 .20024 L
.092 .19193 L
.096 .1841 L
.1 .17727 L
.104 .17186 L
.108 .16789 L
.112 .16518 L
.116 .16346 L
.12 .16242 L
.124 .16184 L
.128 .16153 L
.132 .16137 L
.136 .16129 L
.14 .16125 L
.144 .16124 L
.148 .16123 L
.152 .16123 L
.156 .16123 L
.16 .16123 L
.164 .16123 L
.168 .16123 L
.172 .16123 L
.176 .16123 L
.18 .16123 L
.184 .16123 L
.188 .16123 L
.192 .16123 L
.196 .16123 L
.2 .16123 L
Mistroke
.204 .16123 L
.208 .16123 L
.212 .16123 L
.216 .16123 L
.22 .16123 L
.224 .16123 L
.228 .16123 L
.232 .16123 L
.236 .16123 L
.24 .16123 L
.244 .16123 L
.248 .16123 L
.252 .16123 L
.256 .16123 L
.26 .16123 L
.264 .16123 L
.268 .16123 L
.272 .16123 L
.276 .16123 L
.28 .16123 L
.284 .16123 L
.288 .16123 L
.292 .16123 L
.296 .16123 L
.3 .16123 L
.304 .16123 L
.308 .16123 L
.312 .16123 L
.316 .16123 L
.32 .16123 L
.324 .16123 L
.328 .16123 L
.332 .16123 L
.336 .16123 L
.34 .16123 L
.344 .16123 L
.348 .16123 L
.352 .16123 L
.356 .16123 L
.36 .16123 L
.364 .16123 L
.368 .16123 L
.372 .16123 L
.376 .16123 L
.38 .16123 L
.384 .16123 L
.388 .16123 L
.392 .16123 L
.396 .16123 L
.4 .16123 L
Mistroke
.404 .16123 L
.408 .16123 L
.412 .16123 L
.416 .16123 L
.42 .16123 L
.424 .16123 L
.428 .16123 L
.432 .16123 L
.436 .16123 L
.44 .16123 L
.444 .16123 L
.448 .16123 L
.452 .16123 L
.456 .16123 L
.46 .16123 L
.464 .16123 L
.468 .16123 L
.472 .16123 L
.476 .16123 L
.48 .16123 L
.484 .16123 L
.488 .16123 L
.492 .16123 L
.496 .16123 L
.5 .16123 L
.504 .16123 L
.508 .16123 L
.512 .16123 L
.516 .16123 L
.52 .16123 L
.524 .16123 L
.528 .16123 L
.532 .16123 L
.536 .16123 L
.54 .16123 L
.544 .16123 L
.548 .16123 L
.552 .16123 L
.556 .16123 L
.56 .16123 L
.564 .16123 L
.568 .16123 L
.572 .16123 L
.576 .16123 L
.58 .16123 L
.584 .16123 L
.588 .16123 L
.592 .16123 L
.596 .16123 L
.6 .16123 L
Mistroke
.604 .16123 L
.608 .16123 L
.612 .16123 L
.616 .16123 L
.62 .16123 L
.624 .16123 L
.628 .16123 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(668\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29927 m
.008 .30077 L
.012 .30241 L
.016 .30361 L
.02 .30438 L
.024 .30516 L
.028 .30589 L
.032 .30692 L
.036 .30844 L
.04 .30966 L
.044 .31018 L
.048 .31054 L
.052 .31148 L
.056 .31338 L
.06 .31538 L
.064 .31574 L
.068 .31489 L
.072 .31531 L
.076 .31762 L
.08 .3205 L
.084 .32247 L
.088 .32228 L
.092 .32061 L
.096 .31971 L
.1 .32077 L
.104 .32398 L
.108 .32837 L
.112 .33202 L
.116 .33385 L
.12 .33331 L
.124 .33071 L
.128 .32693 L
.132 .32274 L
.136 .31887 L
.14 .31568 L
.144 .31327 L
.148 .3116 L
.152 .31051 L
.156 .30984 L
.16 .30946 L
.164 .30924 L
.168 .30913 L
.172 .30907 L
.176 .30904 L
.18 .30903 L
.184 .30902 L
.188 .30902 L
.192 .30902 L
.196 .30902 L
.2 .30902 L
Mistroke
.204 .30902 L
.208 .30902 L
.212 .30902 L
.216 .30902 L
.22 .30902 L
.224 .30902 L
.228 .30902 L
.232 .30902 L
.236 .30902 L
.24 .30902 L
.244 .30902 L
.248 .30902 L
.252 .30902 L
.256 .30902 L
.26 .30902 L
.264 .30902 L
.268 .30902 L
.272 .30902 L
.276 .30902 L
.28 .30902 L
.284 .30902 L
.288 .30902 L
.292 .30902 L
.296 .30902 L
.3 .30902 L
.304 .30902 L
.308 .30902 L
.312 .30902 L
.316 .30902 L
.32 .30902 L
.324 .30902 L
.328 .30902 L
.332 .30902 L
.336 .30902 L
.34 .30902 L
.344 .30902 L
.348 .30902 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .48678 m
.008 .48313 L
.012 .47845 L
.016 .47262 L
.02 .46702 L
.024 .46171 L
.028 .45648 L
.032 .4512 L
.036 .44583 L
.04 .44034 L
.044 .43495 L
.048 .42969 L
.052 .4245 L
.056 .4192 L
.06 .41366 L
.064 .40802 L
.068 .40276 L
.072 .39784 L
.076 .39277 L
.08 .38728 L
.084 .38145 L
.088 .37561 L
.092 .3703 L
.096 .36558 L
.1 .36103 L
.104 .3562 L
.108 .35066 L
.112 .3444 L
.116 .33779 L
.12 .33128 L
.124 .32542 L
.128 .32051 L
.132 .31669 L
.136 .3139 L
.14 .31199 L
.144 .31075 L
.148 .30998 L
.152 .30954 L
.156 .30928 L
.16 .30915 L
.164 .30908 L
.168 .30905 L
.172 .30903 L
.176 .30902 L
.18 .30902 L
.184 .30902 L
.188 .30902 L
.192 .30902 L
.196 .30902 L
.2 .30902 L
Mistroke
.204 .30902 L
.208 .30902 L
.212 .30902 L
.216 .30902 L
.22 .30902 L
.224 .30902 L
.228 .30902 L
.232 .30902 L
.236 .30902 L
.24 .30902 L
.244 .30902 L
.248 .30902 L
.252 .30902 L
.256 .30902 L
.26 .30902 L
.264 .30902 L
.268 .30902 L
.272 .30902 L
.276 .30902 L
.28 .30902 L
.284 .30902 L
.288 .30902 L
.292 .30902 L
.296 .30902 L
.3 .30902 L
.304 .30902 L
.308 .30902 L
.312 .30902 L
.316 .30902 L
.32 .30902 L
.324 .30902 L
.328 .30902 L
.332 .30902 L
.336 .30902 L
.34 .30902 L
.344 .30902 L
.348 .30902 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3856 m
.008 .37669 L
.012 .37224 L
.016 .36628 L
.02 .35874 L
.024 .35181 L
.028 .34536 L
.032 .33881 L
.036 .33207 L
.04 .32528 L
.044 .31842 L
.048 .31184 L
.052 .30544 L
.056 .29879 L
.06 .29176 L
.064 .28483 L
.068 .27824 L
.072 .272 L
.076 .26574 L
.08 .2589 L
.084 .25153 L
.088 .24432 L
.092 .23768 L
.096 .23173 L
.1 .22612 L
.104 .22005 L
.108 .21314 L
.112 .20536 L
.116 .19708 L
.12 .189 L
.124 .18167 L
.128 .17555 L
.132 .17079 L
.136 .16731 L
.14 .16493 L
.144 .16338 L
.148 .16243 L
.152 .16187 L
.156 .16156 L
.16 .16139 L
.164 .16131 L
.168 .16126 L
.172 .16124 L
.176 .16123 L
.18 .16123 L
.184 .16123 L
.188 .16123 L
.192 .16123 L
.196 .16123 L
.2 .16123 L
Mistroke
.204 .16123 L
.208 .16123 L
.212 .16123 L
.216 .16123 L
.22 .16123 L
.224 .16123 L
.228 .16123 L
.232 .16123 L
.236 .16123 L
.24 .16123 L
.244 .16123 L
.248 .16123 L
.252 .16123 L
.256 .16123 L
.26 .16123 L
.264 .16123 L
.268 .16123 L
.272 .16123 L
.276 .16123 L
.28 .16123 L
.284 .16123 L
.288 .16123 L
.292 .16123 L
.296 .16123 L
.3 .16123 L
.304 .16123 L
.308 .16123 L
.312 .16123 L
.316 .16123 L
.32 .16123 L
.324 .16123 L
.328 .16123 L
.332 .16123 L
.336 .16123 L
.34 .16123 L
.344 .16123 L
.348 .16123 L
.352 .16123 L
.356 .16123 L
.36 .16123 L
.364 .16123 L
.368 .16123 L
.372 .16123 L
.376 .16123 L
.38 .16123 L
.384 .16123 L
.388 .16123 L
.392 .16123 L
.396 .16123 L
.4 .16123 L
Mistroke
.404 .16123 L
.408 .16123 L
.412 .16123 L
.416 .16123 L
.42 .16123 L
.424 .16123 L
.428 .16123 L
.432 .16123 L
.436 .16123 L
.44 .16123 L
.444 .16123 L
.448 .16123 L
.452 .16123 L
.456 .16123 L
.46 .16123 L
.464 .16123 L
.468 .16123 L
.472 .16123 L
.476 .16123 L
.48 .16123 L
.484 .16123 L
.488 .16123 L
.492 .16123 L
.496 .16123 L
.5 .16123 L
.504 .16123 L
.508 .16123 L
.512 .16123 L
.516 .16123 L
.52 .16123 L
.524 .16123 L
.528 .16123 L
.532 .16123 L
.536 .16123 L
.54 .16123 L
.544 .16123 L
.548 .16123 L
.552 .16123 L
.556 .16123 L
.56 .16123 L
.564 .16123 L
.568 .16123 L
.572 .16123 L
.576 .16123 L
.58 .16123 L
.584 .16123 L
.588 .16123 L
.592 .16123 L
.596 .16123 L
.6 .16123 L
Mistroke
.604 .16123 L
.608 .16123 L
.612 .16123 L
.616 .16123 L
.62 .16123 L
.624 .16123 L
.628 .16123 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(835\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29796 m
.008 .29959 L
.012 .3005 L
.016 .30155 L
.02 .30268 L
.024 .30355 L
.028 .30423 L
.032 .3052 L
.036 .30655 L
.04 .30777 L
.044 .30854 L
.048 .30904 L
.052 .30982 L
.056 .31148 L
.06 .31333 L
.064 .3138 L
.068 .31331 L
.072 .31408 L
.076 .31649 L
.08 .31876 L
.084 .31961 L
.088 .31894 L
.092 .31813 L
.096 .31929 L
.1 .32245 L
.104 .32562 L
.108 .32717 L
.112 .32641 L
.116 .32431 L
.12 .32309 L
.124 .32406 L
.128 .32743 L
.132 .3322 L
.136 .33658 L
.14 .33925 L
.144 .33943 L
.148 .33722 L
.152 .33334 L
.156 .32861 L
.16 .32388 L
.164 .31967 L
.168 .31627 L
.172 .31372 L
.176 .31193 L
.18 .31075 L
.184 .31001 L
.188 .30956 L
.192 .30931 L
.196 .30917 L
.2 .30909 L
Mistroke
.204 .30905 L
.208 .30903 L
.212 .30902 L
.216 .30902 L
.22 .30902 L
.224 .30902 L
.228 .30902 L
.232 .30902 L
.236 .30902 L
.24 .30902 L
.244 .30902 L
.248 .30902 L
.252 .30902 L
.256 .30902 L
.26 .30902 L
.264 .30902 L
.268 .30902 L
.272 .30902 L
.276 .30902 L
.28 .30902 L
.284 .30902 L
.288 .30902 L
.292 .30902 L
.296 .30902 L
.3 .30902 L
.304 .30902 L
.308 .30902 L
.312 .30902 L
.316 .30902 L
.32 .30902 L
.324 .30902 L
.328 .30902 L
.332 .30902 L
.336 .30902 L
.34 .30902 L
.344 .30902 L
.348 .30902 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .52726 m
.008 .51895 L
.012 .51269 L
.016 .50836 L
.02 .50333 L
.024 .49754 L
.028 .49212 L
.032 .48694 L
.036 .48165 L
.04 .47618 L
.044 .47078 L
.048 .46547 L
.052 .46023 L
.056 .45493 L
.06 .44947 L
.064 .44394 L
.068 .43866 L
.072 .4336 L
.076 .42837 L
.08 .42282 L
.084 .41718 L
.088 .41172 L
.092 .40665 L
.096 .40178 L
.1 .39662 L
.104 .39098 L
.108 .38508 L
.112 .37929 L
.116 .37404 L
.12 .36934 L
.124 .36483 L
.128 .36007 L
.132 .35467 L
.136 .34857 L
.14 .34201 L
.144 .33539 L
.148 .3292 L
.152 .32379 L
.156 .31938 L
.16 .31598 L
.164 .3135 L
.168 .3118 L
.172 .31067 L
.176 .30997 L
.18 .30955 L
.184 .3093 L
.188 .30916 L
.192 .30909 L
.196 .30905 L
.2 .30903 L
Mistroke
.204 .30902 L
.208 .30902 L
.212 .30902 L
.216 .30902 L
.22 .30902 L
.224 .30902 L
.228 .30902 L
.232 .30902 L
.236 .30902 L
.24 .30902 L
.244 .30902 L
.248 .30902 L
.252 .30902 L
.256 .30902 L
.26 .30902 L
.264 .30902 L
.268 .30902 L
.272 .30902 L
.276 .30902 L
.28 .30902 L
.284 .30902 L
.288 .30902 L
.292 .30902 L
.296 .30902 L
.3 .30902 L
.304 .30902 L
.308 .30902 L
.312 .30902 L
.316 .30902 L
.32 .30902 L
.324 .30902 L
.328 .30902 L
.332 .30902 L
.336 .30902 L
.34 .30902 L
.344 .30902 L
.348 .30902 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42236 L
.012 .41694 L
.016 .41082 L
.02 .4037 L
.024 .3968 L
.028 .39013 L
.032 .38356 L
.036 .37689 L
.04 .37013 L
.044 .36328 L
.048 .35664 L
.052 .35014 L
.056 .34349 L
.06 .33657 L
.064 .32974 L
.068 .32314 L
.072 .31673 L
.076 .31023 L
.08 .30334 L
.084 .2962 L
.088 .28941 L
.092 .2831 L
.096 .27696 L
.1 .27053 L
.104 .26352 L
.108 .25609 L
.112 .2489 L
.116 .24234 L
.12 .23644 L
.124 .23084 L
.128 .22489 L
.132 .21815 L
.136 .21055 L
.14 .20234 L
.144 .19411 L
.148 .18638 L
.152 .17965 L
.156 .17414 L
.16 .1699 L
.164 .16682 L
.168 .16469 L
.172 .16329 L
.176 .16241 L
.18 .16189 L
.184 .16158 L
.188 .16141 L
.192 .16132 L
.196 .16127 L
.2 .16125 L
Mistroke
.204 .16124 L
.208 .16123 L
.212 .16123 L
.216 .16123 L
.22 .16123 L
.224 .16123 L
.228 .16123 L
.232 .16123 L
.236 .16123 L
.24 .16123 L
.244 .16123 L
.248 .16123 L
.252 .16123 L
.256 .16123 L
.26 .16123 L
.264 .16123 L
.268 .16123 L
.272 .16123 L
.276 .16123 L
.28 .16123 L
.284 .16123 L
.288 .16123 L
.292 .16123 L
.296 .16123 L
.3 .16123 L
.304 .16123 L
.308 .16123 L
.312 .16123 L
.316 .16123 L
.32 .16123 L
.324 .16123 L
.328 .16123 L
.332 .16123 L
.336 .16123 L
.34 .16123 L
.344 .16123 L
.348 .16123 L
.352 .16123 L
.356 .16123 L
.36 .16123 L
.364 .16123 L
.368 .16123 L
.372 .16123 L
.376 .16123 L
.38 .16123 L
.384 .16123 L
.388 .16123 L
.392 .16123 L
.396 .16123 L
.4 .16123 L
Mistroke
.404 .16123 L
.408 .16123 L
.412 .16123 L
.416 .16123 L
.42 .16123 L
.424 .16123 L
.428 .16123 L
.432 .16123 L
.436 .16123 L
.44 .16123 L
.444 .16123 L
.448 .16123 L
.452 .16123 L
.456 .16123 L
.46 .16123 L
.464 .16123 L
.468 .16123 L
.472 .16123 L
.476 .16123 L
.48 .16123 L
.484 .16123 L
.488 .16123 L
.492 .16123 L
.496 .16123 L
.5 .16123 L
.504 .16123 L
.508 .16123 L
.512 .16123 L
.516 .16123 L
.52 .16123 L
.524 .16123 L
.528 .16123 L
.532 .16123 L
.536 .16123 L
.54 .16123 L
.544 .16123 L
.548 .16123 L
.552 .16123 L
.556 .16123 L
.56 .16123 L
.564 .16123 L
.568 .16123 L
.572 .16123 L
.576 .16123 L
.58 .16123 L
.584 .16123 L
.588 .16123 L
.592 .16123 L
.596 .16123 L
.6 .16123 L
Mistroke
.604 .16123 L
.608 .16123 L
.612 .16123 L
.616 .16123 L
.62 .16123 L
.624 .16123 L
.628 .16123 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(1002\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30075 m
.008 .29938 L
.012 .29792 L
.016 .29737 L
.02 .29784 L
.024 .29895 L
.028 .3005 L
.032 .30219 L
.036 .30409 L
.04 .30571 L
.044 .30682 L
.048 .30745 L
.052 .30811 L
.056 .30958 L
.06 .31138 L
.064 .31203 L
.068 .3118 L
.072 .31262 L
.076 .31482 L
.08 .31674 L
.084 .31729 L
.088 .31683 L
.092 .31681 L
.096 .31867 L
.1 .32174 L
.104 .32361 L
.108 .32336 L
.112 .32208 L
.116 .32161 L
.12 .32348 L
.124 .3272 L
.128 .33055 L
.132 .33188 L
.136 .33072 L
.14 .32824 L
.144 .3266 L
.148 .32724 L
.152 .33054 L
.156 .33558 L
.16 .34066 L
.164 .34428 L
.168 .34542 L
.172 .34392 L
.176 .34027 L
.18 .33529 L
.184 .32987 L
.188 .32471 L
.192 .32027 L
.196 .31672 L
.2 .31407 L
Mistroke
.204 .31221 L
.208 .31095 L
.212 .31015 L
.216 .30966 L
.22 .30937 L
.224 .3092 L
.228 .30911 L
.232 .30907 L
.236 .30904 L
.24 .30903 L
.244 .30902 L
.248 .30902 L
.252 .30902 L
.256 .30902 L
.26 .30902 L
.264 .30902 L
.268 .30902 L
.272 .30902 L
.276 .30902 L
.28 .30902 L
.284 .30902 L
.288 .30902 L
.292 .30902 L
.296 .30902 L
.3 .30902 L
.304 .30902 L
.308 .30902 L
.312 .30902 L
.316 .30902 L
.32 .30902 L
.324 .30902 L
.328 .30902 L
.332 .30902 L
.336 .30902 L
.34 .30902 L
.344 .30902 L
.348 .30902 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .52627 m
.008 .52371 L
.012 .52288 L
.016 .52363 L
.02 .52454 L
.024 .52508 L
.028 .52383 L
.032 .52077 L
.036 .51671 L
.04 .51171 L
.044 .50651 L
.048 .50119 L
.052 .49594 L
.056 .49065 L
.06 .48525 L
.064 .47976 L
.068 .47446 L
.072 .4693 L
.076 .46403 L
.08 .45852 L
.084 .453 L
.088 .44764 L
.092 .44254 L
.096 .43746 L
.1 .43208 L
.104 .42639 L
.108 .42077 L
.112 .41548 L
.116 .41053 L
.12 .40565 L
.124 .40041 L
.128 .3947 L
.132 .38877 L
.136 .383 L
.14 .37774 L
.144 .37303 L
.148 .36854 L
.152 .36388 L
.156 .35865 L
.16 .35273 L
.164 .34628 L
.168 .33962 L
.172 .33319 L
.176 .32737 L
.18 .32241 L
.184 .31842 L
.188 .31537 L
.192 .31316 L
.196 .31162 L
.2 .3106 L
Mistroke
.204 .30995 L
.208 .30955 L
.212 .30931 L
.216 .30917 L
.22 .3091 L
.224 .30906 L
.228 .30904 L
.232 .30903 L
.236 .30902 L
.24 .30902 L
.244 .30902 L
.248 .30902 L
.252 .30902 L
.256 .30902 L
.26 .30902 L
.264 .30902 L
.268 .30902 L
.272 .30902 L
.276 .30902 L
.28 .30902 L
.284 .30902 L
.288 .30902 L
.292 .30902 L
.296 .30902 L
.3 .30902 L
.304 .30902 L
.308 .30902 L
.312 .30902 L
.316 .30902 L
.32 .30902 L
.324 .30902 L
.328 .30902 L
.332 .30902 L
.336 .30902 L
.34 .30902 L
.344 .30902 L
.348 .30902 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43412 L
.012 .42931 L
.016 .42838 L
.02 .43108 L
.024 .43165 L
.028 .42972 L
.032 .42607 L
.036 .42077 L
.04 .41472 L
.044 .40803 L
.048 .40142 L
.052 .39486 L
.056 .38822 L
.06 .38138 L
.064 .37459 L
.068 .36793 L
.072 .36143 L
.076 .35484 L
.08 .348 L
.084 .34102 L
.088 .33434 L
.092 .32798 L
.096 .32159 L
.1 .31485 L
.104 .30778 L
.108 .30071 L
.112 .2941 L
.116 .28795 L
.12 .28181 L
.124 .27527 L
.128 .26815 L
.132 .26071 L
.136 .25353 L
.14 .24696 L
.144 .24106 L
.148 .23548 L
.152 .22964 L
.156 .22312 L
.16 .21574 L
.164 .20767 L
.168 .19938 L
.172 .19136 L
.176 .1841 L
.18 .17792 L
.184 .17294 L
.188 .16915 L
.192 .16638 L
.196 .16447 L
.2 .1632 L
Mistroke
.204 .16239 L
.208 .16189 L
.212 .16159 L
.216 .16142 L
.22 .16133 L
.224 .16128 L
.228 .16125 L
.232 .16124 L
.236 .16123 L
.24 .16123 L
.244 .16123 L
.248 .16123 L
.252 .16123 L
.256 .16123 L
.26 .16123 L
.264 .16123 L
.268 .16123 L
.272 .16123 L
.276 .16123 L
.28 .16123 L
.284 .16123 L
.288 .16123 L
.292 .16123 L
.296 .16123 L
.3 .16123 L
.304 .16123 L
.308 .16123 L
.312 .16123 L
.316 .16123 L
.32 .16123 L
.324 .16123 L
.328 .16123 L
.332 .16123 L
.336 .16123 L
.34 .16123 L
.344 .16123 L
.348 .16123 L
.352 .16123 L
.356 .16123 L
.36 .16123 L
.364 .16123 L
.368 .16123 L
.372 .16123 L
.376 .16123 L
.38 .16123 L
.384 .16123 L
.388 .16123 L
.392 .16123 L
.396 .16123 L
.4 .16123 L
Mistroke
.404 .16123 L
.408 .16123 L
.412 .16123 L
.416 .16123 L
.42 .16123 L
.424 .16123 L
.428 .16123 L
.432 .16123 L
.436 .16123 L
.44 .16123 L
.444 .16123 L
.448 .16123 L
.452 .16123 L
.456 .16123 L
.46 .16123 L
.464 .16123 L
.468 .16123 L
.472 .16123 L
.476 .16123 L
.48 .16123 L
.484 .16123 L
.488 .16123 L
.492 .16123 L
.496 .16123 L
.5 .16123 L
.504 .16123 L
.508 .16123 L
.512 .16123 L
.516 .16123 L
.52 .16123 L
.524 .16123 L
.528 .16123 L
.532 .16123 L
.536 .16123 L
.54 .16123 L
.544 .16123 L
.548 .16123 L
.552 .16123 L
.556 .16123 L
.56 .16123 L
.564 .16123 L
.568 .16123 L
.572 .16123 L
.576 .16123 L
.58 .16123 L
.584 .16123 L
.588 .16123 L
.592 .16123 L
.596 .16123 L
.6 .16123 L
Mistroke
.604 .16123 L
.608 .16123 L
.612 .16123 L
.616 .16123 L
.62 .16123 L
.624 .16123 L
.628 .16123 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(1169\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29938 m
.008 .29823 L
.012 .29872 L
.016 .29855 L
.02 .29792 L
.024 .29851 L
.028 .29988 L
.032 .29944 L
.036 .29752 L
.04 .29662 L
.044 .29695 L
.048 .29829 L
.052 .30066 L
.056 .30382 L
.06 .30718 L
.064 .30908 L
.068 .30968 L
.072 .31078 L
.076 .31287 L
.08 .31469 L
.084 .31531 L
.088 .31513 L
.092 .31547 L
.096 .31741 L
.1 .32004 L
.104 .32121 L
.108 .32057 L
.112 .31991 L
.116 .32088 L
.12 .3237 L
.124 .32682 L
.128 .32802 L
.132 .32696 L
.136 .32535 L
.14 .32522 L
.144 .32766 L
.148 .33179 L
.152 .33536 L
.156 .33664 L
.16 .33526 L
.164 .33243 L
.168 .33027 L
.172 .3304 L
.176 .33339 L
.18 .33852 L
.184 .34421 L
.188 .34881 L
.192 .35108 L
.196 .35057 L
.2 .3475 L
Mistroke
.204 .34259 L
.208 .33674 L
.212 .33078 L
.216 .32533 L
.22 .32071 L
.224 .31707 L
.228 .31436 L
.232 .31243 L
.236 .31113 L
.24 .31028 L
.244 .30975 L
.248 .30943 L
.252 .30924 L
.256 .30914 L
.26 .30908 L
.264 .30905 L
.268 .30903 L
.272 .30902 L
.276 .30902 L
.28 .30902 L
.284 .30902 L
.288 .30902 L
.292 .30902 L
.296 .30902 L
.3 .30902 L
.304 .30902 L
.308 .30902 L
.312 .30902 L
.316 .30902 L
.32 .30902 L
.324 .30902 L
.328 .30902 L
.332 .30902 L
.336 .30902 L
.34 .30902 L
.344 .30902 L
.348 .30902 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51756 m
.008 .52351 L
.012 .52548 L
.016 .52334 L
.02 .52286 L
.024 .52378 L
.028 .52374 L
.032 .52276 L
.036 .52278 L
.04 .52378 L
.044 .52481 L
.048 .52539 L
.052 .52468 L
.056 .52249 L
.06 .51906 L
.064 .51459 L
.068 .5098 L
.072 .50481 L
.076 .49963 L
.08 .49421 L
.084 .48876 L
.088 .48343 L
.092 .47827 L
.096 .47307 L
.1 .46766 L
.104 .46206 L
.108 .45661 L
.112 .45144 L
.116 .44641 L
.12 .44122 L
.124 .4357 L
.128 .42997 L
.132 .42442 L
.136 .41925 L
.14 .41438 L
.144 .40947 L
.148 .40419 L
.152 .39845 L
.156 .3925 L
.16 .38672 L
.164 .38143 L
.168 .37667 L
.172 .37219 L
.176 .36762 L
.18 .36257 L
.184 .35686 L
.188 .35056 L
.192 .34393 L
.196 .33735 L
.2 .33119 L
Mistroke
.204 .32576 L
.208 .32121 L
.212 .31759 L
.216 .31484 L
.22 .31285 L
.224 .31145 L
.228 .31052 L
.232 .30992 L
.236 .30954 L
.24 .30931 L
.244 .30918 L
.248 .3091 L
.252 .30906 L
.256 .30904 L
.26 .30903 L
.264 .30902 L
.268 .30902 L
.272 .30902 L
.276 .30902 L
.28 .30902 L
.284 .30902 L
.288 .30902 L
.292 .30902 L
.296 .30902 L
.3 .30902 L
.304 .30902 L
.308 .30902 L
.312 .30902 L
.316 .30902 L
.32 .30902 L
.324 .30902 L
.328 .30902 L
.332 .30902 L
.336 .30902 L
.34 .30902 L
.344 .30902 L
.348 .30902 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43196 L
.012 .42989 L
.016 .42917 L
.02 .42995 L
.024 .43024 L
.028 .42954 L
.032 .42896 L
.036 .42885 L
.04 .42978 L
.044 .43129 L
.048 .43183 L
.052 .43093 L
.056 .42822 L
.06 .42375 L
.064 .4183 L
.068 .41221 L
.072 .40594 L
.076 .39944 L
.08 .3927 L
.084 .38582 L
.088 .37915 L
.092 .37271 L
.096 .36619 L
.1 .35938 L
.104 .35241 L
.108 .34557 L
.112 .33909 L
.116 .33281 L
.12 .32631 L
.124 .31939 L
.128 .31225 L
.132 .30529 L
.136 .29882 L
.14 .29274 L
.144 .2866 L
.148 .27999 L
.152 .27283 L
.156 .26538 L
.16 .25817 L
.164 .25156 L
.168 .24561 L
.172 .24003 L
.176 .23431 L
.18 .22801 L
.184 .22089 L
.188 .21302 L
.192 .20476 L
.196 .19655 L
.2 .18887 L
Mistroke
.204 .18209 L
.208 .17642 L
.212 .17191 L
.216 .16849 L
.22 .166 L
.224 .16426 L
.228 .1631 L
.232 .16235 L
.236 .16188 L
.24 .1616 L
.244 .16143 L
.248 .16134 L
.252 .16128 L
.256 .16126 L
.26 .16124 L
.264 .16123 L
.268 .16123 L
.272 .16123 L
.276 .16123 L
.28 .16123 L
.284 .16123 L
.288 .16123 L
.292 .16123 L
.296 .16123 L
.3 .16123 L
.304 .16123 L
.308 .16123 L
.312 .16123 L
.316 .16123 L
.32 .16123 L
.324 .16123 L
.328 .16123 L
.332 .16123 L
.336 .16123 L
.34 .16123 L
.344 .16123 L
.348 .16123 L
.352 .16123 L
.356 .16123 L
.36 .16123 L
.364 .16123 L
.368 .16123 L
.372 .16123 L
.376 .16123 L
.38 .16123 L
.384 .16123 L
.388 .16123 L
.392 .16123 L
.396 .16123 L
.4 .16123 L
Mistroke
.404 .16123 L
.408 .16123 L
.412 .16123 L
.416 .16123 L
.42 .16123 L
.424 .16123 L
.428 .16123 L
.432 .16123 L
.436 .16123 L
.44 .16123 L
.444 .16123 L
.448 .16123 L
.452 .16123 L
.456 .16123 L
.46 .16123 L
.464 .16123 L
.468 .16123 L
.472 .16123 L
.476 .16123 L
.48 .16123 L
.484 .16123 L
.488 .16123 L
.492 .16123 L
.496 .16123 L
.5 .16123 L
.504 .16123 L
.508 .16123 L
.512 .16123 L
.516 .16123 L
.52 .16123 L
.524 .16123 L
.528 .16123 L
.532 .16123 L
.536 .16123 L
.54 .16123 L
.544 .16123 L
.548 .16123 L
.552 .16123 L
.556 .16123 L
.56 .16123 L
.564 .16123 L
.568 .16123 L
.572 .16123 L
.576 .16123 L
.58 .16123 L
.584 .16123 L
.588 .16123 L
.592 .16123 L
.596 .16123 L
.6 .16123 L
Mistroke
.604 .16123 L
.608 .16123 L
.612 .16123 L
.616 .16123 L
.62 .16123 L
.624 .16123 L
.628 .16123 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(1336\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29634 m
.008 .29757 L
.012 .29974 L
.016 .29979 L
.02 .29778 L
.024 .29777 L
.028 .29962 L
.032 .29954 L
.036 .29763 L
.04 .29727 L
.044 .29875 L
.048 .29993 L
.052 .30009 L
.056 .2991 L
.06 .29737 L
.064 .29581 L
.068 .29504 L
.072 .29667 L
.076 .3007 L
.08 .30507 L
.084 .30838 L
.088 .31038 L
.092 .31219 L
.096 .31485 L
.1 .31764 L
.104 .31882 L
.108 .31839 L
.112 .31833 L
.116 .31994 L
.12 .3227 L
.124 .32486 L
.128 .32495 L
.132 .32368 L
.136 .32338 L
.14 .32533 L
.144 .32878 L
.148 .3317 L
.152 .33223 L
.156 .33057 L
.16 .32876 L
.164 .32887 L
.168 .33171 L
.172 .3362 L
.176 .34005 L
.18 .34146 L
.184 .34003 L
.188 .3369 L
.192 .33417 L
.196 .33362 L
.2 .33607 L
Mistroke
.204 .34108 L
.208 .3472 L
.212 .35274 L
.216 .35624 L
.22 .35693 L
.224 .35477 L
.228 .35028 L
.232 .34433 L
.236 .33779 L
.24 .33143 L
.244 .32575 L
.248 .32103 L
.252 .31733 L
.256 .31457 L
.26 .31261 L
.264 .31127 L
.268 .31039 L
.272 .30983 L
.276 .30948 L
.28 .30928 L
.284 .30916 L
.288 .30909 L
.292 .30906 L
.296 .30904 L
.3 .30903 L
.304 .30902 L
.308 .30902 L
.312 .30902 L
.316 .30902 L
.32 .30902 L
.324 .30902 L
.328 .30902 L
.332 .30902 L
.336 .30902 L
.34 .30902 L
.344 .30902 L
.348 .30902 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51965 m
.008 .52309 L
.012 .52434 L
.016 .52329 L
.02 .5229 L
.024 .52329 L
.028 .5234 L
.032 .52297 L
.036 .52298 L
.04 .52346 L
.044 .52371 L
.048 .52343 L
.052 .52287 L
.056 .5223 L
.06 .5225 L
.064 .52346 L
.068 .52465 L
.072 .52556 L
.076 .52535 L
.08 .52374 L
.084 .52093 L
.088 .5172 L
.092 .51294 L
.096 .5082 L
.1 .50306 L
.104 .49766 L
.108 .49234 L
.112 .48719 L
.116 .48206 L
.12 .47674 L
.124 .4712 L
.128 .46563 L
.132 .46031 L
.136 .45526 L
.14 .45022 L
.144 .44493 L
.148 .43931 L
.152 .43359 L
.156 .4281 L
.16 .42301 L
.164 .41817 L
.168 .41326 L
.172 .40796 L
.176 .40222 L
.18 .39627 L
.184 .39046 L
.188 .3851 L
.192 .38028 L
.196 .37579 L
.2 .37129 L
Mistroke
.204 .36641 L
.208 .36093 L
.212 .35482 L
.216 .34829 L
.22 .34164 L
.224 .33523 L
.228 .32939 L
.232 .32434 L
.236 .32016 L
.24 .31687 L
.244 .31438 L
.248 .31257 L
.252 .3113 L
.256 .31044 L
.26 .30989 L
.264 .30953 L
.268 .30931 L
.272 .30918 L
.276 .30911 L
.28 .30907 L
.284 .30904 L
.288 .30903 L
.292 .30902 L
.296 .30902 L
.3 .30902 L
.304 .30902 L
.308 .30902 L
.312 .30902 L
.316 .30902 L
.32 .30902 L
.324 .30902 L
.328 .30902 L
.332 .30902 L
.336 .30902 L
.34 .30902 L
.344 .30902 L
.348 .30902 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42576 L
.012 .42989 L
.016 .43125 L
.02 .42981 L
.024 .42938 L
.028 .42965 L
.032 .42961 L
.036 .42937 L
.04 .42967 L
.044 .43013 L
.048 .42986 L
.052 .42885 L
.056 .42828 L
.06 .42845 L
.064 .42952 L
.068 .43109 L
.072 .43206 L
.076 .43179 L
.08 .4298 L
.084 .42616 L
.088 .42153 L
.092 .41616 L
.096 .41023 L
.1 .40374 L
.104 .39701 L
.108 .39032 L
.112 .38386 L
.116 .37745 L
.12 .37079 L
.124 .36382 L
.128 .35687 L
.132 .3502 L
.136 .34387 L
.14 .33757 L
.144 .33095 L
.148 .32391 L
.152 .31677 L
.156 .3099 L
.16 .30353 L
.164 .29748 L
.168 .29133 L
.172 .28471 L
.176 .27754 L
.18 .27009 L
.184 .26284 L
.188 .25615 L
.192 .25012 L
.196 .24452 L
.2 .23889 L
Mistroke
.204 .2328 L
.208 .22596 L
.212 .21834 L
.216 .21019 L
.22 .20189 L
.224 .19391 L
.228 .18663 L
.232 .18032 L
.236 .17512 L
.24 .17101 L
.244 .16791 L
.248 .16565 L
.252 .16407 L
.256 .163 L
.26 .16231 L
.264 .16187 L
.268 .1616 L
.272 .16143 L
.276 .16134 L
.28 .16129 L
.284 .16126 L
.288 .16124 L
.292 .16123 L
.296 .16123 L
.3 .16123 L
.304 .16123 L
.308 .16123 L
.312 .16123 L
.316 .16123 L
.32 .16123 L
.324 .16123 L
.328 .16123 L
.332 .16123 L
.336 .16123 L
.34 .16123 L
.344 .16123 L
.348 .16123 L
.352 .16123 L
.356 .16123 L
.36 .16123 L
.364 .16123 L
.368 .16123 L
.372 .16123 L
.376 .16123 L
.38 .16123 L
.384 .16123 L
.388 .16123 L
.392 .16123 L
.396 .16123 L
.4 .16123 L
Mistroke
.404 .16123 L
.408 .16123 L
.412 .16123 L
.416 .16123 L
.42 .16123 L
.424 .16123 L
.428 .16123 L
.432 .16123 L
.436 .16123 L
.44 .16123 L
.444 .16123 L
.448 .16123 L
.452 .16123 L
.456 .16123 L
.46 .16123 L
.464 .16123 L
.468 .16123 L
.472 .16123 L
.476 .16123 L
.48 .16123 L
.484 .16123 L
.488 .16123 L
.492 .16123 L
.496 .16123 L
.5 .16123 L
.504 .16123 L
.508 .16123 L
.512 .16123 L
.516 .16123 L
.52 .16123 L
.524 .16123 L
.528 .16123 L
.532 .16123 L
.536 .16123 L
.54 .16123 L
.544 .16123 L
.548 .16123 L
.552 .16123 L
.556 .16123 L
.56 .16123 L
.564 .16123 L
.568 .16123 L
.572 .16123 L
.576 .16123 L
.58 .16123 L
.584 .16123 L
.588 .16123 L
.592 .16123 L
.596 .16123 L
.6 .16123 L
Mistroke
.604 .16123 L
.608 .16123 L
.612 .16123 L
.616 .16123 L
.62 .16123 L
.624 .16123 L
.628 .16123 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(1503\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29715 m
.008 .29869 L
.012 .29934 L
.016 .29921 L
.02 .29817 L
.024 .29812 L
.028 .29928 L
.032 .29934 L
.036 .29802 L
.04 .2977 L
.044 .29888 L
.048 .2997 L
.052 .29932 L
.056 .29815 L
.06 .29715 L
.064 .29753 L
.068 .299 L
.072 .30038 L
.076 .30106 L
.08 .29992 L
.084 .29693 L
.088 .29405 L
.092 .29315 L
.096 .2956 L
.1 .30027 L
.104 .30452 L
.108 .30764 L
.112 .31078 L
.116 .31477 L
.12 .31881 L
.124 .32137 L
.128 .32176 L
.132 .32125 L
.136 .32212 L
.14 .32487 L
.144 .32785 L
.148 .32917 L
.152 .32833 L
.156 .32688 L
.16 .32717 L
.164 .32993 L
.168 .33375 L
.172 .3364 L
.176 .33638 L
.18 .33427 L
.184 .33229 L
.188 .33251 L
.192 .3356 L
.196 .34041 L
.2 .34461 L
Mistroke
.204 .34633 L
.208 .34501 L
.212 .34168 L
.216 .33837 L
.22 .33701 L
.224 .33872 L
.228 .34335 L
.232 .34967 L
.236 .35602 L
.24 .36075 L
.244 .36281 L
.248 .36184 L
.252 .35813 L
.256 .35241 L
.26 .34558 L
.264 .3385 L
.268 .33184 L
.272 .32602 L
.276 .32124 L
.28 .31751 L
.284 .31473 L
.288 .31275 L
.292 .31138 L
.296 .31048 L
.3 .30989 L
.304 .30953 L
.308 .30931 L
.312 .30918 L
.316 .30911 L
.32 .30906 L
.324 .30904 L
.328 .30903 L
.332 .30902 L
.336 .30902 L
.34 .30902 L
.344 .30902 L
.348 .30902 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .52835 m
.008 .52289 L
.012 .52115 L
.016 .52301 L
.02 .52362 L
.024 .52303 L
.028 .52283 L
.032 .52285 L
.036 .52294 L
.04 .5231 L
.044 .52319 L
.048 .52301 L
.052 .52276 L
.056 .52264 L
.06 .52295 L
.064 .52345 L
.068 .52357 L
.072 .52313 L
.076 .52245 L
.08 .52187 L
.084 .52203 L
.088 .52301 L
.092 .52435 L
.096 .52547 L
.1 .52562 L
.104 .52458 L
.108 .5225 L
.112 .51953 L
.116 .51578 L
.12 .51127 L
.124 .50627 L
.128 .50106 L
.132 .49596 L
.136 .49093 L
.14 .48576 L
.144 .48033 L
.148 .47474 L
.152 .46924 L
.156 .46404 L
.16 .45905 L
.164 .45398 L
.168 .4486 L
.172 .44294 L
.176 .43723 L
.18 .43179 L
.184 .42675 L
.188 .42193 L
.192 .41702 L
.196 .41174 L
.2 .40601 L
Mistroke
.204 .40006 L
.208 .39421 L
.212 .38878 L
.216 .38386 L
.22 .37933 L
.224 .37489 L
.228 .37016 L
.232 .36491 L
.236 .35903 L
.24 .35265 L
.244 .34601 L
.248 .33944 L
.252 .33328 L
.256 .32777 L
.26 .32307 L
.264 .31923 L
.268 .31623 L
.272 .31396 L
.276 .31231 L
.28 .31116 L
.284 .31037 L
.288 .30985 L
.292 .30952 L
.296 .30931 L
.3 .30919 L
.304 .30911 L
.308 .30907 L
.312 .30904 L
.316 .30903 L
.32 .30902 L
.324 .30902 L
.328 .30902 L
.332 .30902 L
.336 .30902 L
.34 .30902 L
.344 .30902 L
.348 .30902 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42703 L
.012 .42964 L
.016 .43074 L
.02 .42993 L
.024 .42952 L
.028 .42962 L
.032 .42967 L
.036 .42949 L
.04 .42959 L
.044 .42979 L
.048 .42962 L
.052 .42905 L
.056 .42893 L
.06 .42935 L
.064 .42984 L
.068 .42996 L
.072 .42943 L
.076 .42842 L
.08 .42777 L
.084 .42788 L
.088 .42901 L
.092 .43073 L
.096 .43201 L
.1 .43215 L
.104 .43085 L
.108 .42818 L
.112 .42445 L
.116 .41972 L
.12 .41408 L
.124 .40777 L
.128 .40127 L
.132 .39487 L
.136 .38855 L
.14 .38208 L
.144 .37528 L
.148 .36826 L
.152 .36139 L
.156 .35488 L
.16 .34862 L
.164 .34228 L
.168 .33555 L
.172 .32845 L
.176 .32131 L
.18 .31451 L
.184 .3082 L
.188 .30218 L
.192 .29604 L
.196 .28943 L
.2 .28228 L
Mistroke
.204 .27484 L
.208 .26753 L
.212 .26074 L
.216 .2546 L
.22 .24895 L
.224 .24339 L
.228 .23749 L
.232 .23093 L
.236 .22359 L
.24 .21563 L
.244 .20734 L
.248 .19916 L
.252 .19147 L
.256 .1846 L
.26 .17874 L
.264 .17396 L
.268 .17021 L
.272 .16739 L
.276 .16533 L
.28 .16389 L
.284 .16291 L
.288 .16226 L
.292 .16185 L
.296 .16159 L
.3 .16144 L
.304 .16134 L
.308 .16129 L
.312 .16126 L
.316 .16124 L
.32 .16124 L
.324 .16123 L
.328 .16123 L
.332 .16123 L
.336 .16123 L
.34 .16123 L
.344 .16123 L
.348 .16123 L
.352 .16123 L
.356 .16123 L
.36 .16123 L
.364 .16123 L
.368 .16123 L
.372 .16123 L
.376 .16123 L
.38 .16123 L
.384 .16123 L
.388 .16123 L
.392 .16123 L
.396 .16123 L
.4 .16123 L
Mistroke
.404 .16123 L
.408 .16123 L
.412 .16123 L
.416 .16123 L
.42 .16123 L
.424 .16123 L
.428 .16123 L
.432 .16123 L
.436 .16123 L
.44 .16123 L
.444 .16123 L
.448 .16123 L
.452 .16123 L
.456 .16123 L
.46 .16123 L
.464 .16123 L
.468 .16123 L
.472 .16123 L
.476 .16123 L
.48 .16123 L
.484 .16123 L
.488 .16123 L
.492 .16123 L
.496 .16123 L
.5 .16123 L
.504 .16123 L
.508 .16123 L
.512 .16123 L
.516 .16123 L
.52 .16123 L
.524 .16123 L
.528 .16123 L
.532 .16123 L
.536 .16123 L
.54 .16123 L
.544 .16123 L
.548 .16123 L
.552 .16123 L
.556 .16123 L
.56 .16123 L
.564 .16123 L
.568 .16123 L
.572 .16123 L
.576 .16123 L
.58 .16123 L
.584 .16123 L
.588 .16123 L
.592 .16123 L
.596 .16123 L
.6 .16123 L
Mistroke
.604 .16123 L
.608 .16123 L
.612 .16123 L
.616 .16123 L
.62 .16123 L
.624 .16123 L
.628 .16123 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(1670\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30041 m
.008 .29968 L
.012 .29833 L
.016 .29799 L
.02 .2986 L
.024 .29891 L
.028 .29905 L
.032 .29894 L
.036 .29832 L
.04 .29811 L
.044 .29877 L
.048 .29938 L
.052 .29917 L
.056 .29821 L
.06 .29752 L
.064 .29824 L
.068 .2997 L
.072 .30001 L
.076 .299 L
.08 .29762 L
.084 .29661 L
.088 .29704 L
.092 .2991 L
.096 .30155 L
.1 .30262 L
.104 .30049 L
.108 .29601 L
.112 .29258 L
.116 .29224 L
.12 .29481 L
.124 .29856 L
.128 .3021 L
.132 .30588 L
.136 .31097 L
.14 .31692 L
.144 .32165 L
.148 .32378 L
.152 .32393 L
.156 .32418 L
.16 .3263 L
.164 .32985 L
.168 .33265 L
.172 .3331 L
.176 .33161 L
.18 .33025 L
.184 .33114 L
.188 .33453 L
.192 .33859 L
.196 .34102 L
.2 .34058 L
Mistroke
.204 .3381 L
.208 .33591 L
.212 .3361 L
.216 .33932 L
.22 .34439 L
.224 .34901 L
.228 .35119 L
.232 .35016 L
.236 .34675 L
.24 .34291 L
.244 .34068 L
.248 .34146 L
.252 .34545 L
.256 .3517 L
.26 .35864 L
.264 .36453 L
.268 .36804 L
.272 .36849 L
.276 .36588 L
.28 .36076 L
.284 .35398 L
.288 .34645 L
.292 .33895 L
.296 .33208 L
.3 .32617 L
.304 .32136 L
.308 .31763 L
.312 .31485 L
.316 .31285 L
.32 .31147 L
.324 .31055 L
.328 .30995 L
.332 .30957 L
.336 .30934 L
.34 .3092 L
.344 .30912 L
.348 .30907 L
.352 .30905 L
.356 .30903 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .52741 m
.008 .52286 L
.012 .52129 L
.016 .52257 L
.02 .52321 L
.024 .52286 L
.028 .52265 L
.032 .52262 L
.036 .52272 L
.04 .52281 L
.044 .52287 L
.048 .52275 L
.052 .52263 L
.056 .52257 L
.06 .52277 L
.064 .52303 L
.068 .52297 L
.072 .52258 L
.076 .52234 L
.08 .52243 L
.084 .52286 L
.088 .52336 L
.092 .52343 L
.096 .52291 L
.1 .5221 L
.104 .52144 L
.108 .52157 L
.112 .52255 L
.116 .52391 L
.12 .52508 L
.124 .52554 L
.128 .52512 L
.132 .5238 L
.136 .5215 L
.14 .5182 L
.144 .51401 L
.148 .50929 L
.152 .50441 L
.156 .49954 L
.16 .49458 L
.164 .48937 L
.168 .48387 L
.172 .47829 L
.176 .47289 L
.18 .46778 L
.184 .46281 L
.188 .4577 L
.192 .45227 L
.196 .44657 L
.2 .44088 L
Mistroke
.204 .43547 L
.208 .43045 L
.212 .42565 L
.216 .42076 L
.22 .41551 L
.224 .40982 L
.228 .40388 L
.232 .39799 L
.236 .39246 L
.24 .38744 L
.244 .38285 L
.248 .37843 L
.252 .37384 L
.256 .3688 L
.26 .36316 L
.264 .35697 L
.268 .35041 L
.272 .34377 L
.276 .33737 L
.28 .33148 L
.284 .3263 L
.288 .32194 L
.292 .31841 L
.296 .31566 L
.3 .31359 L
.304 .31208 L
.308 .31102 L
.312 .3103 L
.316 .30981 L
.32 .3095 L
.324 .30931 L
.328 .30919 L
.332 .30911 L
.336 .30907 L
.34 .30905 L
.344 .30903 L
.348 .30903 L
.352 .30902 L
.356 .30902 L
.36 .30902 L
.364 .30902 L
.368 .30902 L
.372 .30902 L
.376 .30902 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43353 L
.012 .4297 L
.016 .42859 L
.02 .42986 L
.024 .43021 L
.028 .42967 L
.032 .42948 L
.036 .42951 L
.04 .42962 L
.044 .42968 L
.048 .42956 L
.052 .42919 L
.056 .42915 L
.06 .42942 L
.064 .42963 L
.068 .42947 L
.072 .42905 L
.076 .42862 L
.08 .4287 L
.084 .42924 L
.088 .42976 L
.092 .42982 L
.096 .42918 L
.1 .42803 L
.104 .42724 L
.108 .42734 L
.112 .42848 L
.116 .43018 L
.12 .43156 L
.124 .43209 L
.128 .43154 L
.132 .42984 L
.136 .42693 L
.14 .42276 L
.144 .41752 L
.148 .41158 L
.152 .40546 L
.156 .39935 L
.16 .39314 L
.164 .3866 L
.168 .37972 L
.172 .37272 L
.176 .36596 L
.18 .35956 L
.184 .35333 L
.188 .34694 L
.192 .34013 L
.196 .333 L
.2 .32588 L
Mistroke
.204 .31912 L
.208 .31283 L
.212 .30683 L
.216 .30071 L
.22 .29414 L
.224 .28704 L
.228 .27961 L
.232 .27225 L
.236 .26535 L
.24 .25907 L
.244 .25334 L
.248 .24781 L
.252 .24207 L
.256 .23578 L
.26 .22875 L
.264 .22102 L
.268 .21284 L
.272 .20456 L
.276 .19657 L
.28 .18923 L
.284 .18277 L
.288 .17733 L
.292 .17293 L
.296 .1695 L
.3 .16692 L
.304 .16505 L
.308 .16372 L
.312 .16282 L
.316 .16222 L
.32 .16183 L
.324 .16159 L
.328 .16144 L
.332 .16135 L
.336 .16129 L
.34 .16126 L
.344 .16125 L
.348 .16124 L
.352 .16123 L
.356 .16123 L
.36 .16123 L
.364 .16123 L
.368 .16123 L
.372 .16123 L
.376 .16123 L
.38 .16123 L
.384 .16123 L
.388 .16123 L
.392 .16123 L
.396 .16123 L
.4 .16123 L
Mistroke
.404 .16123 L
.408 .16123 L
.412 .16123 L
.416 .16123 L
.42 .16123 L
.424 .16123 L
.428 .16123 L
.432 .16123 L
.436 .16123 L
.44 .16123 L
.444 .16123 L
.448 .16123 L
.452 .16123 L
.456 .16123 L
.46 .16123 L
.464 .16123 L
.468 .16123 L
.472 .16123 L
.476 .16123 L
.48 .16123 L
.484 .16123 L
.488 .16123 L
.492 .16123 L
.496 .16123 L
.5 .16123 L
.504 .16123 L
.508 .16123 L
.512 .16123 L
.516 .16123 L
.52 .16123 L
.524 .16123 L
.528 .16123 L
.532 .16123 L
.536 .16123 L
.54 .16123 L
.544 .16123 L
.548 .16123 L
.552 .16123 L
.556 .16123 L
.56 .16123 L
.564 .16123 L
.568 .16123 L
.572 .16123 L
.576 .16123 L
.58 .16123 L
.584 .16123 L
.588 .16123 L
.592 .16123 L
.596 .16123 L
.6 .16123 L
Mistroke
.604 .16123 L
.608 .16123 L
.612 .16123 L
.616 .16123 L
.62 .16123 L
.624 .16123 L
.628 .16123 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(1837\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30034 m
.008 .29886 L
.012 .29853 L
.016 .29839 L
.02 .29854 L
.024 .29881 L
.028 .29905 L
.032 .29896 L
.036 .29851 L
.04 .29831 L
.044 .29867 L
.048 .29917 L
.052 .29919 L
.056 .29843 L
.06 .29775 L
.064 .2984 L
.068 .29971 L
.072 .29967 L
.076 .29833 L
.08 .29742 L
.084 .29767 L
.088 .29882 L
.092 .30011 L
.096 .30035 L
.1 .29912 L
.104 .29695 L
.108 .29532 L
.112 .29633 L
.116 .29993 L
.12 .30327 L
.124 .30369 L
.128 .30042 L
.132 .29556 L
.136 .29243 L
.14 .29209 L
.144 .29351 L
.148 .29562 L
.152 .2987 L
.156 .30375 L
.16 .31078 L
.164 .31802 L
.168 .32299 L
.172 .32497 L
.176 .32558 L
.18 .32708 L
.184 .33049 L
.188 .33458 L
.192 .33704 L
.196 .33679 L
.2 .3349 L
Mistroke
.204 .33374 L
.208 .33518 L
.212 .33905 L
.216 .34331 L
.22 .34559 L
.224 .34486 L
.228 .34208 L
.232 .33963 L
.236 .33965 L
.24 .34285 L
.244 .34813 L
.248 .35321 L
.252 .35598 L
.256 .35542 L
.26 .3521 L
.264 .34782 L
.268 .34471 L
.272 .34442 L
.276 .34752 L
.28 .35341 L
.284 .36068 L
.288 .36755 L
.292 .37249 L
.296 .3745 L
.3 .37328 L
.304 .36913 L
.308 .36276 L
.312 .35509 L
.316 .34699 L
.32 .33918 L
.324 .33217 L
.328 .32621 L
.332 .32141 L
.336 .31769 L
.34 .31492 L
.344 .31293 L
.348 .31155 L
.352 .31061 L
.356 .31 L
.36 .30961 L
.364 .30937 L
.368 .30922 L
.372 .30913 L
.376 .30908 L
.38 .30905 L
.384 .30904 L
.388 .30903 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51811 m
.008 .52261 L
.012 .52407 L
.016 .52236 L
.02 .52196 L
.024 .52259 L
.028 .52274 L
.032 .52243 L
.036 .52239 L
.04 .52253 L
.044 .52261 L
.048 .52253 L
.052 .52244 L
.056 .52239 L
.06 .52252 L
.064 .52268 L
.068 .52263 L
.072 .52235 L
.076 .52226 L
.08 .52244 L
.084 .52272 L
.088 .52283 L
.092 .52263 L
.096 .52221 L
.1 .522 L
.104 .52219 L
.108 .52273 L
.112 .52328 L
.116 .52332 L
.12 .52269 L
.124 .52177 L
.128 .5211 L
.132 .5212 L
.136 .52205 L
.14 .52328 L
.144 .52445 L
.148 .52524 L
.152 .52542 L
.156 .52476 L
.16 .52305 L
.164 .52021 L
.168 .51643 L
.172 .51214 L
.176 .50763 L
.18 .503 L
.184 .49812 L
.188 .49289 L
.192 .48738 L
.196 .48185 L
.2 .47654 L
Mistroke
.204 .4715 L
.208 .46654 L
.212 .4614 L
.216 .45593 L
.22 .45022 L
.224 .44453 L
.228 .43914 L
.232 .43413 L
.236 .42934 L
.24 .42447 L
.244 .41927 L
.248 .41364 L
.252 .40772 L
.256 .40179 L
.26 .39617 L
.264 .39103 L
.268 .38635 L
.272 .38191 L
.276 .37743 L
.28 .37258 L
.284 .3672 L
.288 .36123 L
.292 .35481 L
.296 .34818 L
.3 .34162 L
.304 .33542 L
.308 .32982 L
.312 .32497 L
.316 .32092 L
.32 .31767 L
.324 .31515 L
.328 .31325 L
.332 .31187 L
.336 .3109 L
.34 .31023 L
.344 .30978 L
.348 .30949 L
.352 .3093 L
.356 .30918 L
.36 .30911 L
.364 .30907 L
.368 .30905 L
.372 .30903 L
.376 .30903 L
.38 .30902 L
.384 .30902 L
.388 .30902 L
.392 .30902 L
.396 .30902 L
.4 .30902 L
Mistroke
.404 .30902 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43349 L
.012 .43001 L
.016 .42871 L
.02 .42964 L
.024 .43012 L
.028 .42978 L
.032 .42955 L
.036 .42948 L
.04 .42958 L
.044 .42964 L
.048 .42955 L
.052 .42928 L
.056 .42923 L
.06 .42939 L
.064 .42951 L
.068 .42934 L
.072 .42906 L
.076 .42885 L
.08 .42901 L
.084 .42935 L
.088 .42944 L
.092 .4291 L
.096 .4286 L
.1 .42824 L
.104 .42843 L
.108 .4291 L
.112 .4297 L
.116 .42971 L
.12 .42892 L
.124 .42767 L
.128 .42684 L
.132 .42691 L
.136 .42791 L
.14 .42941 L
.144 .43082 L
.148 .43175 L
.152 .43193 L
.156 .43108 L
.16 .42889 L
.164 .4253 L
.168 .42057 L
.172 .41516 L
.176 .4095 L
.18 .40369 L
.184 .39757 L
.188 .39102 L
.192 .38412 L
.196 .37718 L
.2 .37053 L
Mistroke
.204 .36422 L
.208 .35801 L
.212 .35157 L
.216 .34472 L
.22 .33757 L
.224 .33046 L
.228 .32371 L
.232 .31744 L
.236 .31144 L
.24 .30535 L
.244 .29885 L
.248 .29181 L
.252 .2844 L
.256 .27701 L
.26 .26998 L
.264 .26356 L
.268 .2577 L
.272 .25216 L
.276 .24656 L
.28 .24051 L
.284 .23379 L
.288 .22634 L
.292 .21833 L
.296 .21005 L
.3 .20187 L
.304 .19415 L
.308 .18716 L
.312 .18111 L
.316 .17606 L
.32 .17201 L
.324 .16887 L
.328 .1665 L
.332 .16478 L
.336 .16357 L
.34 .16273 L
.344 .16217 L
.348 .16181 L
.352 .16158 L
.356 .16143 L
.36 .16135 L
.364 .16129 L
.368 .16126 L
.372 .16125 L
.376 .16124 L
.38 .16123 L
.384 .16123 L
.388 .16123 L
.392 .16123 L
.396 .16123 L
.4 .16123 L
Mistroke
.404 .16123 L
.408 .16123 L
.412 .16123 L
.416 .16123 L
.42 .16123 L
.424 .16123 L
.428 .16123 L
.432 .16123 L
.436 .16123 L
.44 .16123 L
.444 .16123 L
.448 .16123 L
.452 .16123 L
.456 .16123 L
.46 .16123 L
.464 .16123 L
.468 .16123 L
.472 .16123 L
.476 .16123 L
.48 .16123 L
.484 .16123 L
.488 .16123 L
.492 .16123 L
.496 .16123 L
.5 .16123 L
.504 .16123 L
.508 .16123 L
.512 .16123 L
.516 .16123 L
.52 .16123 L
.524 .16123 L
.528 .16123 L
.532 .16123 L
.536 .16123 L
.54 .16123 L
.544 .16123 L
.548 .16123 L
.552 .16123 L
.556 .16123 L
.56 .16123 L
.564 .16123 L
.568 .16123 L
.572 .16123 L
.576 .16123 L
.58 .16123 L
.584 .16123 L
.588 .16123 L
.592 .16123 L
.596 .16123 L
.6 .16123 L
Mistroke
.604 .16123 L
.608 .16123 L
.612 .16123 L
.616 .16123 L
.62 .16123 L
.624 .16123 L
.628 .16123 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(2004\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29724 m
.008 .29786 L
.012 .2995 L
.016 .29967 L
.02 .2984 L
.024 .29819 L
.028 .299 L
.032 .29922 L
.036 .29872 L
.04 .29838 L
.044 .29856 L
.048 .29903 L
.052 .29926 L
.056 .29866 L
.06 .29792 L
.064 .2984 L
.068 .29959 L
.072 .29954 L
.076 .29825 L
.08 .29758 L
.084 .29824 L
.088 .29936 L
.092 .29991 L
.096 .29925 L
.1 .29789 L
.104 .29706 L
.108 .29746 L
.112 .29914 L
.116 .3011 L
.12 .30123 L
.124 .29879 L
.128 .29546 L
.132 .29401 L
.136 .29634 L
.14 .30109 L
.144 .30439 L
.148 .30396 L
.152 .30044 L
.156 .29626 L
.16 .29348 L
.164 .29216 L
.168 .2916 L
.172 .29209 L
.176 .29508 L
.18 .30142 L
.184 .30987 L
.188 .31777 L
.192 .32282 L
.196 .32509 L
.2 .32671 L
Mistroke
.204 .32973 L
.208 .33438 L
.212 .33889 L
.216 .34106 L
.22 .34031 L
.224 .33821 L
.228 .33728 L
.232 .33918 L
.236 .34346 L
.24 .3479 L
.244 .35015 L
.248 .34925 L
.252 .34622 L
.256 .34345 L
.26 .34317 L
.264 .34621 L
.268 .35162 L
.272 .35718 L
.276 .36063 L
.28 .36071 L
.284 .35768 L
.288 .35311 L
.292 .34917 L
.296 .34772 L
.3 .34972 L
.304 .35494 L
.308 .36221 L
.312 .36982 L
.316 .37609 L
.32 .37973 L
.324 .38011 L
.328 .37725 L
.332 .37167 L
.336 .36422 L
.34 .3558 L
.344 .34726 L
.348 .33922 L
.352 .33213 L
.356 .32617 L
.36 .32139 L
.364 .3177 L
.368 .31496 L
.372 .31298 L
.376 .3116 L
.38 .31066 L
.384 .31004 L
.388 .30964 L
.392 .30939 L
.396 .30924 L
.4 .30914 L
Mistroke
.404 .30909 L
.408 .30906 L
.412 .30904 L
.416 .30903 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51688 m
.008 .52216 L
.012 .52402 L
.016 .52234 L
.02 .52171 L
.024 .52221 L
.028 .52248 L
.032 .52227 L
.036 .52219 L
.04 .52224 L
.044 .52233 L
.048 .52231 L
.052 .52224 L
.056 .52217 L
.06 .52226 L
.064 .52239 L
.068 .52235 L
.072 .52215 L
.076 .52211 L
.08 .52226 L
.084 .52244 L
.088 .52243 L
.092 .52224 L
.096 .52201 L
.1 .52204 L
.104 .52232 L
.108 .5226 L
.112 .52263 L
.116 .52232 L
.12 .52184 L
.124 .52164 L
.128 .52195 L
.132 .52262 L
.136 .52318 L
.14 .52315 L
.144 .52246 L
.148 .52154 L
.152 .5209 L
.156 .52089 L
.16 .5215 L
.164 .52252 L
.168 .52369 L
.172 .52478 L
.176 .52547 L
.18 .52537 L
.184 .52417 L
.188 .52182 L
.192 .51856 L
.196 .51476 L
.2 .51067 L
Mistroke
.204 .50629 L
.208 .50152 L
.212 .49633 L
.216 .49086 L
.22 .4854 L
.224 .48018 L
.228 .47519 L
.232 .47024 L
.236 .46509 L
.24 .45959 L
.244 .45388 L
.248 .4482 L
.252 .44281 L
.256 .43778 L
.26 .433 L
.264 .42816 L
.268 .42302 L
.272 .41745 L
.276 .41157 L
.28 .40562 L
.284 .39991 L
.288 .39464 L
.292 .38984 L
.296 .38537 L
.3 .38094 L
.304 .37627 L
.308 .37112 L
.312 .36541 L
.316 .35917 L
.32 .35261 L
.324 .34598 L
.328 .33956 L
.332 .33361 L
.336 .32831 L
.34 .32376 L
.344 .32 L
.348 .317 L
.352 .31468 L
.356 .31295 L
.36 .31168 L
.364 .31078 L
.368 .31016 L
.372 .30974 L
.376 .30947 L
.38 .30929 L
.384 .30918 L
.388 .30911 L
.392 .30907 L
.396 .30905 L
.4 .30903 L
Mistroke
.404 .30903 L
.408 .30902 L
.412 .30902 L
.416 .30902 L
.42 .30902 L
.424 .30902 L
.428 .30902 L
.432 .30902 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42702 L
.012 .43003 L
.016 .43088 L
.02 .42963 L
.024 .42938 L
.028 .42977 L
.032 .42981 L
.036 .4295 L
.04 .42948 L
.044 .42959 L
.048 .42957 L
.052 .42933 L
.056 .42927 L
.06 .42936 L
.064 .42944 L
.068 .42931 L
.072 .4291 L
.076 .42896 L
.08 .42909 L
.084 .42929 L
.088 .42925 L
.092 .42891 L
.096 .42863 L
.1 .42861 L
.104 .42889 L
.108 .42922 L
.112 .42921 L
.116 .42875 L
.12 .42815 L
.124 .42784 L
.128 .42817 L
.132 .42898 L
.136 .42961 L
.14 .42953 L
.144 .42865 L
.148 .42743 L
.152 .42661 L
.156 .42655 L
.16 .42726 L
.164 .42849 L
.168 .42991 L
.172 .43122 L
.176 .43203 L
.18 .43186 L
.184 .43032 L
.188 .42734 L
.192 .42324 L
.196 .41846 L
.2 .41332 L
Mistroke
.204 .40782 L
.208 .40184 L
.212 .39532 L
.216 .38848 L
.22 .38164 L
.224 .37509 L
.228 .36884 L
.232 .36264 L
.236 .35618 L
.24 .34931 L
.244 .34215 L
.248 .33504 L
.252 .3283 L
.256 .32201 L
.26 .31602 L
.264 .30997 L
.268 .30353 L
.272 .29658 L
.276 .28922 L
.28 .28179 L
.284 .27465 L
.288 .26806 L
.292 .26207 L
.296 .25648 L
.3 .25095 L
.304 .24511 L
.308 .23869 L
.312 .23155 L
.316 .22377 L
.32 .21558 L
.324 .20731 L
.328 .19931 L
.332 .19188 L
.336 .18527 L
.34 .1796 L
.344 .17492 L
.348 .17118 L
.352 .16829 L
.356 .16612 L
.36 .16454 L
.364 .16342 L
.368 .16265 L
.372 .16213 L
.376 .16179 L
.38 .16157 L
.384 .16143 L
.388 .16135 L
.392 .1613 L
.396 .16127 L
.4 .16125 L
Mistroke
.404 .16124 L
.408 .16123 L
.412 .16123 L
.416 .16123 L
.42 .16123 L
.424 .16123 L
.428 .16123 L
.432 .16123 L
.436 .16123 L
.44 .16123 L
.444 .16123 L
.448 .16123 L
.452 .16123 L
.456 .16123 L
.46 .16123 L
.464 .16123 L
.468 .16123 L
.472 .16123 L
.476 .16123 L
.48 .16123 L
.484 .16123 L
.488 .16123 L
.492 .16123 L
.496 .16123 L
.5 .16123 L
.504 .16123 L
.508 .16123 L
.512 .16123 L
.516 .16123 L
.52 .16123 L
.524 .16123 L
.528 .16123 L
.532 .16123 L
.536 .16123 L
.54 .16123 L
.544 .16123 L
.548 .16123 L
.552 .16123 L
.556 .16123 L
.56 .16123 L
.564 .16123 L
.568 .16123 L
.572 .16123 L
.576 .16123 L
.58 .16123 L
.584 .16123 L
.588 .16123 L
.592 .16123 L
.596 .16123 L
.6 .16123 L
Mistroke
.604 .16123 L
.608 .16123 L
.612 .16123 L
.616 .16123 L
.62 .16123 L
.624 .16123 L
.628 .16123 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(2171\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29691 m
.008 .29859 L
.012 .2994 L
.016 .29949 L
.02 .29872 L
.024 .29838 L
.028 .29877 L
.032 .29909 L
.036 .29898 L
.04 .29862 L
.044 .29846 L
.048 .29886 L
.052 .29931 L
.056 .29888 L
.06 .29807 L
.064 .29835 L
.068 .29945 L
.072 .2995 L
.076 .29837 L
.08 .29777 L
.084 .29845 L
.088 .29946 L
.092 .29968 L
.096 .29878 L
.1 .29768 L
.104 .29763 L
.108 .29867 L
.112 .29982 L
.116 .30018 L
.12 .29916 L
.124 .29723 L
.128 .29616 L
.132 .29727 L
.136 .30016 L
.14 .30255 L
.144 .3017 L
.148 .29771 L
.152 .29389 L
.156 .2934 L
.16 .29686 L
.164 .30173 L
.168 .30447 L
.172 .30387 L
.176 .30118 L
.18 .29809 L
.184 .29521 L
.188 .29223 L
.192 .28947 L
.196 .28861 L
.2 .29167 L
Mistroke
.204 .29889 L
.208 .30807 L
.212 .31615 L
.216 .3213 L
.22 .32422 L
.224 .32721 L
.228 .33185 L
.232 .3377 L
.236 .34265 L
.24 .34468 L
.244 .34366 L
.248 .3415 L
.252 .34081 L
.256 .34309 L
.26 .34771 L
.264 .35237 L
.268 .35471 L
.272 .35376 L
.276 .35053 L
.28 .3474 L
.284 .3467 L
.288 .34945 L
.292 .35487 L
.296 .36087 L
.3 .36508 L
.304 .36596 L
.308 .36341 L
.312 .35876 L
.316 .35409 L
.32 .35147 L
.324 .35219 L
.328 .35645 L
.332 .36339 L
.336 .37143 L
.34 .37882 L
.344 .38405 L
.348 .38617 L
.352 .38488 L
.356 .38045 L
.36 .3736 L
.364 .36521 L
.368 .35619 L
.372 .3473 L
.376 .33912 L
.38 .33199 L
.384 .32606 L
.388 .32132 L
.392 .31768 L
.396 .31497 L
.4 .31301 L
Mistroke
.404 .31164 L
.408 .3107 L
.412 .31007 L
.416 .30967 L
.42 .30941 L
.424 .30925 L
.428 .30915 L
.432 .30909 L
.436 .30906 L
.44 .30904 L
.444 .30903 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .52549 m
.008 .52188 L
.012 .52081 L
.016 .52214 L
.02 .52248 L
.024 .52195 L
.028 .52189 L
.032 .52205 L
.036 .52208 L
.04 .52199 L
.044 .52203 L
.048 .52207 L
.052 .52204 L
.056 .52195 L
.06 .52201 L
.064 .52211 L
.068 .5221 L
.072 .52195 L
.076 .52192 L
.08 .52203 L
.084 .52215 L
.088 .52212 L
.092 .52198 L
.096 .52185 L
.1 .52193 L
.104 .52214 L
.108 .52226 L
.112 .52213 L
.116 .52189 L
.12 .52171 L
.124 .52183 L
.128 .52218 L
.132 .52247 L
.136 .52241 L
.14 .52198 L
.144 .52145 L
.148 .52132 L
.152 .52176 L
.156 .52248 L
.16 .523 L
.164 .52292 L
.168 .52228 L
.172 .52144 L
.176 .5208 L
.18 .52061 L
.184 .52092 L
.188 .52171 L
.192 .52289 L
.196 .52421 L
.2 .52528 L
Mistroke
.204 .52562 L
.208 .52489 L
.212 .52307 L
.216 .52038 L
.22 .51712 L
.224 .51346 L
.228 .50937 L
.232 .50476 L
.236 .49967 L
.24 .49429 L
.244 .48893 L
.248 .48378 L
.252 .47885 L
.256 .47391 L
.26 .46875 L
.264 .46326 L
.268 .45755 L
.272 .45186 L
.276 .44646 L
.28 .44142 L
.284 .43663 L
.288 .43182 L
.292 .42675 L
.296 .42126 L
.3 .41543 L
.304 .40947 L
.308 .40367 L
.312 .39827 L
.316 .39334 L
.32 .3888 L
.324 .3844 L
.328 .37986 L
.332 .37493 L
.336 .36947 L
.34 .36347 L
.344 .35704 L
.348 .35041 L
.352 .34385 L
.356 .33762 L
.36 .33192 L
.364 .32691 L
.368 .32266 L
.372 .31917 L
.376 .3164 L
.38 .31427 L
.384 .31267 L
.388 .3115 L
.392 .31067 L
.396 .3101 L
.4 .30971 L
Mistroke
.404 .30945 L
.408 .30928 L
.412 .30918 L
.416 .30911 L
.42 .30907 L
.424 .30905 L
.428 .30904 L
.432 .30903 L
.436 .30902 L
.44 .30902 L
.444 .30902 L
.448 .30902 L
.452 .30902 L
.456 .30902 L
.46 .30902 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42587 L
.012 .42974 L
.016 .43117 L
.02 .42983 L
.024 .42931 L
.028 .42966 L
.032 .42982 L
.036 .42957 L
.04 .42949 L
.044 .42954 L
.048 .42955 L
.052 .42938 L
.056 .4293 L
.06 .42933 L
.064 .42939 L
.068 .4293 L
.072 .42915 L
.076 .42902 L
.08 .4291 L
.084 .42922 L
.088 .42916 L
.092 .42889 L
.096 .42872 L
.1 .42878 L
.104 .42898 L
.108 .42908 L
.112 .4289 L
.116 .42851 L
.12 .42828 L
.124 .42838 L
.128 .42876 L
.132 .42909 L
.136 .42898 L
.14 .42836 L
.144 .42769 L
.148 .42747 L
.152 .42796 L
.156 .42884 L
.16 .42943 L
.164 .42928 L
.168 .42845 L
.172 .42735 L
.176 .42651 L
.18 .42622 L
.184 .42657 L
.188 .42751 L
.192 .42893 L
.196 .43054 L
.2 .43182 L
Mistroke
.204 .4322 L
.208 .43125 L
.212 .42893 L
.216 .42553 L
.22 .42143 L
.224 .41683 L
.228 .41169 L
.232 .40591 L
.236 .39951 L
.24 .39277 L
.244 .38605 L
.248 .37961 L
.252 .37342 L
.256 .36724 L
.26 .36077 L
.264 .3539 L
.268 .34674 L
.272 .33963 L
.276 .33287 L
.28 .32656 L
.284 .32056 L
.288 .31455 L
.292 .3082 L
.296 .30134 L
.3 .29404 L
.304 .2866 L
.308 .27936 L
.312 .27261 L
.316 .26645 L
.32 .26076 L
.324 .25526 L
.328 .2496 L
.332 .24344 L
.336 .23662 L
.34 .22913 L
.344 .22111 L
.348 .21284 L
.352 .20466 L
.356 .19688 L
.36 .18978 L
.364 .18353 L
.368 .17823 L
.372 .17389 L
.376 .17043 L
.38 .16777 L
.384 .16577 L
.388 .16432 L
.392 .16329 L
.396 .16257 L
.4 .16209 L
Mistroke
.404 .16177 L
.408 .16156 L
.412 .16143 L
.416 .16135 L
.42 .1613 L
.424 .16127 L
.428 .16125 L
.432 .16124 L
.436 .16123 L
.44 .16123 L
.444 .16123 L
.448 .16123 L
.452 .16123 L
.456 .16123 L
.46 .16123 L
.464 .16123 L
.468 .16123 L
.472 .16123 L
.476 .16123 L
.48 .16123 L
.484 .16123 L
.488 .16123 L
.492 .16123 L
.496 .16123 L
.5 .16123 L
.504 .16123 L
.508 .16123 L
.512 .16123 L
.516 .16123 L
.52 .16123 L
.524 .16123 L
.528 .16123 L
.532 .16123 L
.536 .16123 L
.54 .16123 L
.544 .16123 L
.548 .16123 L
.552 .16123 L
.556 .16123 L
.56 .16123 L
.564 .16123 L
.568 .16123 L
.572 .16123 L
.576 .16123 L
.58 .16123 L
.584 .16123 L
.588 .16123 L
.592 .16123 L
.596 .16123 L
.6 .16123 L
Mistroke
.604 .16123 L
.608 .16123 L
.612 .16123 L
.616 .16123 L
.62 .16123 L
.624 .16123 L
.628 .16123 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(2338\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30009 m
.008 .29983 L
.012 .29834 L
.016 .29816 L
.02 .29919 L
.024 .29925 L
.028 .2986 L
.032 .29866 L
.036 .29912 L
.04 .29895 L
.044 .29845 L
.048 .29868 L
.052 .29931 L
.056 .29907 L
.06 .29824 L
.064 .29833 L
.068 .29929 L
.072 .29948 L
.076 .29856 L
.08 .29796 L
.084 .29849 L
.088 .29939 L
.092 .29957 L
.096 .29868 L
.1 .29775 L
.104 .29801 L
.108 .29917 L
.112 .29984 L
.116 .29941 L
.12 .29827 L
.124 .29732 L
.128 .29755 L
.132 .29905 L
.136 .30061 L
.14 .30073 L
.144 .29869 L
.148 .2959 L
.152 .29521 L
.156 .29782 L
.16 .30178 L
.164 .30367 L
.168 .30138 L
.172 .29649 L
.176 .29301 L
.18 .29346 L
.184 .29718 L
.188 .30141 L
.192 .30373 L
.196 .30386 L
.2 .30269 L
Mistroke
.204 .30064 L
.208 .29723 L
.212 .29236 L
.216 .28758 L
.22 .28564 L
.224 .28864 L
.228 .29616 L
.232 .30541 L
.236 .31331 L
.24 .31859 L
.244 .3224 L
.248 .32691 L
.252 .33321 L
.256 .34028 L
.26 .34577 L
.264 .34788 L
.268 .3468 L
.272 .3447 L
.276 .34424 L
.28 .34684 L
.284 .35177 L
.288 .35671 L
.292 .35925 L
.296 .35837 L
.3 .35501 L
.304 .3515 L
.308 .35028 L
.312 .35258 L
.316 .3579 L
.32 .36426 L
.324 .36925 L
.328 .37106 L
.332 .36922 L
.336 .36471 L
.34 .35949 L
.344 .35575 L
.348 .35509 L
.352 .35813 L
.356 .36437 L
.36 .37248 L
.364 .38072 L
.368 .38741 L
.372 .39131 L
.376 .39179 L
.38 .38884 L
.384 .38297 L
.388 .37498 L
.392 .3658 L
.396 .35629 L
.4 .34715 L
Mistroke
.404 .33889 L
.408 .33176 L
.412 .32588 L
.416 .32121 L
.42 .31762 L
.424 .31495 L
.428 .31302 L
.432 .31166 L
.436 .31073 L
.44 .3101 L
.444 .30969 L
.448 .30943 L
.452 .30926 L
.456 .30916 L
.46 .3091 L
.464 .30906 L
.468 .30904 L
.472 .30903 L
.476 .30903 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .52784 m
.008 .52184 L
.012 .51984 L
.016 .5217 L
.02 .52245 L
.024 .52182 L
.028 .52159 L
.032 .52177 L
.036 .52187 L
.04 .52177 L
.044 .52177 L
.048 .52181 L
.052 .52182 L
.056 .52174 L
.06 .52176 L
.064 .52184 L
.068 .52185 L
.072 .52174 L
.076 .52171 L
.08 .52178 L
.084 .52188 L
.088 .52186 L
.092 .52175 L
.096 .52166 L
.1 .52174 L
.104 .5219 L
.108 .52194 L
.112 .5218 L
.116 .52164 L
.12 .52161 L
.124 .52178 L
.128 .52199 L
.132 .52204 L
.136 .52183 L
.14 .52153 L
.144 .52141 L
.148 .52164 L
.152 .52208 L
.156 .52234 L
.16 .52216 L
.164 .52161 L
.168 .5211 L
.172 .52106 L
.176 .52156 L
.18 .52227 L
.184 .52274 L
.188 .52269 L
.192 .52217 L
.196 .52144 L
.2 .52076 L
Mistroke
.204 .52034 L
.208 .52036 L
.212 .52094 L
.216 .52207 L
.22 .52353 L
.224 .52486 L
.228 .52554 L
.232 .52525 L
.236 .52396 L
.24 .52187 L
.244 .51918 L
.248 .51599 L
.252 .51222 L
.256 .50783 L
.26 .50289 L
.264 .49764 L
.268 .4924 L
.272 .48734 L
.276 .48246 L
.28 .47755 L
.284 .4724 L
.288 .46693 L
.292 .46122 L
.296 .45553 L
.3 .4501 L
.304 .44504 L
.308 .44023 L
.312 .43546 L
.316 .43045 L
.32 .42506 L
.324 .41929 L
.328 .41334 L
.332 .40748 L
.336 .40195 L
.34 .39687 L
.344 .39222 L
.348 .38781 L
.352 .38337 L
.356 .37863 L
.36 .37342 L
.364 .36766 L
.368 .36142 L
.372 .35487 L
.376 .34825 L
.38 .34181 L
.384 .33578 L
.388 .33036 L
.392 .32563 L
.396 .32166 L
.4 .31842 L
Mistroke
.404 .31586 L
.408 .31389 L
.412 .31241 L
.416 .31134 L
.42 .31057 L
.424 .31004 L
.428 .30967 L
.432 .30943 L
.436 .30927 L
.44 .30917 L
.444 .30911 L
.448 .30907 L
.452 .30905 L
.456 .30904 L
.46 .30903 L
.464 .30902 L
.468 .30902 L
.472 .30902 L
.476 .30902 L
.48 .30902 L
.484 .30902 L
.488 .30902 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43212 L
.012 .42966 L
.016 .42905 L
.02 .42988 L
.024 .43004 L
.028 .42964 L
.032 .42957 L
.036 .42959 L
.04 .42958 L
.044 .42952 L
.048 .42951 L
.052 .42941 L
.056 .42934 L
.06 .42931 L
.064 .42935 L
.068 .4293 L
.072 .42918 L
.076 .42905 L
.08 .42909 L
.084 .42918 L
.088 .42913 L
.092 .4289 L
.096 .42878 L
.1 .42884 L
.104 .42897 L
.108 .42897 L
.112 .42878 L
.116 .42851 L
.12 .42845 L
.124 .42861 L
.128 .42883 L
.132 .42883 L
.136 .42854 L
.14 .42811 L
.144 .42793 L
.148 .42817 L
.152 .42866 L
.156 .42896 L
.16 .42869 L
.164 .42795 L
.168 .42728 L
.172 .42718 L
.176 .42775 L
.18 .4286 L
.184 .42913 L
.188 .42902 L
.192 .42834 L
.196 .42738 L
.2 .42649 L
Mistroke
.204 .42593 L
.208 .42591 L
.212 .42658 L
.216 .42795 L
.22 .42973 L
.224 .43133 L
.228 .43214 L
.232 .43173 L
.236 .43008 L
.24 .42742 L
.244 .42403 L
.248 .42001 L
.252 .41527 L
.256 .40976 L
.26 .40356 L
.264 .39698 L
.268 .3904 L
.272 .38407 L
.276 .37794 L
.28 .37179 L
.284 .36535 L
.288 .35849 L
.292 .35134 L
.296 .34423 L
.3 .33743 L
.304 .33108 L
.308 .32507 L
.312 .3191 L
.316 .31283 L
.32 .30608 L
.324 .29887 L
.328 .29143 L
.332 .28411 L
.336 .2772 L
.34 .27086 L
.344 .26504 L
.348 .25953 L
.352 .25397 L
.356 .24806 L
.36 .24155 L
.364 .23436 L
.368 .22657 L
.372 .2184 L
.376 .21014 L
.38 .20211 L
.384 .1946 L
.388 .18783 L
.392 .18194 L
.396 .17698 L
.4 .17295 L
Mistroke
.404 .16975 L
.408 .1673 L
.412 .16546 L
.416 .16412 L
.42 .16316 L
.424 .1625 L
.428 .16204 L
.432 .16174 L
.436 .16155 L
.44 .16142 L
.444 .16134 L
.448 .1613 L
.452 .16127 L
.456 .16125 L
.46 .16124 L
.464 .16123 L
.468 .16123 L
.472 .16123 L
.476 .16123 L
.48 .16123 L
.484 .16123 L
.488 .16123 L
.492 .16123 L
.496 .16123 L
.5 .16123 L
.504 .16123 L
.508 .16123 L
.512 .16123 L
.516 .16123 L
.52 .16123 L
.524 .16123 L
.528 .16123 L
.532 .16123 L
.536 .16123 L
.54 .16123 L
.544 .16123 L
.548 .16123 L
.552 .16123 L
.556 .16123 L
.56 .16123 L
.564 .16123 L
.568 .16123 L
.572 .16123 L
.576 .16123 L
.58 .16123 L
.584 .16123 L
.588 .16123 L
.592 .16123 L
.596 .16123 L
.6 .16123 L
Mistroke
.604 .16123 L
.608 .16123 L
.612 .16123 L
.616 .16123 L
.62 .16123 L
.624 .16123 L
.628 .16123 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(2505\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30113 m
.008 .2994 L
.012 .29822 L
.016 .29811 L
.02 .29916 L
.024 .29941 L
.028 .29872 L
.032 .29859 L
.036 .29911 L
.04 .29908 L
.044 .29856 L
.048 .29863 L
.052 .29924 L
.056 .29918 L
.06 .29844 L
.064 .29836 L
.068 .29913 L
.072 .29942 L
.076 .29877 L
.08 .29817 L
.084 .29846 L
.088 .29927 L
.092 .29953 L
.096 .29875 L
.1 .29788 L
.104 .2982 L
.108 .29933 L
.112 .29975 L
.116 .29901 L
.12 .298 L
.124 .2977 L
.128 .29844 L
.132 .29962 L
.136 .30009 L
.14 .29928 L
.144 .29767 L
.148 .29661 L
.152 .29749 L
.156 .30001 L
.16 .30182 L
.164 .30086 L
.168 .29744 L
.172 .2944 L
.176 .29492 L
.18 .29901 L
.184 .30323 L
.188 .30404 L
.192 .30067 L
.196 .29578 L
.2 .29299 L
Mistroke
.204 .29377 L
.208 .29685 L
.212 .30017 L
.216 .30256 L
.22 .30409 L
.224 .30471 L
.228 .30349 L
.232 .29935 L
.236 .29274 L
.24 .28632 L
.244 .28346 L
.248 .28612 L
.252 .29333 L
.256 .30206 L
.26 .3095 L
.264 .31488 L
.268 .31962 L
.272 .32569 L
.276 .33363 L
.28 .34195 L
.284 .34815 L
.288 .35058 L
.292 .34966 L
.296 .34774 L
.3 .3475 L
.304 .35036 L
.308 .3556 L
.312 .36088 L
.316 .36375 L
.32 .36308 L
.324 .35967 L
.328 .35579 L
.332 .35396 L
.336 .35567 L
.34 .36072 L
.344 .36734 L
.348 .3731 L
.352 .37593 L
.356 .37499 L
.36 .37088 L
.364 .36535 L
.368 .3606 L
.372 .35852 L
.376 .36013 L
.38 .36535 L
.384 .37315 L
.388 .3819 L
.392 .38982 L
.396 .39544 L
.4 .39781 L
Mistroke
.404 .3966 L
.408 .39207 L
.412 .38487 L
.416 .37589 L
.42 .36605 L
.424 .35616 L
.428 .34685 L
.432 .33855 L
.436 .33147 L
.44 .32566 L
.444 .32106 L
.448 .31753 L
.452 .31491 L
.456 .31301 L
.46 .31167 L
.464 .31074 L
.468 .31012 L
.472 .30971 L
.476 .30944 L
.48 .30928 L
.484 .30917 L
.488 .30911 L
.492 .30907 L
.496 .30905 L
.5 .30903 L
.504 .30903 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51925 m
.008 .52168 L
.012 .52244 L
.016 .5214 L
.02 .52124 L
.024 .52161 L
.028 .52168 L
.032 .52152 L
.036 .52152 L
.04 .52154 L
.044 .52157 L
.048 .52157 L
.052 .52157 L
.056 .52151 L
.06 .52153 L
.064 .52158 L
.068 .5216 L
.072 .52153 L
.076 .5215 L
.08 .52153 L
.084 .52161 L
.088 .52161 L
.092 .52153 L
.096 .52146 L
.1 .52152 L
.104 .52164 L
.108 .52165 L
.112 .52153 L
.116 .52143 L
.12 .52146 L
.124 .5216 L
.128 .52171 L
.132 .52166 L
.136 .52147 L
.14 .52134 L
.144 .5214 L
.148 .52163 L
.152 .52184 L
.156 .5218 L
.16 .52149 L
.164 .52117 L
.168 .52114 L
.172 .52149 L
.176 .52198 L
.18 .52217 L
.184 .52186 L
.188 .52128 L
.192 .52082 L
.196 .52084 L
.2 .52133 L
Mistroke
.204 .52197 L
.208 .52242 L
.212 .52246 L
.216 .52211 L
.22 .52149 L
.224 .52075 L
.228 .52012 L
.232 .51986 L
.236 .52024 L
.24 .52129 L
.244 .52278 L
.248 .52425 L
.252 .5252 L
.256 .5253 L
.26 .52453 L
.264 .52303 L
.268 .52092 L
.272 .51821 L
.276 .51482 L
.28 .5107 L
.284 .50597 L
.288 .5009 L
.292 .49579 L
.296 .49084 L
.3 .48602 L
.304 .48115 L
.308 .47604 L
.312 .47059 L
.316 .4649 L
.32 .4592 L
.324 .45375 L
.328 .44864 L
.332 .44382 L
.336 .43907 L
.34 .43413 L
.344 .42883 L
.348 .42314 L
.352 .41722 L
.356 .41131 L
.36 .40566 L
.364 .40044 L
.368 .39566 L
.372 .39119 L
.376 .3868 L
.38 .38222 L
.384 .37724 L
.388 .37174 L
.392 .36573 L
.396 .35931 L
.4 .3527 L
Mistroke
.404 .34614 L
.408 .33986 L
.412 .33406 L
.416 .3289 L
.42 .32446 L
.424 .32074 L
.428 .31773 L
.432 .31536 L
.436 .31354 L
.44 .31218 L
.444 .31118 L
.448 .31047 L
.452 .30998 L
.456 .30964 L
.46 .30941 L
.464 .30927 L
.468 .30917 L
.472 .30911 L
.476 .30907 L
.48 .30905 L
.484 .30904 L
.488 .30903 L
.492 .30902 L
.496 .30902 L
.5 .30902 L
.504 .30902 L
.508 .30902 L
.512 .30902 L
.516 .30902 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43441 L
.012 .42994 L
.016 .42838 L
.02 .42969 L
.024 .43023 L
.028 .42973 L
.032 .42951 L
.036 .42956 L
.04 .4296 L
.044 .42952 L
.048 .42949 L
.052 .42942 L
.056 .42937 L
.06 .4293 L
.064 .42932 L
.068 .42929 L
.072 .4292 L
.076 .42907 L
.08 .42908 L
.084 .42914 L
.088 .42911 L
.092 .42893 L
.096 .42882 L
.1 .42886 L
.104 .42895 L
.108 .42891 L
.112 .42874 L
.116 .42855 L
.12 .42855 L
.124 .42869 L
.128 .42878 L
.132 .42866 L
.136 .4284 L
.14 .42818 L
.144 .4282 L
.148 .42846 L
.152 .42867 L
.156 .42857 L
.16 .42815 L
.164 .42769 L
.168 .42762 L
.172 .42802 L
.176 .42857 L
.18 .42876 L
.184 .42835 L
.188 .42756 L
.192 .42695 L
.196 .42694 L
.2 .4275 L
Mistroke
.204 .42826 L
.208 .42876 L
.212 .42877 L
.216 .4283 L
.22 .42747 L
.224 .42651 L
.228 .42568 L
.232 .42532 L
.236 .42574 L
.24 .427 L
.244 .42882 L
.248 .43061 L
.252 .43174 L
.256 .43182 L
.26 .43082 L
.264 .4289 L
.268 .42622 L
.272 .4228 L
.276 .41853 L
.28 .41336 L
.284 .40742 L
.288 .40106 L
.292 .39466 L
.296 .38845 L
.3 .3824 L
.304 .3763 L
.308 .36989 L
.312 .36307 L
.316 .35595 L
.32 .34882 L
.324 .34199 L
.328 .33559 L
.332 .32956 L
.336 .32361 L
.34 .31743 L
.344 .3108 L
.348 .30369 L
.352 .29629 L
.356 .2889 L
.36 .28184 L
.364 .27531 L
.368 .26934 L
.372 .26376 L
.376 .25827 L
.38 .25255 L
.384 .24633 L
.388 .23946 L
.392 .23195 L
.396 .22394 L
.4 .21569 L
Mistroke
.404 .20751 L
.408 .19967 L
.412 .19245 L
.416 .18601 L
.42 .18047 L
.424 .17584 L
.428 .17209 L
.432 .16913 L
.436 .16686 L
.44 .16517 L
.444 .16393 L
.448 .16304 L
.452 .16242 L
.456 .162 L
.46 .16172 L
.464 .16154 L
.468 .16142 L
.472 .16134 L
.476 .1613 L
.48 .16127 L
.484 .16125 L
.488 .16124 L
.492 .16123 L
.496 .16123 L
.5 .16123 L
.504 .16123 L
.508 .16123 L
.512 .16123 L
.516 .16123 L
.52 .16123 L
.524 .16123 L
.528 .16123 L
.532 .16123 L
.536 .16123 L
.54 .16123 L
.544 .16123 L
.548 .16123 L
.552 .16123 L
.556 .16123 L
.56 .16123 L
.564 .16123 L
.568 .16123 L
.572 .16123 L
.576 .16123 L
.58 .16123 L
.584 .16123 L
.588 .16123 L
.592 .16123 L
.596 .16123 L
.6 .16123 L
Mistroke
.604 .16123 L
.608 .16123 L
.612 .16123 L
.616 .16123 L
.62 .16123 L
.624 .16123 L
.628 .16123 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(2672\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29825 m
.008 .29816 L
.012 .29925 L
.016 .29945 L
.02 .29884 L
.024 .29871 L
.028 .29889 L
.032 .29896 L
.036 .29907 L
.04 .299 L
.044 .29867 L
.048 .2987 L
.052 .29916 L
.056 .29919 L
.06 .29864 L
.064 .29846 L
.068 .29899 L
.072 .29934 L
.076 .29895 L
.08 .29838 L
.084 .29844 L
.088 .29913 L
.092 .29951 L
.096 .29888 L
.1 .29804 L
.104 .29828 L
.108 .29933 L
.112 .29967 L
.116 .29888 L
.12 .29799 L
.124 .298 L
.128 .29888 L
.132 .29973 L
.136 .29959 L
.14 .29856 L
.144 .2976 L
.148 .2976 L
.152 .2988 L
.156 .30032 L
.16 .30052 L
.164 .29881 L
.168 .29651 L
.172 .29589 L
.176 .29812 L
.18 .30154 L
.184 .30276 L
.188 .3002 L
.192 .2958 L
.196 .29339 L
.2 .29537 L
Mistroke
.204 .30024 L
.208 .30399 L
.212 .30382 L
.216 .30016 L
.22 .29588 L
.224 .29362 L
.228 .29393 L
.232 .2958 L
.236 .29829 L
.24 .30123 L
.244 .3045 L
.248 .30689 L
.252 .30633 L
.256 .30151 L
.26 .29356 L
.264 .28589 L
.268 .28221 L
.272 .2842 L
.276 .29056 L
.28 .2983 L
.284 .30498 L
.288 .31035 L
.292 .31594 L
.296 .32346 L
.3 .33297 L
.304 .34259 L
.308 .34969 L
.312 .35268 L
.316 .35214 L
.32 .3505 L
.324 .3505 L
.328 .35361 L
.332 .35915 L
.336 .36484 L
.34 .36817 L
.344 .36784 L
.348 .36448 L
.352 .36026 L
.356 .35778 L
.36 .35878 L
.364 .36339 L
.368 .37012 L
.372 .37657 L
.376 .38049 L
.38 .38063 L
.384 .37718 L
.388 .3716 L
.392 .36604 L
.396 .36258 L
.4 .36262 L
Mistroke
.404 .36653 L
.408 .37363 L
.412 .38248 L
.416 .39133 L
.42 .39851 L
.424 .40279 L
.428 .4035 L
.432 .40063 L
.436 .39461 L
.44 .38622 L
.444 .3764 L
.448 .36602 L
.452 .35584 L
.456 .34642 L
.46 .33813 L
.464 .33111 L
.468 .32539 L
.472 .32088 L
.476 .31743 L
.48 .31485 L
.484 .31299 L
.488 .31167 L
.492 .31075 L
.496 .31013 L
.5 .30972 L
.504 .30946 L
.508 .30928 L
.512 .30918 L
.516 .30911 L
.52 .30907 L
.524 .30905 L
.528 .30904 L
.532 .30903 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51489 m
.008 .52125 L
.012 .52345 L
.016 .52135 L
.02 .52063 L
.024 .52126 L
.028 .52156 L
.032 .52133 L
.036 .52125 L
.04 .52128 L
.044 .52134 L
.048 .52133 L
.052 .52133 L
.056 .52129 L
.06 .5213 L
.064 .52133 L
.068 .52136 L
.072 .52131 L
.076 .52128 L
.08 .52129 L
.084 .52135 L
.088 .52136 L
.092 .52131 L
.096 .52124 L
.1 .52129 L
.104 .52138 L
.108 .52139 L
.112 .52129 L
.116 .52122 L
.12 .52126 L
.124 .52137 L
.128 .52143 L
.132 .52136 L
.136 .52122 L
.14 .52118 L
.144 .52128 L
.148 .52144 L
.152 .5215 L
.156 .52137 L
.16 .52115 L
.164 .52105 L
.168 .52121 L
.172 .5215 L
.176 .52168 L
.18 .52153 L
.184 .52113 L
.188 .52083 L
.192 .52092 L
.196 .52137 L
.2 .52183 L
Mistroke
.204 .52193 L
.208 .52157 L
.212 .52099 L
.216 .5206 L
.22 .52063 L
.224 .52104 L
.228 .52161 L
.232 .52207 L
.236 .52225 L
.24 .52209 L
.244 .52156 L
.248 .52076 L
.252 .51995 L
.256 .51946 L
.26 .51963 L
.264 .52055 L
.268 .52199 L
.272 .52351 L
.276 .52463 L
.28 .52507 L
.284 .52479 L
.288 .52385 L
.292 .52231 L
.296 .5201 L
.3 .51712 L
.304 .51334 L
.308 .50888 L
.312 .50402 L
.316 .49908 L
.32 .49425 L
.324 .48951 L
.328 .4847 L
.332 .47964 L
.336 .47423 L
.34 .46857 L
.344 .46288 L
.348 .45738 L
.352 .45223 L
.356 .44738 L
.36 .44264 L
.364 .43777 L
.368 .43257 L
.372 .42698 L
.376 .42111 L
.38 .41517 L
.384 .40942 L
.388 .40405 L
.392 .39912 L
.396 .39457 L
.4 .39018 L
Mistroke
.404 .38572 L
.408 .38095 L
.412 .3757 L
.416 .36993 L
.42 .3637 L
.424 .35717 L
.428 .35056 L
.432 .34409 L
.436 .338 L
.44 .33245 L
.444 .32756 L
.448 .32337 L
.452 .3199 L
.456 .31711 L
.46 .31491 L
.464 .31322 L
.468 .31196 L
.472 .31104 L
.476 .31038 L
.48 .30992 L
.484 .30961 L
.488 .3094 L
.492 .30926 L
.496 .30917 L
.5 .30911 L
.504 .30907 L
.508 .30905 L
.512 .30904 L
.516 .30903 L
.52 .30902 L
.524 .30902 L
.528 .30902 L
.532 .30902 L
.536 .30902 L
.54 .30902 L
.544 .30902 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42858 L
.012 .43007 L
.016 .43037 L
.02 .42962 L
.024 .42955 L
.028 .42975 L
.032 .42975 L
.036 .42956 L
.04 .42953 L
.044 .42951 L
.048 .4295 L
.052 .42943 L
.056 .42937 L
.06 .4293 L
.064 .4293 L
.068 .42928 L
.072 .42922 L
.076 .42909 L
.08 .42908 L
.084 .42912 L
.088 .42909 L
.092 .42895 L
.096 .42885 L
.1 .42886 L
.104 .42892 L
.108 .42888 L
.112 .42874 L
.116 .42859 L
.12 .42859 L
.124 .4287 L
.128 .42872 L
.132 .42858 L
.136 .42838 L
.14 .42827 L
.144 .42835 L
.148 .42851 L
.152 .42854 L
.156 .42833 L
.16 .42802 L
.164 .42785 L
.168 .428 L
.172 .42833 L
.176 .4285 L
.18 .42826 L
.184 .42773 L
.188 .4273 L
.192 .42737 L
.196 .42789 L
.2 .42842 L
Mistroke
.204 .4285 L
.208 .428 L
.212 .42724 L
.216 .42671 L
.22 .4267 L
.224 .42717 L
.228 .42783 L
.232 .42836 L
.236 .42854 L
.24 .42829 L
.244 .42759 L
.248 .42656 L
.252 .42549 L
.256 .42485 L
.26 .42501 L
.264 .42611 L
.268 .42787 L
.272 .42971 L
.276 .43106 L
.28 .43157 L
.284 .43117 L
.288 .42995 L
.292 .42799 L
.296 .42519 L
.3 .42144 L
.304 .41668 L
.308 .41108 L
.312 .40499 L
.316 .39879 L
.32 .39273 L
.324 .38678 L
.328 .38076 L
.332 .37441 L
.336 .36764 L
.34 .36055 L
.344 .35342 L
.348 .34654 L
.352 .34009 L
.356 .33402 L
.36 .32809 L
.364 .32199 L
.368 .31548 L
.372 .30849 L
.376 .30115 L
.38 .29372 L
.384 .28654 L
.388 .27983 L
.392 .27367 L
.396 .26797 L
.4 .26249 L
Mistroke
.404 .25692 L
.408 .25095 L
.412 .2444 L
.416 .23719 L
.42 .22942 L
.424 .22127 L
.428 .21302 L
.432 .20496 L
.436 .19736 L
.44 .19044 L
.444 .18434 L
.448 .17912 L
.452 .1748 L
.456 .17131 L
.46 .16857 L
.464 .16647 L
.468 .1649 L
.472 .16375 L
.476 .16293 L
.48 .16236 L
.484 .16196 L
.488 .1617 L
.492 .16152 L
.496 .16141 L
.5 .16134 L
.504 .16129 L
.508 .16127 L
.512 .16125 L
.516 .16124 L
.52 .16123 L
.524 .16123 L
.528 .16123 L
.532 .16123 L
.536 .16123 L
.54 .16123 L
.544 .16123 L
.548 .16123 L
.552 .16123 L
.556 .16123 L
.56 .16123 L
.564 .16123 L
.568 .16123 L
.572 .16123 L
.576 .16123 L
.58 .16123 L
.584 .16123 L
.588 .16123 L
.592 .16123 L
.596 .16123 L
.6 .16123 L
Mistroke
.604 .16123 L
.608 .16123 L
.612 .16123 L
.616 .16123 L
.62 .16123 L
.624 .16123 L
.628 .16123 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(2839\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29676 m
.008 .29842 L
.012 .29961 L
.016 .2998 L
.02 .2989 L
.024 .29854 L
.028 .29886 L
.032 .29909 L
.036 .29912 L
.04 .299 L
.044 .29876 L
.048 .29876 L
.052 .2991 L
.056 .29918 L
.06 .29881 L
.064 .29858 L
.068 .29888 L
.072 .29924 L
.076 .2991 L
.08 .29859 L
.084 .29844 L
.088 .29899 L
.092 .29948 L
.096 .29903 L
.1 .29821 L
.104 .29832 L
.108 .29926 L
.112 .29962 L
.116 .29889 L
.12 .29808 L
.124 .29818 L
.128 .29906 L
.132 .2997 L
.136 .2993 L
.14 .29828 L
.144 .29779 L
.148 .2983 L
.152 .29937 L
.156 .30002 L
.16 .29947 L
.164 .29801 L
.168 .29697 L
.172 .29758 L
.176 .29965 L
.18 .30133 L
.184 .3006 L
.188 .29763 L
.192 .29515 L
.196 .29579 L
.2 .29948 L
Mistroke
.204 .30304 L
.208 .30298 L
.212 .29899 L
.216 .29442 L
.22 .29311 L
.224 .29614 L
.228 .301 L
.232 .304 L
.236 .30338 L
.24 .30021 L
.244 .29676 L
.248 .29458 L
.252 .2938 L
.256 .29419 L
.26 .29605 L
.264 .29984 L
.268 .3049 L
.272 .30888 L
.276 .30892 L
.28 .3037 L
.284 .29487 L
.288 .28636 L
.292 .28193 L
.296 .28297 L
.3 .28807 L
.304 .29441 L
.308 .30007 L
.312 .30519 L
.316 .31143 L
.32 .3202 L
.324 .33117 L
.328 .34212 L
.332 .35029 L
.336 .35408 L
.34 .35412 L
.344 .35288 L
.348 .35316 L
.352 .35651 L
.356 .36237 L
.36 .36853 L
.364 .37243 L
.368 .37261 L
.372 .36943 L
.376 .36495 L
.38 .36179 L
.384 .36196 L
.388 .36597 L
.392 .37262 L
.396 .37965 L
.4 .38464 L
Mistroke
.404 .38601 L
.408 .38347 L
.412 .37815 L
.416 .37203 L
.42 .36732 L
.424 .36574 L
.428 .3681 L
.432 .37412 L
.436 .38266 L
.44 .39206 L
.444 .40055 L
.448 .40665 L
.452 .40939 L
.456 .40841 L
.46 .40392 L
.464 .39652 L
.468 .38709 L
.472 .37654 L
.476 .36573 L
.48 .35535 L
.484 .34589 L
.488 .33763 L
.492 .33071 L
.496 .32509 L
.5 .32067 L
.504 .3173 L
.508 .31478 L
.512 .31295 L
.516 .31166 L
.52 .31075 L
.524 .31014 L
.528 .30973 L
.532 .30947 L
.536 .30929 L
.54 .30918 L
.544 .30912 L
.548 .30908 L
.552 .30905 L
.556 .30904 L
.56 .30903 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .52223 m
.008 .52091 L
.012 .52061 L
.016 .52122 L
.02 .52129 L
.024 .52098 L
.028 .52101 L
.032 .52111 L
.036 .52113 L
.04 .52104 L
.044 .52106 L
.048 .52109 L
.052 .52111 L
.056 .52106 L
.06 .52106 L
.064 .52108 L
.068 .52111 L
.072 .52108 L
.076 .52106 L
.08 .52105 L
.084 .5211 L
.088 .52112 L
.092 .52108 L
.096 .52102 L
.1 .52105 L
.104 .52112 L
.108 .52114 L
.112 .52106 L
.116 .52101 L
.12 .52104 L
.124 .52113 L
.128 .52116 L
.132 .52109 L
.136 .52099 L
.14 .52099 L
.144 .52109 L
.148 .52119 L
.152 .52117 L
.156 .52105 L
.16 .52093 L
.164 .52095 L
.168 .52111 L
.172 .52127 L
.176 .52126 L
.18 .52105 L
.184 .52081 L
.188 .5208 L
.192 .52106 L
.196 .52139 L
.2 .52148 L
Mistroke
.204 .52121 L
.208 .52077 L
.212 .52054 L
.216 .52074 L
.22 .52122 L
.224 .52163 L
.228 .52167 L
.232 .5213 L
.236 .52078 L
.24 .52042 L
.244 .5204 L
.248 .52071 L
.252 .5212 L
.256 .5217 L
.26 .52204 L
.264 .52205 L
.268 .52162 L
.272 .52079 L
.276 .51984 L
.28 .51916 L
.284 .51914 L
.288 .51988 L
.292 .52119 L
.296 .52267 L
.3 .52389 L
.304 .52461 L
.308 .52475 L
.312 .52435 L
.316 .52335 L
.32 .52166 L
.324 .51913 L
.328 .51573 L
.332 .51159 L
.336 .50699 L
.34 .50225 L
.344 .49756 L
.348 .49292 L
.352 .4882 L
.356 .48321 L
.36 .47786 L
.364 .47224 L
.368 .46655 L
.372 .46102 L
.376 .45582 L
.38 .45093 L
.384 .4462 L
.388 .44138 L
.392 .43628 L
.396 .4308 L
.4 .42499 L
Mistroke
.404 .41905 L
.408 .41322 L
.412 .40771 L
.416 .40263 L
.42 .39795 L
.424 .39353 L
.428 .38914 L
.432 .38453 L
.436 .37953 L
.44 .37401 L
.444 .36801 L
.448 .36162 L
.452 .35503 L
.456 .34846 L
.46 .34213 L
.464 .33624 L
.468 .33094 L
.472 .32631 L
.476 .32238 L
.48 .31913 L
.484 .31653 L
.488 .31449 L
.492 .31293 L
.496 .31176 L
.5 .31091 L
.504 .3103 L
.508 .30987 L
.512 .30958 L
.516 .30938 L
.52 .30925 L
.524 .30916 L
.528 .30911 L
.532 .30907 L
.536 .30905 L
.54 .30904 L
.544 .30903 L
.548 .30902 L
.552 .30902 L
.556 .30902 L
.56 .30902 L
.564 .30902 L
.568 .30902 L
.572 .30902 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42524 L
.012 .4298 L
.016 .4314 L
.02 .4298 L
.024 .42923 L
.028 .42965 L
.032 .42984 L
.036 .42961 L
.04 .42951 L
.044 .42949 L
.048 .4295 L
.052 .42944 L
.056 .42938 L
.06 .4293 L
.064 .42929 L
.068 .42928 L
.072 .42923 L
.076 .42911 L
.08 .42908 L
.084 .4291 L
.088 .42908 L
.092 .42897 L
.096 .42887 L
.1 .42886 L
.104 .4289 L
.108 .42887 L
.112 .42875 L
.116 .42862 L
.12 .42862 L
.124 .42869 L
.128 .42869 L
.132 .42854 L
.136 .42839 L
.14 .42833 L
.144 .42841 L
.148 .42849 L
.152 .42844 L
.156 .42823 L
.16 .42804 L
.164 .42801 L
.168 .42817 L
.172 .42833 L
.176 .42828 L
.18 .42796 L
.184 .42763 L
.188 .42756 L
.192 .42784 L
.196 .42821 L
.2 .42828 L
Mistroke
.204 .42789 L
.208 .42731 L
.212 .42697 L
.216 .42717 L
.22 .42774 L
.224 .42821 L
.228 .4282 L
.232 .4277 L
.236 .427 L
.24 .42652 L
.244 .42645 L
.248 .42678 L
.252 .42735 L
.256 .42793 L
.26 .42831 L
.264 .42828 L
.268 .4277 L
.272 .42662 L
.276 .42539 L
.28 .4245 L
.284 .42443 L
.288 .42531 L
.292 .4269 L
.296 .42869 L
.3 .43017 L
.304 .43102 L
.308 .43116 L
.312 .4306 L
.316 .42932 L
.32 .42717 L
.324 .42397 L
.328 .41969 L
.332 .41448 L
.336 .40871 L
.34 .40277 L
.344 .39688 L
.348 .39106 L
.352 .38514 L
.356 .37888 L
.36 .37218 L
.364 .36514 L
.368 .35801 L
.372 .3511 L
.376 .34458 L
.38 .33846 L
.384 .33253 L
.388 .32651 L
.392 .32013 L
.396 .31327 L
.4 .30601 L
Mistroke
.404 .29858 L
.408 .29129 L
.412 .2844 L
.416 .27805 L
.42 .2722 L
.424 .26668 L
.428 .26119 L
.432 .25543 L
.436 .24918 L
.44 .24229 L
.444 .23479 L
.448 .22682 L
.452 .21859 L
.456 .2104 L
.46 .20251 L
.464 .19517 L
.468 .18855 L
.472 .18278 L
.476 .17788 L
.48 .17384 L
.484 .17059 L
.488 .16805 L
.492 .1661 L
.496 .16465 L
.5 .16359 L
.504 .16283 L
.508 .16229 L
.512 .16193 L
.516 .16168 L
.52 .16151 L
.524 .16141 L
.528 .16134 L
.532 .16129 L
.536 .16127 L
.54 .16125 L
.544 .16124 L
.548 .16123 L
.552 .16123 L
.556 .16123 L
.56 .16123 L
.564 .16123 L
.568 .16123 L
.572 .16123 L
.576 .16123 L
.58 .16123 L
.584 .16123 L
.588 .16123 L
.592 .16123 L
.596 .16123 L
.6 .16123 L
Mistroke
.604 .16123 L
.608 .16123 L
.612 .16123 L
.616 .16123 L
.62 .16123 L
.624 .16123 L
.628 .16123 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(3006\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29942 m
.008 .29976 L
.012 .29872 L
.016 .2986 L
.02 .29929 L
.024 .29928 L
.028 .29879 L
.032 .2988 L
.036 .29916 L
.04 .29917 L
.044 .29886 L
.048 .29878 L
.052 .29904 L
.056 .29918 L
.06 .29897 L
.064 .29871 L
.068 .29881 L
.072 .29915 L
.076 .29921 L
.08 .29879 L
.084 .29848 L
.088 .29888 L
.092 .29944 L
.096 .29916 L
.1 .29838 L
.104 .29836 L
.108 .29917 L
.112 .29957 L
.116 .29898 L
.12 .29822 L
.124 .29829 L
.128 .29911 L
.132 .29966 L
.136 .29917 L
.14 .29823 L
.144 .29799 L
.148 .29871 L
.152 .29956 L
.156 .29968 L
.16 .29888 L
.164 .29785 L
.168 .29765 L
.172 .29863 L
.176 .30001 L
.18 .30041 L
.184 .29908 L
.188 .297 L
.192 .29633 L
.196 .29815 L
.2 .30104 L
Mistroke
.204 .30214 L
.208 .29989 L
.212 .296 L
.216 .2942 L
.22 .29648 L
.224 .30109 L
.228 .30401 L
.232 .30251 L
.236 .29777 L
.24 .29369 L
.244 .29339 L
.248 .29676 L
.252 .30106 L
.256 .30345 L
.26 .30306 L
.264 .30088 L
.268 .29821 L
.272 .29564 L
.276 .29339 L
.28 .29228 L
.284 .2937 L
.288 .29839 L
.292 .30507 L
.296 .31045 L
.3 .31111 L
.304 .30584 L
.308 .29667 L
.312 .28771 L
.316 .28261 L
.32 .28254 L
.324 .28606 L
.328 .2907 L
.332 .29505 L
.336 .29965 L
.34 .30622 L
.344 .31596 L
.348 .32821 L
.352 .34049 L
.356 .34986 L
.36 .35467 L
.364 .35549 L
.368 .35478 L
.372 .35539 L
.376 .35898 L
.38 .36518 L
.384 .37188 L
.388 .37648 L
.392 .37731 L
.396 .37448 L
.4 .36984 L
Mistroke
.404 .36602 L
.408 .36529 L
.412 .36851 L
.416 .37489 L
.42 .38233 L
.424 .38835 L
.428 .39102 L
.432 .38964 L
.436 .38488 L
.44 .37851 L
.444 .37275 L
.448 .36959 L
.452 .37022 L
.456 .37484 L
.46 .38265 L
.464 .39218 L
.468 .40164 L
.472 .40937 L
.476 .41412 L
.48 .41521 L
.484 .41255 L
.488 .40652 L
.492 .39789 L
.496 .38754 L
.5 .37639 L
.504 .36524 L
.508 .35472 L
.512 .34526 L
.516 .33709 L
.52 .33027 L
.524 .32476 L
.528 .32045 L
.532 .31715 L
.536 .31469 L
.54 .31291 L
.544 .31164 L
.548 .31075 L
.552 .31015 L
.556 .30974 L
.56 .30947 L
.564 .3093 L
.568 .30919 L
.572 .30912 L
.576 .30908 L
.58 .30905 L
.584 .30904 L
.588 .30903 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .52749 m
.008 .52084 L
.012 .51866 L
.016 .52081 L
.02 .52159 L
.024 .52084 L
.028 .5206 L
.032 .52083 L
.036 .52094 L
.04 .52083 L
.044 .52081 L
.048 .52084 L
.052 .52087 L
.056 .52083 L
.06 .52083 L
.064 .52083 L
.068 .52086 L
.072 .52085 L
.076 .52083 L
.08 .52081 L
.084 .52085 L
.088 .52087 L
.092 .52085 L
.096 .5208 L
.1 .52081 L
.104 .52087 L
.108 .52089 L
.112 .52083 L
.116 .52079 L
.12 .52081 L
.124 .52088 L
.128 .5209 L
.132 .52085 L
.136 .52077 L
.14 .52078 L
.144 .52087 L
.148 .52093 L
.152 .52089 L
.156 .52079 L
.16 .52073 L
.164 .52079 L
.168 .52091 L
.172 .52098 L
.176 .5209 L
.18 .52074 L
.184 .52065 L
.188 .52074 L
.192 .52096 L
.196 .5211 L
.2 .52099 L
Mistroke
.204 .52071 L
.208 .5205 L
.212 .52059 L
.216 .52093 L
.22 .52124 L
.224 .52123 L
.228 .52087 L
.232 .52044 L
.236 .5203 L
.24 .52056 L
.244 .52103 L
.248 .52139 L
.252 .52139 L
.256 .52107 L
.26 .52061 L
.264 .52026 L
.268 .52016 L
.272 .52034 L
.276 .52077 L
.28 .52133 L
.284 .52182 L
.288 .52199 L
.292 .52166 L
.296 .52083 L
.3 .51979 L
.304 .51897 L
.308 .51876 L
.312 .5193 L
.316 .52042 L
.32 .52178 L
.324 .52303 L
.328 .52396 L
.332 .52447 L
.336 .52453 L
.34 .52406 L
.344 .52288 L
.348 .52083 L
.352 .51785 L
.356 .51407 L
.36 .50978 L
.364 .50527 L
.368 .50075 L
.372 .49624 L
.376 .49162 L
.38 .48672 L
.384 .48146 L
.388 .47589 L
.392 .47021 L
.396 .46466 L
.4 .4594 L
Mistroke
.404 .45446 L
.408 .44972 L
.412 .44496 L
.416 .43996 L
.42 .43459 L
.424 .42887 L
.428 .42295 L
.432 .41706 L
.436 .41142 L
.44 .40618 L
.444 .40136 L
.448 .39687 L
.452 .3925 L
.456 .38802 L
.46 .38323 L
.464 .37797 L
.468 .37221 L
.472 .366 L
.476 .3595 L
.48 .3529 L
.484 .34641 L
.488 .34025 L
.492 .33459 L
.496 .32953 L
.5 .32515 L
.504 .32146 L
.508 .31843 L
.512 .316 L
.516 .31411 L
.52 .31266 L
.524 .31158 L
.528 .31079 L
.532 .31022 L
.536 .30982 L
.54 .30955 L
.544 .30936 L
.548 .30924 L
.552 .30916 L
.556 .3091 L
.56 .30907 L
.564 .30905 L
.568 .30904 L
.572 .30903 L
.576 .30902 L
.58 .30902 L
.584 .30902 L
.588 .30902 L
.592 .30902 L
.596 .30902 L
.6 .30902 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43043 L
.012 .42963 L
.016 .42961 L
.02 .42991 L
.024 .42986 L
.028 .4296 L
.032 .42962 L
.036 .42963 L
.04 .42959 L
.044 .42948 L
.048 .42947 L
.052 .42944 L
.056 .4294 L
.06 .4293 L
.064 .42929 L
.068 .42927 L
.072 .42923 L
.076 .42913 L
.08 .42908 L
.084 .42908 L
.088 .42907 L
.092 .42898 L
.096 .42889 L
.1 .42886 L
.104 .42888 L
.108 .42886 L
.112 .42876 L
.116 .42864 L
.12 .42863 L
.124 .42867 L
.128 .42866 L
.132 .42853 L
.136 .42841 L
.14 .42837 L
.144 .42843 L
.148 .42846 L
.152 .42838 L
.156 .4282 L
.16 .42809 L
.164 .42811 L
.168 .42822 L
.172 .42826 L
.176 .42813 L
.18 .42787 L
.184 .42772 L
.188 .42779 L
.192 .42802 L
.196 .42814 L
.2 .42797 L
Mistroke
.204 .42756 L
.208 .42726 L
.212 .42733 L
.216 .42772 L
.22 .42806 L
.224 .428 L
.228 .4275 L
.232 .42693 L
.236 .42671 L
.24 .42698 L
.244 .42753 L
.248 .42793 L
.252 .42789 L
.256 .42744 L
.26 .42683 L
.264 .42635 L
.268 .42617 L
.272 .42635 L
.276 .42684 L
.28 .4275 L
.284 .42807 L
.288 .42824 L
.292 .42777 L
.296 .4267 L
.3 .42536 L
.304 .4243 L
.308 .42399 L
.312 .42461 L
.316 .42597 L
.32 .42762 L
.324 .42914 L
.328 .43024 L
.332 .43083 L
.336 .43087 L
.34 .43023 L
.344 .42872 L
.348 .42611 L
.352 .42236 L
.356 .41761 L
.36 .41221 L
.364 .40656 L
.368 .40088 L
.372 .39522 L
.376 .38943 L
.38 .38328 L
.384 .37669 L
.388 .36971 L
.392 .3626 L
.396 .35565 L
.4 .34907 L
Mistroke
.404 .34289 L
.408 .33695 L
.412 .33099 L
.416 .32472 L
.42 .31801 L
.424 .31085 L
.428 .30345 L
.432 .29609 L
.436 .28904 L
.44 .28249 L
.444 .27647 L
.448 .27085 L
.452 .26539 L
.456 .25979 L
.46 .2538 L
.464 .24723 L
.468 .24004 L
.472 .23229 L
.476 .22418 L
.48 .21594 L
.484 .20785 L
.488 .20017 L
.492 .1931 L
.496 .1868 L
.5 .18133 L
.504 .17673 L
.508 .17296 L
.512 .16993 L
.516 .16757 L
.52 .16577 L
.524 .16442 L
.528 .16344 L
.532 .16273 L
.536 .16223 L
.54 .16189 L
.544 .16166 L
.548 .1615 L
.552 .1614 L
.556 .16133 L
.56 .16129 L
.564 .16127 L
.568 .16125 L
.572 .16124 L
.576 .16123 L
.58 .16123 L
.584 .16123 L
.588 .16123 L
.592 .16123 L
.596 .16123 L
.6 .16123 L
Mistroke
.604 .16123 L
.608 .16123 L
.612 .16123 L
.616 .16123 L
.62 .16123 L
.624 .16123 L
.628 .16123 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(3173\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30144 m
.008 .2998 L
.012 .29829 L
.016 .29811 L
.02 .29931 L
.024 .29963 L
.028 .29894 L
.032 .29871 L
.036 .29908 L
.04 .29923 L
.044 .299 L
.048 .29885 L
.052 .29897 L
.056 .29914 L
.06 .2991 L
.064 .29885 L
.068 .29878 L
.072 .29906 L
.076 .29927 L
.08 .29896 L
.084 .29856 L
.088 .2988 L
.092 .29937 L
.096 .29926 L
.1 .29857 L
.104 .29841 L
.108 .29906 L
.112 .29951 L
.116 .29909 L
.12 .29838 L
.124 .29835 L
.128 .29908 L
.132 .29961 L
.136 .29916 L
.14 .29828 L
.144 .29814 L
.148 .29891 L
.152 .29961 L
.156 .29945 L
.16 .2986 L
.164 .29793 L
.168 .29818 L
.172 .29916 L
.176 .29991 L
.18 .29962 L
.184 .29837 L
.188 .29726 L
.192 .29758 L
.196 .29936 L
.2 .30093 L
Mistroke
.204 .3005 L
.208 .29805 L
.212 .29578 L
.216 .29623 L
.22 .29945 L
.224 .30249 L
.228 .30225 L
.232 .29852 L
.236 .2945 L
.24 .29398 L
.244 .29765 L
.248 .30242 L
.252 .30428 L
.256 .30174 L
.26 .29696 L
.264 .29365 L
.268 .29388 L
.272 .29693 L
.276 .30045 L
.28 .3026 L
.284 .30302 L
.288 .30209 L
.292 .30001 L
.296 .29671 L
.3 .29285 L
.304 .29032 L
.308 .29137 L
.312 .29686 L
.316 .30488 L
.32 .31144 L
.324 .31281 L
.328 .30788 L
.332 .29886 L
.336 .28984 L
.34 .28421 L
.344 .28297 L
.348 .28473 L
.352 .28745 L
.356 .29022 L
.36 .29396 L
.364 .30048 L
.368 .31084 L
.372 .32414 L
.376 .33768 L
.38 .34835 L
.384 .35435 L
.388 .35614 L
.392 .35609 L
.396 .35708 L
.4 .36095 L
Mistroke
.404 .36751 L
.408 .37481 L
.412 .38022 L
.416 .38186 L
.42 .37956 L
.424 .37491 L
.428 .37051 L
.432 .36882 L
.436 .37111 L
.44 .37699 L
.444 .38463 L
.448 .39156 L
.452 .39558 L
.456 .39553 L
.46 .39166 L
.464 .38538 L
.468 .37885 L
.472 .37421 L
.476 .37306 L
.48 .37601 L
.484 .38269 L
.488 .39188 L
.492 .40191 L
.496 .41099 L
.5 .41765 L
.504 .42088 L
.508 .42026 L
.512 .41595 L
.516 .4085 L
.52 .39875 L
.524 .38761 L
.528 .37597 L
.532 .36458 L
.536 .35399 L
.54 .34456 L
.544 .33649 L
.548 .3298 L
.552 .32441 L
.556 .3202 L
.56 .31699 L
.564 .3146 L
.568 .31285 L
.572 .31161 L
.576 .31074 L
.58 .31014 L
.584 .30974 L
.588 .30948 L
.592 .30931 L
.596 .30919 L
.6 .30912 L
Mistroke
.604 .30908 L
.608 .30906 L
.612 .30904 L
.616 .30903 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .5207 m
.008 .52074 L
.012 .5207 L
.016 .52044 L
.02 .52056 L
.024 .52068 L
.028 .52065 L
.032 .52056 L
.036 .5206 L
.04 .52061 L
.044 .52061 L
.048 .52059 L
.052 .52062 L
.056 .5206 L
.06 .5206 L
.064 .52059 L
.068 .52062 L
.072 .52062 L
.076 .52061 L
.08 .52058 L
.084 .52061 L
.088 .52063 L
.092 .52062 L
.096 .52057 L
.1 .52058 L
.104 .52062 L
.108 .52065 L
.112 .5206 L
.116 .52057 L
.12 .52057 L
.124 .52063 L
.128 .52065 L
.132 .52061 L
.136 .52055 L
.14 .52056 L
.144 .52063 L
.148 .52067 L
.152 .52063 L
.156 .52055 L
.16 .52052 L
.164 .52059 L
.168 .52068 L
.172 .52069 L
.176 .52061 L
.18 .5205 L
.184 .52049 L
.188 .5206 L
.192 .52074 L
.196 .52075 L
.2 .5206 L
Mistroke
.204 .52042 L
.208 .52039 L
.212 .52058 L
.216 .52082 L
.22 .52089 L
.224 .52068 L
.228 .52036 L
.232 .52022 L
.236 .52042 L
.24 .52081 L
.244 .52106 L
.248 .52095 L
.252 .52055 L
.256 .52017 L
.26 .52009 L
.264 .52036 L
.268 .52079 L
.272 .52111 L
.276 .52113 L
.28 .52088 L
.284 .52049 L
.288 .52011 L
.292 .5199 L
.296 .51996 L
.3 .52033 L
.304 .52095 L
.308 .52157 L
.312 .52189 L
.316 .52165 L
.32 .52087 L
.324 .5198 L
.328 .51888 L
.332 .5185 L
.336 .51881 L
.34 .5197 L
.344 .5209 L
.348 .52211 L
.352 .52316 L
.356 .52396 L
.36 .52444 L
.364 .52444 L
.368 .52376 L
.372 .5222 L
.376 .51967 L
.38 .5163 L
.384 .51235 L
.388 .50811 L
.392 .50379 L
.396 .49944 L
.4 .49495 L
Mistroke
.404 .49017 L
.408 .48501 L
.412 .47952 L
.416 .47387 L
.42 .46829 L
.424 .46298 L
.428 .45799 L
.432 .45323 L
.436 .4485 L
.44 .44359 L
.444 .43834 L
.448 .43272 L
.452 .42685 L
.456 .42093 L
.46 .41518 L
.464 .40979 L
.468 .40481 L
.472 .40021 L
.476 .39582 L
.48 .39143 L
.484 .38681 L
.488 .38179 L
.492 .37628 L
.496 .3703 L
.5 .36394 L
.504 .35738 L
.508 .35081 L
.512 .34444 L
.516 .33846 L
.52 .33302 L
.524 .32821 L
.528 .32407 L
.532 .32061 L
.536 .31778 L
.54 .31552 L
.544 .31376 L
.548 .31242 L
.552 .31141 L
.556 .31068 L
.56 .31015 L
.564 .30978 L
.568 .30952 L
.572 .30935 L
.576 .30923 L
.58 .30915 L
.584 .3091 L
.588 .30907 L
.592 .30905 L
.596 .30904 L
.6 .30903 L
Mistroke
.604 .30902 L
.608 .30902 L
.612 .30902 L
.616 .30902 L
.62 .30902 L
.624 .30902 L
.628 .30902 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43472 L
.012 .42986 L
.016 .42825 L
.02 .42976 L
.024 .43029 L
.028 .42968 L
.032 .42948 L
.036 .42959 L
.04 .42964 L
.044 .4295 L
.048 .42945 L
.052 .42943 L
.056 .42941 L
.06 .42931 L
.064 .42928 L
.068 .42926 L
.072 .42923 L
.076 .42914 L
.08 .42909 L
.084 .42907 L
.088 .42906 L
.092 .42899 L
.096 .42891 L
.1 .42886 L
.104 .42887 L
.108 .42885 L
.112 .42877 L
.116 .42866 L
.12 .42863 L
.124 .42866 L
.128 .42865 L
.132 .42853 L
.136 .42842 L
.14 .42839 L
.144 .42843 L
.148 .42844 L
.152 .42835 L
.156 .4282 L
.16 .42813 L
.164 .42816 L
.168 .42823 L
.172 .4282 L
.176 .42805 L
.18 .42787 L
.184 .42782 L
.188 .42791 L
.192 .42803 L
.196 .42801 L
.2 .42778 L
Mistroke
.204 .42751 L
.208 .42743 L
.212 .42761 L
.216 .42787 L
.22 .42791 L
.224 .4276 L
.228 .42716 L
.232 .42695 L
.236 .42715 L
.24 .42759 L
.244 .42785 L
.248 .42767 L
.252 .42713 L
.256 .42661 L
.26 .42647 L
.264 .42677 L
.268 .42726 L
.272 .42761 L
.276 .42759 L
.28 .42724 L
.284 .4267 L
.288 .42619 L
.292 .42588 L
.296 .42591 L
.3 .42633 L
.304 .42705 L
.308 .42779 L
.312 .42813 L
.316 .4278 L
.32 .42678 L
.324 .4254 L
.328 .42421 L
.332 .42369 L
.336 .42404 L
.34 .42511 L
.344 .42655 L
.348 .42802 L
.352 .42928 L
.356 .43024 L
.36 .43078 L
.364 .43074 L
.368 .42985 L
.372 .42785 L
.376 .42466 L
.38 .42042 L
.384 .41545 L
.388 .41013 L
.392 .4047 L
.396 .39924 L
.4 .39361 L
Mistroke
.404 .38761 L
.408 .38114 L
.412 .37426 L
.416 .36718 L
.42 .3602 L
.424 .35355 L
.428 .3473 L
.432 .34134 L
.436 .33542 L
.44 .32927 L
.444 .3227 L
.448 .31567 L
.452 .30833 L
.456 .30093 L
.46 .29374 L
.464 .287 L
.468 .28078 L
.472 .27503 L
.476 .26954 L
.48 .26404 L
.484 .25827 L
.488 .252 L
.492 .24513 L
.496 .23766 L
.5 .22972 L
.504 .22153 L
.508 .21333 L
.512 .20539 L
.516 .19794 L
.52 .19115 L
.524 .18515 L
.528 .17999 L
.532 .17567 L
.536 .17215 L
.54 .16933 L
.544 .16714 L
.548 .16546 L
.552 .16421 L
.556 .1633 L
.56 .16264 L
.564 .16218 L
.568 .16185 L
.572 .16164 L
.576 .16149 L
.58 .16139 L
.584 .16133 L
.588 .16129 L
.592 .16127 L
.596 .16125 L
.6 .16124 L
Mistroke
.604 .16123 L
.608 .16123 L
.612 .16123 L
.616 .16123 L
.62 .16123 L
.624 .16123 L
.628 .16123 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(3340\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .2992 m
.008 .29852 L
.012 .29921 L
.016 .29931 L
.02 .29895 L
.024 .299 L
.028 .29918 L
.032 .29909 L
.036 .29899 L
.04 .29908 L
.044 .29913 L
.048 .299 L
.052 .29894 L
.056 .29908 L
.06 .29918 L
.064 .29899 L
.068 .2988 L
.072 .29899 L
.076 .29929 L
.08 .2991 L
.084 .29867 L
.088 .29876 L
.092 .29929 L
.096 .29932 L
.1 .29875 L
.104 .29849 L
.108 .29897 L
.112 .29944 L
.116 .2992 L
.12 .29855 L
.124 .29841 L
.128 .29902 L
.132 .29957 L
.136 .2992 L
.14 .29838 L
.144 .29825 L
.148 .29899 L
.152 .2996 L
.156 .29934 L
.16 .29851 L
.164 .29807 L
.168 .29853 L
.172 .2994 L
.176 .29972 L
.18 .29912 L
.184 .29814 L
.188 .29773 L
.192 .29845 L
.196 .29976 L
.2 .30032 L
Mistroke
.204 .29932 L
.208 .29748 L
.212 .29666 L
.216 .29803 L
.22 .30059 L
.224 .3017 L
.228 .29987 L
.232 .29652 L
.236 .29489 L
.24 .29695 L
.244 .3011 L
.248 .30347 L
.252 .30162 L
.256 .29695 L
.26 .29353 L
.264 .29439 L
.268 .29884 L
.272 .30317 L
.276 .30403 L
.28 .30106 L
.284 .29676 L
.288 .29411 L
.292 .29431 L
.296 .29655 L
.3 .29931 L
.304 .30166 L
.308 .30327 L
.312 .30366 L
.316 .30197 L
.32 .29779 L
.324 .29235 L
.328 .28851 L
.332 .2892 L
.336 .29522 L
.34 .30422 L
.344 .31176 L
.348 .31393 L
.352 .3097 L
.356 .30129 L
.36 .29257 L
.364 .28664 L
.368 .28428 L
.372 .28425 L
.376 .28491 L
.38 .28586 L
.384 .28839 L
.388 .29443 L
.392 .30501 L
.396 .31906 L
.4 .33373 L
Mistroke
.404 .34573 L
.408 .35305 L
.412 .35596 L
.416 .35669 L
.42 .35816 L
.424 .36233 L
.428 .36928 L
.432 .37722 L
.436 .38355 L
.44 .38617 L
.444 .3846 L
.448 .38012 L
.452 .37525 L
.456 .37261 L
.46 .37384 L
.464 .379 L
.468 .38661 L
.472 .39427 L
.476 .3996 L
.48 .40104 L
.484 .39832 L
.488 .3925 L
.492 .38553 L
.496 .37963 L
.5 .3767 L
.504 .37781 L
.508 .383 L
.512 .39142 L
.516 .40156 L
.52 .41163 L
.524 .41997 L
.528 .42529 L
.532 .42688 L
.536 .42456 L
.54 .41867 L
.544 .40991 L
.548 .39917 L
.552 .38736 L
.556 .37533 L
.56 .36376 L
.564 .35315 L
.568 .34381 L
.572 .33586 L
.576 .3293 L
.58 .32405 L
.584 .31995 L
.588 .31682 L
.592 .31449 L
.596 .31279 L
.6 .31158 L
Mistroke
.604 .31073 L
.608 .31014 L
.612 .30974 L
.616 .30948 L
.62 .30931 L
.624 .3092 L
.628 .30913 L
.632 .30908 L
.636 .30906 L
.64 .30904 L
.644 .30903 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51379 m
.008 .52036 L
.012 .5226 L
.016 .52035 L
.02 .51964 L
.024 .52035 L
.028 .52063 L
.032 .52036 L
.036 .5203 L
.04 .52036 L
.044 .5204 L
.048 .52036 L
.052 .52037 L
.056 .52037 L
.06 .52038 L
.064 .52035 L
.068 .52037 L
.072 .52038 L
.076 .52038 L
.08 .52035 L
.084 .52036 L
.088 .52039 L
.092 .52039 L
.096 .52035 L
.1 .52035 L
.104 .52037 L
.108 .5204 L
.112 .52037 L
.116 .52034 L
.12 .52034 L
.124 .52039 L
.128 .52041 L
.132 .52038 L
.136 .52032 L
.14 .52033 L
.144 .52039 L
.148 .52042 L
.152 .52038 L
.156 .52032 L
.16 .52031 L
.164 .52037 L
.168 .52043 L
.172 .52042 L
.176 .52034 L
.18 .52028 L
.184 .52031 L
.188 .5204 L
.192 .52047 L
.196 .52044 L
.2 .52031 L
Mistroke
.204 .52023 L
.208 .52028 L
.212 .52044 L
.216 .52055 L
.22 .52049 L
.224 .52028 L
.228 .52012 L
.232 .52018 L
.236 .52044 L
.24 .52067 L
.244 .52063 L
.248 .52034 L
.252 .52003 L
.256 .51999 L
.26 .52027 L
.264 .52065 L
.268 .52083 L
.272 .52065 L
.276 .52026 L
.28 .51993 L
.284 .51989 L
.288 .52014 L
.292 .52051 L
.296 .52081 L
.3 .52089 L
.304 .52073 L
.308 .52038 L
.312 .51996 L
.316 .51963 L
.32 .51958 L
.324 .5199 L
.328 .52056 L
.332 .52128 L
.336 .52172 L
.34 .52161 L
.344 .5209 L
.348 .51985 L
.352 .51887 L
.356 .51834 L
.36 .51843 L
.364 .51907 L
.368 .52005 L
.372 .52117 L
.376 .52227 L
.38 .52328 L
.384 .52409 L
.388 .52452 L
.392 .52431 L
.396 .52324 L
.4 .5212 L
Mistroke
.404 .51827 L
.408 .51469 L
.412 .51075 L
.416 .50667 L
.42 .5025 L
.424 .49817 L
.428 .49354 L
.432 .4885 L
.436 .48311 L
.44 .4775 L
.444 .47192 L
.448 .46656 L
.452 .46151 L
.456 .45672 L
.46 .45201 L
.464 .44718 L
.468 .44205 L
.472 .43655 L
.476 .43075 L
.48 .42482 L
.484 .41899 L
.488 .41345 L
.492 .40831 L
.496 .40358 L
.5 .39912 L
.504 .39477 L
.508 .39028 L
.512 .38548 L
.516 .38023 L
.52 .37449 L
.524 .36832 L
.528 .36185 L
.532 .35527 L
.536 .34876 L
.54 .34254 L
.544 .33676 L
.548 .33155 L
.552 .32698 L
.556 .32308 L
.56 .31982 L
.564 .31718 L
.568 .31507 L
.572 .31344 L
.576 .31219 L
.58 .31126 L
.584 .31057 L
.588 .31008 L
.592 .30974 L
.596 .30949 L
.6 .30933 L
Mistroke
.604 .30922 L
.608 .30915 L
.612 .3091 L
.616 .30907 L
.62 .30905 L
.624 .30904 L
.628 .30903 L
.632 .30902 L
.636 .30902 L
.64 .30902 L
.644 .30902 L
.648 .30902 L
.652 .30902 L
.656 .30902 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43032 L
.012 .43007 L
.016 .42979 L
.02 .42962 L
.024 .42975 L
.028 .42975 L
.032 .42967 L
.036 .42956 L
.04 .42957 L
.044 .42951 L
.048 .42948 L
.052 .42942 L
.056 .4294 L
.06 .42932 L
.064 .42929 L
.068 .42925 L
.072 .42923 L
.076 .42915 L
.08 .4291 L
.084 .42906 L
.088 .42905 L
.092 .42899 L
.096 .42892 L
.1 .42886 L
.104 .42885 L
.108 .42884 L
.112 .42877 L
.116 .42867 L
.12 .42863 L
.124 .42865 L
.128 .42863 L
.132 .42854 L
.136 .42844 L
.14 .4284 L
.144 .42843 L
.148 .42842 L
.152 .42834 L
.156 .42821 L
.16 .42815 L
.164 .42818 L
.168 .42822 L
.172 .42816 L
.176 .42802 L
.18 .4279 L
.184 .42788 L
.188 .42796 L
.192 .428 L
.196 .42791 L
.2 .42771 L
Mistroke
.204 .42756 L
.208 .42758 L
.212 .42773 L
.216 .42783 L
.22 .42771 L
.224 .42741 L
.228 .42716 L
.232 .42719 L
.236 .42747 L
.24 .42771 L
.244 .42762 L
.248 .42721 L
.252 .42678 L
.256 .42668 L
.26 .42699 L
.264 .42742 L
.268 .4276 L
.272 .42734 L
.276 .4268 L
.28 .42635 L
.284 .42625 L
.288 .42652 L
.292 .42694 L
.296 .42727 L
.3 .42732 L
.304 .42707 L
.308 .42659 L
.312 .42603 L
.316 .42558 L
.32 .42547 L
.324 .42583 L
.328 .4266 L
.332 .42746 L
.336 .42796 L
.34 .42777 L
.344 .42684 L
.348 .42549 L
.352 .42423 L
.356 .42353 L
.36 .4236 L
.364 .42435 L
.368 .42553 L
.372 .42687 L
.376 .4282 L
.38 .42941 L
.384 .43038 L
.388 .43087 L
.392 .43057 L
.396 .42919 L
.4 .42659 L
Mistroke
.404 .4229 L
.408 .41839 L
.412 .41345 L
.416 .40832 L
.42 .40309 L
.424 .39765 L
.428 .39183 L
.432 .38552 L
.436 .37876 L
.44 .37174 L
.444 .36475 L
.448 .35803 L
.452 .35171 L
.456 .34571 L
.46 .33982 L
.464 .33377 L
.468 .32734 L
.472 .32046 L
.476 .3132 L
.48 .30579 L
.484 .29851 L
.488 .29158 L
.492 .28516 L
.496 .27924 L
.5 .27367 L
.504 .26822 L
.508 .26261 L
.512 .25661 L
.516 .25005 L
.52 .24289 L
.524 .23519 L
.528 .22711 L
.532 .2189 L
.536 .21078 L
.54 .20302 L
.544 .19582 L
.548 .18932 L
.552 .18362 L
.556 .17875 L
.56 .1747 L
.564 .1714 L
.568 .16877 L
.572 .16673 L
.576 .16518 L
.58 .16402 L
.584 .16317 L
.588 .16255 L
.592 .16212 L
.596 .16182 L
.6 .16162 L
Mistroke
.604 .16148 L
.608 .16139 L
.612 .16133 L
.616 .16129 L
.62 .16126 L
.624 .16125 L
.628 .16124 L
.632 .16123 L
.636 .16123 L
.64 .16123 L
.644 .16123 L
.648 .16123 L
.652 .16123 L
.656 .16123 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(3507\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29682 m
.008 .29831 L
.012 .29991 L
.016 .30011 L
.02 .29887 L
.024 .29856 L
.028 .29922 L
.032 .29937 L
.036 .29904 L
.04 .29898 L
.044 .29917 L
.048 .29913 L
.052 .29896 L
.056 .29904 L
.06 .29922 L
.064 .29911 L
.068 .29885 L
.072 .29895 L
.076 .29927 L
.08 .2992 L
.084 .29879 L
.088 .29877 L
.092 .29921 L
.096 .29935 L
.1 .29892 L
.104 .2986 L
.108 .29889 L
.112 .29936 L
.116 .29929 L
.12 .29872 L
.124 .29847 L
.128 .29896 L
.132 .29952 L
.136 .29927 L
.14 .29851 L
.144 .29834 L
.148 .299 L
.152 .29957 L
.156 .2993 L
.16 .29853 L
.164 .2982 L
.168 .29873 L
.172 .29949 L
.176 .29957 L
.18 .29886 L
.184 .29813 L
.188 .29814 L
.192 .29895 L
.196 .29979 L
.2 .29974 L
Mistroke
.204 .29868 L
.208 .29757 L
.212 .29761 L
.216 .29905 L
.22 .3006 L
.224 .30048 L
.228 .29844 L
.232 .29635 L
.236 .29652 L
.24 .29919 L
.244 .30194 L
.248 .30183 L
.252 .29855 L
.256 .29502 L
.26 .29472 L
.264 .29827 L
.268 .30261 L
.272 .30375 L
.276 .30053 L
.28 .29565 L
.284 .2932 L
.288 .29512 L
.292 .29969 L
.296 .3033 L
.3 .30353 L
.304 .30073 L
.308 .29715 L
.312 .29486 L
.316 .29452 L
.32 .29568 L
.324 .29784 L
.328 .30072 L
.332 .30372 L
.336 .30539 L
.34 .30397 L
.344 .29891 L
.348 .29203 L
.352 .28701 L
.356 .28724 L
.36 .29349 L
.364 .30309 L
.368 .31137 L
.372 .3144 L
.376 .31117 L
.38 .30376 L
.384 .29572 L
.388 .28975 L
.392 .28646 L
.396 .28472 L
.4 .28329 L
Mistroke
.404 .28224 L
.408 .2832 L
.412 .28832 L
.416 .29866 L
.42 .31311 L
.424 .3287 L
.428 .34199 L
.432 .35071 L
.436 .35487 L
.44 .35651 L
.444 .35853 L
.448 .36305 L
.452 .3704 L
.456 .37903 L
.46 .38636 L
.464 .39013 L
.468 .38949 L
.472 .38541 L
.476 .38024 L
.48 .37669 L
.484 .37678 L
.488 .38101 L
.492 .38832 L
.496 .39649 L
.5 .40303 L
.504 .40602 L
.508 .40472 L
.512 .39971 L
.516 .39267 L
.52 .38581 L
.524 .38123 L
.528 .38039 L
.532 .38382 L
.536 .39104 L
.54 .40081 L
.544 .41143 L
.548 .42114 L
.552 .42842 L
.556 .43224 L
.56 .43212 L
.564 .42812 L
.568 .42075 L
.572 .41081 L
.576 .3992 L
.58 .38683 L
.584 .3745 L
.588 .36283 L
.592 .35225 L
.596 .34301 L
.6 .3352 L
Mistroke
.604 .32879 L
.608 .32367 L
.612 .31968 L
.616 .31664 L
.62 .31438 L
.624 .31272 L
.628 .31154 L
.632 .31071 L
.636 .31013 L
.64 .30974 L
.644 .30948 L
.648 .30931 L
.652 .3092 L
.656 .30913 L
.66 .30909 L
.664 .30906 L
.668 .30904 L
.672 .30903 L
.676 .30903 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51887 m
.008 .51996 L
.012 .52048 L
.016 .52027 L
.02 .52007 L
.024 .52004 L
.028 .52016 L
.032 .52016 L
.036 .52014 L
.04 .52011 L
.044 .52014 L
.048 .52013 L
.052 .52014 L
.056 .52013 L
.06 .52014 L
.064 .52012 L
.068 .52014 L
.072 .52014 L
.076 .52014 L
.08 .52012 L
.084 .52013 L
.088 .52014 L
.092 .52015 L
.096 .52012 L
.1 .52012 L
.104 .52013 L
.108 .52016 L
.112 .52014 L
.116 .52012 L
.12 .52011 L
.124 .52014 L
.128 .52017 L
.132 .52015 L
.136 .5201 L
.14 .5201 L
.144 .52015 L
.148 .52018 L
.152 .52014 L
.156 .5201 L
.16 .52009 L
.164 .52014 L
.168 .52019 L
.172 .52017 L
.176 .5201 L
.18 .52007 L
.184 .5201 L
.188 .52018 L
.192 .52021 L
.196 .52015 L
.2 .52006 L
Mistroke
.204 .52004 L
.208 .52011 L
.212 .52022 L
.216 .52025 L
.22 .52015 L
.224 .52001 L
.228 .51997 L
.232 .5201 L
.236 .52028 L
.24 .52034 L
.244 .52019 L
.248 .51995 L
.252 .51985 L
.256 .52001 L
.26 .52031 L
.264 .52047 L
.268 .52034 L
.272 .52001 L
.276 .51975 L
.28 .51979 L
.284 .5201 L
.288 .52045 L
.292 .52057 L
.296 .52037 L
.3 .52001 L
.304 .51973 L
.308 .51968 L
.312 .51988 L
.316 .52021 L
.32 .52051 L
.324 .52066 L
.328 .52059 L
.332 .52028 L
.336 .51981 L
.34 .51938 L
.344 .51922 L
.348 .51949 L
.352 .52016 L
.356 .52095 L
.36 .5215 L
.364 .5215 L
.368 .5209 L
.372 .51992 L
.376 .51893 L
.38 .51828 L
.384 .51816 L
.388 .51854 L
.392 .51928 L
.396 .52024 L
.4 .52132 L
Mistroke
.404 .52246 L
.408 .52353 L
.412 .52432 L
.416 .52456 L
.42 .52397 L
.424 .52241 L
.428 .51994 L
.432 .51677 L
.436 .51317 L
.44 .50936 L
.444 .50541 L
.448 .50127 L
.452 .4968 L
.456 .49192 L
.46 .48665 L
.464 .48111 L
.468 .47554 L
.472 .47013 L
.476 .46502 L
.48 .46019 L
.484 .4555 L
.488 .45073 L
.492 .44571 L
.496 .44033 L
.5 .43463 L
.504 .42873 L
.508 .42284 L
.512 .41718 L
.516 .41188 L
.52 .40698 L
.524 .40243 L
.528 .39806 L
.532 .39367 L
.536 .38905 L
.54 .38403 L
.544 .37855 L
.548 .37261 L
.552 .36629 L
.556 .35975 L
.56 .35318 L
.564 .34678 L
.568 .34072 L
.572 .33515 L
.576 .33017 L
.58 .32584 L
.584 .32215 L
.588 .3191 L
.592 .31662 L
.596 .31466 L
.6 .31314 L
Mistroke
.604 .31198 L
.608 .31111 L
.612 .31048 L
.616 .31002 L
.62 .30969 L
.624 .30947 L
.628 .30931 L
.632 .30921 L
.636 .30914 L
.64 .3091 L
.644 .30907 L
.648 .30905 L
.652 .30904 L
.656 .30903 L
.66 .30902 L
.664 .30902 L
.668 .30902 L
.672 .30902 L
.676 .30902 L
.68 .30902 L
.684 .30902 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42524 L
.012 .42988 L
.016 .43143 L
.02 .42975 L
.024 .42922 L
.028 .42968 L
.032 .42984 L
.036 .4296 L
.04 .42951 L
.044 .4295 L
.048 .4295 L
.052 .42942 L
.056 .42939 L
.06 .42932 L
.064 .42929 L
.068 .42924 L
.072 .42922 L
.076 .42916 L
.08 .42911 L
.084 .42906 L
.088 .42904 L
.092 .429 L
.096 .42893 L
.1 .42886 L
.104 .42885 L
.108 .42883 L
.112 .42878 L
.116 .42868 L
.12 .42864 L
.124 .42864 L
.128 .42862 L
.132 .42854 L
.136 .42845 L
.14 .42841 L
.144 .42842 L
.148 .42841 L
.152 .42833 L
.156 .42822 L
.16 .42817 L
.164 .42819 L
.168 .4282 L
.172 .42813 L
.176 .42801 L
.18 .42792 L
.184 .42792 L
.188 .42797 L
.192 .42796 L
.196 .42785 L
.2 .4277 L
Mistroke
.204 .42762 L
.208 .42766 L
.212 .42776 L
.216 .42775 L
.22 .42758 L
.224 .42736 L
.228 .42727 L
.232 .42738 L
.236 .42757 L
.24 .4276 L
.244 .42737 L
.248 .42702 L
.252 .42685 L
.256 .42701 L
.26 .42733 L
.264 .4275 L
.268 .42729 L
.272 .42683 L
.276 .42646 L
.28 .42646 L
.284 .42682 L
.288 .42721 L
.292 .42731 L
.296 .42702 L
.3 .42652 L
.304 .42612 L
.308 .42602 L
.312 .42622 L
.316 .42659 L
.32 .42692 L
.324 .42707 L
.328 .42693 L
.332 .4265 L
.336 .42587 L
.34 .42529 L
.344 .42505 L
.348 .42534 L
.352 .42613 L
.356 .42708 L
.36 .42772 L
.364 .42767 L
.368 .42688 L
.372 .42561 L
.376 .42433 L
.38 .42348 L
.384 .42329 L
.388 .42372 L
.392 .4246 L
.396 .42575 L
.4 .42705 L
Mistroke
.404 .42842 L
.408 .42971 L
.412 .43066 L
.416 .4309 L
.42 .43012 L
.424 .42814 L
.428 .42501 L
.432 .42102 L
.436 .41649 L
.44 .4117 L
.444 .40673 L
.448 .40153 L
.452 .39593 L
.456 .38981 L
.46 .3832 L
.464 .37626 L
.468 .36928 L
.472 .36251 L
.476 .35611 L
.48 .35006 L
.484 .34418 L
.488 .33821 L
.492 .33192 L
.496 .32519 L
.5 .31806 L
.504 .31068 L
.508 .30332 L
.512 .29624 L
.516 .28961 L
.52 .2835 L
.524 .2778 L
.528 .27234 L
.532 .26685 L
.536 .26107 L
.54 .2548 L
.544 .24796 L
.548 .24054 L
.552 .23265 L
.556 .22449 L
.56 .2163 L
.564 .20831 L
.568 .20075 L
.572 .19381 L
.576 .1876 L
.58 .18219 L
.584 .1776 L
.588 .17379 L
.592 .17071 L
.596 .16826 L
.6 .16636 L
Mistroke
.604 .16492 L
.608 .16384 L
.612 .16305 L
.616 .16247 L
.62 .16207 L
.624 .16179 L
.628 .1616 L
.632 .16147 L
.636 .16138 L
.64 .16132 L
.644 .16129 L
.648 .16126 L
.652 .16125 L
.656 .16124 L
.66 .16123 L
.664 .16123 L
.668 .16123 L
.672 .16123 L
.676 .16123 L
.68 .16123 L
.684 .16123 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(3674\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29867 m
.008 .2996 L
.012 .29922 L
.016 .29914 L
.02 .29924 L
.024 .29915 L
.028 .2991 L
.032 .29916 L
.036 .29914 L
.04 .29911 L
.044 .29918 L
.048 .29915 L
.052 .29902 L
.056 .29905 L
.06 .29924 L
.064 .29918 L
.068 .29893 L
.072 .29895 L
.076 .29924 L
.08 .29926 L
.084 .29892 L
.088 .29881 L
.092 .29913 L
.096 .29934 L
.1 .29907 L
.104 .29873 L
.108 .29885 L
.112 .29927 L
.116 .29935 L
.12 .29889 L
.124 .29855 L
.128 .29889 L
.132 .29946 L
.136 .29933 L
.14 .29866 L
.144 .29842 L
.148 .29898 L
.152 .29953 L
.156 .29932 L
.16 .2986 L
.164 .2983 L
.168 .29883 L
.172 .29952 L
.176 .29948 L
.18 .29875 L
.184 .2982 L
.188 .29844 L
.192 .29921 L
.196 .2997 L
.2 .29934 L
Mistroke
.204 .29841 L
.208 .29786 L
.212 .29833 L
.216 .2995 L
.22 .30022 L
.224 .29954 L
.228 .2979 L
.232 .29695 L
.236 .29793 L
.24 .30014 L
.244 .30136 L
.248 .29999 L
.252 .29706 L
.256 .29548 L
.26 .29714 L
.264 .30077 L
.268 .3029 L
.272 .30118 L
.276 .29691 L
.28 .29399 L
.284 .29525 L
.288 .29976 L
.292 .30361 L
.296 .30343 L
.3 .29939 L
.304 .29486 L
.308 .29339 L
.312 .29582 L
.316 .30002 L
.32 .30294 L
.324 .30303 L
.328 .30086 L
.332 .29802 L
.336 .29573 L
.34 .29445 L
.344 .29445 L
.348 .29619 L
.352 .29981 L
.356 .30425 L
.36 .30711 L
.364 .30593 L
.368 .30013 L
.372 .29203 L
.376 .28595 L
.38 .28558 L
.384 .2917 L
.388 .30151 L
.392 .31029 L
.396 .31419 L
.4 .31216 L
Mistroke
.404 .30607 L
.408 .29905 L
.412 .29338 L
.416 .28943 L
.42 .28619 L
.424 .28273 L
.428 .27955 L
.432 .27865 L
.436 .28242 L
.44 .29204 L
.444 .30648 L
.448 .32273 L
.452 .33718 L
.456 .34731 L
.46 .35281 L
.464 .35546 L
.468 .3581 L
.472 .36301 L
.476 .37079 L
.48 .38013 L
.484 .38854 L
.488 .3936 L
.492 .39411 L
.496 .39068 L
.5 .38542 L
.504 .38108 L
.508 .37999 L
.512 .38312 L
.516 .38986 L
.52 .39828 L
.524 .40586 L
.528 .41041 L
.532 .41069 L
.536 .40683 L
.54 .40013 L
.544 .39266 L
.548 .38665 L
.552 .38388 L
.556 .38533 L
.56 .39098 L
.564 .39991 L
.568 .41061 L
.572 .4213 L
.576 .43029 L
.58 .43627 L
.584 .43845 L
.588 .4366 L
.592 .43099 L
.596 .42225 L
.6 .41124 L
Mistroke
.604 .39888 L
.608 .38606 L
.612 .37351 L
.616 .36179 L
.62 .35128 L
.624 .34217 L
.628 .33452 L
.632 .32826 L
.636 .32328 L
.64 .3194 L
.644 .31645 L
.648 .31425 L
.652 .31265 L
.656 .3115 L
.66 .31069 L
.664 .31012 L
.668 .30974 L
.672 .30948 L
.676 .30931 L
.68 .3092 L
.684 .30913 L
.688 .30909 L
.692 .30906 L
.696 .30904 L
.7 .30903 L
.704 .30903 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .52627 m
.008 .51984 L
.012 .51777 L
.016 .51992 L
.02 .52064 L
.024 .51987 L
.028 .51966 L
.032 .51989 L
.036 .51999 L
.04 .51989 L
.044 .51988 L
.048 .51989 L
.052 .51992 L
.056 .5199 L
.06 .5199 L
.064 .51989 L
.068 .5199 L
.072 .5199 L
.076 .51991 L
.08 .51989 L
.084 .51989 L
.088 .5199 L
.092 .51992 L
.096 .51989 L
.1 .51989 L
.104 .51989 L
.108 .51992 L
.112 .51991 L
.116 .51989 L
.12 .51987 L
.124 .5199 L
.128 .51992 L
.132 .51991 L
.136 .51987 L
.14 .51987 L
.144 .51991 L
.148 .51993 L
.152 .51991 L
.156 .51987 L
.16 .51986 L
.164 .5199 L
.168 .51994 L
.172 .51992 L
.176 .51987 L
.18 .51985 L
.184 .51988 L
.188 .51994 L
.192 .51995 L
.196 .5199 L
.2 .51983 L
Mistroke
.204 .51984 L
.208 .51991 L
.212 .51998 L
.216 .51996 L
.22 .51987 L
.224 .51979 L
.228 .51981 L
.232 .51993 L
.236 .52003 L
.24 .52 L
.244 .51985 L
.248 .51971 L
.252 .51975 L
.256 .51994 L
.26 .52012 L
.264 .52009 L
.268 .51987 L
.272 .51963 L
.276 .51962 L
.28 .51986 L
.284 .52015 L
.288 .52024 L
.292 .52004 L
.296 .5197 L
.3 .5195 L
.304 .5196 L
.308 .51992 L
.312 .52022 L
.316 .5203 L
.32 .52012 L
.324 .5198 L
.328 .51954 L
.332 .51946 L
.336 .51959 L
.34 .51988 L
.344 .52021 L
.348 .52044 L
.352 .52045 L
.356 .52018 L
.36 .51967 L
.364 .51915 L
.368 .51889 L
.372 .5191 L
.376 .51975 L
.38 .52058 L
.384 .52122 L
.388 .52135 L
.392 .52088 L
.396 .51999 L
.4 .51903 L
Mistroke
.404 .51831 L
.408 .518 L
.412 .51812 L
.416 .5186 L
.42 .51937 L
.424 .52036 L
.428 .52154 L
.432 .52279 L
.436 .52389 L
.44 .52451 L
.444 .52438 L
.448 .52331 L
.452 .52132 L
.456 .51858 L
.46 .51535 L
.464 .51183 L
.468 .50813 L
.472 .50421 L
.476 .49995 L
.48 .49525 L
.484 .49012 L
.488 .48468 L
.492 .47913 L
.496 .4737 L
.5 .46854 L
.504 .46365 L
.508 .45895 L
.512 .45424 L
.516 .44932 L
.52 .44407 L
.524 .43848 L
.528 .43263 L
.532 .42672 L
.536 .42096 L
.54 .4155 L
.544 .41045 L
.548 .40576 L
.552 .40134 L
.556 .39699 L
.56 .39251 L
.564 .38771 L
.568 .38248 L
.572 .37678 L
.576 .37065 L
.58 .36422 L
.584 .35766 L
.588 .35114 L
.592 .34486 L
.596 .33898 L
.6 .33363 L
Mistroke
.604 .32887 L
.608 .32476 L
.612 .32129 L
.616 .31843 L
.62 .31611 L
.624 .31428 L
.628 .31286 L
.632 .31178 L
.636 .31098 L
.64 .31039 L
.644 .30996 L
.648 .30966 L
.652 .30945 L
.656 .3093 L
.66 .3092 L
.664 .30914 L
.668 .30909 L
.672 .30906 L
.676 .30905 L
.68 .30903 L
.684 .30903 L
.688 .30902 L
.692 .30902 L
.696 .30902 L
.7 .30902 L
.704 .30902 L
.708 .30902 L
.712 .30902 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42869 L
.012 .42964 L
.016 .43019 L
.02 .42991 L
.024 .42966 L
.028 .4296 L
.032 .42968 L
.036 .42963 L
.04 .42957 L
.044 .42949 L
.048 .42948 L
.052 .42943 L
.056 .4294 L
.06 .42933 L
.064 .42929 L
.068 .42924 L
.072 .42922 L
.076 .42916 L
.08 .42911 L
.084 .42905 L
.088 .42903 L
.092 .42899 L
.096 .42894 L
.1 .42887 L
.104 .42884 L
.108 .42882 L
.112 .42878 L
.116 .4287 L
.12 .42864 L
.124 .42863 L
.128 .42862 L
.132 .42855 L
.136 .42847 L
.14 .42841 L
.144 .42841 L
.148 .4284 L
.152 .42833 L
.156 .42823 L
.16 .42818 L
.164 .42819 L
.168 .42819 L
.172 .42812 L
.176 .42801 L
.18 .42794 L
.184 .42794 L
.188 .42797 L
.192 .42794 L
.196 .42782 L
.2 .42771 L
Mistroke
.204 .42766 L
.208 .42771 L
.212 .42775 L
.216 .42769 L
.22 .42753 L
.224 .42738 L
.228 .42737 L
.232 .42747 L
.236 .42755 L
.24 .42747 L
.244 .42723 L
.248 .42702 L
.252 .42702 L
.256 .42722 L
.26 .42739 L
.264 .42732 L
.268 .42699 L
.272 .42666 L
.276 .42659 L
.28 .42685 L
.284 .42717 L
.288 .42724 L
.292 .42694 L
.296 .42647 L
.3 .42618 L
.304 .42626 L
.308 .42661 L
.312 .42695 L
.316 .427 L
.32 .42673 L
.324 .42629 L
.328 .42592 L
.332 .42578 L
.336 .4259 L
.34 .42621 L
.344 .42658 L
.348 .42682 L
.352 .42679 L
.356 .4264 L
.36 .42573 L
.364 .42503 L
.368 .42467 L
.372 .42488 L
.376 .42565 L
.38 .42665 L
.384 .4274 L
.388 .42751 L
.392 .42688 L
.396 .42573 L
.4 .42449 L
Mistroke
.404 .42354 L
.408 .42311 L
.412 .42323 L
.416 .42378 L
.42 .42469 L
.424 .42589 L
.428 .42732 L
.432 .42883 L
.436 .43014 L
.44 .43088 L
.444 .43067 L
.448 .42929 L
.452 .42676 L
.456 .4233 L
.46 .41923 L
.464 .41481 L
.468 .41016 L
.472 .40523 L
.476 .39987 L
.48 .39398 L
.484 .38755 L
.488 .38073 L
.492 .37378 L
.496 .36698 L
.5 .36051 L
.504 .3544 L
.508 .3485 L
.512 .3426 L
.516 .33644 L
.52 .32988 L
.524 .32287 L
.528 .31556 L
.532 .30817 L
.536 .30096 L
.54 .29414 L
.544 .28782 L
.548 .28197 L
.552 .27644 L
.556 .271 L
.56 .26539 L
.564 .25939 L
.568 .25286 L
.572 .24574 L
.576 .2381 L
.58 .23007 L
.584 .22188 L
.588 .21375 L
.592 .20591 L
.596 .19858 L
.6 .1919 L
Mistroke
.604 .18598 L
.608 .18086 L
.612 .17653 L
.616 .17296 L
.62 .17007 L
.624 .16779 L
.628 .16602 L
.632 .16467 L
.636 .16367 L
.64 .16293 L
.644 .1624 L
.648 .16202 L
.652 .16176 L
.656 .16158 L
.66 .16146 L
.664 .16137 L
.668 .16132 L
.672 .16129 L
.676 .16126 L
.68 .16125 L
.684 .16124 L
.688 .16123 L
.692 .16123 L
.696 .16123 L
.7 .16123 L
.704 .16123 L
.708 .16123 L
.712 .16123 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(3841\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30144 m
.008 .30012 L
.012 .29849 L
.016 .29825 L
.02 .29943 L
.024 .29973 L
.028 .29915 L
.032 .29894 L
.036 .29914 L
.04 .29925 L
.044 .29924 L
.048 .29916 L
.052 .29906 L
.056 .29909 L
.06 .29925 L
.064 .29923 L
.068 .29902 L
.072 .29898 L
.076 .29921 L
.08 .29928 L
.084 .29905 L
.088 .29888 L
.092 .29908 L
.096 .29931 L
.1 .29919 L
.104 .29886 L
.108 .29884 L
.112 .29919 L
.116 .29939 L
.12 .29904 L
.124 .29864 L
.128 .29885 L
.132 .29939 L
.136 .29939 L
.14 .29881 L
.144 .29851 L
.148 .29894 L
.152 .29948 L
.156 .29936 L
.16 .29871 L
.164 .2984 L
.168 .29887 L
.172 .29951 L
.176 .29944 L
.18 .29874 L
.184 .29829 L
.188 .29863 L
.192 .29934 L
.196 .29961 L
.2 .2991 L
Mistroke
.204 .29834 L
.208 .29815 L
.212 .29879 L
.216 .29963 L
.22 .2998 L
.224 .29897 L
.228 .29786 L
.232 .29767 L
.236 .29882 L
.24 .30029 L
.244 .30045 L
.248 .29882 L
.252 .29686 L
.256 .29672 L
.26 .29891 L
.264 .30141 L
.268 .30156 L
.272 .2988 L
.276 .29562 L
.28 .29527 L
.284 .29843 L
.288 .3023 L
.292 .30318 L
.296 .29997 L
.3 .29541 L
.304 .2936 L
.308 .29622 L
.312 .30104 L
.316 .30402 L
.32 .30279 L
.324 .29852 L
.328 .29463 L
.332 .29385 L
.336 .29626 L
.34 .29982 L
.344 .30228 L
.348 .3027 L
.352 .30144 L
.356 .29923 L
.36 .29661 L
.364 .29416 L
.368 .293 L
.372 .29445 L
.376 .29889 L
.38 .30472 L
.384 .30869 L
.388 .3078 L
.392 .30146 L
.396 .29242 L
.4 .28538 L
Mistroke
.404 .28429 L
.408 .28994 L
.412 .29957 L
.416 .3086 L
.42 .31328 L
.424 .31256 L
.428 .30804 L
.432 .30235 L
.436 .29732 L
.44 .29307 L
.444 .28862 L
.448 .28332 L
.452 .27799 L
.456 .27499 L
.46 .277 L
.464 .28543 L
.468 .29941 L
.472 .31598 L
.476 .3314 L
.48 .34289 L
.484 .34975 L
.488 .3535 L
.492 .35683 L
.496 .36216 L
.5 .37036 L
.504 .38042 L
.508 .38997 L
.512 .39645 L
.516 .39834 L
.52 .39582 L
.524 .39072 L
.528 .38577 L
.532 .38352 L
.536 .38542 L
.54 .39134 L
.544 .3997 L
.548 .40809 L
.552 .41411 L
.556 .41611 L
.56 .4137 L
.564 .40773 L
.568 .40006 L
.572 .39291 L
.576 .38834 L
.58 .38772 L
.584 .39149 L
.588 .39914 L
.592 .40942 L
.596 .42062 L
.6 .43098 L
Mistroke
.604 .43895 L
.608 .44344 L
.612 .44392 L
.616 .44036 L
.62 .43321 L
.624 .42321 L
.628 .41126 L
.632 .39827 L
.636 .38509 L
.64 .37239 L
.644 .36068 L
.648 .35026 L
.652 .34131 L
.656 .33382 L
.66 .32772 L
.664 .32288 L
.668 .31912 L
.672 .31626 L
.676 .31413 L
.68 .31257 L
.684 .31145 L
.688 .31066 L
.692 .31011 L
.696 .30974 L
.7 .30948 L
.704 .30931 L
.708 .30921 L
.712 .30913 L
.716 .30909 L
.72 .30906 L
.724 .30904 L
.728 .30903 L
.732 .30903 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .52213 m
.008 .51979 L
.012 .51896 L
.016 .5195 L
.02 .51989 L
.024 .51974 L
.028 .51962 L
.032 .51961 L
.036 .51969 L
.04 .51968 L
.044 .51967 L
.048 .51965 L
.052 .51967 L
.056 .51967 L
.06 .51967 L
.064 .51965 L
.068 .51966 L
.072 .51967 L
.076 .51968 L
.08 .51966 L
.084 .51966 L
.088 .51966 L
.092 .51968 L
.096 .51966 L
.1 .51966 L
.104 .51965 L
.108 .51968 L
.112 .51968 L
.116 .51966 L
.12 .51964 L
.124 .51966 L
.128 .51968 L
.132 .51968 L
.136 .51965 L
.14 .51964 L
.144 .51967 L
.148 .51969 L
.152 .51968 L
.156 .51964 L
.16 .51963 L
.164 .51967 L
.168 .5197 L
.172 .51968 L
.176 .51964 L
.18 .51962 L
.184 .51966 L
.188 .5197 L
.192 .5197 L
.196 .51965 L
.2 .51961 L
Mistroke
.204 .51963 L
.208 .51969 L
.212 .51972 L
.216 .51969 L
.22 .51962 L
.224 .51958 L
.228 .51963 L
.232 .51972 L
.236 .51976 L
.24 .51969 L
.244 .51958 L
.248 .51953 L
.252 .51962 L
.256 .51976 L
.26 .51982 L
.264 .51972 L
.268 .51953 L
.272 .51945 L
.276 .51956 L
.28 .5198 L
.284 .51992 L
.288 .51981 L
.292 .51954 L
.296 .51935 L
.3 .51942 L
.304 .51971 L
.308 .51997 L
.312 .51998 L
.316 .51974 L
.32 .51942 L
.324 .51927 L
.328 .5194 L
.332 .5197 L
.336 .51997 L
.34 .52004 L
.344 .51988 L
.348 .51961 L
.352 .51935 L
.356 .51923 L
.36 .51929 L
.364 .51955 L
.368 .51991 L
.372 .52022 L
.376 .52032 L
.38 .52007 L
.384 .51954 L
.388 .51894 L
.392 .51859 L
.396 .51872 L
.4 .51934 L
Mistroke
.404 .52018 L
.408 .52089 L
.412 .52113 L
.416 .52081 L
.42 .52006 L
.424 .51916 L
.428 .51839 L
.432 .51793 L
.436 .51782 L
.44 .51804 L
.444 .51858 L
.448 .51943 L
.452 .52058 L
.456 .52193 L
.46 .52325 L
.464 .52421 L
.468 .5245 L
.472 .5239 L
.476 .52239 L
.48 .5201 L
.484 .51726 L
.488 .51407 L
.492 .51065 L
.496 .50698 L
.5 .50295 L
.504 .49846 L
.508 .49351 L
.512 .48819 L
.516 .4827 L
.52 .47726 L
.524 .47204 L
.528 .46711 L
.532 .46238 L
.536 .45771 L
.54 .45288 L
.544 .44776 L
.548 .44229 L
.552 .43653 L
.556 .43062 L
.56 .42478 L
.564 .41919 L
.568 .41397 L
.572 .40914 L
.576 .40462 L
.58 .40027 L
.584 .39588 L
.588 .39126 L
.592 .38626 L
.596 .38082 L
.6 .37492 L
Mistroke
.604 .36864 L
.608 .36214 L
.612 .35558 L
.616 .34914 L
.62 .34301 L
.624 .33732 L
.628 .33218 L
.632 .32766 L
.636 .32377 L
.64 .3205 L
.644 .31781 L
.648 .31564 L
.652 .31393 L
.656 .31261 L
.66 .3116 L
.664 .31085 L
.668 .3103 L
.672 .3099 L
.676 .30962 L
.68 .30942 L
.684 .30929 L
.688 .30919 L
.692 .30913 L
.696 .30909 L
.7 .30906 L
.704 .30905 L
.708 .30903 L
.712 .30903 L
.716 .30902 L
.72 .30902 L
.724 .30902 L
.728 .30902 L
.732 .30902 L
.736 .30902 L
.74 .30902 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43439 L
.012 .42978 L
.016 .42833 L
.02 .42981 L
.024 .43027 L
.028 .42966 L
.032 .42948 L
.036 .4296 L
.04 .42964 L
.044 .4295 L
.048 .42946 L
.052 .42942 L
.056 .4294 L
.06 .42933 L
.064 .42929 L
.068 .42924 L
.072 .42921 L
.076 .42916 L
.08 .42912 L
.084 .42906 L
.088 .42903 L
.092 .42899 L
.096 .42895 L
.1 .42887 L
.104 .42884 L
.108 .42881 L
.112 .42878 L
.116 .42871 L
.12 .42865 L
.124 .42862 L
.128 .42861 L
.132 .42855 L
.136 .42848 L
.14 .42842 L
.144 .42841 L
.148 .42839 L
.152 .42833 L
.156 .42824 L
.16 .42819 L
.164 .42819 L
.168 .42818 L
.172 .42812 L
.176 .42802 L
.18 .42795 L
.184 .42795 L
.188 .42796 L
.192 .42792 L
.196 .42781 L
.2 .42772 L
Mistroke
.204 .42769 L
.208 .42772 L
.212 .42772 L
.216 .42764 L
.22 .42751 L
.224 .42742 L
.228 .42743 L
.232 .4275 L
.236 .4275 L
.24 .42738 L
.244 .42719 L
.248 .42709 L
.252 .42715 L
.256 .42729 L
.26 .42732 L
.264 .42715 L
.268 .42687 L
.272 .42672 L
.276 .42682 L
.28 .42706 L
.284 .42718 L
.288 .42699 L
.292 .42661 L
.296 .42633 L
.3 .42638 L
.304 .42669 L
.308 .42697 L
.312 .42694 L
.316 .42659 L
.32 .42615 L
.324 .42593 L
.328 .42604 L
.332 .42637 L
.336 .42666 L
.34 .4267 L
.344 .42647 L
.348 .42608 L
.352 .42571 L
.356 .42551 L
.36 .42555 L
.364 .42583 L
.368 .42623 L
.372 .42658 L
.376 .42665 L
.38 .4263 L
.384 .42559 L
.388 .4248 L
.392 .42433 L
.396 .42445 L
.4 .42517 L
Mistroke
.404 .42618 L
.408 .42701 L
.412 .42727 L
.416 .42682 L
.42 .42584 L
.424 .42468 L
.428 .42368 L
.432 .42306 L
.436 .42288 L
.44 .42311 L
.444 .42374 L
.448 .42476 L
.452 .42615 L
.456 .42779 L
.46 .42938 L
.464 .43053 L
.468 .43085 L
.472 .43006 L
.476 .42813 L
.48 .42523 L
.484 .42164 L
.488 .41763 L
.492 .41333 L
.496 .40871 L
.5 .40364 L
.504 .39801 L
.508 .3918 L
.512 .38513 L
.516 .37826 L
.52 .37144 L
.524 .36491 L
.528 .35872 L
.532 .3528 L
.536 .34694 L
.54 .3409 L
.544 .33449 L
.548 .32765 L
.552 .32043 L
.556 .31305 L
.56 .30575 L
.564 .29876 L
.568 .29223 L
.572 .28619 L
.576 .28054 L
.58 .27509 L
.584 .2696 L
.588 .26383 L
.592 .25759 L
.596 .25078 L
.6 .24342 L
Mistroke
.604 .23559 L
.608 .22747 L
.612 .21929 L
.616 .21126 L
.62 .20361 L
.624 .19651 L
.628 .19011 L
.632 .18446 L
.636 .17961 L
.64 .17553 L
.644 .17218 L
.648 .16948 L
.652 .16735 L
.656 .1657 L
.66 .16445 L
.664 .16351 L
.668 .16283 L
.672 .16233 L
.676 .16198 L
.68 .16173 L
.684 .16156 L
.688 .16145 L
.692 .16137 L
.696 .16132 L
.7 .16128 L
.704 .16126 L
.708 .16125 L
.712 .16124 L
.716 .16123 L
.72 .16123 L
.724 .16123 L
.728 .16123 L
.732 .16123 L
.736 .16123 L
.74 .16123 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(4008\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30016 m
.008 .29899 L
.012 .29911 L
.016 .29912 L
.02 .29915 L
.024 .29931 L
.028 .29935 L
.032 .29921 L
.036 .29911 L
.04 .29918 L
.044 .29929 L
.048 .29925 L
.052 .29911 L
.056 .2991 L
.06 .29925 L
.064 .29927 L
.068 .29911 L
.072 .29903 L
.076 .29918 L
.08 .29929 L
.084 .29915 L
.088 .29897 L
.092 .29905 L
.096 .29927 L
.1 .29927 L
.104 .299 L
.108 .29886 L
.112 .29912 L
.116 .29939 L
.12 .29917 L
.124 .29876 L
.128 .29884 L
.132 .29932 L
.136 .29942 L
.14 .29895 L
.144 .29861 L
.148 .29891 L
.152 .29942 L
.156 .2994 L
.16 .29883 L
.164 .29849 L
.168 .29888 L
.172 .29948 L
.176 .29944 L
.18 .29879 L
.184 .29839 L
.188 .29874 L
.192 .2994 L
.196 .29955 L
.2 .29899 L
Mistroke
.204 .29837 L
.208 .29839 L
.212 .29906 L
.216 .29964 L
.22 .29949 L
.224 .29869 L
.228 .29802 L
.232 .29825 L
.236 .29928 L
.24 .30009 L
.244 .2997 L
.248 .29829 L
.252 .29724 L
.256 .29785 L
.26 .29976 L
.264 .30105 L
.268 .30012 L
.272 .2976 L
.276 .29599 L
.28 .29719 L
.284 .30036 L
.288 .30238 L
.292 .301 L
.296 .29722 L
.3 .29458 L
.304 .2958 L
.308 .30001 L
.312 .3034 L
.316 .30278 L
.32 .29856 L
.324 .29436 L
.328 .29379 L
.332 .29729 L
.336 .30188 L
.34 .30394 L
.344 .3021 L
.348 .29808 L
.352 .29487 L
.356 .29436 L
.36 .29632 L
.364 .29917 L
.368 .30148 L
.372 .3026 L
.376 .30237 L
.38 .30064 L
.384 .29746 L
.388 .29374 L
.392 .29147 L
.396 .29271 L
.4 .29793 L
Mistroke
.404 .30501 L
.408 .31002 L
.412 .30952 L
.416 .30292 L
.42 .29321 L
.424 .28536 L
.428 .28343 L
.432 .28831 L
.436 .2974 L
.44 .30637 L
.444 .31169 L
.448 .31229 L
.452 .30947 L
.456 .30537 L
.46 .30133 L
.464 .2972 L
.468 .29194 L
.472 .28506 L
.476 .27767 L
.48 .27242 L
.484 .27233 L
.488 .27911 L
.492 .29216 L
.496 .30865 L
.5 .32478 L
.504 .33749 L
.508 .34571 L
.512 .35059 L
.516 .35467 L
.52 .36044 L
.524 .36907 L
.528 .37984 L
.532 .39054 L
.536 .39855 L
.54 .40201 L
.544 .4007 L
.548 .39606 L
.552 .39072 L
.556 .3874 L
.56 .38798 L
.564 .39284 L
.568 .40085 L
.572 .40977 L
.576 .41711 L
.58 .42086 L
.584 .42012 L
.588 .41528 L
.592 .40784 L
.596 .39994 L
.6 .39378 L
Mistroke
.604 .3911 L
.608 .39278 L
.612 .39876 L
.616 .40812 L
.62 .41934 L
.624 .43063 L
.628 .44031 L
.632 .44702 L
.636 .4499 L
.64 .44864 L
.644 .44342 L
.648 .43483 L
.652 .42369 L
.656 .41091 L
.66 .3974 L
.664 .38394 L
.668 .37116 L
.672 .35949 L
.676 .34921 L
.68 .34042 L
.684 .33311 L
.688 .32718 L
.692 .32248 L
.696 .31884 L
.7 .31607 L
.704 .314 L
.708 .31249 L
.712 .3114 L
.716 .31063 L
.72 .3101 L
.724 .30973 L
.728 .30948 L
.732 .30931 L
.736 .30921 L
.74 .30914 L
.744 .30909 L
.748 .30906 L
.752 .30904 L
.756 .30903 L
.76 .30903 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51357 m
.008 .51948 L
.012 .52145 L
.016 .51935 L
.02 .51876 L
.024 .51945 L
.028 .51968 L
.032 .51941 L
.036 .51936 L
.04 .51943 L
.044 .51947 L
.048 .51942 L
.052 .51943 L
.056 .51943 L
.06 .51944 L
.064 .51942 L
.068 .51943 L
.072 .51943 L
.076 .51944 L
.08 .51942 L
.084 .51943 L
.088 .51942 L
.092 .51944 L
.096 .51943 L
.1 .51943 L
.104 .51942 L
.108 .51944 L
.112 .51944 L
.116 .51943 L
.12 .51941 L
.124 .51942 L
.128 .51944 L
.132 .51945 L
.136 .51942 L
.14 .51941 L
.144 .51943 L
.148 .51945 L
.152 .51944 L
.156 .51941 L
.16 .5194 L
.164 .51943 L
.168 .51946 L
.172 .51945 L
.176 .51941 L
.18 .5194 L
.184 .51942 L
.188 .51946 L
.192 .51945 L
.196 .51941 L
.2 .51939 L
Mistroke
.204 .51941 L
.208 .51945 L
.212 .51947 L
.216 .51944 L
.22 .51939 L
.224 .51937 L
.228 .51942 L
.232 .51948 L
.236 .51949 L
.24 .51942 L
.244 .51935 L
.248 .51935 L
.252 .51944 L
.256 .51953 L
.26 .51952 L
.264 .51941 L
.268 .51929 L
.272 .5193 L
.276 .51945 L
.28 .51959 L
.284 .51958 L
.288 .51941 L
.292 .51923 L
.296 .51922 L
.3 .51941 L
.304 .51963 L
.308 .51969 L
.312 .5195 L
.316 .51923 L
.32 .5191 L
.324 .51924 L
.328 .51954 L
.332 .51975 L
.336 .51971 L
.34 .51945 L
.344 .51917 L
.348 .51906 L
.352 .51919 L
.356 .51946 L
.36 .5197 L
.364 .51978 L
.368 .51967 L
.372 .51944 L
.376 .51917 L
.38 .51898 L
.384 .51898 L
.388 .51921 L
.392 .51961 L
.396 .52 L
.4 .52017 L
Mistroke
.404 .51996 L
.408 .51941 L
.412 .51876 L
.416 .51833 L
.42 .51838 L
.424 .51893 L
.428 .51976 L
.432 .5205 L
.436 .52085 L
.44 .52068 L
.444 .52009 L
.448 .51929 L
.452 .51853 L
.456 .51795 L
.46 .51763 L
.464 .5176 L
.468 .51789 L
.472 .51856 L
.476 .51962 L
.48 .52099 L
.484 .52245 L
.488 .52368 L
.492 .52435 L
.496 .5242 L
.5 .52316 L
.504 .52133 L
.508 .51889 L
.512 .51607 L
.516 .51295 L
.52 .50956 L
.524 .50578 L
.528 .50154 L
.532 .4968 L
.536 .49163 L
.54 .48622 L
.544 .4808 L
.548 .47554 L
.552 .47055 L
.556 .4658 L
.56 .46114 L
.564 .4564 L
.568 .4514 L
.572 .44606 L
.576 .4404 L
.58 .43453 L
.584 .42865 L
.588 .42294 L
.592 .41756 L
.596 .41256 L
.6 .40792 L
Mistroke
.604 .40352 L
.608 .39918 L
.612 .3947 L
.616 .38992 L
.62 .38472 L
.624 .37906 L
.628 .37299 L
.632 .3666 L
.636 .36006 L
.64 .35354 L
.644 .34721 L
.648 .34124 L
.652 .33574 L
.656 .33082 L
.66 .32652 L
.664 .32283 L
.668 .31975 L
.672 .31723 L
.676 .3152 L
.68 .31361 L
.684 .31237 L
.688 .31144 L
.692 .31074 L
.696 .31022 L
.7 .30985 L
.704 .30959 L
.708 .3094 L
.712 .30927 L
.716 .30918 L
.72 .30913 L
.724 .30909 L
.728 .30906 L
.732 .30904 L
.736 .30903 L
.74 .30903 L
.744 .30902 L
.748 .30902 L
.752 .30902 L
.756 .30902 L
.76 .30902 L
.764 .30902 L
.768 .30902 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43199 L
.012 .43005 L
.016 .42922 L
.02 .42963 L
.024 .42994 L
.028 .42975 L
.032 .42961 L
.036 .42956 L
.04 .42959 L
.044 .42952 L
.048 .42948 L
.052 .42941 L
.056 .42939 L
.06 .42934 L
.064 .4293 L
.068 .42924 L
.072 .42921 L
.076 .42916 L
.08 .42912 L
.084 .42906 L
.088 .42903 L
.092 .42899 L
.096 .42895 L
.1 .42888 L
.104 .42884 L
.108 .42881 L
.112 .42878 L
.116 .42871 L
.12 .42866 L
.124 .42862 L
.128 .4286 L
.132 .42855 L
.136 .42849 L
.14 .42842 L
.144 .4284 L
.148 .42839 L
.152 .42834 L
.156 .42825 L
.16 .4282 L
.164 .42818 L
.168 .42817 L
.172 .42811 L
.176 .42803 L
.18 .42796 L
.184 .42796 L
.188 .42796 L
.192 .42791 L
.196 .42781 L
.2 .42773 L
Mistroke
.204 .42771 L
.208 .42773 L
.212 .42771 L
.216 .42762 L
.22 .42751 L
.224 .42745 L
.228 .42747 L
.232 .4275 L
.236 .42746 L
.24 .42733 L
.244 .4272 L
.248 .42716 L
.252 .42722 L
.256 .42729 L
.26 .42723 L
.264 .42705 L
.268 .42686 L
.272 .42683 L
.276 .42697 L
.28 .4271 L
.284 .42705 L
.288 .42679 L
.292 .42652 L
.296 .42646 L
.3 .42665 L
.304 .42689 L
.308 .42691 L
.312 .42664 L
.316 .42625 L
.32 .42605 L
.324 .42618 L
.328 .42651 L
.332 .42673 L
.336 .42663 L
.34 .42627 L
.344 .42587 L
.348 .42569 L
.352 .42581 L
.356 .4261 L
.36 .42635 L
.364 .42641 L
.368 .42623 L
.372 .42589 L
.376 .42551 L
.38 .42524 L
.384 .4252 L
.388 .42544 L
.392 .42589 L
.396 .42633 L
.4 .42649 L
Mistroke
.404 .42619 L
.408 .42546 L
.412 .42461 L
.416 .42403 L
.42 .42405 L
.424 .42469 L
.428 .42568 L
.432 .42656 L
.436 .42695 L
.44 .4267 L
.444 .42591 L
.448 .42487 L
.452 .42388 L
.456 .42312 L
.46 .42268 L
.464 .4226 L
.468 .42292 L
.472 .4237 L
.476 .42497 L
.48 .42664 L
.484 .42842 L
.488 .42991 L
.492 .43069 L
.496 .43046 L
.5 .42912 L
.504 .42679 L
.508 .42371 L
.512 .42014 L
.516 .41622 L
.52 .41195 L
.524 .4072 L
.528 .40188 L
.532 .39592 L
.536 .38945 L
.54 .38267 L
.544 .37587 L
.548 .36929 L
.552 .36304 L
.556 .35708 L
.56 .35124 L
.564 .3453 L
.568 .33904 L
.572 .33236 L
.576 .32528 L
.58 .31794 L
.584 .31058 L
.588 .30345 L
.592 .29672 L
.596 .29047 L
.6 .28467 L
Mistroke
.604 .27916 L
.608 .27373 L
.612 .26813 L
.616 .26215 L
.62 .25566 L
.624 .24859 L
.628 .24101 L
.632 .23304 L
.636 .22488 L
.64 .21674 L
.644 .20884 L
.648 .20139 L
.652 .19455 L
.656 .18841 L
.66 .18304 L
.664 .17845 L
.668 .17461 L
.672 .17146 L
.676 .16894 L
.68 .16695 L
.684 .16541 L
.688 .16424 L
.692 .16337 L
.696 .16273 L
.7 .16227 L
.704 .16194 L
.708 .1617 L
.712 .16154 L
.716 .16144 L
.72 .16136 L
.724 .16131 L
.728 .16128 L
.732 .16126 L
.736 .16125 L
.74 .16124 L
.744 .16123 L
.748 .16123 L
.752 .16123 L
.756 .16123 L
.76 .16123 L
.764 .16123 L
.768 .16123 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(4175\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29723 m
.008 .29834 L
.012 .30003 L
.016 .30024 L
.02 .29898 L
.024 .29871 L
.028 .2994 L
.032 .29955 L
.036 .29917 L
.04 .29909 L
.044 .29929 L
.048 .29933 L
.052 .29918 L
.056 .29913 L
.06 .29924 L
.064 .2993 L
.068 .29919 L
.072 .29909 L
.076 .29917 L
.08 .29928 L
.084 .29924 L
.088 .29907 L
.092 .29904 L
.096 .29923 L
.1 .29933 L
.104 .29912 L
.108 .29891 L
.112 .29908 L
.116 .29938 L
.12 .29927 L
.124 .29888 L
.128 .29885 L
.132 .29925 L
.136 .29943 L
.14 .29909 L
.144 .29872 L
.148 .29888 L
.152 .29935 L
.156 .29944 L
.16 .29896 L
.164 .29858 L
.168 .29888 L
.172 .29944 L
.176 .29945 L
.18 .29887 L
.184 .29848 L
.188 .29881 L
.192 .29941 L
.196 .29952 L
.2 .29897 L
Mistroke
.204 .29843 L
.208 .29856 L
.212 .29921 L
.216 .29961 L
.22 .29929 L
.224 .29858 L
.228 .29822 L
.232 .29865 L
.236 .29948 L
.24 .29982 L
.244 .29921 L
.248 .29815 L
.252 .29776 L
.256 .29862 L
.26 .3 L
.264 .3004 L
.268 .29915 L
.272 .29733 L
.276 .29692 L
.28 .29864 L
.284 .30094 L
.288 .30135 L
.292 .29911 L
.296 .29624 L
.3 .2957 L
.304 .29836 L
.308 .30185 L
.312 .3027 L
.316 .2998 L
.32 .29567 L
.324 .29418 L
.328 .29688 L
.332 .30149 L
.336 .3039 L
.34 .30196 L
.344 .29731 L
.348 .29385 L
.352 .29433 L
.356 .29817 L
.36 .30222 L
.364 .30355 L
.368 .3016 L
.372 .2981 L
.376 .29542 L
.38 .29478 L
.384 .29599 L
.388 .29819 L
.392 .30064 L
.396 .30271 L
.4 .30354 L
Mistroke
.404 .30216 L
.408 .29829 L
.412 .2933 L
.416 .28998 L
.42 .291 L
.424 .29688 L
.428 .30504 L
.432 .31102 L
.436 .31104 L
.44 .30447 L
.444 .29441 L
.448 .2859 L
.452 .28306 L
.456 .28692 L
.46 .29513 L
.464 .30374 L
.468 .30948 L
.472 .31131 L
.476 .31022 L
.48 .30789 L
.484 .30519 L
.488 .30161 L
.492 .29599 L
.496 .2879 L
.5 .27863 L
.504 .2711 L
.508 .26864 L
.512 .27336 L
.516 .28501 L
.52 .30099 L
.524 .3175 L
.528 .33123 L
.532 .34072 L
.536 .34673 L
.54 .35159 L
.544 .35782 L
.548 .36685 L
.552 .37829 L
.556 .39015 L
.56 .39976 L
.564 .40499 L
.568 .40515 L
.572 .40131 L
.576 .39586 L
.58 .39164 L
.584 .39088 L
.588 .39449 L
.592 .40183 L
.596 .41097 L
.6 .4194 L
Mistroke
.604 .42485 L
.608 .42595 L
.612 .42257 L
.616 .4158 L
.62 .40757 L
.624 .40015 L
.628 .39552 L
.632 .39501 L
.636 .39901 L
.64 .407 L
.644 .41772 L
.648 .42947 L
.652 .44048 L
.656 .44919 L
.66 .45445 L
.664 .45562 L
.668 .45263 L
.672 .44583 L
.676 .4359 L
.68 .42373 L
.684 .41024 L
.688 .3963 L
.692 .38264 L
.696 .36983 L
.7 .35826 L
.704 .34814 L
.708 .33953 L
.712 .3324 L
.716 .32664 L
.72 .32208 L
.724 .31855 L
.728 .31587 L
.732 .31387 L
.736 .3124 L
.74 .31135 L
.744 .3106 L
.748 .31008 L
.752 .30972 L
.756 .30948 L
.76 .30931 L
.764 .30921 L
.768 .30914 L
.772 .30909 L
.776 .30906 L
.78 .30904 L
.784 .30903 L
.788 .30903 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .5157 m
.008 .51905 L
.012 .5203 L
.016 .51932 L
.02 .51888 L
.024 .51911 L
.028 .51931 L
.032 .51922 L
.036 .51917 L
.04 .51917 L
.044 .51922 L
.048 .51919 L
.052 .5192 L
.056 .51919 L
.06 .51921 L
.064 .51919 L
.068 .5192 L
.072 .51919 L
.076 .5192 L
.08 .51919 L
.084 .5192 L
.088 .51919 L
.092 .5192 L
.096 .5192 L
.1 .5192 L
.104 .51918 L
.108 .5192 L
.112 .5192 L
.116 .5192 L
.12 .51918 L
.124 .51919 L
.128 .5192 L
.132 .51921 L
.136 .51919 L
.14 .51918 L
.144 .51919 L
.148 .51921 L
.152 .51921 L
.156 .51919 L
.16 .51917 L
.164 .51919 L
.168 .51922 L
.172 .51921 L
.176 .51918 L
.18 .51917 L
.184 .51919 L
.188 .51922 L
.192 .51922 L
.196 .51918 L
.2 .51916 L
Mistroke
.204 .51918 L
.208 .51922 L
.212 .51923 L
.216 .51919 L
.22 .51916 L
.224 .51916 L
.228 .5192 L
.232 .51924 L
.236 .51923 L
.24 .51917 L
.244 .51913 L
.248 .51915 L
.252 .51922 L
.256 .51927 L
.26 .51923 L
.264 .51914 L
.268 .51909 L
.272 .51914 L
.276 .51926 L
.28 .51932 L
.284 .51925 L
.288 .5191 L
.292 .51903 L
.296 .51911 L
.3 .51929 L
.304 .51939 L
.308 .51931 L
.312 .51909 L
.316 .51895 L
.32 .51902 L
.324 .51925 L
.328 .51945 L
.332 .51943 L
.336 .51919 L
.34 .51894 L
.344 .51888 L
.348 .51907 L
.352 .51935 L
.356 .51951 L
.36 .51944 L
.364 .51919 L
.368 .51895 L
.372 .51886 L
.376 .51896 L
.38 .51919 L
.384 .51942 L
.388 .51953 L
.392 .51948 L
.396 .51927 L
.4 .51898 L
Mistroke
.404 .51874 L
.408 .51867 L
.412 .51888 L
.416 .5193 L
.42 .51976 L
.424 .52 L
.428 .51983 L
.432 .51929 L
.436 .51861 L
.44 .51811 L
.444 .51807 L
.448 .51854 L
.452 .51931 L
.456 .52007 L
.46 .52052 L
.464 .5205 L
.468 .52007 L
.472 .5194 L
.476 .51868 L
.48 .51804 L
.484 .51756 L
.488 .51729 L
.492 .51733 L
.496 .51778 L
.5 .51868 L
.504 .52 L
.508 .52153 L
.512 .52297 L
.516 .52396 L
.52 .52422 L
.524 .52363 L
.528 .52225 L
.532 .52025 L
.536 .51779 L
.54 .51501 L
.544 .51192 L
.548 .50843 L
.552 .50446 L
.556 .49996 L
.56 .49498 L
.564 .48969 L
.568 .48431 L
.572 .47903 L
.576 .47399 L
.58 .46919 L
.584 .46454 L
.588 .45986 L
.592 .45498 L
.596 .44977 L
.6 .44423 L
Mistroke
.604 .43843 L
.608 .43254 L
.612 .42675 L
.616 .42122 L
.62 .41605 L
.624 .41127 L
.628 .40678 L
.632 .40243 L
.636 .39805 L
.64 .39344 L
.644 .38848 L
.648 .38307 L
.652 .37722 L
.656 .37101 L
.66 .36454 L
.664 .35799 L
.668 .35153 L
.672 .34533 L
.676 .33953 L
.68 .33425 L
.684 .32954 L
.688 .32545 L
.692 .32196 L
.696 .31906 L
.7 .31669 L
.704 .3148 L
.708 .31331 L
.712 .31216 L
.716 .31128 L
.72 .31063 L
.724 .31015 L
.728 .3098 L
.732 .30955 L
.736 .30938 L
.74 .30926 L
.744 .30918 L
.748 .30912 L
.752 .30908 L
.756 .30906 L
.76 .30904 L
.764 .30903 L
.768 .30903 L
.772 .30902 L
.776 .30902 L
.78 .30902 L
.784 .30902 L
.788 .30902 L
.792 .30902 L
.796 .30902 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42587 L
.012 .42996 L
.016 .43124 L
.02 .4297 L
.024 .42927 L
.028 .42971 L
.032 .42983 L
.036 .42958 L
.04 .42951 L
.044 .42951 L
.048 .4295 L
.052 .42941 L
.056 .42938 L
.06 .42934 L
.064 .4293 L
.068 .42924 L
.072 .42921 L
.076 .42916 L
.08 .42913 L
.084 .42906 L
.088 .42903 L
.092 .42899 L
.096 .42895 L
.1 .42889 L
.104 .42884 L
.108 .4288 L
.112 .42878 L
.116 .42872 L
.12 .42866 L
.124 .42862 L
.128 .42859 L
.132 .42855 L
.136 .42849 L
.14 .42843 L
.144 .4284 L
.148 .42838 L
.152 .42834 L
.156 .42826 L
.16 .4282 L
.164 .42818 L
.168 .42817 L
.172 .42811 L
.176 .42803 L
.18 .42797 L
.184 .42796 L
.188 .42795 L
.192 .4279 L
.196 .42781 L
.2 .42774 L
Mistroke
.204 .42772 L
.208 .42773 L
.212 .42769 L
.216 .42761 L
.22 .42751 L
.224 .42747 L
.228 .42748 L
.232 .42749 L
.236 .42743 L
.24 .42731 L
.244 .42722 L
.248 .4272 L
.252 .42725 L
.256 .42726 L
.26 .42717 L
.264 .42701 L
.268 .4269 L
.272 .42692 L
.276 .42702 L
.28 .42706 L
.284 .42693 L
.288 .4267 L
.292 .42656 L
.296 .42662 L
.3 .42679 L
.304 .42688 L
.308 .42673 L
.312 .42642 L
.316 .4262 L
.32 .42624 L
.324 .42649 L
.328 .42669 L
.332 .42661 L
.336 .42628 L
.34 .42592 L
.344 .42581 L
.348 .42599 L
.352 .4263 L
.356 .42645 L
.36 .42632 L
.364 .42597 L
.368 .42562 L
.372 .42546 L
.376 .42555 L
.38 .4258 L
.384 .42604 L
.388 .42613 L
.392 .42602 L
.396 .42572 L
.4 .42531 L
Mistroke
.404 .42496 L
.408 .42484 L
.412 .42505 L
.416 .42554 L
.42 .42606 L
.424 .42631 L
.428 .42607 L
.432 .42535 L
.436 .42445 L
.44 .42379 L
.444 .42369 L
.448 .42423 L
.452 .42516 L
.456 .42606 L
.46 .42656 L
.464 .4265 L
.468 .42592 L
.472 .42505 L
.476 .4241 L
.48 .42326 L
.484 .42261 L
.488 .42224 L
.492 .42225 L
.496 .42275 L
.5 .42384 L
.504 .42544 L
.508 .42731 L
.512 .42905 L
.516 .43024 L
.52 .43051 L
.524 .42974 L
.528 .42798 L
.532 .42543 L
.536 .42233 L
.54 .41882 L
.544 .41492 L
.548 .41053 L
.552 .40554 L
.556 .39989 L
.56 .39365 L
.564 .38702 L
.568 .38027 L
.572 .37366 L
.576 .36734 L
.58 .36134 L
.584 .3555 L
.588 .34964 L
.592 .34352 L
.596 .33701 L
.6 .33007 L
Mistroke
.604 .32282 L
.608 .31545 L
.612 .3082 L
.616 .30129 L
.62 .29483 L
.624 .28885 L
.628 .28323 L
.632 .2778 L
.636 .27232 L
.64 .26656 L
.644 .26035 L
.648 .2536 L
.652 .2463 L
.656 .23854 L
.66 .23047 L
.664 .2223 L
.668 .21424 L
.672 .2065 L
.676 .19927 L
.68 .19268 L
.684 .18681 L
.688 .18171 L
.692 .17736 L
.696 .17375 L
.7 .1708 L
.704 .16843 L
.708 .16657 L
.712 .16514 L
.716 .16405 L
.72 .16323 L
.724 .16264 L
.728 .1622 L
.732 .1619 L
.736 .16168 L
.74 .16153 L
.744 .16143 L
.748 .16136 L
.752 .16131 L
.756 .16128 L
.76 .16126 L
.764 .16125 L
.768 .16124 L
.772 .16123 L
.776 .16123 L
.78 .16123 L
.784 .16123 L
.788 .16123 L
.792 .16123 L
.796 .16123 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(4342\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29804 m
.008 .29942 L
.012 .29963 L
.016 .29963 L
.02 .2993 L
.024 .29909 L
.028 .29926 L
.032 .29941 L
.036 .29932 L
.04 .29921 L
.044 .29926 L
.048 .29932 L
.052 .29927 L
.056 .2992 L
.06 .29924 L
.064 .2993 L
.068 .29927 L
.072 .29917 L
.076 .29917 L
.08 .29927 L
.084 .29931 L
.088 .29917 L
.092 .29907 L
.096 .2992 L
.1 .29935 L
.104 .29922 L
.108 .29899 L
.112 .29906 L
.116 .29935 L
.12 .29934 L
.124 .29901 L
.128 .29889 L
.132 .29919 L
.136 .29942 L
.14 .29921 L
.144 .29884 L
.148 .29888 L
.152 .29929 L
.156 .29946 L
.16 .29908 L
.164 .29868 L
.168 .29887 L
.172 .29939 L
.176 .29947 L
.18 .29897 L
.184 .29858 L
.188 .29884 L
.192 .2994 L
.196 .2995 L
.2 .29899 L
Mistroke
.204 .29851 L
.208 .29867 L
.212 .29929 L
.216 .29958 L
.22 .29918 L
.224 .29856 L
.228 .29841 L
.232 .29892 L
.236 .29955 L
.24 .29959 L
.244 .29893 L
.248 .29821 L
.252 .29822 L
.256 .29908 L
.26 .29995 L
.264 .29982 L
.268 .29863 L
.272 .29754 L
.276 .29781 L
.28 .29942 L
.284 .30076 L
.288 .30024 L
.292 .29809 L
.296 .29645 L
.3 .29722 L
.304 .29993 L
.308 .30191 L
.312 .30094 L
.316 .29765 L
.32 .29518 L
.324 .29615 L
.328 .2999 L
.332 .30297 L
.336 .30231 L
.34 .2983 L
.344 .29451 L
.348 .29441 L
.352 .29818 L
.356 .30258 L
.36 .30385 L
.364 .30098 L
.368 .29643 L
.372 .29381 L
.376 .29497 L
.38 .29869 L
.384 .30211 L
.388 .30305 L
.392 .30139 L
.396 .29855 L
.4 .29614 L
Mistroke
.404 .29502 L
.408 .29533 L
.412 .297 L
.416 .29982 L
.42 .30298 L
.424 .30485 L
.428 .30371 L
.432 .29912 L
.436 .29292 L
.44 .28862 L
.444 .28937 L
.448 .29572 L
.452 .30476 L
.456 .31163 L
.46 .31231 L
.464 .30608 L
.468 .29597 L
.472 .28698 L
.476 .28323 L
.48 .28587 L
.484 .29293 L
.488 .30087 L
.492 .30675 L
.496 .3096 L
.5 .31018 L
.504 .30974 L
.508 .30865 L
.512 .30606 L
.516 .30058 L
.52 .29174 L
.524 .28088 L
.528 .27113 L
.532 .26614 L
.536 .26845 L
.54 .27825 L
.544 .29326 L
.548 .30976 L
.552 .32425 L
.556 .33488 L
.56 .34198 L
.564 .34761 L
.568 .35429 L
.572 .36368 L
.576 .37573 L
.58 .38869 L
.584 .39994 L
.588 .40709 L
.592 .409 L
.596 .4063 L
.6 .40108 L
Mistroke
.604 .39619 L
.608 .39415 L
.612 .39639 L
.616 .40277 L
.62 .41178 L
.624 .42102 L
.628 .42804 L
.632 .43105 L
.636 .42941 L
.64 .42373 L
.644 .41564 L
.648 .40734 L
.652 .40101 L
.656 .39832 L
.66 .40012 L
.664 .40634 L
.668 .41604 L
.672 .42773 L
.676 .43963 L
.68 .45002 L
.684 .45752 L
.688 .46117 L
.692 .46061 L
.696 .45592 L
.7 .44761 L
.704 .43646 L
.708 .42338 L
.712 .40929 L
.716 .39501 L
.72 .38122 L
.724 .36844 L
.728 .35699 L
.732 .34704 L
.736 .33863 L
.74 .33169 L
.744 .32609 L
.748 .32168 L
.752 .31826 L
.756 .31567 L
.76 .31373 L
.764 .31232 L
.768 .31129 L
.772 .31057 L
.776 .31006 L
.78 .30971 L
.784 .30947 L
.788 .30931 L
.792 .30921 L
.796 .30914 L
.8 .30909 L
Mistroke
.804 .30906 L
.808 .30905 L
.812 .30903 L
.816 .30903 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .52421 m
.008 .51886 L
.012 .51718 L
.016 .51903 L
.02 .5196 L
.024 .51891 L
.028 .51876 L
.032 .51897 L
.036 .51905 L
.04 .51895 L
.044 .51895 L
.048 .51896 L
.052 .51898 L
.056 .51896 L
.06 .51897 L
.064 .51896 L
.068 .51897 L
.072 .51896 L
.076 .51897 L
.08 .51896 L
.084 .51896 L
.088 .51895 L
.092 .51897 L
.096 .51897 L
.1 .51897 L
.104 .51895 L
.108 .51896 L
.112 .51897 L
.116 .51897 L
.12 .51895 L
.124 .51895 L
.128 .51896 L
.132 .51898 L
.136 .51896 L
.14 .51895 L
.144 .51895 L
.148 .51897 L
.152 .51897 L
.156 .51896 L
.16 .51894 L
.164 .51896 L
.168 .51898 L
.172 .51898 L
.176 .51895 L
.18 .51894 L
.184 .51896 L
.188 .51898 L
.192 .51898 L
.196 .51895 L
.2 .51893 L
Mistroke
.204 .51895 L
.208 .51898 L
.212 .51899 L
.216 .51896 L
.22 .51893 L
.224 .51893 L
.228 .51897 L
.232 .519 L
.236 .51898 L
.24 .51893 L
.244 .51891 L
.248 .51894 L
.252 .519 L
.256 .51901 L
.26 .51897 L
.264 .5189 L
.268 .51889 L
.272 .51895 L
.276 .51903 L
.28 .51904 L
.284 .51896 L
.288 .51886 L
.292 .51885 L
.296 .51896 L
.3 .51908 L
.304 .51908 L
.308 .51896 L
.312 .51881 L
.316 .51879 L
.32 .51894 L
.324 .51912 L
.328 .51916 L
.332 .51901 L
.336 .51879 L
.34 .5187 L
.344 .51884 L
.348 .51909 L
.352 .51923 L
.356 .51915 L
.36 .5189 L
.364 .51868 L
.368 .51868 L
.372 .51887 L
.376 .51913 L
.38 .51926 L
.384 .51918 L
.388 .51895 L
.392 .51873 L
.396 .51864 L
.4 .51872 L
Mistroke
.404 .51892 L
.408 .51914 L
.412 .5193 L
.416 .5193 L
.42 .51911 L
.424 .5188 L
.428 .51849 L
.432 .51837 L
.436 .51855 L
.44 .51899 L
.444 .5195 L
.448 .51981 L
.452 .5197 L
.456 .51918 L
.46 .51848 L
.464 .51793 L
.468 .5178 L
.472 .51816 L
.476 .51887 L
.48 .51962 L
.484 .52013 L
.488 .52025 L
.492 .52 L
.496 .51948 L
.5 .51884 L
.504 .51817 L
.508 .51757 L
.512 .51711 L
.516 .5169 L
.52 .5171 L
.524 .51781 L
.528 .51901 L
.532 .52055 L
.536 .52211 L
.54 .52336 L
.544 .52398 L
.548 .52383 L
.552 .52289 L
.556 .52131 L
.56 .51925 L
.564 .51682 L
.568 .51405 L
.572 .51087 L
.576 .5072 L
.58 .50297 L
.584 .49822 L
.588 .49308 L
.592 .48777 L
.596 .48249 L
.6 .47741 L
Mistroke
.604 .47258 L
.608 .46791 L
.612 .46328 L
.616 .4585 L
.62 .45343 L
.624 .44802 L
.628 .44231 L
.632 .43645 L
.636 .43059 L
.64 .42494 L
.644 .41961 L
.648 .41466 L
.652 .41006 L
.656 .40567 L
.66 .40133 L
.664 .39686 L
.668 .3921 L
.672 .38694 L
.676 .38134 L
.68 .37532 L
.684 .36899 L
.688 .36247 L
.692 .35595 L
.696 .34958 L
.7 .34352 L
.704 .33791 L
.708 .33283 L
.712 .32833 L
.716 .32444 L
.72 .32115 L
.724 .31842 L
.728 .3162 L
.732 .31442 L
.736 .31303 L
.74 .31195 L
.744 .31114 L
.748 .31053 L
.752 .31008 L
.756 .30976 L
.76 .30952 L
.764 .30936 L
.768 .30925 L
.772 .30917 L
.776 .30912 L
.78 .30908 L
.784 .30906 L
.788 .30904 L
.792 .30903 L
.796 .30903 L
.8 .30902 L
Mistroke
.804 .30902 L
.808 .30902 L
.812 .30902 L
.816 .30902 L
.82 .30902 L
.824 .30902 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42714 L
.012 .42967 L
.016 .43072 L
.02 .42989 L
.024 .42948 L
.028 .42962 L
.032 .42975 L
.036 .42962 L
.04 .42955 L
.044 .4295 L
.048 .42949 L
.052 .42942 L
.056 .42939 L
.06 .42933 L
.064 .4293 L
.068 .42924 L
.072 .42921 L
.076 .42916 L
.08 .42913 L
.084 .42906 L
.088 .42903 L
.092 .42898 L
.096 .42895 L
.1 .42889 L
.104 .42884 L
.108 .4288 L
.112 .42877 L
.116 .42872 L
.12 .42867 L
.124 .42862 L
.128 .42859 L
.132 .42855 L
.136 .4285 L
.14 .42843 L
.144 .4284 L
.148 .42837 L
.152 .42834 L
.156 .42827 L
.16 .42821 L
.164 .42818 L
.168 .42816 L
.172 .42811 L
.176 .42804 L
.18 .42798 L
.184 .42796 L
.188 .42794 L
.192 .4279 L
.196 .42782 L
.2 .42775 L
Mistroke
.204 .42773 L
.208 .42772 L
.212 .42769 L
.216 .4276 L
.22 .42752 L
.224 .42749 L
.228 .42749 L
.232 .42748 L
.236 .42741 L
.24 .42731 L
.244 .42724 L
.248 .42723 L
.252 .42725 L
.256 .42723 L
.26 .42713 L
.264 .42701 L
.268 .42695 L
.272 .42698 L
.276 .42703 L
.28 .427 L
.284 .42685 L
.288 .42669 L
.292 .42664 L
.296 .42672 L
.3 .42683 L
.304 .42679 L
.308 .42659 L
.312 .42636 L
.316 .42629 L
.32 .42643 L
.324 .42661 L
.328 .42662 L
.332 .42638 L
.336 .42607 L
.34 .42592 L
.344 .42605 L
.348 .42631 L
.352 .42645 L
.356 .4263 L
.36 .42594 L
.364 .42563 L
.368 .42558 L
.372 .42578 L
.376 .42605 L
.38 .42617 L
.384 .42602 L
.388 .4257 L
.392 .42539 L
.396 .42523 L
.4 .42528 L
Mistroke
.404 .42548 L
.408 .42572 L
.412 .42587 L
.416 .42582 L
.42 .42555 L
.424 .42511 L
.428 .42468 L
.432 .42449 L
.436 .42467 L
.44 .42518 L
.444 .42577 L
.448 .4261 L
.452 .42592 L
.456 .42523 L
.46 .42432 L
.464 .42359 L
.468 .42338 L
.472 .4238 L
.476 .42463 L
.48 .42552 L
.484 .42611 L
.488 .42622 L
.492 .42586 L
.496 .42517 L
.5 .42433 L
.504 .42345 L
.508 .42266 L
.512 .42204 L
.516 .42174 L
.52 .42195 L
.524 .42278 L
.528 .42424 L
.532 .42611 L
.536 .42802 L
.54 .42952 L
.544 .43025 L
.548 .43001 L
.552 .4288 L
.556 .42679 L
.56 .42417 L
.564 .4211 L
.568 .4176 L
.572 .41361 L
.576 .40899 L
.58 .40367 L
.584 .39771 L
.588 .39127 L
.592 .38461 L
.596 .378 L
.6 .37164 L
Mistroke
.604 .36557 L
.608 .35973 L
.612 .35392 L
.616 .34793 L
.62 .34158 L
.624 .33481 L
.628 .32767 L
.632 .32033 L
.636 .31302 L
.64 .30595 L
.644 .29929 L
.648 .2931 L
.652 .28733 L
.656 .28185 L
.66 .27642 L
.664 .27084 L
.668 .26488 L
.672 .25844 L
.676 .25144 L
.68 .24392 L
.684 .23602 L
.688 .22789 L
.692 .21975 L
.696 .2118 L
.7 .20425 L
.704 .19724 L
.708 .19091 L
.712 .1853 L
.716 .18046 L
.72 .17635 L
.724 .17295 L
.728 .17018 L
.732 .16796 L
.736 .16622 L
.74 .16488 L
.744 .16387 L
.748 .16311 L
.752 .16255 L
.756 .16215 L
.76 .16186 L
.764 .16165 L
.768 .16151 L
.772 .16142 L
.776 .16135 L
.78 .16131 L
.784 .16128 L
.788 .16126 L
.792 .16125 L
.796 .16124 L
.8 .16123 L
Mistroke
.804 .16123 L
.808 .16123 L
.812 .16123 L
.816 .16123 L
.82 .16123 L
.824 .16123 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo02]oo`8000=oo`03001oo`0003Uoo`008Woo0P003Woo00P007oo001oo`00Ool007oo1000
00=oo`00Ool0100000Aoo`00001oo`80009oo`800003Ool0000000=oo`03001oo`0003Uoo`008Woo
H`0037oo000ROol01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1000Oomoo`000goo00D007ooOomoo`0000=oo`08001oogooOol007oo001oo`<00004Ool007ooOol2
0003Ool01000Oomoo`000goo00D007ooOomoo`00009oo`L0009oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00<007ooOol02Woo000ROol2000dOol00`00Oomoo`0@Ool00`00Oomoo`0SOol0
029oo`03001oogoo03=oo`03001oogoo00moo`03001oogoo02Aoo`008Woo0P00=Goo00<007ooOol0
3Goo00<007ooOol09Goo000ROol2000eOol00`00Oomoo`0=Ool00`00Oomoo`0UOol000]oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo03Eoo`03001oogoo00aoo`03001oogoo02Eo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000fOol00`00Oomoo`0<
Ool00`00Oomoo`0UOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
=goo00<007ooOol02Woo00<007ooOol09Woo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo03Ioo`04001oo`000003Ool00`00Oomoo`03Ool00`00Oomoo`0VOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00=goo0P0000Moo`00Oomo
o`00Ool00004Ool00`00Oomoo`0VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
0P00>goo00D007oo001oo`0000Aoo`03001oogoo02Ioo`002goo0P002Woo0P0017oo00<007ooOol0
0Woo00<007ooOol0>Woo0P000goo00@007ooOol002Uoo`002goo0P0017oo00<007ooOol00goo0P00
0Woo1@000Woo0P00@7oo00@007ooOol002Uoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`000Woo0P00@7oo00<007oo0000:Woo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo041oo`8002Yoo`002Woo00@007ooOol000Qoo`04001oogoo0004
Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomo
o`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]o
o`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=o
o`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol0
0`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool5
0002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`80
00Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Io
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool5
0002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004
Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003
Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol0
07oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool0
0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05
001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04
001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=o
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qo
o`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001o
ogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0
009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo
1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<0
00Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo
00<007ooOol027oo0P001Goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`0nOol2
000VOol002Qoo`03001oogoo03eoo`03001oogoo02Ioo`00:7oo00<007ooOol0?7oo0P00:7oo000X
Ool00`00Oomoo`0lOol00`00Oomoo`0WOol002Qoo`03001oogoo03]oo`8002Uoo`002goo0P0017oo
00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0>goo00<007ooOol0:7oo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol003aoo`03001o
ogoo02Uoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0
03]oo`03001oogoo02Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol00P00>Goo00<007ooOol0:goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05
001oogoo001oo`040003Ool00`00Oomoo`0gOol2000]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0gOol00`00Oomoo`0/Ool000]oo`8000Yoo`80
00Aoo`80009oo`D0009oo`03001oogoo03Ioo`03001oogoo02eoo`00:7oo00<007ooOol0=Goo00<0
07ooOol0;Woo000XOol00`00Oomoo`0dOol2000`Ool0015oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`03001oogoo03=oo`80035oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`0cOol00`00Oomoo`0`Ool0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0<Woo00<007ooOol0<Goo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009ooc800003Ool0000003Aoo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0^Ool3000eOol0011oo`04001oogoo0008Ool01000
Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002
Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Ao
o`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool3
0004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool2
0005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`00
2Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@0
07ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eo
o`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo
00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03
001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005
Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo000017oo0`0000=oo`00Ool00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00
Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo04Moo`8002Uoo`0077oo0P00Agoo0P00:Woo
000LOol00`00Oomoo`16Ool00`00Oomoo`0YOol001aoo`03001oogoo04Ioo`03001oogoo02Uoo`00
77oo0P00AWoo00<007ooOol0:Woo000LOol00`00Oomoo`14Ool00`00Oomoo`0[Ool001aoo`03001o
ogoo04Aoo`03001oogoo02]oo`0077oo0P00A7oo00<007ooOol0;7oo000LOol00`00Oomoo`13Ool0
0`00Oomoo`0/Ool001aoo`8004=oo`03001oogoo02eoo`002goo0P0017oo00<007ooOol00Woo0`00
0goo00<007ooOol0@Goo0P00;goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo045oo`03001oogoo02ioo`002Woo00@007ooOol000]oo`03001oogoo0080045oo`03001oogoo
02moo`002Woo00@007ooOol000]oo`04001oogoo0011Ool2000aOol000Yoo`04001oogoo0007Ool4
0003Ool00`00Oomoo`0oOol00`00Oomoo`0`Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2
000oOol2000bOol000]oo`8000Qoo`D0009oo`03001oogoo03ioo`03001oogoo035oo`0077oo00<0
07ooOol0?Goo00<007ooOol0<Woo000LOol2000mOol2000dOol001aoo`03001oogoo03aoo`03001o
ogoo03=oo`0077oo0P00?7oo00<007ooOol0=7oo000LOol00`00Oomoo`0jOol2000fOol001aoo`03
001oogoo03Yoo`03001oogoo03Eoo`0077oo0P00>Woo0P00=goo000FOol30003Ool00`00Oomoo`0h
Ool2000hOol001Moo`03001oogoo009oo`03001oogoo02Uoo`80009oo`80009oo`@0009oo`8003Uo
o`005goo00<007ooOol00Woo;@0000=oo`0000000Woo0P000goo1000>Woo000GOol00`00Oomoo`02
Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo
000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
00Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomo
o`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007oo
Ool02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yo
o`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
0001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(4509\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30118 m
.008 .30033 L
.012 .2987 L
.016 .29847 L
.02 .29962 L
.024 .29984 L
.028 .29922 L
.032 .2991 L
.036 .29937 L
.04 .29941 L
.044 .29929 L
.048 .29928 L
.052 .29932 L
.056 .29928 L
.06 .29925 L
.064 .2993 L
.068 .29933 L
.072 .29925 L
.076 .29919 L
.08 .29926 L
.084 .29935 L
.088 .29925 L
.092 .29911 L
.096 .29919 L
.1 .29936 L
.104 .2993 L
.108 .29907 L
.112 .29907 L
.116 .29931 L
.12 .29938 L
.124 .29913 L
.128 .29895 L
.132 .29915 L
.136 .2994 L
.14 .2993 L
.144 .29896 L
.148 .2989 L
.152 .29923 L
.156 .29947 L
.16 .29919 L
.164 .29879 L
.168 .29888 L
.172 .29934 L
.176 .29949 L
.18 .29907 L
.184 .29867 L
.188 .29886 L
.192 .29937 L
.196 .29951 L
.2 .29905 L
Mistroke
.204 .29859 L
.208 .29875 L
.212 .29932 L
.216 .29955 L
.22 .29915 L
.224 .29859 L
.228 .29855 L
.232 .29908 L
.236 .29956 L
.24 .29944 L
.244 .2988 L
.248 .29833 L
.252 .29857 L
.256 .29932 L
.26 .2998 L
.264 .29941 L
.268 .29844 L
.272 .29789 L
.276 .29848 L
.28 .29974 L
.284 .30033 L
.288 .29942 L
.292 .29776 L
.296 .29713 L
.3 .29842 L
.304 .3005 L
.308 .30117 L
.312 .29942 L
.316 .29682 L
.32 .29606 L
.324 .29821 L
.328 .30135 L
.332 .30231 L
.336 .29985 L
.34 .29613 L
.344 .29474 L
.348 .29722 L
.352 .30144 L
.356 .30351 L
.36 .30139 L
.364 .29686 L
.368 .29389 L
.372 .29507 L
.376 .29939 L
.38 .30319 L
.384 .30345 L
.388 .30012 L
.392 .29599 L
.396 .2941 L
.4 .29551 L
Mistroke
.404 .29882 L
.408 .30168 L
.412 .30259 L
.416 .30151 L
.42 .29932 L
.424 .29694 L
.428 .29507 L
.432 .29441 L
.436 .29567 L
.44 .29902 L
.444 .30332 L
.448 .30619 L
.452 .30525 L
.456 .30001 L
.46 .2927 L
.464 .28747 L
.468 .28785 L
.472 .29443 L
.476 .30412 L
.48 .3118 L
.484 .31327 L
.488 .30765 L
.492 .29781 L
.496 .28856 L
.5 .28395 L
.504 .28528 L
.508 .29096 L
.512 .29792 L
.516 .30363 L
.52 .30722 L
.524 .3093 L
.528 .31075 L
.532 .3115 L
.536 .31029 L
.54 .30548 L
.544 .29638 L
.548 .28433 L
.552 .27254 L
.556 .26498 L
.56 .26461 L
.564 .27216 L
.568 .28573 L
.572 .30181 L
.576 .31674 L
.58 .3283 L
.584 .3364 L
.588 .34277 L
.592 .34987 L
.596 .35956 L
.6 .37212 L
Mistroke
.604 .38612 L
.608 .399 L
.612 .40817 L
.616 .41208 L
.62 .41086 L
.624 .40625 L
.628 .40098 L
.632 .39781 L
.636 .3986 L
.64 .4038 L
.644 .41233 L
.648 .42204 L
.652 .43041 L
.656 .43531 L
.66 .43562 L
.664 .43141 L
.668 .42394 L
.672 .41522 L
.676 .4075 L
.68 .40276 L
.684 .40226 L
.688 .40639 L
.692 .41462 L
.696 .4257 L
.7 .43798 L
.704 .44965 L
.708 .45914 L
.712 .46521 L
.716 .46718 L
.72 .46486 L
.724 .45853 L
.728 .44882 L
.732 .43656 L
.736 .42269 L
.74 .40809 L
.744 .39355 L
.748 .3797 L
.752 .36699 L
.756 .35569 L
.76 .34593 L
.764 .33772 L
.768 .33097 L
.772 .32555 L
.776 .32128 L
.78 .31797 L
.784 .31547 L
.788 .3136 L
.792 .31223 L
.796 .31124 L
.8 .31053 L
Mistroke
.804 .31004 L
.808 .3097 L
.812 .30947 L
.816 .30931 L
.82 .30921 L
.824 .30914 L
.828 .30909 L
.832 .30906 L
.836 .30905 L
.84 .30903 L
.844 .30903 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .52321 m
.008 .51883 L
.012 .51733 L
.016 .5186 L
.02 .51919 L
.024 .51879 L
.028 .5186 L
.032 .51869 L
.036 .51878 L
.04 .51874 L
.044 .51872 L
.048 .51872 L
.052 .51874 L
.056 .51873 L
.06 .51874 L
.064 .51872 L
.068 .51873 L
.072 .51872 L
.076 .51873 L
.08 .51873 L
.084 .51873 L
.088 .51872 L
.092 .51873 L
.096 .51873 L
.1 .51873 L
.104 .51872 L
.108 .51873 L
.112 .51873 L
.116 .51874 L
.12 .51872 L
.124 .51872 L
.128 .51873 L
.132 .51874 L
.136 .51873 L
.14 .51872 L
.144 .51872 L
.148 .51874 L
.152 .51874 L
.156 .51873 L
.16 .51871 L
.164 .51872 L
.168 .51874 L
.172 .51874 L
.176 .51872 L
.18 .51871 L
.184 .51872 L
.188 .51874 L
.192 .51874 L
.196 .51872 L
.2 .5187 L
Mistroke
.204 .51872 L
.208 .51875 L
.212 .51875 L
.216 .51872 L
.22 .5187 L
.224 .51871 L
.228 .51874 L
.232 .51876 L
.236 .51874 L
.24 .5187 L
.244 .51869 L
.248 .51872 L
.252 .51876 L
.256 .51876 L
.26 .51872 L
.264 .51868 L
.268 .51868 L
.272 .51874 L
.276 .51878 L
.28 .51877 L
.284 .5187 L
.288 .51864 L
.292 .51867 L
.296 .51876 L
.3 .51882 L
.304 .51878 L
.308 .51867 L
.312 .51859 L
.316 .51865 L
.32 .51879 L
.324 .51888 L
.328 .51882 L
.332 .51865 L
.336 .51853 L
.34 .51859 L
.344 .51877 L
.348 .51893 L
.352 .5189 L
.356 .5187 L
.36 .5185 L
.364 .51848 L
.368 .51867 L
.372 .5189 L
.376 .51899 L
.38 .51887 L
.384 .51862 L
.388 .51845 L
.392 .51847 L
.396 .51867 L
.4 .51889 L
Mistroke
.404 .519 L
.408 .51893 L
.412 .51873 L
.416 .51853 L
.42 .51842 L
.424 .51846 L
.428 .51863 L
.432 .51887 L
.436 .51907 L
.44 .51912 L
.444 .51895 L
.448 .51861 L
.452 .51825 L
.456 .51807 L
.46 .51822 L
.464 .51868 L
.468 .51923 L
.472 .51959 L
.476 .51954 L
.48 .51907 L
.484 .51837 L
.488 .51778 L
.492 .51756 L
.496 .51782 L
.5 .51843 L
.504 .51914 L
.508 .5197 L
.512 .51995 L
.516 .51986 L
.52 .51951 L
.524 .51898 L
.528 .51834 L
.532 .51766 L
.536 .51703 L
.54 .5166 L
.544 .51656 L
.548 .51703 L
.552 .51806 L
.556 .51953 L
.56 .52116 L
.564 .52259 L
.568 .52353 L
.572 .52376 L
.576 .52325 L
.58 .52209 L
.584 .52042 L
.588 .51836 L
.592 .51593 L
.596 .51309 L
.6 .50974 L
Mistroke
.604 .50581 L
.608 .50132 L
.612 .49637 L
.616 .49117 L
.62 .48592 L
.624 .48082 L
.628 .47594 L
.632 .47126 L
.636 .46665 L
.64 .46196 L
.644 .45702 L
.648 .45175 L
.652 .44616 L
.656 .44035 L
.66 .43447 L
.664 .42872 L
.668 .42324 L
.672 .41813 L
.676 .41337 L
.68 .4089 L
.684 .40457 L
.688 .40019 L
.692 .39561 L
.696 .39067 L
.7 .38532 L
.704 .37953 L
.708 .37337 L
.712 .36695 L
.716 .36042 L
.72 .35394 L
.724 .34768 L
.728 .34178 L
.732 .33636 L
.736 .33148 L
.74 .32719 L
.744 .3235 L
.748 .32039 L
.752 .31782 L
.756 .31574 L
.76 .31407 L
.764 .31277 L
.768 .31176 L
.772 .311 L
.776 .31043 L
.78 .31002 L
.784 .30971 L
.788 .30949 L
.792 .30934 L
.796 .30924 L
.8 .30916 L
Mistroke
.804 .30911 L
.808 .30908 L
.812 .30906 L
.816 .30904 L
.82 .30903 L
.824 .30903 L
.828 .30902 L
.832 .30902 L
.836 .30902 L
.84 .30902 L
.844 .30902 L
.848 .30902 L
.852 .30902 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43348 L
.012 .42971 L
.016 .42861 L
.02 .42985 L
.024 .43019 L
.028 .42964 L
.032 .42951 L
.036 .42961 L
.04 .42962 L
.044 .4295 L
.048 .42946 L
.052 .42942 L
.056 .4294 L
.06 .42933 L
.064 .4293 L
.068 .42924 L
.072 .42921 L
.076 .42916 L
.08 .42913 L
.084 .42907 L
.088 .42903 L
.092 .42898 L
.096 .42895 L
.1 .42889 L
.104 .42885 L
.108 .4288 L
.112 .42877 L
.116 .42872 L
.12 .42867 L
.124 .42862 L
.128 .42859 L
.132 .42855 L
.136 .4285 L
.14 .42844 L
.144 .4284 L
.148 .42837 L
.152 .42834 L
.156 .42827 L
.16 .42821 L
.164 .42818 L
.168 .42816 L
.172 .42811 L
.176 .42805 L
.18 .42798 L
.184 .42796 L
.188 .42794 L
.192 .4279 L
.196 .42782 L
.2 .42776 L
Mistroke
.204 .42773 L
.208 .42772 L
.212 .42768 L
.216 .4276 L
.22 .42753 L
.224 .4275 L
.228 .42749 L
.232 .42747 L
.236 .4274 L
.24 .42731 L
.244 .42726 L
.248 .42725 L
.252 .42725 L
.256 .42721 L
.26 .42711 L
.264 .42702 L
.268 .42698 L
.272 .42701 L
.276 .42702 L
.28 .42695 L
.284 .42682 L
.288 .42671 L
.292 .4267 L
.296 .42677 L
.3 .4268 L
.304 .42671 L
.308 .42652 L
.312 .42639 L
.316 .42641 L
.32 .42654 L
.324 .4266 L
.328 .42649 L
.332 .42624 L
.336 .42605 L
.34 .42607 L
.344 .42626 L
.348 .4264 L
.352 .42632 L
.356 .42603 L
.36 .42574 L
.364 .42568 L
.368 .42586 L
.372 .42611 L
.376 .42618 L
.38 .42597 L
.384 .42562 L
.388 .42536 L
.392 .42535 L
.396 .42555 L
.4 .42579 L
Mistroke
.404 .42588 L
.408 .42574 L
.412 .42546 L
.416 .42516 L
.42 .42498 L
.424 .42498 L
.428 .42515 L
.432 .4254 L
.436 .42561 L
.44 .42563 L
.444 .42538 L
.448 .42491 L
.452 .42441 L
.456 .42415 L
.46 .42429 L
.464 .42482 L
.468 .42546 L
.472 .42587 L
.476 .42576 L
.48 .42512 L
.484 .42421 L
.488 .42343 L
.492 .42312 L
.496 .42339 L
.5 .42411 L
.504 .42495 L
.508 .4256 L
.512 .42587 L
.516 .42572 L
.52 .42524 L
.524 .42453 L
.528 .42369 L
.532 .4228 L
.536 .42197 L
.54 .4214 L
.544 .42129 L
.548 .42184 L
.552 .42309 L
.556 .42487 L
.56 .42685 L
.564 .4286 L
.568 .42971 L
.572 .42996 L
.576 .42928 L
.58 .42779 L
.584 .42566 L
.588 .42305 L
.592 .41998 L
.596 .4164 L
.6 .41218 L
Mistroke
.604 .40724 L
.608 .4016 L
.612 .3954 L
.616 .38887 L
.62 .3823 L
.624 .37591 L
.628 .36979 L
.632 .36392 L
.636 .35815 L
.64 .35227 L
.644 .34608 L
.648 .33948 L
.652 .33249 L
.656 .32522 L
.66 .31787 L
.664 .31068 L
.668 .30383 L
.672 .29743 L
.676 .29148 L
.68 .28589 L
.684 .28047 L
.688 .275 L
.692 .26926 L
.696 .2631 L
.7 .2564 L
.704 .24918 L
.708 .24148 L
.712 .23347 L
.716 .22532 L
.72 .21724 L
.724 .20943 L
.728 .20208 L
.732 .19531 L
.736 .18923 L
.74 .18388 L
.744 .17928 L
.748 .17541 L
.752 .1722 L
.756 .1696 L
.76 .16753 L
.764 .1659 L
.768 .16465 L
.772 .1637 L
.776 .16299 L
.78 .16247 L
.784 .16209 L
.788 .16182 L
.792 .16163 L
.796 .1615 L
.8 .16141 L
Mistroke
.804 .16134 L
.808 .1613 L
.812 .16128 L
.816 .16126 L
.82 .16125 L
.824 .16124 L
.828 .16123 L
.832 .16123 L
.836 .16123 L
.84 .16123 L
.844 .16123 L
.848 .16123 L
.852 .16123 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`800004Ool000000006Ool01000Oomoo`000Woo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool00`00Ool0
00060003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001o
ogoo02Yoo`80009oo`03001oogoo009oo`8003Moo`008Woo0`003goo00H007oo001oo`00Ool40000
0goo001oo`0400000goo001oo`0200001Goo00000000Ool00P0000Aoo`00Ool0009oo`03001oo`00
03Moo`008WooH`0037oo000ROol01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomo
ogoo0P000Woo0P000Woo00@007ooOol000=oo`05001oogooOol00003Ool00`00Ool000060003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000aoo`008Woo0P00=goo00<007ooOol03goo0P008Woo
000ROol00`00Oomoo`0fOol00`00Oomoo`0?Ool00`00Oomoo`0QOol0029oo`8003Moo`8000moo`03
001oogoo029oo`008Woo0P00>7oo00<007ooOol03Goo00<007ooOol08Woo000;Ool20004Ool00`00
Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0gOol00`00Oomoo`0<Ool00`00Oomoo`0SOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00>Goo00<007ooOol02goo00<0
07ooOol08goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8003Uoo`03
001oogoo00]oo`03001oogoo02=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`0hOol01000Ool000002Woo00<007ooOol08goo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8003Yoo`<000=oo`8000Aoo`03001oogoo02Aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2000jOol01000Oomoo`000Woo00<007oo0000
0goo00<007ooOol097oo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0lOol30002
Ool01@00Oomoogoo00009Woo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2000nOol0
1@00Oomoogoo00000Woo00<007ooOol09Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04
001oogoo0002Ool20013Ool00`00Ool0000WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0@Woo00<007oo00009goo000:Ool01000Oomoo`0027oo00@007oo
Ool000Aoo`04001oogooOol20014Ool00`00Oomoo`0VOol000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eo
o`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qo
o`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo
000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool0
0`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo
00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001o
ogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<0
07ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03
001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1V
Ool0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03
001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04
001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eo
o`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009o
o`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001o
ogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007oo
Oomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@00
0Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001o
ogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009o
o`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007oo
Ool000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001o
ogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo
000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomo
ogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomo
o`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0:Ool30002Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool0
02Qoo`03001oogoo041oo`8002Aoo`00:7oo00<007ooOol0@7oo00<007ooOol08goo000XOol00`00
Oomoo`0oOol00`00Oomoo`0TOol002Qoo`03001oogoo03ioo`8002Ioo`00:7oo00<007ooOol0?Woo
00<007ooOol09Goo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomo
o`0mOol00`00Oomoo`0VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0003Ool01000Oomoo`00?Woo0P00:7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0005Ool01000Oomoo`00?Goo0P00:Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04
001oogoo0005Ool00`00Oomoo`02000lOol00`00Oomoo`0XOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo03Yoo`03001oogoo02Uoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo03Uoo`03001oogoo
02Yoo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0>7oo0P00;7oo000XOol00`00
Oomoo`0hOol00`00Oomoo`0[Ool002Qoo`03001oogoo03Moo`03001oogoo02aoo`004Goo0P0017oo
00<007ooOol00goo0P000goo0`000goo00<007ooOol0=Woo00<007ooOol0;Goo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo03Eoo`03001oogoo02ioo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0dOol2000`Ool0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo=0000Woo0P00<Goo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo035oo`8003=oo`0047oo00@0
07ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03
001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomo
o`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo0080
06Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogoo
Ool5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009o
o`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;
Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001ao
o`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eo
o`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00
009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001o
ogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000L
Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Ao
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo1000
0goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`80
00Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Ao
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo0000
1Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P00
1Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Io
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00004Ool00`00Oomoo`030002Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0BWoo0P009Woo000L
Ool2001:Ool2000WOol001aoo`03001oogoo04Qoo`8002Qoo`0077oo00<007ooOol0B7oo00<007oo
Ool09goo000LOol20019Ool00`00Oomoo`0WOol001aoo`03001oogoo04Moo`03001oogoo02Qoo`00
77oo00<007ooOol0Agoo00<007ooOol0:7oo000LOol20017Ool00`00Oomoo`0YOol001aoo`03001o
ogoo04Ioo`03001oogoo02Uoo`0077oo0P00AWoo00<007ooOol0:Woo000;Ool20004Ool00`00Oomo
o`02Ool30003Ool00`00Oomoo`14Ool00`00Oomoo`0[Ool000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0@goo0P00;Goo000:Ool01000Oomoo`002goo00<007ooOol00P00A7oo
00<007ooOol0;7oo000:Ool01000Oomoo`002goo00@007ooOol004Aoo`03001oogoo02eoo`002Woo
00@007ooOol000Moo`@000=oo`03001oogoo045oo`8002moo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`80049oo`03001oogoo02ioo`002goo0P0027oo1@000Woo00<007ooOol0@Goo00<007oo
Ool0;Woo000LOol00`00Oomoo`10Ool00`00Oomoo`0_Ool001aoo`80041oo`03001oogoo031oo`00
77oo00<007ooOol0?goo00<007ooOol0<7oo000LOol2000oOol00`00Oomoo`0aOol001aoo`03001o
ogoo03eoo`03001oogoo039oo`0077oo00<007ooOol0?7oo0P00=7oo000LOol2000mOol00`00Oomo
o`0cOol001Ioo`<000=oo`03001oogoo03]oo`8003Eoo`005goo00<007ooOol00Woo00<007ooOol0
;7oo0P0000Eoo`00000007oo00@000=oo`8003Ioo`005goo00<007ooOol00Woo<`0000Aoo`000000
00=oo`@003Moo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00
Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol0
0`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol0
00]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]o
o`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol0
1goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]o
o`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(4676\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30103 m
.008 .2995 L
.012 .29898 L
.016 .29892 L
.02 .29943 L
.024 .29967 L
.028 .2994 L
.032 .29923 L
.036 .29934 L
.04 .29941 L
.044 .29935 L
.048 .29932 L
.052 .29935 L
.056 .29933 L
.06 .29929 L
.064 .29931 L
.068 .29937 L
.072 .29931 L
.076 .29923 L
.08 .29927 L
.084 .29937 L
.088 .29932 L
.092 .29917 L
.096 .29919 L
.1 .29936 L
.104 .29936 L
.108 .29916 L
.112 .2991 L
.116 .29928 L
.12 .2994 L
.124 .29923 L
.128 .29903 L
.132 .29913 L
.136 .29937 L
.14 .29937 L
.144 .29908 L
.148 .29894 L
.152 .29919 L
.156 .29946 L
.16 .29929 L
.164 .29891 L
.168 .29889 L
.172 .29929 L
.176 .29949 L
.18 .29917 L
.184 .29878 L
.188 .29888 L
.192 .29934 L
.196 .29951 L
.2 .29912 L
Mistroke
.204 .29868 L
.208 .2988 L
.212 .29933 L
.216 .29954 L
.22 .29915 L
.224 .29865 L
.228 .29866 L
.232 .29917 L
.236 .29956 L
.24 .29934 L
.244 .29875 L
.248 .29846 L
.252 .29882 L
.256 .29944 L
.26 .29964 L
.264 .29915 L
.268 .29842 L
.272 .29824 L
.276 .29891 L
.28 .29979 L
.284 .29989 L
.288 .29894 L
.292 .29783 L
.296 .29783 L
.3 .29914 L
.304 .30049 L
.308 .30031 L
.312 .29853 L
.316 .29689 L
.32 .29726 L
.324 .29954 L
.328 .30148 L
.332 .30092 L
.336 .29811 L
.34 .29576 L
.344 .29638 L
.348 .29965 L
.352 .30249 L
.356 .30199 L
.36 .29838 L
.364 .29493 L
.368 .29495 L
.372 .2986 L
.376 .30265 L
.38 .30346 L
.384 .30023 L
.388 .29573 L
.392 .29378 L
.396 .29593 L
.4 .3003 L
Mistroke
.404 .30336 L
.408 .30288 L
.412 .29953 L
.416 .29596 L
.42 .29455 L
.424 .29582 L
.428 .29856 L
.432 .30105 L
.436 .30225 L
.44 .30194 L
.444 .30032 L
.448 .29774 L
.452 .29496 L
.456 .29333 L
.46 .29429 L
.464 .29824 L
.468 .30367 L
.472 .30747 L
.476 .30676 L
.48 .30097 L
.484 .29271 L
.488 .28659 L
.492 .28648 L
.496 .29305 L
.5 .30314 L
.504 .31152 L
.508 .31386 L
.512 .30911 L
.516 .29983 L
.52 .29057 L
.524 .28523 L
.528 .28523 L
.532 .28937 L
.536 .29508 L
.54 .30026 L
.544 .30426 L
.548 .30758 L
.552 .31082 L
.556 .31353 L
.56 .31406 L
.564 .31041 L
.568 .30162 L
.572 .28884 L
.576 .27532 L
.58 .26525 L
.584 .26205 L
.588 .26699 L
.592 .2787 L
.596 .2939 L
.6 .30891 L
Mistroke
.604 .32116 L
.608 .33011 L
.612 .33714 L
.616 .3446 L
.62 .35451 L
.624 .36747 L
.628 .38238 L
.632 .39682 L
.636 .40808 L
.64 .4142 L
.644 .41481 L
.648 .4112 L
.652 .40592 L
.656 .40182 L
.66 .4012 L
.664 .40502 L
.668 .41275 L
.672 .42256 L
.676 .43199 L
.68 .43868 L
.684 .44103 L
.688 .43862 L
.692 .43222 L
.696 .42357 L
.7 .41489 L
.704 .40833 L
.708 .40555 L
.712 .40737 L
.716 .41372 L
.72 .42369 L
.724 .43579 L
.728 .44828 L
.732 .4594 L
.736 .46772 L
.74 .47224 L
.744 .47246 L
.748 .46841 L
.752 .46052 L
.756 .4495 L
.76 .43625 L
.764 .42169 L
.768 .40668 L
.772 .39196 L
.776 .3781 L
.78 .36549 L
.784 .35437 L
.788 .34482 L
.792 .33682 L
.796 .33026 L
.8 .32501 L
Mistroke
.804 .32088 L
.808 .31769 L
.812 .31527 L
.816 .31346 L
.82 .31214 L
.824 .31118 L
.828 .3105 L
.832 .31002 L
.836 .30969 L
.84 .30946 L
.844 .30931 L
.848 .3092 L
.852 .30914 L
.856 .30909 L
.86 .30906 L
.864 .30905 L
.868 .30903 L
.872 .30903 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51412 m
.008 .51859 L
.012 .52005 L
.016 .51838 L
.02 .51797 L
.024 .51854 L
.028 .5187 L
.032 .51846 L
.036 .51844 L
.04 .5185 L
.044 .51853 L
.048 .51849 L
.052 .5185 L
.056 .51849 L
.06 .51851 L
.064 .51849 L
.068 .5185 L
.072 .51849 L
.076 .5185 L
.08 .5185 L
.084 .5185 L
.088 .51849 L
.092 .5185 L
.096 .5185 L
.1 .5185 L
.104 .51849 L
.108 .51849 L
.112 .5185 L
.116 .5185 L
.12 .51849 L
.124 .51849 L
.128 .51849 L
.132 .5185 L
.136 .5185 L
.14 .51849 L
.144 .51849 L
.148 .5185 L
.152 .51851 L
.156 .5185 L
.16 .51848 L
.164 .51849 L
.168 .5185 L
.172 .51851 L
.176 .51849 L
.18 .51848 L
.184 .51849 L
.188 .51851 L
.192 .51851 L
.196 .51849 L
.2 .51847 L
Mistroke
.204 .51849 L
.208 .51851 L
.212 .51851 L
.216 .51849 L
.22 .51847 L
.224 .51848 L
.228 .51851 L
.232 .51852 L
.236 .5185 L
.24 .51847 L
.244 .51847 L
.248 .5185 L
.252 .51852 L
.256 .51851 L
.26 .51848 L
.264 .51845 L
.268 .51847 L
.272 .51851 L
.276 .51854 L
.28 .51851 L
.284 .51846 L
.288 .51843 L
.292 .51847 L
.296 .51854 L
.3 .51856 L
.304 .5185 L
.308 .51842 L
.312 .5184 L
.316 .51848 L
.32 .51858 L
.324 .5186 L
.328 .5185 L
.332 .51838 L
.336 .51836 L
.34 .51846 L
.344 .51861 L
.348 .51865 L
.352 .51853 L
.356 .51836 L
.36 .51829 L
.364 .5184 L
.368 .51861 L
.372 .51871 L
.376 .51862 L
.38 .5184 L
.384 .51825 L
.388 .51828 L
.392 .51849 L
.396 .51869 L
.4 .51874 L
Mistroke
.404 .51859 L
.408 .51836 L
.412 .51822 L
.416 .51826 L
.42 .51844 L
.424 .51864 L
.428 .51874 L
.432 .5187 L
.436 .51853 L
.44 .51833 L
.444 .51819 L
.448 .51819 L
.452 .51834 L
.456 .51859 L
.46 .51884 L
.464 .51894 L
.468 .51879 L
.472 .51843 L
.476 .51802 L
.48 .51779 L
.484 .51791 L
.488 .51836 L
.492 .51894 L
.496 .51935 L
.5 .51937 L
.504 .51895 L
.508 .51828 L
.512 .51766 L
.516 .51737 L
.52 .51751 L
.524 .51801 L
.528 .51866 L
.532 .51923 L
.536 .51958 L
.54 .51966 L
.544 .51948 L
.548 .51908 L
.552 .5185 L
.556 .5178 L
.56 .51706 L
.564 .51643 L
.568 .51614 L
.572 .51637 L
.576 .51718 L
.58 .51852 L
.584 .52014 L
.588 .5217 L
.592 .52288 L
.596 .52345 L
.6 .52334 L
Mistroke
.604 .52258 L
.608 .52131 L
.612 .51962 L
.616 .51755 L
.62 .51506 L
.624 .51206 L
.628 .50846 L
.632 .50426 L
.636 .49954 L
.64 .49449 L
.644 .48931 L
.648 .4842 L
.652 .47929 L
.656 .47458 L
.66 .46999 L
.664 .46536 L
.668 .46055 L
.672 .45542 L
.676 .44996 L
.68 .44423 L
.684 .43837 L
.688 .43255 L
.692 .42694 L
.696 .42166 L
.7 .41675 L
.704 .41216 L
.708 .40778 L
.712 .40346 L
.716 .399 L
.72 .39427 L
.724 .38915 L
.728 .38361 L
.732 .37765 L
.736 .37137 L
.74 .3649 L
.744 .35838 L
.748 .35197 L
.752 .34584 L
.756 .34011 L
.76 .33488 L
.764 .33021 L
.768 .32612 L
.772 .32262 L
.776 .31969 L
.78 .31727 L
.784 .31531 L
.788 .31375 L
.792 .31253 L
.796 .31159 L
.8 .31088 L
Mistroke
.804 .31035 L
.808 .30996 L
.812 .30967 L
.816 .30947 L
.82 .30932 L
.824 .30922 L
.828 .30915 L
.832 .30911 L
.836 .30908 L
.84 .30906 L
.844 .30904 L
.848 .30903 L
.852 .30903 L
.856 .30902 L
.86 .30902 L
.864 .30902 L
.868 .30902 L
.872 .30902 L
.876 .30902 L
.88 .30902 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43338 L
.012 .43001 L
.016 .42875 L
.02 .42966 L
.024 .43011 L
.028 .42974 L
.032 .42955 L
.036 .42957 L
.04 .42961 L
.044 .42952 L
.048 .42947 L
.052 .42941 L
.056 .42939 L
.06 .42934 L
.064 .4293 L
.068 .42924 L
.072 .42921 L
.076 .42916 L
.08 .42913 L
.084 .42907 L
.088 .42903 L
.092 .42898 L
.096 .42895 L
.1 .4289 L
.104 .42885 L
.108 .4288 L
.112 .42877 L
.116 .42872 L
.12 .42868 L
.124 .42862 L
.128 .42858 L
.132 .42855 L
.136 .4285 L
.14 .42844 L
.144 .4284 L
.148 .42837 L
.152 .42833 L
.156 .42828 L
.16 .42822 L
.164 .42818 L
.168 .42815 L
.172 .42811 L
.176 .42805 L
.18 .42799 L
.184 .42796 L
.188 .42794 L
.192 .4279 L
.196 .42783 L
.2 .42776 L
Mistroke
.204 .42773 L
.208 .42772 L
.212 .42768 L
.216 .42761 L
.22 .42754 L
.224 .4275 L
.228 .42749 L
.232 .42746 L
.236 .42739 L
.24 .42732 L
.244 .42727 L
.248 .42726 L
.252 .42725 L
.256 .42719 L
.26 .42711 L
.264 .42703 L
.268 .42701 L
.272 .42702 L
.276 .427 L
.28 .42692 L
.284 .42681 L
.288 .42674 L
.292 .42675 L
.296 .42678 L
.3 .42677 L
.304 .42665 L
.308 .42651 L
.312 .42644 L
.316 .42649 L
.32 .42656 L
.324 .42655 L
.328 .42639 L
.332 .42619 L
.336 .42611 L
.34 .42621 L
.344 .42634 L
.348 .42635 L
.352 .42616 L
.356 .42589 L
.36 .42577 L
.364 .42587 L
.368 .42607 L
.372 .42616 L
.376 .426 L
.38 .42569 L
.384 .42545 L
.388 .42545 L
.392 .42566 L
.396 .42588 L
.4 .42589 L
Mistroke
.404 .42566 L
.408 .42533 L
.412 .42511 L
.416 .42512 L
.42 .4253 L
.424 .4255 L
.428 .42559 L
.432 .42548 L
.436 .42523 L
.44 .42494 L
.444 .42472 L
.448 .42467 L
.452 .42482 L
.456 .42509 L
.46 .42535 L
.464 .42543 L
.468 .42521 L
.472 .42471 L
.476 .42416 L
.48 .42383 L
.484 .42393 L
.488 .42444 L
.492 .42512 L
.496 .4256 L
.5 .42557 L
.504 .42501 L
.508 .42413 L
.512 .42331 L
.516 .4229 L
.52 .42304 L
.524 .42361 L
.528 .42438 L
.532 .42505 L
.536 .42545 L
.54 .4255 L
.544 .42523 L
.548 .42469 L
.552 .42393 L
.556 .423 L
.56 .42203 L
.564 .42121 L
.568 .42081 L
.572 .42104 L
.576 .42202 L
.58 .42364 L
.584 .42561 L
.588 .42751 L
.592 .42894 L
.596 .42961 L
.6 .42942 L
Mistroke
.604 .42844 L
.608 .4268 L
.612 .42465 L
.616 .42203 L
.62 .41888 L
.624 .4151 L
.628 .41057 L
.632 .4053 L
.636 .39938 L
.64 .39304 L
.644 .38654 L
.648 .38015 L
.652 .37399 L
.656 .36809 L
.66 .36233 L
.664 .35653 L
.668 .3505 L
.672 .34408 L
.676 .33724 L
.68 .33008 L
.684 .32274 L
.688 .31547 L
.692 .30845 L
.696 .30185 L
.7 .2957 L
.704 .28997 L
.708 .28449 L
.712 .27908 L
.716 .27351 L
.72 .26759 L
.724 .2612 L
.728 .25427 L
.732 .24683 L
.736 .23899 L
.74 .23091 L
.744 .22278 L
.748 .21479 L
.752 .20714 L
.756 .19999 L
.76 .19347 L
.764 .18764 L
.768 .18255 L
.772 .17819 L
.776 .17452 L
.78 .17151 L
.784 .16906 L
.788 .16712 L
.792 .1656 L
.796 .16443 L
.8 .16355 L
Mistroke
.804 .16288 L
.808 .1624 L
.812 .16204 L
.816 .16179 L
.82 .16161 L
.824 .16148 L
.828 .1614 L
.832 .16134 L
.836 .1613 L
.84 .16127 L
.844 .16126 L
.848 .16125 L
.852 .16124 L
.856 .16123 L
.86 .16123 L
.864 .16123 L
.868 .16123 L
.872 .16123 L
.876 .16123 L
.88 .16123 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`8000Eoo`04001oogoo0002Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo
02eoo`03001oogoo008000=oo`03001oo`0003Aoo`008Woo0P004Woo00H007oo001oo`00Ool20000
1Goo001oo`00Ool0100000Aoo`00001oo`800004Ool00000Ool20002Ool20003Ool00`00Ool0000d
Ool0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00@007ooOol000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo0000
0P000Woo0P000goo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoogoo1`0000=oo`00
Ool00Woo00D007ooOomoo`0000=oo`03001oogoo00Yoo`008Woo0P00>Goo00<007ooOol047oo00<0
07ooOol07Woo000ROol00`00Oomoo`0hOol2000@Ool2000POol0029oo`8003Yoo`03001oogoo00io
o`03001oogoo01moo`008Woo0P00>goo00<007ooOol03Goo00<007ooOol07goo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0jOol00`00Oomoo`0<Ool00`00Oomoo`0POol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00>goo00<007ooOol037oo
00<007ooOol087oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8003]o
o`03001oogoo00aoo`03001oogoo021oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`0kOol00`00Ool0000:Ool00`00Oomoo`0QOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P00?7oo10000goo0P0017oo00<007ooOol08Goo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8003aoo`800007Ool007ooOol007oo0000
17oo00<007ooOol08Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0oOol01@00
Ool007oo000017oo00<007ooOol08Goo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2
0010Ool20003Ool01000Oomoo`0097oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0002Ool20015Ool01000Oomoo`0097oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo04Aoo`03001oo`0002Eoo`002Woo00@007ooOol000Qoo`04001oogoo
0004Ool01000Oomoogoo0P00AWoo0P009Goo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo
001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomo
o`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007oo
Ool000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00
KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<0
06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0
JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001W
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Io
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1V
Ool000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2
000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1V
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00
J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomo
o`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02
000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool2
0004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002
Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo
00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007oo
Ool0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001o
ogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool0
02Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo
00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<0
07ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=o
o`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<0
07ooOol03goo00<007ooOol03Goo0`004Woo00<007ooOol02Woo000XOol00`00Oomoo`13Ool00`00
Oomoo`0POol002Qoo`03001oogoo049oo`03001oogoo025oo`00:7oo00<007ooOol0@Woo00<007oo
Ool08Goo000XOol00`00Oomoo`11Ool00`00Oomoo`0ROol002Qoo`03001oogoo041oo`03001oogoo
02=oo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0?goo0P00
9Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol0
045oo`03001oogoo02Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOol0041oo`03001oogoo02Eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol00P00?Woo00<007ooOol09Woo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`05001oogoo001oo`040003Ool00`00Oomoo`0lOol00`00Oomoo`0WOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0kOol2000YOol000]o
o`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo03]oo`03001oogoo02Qoo`00:7oo00<007oo
Ool0>Woo00<007ooOol0:Goo000XOol00`00Oomoo`0iOol00`00Oomoo`0ZOol0015oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`03001oogoo03Qoo`8002aoo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0hOol00`00Oomoo`0[Ool0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0=goo00<007ooOol0;7oo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oocL00003Ool0000002moo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0cOol3000`Ool0011oo`04
001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007oo
Ool006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02
001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomo
ogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02
Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`00
2goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000L
Ool00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005
Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol0
0002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00
Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`00
77oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo
00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@0
00=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool2
0004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`00
00Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`80
00Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006
Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogoo
Ool00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo000017oo00H007ooOomoo`00Ool30003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000Aoo`03001oogoo00Yoo`0077oo00<007ooOol0CGoo00<007ooOol08Woo000L
Ool2001=Ool00`00Oomoo`0SOol001aoo`03001oogoo04]oo`8002Eoo`0077oo00<007ooOol0Bgoo
00<007ooOol097oo000LOol2001<Ool00`00Oomoo`0TOol001aoo`03001oogoo04Yoo`03001oogoo
02Eoo`0077oo00<007ooOol0BGoo00<007ooOol09Woo000LOol2001:Ool00`00Oomoo`0VOol001ao
o`03001oogoo04Qoo`03001oogoo02Moo`0077oo0P00BGoo00<007ooOol09goo000;Ool20004Ool0
0`00Oomoo`02Ool30003Ool00`00Oomoo`17Ool00`00Oomoo`0XOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0AWoo00<007ooOol0:Goo000:Ool01000Oomoo`002goo00<0
07ooOol00P00Agoo00<007ooOol0:Goo000:Ool01000Oomoo`002goo00@007ooOol004Moo`03001o
ogoo02Yoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo04Aoo`03001oogoo02]oo`002Woo
00@007ooOol000Moo`03001oogoo00Aoo`8004Eoo`03001oogoo02]oo`002goo0P0027oo1@000Woo
00<007ooOol0@goo00<007ooOol0;7oo000LOol00`00Oomoo`13Ool00`00Oomoo`0/Ool001aoo`80
04=oo`03001oogoo02eoo`0077oo00<007ooOol0@Goo00<007ooOol0;Woo000LOol20012Ool00`00
Oomoo`0^Ool001aoo`03001oogoo041oo`03001oogoo02moo`0077oo00<007ooOol0?goo0P00<Goo
000LOol20010Ool00`00Oomoo`0`Ool001Ioo`<000=oo`03001oogoo03ioo`03001oogoo035oo`00
5goo00<007ooOol00Woo00<007ooOol0;7oo00<007oo00000P0000Eoo`00000007oo00@0009oo`<0
03=oo`005goo00<007ooOol00Woo<P0000=oo`0000000Woo0`000goo0`00=Goo000GOol00`00Oomo
o`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00
Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1b
Ool000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007oo
Oomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<0
07ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol0
00Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(4843\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29793 m
.008 .2985 L
.012 .30002 L
.016 .30022 L
.02 .29916 L
.024 .29897 L
.028 .29952 L
.032 .29961 L
.036 .29936 L
.04 .2993 L
.044 .29938 L
.048 .29941 L
.052 .2994 L
.056 .29936 L
.06 .29932 L
.064 .29934 L
.068 .2994 L
.072 .29936 L
.076 .29927 L
.08 .29929 L
.084 .29939 L
.088 .29937 L
.092 .29924 L
.096 .29922 L
.1 .29935 L
.104 .2994 L
.108 .29925 L
.112 .29915 L
.116 .29927 L
.12 .2994 L
.124 .29932 L
.128 .29912 L
.132 .29913 L
.136 .29934 L
.14 .29942 L
.144 .29919 L
.148 .299 L
.152 .29916 L
.156 .29944 L
.16 .29937 L
.164 .29902 L
.168 .29893 L
.172 .29925 L
.176 .29949 L
.18 .29927 L
.184 .29889 L
.188 .2989 L
.192 .2993 L
.196 .29952 L
.2 .2992 L
Mistroke
.204 .29878 L
.208 .29884 L
.212 .29932 L
.216 .29954 L
.22 .29919 L
.224 .29873 L
.228 .29874 L
.232 .29922 L
.236 .29955 L
.24 .2993 L
.244 .29876 L
.248 .29858 L
.252 .29898 L
.256 .29949 L
.26 .29953 L
.264 .29901 L
.268 .29847 L
.272 .29853 L
.276 .29918 L
.28 .29974 L
.284 .29955 L
.288 .29871 L
.292 .29805 L
.296 .29839 L
.3 .2995 L
.304 .30022 L
.308 .29963 L
.312 .29816 L
.316 .29735 L
.32 .29825 L
.324 .30012 L
.328 .30098 L
.332 .29969 L
.336 .29736 L
.34 .29641 L
.344 .29805 L
.348 .30086 L
.352 .30197 L
.356 .29999 L
.36 .29666 L
.364 .29525 L
.368 .29735 L
.372 .30117 L
.376 .30307 L
.38 .30109 L
.384 .29688 L
.388 .29426 L
.392 .29569 L
.396 .29998 L
.4 .30339 L
Mistroke
.404 .30296 L
.408 .29909 L
.412 .29503 L
.416 .29405 L
.42 .29675 L
.424 .30083 L
.428 .30319 L
.432 .30235 L
.436 .29929 L
.44 .29626 L
.444 .29502 L
.448 .29587 L
.452 .29798 L
.456 .30032 L
.46 .30207 L
.464 .30262 L
.468 .30146 L
.472 .29852 L
.476 .29475 L
.48 .29218 L
.484 .29289 L
.488 .29745 L
.492 .30393 L
.496 .30863 L
.5 .3082 L
.504 .30203 L
.508 .29299 L
.512 .28603 L
.516 .2853 L
.52 .2916 L
.524 .30183 L
.528 .31079 L
.532 .31405 L
.536 .31035 L
.54 .30192 L
.544 .29291 L
.548 .28703 L
.552 .28577 L
.556 .28829 L
.56 .29253 L
.564 .29685 L
.568 .30085 L
.572 .30507 L
.576 .3099 L
.58 .3146 L
.584 .31713 L
.588 .31509 L
.592 .30717 L
.596 .29422 L
.6 .27937 L
Mistroke
.604 .26698 L
.608 .2609 L
.612 .26299 L
.616 .27243 L
.62 .28632 L
.624 .301 L
.628 .31363 L
.632 .32325 L
.636 .33084 L
.64 .33858 L
.644 .34858 L
.648 .3618 L
.652 .37746 L
.656 .39335 L
.66 .40669 L
.664 .41518 L
.668 .41793 L
.672 .41574 L
.676 .41085 L
.68 .40614 L
.684 .4042 L
.688 .40654 L
.692 .41317 L
.696 .42271 L
.7 .43286 L
.704 .44113 L
.708 .44555 L
.712 .44517 L
.716 .44026 L
.72 .43218 L
.724 .423 L
.728 .41497 L
.732 .41004 L
.736 .40946 L
.74 .41361 L
.744 .42199 L
.748 .43338 L
.752 .44614 L
.756 .45847 L
.76 .46875 L
.764 .47571 L
.768 .47856 L
.772 .47701 L
.776 .47128 L
.78 .46191 L
.784 .4497 L
.788 .43557 L
.792 .42042 L
.796 .40509 L
.8 .39026 L
Mistroke
.804 .37643 L
.808 .36397 L
.812 .35304 L
.816 .34371 L
.82 .33592 L
.824 .32956 L
.828 .32448 L
.832 .32048 L
.836 .31741 L
.84 .31507 L
.844 .31333 L
.848 .31205 L
.852 .31112 L
.856 .31046 L
.86 .31 L
.864 .30967 L
.868 .30945 L
.872 .3093 L
.876 .3092 L
.88 .30914 L
.884 .30909 L
.888 .30906 L
.892 .30905 L
.896 .30904 L
.9 .30903 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51303 m
.008 .51815 L
.012 .51997 L
.016 .51835 L
.02 .51773 L
.024 .51819 L
.028 .51845 L
.032 .51828 L
.036 .51822 L
.04 .51824 L
.044 .51829 L
.048 .51826 L
.052 .51827 L
.056 .51826 L
.06 .51827 L
.064 .51826 L
.068 .51827 L
.072 .51826 L
.076 .51827 L
.08 .51826 L
.084 .51827 L
.088 .51826 L
.092 .51827 L
.096 .51826 L
.1 .51827 L
.104 .51826 L
.108 .51826 L
.112 .51826 L
.116 .51827 L
.12 .51826 L
.124 .51826 L
.128 .51826 L
.132 .51827 L
.136 .51827 L
.14 .51826 L
.144 .51826 L
.148 .51826 L
.152 .51827 L
.156 .51827 L
.16 .51825 L
.164 .51826 L
.168 .51827 L
.172 .51827 L
.176 .51826 L
.18 .51825 L
.184 .51825 L
.188 .51827 L
.192 .51827 L
.196 .51826 L
.2 .51825 L
Mistroke
.204 .51825 L
.208 .51827 L
.212 .51828 L
.216 .51826 L
.22 .51824 L
.224 .51825 L
.228 .51827 L
.232 .51828 L
.236 .51826 L
.24 .51824 L
.244 .51824 L
.248 .51827 L
.252 .51829 L
.256 .51827 L
.26 .51824 L
.264 .51823 L
.268 .51825 L
.272 .51828 L
.276 .51829 L
.28 .51826 L
.284 .51822 L
.288 .51822 L
.292 .51826 L
.296 .5183 L
.3 .5183 L
.304 .51825 L
.308 .5182 L
.312 .51821 L
.316 .51828 L
.32 .51833 L
.324 .51831 L
.328 .51823 L
.332 .51816 L
.336 .51819 L
.34 .51829 L
.344 .51838 L
.348 .51834 L
.352 .51821 L
.356 .51811 L
.36 .51814 L
.364 .51829 L
.368 .51842 L
.372 .5184 L
.376 .51823 L
.38 .51808 L
.384 .51807 L
.388 .51823 L
.392 .51842 L
.396 .51847 L
.4 .51834 L
Mistroke
.404 .51812 L
.408 .51801 L
.412 .51809 L
.416 .51829 L
.42 .51847 L
.424 .51848 L
.428 .51833 L
.432 .51813 L
.436 .51801 L
.44 .51804 L
.444 .5182 L
.448 .51839 L
.452 .51849 L
.456 .51847 L
.46 .51833 L
.464 .51813 L
.468 .51796 L
.472 .51791 L
.476 .51804 L
.48 .51832 L
.484 .51861 L
.488 .51875 L
.492 .51863 L
.496 .51826 L
.5 .51781 L
.504 .51753 L
.508 .5176 L
.512 .51803 L
.516 .51863 L
.52 .51909 L
.524 .51917 L
.528 .51882 L
.532 .5182 L
.536 .51757 L
.54 .51721 L
.544 .51723 L
.548 .51761 L
.552 .51818 L
.556 .51875 L
.56 .51917 L
.564 .51938 L
.568 .51937 L
.572 .51913 L
.576 .51865 L
.58 .51797 L
.584 .51716 L
.588 .51638 L
.592 .51586 L
.596 .51583 L
.6 .5164 L
Mistroke
.604 .51756 L
.608 .51909 L
.612 .52071 L
.616 .52207 L
.62 .52294 L
.624 .52318 L
.628 .52281 L
.632 .52192 L
.636 .52061 L
.64 .5189 L
.644 .51678 L
.648 .51414 L
.652 .5109 L
.656 .50702 L
.66 .50257 L
.664 .49771 L
.668 .49263 L
.672 .48755 L
.676 .48262 L
.68 .47788 L
.684 .47329 L
.688 .46872 L
.692 .46401 L
.696 .45902 L
.7 .45371 L
.704 .44808 L
.708 .44227 L
.712 .43642 L
.716 .4307 L
.72 .42527 L
.724 .42019 L
.728 .41546 L
.732 .411 L
.736 .40667 L
.74 .40231 L
.744 .39775 L
.748 .39285 L
.752 .38755 L
.756 .38182 L
.76 .37573 L
.764 .36935 L
.768 .36285 L
.772 .35636 L
.776 .35006 L
.78 .34407 L
.784 .33851 L
.788 .33347 L
.792 .329 L
.796 .32511 L
.8 .3218 L
Mistroke
.804 .31902 L
.808 .31675 L
.812 .31491 L
.816 .31345 L
.82 .3123 L
.824 .31143 L
.828 .31076 L
.832 .31027 L
.836 .3099 L
.84 .30963 L
.844 .30944 L
.848 .30931 L
.852 .30921 L
.856 .30915 L
.86 .3091 L
.864 .30907 L
.868 .30905 L
.872 .30904 L
.876 .30903 L
.88 .30903 L
.884 .30902 L
.888 .30902 L
.892 .30902 L
.896 .30902 L
.9 .30902 L
.904 .30902 L
.908 .30902 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42703 L
.012 .43002 L
.016 .43088 L
.02 .42966 L
.024 .42939 L
.028 .42973 L
.032 .42979 L
.036 .42957 L
.04 .42953 L
.044 .42952 L
.048 .4295 L
.052 .42942 L
.056 .42939 L
.06 .42933 L
.064 .42931 L
.068 .42924 L
.072 .42921 L
.076 .42916 L
.08 .42913 L
.084 .42907 L
.088 .42903 L
.092 .42898 L
.096 .42895 L
.1 .4289 L
.104 .42885 L
.108 .4288 L
.112 .42877 L
.116 .42872 L
.12 .42868 L
.124 .42862 L
.128 .42858 L
.132 .42855 L
.136 .42851 L
.14 .42845 L
.144 .4284 L
.148 .42836 L
.152 .42833 L
.156 .42828 L
.16 .42822 L
.164 .42818 L
.168 .42815 L
.172 .42811 L
.176 .42806 L
.18 .42799 L
.184 .42796 L
.188 .42793 L
.192 .42789 L
.196 .42783 L
.2 .42777 L
Mistroke
.204 .42773 L
.208 .42771 L
.212 .42767 L
.216 .42761 L
.22 .42754 L
.224 .42751 L
.228 .42749 L
.232 .42746 L
.236 .42739 L
.24 .42732 L
.244 .42728 L
.248 .42726 L
.252 .42724 L
.256 .42719 L
.26 .4271 L
.264 .42704 L
.268 .42702 L
.272 .42702 L
.276 .42699 L
.28 .42691 L
.284 .42682 L
.288 .42677 L
.292 .42677 L
.296 .42678 L
.3 .42673 L
.304 .42662 L
.308 .42652 L
.312 .42649 L
.316 .42653 L
.32 .42655 L
.324 .42649 L
.328 .42633 L
.332 .4262 L
.336 .4262 L
.34 .42629 L
.344 .42634 L
.348 .42625 L
.352 .42605 L
.356 .42588 L
.36 .42588 L
.364 .42602 L
.368 .42613 L
.372 .42606 L
.376 .42581 L
.38 .42557 L
.384 .42552 L
.388 .42568 L
.392 .42587 L
.396 .42589 L
.4 .42568 L
Mistroke
.404 .42537 L
.408 .42518 L
.412 .42523 L
.416 .42545 L
.42 .42562 L
.424 .4256 L
.428 .42536 L
.432 .42506 L
.436 .42487 L
.44 .42487 L
.444 .42503 L
.448 .42521 L
.452 .4253 L
.456 .42523 L
.46 .42502 L
.464 .42472 L
.468 .42446 L
.472 .42436 L
.476 .42448 L
.48 .42478 L
.484 .4251 L
.488 .42523 L
.492 .42503 L
.496 .42452 L
.5 .42392 L
.504 .42353 L
.508 .42358 L
.512 .42407 L
.516 .42477 L
.52 .42529 L
.524 .42536 L
.528 .42488 L
.532 .42405 L
.536 .42323 L
.54 .42273 L
.544 .42272 L
.548 .42315 L
.552 .42381 L
.556 .42448 L
.56 .42496 L
.564 .42518 L
.568 .42512 L
.572 .42478 L
.576 .42414 L
.58 .42325 L
.584 .42219 L
.588 .42118 L
.592 .42049 L
.596 .4204 L
.6 .42108 L
Mistroke
.604 .42247 L
.608 .42435 L
.612 .42631 L
.616 .42797 L
.62 .429 L
.624 .42926 L
.628 .42875 L
.632 .4276 L
.636 .42591 L
.64 .42375 L
.644 .42105 L
.648 .41772 L
.652 .41364 L
.656 .40877 L
.66 .40318 L
.664 .39707 L
.668 .39071 L
.672 .38434 L
.676 .37816 L
.68 .37222 L
.684 .36647 L
.688 .36074 L
.692 .35483 L
.696 .34859 L
.7 .34193 L
.704 .3349 L
.708 .32762 L
.712 .3203 L
.716 .31316 L
.72 .30636 L
.724 .30001 L
.728 .29409 L
.732 .28851 L
.736 .2831 L
.74 .27764 L
.744 .27194 L
.748 .26582 L
.752 .25919 L
.756 .25204 L
.76 .24443 L
.764 .23647 L
.768 .22836 L
.772 .22026 L
.776 .2124 L
.78 .20493 L
.784 .198 L
.788 .19171 L
.792 .18614 L
.796 .18129 L
.8 .17716 L
Mistroke
.804 .1737 L
.808 .17086 L
.812 .16857 L
.816 .16675 L
.82 .16532 L
.824 .16423 L
.828 .1634 L
.832 .16278 L
.836 .16233 L
.84 .16199 L
.844 .16176 L
.848 .16159 L
.852 .16147 L
.856 .16139 L
.86 .16133 L
.864 .1613 L
.868 .16127 L
.872 .16126 L
.876 .16124 L
.88 .16124 L
.884 .16123 L
.888 .16123 L
.892 .16123 L
.896 .16123 L
.9 .16123 L
.904 .16123 L
.908 .16123 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo0080009oo`04001oogoo0002Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04
001oogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04
001oogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029o
o`03001oogoo02moo`05001oogooOol00004Ool00`00Ool0000aOol0029oo`8001Aoo`04001oo`00
Ool400000goo001oo`0400000goo001oo`02000017oo000007oo0`0000Moo`00001oo`00Ool00002
Ool01000Oomoo`00<Goo000ROomS000<Ool0029oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`04001oogoo0003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`04001oogooOol20002Ool300000goo001oo`020003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`H0009oo`05001oogooOol00003Ool00`00Oomoo`0:Ool0029oo`8003aoo`03001o
ogoo00moo`8001eoo`008Woo00<007ooOol0>goo00<007ooOol03goo00<007ooOol077oo000ROol2
000mOol00`00Oomoo`0>Ool00`00Oomoo`0LOol0029oo`8003eoo`03001oogoo00eoo`03001oogoo
01eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0?7oo00<007ooOol0
3Goo00<007ooOol07Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
03ioo`03001oogoo00]oo`03001oogoo01ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool2000nOol00`00Oomoo`0;Ool00`00Oomoo`0NOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0?Goo00<007ooOol02goo00<007ooOol07Woo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8003ioo`04001oo`000003
Ool20005Ool00`00Oomoo`0NOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00
?goo0P0000Aoo`00Oomoo`8000Aoo`03001oogoo01moo`002goo0P002Woo0P0017oo00<007ooOol0
0Woo00<007ooOol0@Goo00H007oo000007oo0003Ool00`00Oomoo`0OOol000]oo`8000Aoo`03001o
ogoo00=oo`80009oo`D0009oo`80049oo`<0009oo`05001oogooOol0000QOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8004=oo`80009oo`05001oogooOol0000QOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0Agoo00<007oo
00008Woo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol20018Ool00`00Ool0
000ROol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008004Uoo`03001o
ogoo025oo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo
0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<0
07ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03
001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0
009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P00
2Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2
001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Ao
o`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
00]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0
009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Ao
o`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=o
o`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00
Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`00
00=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D0
07ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomo
o`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo
00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007oo
Ool02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`00
0Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool5
0003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`00
17oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool0
0`00Oomoo`0?Ool2000AOol00`00Oomoo`0:Ool002Qoo`03001oogoo04Eoo`8001moo`00:7oo00<0
07ooOol0A7oo0P0087oo000XOol00`00Oomoo`14Ool00`00Oomoo`0OOol002Qoo`03001oogoo04=o
o`03001oogoo021oo`00:7oo00<007ooOol0@goo00<007ooOol087oo000;Ool20004Ool00`00Oomo
o`03Ool20004Ool20003Ool30003Ool00`00Oomoo`12Ool00`00Oomoo`0QOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00@goo0P008goo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00@Woo0P0097oo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`020010Ool2000U
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo
03moo`03001oogoo02Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool0
00Ioo`03001oogoo03ioo`03001oogoo02Eoo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<0
07ooOol0?Goo00<007ooOol09Woo000XOol00`00Oomoo`0lOol2000XOol002Qoo`03001oogoo03ao
o`03001oogoo02Moo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0>goo
00<007ooOol0:7oo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo03Yoo`03001oogoo02Uoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`0iOol00`00Oomoo`0ZOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo>@0000Aoo`00000002aoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`0eOol3000^Ool0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P00
17oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<0
07ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`00
2goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007oo
Ool000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=o
o`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool3
0004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool3
0004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03
001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001o
o`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009o
o`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00
77oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001o
ogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol0
00Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eo
o`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool3
0004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D0
07ooOomoo`0000=oo`D000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool0
01aoo`03001oogoo04moo`80025oo`0077oo0P00D7oo00<007ooOol087oo000LOol00`00Oomoo`1>
Ool00`00Oomoo`0QOol001aoo`03001oogoo04ioo`03001oogoo025oo`0077oo0P00CWoo00<007oo
Ool08Woo000LOol00`00Oomoo`1=Ool00`00Oomoo`0ROol001aoo`03001oogoo04aoo`03001oogoo
02=oo`0077oo0P00CGoo00<007ooOol08goo000LOol00`00Oomoo`1;Ool00`00Oomoo`0TOol001ao
o`8004aoo`03001oogoo02Aoo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0BWoo
00<007ooOol09Goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo04Uoo`03
001oogoo02Ioo`002Woo00@007ooOol000]oo`03001oogoo008004Uoo`03001oogoo02Moo`002Woo
00@007ooOol000]oo`04001oogoo001:Ool00`00Oomoo`0WOol000Yoo`04001oogoo0007Ool40003
Ool00`00Oomoo`17Ool00`00Oomoo`0XOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool20017
Ool2000ZOol000]oo`8000Qoo`D0009oo`03001oogoo04Ioo`03001oogoo02Uoo`0077oo00<007oo
Ool0AWoo00<007ooOol0:Goo000LOol20016Ool00`00Oomoo`0ZOol001aoo`03001oogoo04Aoo`03
001oogoo02]oo`0077oo0P00A7oo00<007ooOol0;7oo000LOol00`00Oomoo`13Ool00`00Oomoo`0/
Ool001aoo`03001oogoo049oo`03001oogoo02eoo`0077oo0P00@Woo0P00;goo000FOol30003Ool0
0`00Oomoo`11Ool00`00Oomoo`0^Ool001Moo`03001oogoo009oo`03001oogoo02ioo`03001oo`00
00800003Ool0000000800003Ool000000080009oo`80035oo`005goo00<007ooOol00Woo<@0000=o
o`0000000Woo0P000Woo0P000goo1000<Woo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Mo
o`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo
009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079o
o`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00
Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Ao
o`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(5010\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .2976 m
.008 .29921 L
.012 .29998 L
.016 .30007 L
.02 .29938 L
.024 .29909 L
.028 .29942 L
.032 .29961 L
.036 .29948 L
.04 .29936 L
.044 .29938 L
.048 .29943 L
.052 .29945 L
.056 .29941 L
.06 .29935 L
.064 .29936 L
.068 .29943 L
.072 .29941 L
.076 .29933 L
.08 .29931 L
.084 .2994 L
.088 .29941 L
.092 .29931 L
.096 .29926 L
.1 .29935 L
.104 .29942 L
.108 .29933 L
.112 .29921 L
.116 .29926 L
.12 .2994 L
.124 .29939 L
.128 .29921 L
.132 .29915 L
.136 .29931 L
.14 .29944 L
.144 .29929 L
.148 .29907 L
.152 .29915 L
.156 .29941 L
.16 .29942 L
.164 .29913 L
.168 .29898 L
.172 .29921 L
.176 .29947 L
.18 .29935 L
.184 .299 L
.188 .29893 L
.192 .29927 L
.196 .29951 L
.2 .29928 L
Mistroke
.204 .29888 L
.208 .29888 L
.212 .2993 L
.216 .29953 L
.22 .29925 L
.224 .29881 L
.228 .29881 L
.232 .29925 L
.236 .29955 L
.24 .2993 L
.244 .29881 L
.248 .29868 L
.252 .29908 L
.256 .29952 L
.26 .29945 L
.264 .29895 L
.268 .29856 L
.272 .29875 L
.276 .29933 L
.28 .29965 L
.284 .29932 L
.288 .29863 L
.292 .29831 L
.296 .29879 L
.3 .29963 L
.304 .29991 L
.308 .29919 L
.312 .29812 L
.316 .29789 L
.32 .29891 L
.324 .30022 L
.328 .30033 L
.332 .29891 L
.336 .29731 L
.34 .29733 L
.344 .29919 L
.348 .30108 L
.352 .3009 L
.356 .29855 L
.36 .29631 L
.364 .29657 L
.368 .29934 L
.372 .302 L
.376 .30177 L
.38 .29862 L
.384 .29545 L
.388 .2954 L
.392 .29871 L
.396 .30242 L
.4 .30303 L
Mistroke
.404 .29984 L
.408 .29563 L
.412 .29414 L
.416 .2967 L
.42 .30113 L
.424 .30365 L
.428 .30224 L
.432 .29816 L
.436 .29474 L
.44 .29451 L
.444 .29737 L
.448 .30098 L
.452 .30282 L
.456 .30197 L
.46 .29938 L
.464 .29678 L
.468 .29542 L
.472 .29563 L
.476 .29717 L
.48 .29955 L
.484 .30203 L
.488 .30348 L
.492 .30269 L
.496 .29928 L
.5 .29449 L
.504 .29102 L
.508 .29151 L
.512 .29661 L
.516 .30405 L
.52 .3096 L
.524 .30955 L
.528 .30319 L
.532 .29355 L
.536 .28582 L
.54 .28436 L
.544 .29014 L
.548 .30025 L
.552 .30961 L
.556 .31379 L
.56 .31129 L
.564 .30395 L
.568 .29548 L
.572 .2893 L
.576 .28693 L
.58 .28783 L
.584 .29043 L
.588 .29358 L
.592 .29717 L
.596 .30187 L
.6 .308 L
Mistroke
.604 .31459 L
.608 .31928 L
.612 .31926 L
.616 .31275 L
.62 .3002 L
.624 .28453 L
.628 .27014 L
.632 .26126 L
.636 .26032 L
.64 .26717 L
.644 .27932 L
.648 .29326 L
.652 .30594 L
.656 .31599 L
.66 .32399 L
.664 .3319 L
.668 .34188 L
.672 .35517 L
.676 .37138 L
.68 .38855 L
.684 .40391 L
.688 .41486 L
.692 .42002 L
.696 .41965 L
.7 .4156 L
.704 .41064 L
.708 .40759 L
.712 .40842 L
.716 .41373 L
.72 .42263 L
.724 .43312 L
.728 .44269 L
.732 .44908 L
.736 .45087 L
.74 .4478 L
.744 .44079 L
.748 .43163 L
.752 .42256 L
.756 .41573 L
.76 .41277 L
.764 .41452 L
.768 .4209 L
.772 .43106 L
.776 .44353 L
.78 .45657 L
.784 .46843 L
.788 .47762 L
.792 .48305 L
.796 .48415 L
.8 .48086 L
Mistroke
.804 .4735 L
.808 .46275 L
.812 .44946 L
.816 .43455 L
.82 .41892 L
.824 .40334 L
.828 .38846 L
.832 .37472 L
.836 .36242 L
.84 .35171 L
.844 .3426 L
.848 .33503 L
.852 .32887 L
.856 .32395 L
.86 .3201 L
.864 .31713 L
.868 .31487 L
.872 .31319 L
.876 .31196 L
.88 .31107 L
.884 .31043 L
.888 .30998 L
.892 .30966 L
.896 .30945 L
.9 .3093 L
.904 .3092 L
.908 .30914 L
.912 .30909 L
.916 .30906 L
.92 .30905 L
.924 .30904 L
.928 .30903 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .52147 m
.008 .51789 L
.012 .51682 L
.016 .51814 L
.02 .51849 L
.024 .51795 L
.028 .51789 L
.032 .51805 L
.036 .5181 L
.04 .51801 L
.044 .51802 L
.048 .51803 L
.052 .51805 L
.056 .51802 L
.06 .51804 L
.064 .51803 L
.068 .51804 L
.072 .51803 L
.076 .51804 L
.08 .51803 L
.084 .51804 L
.088 .51803 L
.092 .51803 L
.096 .51803 L
.1 .51804 L
.104 .51803 L
.108 .51803 L
.112 .51803 L
.116 .51804 L
.12 .51803 L
.124 .51803 L
.128 .51803 L
.132 .51804 L
.136 .51804 L
.14 .51803 L
.144 .51802 L
.148 .51803 L
.152 .51804 L
.156 .51804 L
.16 .51803 L
.164 .51802 L
.168 .51803 L
.172 .51804 L
.176 .51803 L
.18 .51802 L
.184 .51802 L
.188 .51804 L
.192 .51804 L
.196 .51803 L
.2 .51802 L
Mistroke
.204 .51802 L
.208 .51804 L
.212 .51804 L
.216 .51803 L
.22 .51801 L
.224 .51802 L
.228 .51804 L
.232 .51805 L
.236 .51803 L
.24 .51801 L
.244 .51801 L
.248 .51803 L
.252 .51805 L
.256 .51804 L
.26 .51801 L
.264 .518 L
.268 .51802 L
.272 .51805 L
.276 .51805 L
.28 .51802 L
.284 .518 L
.288 .518 L
.292 .51804 L
.296 .51806 L
.3 .51805 L
.304 .518 L
.308 .51798 L
.312 .518 L
.316 .51806 L
.32 .51808 L
.324 .51805 L
.328 .51798 L
.332 .51795 L
.336 .518 L
.34 .51808 L
.344 .51811 L
.348 .51805 L
.352 .51795 L
.356 .51791 L
.36 .51799 L
.364 .51811 L
.368 .51815 L
.372 .51806 L
.376 .51792 L
.38 .51786 L
.384 .51796 L
.388 .51812 L
.392 .5182 L
.396 .51812 L
.4 .51794 L
Mistroke
.404 .51782 L
.408 .51787 L
.412 .51805 L
.416 .51822 L
.42 .51822 L
.424 .51806 L
.428 .51786 L
.432 .51778 L
.436 .51789 L
.44 .51808 L
.444 .51823 L
.448 .51823 L
.452 .51808 L
.456 .5179 L
.46 .51779 L
.464 .51782 L
.468 .51795 L
.472 .51812 L
.476 .51825 L
.48 .51826 L
.484 .51814 L
.488 .51793 L
.492 .51773 L
.496 .51764 L
.5 .51775 L
.504 .51804 L
.508 .51838 L
.512 .51856 L
.516 .51846 L
.52 .51808 L
.524 .5176 L
.528 .51728 L
.532 .51731 L
.536 .51771 L
.54 .5183 L
.544 .5188 L
.548 .51895 L
.552 .51868 L
.556 .51812 L
.56 .5175 L
.564 .51708 L
.568 .517 L
.572 .51725 L
.576 .51772 L
.58 .51825 L
.584 .51871 L
.588 .51904 L
.592 .51919 L
.596 .51911 L
.6 .51877 L
Mistroke
.604 .51815 L
.608 .51732 L
.612 .51643 L
.616 .51571 L
.62 .51543 L
.624 .51574 L
.628 .51667 L
.632 .51807 L
.636 .51967 L
.64 .52116 L
.644 .52225 L
.648 .5228 L
.652 .52279 L
.656 .52227 L
.66 .52132 L
.664 .51998 L
.668 .51823 L
.672 .51597 L
.676 .5131 L
.68 .50958 L
.684 .50544 L
.688 .5008 L
.692 .49586 L
.696 .49084 L
.7 .48591 L
.704 .48115 L
.708 .47656 L
.712 .47202 L
.716 .4674 L
.72 .46255 L
.724 .45738 L
.728 .45189 L
.732 .44615 L
.736 .4403 L
.74 .43452 L
.744 .42895 L
.748 .4237 L
.752 .41882 L
.756 .41424 L
.76 .40987 L
.764 .40555 L
.768 .40112 L
.772 .39642 L
.776 .39135 L
.78 .38586 L
.784 .37998 L
.788 .37376 L
.792 .36732 L
.796 .36081 L
.8 .35439 L
Mistroke
.804 .34819 L
.808 .34236 L
.812 .33698 L
.816 .33214 L
.82 .32786 L
.824 .32416 L
.828 .32102 L
.832 .31841 L
.836 .31626 L
.84 .31453 L
.844 .31317 L
.848 .3121 L
.852 .31128 L
.856 .31065 L
.86 .31019 L
.864 .30985 L
.868 .3096 L
.872 .30942 L
.876 .30929 L
.88 .3092 L
.884 .30914 L
.888 .3091 L
.892 .30907 L
.896 .30905 L
.9 .30904 L
.904 .30903 L
.908 .30903 L
.912 .30902 L
.916 .30902 L
.92 .30902 L
.924 .30902 L
.928 .30902 L
.932 .30902 L
.936 .30902 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42598 L
.012 .42973 L
.016 .43113 L
.02 .42985 L
.024 .42934 L
.028 .42963 L
.032 .4298 L
.036 .42962 L
.04 .42953 L
.044 .4295 L
.048 .4295 L
.052 .42942 L
.056 .42939 L
.06 .42933 L
.064 .42931 L
.068 .42925 L
.072 .42921 L
.076 .42916 L
.08 .42912 L
.084 .42907 L
.088 .42903 L
.092 .42898 L
.096 .42895 L
.1 .4289 L
.104 .42886 L
.108 .4288 L
.112 .42877 L
.116 .42872 L
.12 .42868 L
.124 .42862 L
.128 .42858 L
.132 .42854 L
.136 .42851 L
.14 .42845 L
.144 .4284 L
.148 .42836 L
.152 .42833 L
.156 .42828 L
.16 .42823 L
.164 .42818 L
.168 .42815 L
.172 .42811 L
.176 .42806 L
.18 .428 L
.184 .42796 L
.188 .42793 L
.192 .42789 L
.196 .42783 L
.2 .42777 L
Mistroke
.204 .42773 L
.208 .42771 L
.212 .42767 L
.216 .42761 L
.22 .42755 L
.224 .42751 L
.228 .42749 L
.232 .42746 L
.236 .42739 L
.24 .42733 L
.244 .42728 L
.248 .42727 L
.252 .42724 L
.256 .42718 L
.26 .42711 L
.264 .42705 L
.268 .42703 L
.272 .42702 L
.276 .42698 L
.28 .4269 L
.284 .42682 L
.288 .42679 L
.292 .42678 L
.296 .42677 L
.3 .42671 L
.304 .42661 L
.308 .42654 L
.312 .42652 L
.316 .42654 L
.32 .42653 L
.324 .42644 L
.328 .42632 L
.332 .42624 L
.336 .42626 L
.34 .42631 L
.344 .4263 L
.348 .42618 L
.352 .42601 L
.356 .42593 L
.36 .42598 L
.364 .42609 L
.368 .42609 L
.372 .42594 L
.376 .42572 L
.38 .4256 L
.384 .42567 L
.388 .42583 L
.392 .42589 L
.396 .42574 L
.4 .42548 L
Mistroke
.404 .42528 L
.408 .4253 L
.412 .42549 L
.416 .42564 L
.42 .4256 L
.424 .42536 L
.428 .42507 L
.432 .42493 L
.436 .42501 L
.44 .42522 L
.444 .42535 L
.448 .4253 L
.452 .42508 L
.456 .42481 L
.46 .42463 L
.464 .42462 L
.468 .42474 L
.472 .42491 L
.476 .42503 L
.48 .425 L
.484 .42481 L
.488 .4245 L
.492 .4242 L
.496 .42405 L
.5 .42414 L
.504 .42446 L
.508 .42483 L
.512 .42502 L
.516 .42485 L
.52 .42434 L
.524 .42369 L
.528 .42325 L
.532 .42324 L
.536 .42369 L
.54 .42439 L
.544 .42496 L
.548 .42511 L
.552 .42473 L
.556 .42398 L
.56 .42317 L
.564 .42261 L
.568 .42246 L
.572 .42273 L
.576 .42327 L
.58 .42389 L
.584 .42442 L
.588 .42479 L
.592 .42493 L
.596 .42478 L
.6 .42431 L
Mistroke
.604 .4235 L
.608 .42242 L
.612 .42126 L
.616 .42033 L
.62 .41993 L
.624 .42028 L
.628 .4214 L
.632 .4231 L
.636 .42505 L
.64 .42686 L
.644 .42817 L
.648 .42882 L
.652 .42876 L
.656 .42806 L
.66 .42683 L
.664 .42512 L
.668 .42289 L
.672 .42003 L
.676 .41641 L
.68 .41198 L
.684 .40678 L
.688 .40096 L
.692 .39477 L
.696 .38847 L
.7 .38229 L
.704 .37633 L
.708 .37056 L
.712 .36488 L
.716 .35908 L
.72 .35301 L
.724 .34654 L
.728 .33966 L
.732 .33248 L
.736 .32516 L
.74 .31792 L
.744 .31096 L
.748 .3044 L
.752 .29829 L
.756 .29257 L
.76 .2871 L
.764 .2817 L
.768 .27615 L
.772 .27027 L
.776 .26394 L
.78 .25709 L
.784 .24974 L
.788 .24197 L
.792 .23394 L
.796 .22582 L
.8 .2178 L
Mistroke
.804 .21007 L
.808 .20279 L
.812 .19609 L
.816 .19005 L
.82 .18472 L
.824 .18011 L
.828 .17619 L
.832 .17293 L
.836 .17026 L
.84 .1681 L
.844 .1664 L
.848 .16506 L
.852 .16404 L
.856 .16327 L
.86 .16269 L
.864 .16226 L
.868 .16195 L
.872 .16173 L
.876 .16157 L
.88 .16146 L
.884 .16138 L
.888 .16133 L
.892 .16129 L
.896 .16127 L
.9 .16125 L
.904 .16124 L
.908 .16124 L
.912 .16123 L
.916 .16123 L
.92 .16123 L
.924 .16123 L
.928 .16123 L
.932 .16123 L
.936 .16123 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00=oo`80009oo`04001oogoo0003Ool0
1000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00003Ool00`00Ool00006Ool01000Oomo
o`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomo
ogoo1`0000=oo`00000017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol0
0`00Oomoo`0aOol20002Ool20003Ool00`00Ool0000_Ool0029oo`8001Ioo`03001oo`0000<00005
Ool007oo001oo`0400000goo0000000200001Goo00000000Ool00P0000Aoo`00001oo`@0009oo`03
001oo`0002moo`008WooH`0037oo000ROol01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000Woo0P000goo0P0000Ioo`00Ool007oo0003Ool01@00Oomoogoo00000goo00H0
07ooOomoo`00Ool70003Ool01@00Oomoogoo000037oo000ROol2000nOol00`00Oomoo`0@Ool2000J
Ool0029oo`03001oogoo03ioo`03001oogoo00moo`03001oogoo01Uoo`008Woo0P00?goo00<007oo
Ool03Woo00<007ooOol06Woo000ROol20010Ool00`00Oomoo`0=Ool00`00Oomoo`0JOol000]oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo03moo`03001oogoo00eoo`03001oogoo
01Yoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20010Ool00`00Oomo
o`0<Ool00`00Oomoo`0KOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00@7oo00<007ooOol037oo00<007ooOol06goo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo03moo`03001oogoo00aoo`03001oogoo01]oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20011Ool01000Ool000002Goo00<007ooOol0
77oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`80045oo`800003Ool007oo009o
o`8000Aoo`03001oogoo01aoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0@goo
00H007ooOol007oo0004Ool00`00Oomoo`0LOol000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0
009oo`8004Eoo`05001oo`00Ool00004Ool00`00Oomoo`0LOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol0009oo`8004Eoo`8000=oo`04001oogoo000OOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0BGoo00@007ooOol001moo`002Woo
00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00Bgoo00<007oo00007goo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001;Ool2000POol000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001=Ool00`00Oomoo`0NOol000]oo`8000Yo
o`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo
0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001o
ogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomo
o`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`80
00Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool2
0004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007
Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002
Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@0
00=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001o
ogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogoo
Ool00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo
0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001o
ogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uo
o`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`80
00=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo
0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`80
00Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007oo
Ool03goo00<007oo00000P003Woo00<007ooOol02Woo000XOol00`00Oomoo`18Ool00`00Oomoo`0K
Ool002Qoo`03001oogoo04Moo`03001oogoo01aoo`00:7oo00<007ooOol0AWoo0P007Woo000XOol0
0`00Oomoo`16Ool00`00Oomoo`0MOol002Qoo`03001oogoo04Eoo`03001oogoo01ioo`002goo0P00
17oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0A7oo0P0087oo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol004Ioo`03001oogoo
01moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol004Eo
o`03001oogoo021oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol00P00@goo00<007ooOol08Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001o
ogoo001oo`040003Ool00`00Oomoo`11Ool2000SOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00H007ooOol007oo0006Ool00`00Oomoo`10Ool2000TOol000]oo`8000Yoo`8000Aoo`80009o
o`D0009oo`03001oogoo041oo`03001oogoo02=oo`00:7oo00<007ooOol0?goo00<007ooOol097oo
000XOol00`00Oomoo`0nOol2000VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03
001oogoo03eoo`03001oogoo02Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`0lOol2000XOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0>goo0P00:Goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009ooc`00003Ool0000002Yoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`0hOol2000/Ool0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007oo
Ool0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo
00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol0
00Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`00
2goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004
Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004
Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001o
ogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`00
0goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03
001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo
0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo
00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Ao
o`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D0
00=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004
Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007oo
Oomoo`0000=oo`03001oogoo00<0009oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomo
o`0:Ool001aoo`03001oogoo059oo`8001ioo`0077oo0P00Dgoo00<007ooOol07Goo000LOol00`00
Oomoo`1AOol00`00Oomoo`0NOol001aoo`03001oogoo051oo`80021oo`0077oo0P00DGoo00<007oo
Ool07goo000LOol00`00Oomoo`1?Ool00`00Oomoo`0POol001aoo`03001oogoo04moo`03001oogoo
021oo`0077oo0P00Cgoo0P008Woo000LOol00`00Oomoo`1>Ool00`00Oomoo`0QOol001aoo`8004io
o`03001oogoo029oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0CGoo00<007oo
Ool08Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo04aoo`03001oogoo
02=oo`002Woo00@007ooOol000]oo`03001oogoo008004aoo`03001oogoo02Aoo`002Woo00@007oo
Ool000]oo`04001oogoo001=Ool00`00Oomoo`0TOol000Yoo`04001oogoo0007Ool40003Ool00`00
Oomoo`1:Ool00`00Oomoo`0UOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001:Ool00`00
Oomoo`0VOol000]oo`8000Qoo`D0009oo`03001oogoo04Uoo`03001oogoo02Ioo`0077oo00<007oo
Ool0B7oo00<007ooOol09goo000LOol20019Ool00`00Oomoo`0WOol001aoo`03001oogoo04Moo`03
001oogoo02Qoo`0077oo0P00Agoo00<007ooOol0:Goo000LOol00`00Oomoo`16Ool00`00Oomoo`0Y
Ool001aoo`03001oogoo04Eoo`03001oogoo02Yoo`0077oo0P00AGoo00<007ooOol0:goo000FOol3
0003Ool00`00Oomoo`13Ool2000]Ool001Moo`03001oogoo009oo`03001oogoo02eoo`03001oogoo
00800005Ool00000001oo`090002Ool2000^Ool001Moo`03001oogoo009ooc000003Ool00000009o
o`800003Ool0000000=oo`8000=oo`@002moo`005goo00<007ooOol00Woo00<007ooOol0LWoo000G
Ool00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol00Woo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomo
o`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo0080
07=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04
Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo
000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(5177\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30069 m
.008 .30041 L
.012 .299 L
.016 .29881 L
.02 .29975 L
.024 .29987 L
.028 .29934 L
.032 .29928 L
.036 .29955 L
.04 .29956 L
.044 .29941 L
.048 .29939 L
.052 .29948 L
.056 .29948 L
.06 .2994 L
.064 .29939 L
.068 .29945 L
.072 .29945 L
.076 .29938 L
.08 .29935 L
.084 .29941 L
.088 .29944 L
.092 .29938 L
.096 .29931 L
.1 .29936 L
.104 .29943 L
.108 .2994 L
.112 .29928 L
.116 .29928 L
.12 .29939 L
.124 .29943 L
.128 .2993 L
.132 .29919 L
.136 .2993 L
.14 .29945 L
.144 .29937 L
.148 .29916 L
.152 .29916 L
.156 .29938 L
.16 .29946 L
.164 .29924 L
.168 .29905 L
.172 .2992 L
.176 .29945 L
.18 .29941 L
.184 .29911 L
.188 .29898 L
.192 .29924 L
.196 .2995 L
.2 .29936 L
Mistroke
.204 .29898 L
.208 .29892 L
.212 .29928 L
.216 .29953 L
.22 .29931 L
.224 .2989 L
.228 .29886 L
.232 .29925 L
.236 .29954 L
.24 .29932 L
.244 .29887 L
.248 .29876 L
.252 .29915 L
.256 .29953 L
.26 .29942 L
.264 .29894 L
.268 .29865 L
.272 .29891 L
.276 .29941 L
.28 .29958 L
.284 .29919 L
.288 .29864 L
.292 .29854 L
.296 .29905 L
.3 .29965 L
.304 .29965 L
.308 .29895 L
.312 .29824 L
.316 .29835 L
.32 .29929 L
.324 .30009 L
.328 .29979 L
.332 .29852 L
.336 .2976 L
.34 .29815 L
.344 .29977 L
.348 .30078 L
.352 .29991 L
.356 .29786 L
.36 .29674 L
.364 .29793 L
.368 .30041 L
.372 .30165 L
.376 .30016 L
.38 .2972 L
.384 .29572 L
.388 .29739 L
.392 .30079 L
.396 .30264 L
.4 .30095 L
Mistroke
.404 .29714 L
.408 .29474 L
.412 .29612 L
.416 .30016 L
.42 .30322 L
.424 .30249 L
.428 .29854 L
.432 .29479 L
.436 .29445 L
.44 .29776 L
.444 .30191 L
.448 .30354 L
.452 .30149 L
.456 .29756 L
.46 .29479 L
.464 .29501 L
.468 .29771 L
.472 .30081 L
.476 .30237 L
.48 .3018 L
.484 .29978 L
.488 .29744 L
.492 .29571 L
.496 .29517 L
.5 .29619 L
.504 .29878 L
.508 .30211 L
.512 .30444 L
.516 .30395 L
.52 .30003 L
.524 .29426 L
.528 .28993 L
.532 .29017 L
.536 .2957 L
.54 .30398 L
.544 .31035 L
.548 .31078 L
.552 .30445 L
.556 .29442 L
.56 .28599 L
.564 .28369 L
.568 .28873 L
.572 .29847 L
.576 .30804 L
.58 .31306 L
.584 .31185 L
.588 .30579 L
.592 .29813 L
.596 .29193 L
.6 .28868 L
Mistroke
.604 .28806 L
.608 .28895 L
.612 .29064 L
.616 .29342 L
.62 .29814 L
.624 .30518 L
.628 .31346 L
.632 .32035 L
.636 .32265 L
.64 .31805 L
.644 .30651 L
.648 .29058 L
.652 .27461 L
.656 .26312 L
.66 .25913 L
.664 .26312 L
.668 .27316 L
.672 .28594 L
.676 .29832 L
.68 .30855 L
.684 .31678 L
.688 .32471 L
.692 .33452 L
.696 .34768 L
.7 .3642 L
.704 .38243 L
.708 .39966 L
.712 .4131 L
.716 .42089 L
.72 .42271 L
.724 .41996 L
.728 .41518 L
.732 .4113 L
.736 .4107 L
.74 .41454 L
.744 .42248 L
.748 .4329 L
.752 .44341 L
.756 .45159 L
.76 .4556 L
.764 .45464 L
.768 .44914 L
.772 .44054 L
.776 .43092 L
.78 .42255 L
.784 .41736 L
.788 .41661 L
.792 .42069 L
.796 .42913 L
.8 .44076 L
Mistroke
.804 .45396 L
.808 .46693 L
.812 .47803 L
.816 .48591 L
.82 .4897 L
.824 .48903 L
.828 .48401 L
.832 .47511 L
.836 .46308 L
.84 .44882 L
.844 .43324 L
.848 .41721 L
.852 .40147 L
.856 .38659 L
.86 .37297 L
.864 .36086 L
.868 .35038 L
.872 .3415 L
.876 .33415 L
.88 .32819 L
.884 .32344 L
.888 .31971 L
.892 .31685 L
.896 .31468 L
.9 .31306 L
.904 .31187 L
.908 .31101 L
.912 .31039 L
.916 .30995 L
.92 .30965 L
.924 .30944 L
.928 .30929 L
.932 .3092 L
.936 .30913 L
.94 .30909 L
.944 .30906 L
.948 .30905 L
.952 .30904 L
.956 .30903 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .52369 m
.008 .51785 L
.012 .51591 L
.016 .51771 L
.02 .51844 L
.024 .51783 L
.028 .51761 L
.032 .51777 L
.036 .51788 L
.04 .5178 L
.044 .51779 L
.048 .51779 L
.052 .51782 L
.056 .5178 L
.06 .5178 L
.064 .5178 L
.068 .51781 L
.072 .5178 L
.076 .5178 L
.08 .5178 L
.084 .51781 L
.088 .5178 L
.092 .5178 L
.096 .5178 L
.1 .51781 L
.104 .5178 L
.108 .5178 L
.112 .5178 L
.116 .5178 L
.12 .5178 L
.124 .5178 L
.128 .5178 L
.132 .5178 L
.136 .5178 L
.14 .5178 L
.144 .51779 L
.148 .5178 L
.152 .5178 L
.156 .51781 L
.16 .5178 L
.164 .51779 L
.168 .5178 L
.172 .51781 L
.176 .5178 L
.18 .51779 L
.184 .51779 L
.188 .5178 L
.192 .51781 L
.196 .5178 L
.2 .51779 L
Mistroke
.204 .51779 L
.208 .5178 L
.212 .51781 L
.216 .5178 L
.22 .51779 L
.224 .51779 L
.228 .5178 L
.232 .51781 L
.236 .5178 L
.24 .51778 L
.244 .51778 L
.248 .5178 L
.252 .51781 L
.256 .5178 L
.26 .51778 L
.264 .51778 L
.268 .5178 L
.272 .51781 L
.276 .51781 L
.28 .51779 L
.284 .51777 L
.288 .51778 L
.292 .51781 L
.296 .51782 L
.3 .5178 L
.304 .51777 L
.308 .51776 L
.312 .51779 L
.316 .51783 L
.32 .51783 L
.324 .51779 L
.328 .51775 L
.332 .51775 L
.336 .5178 L
.34 .51785 L
.344 .51784 L
.348 .51778 L
.352 .51772 L
.356 .51773 L
.36 .51781 L
.364 .51788 L
.368 .51787 L
.372 .51777 L
.376 .51768 L
.38 .5177 L
.384 .51781 L
.388 .51792 L
.392 .5179 L
.396 .51778 L
.4 .51765 L
Mistroke
.404 .51764 L
.408 .51778 L
.412 .51793 L
.416 .51796 L
.42 .51784 L
.424 .51766 L
.428 .51758 L
.432 .51768 L
.436 .51786 L
.44 .51799 L
.444 .51796 L
.448 .51778 L
.452 .51761 L
.456 .51757 L
.46 .51768 L
.464 .51786 L
.468 .51798 L
.472 .51798 L
.476 .51785 L
.48 .51768 L
.484 .51757 L
.488 .51758 L
.492 .51769 L
.496 .51786 L
.5 .51801 L
.504 .51806 L
.508 .51795 L
.512 .51773 L
.516 .51749 L
.52 .51737 L
.524 .51746 L
.528 .51777 L
.532 .51813 L
.536 .51836 L
.54 .51829 L
.544 .51791 L
.548 .51741 L
.552 .51705 L
.556 .51703 L
.56 .51738 L
.564 .51796 L
.568 .51848 L
.572 .5187 L
.576 .51852 L
.58 .51803 L
.584 .51744 L
.588 .51699 L
.592 .51681 L
.596 .51694 L
.6 .51729 L
Mistroke
.604 .51775 L
.608 .51823 L
.612 .51864 L
.616 .51893 L
.62 .51902 L
.624 .51883 L
.628 .51831 L
.632 .51751 L
.636 .51655 L
.64 .51568 L
.644 .51516 L
.648 .5152 L
.652 .51588 L
.656 .5171 L
.66 .51863 L
.664 .52016 L
.668 .52142 L
.672 .52224 L
.676 .52254 L
.68 .52237 L
.684 .52177 L
.688 .52079 L
.692 .5194 L
.696 .51753 L
.7 .51506 L
.704 .51192 L
.708 .50811 L
.712 .50375 L
.716 .49899 L
.72 .49407 L
.724 .48916 L
.728 .4844 L
.732 .47979 L
.736 .47528 L
.74 .47073 L
.744 .46601 L
.748 .46099 L
.752 .45564 L
.756 .45 L
.76 .44419 L
.764 .43837 L
.768 .43269 L
.772 .42729 L
.776 .42224 L
.78 .41752 L
.784 .41307 L
.788 .40875 L
.792 .4044 L
.796 .39986 L
.8 .39501 L
Mistroke
.804 .38977 L
.808 .38411 L
.812 .37808 L
.816 .37176 L
.82 .36529 L
.824 .3588 L
.828 .35245 L
.832 .34638 L
.836 .34071 L
.84 .33552 L
.844 .33087 L
.848 .32679 L
.852 .32327 L
.856 .3203 L
.86 .31783 L
.864 .31581 L
.868 .31419 L
.872 .3129 L
.876 .3119 L
.88 .31113 L
.884 .31055 L
.888 .31012 L
.892 .3098 L
.896 .30956 L
.9 .3094 L
.904 .30928 L
.908 .30919 L
.912 .30914 L
.916 .3091 L
.92 .30907 L
.924 .30905 L
.928 .30904 L
.932 .30903 L
.936 .30903 L
.94 .30902 L
.944 .30902 L
.948 .30902 L
.952 .30902 L
.956 .30902 L
.96 .30902 L
.964 .30902 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43211 L
.012 .42966 L
.016 .42905 L
.02 .42989 L
.024 .43004 L
.028 .42962 L
.032 .42956 L
.036 .42962 L
.04 .42961 L
.044 .4295 L
.048 .42947 L
.052 .42942 L
.056 .4294 L
.06 .42933 L
.064 .4293 L
.068 .42925 L
.072 .42921 L
.076 .42916 L
.08 .42912 L
.084 .42907 L
.088 .42903 L
.092 .42898 L
.096 .42895 L
.1 .4289 L
.104 .42886 L
.108 .4288 L
.112 .42877 L
.116 .42872 L
.12 .42868 L
.124 .42863 L
.128 .42859 L
.132 .42854 L
.136 .42851 L
.14 .42845 L
.144 .42841 L
.148 .42836 L
.152 .42833 L
.156 .42828 L
.16 .42823 L
.164 .42818 L
.168 .42814 L
.172 .42811 L
.176 .42806 L
.18 .428 L
.184 .42796 L
.188 .42793 L
.192 .42789 L
.196 .42784 L
.2 .42778 L
Mistroke
.204 .42774 L
.208 .42771 L
.212 .42767 L
.216 .42762 L
.22 .42755 L
.224 .42751 L
.228 .42749 L
.232 .42745 L
.236 .42739 L
.24 .42733 L
.244 .42729 L
.248 .42727 L
.252 .42724 L
.256 .42718 L
.26 .42711 L
.264 .42706 L
.268 .42704 L
.272 .42702 L
.276 .42697 L
.28 .4269 L
.284 .42683 L
.288 .4268 L
.292 .42679 L
.296 .42676 L
.3 .4267 L
.304 .42661 L
.308 .42655 L
.312 .42654 L
.316 .42655 L
.32 .42651 L
.324 .42642 L
.328 .42632 L
.332 .42627 L
.336 .42629 L
.34 .42631 L
.344 .42626 L
.348 .42614 L
.352 .42602 L
.356 .42599 L
.36 .42604 L
.364 .42609 L
.368 .42602 L
.372 .42586 L
.376 .4257 L
.38 .42568 L
.384 .42578 L
.388 .42587 L
.392 .42581 L
.396 .4256 L
.4 .4254 L
Mistroke
.404 .42535 L
.408 .42547 L
.412 .42562 L
.416 .42562 L
.42 .42542 L
.424 .42515 L
.428 .42501 L
.432 .42509 L
.436 .42528 L
.44 .42539 L
.444 .4253 L
.448 .42505 L
.452 .42479 L
.456 .42469 L
.46 .42478 L
.464 .42496 L
.468 .42508 L
.472 .42502 L
.476 .42482 L
.48 .42457 L
.484 .42439 L
.488 .42435 L
.492 .42445 L
.496 .42462 L
.5 .42476 L
.504 .42477 L
.508 .4246 L
.512 .42428 L
.516 .42393 L
.52 .42373 L
.524 .42381 L
.528 .42415 L
.532 .42456 L
.536 .4248 L
.54 .42466 L
.544 .42415 L
.548 .42349 L
.552 .42299 L
.556 .42292 L
.56 .42332 L
.564 .424 L
.568 .4246 L
.572 .42483 L
.576 .42456 L
.58 .4239 L
.584 .42313 L
.588 .42252 L
.592 .42225 L
.596 .42237 L
.6 .42276 L
Mistroke
.604 .4233 L
.608 .42385 L
.612 .42432 L
.616 .42463 L
.62 .4247 L
.624 .42442 L
.628 .42373 L
.632 .42269 L
.636 .42145 L
.64 .42032 L
.644 .41963 L
.648 .41964 L
.652 .42045 L
.656 .42192 L
.66 .42378 L
.664 .42565 L
.668 .42718 L
.672 .42815 L
.676 .42848 L
.68 .42821 L
.684 .42742 L
.688 .42616 L
.692 .42439 L
.696 .422 L
.7 .41888 L
.704 .41492 L
.708 .41014 L
.712 .40466 L
.716 .3987 L
.72 .39252 L
.724 .38637 L
.728 .38039 L
.732 .37462 L
.736 .36896 L
.74 .36326 L
.744 .35734 L
.748 .35105 L
.752 .34435 L
.756 .3373 L
.76 .33003 L
.764 .32274 L
.768 .31564 L
.772 .30889 L
.776 .30257 L
.78 .29667 L
.784 .29111 L
.788 .2857 L
.792 .28026 L
.796 .27458 L
.8 .26852 L
Mistroke
.804 .26196 L
.808 .2549 L
.812 .24736 L
.816 .23948 L
.82 .2314 L
.824 .2233 L
.828 .21539 L
.832 .20782 L
.836 .20074 L
.84 .19427 L
.844 .18847 L
.848 .18338 L
.852 .179 L
.856 .17529 L
.86 .17221 L
.864 .16969 L
.868 .16767 L
.872 .16607 L
.876 .16482 L
.88 .16386 L
.884 .16314 L
.888 .1626 L
.892 .1622 L
.896 .16191 L
.9 .1617 L
.904 .16155 L
.908 .16145 L
.912 .16137 L
.916 .16132 L
.92 .16129 L
.924 .16127 L
.928 .16125 L
.932 .16124 L
.936 .16124 L
.94 .16123 L
.944 .16123 L
.948 .16123 L
.952 .16123 L
.956 .16123 L
.96 .16123 L
.964 .16123 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`@0009oo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eo
o`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D0
00=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol0
=7oo00D007ooOomoo`0000Aoo`03001oo`0002aoo`008Woo0P005Woo00@007oo001oo`800005Ool0
0000001oo`0400000goo001oo`02000017oo000007oo0P0000Aoo`00001oo`<00003Ool000000080
0005Ool007ooOol0000/Ool0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00H007ooOomoo`00Ool300001Goo001oo`00Ool00P000goo0P000Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool90003Ool00`00Oomoo`0:Ool0029oo`8003aoo`03001oogoo009o
o`03001oogoo011oo`8001Moo`008Woo00<007ooOol0@Goo00<007ooOol03Woo00<007ooOol05goo
000ROol20012Ool00`00Oomoo`0>Ool00`00Oomoo`0GOol0029oo`80049oo`03001oogoo00ioo`03
001oogoo01Moo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0@Goo00<0
07ooOol03Goo00<007ooOol067oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`80049oo`03001oogoo00eoo`03001oogoo01Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool20013Ool00`00Oomoo`0<Ool00`00Oomoo`0HOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0@Woo00<007ooOol037oo00<007oo
Ool067oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8004=oo`04001o
o`00000:Ool00`00Oomoo`0IOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00
A7oo0`0017oo00<007ooOol00goo00<007ooOol06Goo000;Ool2000:Ool20004Ool00`00Oomoo`02
Ool00`00Oomoo`13Ool01000Oomoo`000Woo00<007oo000017oo00<007ooOol06Goo000;Ool20004
Ool00`00Oomoo`03Ool20002Ool50002Ool20017Ool00`00Ool00002Ool01@00Oomoogoo000077oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool20017Ool30002Ool01@00
Oomoogoo000077oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo04Moo`80009oo`05001oogooOol0000LOol000Yoo`04001oogoo0008Ool01000Oomoo`0017oo
00@007ooOomoo`8004eoo`04001oogoo000LOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0
00=oo`03001oogoo008004eoo`03001oo`0001eoo`002Woo00@007ooOol000Qoo`06001oogoo001o
o`000goo00@007ooOol004moo`8001eoo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol0
0`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P00
0goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo
0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00
Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001o
ogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomo
ogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03
001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
4Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004
Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`80
00=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo
00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=o
o`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomo
o`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05
001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool0
1000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000
Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P00
17oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo
00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001o
ogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo0000
0`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Io
o`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol0
07oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool0
1000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool2
0004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P00
1Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomo
o`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool2000<Ool0
0`00Oomoo`0:Ool002Qoo`03001oogoo04Yoo`8001Yoo`00:7oo00<007ooOol0BWoo00<007ooOol0
6Goo000XOol00`00Oomoo`19Ool00`00Oomoo`0JOol002Qoo`03001oogoo04Qoo`03001oogoo01]o
o`00:7oo00<007ooOol0Agoo0P007Goo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool3
0003Ool00`00Oomoo`17Ool00`00Oomoo`0LOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0003Ool01000Oomoo`00B7oo00<007ooOol07Goo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00Agoo0P007goo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`020015Ool2000POol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo04=oo`80025oo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo04=oo`03
001oogoo021oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0@Woo00<007ooOol0
8Goo000XOol00`00Oomoo`11Ool2000SOol002Qoo`03001oogoo041oo`8002Aoo`004Goo0P0017oo
00<007ooOol00goo0P000goo0`000goo00<007ooOol0@7oo00<007ooOol08goo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo03moo`03001oogoo02Aoo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0nOol00`00Oomoo`0U
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo?P0000=oo`000000:7oo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo03Yoo`<002Uo
o`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yo
o`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00
0goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003
Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03
001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00
Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Ao
o`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03
001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04
001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomo
o`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<0
00Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D0
07ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007oo
Ool00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
17oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`00
2Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@0
07ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogoo
Ool007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007oo
Ool000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@0
07ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogoo
Ool007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo
0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D0
00=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo
00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00H007ooOomoo`00
Ool30003Ool01@00Oomoogoo000017oo00<007ooOol02Woo000LOol00`00Oomoo`1EOol2000KOol0
01aoo`8005Eoo`8001aoo`0077oo00<007ooOol0E7oo00<007ooOol06goo000LOol00`00Oomoo`1C
Ool00`00Oomoo`0LOol001aoo`8005Aoo`03001oogoo01aoo`0077oo00<007ooOol0DWoo00<007oo
Ool07Goo000LOol00`00Oomoo`1BOol00`00Oomoo`0MOol001aoo`80059oo`03001oogoo01ioo`00
77oo00<007ooOol0DGoo00<007ooOol07Woo000LOol2001AOol00`00Oomoo`0OOol000]oo`8000Ao
o`03001oogoo009oo`<000=oo`03001oogoo04moo`03001oogoo021oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1?Ool00`00Oomoo`0POol000Yoo`04001oogoo000;Ool0
0`00Oomoo`02001?Ool00`00Oomoo`0QOol000Yoo`04001oogoo000;Ool01000Oomoo`00Cgoo00<0
07ooOol08Woo000:Ool01000Oomoo`001goo10000goo00<007ooOol0CGoo00<007ooOol08Woo000:
Ool01000Oomoo`001goo00<007ooOol017oo0P00CGoo00<007ooOol08goo000;Ool20008Ool50002
Ool00`00Oomoo`1;Ool2000UOol001aoo`03001oogoo04]oo`03001oogoo02Aoo`0077oo0P00C7oo
00<007ooOol097oo000LOol00`00Oomoo`1:Ool00`00Oomoo`0UOol001aoo`8004Yoo`03001oogoo
02Ioo`0077oo00<007ooOol0B7oo00<007ooOol09goo000LOol00`00Oomoo`18Ool00`00Oomoo`0W
Ool001aoo`8004Qoo`03001oogoo02Qoo`005Woo0`000goo00<007ooOol0AWoo00<007ooOol0:Goo
000GOol00`00Oomoo`02Ool00`00Oomoo`0_Ool200000goo0000000>0003Ool2000[Ool001Moo`03
001oogoo009ooc80009oo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool3000]
Ool001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo
000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00
Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomo
o`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=o
o`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomo
o`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(5344\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30165 m
.008 .29998 L
.012 .29893 L
.016 .29879 L
.02 .29967 L
.024 .29997 L
.028 .2995 L
.032 .29929 L
.036 .2995 L
.04 .2996 L
.044 .29949 L
.048 .29943 L
.052 .29949 L
.056 .29951 L
.06 .29946 L
.064 .29943 L
.068 .29946 L
.072 .29948 L
.076 .29944 L
.08 .2994 L
.084 .29943 L
.088 .29947 L
.092 .29944 L
.096 .29937 L
.1 .29937 L
.104 .29944 L
.108 .29945 L
.112 .29936 L
.116 .2993 L
.12 .29939 L
.124 .29947 L
.128 .29938 L
.132 .29925 L
.136 .2993 L
.14 .29945 L
.144 .29943 L
.148 .29924 L
.152 .29919 L
.156 .29936 L
.16 .29948 L
.164 .29933 L
.168 .29913 L
.172 .29919 L
.176 .29943 L
.18 .29946 L
.184 .29921 L
.188 .29904 L
.192 .29922 L
.196 .29949 L
.2 .29942 L
Mistroke
.204 .29908 L
.208 .29897 L
.212 .29926 L
.216 .29952 L
.22 .29937 L
.224 .29899 L
.228 .29891 L
.232 .29925 L
.236 .29954 L
.24 .29936 L
.244 .29894 L
.248 .29884 L
.252 .29919 L
.256 .29953 L
.26 .29941 L
.264 .29896 L
.268 .29874 L
.272 .29902 L
.276 .29946 L
.28 .29953 L
.284 .29912 L
.288 .29869 L
.292 .29873 L
.296 .29922 L
.3 .29963 L
.304 .29946 L
.308 .29884 L
.312 .29842 L
.316 .29871 L
.32 .29948 L
.324 .29989 L
.328 .2994 L
.332 .29841 L
.336 .29799 L
.34 .29874 L
.344 .29997 L
.348 .30031 L
.352 .29922 L
.356 .29771 L
.36 .29744 L
.364 .29891 L
.368 .3007 L
.372 .30085 L
.376 .29895 L
.38 .29682 L
.384 .29675 L
.388 .29904 L
.392 .30153 L
.396 .3016 L
.4 .29893 L
Mistroke
.404 .296 L
.408 .29577 L
.412 .29866 L
.416 .30205 L
.42 .30266 L
.424 .29972 L
.428 .29584 L
.432 .29459 L
.436 .29721 L
.44 .30142 L
.444 .30351 L
.448 .30164 L
.452 .29741 L
.456 .29439 L
.46 .29502 L
.464 .29867 L
.468 .30232 L
.472 .30319 L
.476 .30086 L
.48 .2973 L
.484 .29506 L
.488 .29542 L
.492 .29776 L
.496 .3004 L
.5 .30194 L
.504 .30187 L
.508 .30042 L
.512 .29817 L
.516 .29587 L
.52 .29451 L
.524 .29512 L
.528 .29803 L
.532 .30225 L
.536 .30545 L
.54 .30522 L
.544 .30081 L
.548 .29411 L
.552 .28896 L
.556 .28888 L
.56 .29471 L
.564 .30368 L
.568 .31083 L
.572 .31186 L
.576 .30577 L
.58 .29557 L
.584 .28655 L
.588 .28336 L
.592 .28747 L
.596 .29657 L
.6 .30612 L
Mistroke
.604 .31186 L
.608 .31194 L
.612 .30732 L
.616 .30072 L
.62 .29482 L
.624 .29097 L
.628 .28901 L
.632 .28819 L
.636 .28823 L
.64 .28981 L
.644 .29408 L
.648 .30157 L
.652 .31122 L
.656 .32024 L
.66 .32504 L
.664 .32278 L
.668 .31283 L
.672 .29726 L
.676 .28023 L
.68 .26646 L
.684 .25948 L
.688 .26046 L
.692 .26806 L
.696 .27931 L
.7 .29102 L
.704 .30113 L
.708 .30939 L
.712 .31719 L
.716 .32665 L
.72 .33947 L
.724 .35603 L
.728 .37503 L
.732 .39393 L
.736 .4098 L
.74 .42034 L
.744 .4247 L
.748 .4237 L
.752 .41958 L
.756 .41525 L
.76 .41339 L
.764 .41568 L
.768 .42238 L
.772 .43234 L
.776 .44342 L
.78 .45311 L
.784 .45926 L
.788 .46059 L
.792 .45698 L
.796 .44944 L
.8 .43983 L
Mistroke
.804 .43037 L
.808 .42322 L
.812 .42001 L
.816 .42158 L
.82 .42791 L
.824 .43817 L
.828 .45095 L
.832 .46451 L
.836 .4771 L
.84 .48717 L
.844 .49357 L
.848 .49564 L
.852 .49319 L
.856 .4865 L
.86 .47614 L
.864 .46294 L
.868 .44782 L
.872 .43167 L
.876 .41534 L
.88 .39949 L
.884 .38465 L
.888 .37119 L
.892 .3593 L
.896 .34905 L
.9 .34042 L
.904 .33329 L
.908 .32752 L
.912 .32293 L
.916 .31934 L
.92 .31658 L
.924 .31449 L
.928 .31293 L
.932 .31178 L
.936 .31095 L
.94 .31035 L
.944 .30993 L
.948 .30963 L
.952 .30943 L
.956 .30929 L
.96 .3092 L
.964 .30913 L
.968 .30909 L
.972 .30906 L
.976 .30905 L
.98 .30904 L
.984 .30903 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51525 m
.008 .51769 L
.012 .51846 L
.016 .51742 L
.02 .51726 L
.024 .51763 L
.028 .5177 L
.032 .51753 L
.036 .51754 L
.04 .51758 L
.044 .5176 L
.048 .51756 L
.052 .51757 L
.056 .51757 L
.06 .51758 L
.064 .51756 L
.068 .51758 L
.072 .51757 L
.076 .51757 L
.08 .51757 L
.084 .51758 L
.088 .51757 L
.092 .51757 L
.096 .51757 L
.1 .51757 L
.104 .51757 L
.108 .51757 L
.112 .51757 L
.116 .51757 L
.12 .51757 L
.124 .51757 L
.128 .51756 L
.132 .51757 L
.136 .51757 L
.14 .51757 L
.144 .51756 L
.148 .51757 L
.152 .51757 L
.156 .51757 L
.16 .51757 L
.164 .51756 L
.168 .51757 L
.172 .51757 L
.176 .51757 L
.18 .51757 L
.184 .51756 L
.188 .51757 L
.192 .51758 L
.196 .51757 L
.2 .51756 L
Mistroke
.204 .51756 L
.208 .51757 L
.212 .51758 L
.216 .51757 L
.22 .51756 L
.224 .51756 L
.228 .51757 L
.232 .51758 L
.236 .51757 L
.24 .51755 L
.244 .51756 L
.248 .51757 L
.252 .51758 L
.256 .51757 L
.26 .51755 L
.264 .51755 L
.268 .51757 L
.272 .51758 L
.276 .51758 L
.28 .51756 L
.284 .51754 L
.288 .51756 L
.292 .51758 L
.296 .51758 L
.3 .51757 L
.304 .51754 L
.308 .51754 L
.312 .51757 L
.316 .51759 L
.32 .51759 L
.324 .51755 L
.328 .51752 L
.332 .51754 L
.336 .51758 L
.34 .51761 L
.344 .51759 L
.348 .51753 L
.352 .5175 L
.356 .51753 L
.36 .5176 L
.364 .51763 L
.368 .51759 L
.372 .51751 L
.376 .51747 L
.38 .51752 L
.384 .51762 L
.388 .51766 L
.392 .5176 L
.396 .51749 L
.4 .51743 L
Mistroke
.404 .5175 L
.408 .51763 L
.412 .5177 L
.416 .51764 L
.42 .51749 L
.424 .51739 L
.428 .51744 L
.432 .5176 L
.436 .51772 L
.44 .51771 L
.444 .51756 L
.448 .5174 L
.452 .51736 L
.456 .51748 L
.46 .51766 L
.464 .51776 L
.468 .51769 L
.472 .51753 L
.476 .51738 L
.48 .51735 L
.484 .51746 L
.488 .51762 L
.492 .51774 L
.496 .51773 L
.5 .51763 L
.504 .51747 L
.508 .51735 L
.512 .51733 L
.516 .51742 L
.52 .5176 L
.524 .51777 L
.528 .51785 L
.532 .51777 L
.536 .51753 L
.54 .51726 L
.544 .5171 L
.548 .51718 L
.552 .51749 L
.556 .51788 L
.56 .51815 L
.564 .51811 L
.568 .51775 L
.572 .51724 L
.576 .51684 L
.58 .51676 L
.584 .51707 L
.588 .51761 L
.592 .51815 L
.596 .51843 L
.6 .51834 L
Mistroke
.604 .51793 L
.608 .51739 L
.612 .51692 L
.616 .51666 L
.62 .51666 L
.624 .51689 L
.628 .51727 L
.632 .51773 L
.636 .5182 L
.64 .5186 L
.644 .51885 L
.648 .51882 L
.652 .51844 L
.656 .51771 L
.66 .51674 L
.664 .51575 L
.668 .51503 L
.672 .51481 L
.676 .51522 L
.68 .51621 L
.684 .51761 L
.688 .51913 L
.692 .5205 L
.696 .52152 L
.7 .52209 L
.704 .52223 L
.708 .52196 L
.712 .52133 L
.716 .52031 L
.72 .51882 L
.724 .51675 L
.728 .51401 L
.732 .51058 L
.736 .50652 L
.74 .502 L
.744 .49721 L
.748 .49236 L
.752 .4876 L
.756 .48299 L
.76 .4785 L
.764 .47401 L
.768 .46939 L
.772 .46452 L
.776 .45932 L
.78 .45381 L
.784 .44807 L
.788 .44224 L
.792 .43649 L
.796 .43095 L
.8 .42573 L
Mistroke
.804 .42086 L
.808 .4163 L
.812 .41193 L
.816 .40762 L
.82 .40321 L
.824 .39854 L
.828 .39353 L
.832 .38811 L
.836 .38229 L
.84 .37614 L
.844 .36975 L
.848 .36326 L
.852 .35682 L
.856 .35057 L
.86 .34464 L
.864 .33913 L
.868 .33413 L
.872 .32967 L
.876 .32577 L
.88 .32243 L
.884 .31962 L
.888 .31729 L
.892 .31539 L
.896 .31386 L
.9 .31266 L
.904 .31172 L
.908 .311 L
.912 .31046 L
.916 .31005 L
.92 .30975 L
.924 .30953 L
.928 .30937 L
.932 .30926 L
.936 .30918 L
.94 .30913 L
.944 .30909 L
.948 .30907 L
.952 .30905 L
.956 .30904 L
.96 .30903 L
.964 .30903 L
.968 .30902 L
.972 .30902 L
.976 .30902 L
.98 .30902 L
.984 .30902 L
.988 .30902 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43429 L
.012 .42994 L
.016 .42842 L
.02 .4297 L
.024 .43022 L
.028 .42972 L
.032 .42951 L
.036 .42958 L
.04 .42962 L
.044 .42951 L
.048 .42947 L
.052 .42942 L
.056 .4294 L
.06 .42933 L
.064 .4293 L
.068 .42925 L
.072 .42921 L
.076 .42916 L
.08 .42912 L
.084 .42907 L
.088 .42904 L
.092 .42898 L
.096 .42894 L
.1 .4289 L
.104 .42886 L
.108 .4288 L
.112 .42877 L
.116 .42872 L
.12 .42868 L
.124 .42863 L
.128 .42859 L
.132 .42854 L
.136 .42851 L
.14 .42846 L
.144 .42841 L
.148 .42836 L
.152 .42833 L
.156 .42828 L
.16 .42824 L
.164 .42818 L
.168 .42814 L
.172 .42811 L
.176 .42806 L
.18 .42801 L
.184 .42796 L
.188 .42792 L
.192 .42789 L
.196 .42784 L
.2 .42778 L
Mistroke
.204 .42774 L
.208 .42771 L
.212 .42767 L
.216 .42762 L
.22 .42756 L
.224 .42752 L
.228 .42749 L
.232 .42745 L
.236 .4274 L
.24 .42734 L
.244 .42729 L
.248 .42727 L
.252 .42723 L
.256 .42718 L
.26 .42711 L
.264 .42707 L
.268 .42704 L
.272 .42702 L
.276 .42697 L
.28 .4269 L
.284 .42684 L
.288 .42681 L
.292 .42679 L
.296 .42676 L
.3 .42669 L
.304 .42661 L
.308 .42657 L
.312 .42656 L
.316 .42654 L
.32 .42649 L
.324 .42641 L
.328 .42633 L
.332 .4263 L
.336 .42631 L
.34 .4263 L
.344 .42623 L
.348 .42612 L
.352 .42604 L
.356 .42603 L
.36 .42607 L
.364 .42607 L
.368 .42597 L
.372 .42582 L
.376 .42574 L
.38 .42576 L
.384 .42583 L
.388 .42584 L
.392 .42572 L
.396 .42553 L
.4 .42542 L
Mistroke
.404 .42546 L
.408 .42558 L
.412 .42563 L
.416 .4255 L
.42 .42527 L
.424 .42511 L
.428 .42513 L
.432 .42528 L
.436 .42539 L
.44 .42533 L
.444 .4251 L
.448 .42485 L
.452 .42477 L
.456 .42487 L
.46 .42505 L
.464 .42513 L
.468 .425 L
.472 .42475 L
.476 .42452 L
.48 .42445 L
.484 .42454 L
.488 .4247 L
.492 .42479 L
.496 .42475 L
.5 .42457 L
.504 .42433 L
.508 .42414 L
.512 .42407 L
.516 .42414 L
.52 .42432 L
.524 .42449 L
.528 .42455 L
.532 .42439 L
.536 .42406 L
.54 .42367 L
.544 .42343 L
.548 .42348 L
.552 .42383 L
.556 .42428 L
.56 .42456 L
.564 .42447 L
.568 .42398 L
.572 .4233 L
.576 .42275 L
.58 .42262 L
.584 .42295 L
.588 .42359 L
.592 .42421 L
.596 .42452 L
.6 .42436 L
Mistroke
.604 .42381 L
.608 .42309 L
.612 .42246 L
.616 .4221 L
.62 .42206 L
.624 .4223 L
.628 .42273 L
.632 .42326 L
.636 .4238 L
.64 .42425 L
.644 .42451 L
.648 .42444 L
.652 .42392 L
.656 .42297 L
.66 .42171 L
.664 .42044 L
.668 .41949 L
.672 .41918 L
.676 .41964 L
.68 .42085 L
.684 .42254 L
.688 .42439 L
.692 .42605 L
.696 .42728 L
.7 .42795 L
.704 .42807 L
.708 .4277 L
.712 .42686 L
.716 .42554 L
.72 .42364 L
.724 .42102 L
.728 .41756 L
.732 .41324 L
.736 .40815 L
.74 .40247 L
.744 .39646 L
.748 .39038 L
.752 .38441 L
.756 .37863 L
.76 .37299 L
.764 .36737 L
.768 .36158 L
.772 .35547 L
.776 .34896 L
.78 .34207 L
.784 .33488 L
.788 .32759 L
.792 .32039 L
.796 .31347 L
.8 .30694 L
Mistroke
.804 .30085 L
.808 .29514 L
.812 .28968 L
.816 .28429 L
.82 .27876 L
.824 .27293 L
.828 .26666 L
.832 .25989 L
.836 .25262 L
.84 .24494 L
.844 .23696 L
.848 .22887 L
.852 .22083 L
.856 .21303 L
.86 .20563 L
.864 .19877 L
.868 .19253 L
.872 .18697 L
.876 .18211 L
.88 .17795 L
.884 .17444 L
.888 .17153 L
.892 .16917 L
.896 .16727 L
.9 .16577 L
.904 .1646 L
.908 .1637 L
.912 .16302 L
.916 .16251 L
.92 .16214 L
.924 .16187 L
.928 .16167 L
.932 .16153 L
.936 .16143 L
.94 .16137 L
.944 .16132 L
.948 .16129 L
.952 .16127 L
.956 .16125 L
.96 .16124 L
.964 .16124 L
.968 .16123 L
.972 .16123 L
.976 .16123 L
.98 .16123 L
.984 .16123 L
.988 .16123 L
.992 .16123 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`03001oogoo00800003Ool007oo
009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`0000=oo`03001oo`0000Ioo`04
001oogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04
001oogooOol50003Ool300000goo001oo`030004Ool20004Ool20005Ool30002Ool50003Ool20006
Ool0029oo`03001oogoo03Ioo`8000=oo`07001oogooOol007oo0000:Woo000ROol2000HOol01@00
Ool00000Ool00`0000=oo`00Ool00P0000=oo`00Ool0100000Aoo`00001oo`<00004Ool00000Ool2
0002Ool30002Ool00`00Ool0000ZOol0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`80009oo`05001oogoo001oo`030002Ool20003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`L00003Ool007oo00]oo`008Woo0P00?Woo0P00
17oo00<007ooOol047oo00<007ooOol04goo000ROol00`00Oomoo`13Ool00`00Oomoo`0?Ool00`00
Oomoo`0DOol0029oo`8004Aoo`03001oogoo00ioo`8001Ioo`008Woo0P00AGoo00<007ooOol03Goo
00<007ooOol05Goo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`14Ool0
0`00Oomoo`0=Ool00`00Oomoo`0EOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P00AGoo00<007ooOol03Goo00<007ooOol05Goo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8004Eoo`03001oogoo00aoo`03001oogoo01Ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`14Ool00`00Oomoo`0<Ool00`00
Oomoo`0FOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00AWoo00<0
07ooOol02goo00<007ooOol05Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`80
04Ioo`@000=oo`8000Aoo`03001oogoo01Moo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<0
07ooOol0AWoo00<007oo00000Woo0`0017oo00<007ooOol05goo000;Ool20004Ool00`00Oomoo`03
Ool20002Ool50002Ool20019Ool01P00Oomoo`00Ool000Aoo`03001oogoo01Moo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00BWoo00<007oo00000Woo00D007ooOomo
o`0001Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`19
Ool20003Ool01000Oomoo`006Woo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogoo
Ool2001?Ool01000Oomoo`006Woo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00
Oomoo`02001@Ool00`00Ool0000JOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04
001oogoo001AOol3000JOol000]oo`8000Yoo`8000=oo`<000=oo`80055oo`03001oogoo01Uoo`00
8Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool0
00Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`80
00=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo
00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@0
07ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003
Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo
0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004
Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool3
0003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001o
ogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol0
0goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0
3Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo
00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yo
o`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo
00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo
0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
o`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo
0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001o
ogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo0000
1Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P00
17oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=o
o`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<0
07ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol01Goo0P00
2Goo00<007ooOol02Woo000XOol00`00Oomoo`1<Ool2000HOol002Qoo`03001oogoo04aoo`03001o
ogoo01Moo`00:7oo00<007ooOol0Bgoo00<007ooOol067oo000XOol00`00Oomoo`1;Ool00`00Oomo
o`0HOol002Qoo`03001oogoo04Yoo`03001oogoo01Uoo`002goo0P0017oo00<007ooOol00goo0P00
17oo0P000goo0`000goo00<007ooOol0BGoo0P006goo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`06001oogoo001oo`000goo00@007ooOol004Yoo`8001aoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`001Goo00@007ooOol004Yoo`03001oogoo01]oo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00B7oo00<007ooOol077oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`16
Ool00`00Oomoo`0MOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006
Ool00`00Oomoo`15Ool2000OOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo04Ao
o`80021oo`00:7oo00<007ooOol0A7oo00<007ooOol07goo000XOol00`00Oomoo`13Ool00`00Oomo
o`0POol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo049oo`80029oo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`11Ool2000SOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0@7oo0P0097oo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009ood00009oo`8002Eoo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0mOol2000WOol0011o
o`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03
001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@0
07ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0
JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000
Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomo
o`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomo
o`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo
000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool2
0005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogoo
Ool00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
1@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomo
o`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=o
o`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol0
17oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo
0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001o
o`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008
Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo
0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001o
o`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Ao
o`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool2
0006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001o
ogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool5
0003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo05Qoo`8001Qoo`0077oo0P00
F7oo00<007ooOol067oo000LOol00`00Oomoo`1GOol00`00Oomoo`0HOol001aoo`03001oogoo05Io
o`03001oogoo01Uoo`0077oo0P00EWoo0P006goo000LOol00`00Oomoo`1EOol00`00Oomoo`0JOol0
01aoo`03001oogoo05Aoo`03001oogoo01]oo`0077oo0P00EGoo00<007ooOol06goo000LOol00`00
Oomoo`1COol2000MOol001aoo`8005Aoo`03001oogoo01aoo`002goo0P0017oo00<007ooOol00Woo
0`000goo00<007ooOol0DWoo00<007ooOol07Goo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo059oo`03001oogoo01eoo`002Woo00@007ooOol000]oo`03001oogoo0080059o
o`03001oogoo01ioo`002Woo00@007ooOol000]oo`04001oogoo001BOol00`00Oomoo`0OOol000Yo
o`04001oogoo0007Ool40003Ool00`00Oomoo`1?Ool00`00Oomoo`0POol000Yoo`04001oogoo0007
Ool00`00Oomoo`04Ool2001@Ool00`00Oomoo`0POol000]oo`8000Qoo`D0009oo`03001oogoo04io
o`03001oogoo025oo`0077oo00<007ooOol0CWoo00<007ooOol08Goo000LOol2001>Ool00`00Oomo
o`0ROol001aoo`03001oogoo04eoo`03001oogoo029oo`0077oo0P00CGoo00<007ooOol08goo000L
Ool00`00Oomoo`1;Ool00`00Oomoo`0TOol001aoo`03001oogoo04]oo`03001oogoo02Aoo`0077oo
0P00Bgoo00<007ooOol09Goo000FOol30003Ool00`00Oomoo`19Ool00`00Oomoo`0VOol001Moo`03
001oogoo009oo`03001oogoo02ioo`800003Ool00000018000=oo`03001oogoo02Moo`005goo00<0
07ooOol00Woo<P0000=oo`00Ool04goo0`00:Woo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol0
01Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001o
ogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo
079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol0
0P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo
00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(5511\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29881 m
.008 .29877 L
.012 .29995 L
.016 .30011 L
.02 .29935 L
.024 .29927 L
.028 .29967 L
.032 .29968 L
.036 .29948 L
.04 .29948 L
.044 .29955 L
.048 .29954 L
.052 .29951 L
.056 .29951 L
.06 .29951 L
.064 .29948 L
.068 .29949 L
.072 .2995 L
.076 .29949 L
.08 .29945 L
.084 .29945 L
.088 .29948 L
.092 .29949 L
.096 .29943 L
.1 .2994 L
.104 .29945 L
.108 .29949 L
.112 .29942 L
.116 .29935 L
.12 .29939 L
.124 .29949 L
.128 .29944 L
.132 .29931 L
.136 .29931 L
.14 .29945 L
.144 .29948 L
.148 .29933 L
.152 .29923 L
.156 .29935 L
.16 .29949 L
.164 .29941 L
.168 .29921 L
.172 .29921 L
.176 .29941 L
.18 .2995 L
.184 .2993 L
.188 .29911 L
.192 .29921 L
.196 .29947 L
.2 .29947 L
Mistroke
.204 .29918 L
.208 .29903 L
.212 .29924 L
.216 .29951 L
.22 .29943 L
.224 .29909 L
.228 .29897 L
.232 .29925 L
.236 .29953 L
.24 .2994 L
.244 .29902 L
.248 .2989 L
.252 .29921 L
.256 .29953 L
.26 .29942 L
.264 .29901 L
.268 .29882 L
.272 .29909 L
.276 .29948 L
.28 .2995 L
.284 .2991 L
.288 .29876 L
.292 .29887 L
.296 .29933 L
.3 .29959 L
.304 .29934 L
.308 .29881 L
.312 .29859 L
.316 .29896 L
.32 .29955 L
.324 .29971 L
.328 .29916 L
.332 .29844 L
.336 .29837 L
.34 .29912 L
.344 .29995 L
.348 .29988 L
.352 .29884 L
.356 .29786 L
.36 .29811 L
.364 .29948 L
.368 .30056 L
.372 .30006 L
.376 .2983 L
.38 .29708 L
.384 .29784 L
.388 .3 L
.392 .30135 L
.396 .30031 L
.4 .29772 L
Mistroke
.404 .29616 L
.408 .29739 L
.412 .30039 L
.416 .30222 L
.42 .30091 L
.424 .29751 L
.428 .29525 L
.432 .29642 L
.436 .30009 L
.44 .30289 L
.444 .30212 L
.448 .29836 L
.452 .29494 L
.456 .29494 L
.46 .2984 L
.464 .30234 L
.468 .30338 L
.472 .30069 L
.476 .29656 L
.48 .29435 L
.484 .29568 L
.488 .29932 L
.492 .30239 L
.496 .30275 L
.5 .30045 L
.504 .29734 L
.508 .29545 L
.512 .29568 L
.516 .29752 L
.52 .29984 L
.524 .30159 L
.528 .30215 L
.532 .30123 L
.536 .29891 L
.54 .29592 L
.544 .29374 L
.548 .29398 L
.552 .29729 L
.556 .30241 L
.56 .30643 L
.564 .30646 L
.568 .30162 L
.572 .29409 L
.576 .28815 L
.58 .28768 L
.584 .29363 L
.588 .30313 L
.592 .31101 L
.596 .31274 L
.6 .30712 L
Mistroke
.604 .29696 L
.608 .28748 L
.612 .28339 L
.616 .28641 L
.62 .29464 L
.624 .30393 L
.628 .31022 L
.632 .31153 L
.636 .30842 L
.64 .30311 L
.644 .29783 L
.648 .29371 L
.652 .29067 L
.656 .28824 L
.66 .28651 L
.664 .28655 L
.668 .28989 L
.672 .29733 L
.676 .30794 L
.68 .31888 L
.684 .32625 L
.688 .32667 L
.692 .31884 L
.696 .30426 L
.7 .28676 L
.704 .27113 L
.708 .26137 L
.712 .25929 L
.716 .26422 L
.72 .27358 L
.724 .28426 L
.728 .29395 L
.732 .30202 L
.736 .30952 L
.74 .31846 L
.744 .33071 L
.748 .347 L
.752 .36645 L
.756 .38674 L
.76 .40488 L
.764 .41824 L
.768 .42539 L
.772 .42658 L
.776 .42362 L
.78 .41928 L
.784 .41643 L
.788 .41721 L
.792 .42248 L
.796 .43162 L
.8 .44283 L
Mistroke
.804 .45368 L
.808 .4618 L
.812 .46548 L
.816 .46407 L
.82 .45808 L
.824 .44901 L
.828 .43898 L
.832 .43025 L
.836 .42474 L
.84 .42373 L
.844 .42764 L
.848 .43606 L
.852 .44786 L
.856 .46144 L
.86 .47503 L
.864 .48694 L
.868 .49577 L
.872 .50057 L
.876 .50087 L
.88 .49666 L
.884 .48835 L
.888 .47664 L
.892 .46238 L
.896 .4465 L
.9 .42988 L
.904 .41331 L
.908 .39742 L
.912 .38268 L
.916 .3694 L
.92 .35774 L
.924 .34774 L
.928 .33935 L
.932 .33244 L
.936 .32686 L
.94 .32243 L
.944 .31897 L
.948 .31631 L
.952 .3143 L
.956 .3128 L
.96 .31169 L
.964 .31089 L
.968 .31031 L
.972 .3099 L
.976 .30962 L
.98 .30942 L
.984 .30929 L
.988 .3092 L
.992 .30914 L
.996 .3091 L
1 .30908 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51108 m
.008 .51728 L
.012 .51942 L
.016 .51738 L
.02 .51667 L
.024 .5173 L
.028 .51758 L
.032 .51735 L
.036 .51727 L
.04 .51732 L
.044 .51737 L
.048 .51734 L
.052 .51734 L
.056 .51733 L
.06 .51735 L
.064 .51733 L
.068 .51734 L
.072 .51733 L
.076 .51734 L
.08 .51734 L
.084 .51734 L
.088 .51734 L
.092 .51734 L
.096 .51734 L
.1 .51734 L
.104 .51734 L
.108 .51734 L
.112 .51734 L
.116 .51734 L
.12 .51734 L
.124 .51734 L
.128 .51733 L
.132 .51734 L
.136 .51734 L
.14 .51734 L
.144 .51734 L
.148 .51734 L
.152 .51734 L
.156 .51734 L
.16 .51734 L
.164 .51733 L
.168 .51733 L
.172 .51734 L
.176 .51734 L
.18 .51734 L
.184 .51733 L
.188 .51734 L
.192 .51734 L
.196 .51734 L
.2 .51733 L
Mistroke
.204 .51733 L
.208 .51734 L
.212 .51734 L
.216 .51734 L
.22 .51733 L
.224 .51733 L
.228 .51734 L
.232 .51735 L
.236 .51734 L
.24 .51733 L
.244 .51733 L
.248 .51734 L
.252 .51735 L
.256 .51734 L
.26 .51732 L
.264 .51732 L
.268 .51734 L
.272 .51735 L
.276 .51734 L
.28 .51733 L
.284 .51732 L
.288 .51733 L
.292 .51735 L
.296 .51735 L
.3 .51733 L
.304 .51731 L
.308 .51732 L
.312 .51734 L
.316 .51736 L
.32 .51735 L
.324 .51732 L
.328 .5173 L
.332 .51732 L
.336 .51735 L
.34 .51736 L
.344 .51734 L
.348 .5173 L
.352 .51729 L
.356 .51732 L
.36 .51737 L
.364 .51738 L
.368 .51733 L
.372 .51727 L
.376 .51727 L
.38 .51733 L
.384 .5174 L
.388 .51739 L
.392 .51732 L
.396 .51724 L
.4 .51725 L
Mistroke
.404 .51733 L
.408 .51742 L
.412 .51742 L
.416 .51732 L
.42 .51721 L
.424 .51721 L
.428 .51731 L
.432 .51744 L
.436 .51747 L
.44 .51736 L
.444 .51721 L
.448 .51716 L
.452 .51725 L
.456 .51741 L
.46 .5175 L
.464 .51744 L
.468 .51728 L
.472 .51715 L
.476 .51715 L
.48 .51728 L
.484 .51745 L
.488 .51751 L
.492 .51744 L
.496 .51728 L
.5 .51715 L
.504 .51714 L
.508 .51723 L
.512 .51738 L
.516 .51749 L
.52 .5175 L
.524 .51741 L
.528 .51726 L
.532 .51713 L
.536 .51708 L
.54 .51716 L
.544 .51734 L
.548 .51754 L
.552 .51765 L
.556 .51758 L
.56 .51733 L
.564 .51703 L
.568 .51683 L
.572 .51689 L
.576 .5172 L
.58 .51762 L
.584 .51792 L
.588 .51792 L
.592 .51759 L
.596 .51708 L
.6 .51665 L
Mistroke
.604 .51651 L
.608 .51676 L
.612 .51726 L
.616 .5178 L
.62 .51813 L
.624 .51813 L
.628 .51781 L
.632 .51733 L
.636 .51686 L
.64 .51655 L
.644 .51644 L
.648 .51654 L
.652 .51682 L
.656 .51723 L
.66 .51772 L
.664 .51821 L
.668 .51859 L
.672 .51874 L
.676 .51852 L
.68 .5179 L
.684 .51696 L
.688 .5159 L
.692 .51501 L
.696 .51455 L
.7 .51468 L
.704 .51543 L
.708 .51665 L
.712 .5181 L
.716 .51951 L
.72 .52068 L
.724 .52148 L
.728 .52188 L
.732 .52192 L
.736 .52161 L
.74 .52094 L
.744 .51983 L
.748 .51817 L
.752 .51584 L
.756 .51281 L
.76 .5091 L
.764 .50485 L
.768 .50024 L
.772 .49549 L
.776 .49076 L
.78 .48615 L
.784 .48167 L
.788 .47723 L
.792 .4727 L
.796 .46797 L
.8 .46293 L
Mistroke
.804 .45756 L
.808 .45192 L
.812 .44612 L
.816 .44032 L
.82 .43468 L
.824 .4293 L
.828 .42427 L
.832 .41957 L
.836 .41512 L
.84 .41081 L
.844 .40647 L
.848 .40196 L
.852 .39715 L
.856 .39197 L
.86 .38638 L
.864 .38042 L
.868 .37416 L
.872 .36772 L
.876 .36125 L
.88 .35487 L
.884 .34873 L
.888 .34295 L
.892 .33762 L
.896 .3328 L
.9 .32853 L
.904 .32482 L
.908 .32165 L
.912 .31898 L
.916 .31678 L
.92 .31499 L
.924 .31356 L
.928 .31243 L
.932 .31155 L
.936 .31088 L
.94 .31037 L
.944 .30999 L
.948 .30971 L
.952 .3095 L
.956 .30935 L
.96 .30925 L
.964 .30918 L
.968 .30912 L
.972 .30909 L
.976 .30906 L
.98 .30905 L
.984 .30904 L
.988 .30903 L
.992 .30902 L
.996 .30902 L
1 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42857 L
.012 .43006 L
.016 .43038 L
.02 .42963 L
.024 .42955 L
.028 .42975 L
.032 .42974 L
.036 .42956 L
.04 .42955 L
.044 .42952 L
.048 .42949 L
.052 .42942 L
.056 .42939 L
.06 .42933 L
.064 .42931 L
.068 .42925 L
.072 .42921 L
.076 .42916 L
.08 .42912 L
.084 .42907 L
.088 .42904 L
.092 .42898 L
.096 .42895 L
.1 .4289 L
.104 .42886 L
.108 .42881 L
.112 .42877 L
.116 .42872 L
.12 .42868 L
.124 .42863 L
.128 .42859 L
.132 .42854 L
.136 .4285 L
.14 .42846 L
.144 .42841 L
.148 .42836 L
.152 .42833 L
.156 .42828 L
.16 .42824 L
.164 .42819 L
.168 .42814 L
.172 .42811 L
.176 .42806 L
.18 .42801 L
.184 .42796 L
.188 .42792 L
.192 .42789 L
.196 .42784 L
.2 .42779 L
Mistroke
.204 .42774 L
.208 .42771 L
.212 .42767 L
.216 .42762 L
.22 .42756 L
.224 .42752 L
.228 .42749 L
.232 .42745 L
.236 .4274 L
.24 .42734 L
.244 .42729 L
.248 .42727 L
.252 .42723 L
.256 .42718 L
.26 .42712 L
.264 .42707 L
.268 .42704 L
.272 .42701 L
.276 .42696 L
.28 .4269 L
.284 .42684 L
.288 .42681 L
.292 .42679 L
.296 .42675 L
.3 .42669 L
.304 .42662 L
.308 .42658 L
.312 .42656 L
.316 .42654 L
.32 .42648 L
.324 .4264 L
.328 .42634 L
.332 .42632 L
.336 .42632 L
.34 .42629 L
.344 .42621 L
.348 .42612 L
.352 .42606 L
.356 .42606 L
.36 .42608 L
.364 .42604 L
.368 .42594 L
.372 .42582 L
.376 .42578 L
.38 .42581 L
.384 .42584 L
.388 .4258 L
.392 .42566 L
.396 .42552 L
.4 .42548 L
Mistroke
.404 .42555 L
.408 .42562 L
.412 .42557 L
.416 .4254 L
.42 .42522 L
.424 .42517 L
.428 .42526 L
.432 .42537 L
.436 .42536 L
.44 .42518 L
.444 .42496 L
.448 .42484 L
.452 .42491 L
.456 .42507 L
.46 .42514 L
.464 .42503 L
.468 .42478 L
.472 .42457 L
.476 .42453 L
.48 .42465 L
.484 .42481 L
.488 .42485 L
.492 .42471 L
.496 .42447 L
.5 .42427 L
.504 .42421 L
.508 .42428 L
.512 .42442 L
.516 .42451 L
.52 .42448 L
.524 .42433 L
.528 .4241 L
.532 .42389 L
.536 .42379 L
.54 .42384 L
.544 .42402 L
.548 .42423 L
.552 .42432 L
.556 .42419 L
.56 .42384 L
.564 .42341 L
.568 .42313 L
.572 .42316 L
.576 .4235 L
.58 .42398 L
.584 .42431 L
.588 .42426 L
.592 .4238 L
.596 .42312 L
.6 .42254 L
Mistroke
.604 .42234 L
.608 .4226 L
.612 .42318 L
.616 .42381 L
.62 .42417 L
.624 .42413 L
.628 .42369 L
.632 .42305 L
.636 .42242 L
.64 .42198 L
.644 .42181 L
.648 .42189 L
.652 .4222 L
.656 .42266 L
.66 .42322 L
.664 .42379 L
.668 .42423 L
.672 .42436 L
.676 .42405 L
.68 .42323 L
.684 .42201 L
.688 .42066 L
.692 .4195 L
.696 .41888 L
.7 .41901 L
.704 .4199 L
.708 .42137 L
.712 .42313 L
.716 .42485 L
.72 .42626 L
.724 .42721 L
.728 .42767 L
.732 .42768 L
.736 .42725 L
.74 .42637 L
.744 .42494 L
.748 .42282 L
.752 .41988 L
.756 .41605 L
.76 .41139 L
.764 .40605 L
.768 .40027 L
.772 .3943 L
.776 .38837 L
.78 .38259 L
.784 .37697 L
.788 .3714 L
.792 .36573 L
.796 .35979 L
.8 .35348 L
Mistroke
.804 .34676 L
.808 .3397 L
.812 .33244 L
.816 .32519 L
.82 .31813 L
.824 .31141 L
.828 .30511 L
.832 .29923 L
.836 .29367 L
.84 .28827 L
.844 .28284 L
.848 .2772 L
.852 .27119 L
.856 .26471 L
.86 .25773 L
.864 .25029 L
.868 .24248 L
.872 .23444 L
.876 .22635 L
.88 .2184 L
.884 .21074 L
.888 .20353 L
.892 .19688 L
.896 .19087 L
.9 .18555 L
.904 .18092 L
.908 .17697 L
.912 .17365 L
.916 .1709 L
.92 .16868 L
.924 .16689 L
.928 .16548 L
.932 .16439 L
.936 .16355 L
.94 .16291 L
.944 .16244 L
.948 .16209 L
.952 .16183 L
.956 .16165 L
.96 .16152 L
.964 .16142 L
.968 .16136 L
.972 .16132 L
.976 .16129 L
.98 .16127 L
.984 .16125 L
.988 .16124 L
.992 .16124 L
.996 .16123 L
1 .16123 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool20002Ool0
1000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00003Ool00`00Ool00006Ool01000Oomo
o`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomo
ogoo1@000goo0P000goo100017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00
Oomoo`0eOol200000goo00000003Ool20002Ool01000Oomoo`009goo000ROol2000JOol00`00Oomo
o`0300000goo001oo`0600001Woo000007oo001oo`80009oo`800008Ool00000Ool007oo001oo`@0
0005Ool007ooOol0000WOol0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`03001oogoo00800003Ool0000000=oo`09001oo`00Ool007oo
001oo`0000=oo`05001oogooOol00003Ool01P00Oomoogoo001oo`L000aoo`008Woo0P00@Goo00<0
07ooOol00Woo00<007ooOol047oo0P004Woo000ROol00`00Oomoo`16Ool00`00Oomoo`0?Ool00`00
Oomoo`0AOol0029oo`8004Moo`03001oogoo00ioo`03001oogoo019oo`008Woo0P00Agoo00<007oo
Ool03Woo00<007ooOol04Woo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomo
o`16Ool00`00Oomoo`0=Ool00`00Oomoo`0COol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00Agoo00<007ooOol03Goo00<007ooOol04goo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8004Qoo`03001oogoo00aoo`03001oogoo01=oo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`17Ool00`00Oomoo`0<
Ool00`00Oomoo`0COol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
B7oo00<007ooOol037oo00<007ooOol04goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`8004Uoo`<000Yoo`03001oogoo01Aoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<0
07ooOol0B7oo10000Woo0P001Goo00<007ooOol057oo000;Ool20004Ool00`00Oomoo`03Ool20002
Ool50002Ool2001<Ool01P00Oomoo`00Ool000Aoo`03001oogoo01Aoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`000Woo0P00C7oo00<007oo00000Woo00D007ooOomoo`0001Mo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1;Ool30003
Ool01000Oomoo`005goo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001=
Ool20003Ool01000Oomoo`005goo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00
Oomoo`02001BOol01000Oomoo`005goo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
1000Oomoo`00Dgoo00<007oo000067oo000;Ool2000:Ool20003Ool30003Ool2001COol2000HOol0
029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool2
0003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029o
o`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04
001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P00
0goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P00
17oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06
001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo
0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00
Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo
00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009o
o`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:
Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomo
o`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo
00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00
Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomo
o`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00
Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`00
00Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`80
00Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003
Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qoo`03
001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo00Moo`<0
00Ioo`03001oogoo00Yoo`00:7oo00<007ooOol0Cgoo0P005Goo000XOol00`00Oomoo`1>Ool2000F
Ool002Qoo`03001oogoo04ioo`03001oogoo01Eoo`00:7oo00<007ooOol0CGoo00<007ooOol05Woo
000XOol00`00Oomoo`1<Ool00`00Oomoo`0GOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`80
00=oo`<000=oo`03001oogoo04aoo`03001oogoo01Moo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001=Ool00`00Oomoo`0HOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001<Ool2000JOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008004Yoo`8001]oo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0B7oo0P00
77oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0
B7oo00<007ooOol06goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`17Ool00`00
Oomoo`0LOol002Qoo`03001oogoo04Ioo`8001ioo`00:7oo00<007ooOol0AGoo0P007goo000AOol2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`14Ool2000POol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0A7oo00<007ooOol07goo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo04=oo`03001oogoo021o
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Oom300000goo0000000SOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0?goo0P009Goo
000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo
0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003
Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=o
o`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<0
07ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001o
ogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo
00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<0
07ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@0
07ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo
079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`00
17oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00
Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001o
ogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000
Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomo
o`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomo
o`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000
Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomo
o`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool2
0004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@00
0goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol0
1@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00@007ooOomoo`<00003Ool007oo00=oo`03001oogoo00Yoo`0077oo00<007ooOol0Fgoo00<0
07ooOol057oo000LOol2001KOol00`00Oomoo`0EOol001aoo`03001oogoo05Uoo`03001oogoo01Io
o`0077oo00<007ooOol0FGoo00<007ooOol05Woo000LOol2001IOol00`00Oomoo`0GOol001aoo`03
001oogoo05Qoo`03001oogoo01Moo`0077oo00<007ooOol0Egoo00<007ooOol067oo000LOol2001H
Ool00`00Oomoo`0HOol001aoo`03001oogoo05Ioo`03001oogoo01Uoo`0077oo0P00Egoo00<007oo
Ool06Goo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1EOol00`00Oomoo`0JOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0E7oo00<007ooOol06goo000:
Ool01000Oomoo`002goo00<007ooOol00P00EGoo00<007ooOol06goo000:Ool01000Oomoo`002goo
00@007ooOol005Eoo`03001oogoo01aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo059o
o`03001oogoo01eoo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8005=oo`03001oogoo01eo
o`002goo0P0027oo1@000Woo00<007ooOol0DGoo00<007ooOol07Woo000LOol00`00Oomoo`1@Ool2
000POol001aoo`80055oo`03001oogoo01moo`0077oo00<007ooOol0Cgoo00<007ooOol087oo000L
Ool2001@Ool00`00Oomoo`0POol001aoo`03001oogoo04ioo`03001oogoo025oo`0077oo00<007oo
Ool0CGoo00<007ooOol08Woo000LOol2001>Ool00`00Oomoo`0ROol001Ioo`<000=oo`03001oogoo
04aoo`03001oogoo02=oo`005goo00<007ooOol00Woo00<007ooOol0;Woo6P000goo00<007ooOol0
97oo000GOol00`00Oomoo`02Oold000FOol4000WOol001Moo`03001oogoo009oo`03001oogoo079o
o`005goo00<007ooOol00Woo00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo
009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<0
07ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomo
o`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007oo
Ool017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(5678\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29739 m
.008 .29904 L
.012 .30029 L
.016 .30044 L
.02 .29943 L
.024 .2991 L
.028 .29962 L
.032 .29981 L
.036 .29958 L
.04 .29947 L
.044 .29956 L
.048 .29959 L
.052 .29955 L
.056 .29954 L
.06 .29954 L
.064 .29953 L
.068 .29952 L
.072 .29953 L
.076 .29953 L
.08 .2995 L
.084 .29948 L
.088 .2995 L
.092 .29953 L
.096 .29948 L
.1 .29943 L
.104 .29946 L
.108 .29952 L
.112 .29948 L
.116 .29939 L
.12 .29941 L
.124 .2995 L
.128 .29949 L
.132 .29938 L
.136 .29934 L
.14 .29945 L
.144 .29951 L
.148 .2994 L
.152 .29929 L
.156 .29935 L
.16 .29949 L
.164 .29947 L
.168 .2993 L
.172 .29924 L
.176 .29939 L
.18 .29951 L
.184 .29939 L
.188 .29918 L
.192 .29922 L
.196 .29945 L
.2 .29951 L
Mistroke
.204 .29928 L
.208 .29909 L
.212 .29924 L
.216 .29949 L
.22 .29947 L
.224 .29918 L
.228 .29903 L
.232 .29924 L
.236 .29952 L
.24 .29945 L
.244 .2991 L
.248 .29896 L
.252 .29922 L
.256 .29953 L
.26 .29945 L
.264 .29907 L
.268 .29889 L
.272 .29914 L
.276 .2995 L
.28 .29949 L
.284 .29911 L
.288 .29883 L
.292 .29898 L
.296 .29939 L
.3 .29956 L
.304 .29927 L
.308 .29883 L
.312 .29874 L
.316 .29913 L
.32 .29958 L
.324 .29956 L
.328 .29904 L
.332 .29855 L
.336 .29867 L
.34 .29934 L
.344 .29984 L
.348 .29956 L
.352 .29868 L
.356 .29813 L
.36 .29862 L
.364 .29973 L
.368 .30026 L
.372 .29947 L
.376 .29809 L
.38 .29759 L
.384 .29869 L
.388 .30036 L
.392 .30077 L
.396 .2993 L
.4 .29731 L
Mistroke
.404 .29694 L
.408 .29878 L
.412 .30109 L
.416 .30144 L
.42 .29925 L
.424 .29655 L
.428 .29609 L
.432 .29853 L
.436 .30163 L
.44 .30233 L
.444 .29976 L
.448 .29622 L
.452 .29506 L
.456 .29749 L
.46 .30139 L
.464 .30321 L
.468 .30122 L
.472 .29712 L
.476 .29449 L
.48 .29561 L
.484 .29951 L
.488 .30287 L
.492 .30296 L
.496 .29982 L
.5 .29606 L
.504 .29457 L
.508 .29629 L
.512 .29968 L
.516 .30222 L
.52 .30234 L
.524 .3003 L
.528 .29763 L
.532 .29588 L
.536 .29574 L
.54 .29705 L
.544 .29918 L
.548 .30133 L
.552 .30262 L
.556 .30216 L
.56 .29965 L
.564 .29589 L
.568 .29289 L
.572 .29283 L
.576 .29655 L
.58 .30253 L
.584 .30735 L
.588 .30767 L
.592 .3025 L
.596 .29424 L
.6 .28754 L
Mistroke
.604 .28659 L
.608 .29247 L
.612 .30233 L
.616 .31087 L
.62 .31339 L
.624 .30843 L
.628 .29855 L
.632 .28877 L
.636 .28381 L
.64 .28564 L
.644 .2928 L
.648 .30158 L
.652 .30819 L
.656 .31059 L
.66 .30901 L
.664 .30515 L
.668 .30078 L
.672 .29677 L
.676 .29299 L
.68 .28913 L
.684 .28561 L
.688 .28387 L
.692 .28584 L
.696 .29269 L
.7 .30377 L
.704 .3163 L
.708 .32617 L
.712 .32948 L
.716 .32424 L
.72 .31125 L
.724 .29392 L
.728 .27697 L
.732 .26473 L
.736 .25967 L
.74 .26177 L
.744 .26896 L
.748 .27828 L
.752 .28726 L
.756 .2949 L
.76 .30191 L
.764 .31014 L
.768 .32157 L
.772 .33729 L
.776 .35682 L
.78 .37815 L
.784 .39833 L
.788 .41446 L
.792 .42459 L
.796 .42836 L
.8 .42706 L
Mistroke
.804 .4232 L
.808 .41972 L
.812 .41914 L
.816 .42287 L
.82 .43087 L
.824 .4418 L
.828 .45342 L
.832 .46325 L
.836 .46923 L
.84 .47021 L
.844 .46617 L
.848 .45819 L
.852 .44816 L
.856 .43831 L
.86 .43079 L
.864 .42725 L
.868 .42856 L
.872 .43474 L
.876 .44503 L
.88 .45805 L
.884 .47209 L
.888 .48539 L
.892 .49637 L
.896 .50378 L
.9 .50688 L
.904 .50538 L
.908 .49945 L
.912 .48962 L
.916 .47665 L
.92 .46144 L
.924 .4449 L
.928 .42789 L
.932 .41116 L
.936 .39528 L
.94 .38068 L
.944 .36761 L
.948 .35619 L
.952 .34645 L
.956 .3383 L
.96 .33161 L
.964 .32622 L
.968 .32196 L
.972 .31863 L
.976 .31608 L
.98 .31416 L
.984 .31274 L
.988 .31171 L
.992 .31098 L
.996 .31051 L
1 .31022 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51831 m
.008 .51694 L
.012 .51663 L
.016 .51724 L
.02 .51732 L
.024 .51702 L
.028 .51704 L
.032 .51714 L
.036 .51715 L
.04 .51708 L
.044 .51711 L
.048 .51711 L
.052 .51712 L
.056 .5171 L
.06 .51711 L
.064 .5171 L
.068 .51712 L
.072 .5171 L
.076 .51711 L
.08 .5171 L
.084 .51711 L
.088 .51711 L
.092 .51711 L
.096 .51711 L
.1 .51711 L
.104 .51711 L
.108 .51711 L
.112 .51711 L
.116 .51711 L
.12 .51711 L
.124 .51711 L
.128 .51711 L
.132 .51711 L
.136 .51711 L
.14 .51711 L
.144 .51711 L
.148 .51711 L
.152 .51711 L
.156 .51711 L
.16 .51711 L
.164 .51711 L
.168 .5171 L
.172 .51711 L
.176 .51711 L
.18 .51711 L
.184 .5171 L
.188 .51711 L
.192 .51711 L
.196 .51711 L
.2 .5171 L
Mistroke
.204 .5171 L
.208 .51711 L
.212 .51711 L
.216 .51711 L
.22 .5171 L
.224 .5171 L
.228 .51711 L
.232 .51711 L
.236 .51711 L
.24 .5171 L
.244 .5171 L
.248 .51711 L
.252 .51711 L
.256 .51711 L
.26 .5171 L
.264 .51709 L
.268 .5171 L
.272 .51712 L
.276 .51711 L
.28 .5171 L
.284 .51709 L
.288 .5171 L
.292 .51711 L
.296 .51711 L
.3 .5171 L
.304 .51709 L
.308 .51709 L
.312 .51711 L
.316 .51712 L
.32 .51711 L
.324 .51709 L
.328 .51708 L
.332 .5171 L
.336 .51712 L
.34 .51712 L
.344 .5171 L
.348 .51707 L
.352 .51707 L
.356 .51711 L
.36 .51713 L
.364 .51713 L
.368 .51708 L
.372 .51705 L
.376 .51707 L
.38 .51712 L
.384 .51715 L
.388 .51713 L
.392 .51706 L
.396 .51703 L
.4 .51706 L
Mistroke
.404 .51714 L
.408 .51718 L
.412 .51714 L
.416 .51704 L
.42 .51699 L
.424 .51704 L
.428 .51715 L
.432 .51721 L
.436 .51716 L
.44 .51704 L
.444 .51696 L
.448 .517 L
.452 .51713 L
.456 .51723 L
.46 .51721 L
.464 .51708 L
.468 .51695 L
.472 .51694 L
.476 .51706 L
.48 .51721 L
.484 .51726 L
.488 .51718 L
.492 .51702 L
.496 .51691 L
.5 .51694 L
.504 .51708 L
.508 .51722 L
.512 .51727 L
.516 .51719 L
.52 .51705 L
.524 .51693 L
.528 .51691 L
.532 .517 L
.536 .51713 L
.54 .51724 L
.544 .51727 L
.548 .5172 L
.552 .51705 L
.556 .5169 L
.56 .51683 L
.564 .51689 L
.568 .51708 L
.572 .51731 L
.576 .51745 L
.58 .51739 L
.584 .51714 L
.588 .5168 L
.592 .51658 L
.596 .51661 L
.6 .51692 L
Mistroke
.604 .51735 L
.608 .51768 L
.612 .51772 L
.616 .51742 L
.62 .51692 L
.624 .51647 L
.628 .51629 L
.632 .51646 L
.636 .51691 L
.64 .51744 L
.644 .51781 L
.648 .51789 L
.652 .51767 L
.656 .51727 L
.66 .51682 L
.664 .51646 L
.668 .51626 L
.672 .51624 L
.676 .51641 L
.68 .51674 L
.684 .51721 L
.688 .51776 L
.692 .51826 L
.696 .51857 L
.7 .51852 L
.704 .51805 L
.708 .51719 L
.712 .51611 L
.716 .5151 L
.72 .51442 L
.724 .51429 L
.728 .51477 L
.732 .51577 L
.736 .5171 L
.74 .51849 L
.744 .51975 L
.748 .52072 L
.752 .52136 L
.756 .52166 L
.76 .52166 L
.764 .52132 L
.768 .52057 L
.772 .51931 L
.776 .5174 L
.78 .51479 L
.784 .51146 L
.788 .50752 L
.792 .50314 L
.796 .49852 L
.8 .49385 L
Mistroke
.804 .48926 L
.808 .48479 L
.812 .48039 L
.816 .47594 L
.82 .47134 L
.824 .46645 L
.828 .46124 L
.832 .45572 L
.836 .44999 L
.84 .44418 L
.844 .43846 L
.848 .43295 L
.852 .42775 L
.856 .4229 L
.86 .41834 L
.864 .41397 L
.868 .40967 L
.872 .40527 L
.876 .40065 L
.88 .39569 L
.884 .39034 L
.888 .38459 L
.892 .3785 L
.896 .37217 L
.9 .36571 L
.904 .35926 L
.908 .35296 L
.912 .34695 L
.916 .34132 L
.92 .33617 L
.924 .33154 L
.928 .32745 L
.932 .32392 L
.936 .32091 L
.94 .31839 L
.944 .31631 L
.948 .31463 L
.952 .31328 L
.956 .31222 L
.96 .3114 L
.964 .31076 L
.968 .31029 L
.972 .30993 L
.976 .30966 L
.98 .30947 L
.984 .30933 L
.988 .30923 L
.992 .30916 L
.996 .3091 L
1 .30906 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42535 L
.012 .4298 L
.016 .43137 L
.02 .42981 L
.024 .42925 L
.028 .42966 L
.032 .42983 L
.036 .42961 L
.04 .42952 L
.044 .4295 L
.048 .4295 L
.052 .42942 L
.056 .42939 L
.06 .42933 L
.064 .42931 L
.068 .42925 L
.072 .42921 L
.076 .42916 L
.08 .42912 L
.084 .42907 L
.088 .42904 L
.092 .42898 L
.096 .42895 L
.1 .4289 L
.104 .42886 L
.108 .42881 L
.112 .42877 L
.116 .42872 L
.12 .42868 L
.124 .42863 L
.128 .42859 L
.132 .42854 L
.136 .4285 L
.14 .42846 L
.144 .42841 L
.148 .42836 L
.152 .42833 L
.156 .42828 L
.16 .42824 L
.164 .42819 L
.168 .42814 L
.172 .4281 L
.176 .42807 L
.18 .42801 L
.184 .42797 L
.188 .42792 L
.192 .42789 L
.196 .42784 L
.2 .42779 L
Mistroke
.204 .42774 L
.208 .42771 L
.212 .42767 L
.216 .42762 L
.22 .42757 L
.224 .42752 L
.228 .42749 L
.232 .42745 L
.236 .4274 L
.24 .42734 L
.244 .4273 L
.248 .42727 L
.252 .42723 L
.256 .42718 L
.26 .42712 L
.264 .42707 L
.268 .42704 L
.272 .42701 L
.276 .42696 L
.28 .4269 L
.284 .42685 L
.288 .42682 L
.292 .42679 L
.296 .42675 L
.3 .42669 L
.304 .42663 L
.308 .42659 L
.312 .42657 L
.316 .42654 L
.32 .42648 L
.324 .42641 L
.328 .42635 L
.332 .42633 L
.336 .42632 L
.34 .42628 L
.344 .4262 L
.348 .42612 L
.352 .42608 L
.356 .42608 L
.36 .42607 L
.364 .42602 L
.368 .42592 L
.372 .42584 L
.376 .42581 L
.38 .42583 L
.384 .42583 L
.388 .42576 L
.392 .42563 L
.396 .42554 L
.4 .42554 L
Mistroke
.404 .42559 L
.408 .4256 L
.412 .4255 L
.416 .42535 L
.42 .42524 L
.424 .42525 L
.428 .42534 L
.432 .42537 L
.436 .42527 L
.44 .42508 L
.444 .42493 L
.448 .42494 L
.452 .42506 L
.456 .42514 L
.46 .42507 L
.464 .42486 L
.468 .42466 L
.472 .4246 L
.476 .4247 L
.48 .42485 L
.484 .42487 L
.488 .42472 L
.492 .42448 L
.496 .42431 L
.5 .4243 L
.504 .42442 L
.508 .42456 L
.512 .42457 L
.516 .42443 L
.52 .42421 L
.524 .42402 L
.528 .42396 L
.532 .42402 L
.536 .42414 L
.54 .42424 L
.544 .42423 L
.548 .42409 L
.552 .42387 L
.556 .42363 L
.56 .4235 L
.564 .42353 L
.568 .42372 L
.572 .42397 L
.576 .4241 L
.58 .42398 L
.584 .42362 L
.588 .42316 L
.592 .42284 L
.596 .42284 L
.6 .42318 L
Mistroke
.604 .42367 L
.608 .42404 L
.612 .42404 L
.616 .42363 L
.62 .42296 L
.624 .42235 L
.628 .42208 L
.632 .42226 L
.636 .42278 L
.64 .42338 L
.644 .4238 L
.648 .42386 L
.652 .42355 L
.656 .423 L
.66 .4224 L
.664 .42191 L
.668 .42161 L
.672 .42155 L
.676 .42171 L
.68 .42208 L
.684 .42263 L
.688 .42327 L
.692 .42385 L
.696 .42418 L
.7 .42408 L
.704 .42345 L
.708 .42233 L
.712 .42095 L
.716 .41964 L
.72 .41875 L
.724 .41855 L
.728 .4191 L
.732 .42031 L
.736 .42192 L
.74 .42362 L
.744 .42514 L
.748 .4263 L
.752 .42705 L
.756 .42739 L
.76 .42733 L
.764 .42686 L
.768 .42589 L
.772 .42427 L
.776 .42185 L
.78 .41855 L
.784 .41436 L
.788 .40941 L
.792 .40391 L
.796 .39811 L
.8 .39226 L
Mistroke
.804 .3865 L
.808 .38089 L
.812 .37536 L
.816 .36979 L
.82 .36401 L
.824 .35789 L
.828 .35137 L
.832 .34446 L
.836 .33729 L
.84 .33002 L
.844 .32286 L
.848 .31597 L
.852 .30947 L
.856 .30339 L
.86 .29769 L
.864 .29223 L
.868 .28684 L
.872 .28135 L
.876 .27556 L
.88 .26936 L
.884 .26267 L
.888 .2555 L
.892 .2479 L
.896 .23999 L
.9 .23192 L
.904 .22387 L
.908 .21602 L
.912 .20852 L
.916 .2015 L
.92 .19507 L
.924 .1893 L
.928 .18421 L
.932 .1798 L
.936 .17604 L
.94 .1729 L
.944 .17032 L
.948 .16822 L
.952 .16654 L
.956 .16522 L
.96 .16419 L
.964 .16341 L
.968 .16281 L
.972 .16237 L
.976 .16204 L
.98 .1618 L
.984 .16163 L
.988 .16151 L
.992 .16143 L
.996 .16138 L
1 .16134 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Ool0
00020002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007oo
Ool000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007oo
Oomoo`D000=oo`8000Aoo`@000=oo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<0
07ooOol0>7oo00@007ooOol000Aoo`80009oo`03001oo`0002Eoo`008Woo0P007Goo1@0000=oo`00
0000100000=oo`0000000P0000Aoo`00001oo`800004Ool00000Ool2000017oo000000000Woo00<0
07oo00000Woo00@007ooOol002Aoo`008WooH`0037oo000ROol01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00@007ooOomoo`@00004Ool007oo0002Ool20003Ool2
0002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`D000aoo`008Woo0P00@goo0P0017oo
00<007ooOol047oo00<007ooOol03Woo000ROol00`00Oomoo`18Ool00`00Oomoo`0?Ool2000@Ool0
029oo`8004Uoo`03001oogoo00moo`03001oogoo00moo`008Woo0P00BWoo00<007ooOol03Goo00<0
07ooOol047oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`19Ool00`00
Oomoo`0=Ool00`00Oomoo`0@Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P00BWoo00<007ooOol03Goo00<007ooOol047oo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8004Yoo`03001oogoo00eoo`03001oogoo011oo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1:Ool00`00Oomoo`0;Ool00`00Oomo
o`0AOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Bgoo00<007oo
Ool02goo00<007ooOol04Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8004]o
o`03001oo`0000]oo`03001oogoo015oo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007oo
Ool0BWoo0P0000=oo`00Ool00Woo0P001Goo00<007ooOol04Goo000;Ool20004Ool00`00Oomoo`03
Ool20002Ool50002Ool2001>Ool01000Oomoogoo0P001Goo00<007ooOol04Goo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001>Ool01P00Oomoo`00Ool000Aoo`03001o
ogoo019oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1>
Ool00`00Ool00002Ool01@00Oomoogoo000057oo000:Ool01000Oomoo`0027oo00@007ooOol000Ao
o`04001oogooOol2001?Ool20003Ool01@00Oomoogoo000057oo000:Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool00`00Oomoo`02001DOol01000Oomoo`005Goo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool01000Oomoo`00EWoo00<007oo00005Goo000;Ool2000:Ool20003Ool3
0003Ool2001EOol00`00Ool0000EOol0029oo`03001oogoo05Eoo`03001oogoo01Aoo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007oo
Ool006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007oo
Ool007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`80
06eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3
001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo
06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00
Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1V
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0
IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03
Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo
0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0
IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol0
06Qoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Ool006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
0P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo
0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001o
ogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo0000
0Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001o
ogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00
Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00
009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007oo
Ool00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo
000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009o
o`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03
001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003
Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03
001oogoo00moo`03001oogoo00moo`03001oogoo00Uoo`<000Aoo`03001oogoo00Yoo`00:7oo00<0
07ooOol0DWoo00<007ooOol04Goo000XOol00`00Oomoo`1AOol00`00Oomoo`0BOol002Qoo`03001o
ogoo051oo`8001Aoo`00:7oo00<007ooOol0Cgoo0P005Goo000XOol00`00Oomoo`1?Ool00`00Oomo
o`0DOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo04ioo`03
001oogoo01Eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04
001oogoo001?Ool2000GOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eo
o`04001oogoo001>Ool2000HOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo008004eoo`03001oogoo01Moo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01@00Oomoo`00Ool010000goo00<007ooOol0Bgoo00<007ooOol067oo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0BWoo00<007ooOol06Goo000;
Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1:Ool00`00Oomoo`0IOol002Qoo`03001o
ogoo04Qoo`8001aoo`00:7oo00<007ooOol0B7oo00<007ooOol06goo000AOol20004Ool00`00Oomo
o`03Ool20003Ool30003Ool00`00Oomoo`17Ool00`00Oomoo`0LOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0AWoo0P007Woo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo04Eoo`8001moo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Oom9000POol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0@Woo0P008Woo000@Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@0
07ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yo
o`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04
Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo
0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo
1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00
Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001o
ogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001o
ogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000L
Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04
001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000L
Ool2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo
0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00H007ooOomoo`00Ool40003Ool00`00
Oomoo`0:Ool001aoo`03001oogoo05ioo`03001oogoo015oo`0077oo0P00GWoo00<007ooOol04Woo
000LOol00`00Oomoo`1LOol00`00Oomoo`0COol001aoo`03001oogoo05]oo`03001oogoo01Aoo`00
77oo0P00G7oo00<007ooOol057oo000LOol00`00Oomoo`1KOol00`00Oomoo`0DOol001aoo`03001o
ogoo05Yoo`03001oogoo01Eoo`0077oo0P00FWoo00<007ooOol05Woo000LOol00`00Oomoo`1IOol0
0`00Oomoo`0FOol001aoo`8005Uoo`8001Qoo`002goo0P0017oo00<007ooOol00Woo0`000goo00<0
07ooOol0F7oo00<007ooOol05goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo05Moo`03001oogoo01Qoo`002Woo00@007ooOol000]oo`03001oogoo008005Moo`8001Yoo`00
2Woo00@007ooOol000]oo`04001oogoo001HOol00`00Oomoo`0IOol000Yoo`04001oogoo0007Ool4
0003Ool00`00Oomoo`1EOol00`00Oomoo`0JOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2
001EOol00`00Oomoo`0KOol000]oo`8000Qoo`D0009oo`03001oogoo05Aoo`03001oogoo01]oo`00
77oo00<007ooOol0Dgoo00<007ooOol077oo000LOol2001DOol00`00Oomoo`0LOol001aoo`03001o
ogoo059oo`03001oogoo01eoo`0077oo0P00DWoo0P007goo000LOol00`00Oomoo`1AOol00`00Oomo
o`0NOol001aoo`03001oogoo051oo`03001oogoo01moo`0077oo0P00D7oo00<007ooOol087oo000F
Ool30003Ool00`00Oomoo`1>Ool2000ROol001Moo`03001oogoo009oo`03001oogoo02ioo`03001o
o`0001X0009oo`8002=oo`005goo00<007ooOol00Woo=0006Goo100097oo000GOol00`00Oomoo`02
Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo
000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
00Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomo
o`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007oo
Ool02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yo
o`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
0001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(5845\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30003 m
.008 .30036 L
.012 .29939 L
.016 .29925 L
.02 .29983 L
.024 .29983 L
.028 .29951 L
.032 .29951 L
.036 .29967 L
.04 .29965 L
.044 .29957 L
.048 .29957 L
.052 .29959 L
.056 .29959 L
.06 .29958 L
.064 .29956 L
.068 .29955 L
.072 .29956 L
.076 .29957 L
.08 .29954 L
.084 .29951 L
.088 .29953 L
.092 .29956 L
.096 .29953 L
.1 .29948 L
.104 .29949 L
.108 .29954 L
.112 .29953 L
.116 .29945 L
.12 .29944 L
.124 .29951 L
.128 .29953 L
.132 .29944 L
.136 .29938 L
.14 .29945 L
.144 .29953 L
.148 .29947 L
.152 .29936 L
.156 .29936 L
.16 .29948 L
.164 .29951 L
.168 .29938 L
.172 .29928 L
.176 .29938 L
.18 .29952 L
.184 .29946 L
.188 .29926 L
.192 .29924 L
.196 .29943 L
.2 .29953 L
Mistroke
.204 .29936 L
.208 .29917 L
.212 .29924 L
.216 .29948 L
.22 .29951 L
.224 .29927 L
.228 .29909 L
.232 .29924 L
.236 .29951 L
.24 .29949 L
.244 .29919 L
.248 .29902 L
.252 .29923 L
.256 .29952 L
.26 .29948 L
.264 .29914 L
.268 .29896 L
.272 .29918 L
.276 .2995 L
.28 .2995 L
.284 .29915 L
.288 .2989 L
.292 .29906 L
.296 .29943 L
.3 .29955 L
.304 .29925 L
.308 .29887 L
.312 .29887 L
.316 .29925 L
.32 .29958 L
.324 .29946 L
.328 .29898 L
.332 .29867 L
.336 .2989 L
.34 .29946 L
.344 .29972 L
.348 .29934 L
.352 .29865 L
.356 .29842 L
.36 .29898 L
.364 .2998 L
.368 .29993 L
.372 .29911 L
.376 .29813 L
.38 .29812 L
.384 .29923 L
.388 .30035 L
.392 .30016 L
.396 .29869 L
.4 .29742 L
Mistroke
.404 .29782 L
.408 .29964 L
.412 .30105 L
.416 .30042 L
.42 .29819 L
.424 .29659 L
.428 .2974 L
.432 .30001 L
.436 .30183 L
.44 .30091 L
.444 .29793 L
.448 .29575 L
.452 .29663 L
.456 .2999 L
.46 .3025 L
.464 .30186 L
.468 .29842 L
.472 .29529 L
.476 .29539 L
.48 .29874 L
.484 .30238 L
.488 .30306 L
.492 .30015 L
.496 .29614 L
.5 .29445 L
.504 .29643 L
.508 .30038 L
.512 .30305 L
.516 .30241 L
.52 .29915 L
.524 .29587 L
.528 .29493 L
.532 .29673 L
.536 .29975 L
.54 .3019 L
.544 .30203 L
.548 .3004 L
.552 .2981 L
.556 .29627 L
.56 .29561 L
.564 .2964 L
.568 .29847 L
.572 .30117 L
.576 .30322 L
.58 .30317 L
.584 .30038 L
.588 .29583 L
.592 .29203 L
.596 .29169 L
.6 .2958 L
Mistroke
.604 .30258 L
.608 .30816 L
.612 .30881 L
.616 .30344 L
.62 .29458 L
.624 .28716 L
.628 .28563 L
.632 .29126 L
.636 .30129 L
.64 .31041 L
.644 .31377 L
.648 .30965 L
.652 .30027 L
.656 .29039 L
.66 .28464 L
.664 .28522 L
.668 .29114 L
.672 .29916 L
.676 .30583 L
.68 .30914 L
.684 .30902 L
.688 .30672 L
.692 .30353 L
.696 .3 L
.7 .29586 L
.704 .29086 L
.708 .28562 L
.712 .28194 L
.716 .28215 L
.72 .28789 L
.724 .29889 L
.728 .31258 L
.732 .32473 L
.736 .33101 L
.74 .32873 L
.744 .31792 L
.748 .30141 L
.752 .28373 L
.756 .26945 L
.76 .26158 L
.764 .2608 L
.768 .2656 L
.772 .27327 L
.776 .28126 L
.78 .28824 L
.784 .29458 L
.788 .30191 L
.792 .31229 L
.796 .32711 L
.8 .34632 L
Mistroke
.804 .36828 L
.808 .39018 L
.812 .40894 L
.816 .42214 L
.82 .42881 L
.824 .42965 L
.828 .4268 L
.832 .42313 L
.836 .42144 L
.84 .42362 L
.844 .43025 L
.848 .44051 L
.852 .45246 L
.856 .46365 L
.86 .47178 L
.864 .47523 L
.868 .47347 L
.872 .46708 L
.876 .45761 L
.88 .44718 L
.884 .43806 L
.888 .43217 L
.892 .43082 L
.896 .43448 L
.9 .44279 L
.904 .45468 L
.908 .46859 L
.912 .48276 L
.916 .49548 L
.92 .50529 L
.924 .51114 L
.928 .51248 L
.932 .50919 L
.936 .50161 L
.94 .49034 L
.944 .47622 L
.948 .46017 L
.952 .44309 L
.956 .42581 L
.96 .40901 L
.964 .39324 L
.968 .37888 L
.972 .36614 L
.976 .35513 L
.98 .34587 L
.984 .33825 L
.988 .3322 L
.992 .32753 L
.996 .32417 L
1 .32192 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .52338 m
.008 .51688 L
.012 .51474 L
.016 .51684 L
.02 .51761 L
.024 .51688 L
.028 .51665 L
.032 .51686 L
.036 .51697 L
.04 .51688 L
.044 .51686 L
.048 .51687 L
.052 .5169 L
.056 .51687 L
.06 .51688 L
.064 .51687 L
.068 .51689 L
.072 .51688 L
.076 .51688 L
.08 .51687 L
.084 .51688 L
.088 .51688 L
.092 .51688 L
.096 .51688 L
.1 .51688 L
.104 .51688 L
.108 .51688 L
.112 .51688 L
.116 .51688 L
.12 .51688 L
.124 .51688 L
.128 .51688 L
.132 .51688 L
.136 .51688 L
.14 .51688 L
.144 .51688 L
.148 .51688 L
.152 .51688 L
.156 .51688 L
.16 .51688 L
.164 .51688 L
.168 .51687 L
.172 .51688 L
.176 .51688 L
.18 .51688 L
.184 .51687 L
.188 .51687 L
.192 .51688 L
.196 .51688 L
.2 .51688 L
Mistroke
.204 .51687 L
.208 .51687 L
.212 .51688 L
.216 .51688 L
.22 .51687 L
.224 .51687 L
.228 .51688 L
.232 .51688 L
.236 .51688 L
.24 .51687 L
.244 .51687 L
.248 .51688 L
.252 .51688 L
.256 .51688 L
.26 .51687 L
.264 .51687 L
.268 .51687 L
.272 .51688 L
.276 .51688 L
.28 .51687 L
.284 .51686 L
.288 .51687 L
.292 .51688 L
.296 .51688 L
.3 .51687 L
.304 .51686 L
.308 .51686 L
.312 .51688 L
.316 .51689 L
.32 .51687 L
.324 .51686 L
.328 .51686 L
.332 .51687 L
.336 .51689 L
.34 .51689 L
.344 .51686 L
.348 .51685 L
.352 .51685 L
.356 .51688 L
.36 .5169 L
.364 .51688 L
.368 .51685 L
.372 .51683 L
.376 .51686 L
.38 .5169 L
.384 .51691 L
.388 .51687 L
.392 .51683 L
.396 .51682 L
.4 .51686 L
Mistroke
.404 .51692 L
.408 .51692 L
.412 .51687 L
.416 .5168 L
.42 .5168 L
.424 .51686 L
.428 .51694 L
.432 .51694 L
.436 .51687 L
.44 .51678 L
.444 .51677 L
.448 .51685 L
.452 .51695 L
.456 .51698 L
.46 .51689 L
.464 .51677 L
.468 .51673 L
.472 .5168 L
.476 .51694 L
.48 .51701 L
.484 .51695 L
.488 .51681 L
.492 .5167 L
.496 .51673 L
.5 .51686 L
.504 .51699 L
.508 .51702 L
.512 .51692 L
.516 .51677 L
.52 .51669 L
.524 .51673 L
.528 .51686 L
.532 .51698 L
.536 .51702 L
.54 .51695 L
.544 .51682 L
.548 .51671 L
.552 .51669 L
.556 .51676 L
.56 .51688 L
.564 .517 L
.568 .51705 L
.572 .517 L
.576 .51685 L
.58 .51667 L
.584 .51657 L
.588 .51662 L
.592 .51682 L
.596 .51707 L
.6 .51724 L
Mistroke
.604 .5172 L
.608 .51694 L
.612 .51659 L
.616 .51634 L
.62 .51634 L
.624 .51663 L
.628 .51707 L
.632 .51743 L
.636 .51751 L
.64 .51725 L
.644 .51678 L
.648 .51631 L
.652 .51608 L
.656 .51618 L
.66 .51657 L
.664 .51707 L
.668 .51746 L
.672 .51762 L
.676 .5175 L
.68 .51718 L
.684 .51678 L
.688 .5164 L
.692 .51613 L
.696 .516 L
.7 .51604 L
.704 .51628 L
.708 .5167 L
.712 .51727 L
.716 .51787 L
.72 .51832 L
.724 .51845 L
.728 .51814 L
.732 .5174 L
.736 .51635 L
.74 .51526 L
.744 .51441 L
.748 .51403 L
.752 .51424 L
.756 .515 L
.76 .51616 L
.764 .51749 L
.768 .51877 L
.772 .51986 L
.776 .52068 L
.78 .52122 L
.784 .52148 L
.788 .52144 L
.792 .52104 L
.796 .52017 L
.8 .51869 L
Mistroke
.804 .5165 L
.808 .51359 L
.812 .51 L
.816 .50589 L
.82 .50145 L
.824 .49687 L
.828 .49232 L
.832 .48787 L
.836 .48349 L
.84 .47912 L
.844 .47462 L
.848 .46989 L
.852 .46484 L
.856 .45947 L
.86 .45383 L
.864 .44805 L
.868 .44228 L
.872 .43666 L
.876 .43131 L
.88 .42629 L
.884 .42159 L
.888 .41715 L
.892 .41284 L
.896 .40851 L
.9 .40403 L
.904 .39927 L
.908 .39415 L
.912 .38864 L
.916 .38275 L
.92 .37656 L
.924 .37016 L
.928 .3637 L
.932 .3573 L
.936 .3511 L
.94 .34522 L
.944 .33976 L
.948 .33478 L
.952 .33033 L
.956 .32643 L
.96 .32306 L
.964 .3202 L
.968 .31781 L
.972 .31584 L
.976 .31424 L
.98 .31296 L
.984 .31194 L
.988 .31113 L
.992 .31049 L
.996 .30997 L
1 .30954 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43047 L
.012 .42964 L
.016 .4296 L
.02 .42991 L
.024 .42986 L
.028 .42961 L
.032 .42962 L
.036 .42963 L
.04 .42959 L
.044 .42949 L
.048 .42948 L
.052 .42943 L
.056 .4294 L
.06 .42933 L
.064 .4293 L
.068 .42925 L
.072 .42922 L
.076 .42916 L
.08 .42913 L
.084 .42907 L
.088 .42904 L
.092 .42898 L
.096 .42895 L
.1 .4289 L
.104 .42886 L
.108 .42881 L
.112 .42877 L
.116 .42872 L
.12 .42868 L
.124 .42863 L
.128 .42859 L
.132 .42854 L
.136 .4285 L
.14 .42846 L
.144 .42842 L
.148 .42837 L
.152 .42833 L
.156 .42828 L
.16 .42824 L
.164 .42819 L
.168 .42815 L
.172 .4281 L
.176 .42807 L
.18 .42802 L
.184 .42797 L
.188 .42792 L
.192 .42789 L
.196 .42784 L
.2 .42779 L
Mistroke
.204 .42774 L
.208 .42771 L
.212 .42767 L
.216 .42762 L
.22 .42757 L
.224 .42752 L
.228 .42749 L
.232 .42745 L
.236 .4274 L
.24 .42735 L
.244 .4273 L
.248 .42727 L
.252 .42723 L
.256 .42718 L
.26 .42713 L
.264 .42708 L
.268 .42704 L
.272 .42701 L
.276 .42696 L
.28 .4269 L
.284 .42685 L
.288 .42682 L
.292 .42679 L
.296 .42675 L
.3 .42669 L
.304 .42663 L
.308 .42659 L
.312 .42657 L
.316 .42653 L
.32 .42647 L
.324 .42641 L
.328 .42636 L
.332 .42634 L
.336 .42632 L
.34 .42627 L
.344 .4262 L
.348 .42613 L
.352 .4261 L
.356 .42609 L
.36 .42606 L
.364 .426 L
.368 .42591 L
.372 .42585 L
.376 .42584 L
.38 .42584 L
.384 .42581 L
.388 .42573 L
.392 .42563 L
.396 .42557 L
.4 .42558 L
Mistroke
.404 .4256 L
.408 .42557 L
.412 .42546 L
.416 .42533 L
.42 .42528 L
.424 .42532 L
.428 .42537 L
.432 .42533 L
.436 .42519 L
.44 .42504 L
.444 .42498 L
.448 .42504 L
.452 .42513 L
.456 .42511 L
.46 .42496 L
.464 .42477 L
.468 .42467 L
.472 .42472 L
.476 .42485 L
.48 .42489 L
.484 .42477 L
.488 .42455 L
.492 .42438 L
.496 .42436 L
.5 .42449 L
.504 .42461 L
.508 .42459 L
.512 .42442 L
.516 .4242 L
.52 .42405 L
.524 .42406 L
.528 .42418 L
.532 .42429 L
.536 .42429 L
.54 .42416 L
.544 .42395 L
.548 .42378 L
.552 .4237 L
.556 .42374 L
.56 .42386 L
.564 .42396 L
.568 .42398 L
.572 .42387 L
.576 .42364 L
.58 .42338 L
.584 .42321 L
.588 .42322 L
.592 .42343 L
.596 .4237 L
.6 .42386 L
Mistroke
.604 .42377 L
.608 .42341 L
.612 .42292 L
.616 .42256 L
.62 .42253 L
.624 .42285 L
.628 .42335 L
.632 .42376 L
.636 .42381 L
.64 .42345 L
.644 .42281 L
.648 .42218 L
.652 .42185 L
.656 .42194 L
.66 .42238 L
.664 .42295 L
.668 .4234 L
.672 .42355 L
.676 .42336 L
.68 .42292 L
.684 .42238 L
.688 .42186 L
.692 .42148 L
.696 .42127 L
.7 .42128 L
.704 .42153 L
.708 .42202 L
.712 .42269 L
.716 .42338 L
.72 .4239 L
.724 .42402 L
.728 .42359 L
.732 .42262 L
.736 .42128 L
.74 .41987 L
.744 .41877 L
.748 .41825 L
.752 .41847 L
.756 .41938 L
.76 .42078 L
.764 .42239 L
.768 .42395 L
.772 .42526 L
.776 .42624 L
.78 .42686 L
.784 .42714 L
.788 .42705 L
.792 .42651 L
.796 .42538 L
.8 .42349 L
Mistroke
.804 .42072 L
.808 .41704 L
.812 .41252 L
.816 .40736 L
.82 .40178 L
.824 .39605 L
.828 .39033 L
.832 .38474 L
.836 .37926 L
.84 .37377 L
.844 .36813 L
.848 .3622 L
.852 .35588 L
.856 .34915 L
.86 .34209 L
.864 .33486 L
.868 .32764 L
.872 .32061 L
.876 .31392 L
.88 .30764 L
.884 .30176 L
.888 .2962 L
.892 .2908 L
.896 .28539 L
.9 .27979 L
.904 .27384 L
.908 .26744 L
.912 .26055 L
.916 .2532 L
.92 .24546 L
.924 .23748 L
.928 .22941 L
.932 .22143 L
.936 .2137 L
.94 .20637 L
.944 .19955 L
.948 .19335 L
.952 .1878 L
.956 .18294 L
.96 .17874 L
.964 .17519 L
.968 .17223 L
.972 .1698 L
.976 .16784 L
.98 .16628 L
.984 .16507 L
.988 .16416 L
.992 .16348 L
.996 .16302 L
1 .16271 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01000Oomo
ogoo10000Woo00@007ooOol0009oo`05001oogooOol00003Ool00`00Ool00006Ool01000Oomoo`00
1Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo
1@000goo0P0017oo0`0000Aoo`00001oo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo
00<007ooOol0>Woo00<007ooOol00P000goo0P000Woo00@007ooOol0029oo`008Woo0P007Woo00L0
07oo000007oo001oo`0600000goo00000002000017oo000007oo0P0000Eoo`00000007oo00800003
Ool00000009oo`<0009oo`05001oogooOol0000QOol0029oof<000aoo`008Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00002Ool20002Ool0
1000Oomoogoo0P0000=oo`0000000Woo0P000goo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool00`00Oomoo`0:Ool0029oo`8004Eoo`8000Eoo`03001oogoo011oo`8000aoo`008Woo00<007oo
Ool0AGoo00<007ooOol00goo00<007ooOol03goo00<007ooOol037oo000ROol2001<Ool00`00Oomo
o`0?Ool00`00Oomoo`0<Ool0029oo`8004aoo`03001oogoo00ioo`03001oogoo00eoo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0Bgoo00<007ooOol03Woo00<007ooOol0
3Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8004aoo`03001oogoo
00eoo`03001oogoo00ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2
001=Ool00`00Oomoo`0<Ool00`00Oomoo`0>Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0C7oo00<007ooOol037oo00<007ooOol03Woo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8004eoo`03001oogoo00aoo`03001oogoo00io
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001=Ool01000Oomoo`002goo00<0
07ooOol03Woo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1=Ool30004Ool00`00
Oomoo`03Ool00`00Oomoo`0?Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`80055o
o`03001oogoo008000Eoo`03001oogoo00moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`000Woo0P00DGoo00H007ooOol007oo0004Ool00`00Oomoo`0?Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0D7oo00<007oo00000Woo00D007oo
Oomoo`00019oo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00DWoo0P00
0goo00@007ooOol0019oo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol0
0P00DWoo0P000goo00@007ooOol0019oo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00@007ooOol005Qoo`04001oogoo000BOol000]oo`8000Yoo`8000=oo`<000=oo`8005Moo`03001o
o`0001=oo`008Woo00<007ooOol0Egoo0P004goo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eo
o`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool0
0`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^
Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0
029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04
001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo
06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
00Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool0
0`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004
Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004
Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03
001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004
Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001o
ogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uo
o`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04
001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001o
ogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03
001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo
00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`80
00Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
oed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo
00<007ooOol037oo0P000Woo00<007ooOol02Woo000XOol00`00Oomoo`1DOol2000@Ool002Qoo`03
001oogoo05=oo`03001oogoo011oo`00:7oo00<007ooOol0Dgoo00<007ooOol047oo000XOol00`00
Oomoo`1BOol00`00Oomoo`0AOol002Qoo`03001oogoo055oo`8001=oo`002goo0P0017oo00<007oo
Ool00goo0P0017oo0P000goo0`000goo00<007ooOol0DGoo00<007ooOol04Woo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol0059oo`03001oogoo01=o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0055oo`03
001oogoo01Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool00P00Cgoo0P005Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`04
0003Ool00`00Oomoo`1=Ool2000GOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007oo
Ool007oo0006Ool00`00Oomoo`1<Ool2000HOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03
001oogoo04aoo`03001oogoo01Moo`00:7oo00<007ooOol0Bgoo00<007ooOol067oo000XOol00`00
Oomoo`1:Ool2000JOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo04Uo
o`8001]oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`18
Ool2000LOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
Agoo0P007Goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oodP00003Ool0
000001ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`14
Ool2000POol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000A
Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomo
ogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
1Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:
Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool2
0004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo
000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo
00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool3
0003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`80
00eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009o
o`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001o
ogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@0
07ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@0
00=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool0
1P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Ao
o`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo
00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool0
1`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001o
ogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool3
0002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<
Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo1P0037oo000LOol00`00Oomoo`1POol2000@Ool001ao
o`80065oo`03001oogoo00moo`0077oo00<007ooOol0Ggoo00<007ooOol047oo000LOol00`00Oomo
o`1NOol00`00Oomoo`0AOol001aoo`8005moo`03001oogoo015oo`0077oo00<007ooOol0GGoo00<0
07ooOol04Woo000LOol00`00Oomoo`1MOol00`00Oomoo`0BOol001aoo`8005eoo`03001oogoo01=o
o`0077oo00<007ooOol0G7oo00<007ooOol04goo000LOol2001LOol00`00Oomoo`0DOol000]oo`80
00Aoo`03001oogoo009oo`<000=oo`03001oogoo05]oo`03001oogoo01Aoo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1JOol00`00Oomoo`0EOol000Yoo`04001oogoo000;
Ool00`00Oomoo`02001JOol00`00Oomoo`0FOol000Yoo`04001oogoo000;Ool01000Oomoo`00FWoo
0P0067oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0F7oo00<007ooOol05goo000:Ool0
1000Oomoo`001goo00<007ooOol017oo0P00F7oo00<007ooOol067oo000;Ool20008Ool50002Ool0
0`00Oomoo`1GOol00`00Oomoo`0HOol001aoo`03001oogoo05Ioo`03001oogoo01Uoo`0077oo0P00
EWoo0P006goo000LOol00`00Oomoo`1EOol00`00Oomoo`0JOol001aoo`8005Eoo`03001oogoo01]o
o`0077oo00<007ooOol0Dgoo0P007Goo000LOol00`00Oomoo`1COol00`00Oomoo`0LOol001aoo`80
05=oo`03001oogoo01eoo`005Woo0`000goo00<007ooOol0DGoo0P007goo000GOol00`00Oomoo`02
Ool00`00Oomoo`0^Ool00`00Ool0000M0002Ool2000POol001Moo`03001oogoo009ooc<001eoo`<0
029oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1b
Ool001Ioo`8000Aoo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03
001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001o
ogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo1000
0goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001o
ogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(6012\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30199 m
.008 .30039 L
.012 .29896 L
.016 .29877 L
.02 .29988 L
.024 .30019 L
.028 .29961 L
.032 .2994 L
.036 .29965 L
.04 .29975 L
.044 .29965 L
.048 .29958 L
.052 .29961 L
.056 .29963 L
.06 .29963 L
.064 .2996 L
.068 .29958 L
.072 .29959 L
.076 .29961 L
.08 .29959 L
.084 .29955 L
.088 .29955 L
.092 .29959 L
.096 .29958 L
.1 .29952 L
.104 .29951 L
.108 .29956 L
.112 .29957 L
.116 .2995 L
.12 .29947 L
.124 .29952 L
.128 .29956 L
.132 .29951 L
.136 .29943 L
.14 .29946 L
.144 .29954 L
.148 .29952 L
.152 .29942 L
.156 .29939 L
.16 .29948 L
.164 .29955 L
.168 .29945 L
.172 .29933 L
.176 .29939 L
.18 .29953 L
.184 .29951 L
.188 .29934 L
.192 .29928 L
.196 .29942 L
.2 .29955 L
Mistroke
.204 .29944 L
.208 .29924 L
.212 .29926 L
.216 .29946 L
.22 .29954 L
.224 .29935 L
.228 .29916 L
.232 .29925 L
.236 .2995 L
.24 .29953 L
.244 .29927 L
.248 .29909 L
.252 .29924 L
.256 .29951 L
.26 .29951 L
.264 .29921 L
.268 .29902 L
.272 .2992 L
.276 .29951 L
.28 .29951 L
.284 .2992 L
.288 .29896 L
.292 .29912 L
.296 .29946 L
.3 .29954 L
.304 .29925 L
.308 .29893 L
.312 .29897 L
.316 .29933 L
.32 .29957 L
.324 .2994 L
.328 .29898 L
.332 .29879 L
.336 .29907 L
.34 .29951 L
.344 .29962 L
.348 .29921 L
.352 .2987 L
.356 .29867 L
.36 .29922 L
.364 .29977 L
.368 .29967 L
.372 .29892 L
.376 .2983 L
.38 .29856 L
.384 .29953 L
.388 .30017 L
.392 .29967 L
.396 .29843 L
.4 .29778 L
Mistroke
.404 .29854 L
.408 .30004 L
.412 .30067 L
.416 .29958 L
.42 .29776 L
.424 .29715 L
.428 .29856 L
.432 .30068 L
.436 .30127 L
.44 .29954 L
.444 .29707 L
.448 .2964 L
.452 .29838 L
.456 .3012 L
.46 .30204 L
.464 .29988 L
.468 .29667 L
.472 .29549 L
.476 .29763 L
.48 .30119 L
.484 .30285 L
.488 .30096 L
.492 .29713 L
.496 .2948 L
.5 .29611 L
.504 .29995 L
.508 .30297 L
.512 .30257 L
.516 .2991 L
.52 .2955 L
.524 .2947 L
.528 .29724 L
.532 .30096 L
.536 .30296 L
.54 .30186 L
.544 .29872 L
.548 .29593 L
.552 .29531 L
.556 .29697 L
.56 .29958 L
.564 .30151 L
.568 .30187 L
.572 .30072 L
.576 .29868 L
.58 .29659 L
.584 .29532 L
.588 .29561 L
.592 .29776 L
.596 .30109 L
.6 .3039 L
Mistroke
.604 .3042 L
.608 .3011 L
.612 .29576 L
.616 .29121 L
.62 .29057 L
.624 .295 L
.628 .3025 L
.632 .30881 L
.636 .30988 L
.64 .30445 L
.644 .29514 L
.648 .28704 L
.652 .28483 L
.656 .29003 L
.66 .30003 L
.664 .30961 L
.668 .31384 L
.672 .31072 L
.676 .30206 L
.68 .29227 L
.684 .28586 L
.688 .28522 L
.692 .28976 L
.696 .2968 L
.7 .30325 L
.704 .30721 L
.708 .30841 L
.712 .3077 L
.716 .30592 L
.72 .30323 L
.724 .29914 L
.728 .29336 L
.732 .28659 L
.736 .28091 L
.74 .27906 L
.744 .28319 L
.748 .29354 L
.752 .30786 L
.756 .32196 L
.76 .33115 L
.764 .33206 L
.768 .32393 L
.772 .3089 L
.776 .29114 L
.78 .27531 L
.784 .26493 L
.788 .26134 L
.792 .26362 L
.796 .2694 L
.8 .27614 L
Mistroke
.804 .28225 L
.808 .28773 L
.812 .294 L
.816 .30311 L
.82 .3167 L
.824 .33518 L
.828 .35731 L
.832 .38053 L
.836 .40166 L
.84 .41791 L
.844 .4277 L
.848 .43112 L
.852 .42981 L
.856 .42647 L
.86 .424 L
.864 .42475 L
.868 .42988 L
.872 .43912 L
.876 .45095 L
.88 .4631 L
.884 .47312 L
.888 .47902 L
.892 .47975 L
.896 .47538 L
.9 .46704 L
.904 .45663 L
.908 .44638 L
.912 .43846 L
.916 .43453 L
.92 .43551 L
.924 .44148 L
.928 .45173 L
.932 .46495 L
.936 .47947 L
.94 .49353 L
.944 .5055 L
.948 .51411 L
.952 .51849 L
.956 .51832 L
.96 .51366 L
.964 .50501 L
.968 .4931 L
.972 .47889 L
.976 .46329 L
.98 .44732 L
.984 .43177 L
.988 .4174 L
.992 .40473 L
.996 .39415 L
1 .38592 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51668 m
.008 .51678 L
.012 .51676 L
.016 .51648 L
.02 .5166 L
.024 .51672 L
.028 .5167 L
.032 .5166 L
.036 .51664 L
.04 .51666 L
.044 .51667 L
.048 .51664 L
.052 .51665 L
.056 .51665 L
.06 .51666 L
.064 .51664 L
.068 .51665 L
.072 .51665 L
.076 .51665 L
.08 .51665 L
.084 .51665 L
.088 .51665 L
.092 .51665 L
.096 .51665 L
.1 .51665 L
.104 .51665 L
.108 .51665 L
.112 .51665 L
.116 .51665 L
.12 .51665 L
.124 .51665 L
.128 .51665 L
.132 .51665 L
.136 .51665 L
.14 .51665 L
.144 .51665 L
.148 .51665 L
.152 .51665 L
.156 .51665 L
.16 .51665 L
.164 .51665 L
.168 .51664 L
.172 .51665 L
.176 .51665 L
.18 .51665 L
.184 .51664 L
.188 .51665 L
.192 .51665 L
.196 .51665 L
.2 .51665 L
Mistroke
.204 .51664 L
.208 .51664 L
.212 .51665 L
.216 .51665 L
.22 .51665 L
.224 .51664 L
.228 .51664 L
.232 .51665 L
.236 .51665 L
.24 .51664 L
.244 .51664 L
.248 .51664 L
.252 .51665 L
.256 .51665 L
.26 .51664 L
.264 .51664 L
.268 .51664 L
.272 .51665 L
.276 .51665 L
.28 .51664 L
.284 .51663 L
.288 .51664 L
.292 .51665 L
.296 .51665 L
.3 .51664 L
.304 .51663 L
.308 .51664 L
.312 .51665 L
.316 .51665 L
.32 .51664 L
.324 .51663 L
.328 .51663 L
.332 .51664 L
.336 .51666 L
.34 .51665 L
.344 .51663 L
.348 .51662 L
.352 .51663 L
.356 .51665 L
.36 .51666 L
.364 .51664 L
.368 .51662 L
.372 .51661 L
.376 .51664 L
.38 .51666 L
.384 .51666 L
.388 .51663 L
.392 .5166 L
.396 .51661 L
.4 .51665 L
Mistroke
.404 .51668 L
.408 .51667 L
.412 .51662 L
.416 .51658 L
.42 .5166 L
.424 .51666 L
.428 .5167 L
.432 .51667 L
.436 .5166 L
.44 .51655 L
.444 .51658 L
.448 .51667 L
.452 .51672 L
.456 .51669 L
.46 .5166 L
.464 .51653 L
.468 .51655 L
.472 .51666 L
.476 .51675 L
.48 .51673 L
.484 .51662 L
.488 .51651 L
.492 .51651 L
.496 .51661 L
.5 .51674 L
.504 .51677 L
.508 .51668 L
.512 .51655 L
.516 .51647 L
.52 .51652 L
.524 .51666 L
.528 .51677 L
.532 .51677 L
.536 .51666 L
.54 .51653 L
.544 .51647 L
.548 .51651 L
.552 .51663 L
.556 .51675 L
.56 .51678 L
.564 .51672 L
.568 .5166 L
.572 .51649 L
.576 .51645 L
.58 .51651 L
.584 .51663 L
.588 .51676 L
.592 .51683 L
.596 .51679 L
.6 .51664 L
Mistroke
.604 .51644 L
.608 .51632 L
.612 .51635 L
.616 .51656 L
.62 .51683 L
.624 .51703 L
.628 .517 L
.632 .51675 L
.636 .51638 L
.64 .5161 L
.644 .51608 L
.648 .51635 L
.652 .51679 L
.656 .51717 L
.66 .51729 L
.664 .51708 L
.668 .51664 L
.672 .51617 L
.676 .51589 L
.68 .51592 L
.684 .51624 L
.688 .5167 L
.692 .5171 L
.696 .51732 L
.7 .5173 L
.704 .51707 L
.708 .51673 L
.712 .51636 L
.716 .51603 L
.72 .5158 L
.724 .51573 L
.728 .51585 L
.732 .5162 L
.736 .51676 L
.74 .51741 L
.744 .51799 L
.748 .51829 L
.752 .51817 L
.756 .51757 L
.76 .51661 L
.764 .51549 L
.768 .5145 L
.772 .5139 L
.776 .51385 L
.78 .51435 L
.784 .51531 L
.788 .51652 L
.792 .51778 L
.796 .51894 L
.8 .51989 L
Mistroke
.804 .52061 L
.808 .5211 L
.812 .52134 L
.816 .52126 L
.82 .52076 L
.824 .51969 L
.828 .51794 L
.832 .51545 L
.836 .51225 L
.84 .50845 L
.844 .50423 L
.848 .4998 L
.852 .49531 L
.856 .49089 L
.86 .48654 L
.864 .48223 L
.868 .47783 L
.872 .47324 L
.876 .46835 L
.88 .46314 L
.884 .45763 L
.888 .45191 L
.892 .44613 L
.896 .44043 L
.9 .43494 L
.904 .42976 L
.908 .42491 L
.912 .42035 L
.916 .41599 L
.92 .41169 L
.924 .40732 L
.928 .40273 L
.932 .39782 L
.936 .39254 L
.94 .38686 L
.944 .38084 L
.948 .37455 L
.952 .3681 L
.956 .36163 L
.96 .35526 L
.964 .34913 L
.968 .34333 L
.972 .33794 L
.976 .33302 L
.98 .32859 L
.984 .32464 L
.988 .32115 L
.992 .31807 L
.996 .31536 L
1 .31291 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43461 L
.012 .42986 L
.016 .42828 L
.02 .42975 L
.024 .43028 L
.028 .42969 L
.032 .42949 L
.036 .42959 L
.04 .42963 L
.044 .42951 L
.048 .42946 L
.052 .42942 L
.056 .4294 L
.06 .42933 L
.064 .4293 L
.068 .42925 L
.072 .42922 L
.076 .42916 L
.08 .42913 L
.084 .42907 L
.088 .42904 L
.092 .42898 L
.096 .42895 L
.1 .4289 L
.104 .42886 L
.108 .42881 L
.112 .42877 L
.116 .42872 L
.12 .42868 L
.124 .42863 L
.128 .42859 L
.132 .42854 L
.136 .4285 L
.14 .42846 L
.144 .42842 L
.148 .42837 L
.152 .42833 L
.156 .42828 L
.16 .42824 L
.164 .42819 L
.168 .42815 L
.172 .4281 L
.176 .42807 L
.18 .42802 L
.184 .42797 L
.188 .42792 L
.192 .42789 L
.196 .42784 L
.2 .4278 L
Mistroke
.204 .42775 L
.208 .42771 L
.212 .42767 L
.216 .42763 L
.22 .42757 L
.224 .42753 L
.228 .42749 L
.232 .42745 L
.236 .4274 L
.24 .42735 L
.244 .4273 L
.248 .42727 L
.252 .42723 L
.256 .42718 L
.26 .42713 L
.264 .42708 L
.268 .42705 L
.272 .42701 L
.276 .42696 L
.28 .42691 L
.284 .42686 L
.288 .42682 L
.292 .42679 L
.296 .42675 L
.3 .42669 L
.304 .42663 L
.308 .4266 L
.312 .42657 L
.316 .42653 L
.32 .42647 L
.324 .42641 L
.328 .42637 L
.332 .42634 L
.336 .42631 L
.34 .42626 L
.344 .4262 L
.348 .42614 L
.352 .42611 L
.356 .42609 L
.36 .42606 L
.364 .42599 L
.368 .42592 L
.372 .42587 L
.376 .42585 L
.38 .42584 L
.384 .4258 L
.388 .42571 L
.392 .42563 L
.396 .4256 L
.4 .4256 L
Mistroke
.404 .4256 L
.408 .42554 L
.412 .42543 L
.416 .42534 L
.42 .42532 L
.424 .42536 L
.428 .42536 L
.432 .42529 L
.436 .42515 L
.44 .42505 L
.444 .42504 L
.448 .4251 L
.452 .42513 L
.456 .42504 L
.46 .42488 L
.464 .42475 L
.468 .42474 L
.472 .42483 L
.476 .42489 L
.48 .42483 L
.484 .42465 L
.488 .42447 L
.492 .42442 L
.496 .42451 L
.5 .42462 L
.504 .42462 L
.508 .42447 L
.512 .42425 L
.516 .42411 L
.52 .42414 L
.524 .42426 L
.528 .42435 L
.532 .42431 L
.536 .42413 L
.54 .42392 L
.544 .4238 L
.548 .42382 L
.552 .42392 L
.556 .42402 L
.56 .42402 L
.564 .42389 L
.568 .4237 L
.572 .42353 L
.576 .42344 L
.58 .42346 L
.584 .42357 L
.588 .42369 L
.592 .42374 L
.596 .42364 L
.6 .42341 L
Mistroke
.604 .42312 L
.608 .42292 L
.612 .42292 L
.616 .42313 L
.62 .42343 L
.624 .42363 L
.628 .42356 L
.632 .42319 L
.636 .42269 L
.64 .4223 L
.644 .42223 L
.648 .42252 L
.652 .42302 L
.656 .42346 L
.66 .42356 L
.664 .42326 L
.668 .42266 L
.672 .42203 L
.676 .42164 L
.68 .42164 L
.684 .422 L
.688 .42252 L
.692 .42298 L
.696 .42321 L
.7 .42314 L
.704 .42282 L
.708 .42234 L
.712 .42184 L
.716 .42138 L
.72 .42105 L
.724 .42092 L
.728 .42103 L
.732 .42143 L
.736 .42208 L
.74 .42284 L
.744 .42352 L
.748 .42385 L
.752 .42365 L
.756 .42287 L
.76 .42162 L
.764 .42018 L
.768 .41891 L
.772 .41812 L
.776 .41801 L
.78 .4186 L
.784 .41975 L
.788 .42122 L
.792 .42275 L
.796 .42414 L
.8 .42528 L
Mistroke
.804 .42614 L
.808 .4267 L
.812 .42695 L
.816 .42681 L
.82 .42614 L
.824 .42477 L
.828 .42254 L
.832 .4194 L
.836 .41536 L
.84 .41058 L
.844 .40529 L
.848 .39972 L
.852 .39409 L
.856 .38854 L
.86 .38309 L
.864 .37767 L
.868 .37216 L
.872 .3664 L
.876 .36028 L
.88 .35375 L
.884 .34684 L
.888 .33969 L
.892 .33245 L
.896 .32532 L
.9 .31846 L
.904 .31198 L
.908 .30591 L
.912 .30021 L
.916 .29475 L
.92 .28938 L
.924 .28391 L
.928 .27817 L
.932 .27204 L
.936 .26545 L
.94 .25837 L
.944 .25087 L
.948 .24305 L
.952 .23504 L
.956 .22703 L
.96 .21917 L
.964 .21164 L
.968 .20457 L
.972 .19808 L
.976 .19225 L
.98 .18714 L
.984 .18276 L
.988 .17912 L
.992 .1762 L
.996 .17398 L
1 .17241 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo0P0000Eoo`00Oomoo`00009oo`05001oogooOol00003Ool00`00Ool00006Ool01000
Oomoo`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000
Oomoogoo1@000goo0P0017oo0`000goo0`0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol0
0`00Oomoo`0lOol20002Ool01000Oomoogoo0`000Woo00@007oo000001moo`008Woo0P0087oo0P00
00=oo`00Ool01P0000=oo`0000000P0000=oo`0000000P0000Eoo`00000007oo00800007Ool00000
Ool007oo00000Woo00<007oo00000Woo00@007ooOol001moo`008WooH`0037oo000ROol01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoo`000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`03
001oogoo008000=oo`03001oogoo00<0009oo`05001oo`00Ool00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000aoo`008Woo0P00B7oo0P0017oo00<007ooOol077oo000ROol00`00Oomoo`17
Ool20004Ool00`00Oomoo`0LOol0029oo`8004ioo`03001oogoo01aoo`008Woo0P00Cgoo00<007oo
Ool06goo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1>Ool00`00Oomo
o`0KOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Cgoo00<007oo
Ool06goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8004moo`03001o
ogoo00ioo`03001oogoo00Yoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1?Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P00D7oo00<007ooOol037oo00<007ooOol02goo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000Aoo`80051oo`03001oogoo00]oo`03001oogoo00aoo`00
2goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0Cgoo10002Woo00<007ooOol037oo000;
Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001COol01000Oomoogoo0P001Goo00<007oo
Ool037oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001COol01`00
Oomoogoo001oo`0000Aoo`03001oogoo00aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1BOol01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol037oo
000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001DOol00`00Ool00002Ool0
1@00Oomoogoo00003goo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001EOol01@00Oomoogoo00000goo00<007ooOol03Goo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool01000Oomoo`00Fgoo00<007oo000047oo000;Ool2000:Ool20003Ool30003Ool2001J
Ool00`00Ool0000@Ool0029oo`03001oogoo05Uoo`03001oo`00011oo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0P00Fgoo00<007ooOol03goo000:Ool01000Oomoo`0027oo00H007oo
Ool007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@0
07ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04
001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029o
o`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003
Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001o
ogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00
Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0
0P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomo
o`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007oo
Ool0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomo
o`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`00
4Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007oo
Ool006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@00
0goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol0
00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo
00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04
001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool0
0`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`00
1Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0
009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qo
o`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol5
0003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011o
o`03001oogoo00moo`03001oogoo00moo`03001oogoo00ioo`<000aoo`00:7oo00<007ooOol0EWoo
0P003Woo000XOol00`00Oomoo`1FOol00`00Oomoo`0=Ool002Qoo`03001oogoo05Eoo`03001oogoo
00ioo`00:7oo00<007ooOol0E7oo0P0047oo000XOol00`00Oomoo`1DOol00`00Oomoo`0?Ool000]o
o`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo05=oo`03001oogoo011o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001D
Ool2000BOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo
001COol2000COol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo0080059oo`03001oogoo019oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomo
o`00Ool010000goo00<007ooOol0D7oo00<007ooOol04goo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`001Woo00<007ooOol0Cgoo00<007ooOol057oo000;Ool2000:Ool2
0004Ool20002Ool50002Ool00`00Oomoo`1>Ool2000FOol002Qoo`03001oogoo04ioo`03001oogoo
01Eoo`00:7oo00<007ooOol0CGoo00<007ooOol05Woo000AOol20004Ool00`00Oomoo`03Ool20003
Ool30003Ool00`00Oomoo`1<Ool00`00Oomoo`0GOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0Bgoo00<007ooOol067oo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo04Yoo`8001Yoo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Oom>000KOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0Agoo0P007Goo000@Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=o
o`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007oo
Ool000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04
001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2
001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P00
2Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@00
0Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo
0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo
011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03
Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol0
0`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001o
ogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2
000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P00
1Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Ao
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009o
o`03001oogoo00Yoo`0077oo00<007ooOol0Hgoo0P003Goo000LOol2001SOol2000>Ool001aoo`03
001oogoo069oo`03001oogoo00eoo`0077oo00<007ooOol0HGoo00<007ooOol03Woo000LOol2001Q
Ool00`00Oomoo`0?Ool001aoo`03001oogoo061oo`03001oogoo00moo`0077oo00<007ooOol0H7oo
00<007ooOol03goo000LOol2001POol00`00Oomoo`0@Ool001aoo`03001oogoo05ioo`80019oo`00
77oo0P00Ggoo00<007ooOol04Goo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1M
Ool2000COol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0GGoo00<007oo
Ool04Woo000:Ool01000Oomoo`002goo00<007ooOol00P00GGoo00<007ooOol04goo000:Ool01000
Oomoo`002goo00@007ooOol005eoo`03001oogoo01Aoo`002Woo00@007ooOol000Moo`@000=oo`03
001oogoo05]oo`03001oogoo01Aoo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8005]oo`03
001oogoo01Eoo`002goo0P0027oo1@000Woo00<007ooOol0FGoo00<007ooOol05Woo000LOol00`00
Oomoo`1IOol00`00Oomoo`0FOol001aoo`8005Uoo`03001oogoo01Moo`0077oo00<007ooOol0Egoo
0P006Goo000LOol2001HOol00`00Oomoo`0HOol001aoo`03001oogoo05Ioo`8001Yoo`0077oo00<0
07ooOol0EGoo0P006goo000LOol2001EOol2000LOol001Ioo`<000=oo`03001oogoo05Aoo`03001o
ogoo01]oo`005goo00<007ooOol00Woo00<007ooOol0;goo8@000goo0P007Goo000GOol00`00Oomo
o`02Oolc000POol3000OOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol00Woo00<0
07ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo
000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;
Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo
00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;
Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(6179\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29978 m
.008 .29915 L
.012 .29984 L
.016 .29994 L
.02 .29955 L
.024 .29959 L
.028 .29981 L
.032 .29975 L
.036 .29962 L
.04 .29965 L
.044 .29971 L
.048 .29968 L
.052 .29963 L
.056 .29964 L
.06 .29967 L
.064 .29965 L
.068 .29962 L
.072 .29962 L
.076 .29964 L
.08 .29963 L
.084 .29959 L
.088 .29958 L
.092 .29962 L
.096 .29961 L
.1 .29957 L
.104 .29955 L
.108 .29958 L
.112 .2996 L
.116 .29956 L
.12 .29951 L
.124 .29954 L
.128 .29958 L
.132 .29956 L
.136 .29949 L
.14 .29949 L
.144 .29955 L
.148 .29957 L
.152 .29949 L
.156 .29943 L
.16 .29949 L
.164 .29957 L
.168 .29951 L
.172 .2994 L
.176 .2994 L
.18 .29953 L
.184 .29955 L
.188 .29942 L
.192 .29933 L
.196 .29942 L
.2 .29955 L
Mistroke
.204 .2995 L
.208 .29932 L
.212 .29929 L
.216 .29945 L
.22 .29956 L
.224 .29943 L
.228 .29923 L
.232 .29927 L
.236 .29949 L
.24 .29955 L
.244 .29935 L
.248 .29915 L
.252 .29926 L
.256 .29951 L
.26 .29954 L
.264 .29928 L
.268 .29909 L
.272 .29922 L
.276 .29951 L
.28 .29953 L
.284 .29925 L
.288 .29903 L
.292 .29916 L
.296 .29947 L
.3 .29955 L
.304 .29927 L
.308 .29899 L
.312 .29905 L
.316 .29938 L
.32 .29957 L
.324 .29937 L
.328 .299 L
.332 .2989 L
.336 .29919 L
.34 .29954 L
.344 .29954 L
.348 .29914 L
.352 .29878 L
.356 .29887 L
.36 .29936 L
.364 .29971 L
.368 .29948 L
.372 .29885 L
.376 .29851 L
.38 .29889 L
.384 .29965 L
.388 .29994 L
.392 .29933 L
.396 .2984 L
.4 .29818 L
Mistroke
.404 .29904 L
.408 .30013 L
.412 .3002 L
.416 .29902 L
.42 .29776 L
.424 .29784 L
.428 .29934 L
.432 .30076 L
.436 .30049 L
.44 .29862 L
.444 .29701 L
.448 .29744 L
.452 .29965 L
.456 .30146 L
.46 .30091 L
.464 .29834 L
.468 .29624 L
.472 .29679 L
.476 .29964 L
.48 .30209 L
.484 .30167 L
.488 .2986 L
.492 .29571 L
.496 .29578 L
.5 .29886 L
.504 .3022 L
.508 .30272 L
.512 .29985 L
.516 .29609 L
.52 .29476 L
.524 .29704 L
.528 .30095 L
.532 .30318 L
.536 .30189 L
.54 .29823 L
.544 .29519 L
.548 .29513 L
.552 .29791 L
.556 .30126 L
.56 .3027 L
.564 .30141 L
.568 .29855 L
.572 .29616 L
.576 .29564 L
.58 .297 L
.584 .29922 L
.588 .30112 L
.592 .30187 L
.596 .30122 L
.6 .29933 L
Mistroke
.604 .29684 L
.608 .29488 L
.612 .29474 L
.616 .29704 L
.62 .30106 L
.624 .30462 L
.628 .30525 L
.632 .30183 L
.636 .29574 L
.64 .29045 L
.644 .2895 L
.648 .29416 L
.652 .30228 L
.656 .30929 L
.66 .31085 L
.664 .30553 L
.668 .29591 L
.672 .28719 L
.676 .28424 L
.68 .28882 L
.684 .29859 L
.688 .30851 L
.692 .31359 L
.696 .31156 L
.7 .30382 L
.704 .29435 L
.708 .28746 L
.712 .28565 L
.716 .28876 L
.72 .29461 L
.724 .30056 L
.728 .30487 L
.732 .30719 L
.736 .30801 L
.74 .30779 L
.744 .30627 L
.748 .30268 L
.752 .29652 L
.756 .28852 L
.76 .2809 L
.764 .27679 L
.768 .27887 L
.772 .28798 L
.776 .30234 L
.78 .31793 L
.784 .32983 L
.788 .33405 L
.792 .329 L
.796 .31603 L
.8 .29886 L
Mistroke
.804 .28208 L
.808 .2696 L
.812 .26336 L
.816 .26308 L
.82 .26681 L
.824 .27208 L
.828 .27712 L
.832 .28159 L
.836 .28664 L
.84 .29425 L
.844 .30632 L
.848 .32364 L
.852 .34546 L
.856 .36951 L
.86 .39266 L
.864 .41183 L
.868 .42488 L
.872 .43124 L
.876 .432 L
.88 .42951 L
.884 .42672 L
.888 .42627 L
.892 .42985 L
.896 .43782 L
.9 .44915 L
.904 .46185 L
.908 .47345 L
.912 .48172 L
.916 .48515 L
.92 .48329 L
.924 .47679 L
.928 .46725 L
.932 .45682 L
.936 .44779 L
.94 .44216 L
.944 .44129 L
.948 .4458 L
.952 .45542 L
.956 .46926 L
.96 .48583 L
.964 .5035 L
.968 .52057 L
.972 .53558 L
.976 .54747 L
.98 .55546 L
.984 .55948 L
.988 .55936 L
.992 .55586 L
.996 .54906 L
1 .54012 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .50998 m
.008 .51641 L
.012 .5186 L
.016 .5164 L
.02 .51571 L
.024 .51641 L
.028 .51668 L
.032 .51641 L
.036 .51635 L
.04 .51641 L
.044 .51646 L
.048 .51641 L
.052 .51642 L
.056 .51641 L
.06 .51643 L
.064 .51642 L
.068 .51642 L
.072 .51642 L
.076 .51643 L
.08 .51642 L
.084 .51642 L
.088 .51642 L
.092 .51642 L
.096 .51642 L
.1 .51642 L
.104 .51642 L
.108 .51642 L
.112 .51642 L
.116 .51642 L
.12 .51642 L
.124 .51642 L
.128 .51642 L
.132 .51642 L
.136 .51642 L
.14 .51642 L
.144 .51642 L
.148 .51642 L
.152 .51642 L
.156 .51642 L
.16 .51642 L
.164 .51642 L
.168 .51642 L
.172 .51642 L
.176 .51642 L
.18 .51642 L
.184 .51642 L
.188 .51642 L
.192 .51642 L
.196 .51642 L
.2 .51642 L
Mistroke
.204 .51642 L
.208 .51641 L
.212 .51642 L
.216 .51642 L
.22 .51642 L
.224 .51641 L
.228 .51642 L
.232 .51642 L
.236 .51642 L
.24 .51641 L
.244 .51641 L
.248 .51641 L
.252 .51642 L
.256 .51642 L
.26 .51641 L
.264 .51641 L
.268 .51641 L
.272 .51642 L
.276 .51642 L
.28 .51641 L
.284 .51641 L
.288 .51641 L
.292 .51642 L
.296 .51642 L
.3 .51641 L
.304 .5164 L
.308 .51641 L
.312 .51642 L
.316 .51642 L
.32 .51641 L
.324 .5164 L
.328 .5164 L
.332 .51642 L
.336 .51642 L
.34 .51642 L
.344 .5164 L
.348 .5164 L
.352 .51641 L
.356 .51642 L
.36 .51642 L
.364 .51641 L
.368 .51639 L
.372 .51639 L
.376 .51641 L
.38 .51643 L
.384 .51642 L
.388 .5164 L
.392 .51638 L
.396 .51639 L
.4 .51643 L
Mistroke
.404 .51644 L
.408 .51642 L
.412 .51638 L
.416 .51637 L
.42 .51639 L
.424 .51644 L
.428 .51645 L
.432 .51641 L
.436 .51636 L
.44 .51635 L
.444 .51639 L
.448 .51646 L
.452 .51647 L
.456 .51641 L
.46 .51634 L
.464 .51632 L
.468 .51639 L
.472 .51647 L
.476 .5165 L
.48 .51643 L
.484 .51633 L
.488 .51629 L
.492 .51636 L
.496 .51647 L
.5 .51652 L
.504 .51647 L
.508 .51635 L
.512 .51627 L
.516 .5163 L
.52 .51642 L
.524 .51652 L
.528 .51653 L
.532 .51642 L
.536 .51629 L
.54 .51625 L
.544 .51632 L
.548 .51645 L
.552 .51654 L
.556 .51652 L
.56 .51642 L
.564 .5163 L
.568 .51624 L
.572 .51629 L
.576 .5164 L
.58 .5165 L
.584 .51654 L
.588 .51649 L
.592 .51638 L
.596 .51627 L
.6 .51622 L
Mistroke
.604 .51626 L
.608 .51638 L
.612 .51653 L
.616 .51662 L
.62 .51659 L
.624 .51643 L
.628 .51621 L
.632 .51607 L
.636 .51609 L
.64 .51629 L
.644 .51659 L
.648 .51681 L
.652 .51681 L
.656 .51656 L
.66 .51618 L
.664 .51588 L
.668 .51582 L
.672 .51606 L
.676 .51649 L
.68 .51689 L
.684 .51706 L
.688 .5169 L
.692 .5165 L
.696 .51603 L
.7 .51572 L
.704 .51568 L
.708 .51593 L
.712 .51633 L
.716 .51673 L
.72 .517 L
.724 .51706 L
.728 .51693 L
.732 .51666 L
.736 .51632 L
.74 .51596 L
.744 .51565 L
.748 .51546 L
.752 .51547 L
.756 .51573 L
.76 .51623 L
.764 .51691 L
.768 .51758 L
.772 .51804 L
.776 .51811 L
.78 .51769 L
.784 .51684 L
.788 .51575 L
.792 .51467 L
.796 .51389 L
.8 .51359 L
Mistroke
.804 .51384 L
.808 .51457 L
.812 .51562 L
.816 .51681 L
.82 .51798 L
.824 .51901 L
.828 .51987 L
.832 .52055 L
.836 .52103 L
.84 .52124 L
.844 .52108 L
.848 .52041 L
.852 .5191 L
.856 .51705 L
.86 .51426 L
.864 .51081 L
.868 .50686 L
.872 .5026 L
.876 .49822 L
.88 .49384 L
.884 .48953 L
.888 .48527 L
.892 .48096 L
.896 .4765 L
.9 .47177 L
.904 .46672 L
.908 .46135 L
.912 .45572 L
.916 .44996 L
.92 .4442 L
.924 .43859 L
.928 .43323 L
.932 .42819 L
.936 .42345 L
.94 .41894 L
.944 .41454 L
.948 .41012 L
.952 .40551 L
.956 .4006 L
.96 .39527 L
.964 .38949 L
.968 .38323 L
.972 .37656 L
.976 .36952 L
.98 .36224 L
.984 .35481 L
.988 .34736 L
.992 .34 L
.996 .3328 L
1 .32586 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43027 L
.012 .43007 L
.016 .42981 L
.02 .42962 L
.024 .42974 L
.028 .42975 L
.032 .42968 L
.036 .42956 L
.04 .42957 L
.044 .42952 L
.048 .42949 L
.052 .42942 L
.056 .42939 L
.06 .42934 L
.064 .42931 L
.068 .42925 L
.072 .42922 L
.076 .42916 L
.08 .42913 L
.084 .42907 L
.088 .42904 L
.092 .42899 L
.096 .42895 L
.1 .4289 L
.104 .42886 L
.108 .42881 L
.112 .42877 L
.116 .42872 L
.12 .42868 L
.124 .42864 L
.128 .42859 L
.132 .42854 L
.136 .4285 L
.14 .42846 L
.144 .42842 L
.148 .42837 L
.152 .42833 L
.156 .42828 L
.16 .42824 L
.164 .42819 L
.168 .42815 L
.172 .4281 L
.176 .42807 L
.18 .42802 L
.184 .42797 L
.188 .42793 L
.192 .42789 L
.196 .42785 L
.2 .4278 L
Mistroke
.204 .42775 L
.208 .42771 L
.212 .42767 L
.216 .42763 L
.22 .42758 L
.224 .42753 L
.228 .42749 L
.232 .42745 L
.236 .42741 L
.24 .42735 L
.244 .42731 L
.248 .42727 L
.252 .42723 L
.256 .42719 L
.26 .42713 L
.264 .42708 L
.268 .42705 L
.272 .42701 L
.276 .42697 L
.28 .42691 L
.284 .42686 L
.288 .42682 L
.292 .42679 L
.296 .42675 L
.3 .42669 L
.304 .42664 L
.308 .4266 L
.312 .42657 L
.316 .42653 L
.32 .42647 L
.324 .42642 L
.328 .42638 L
.332 .42635 L
.336 .42631 L
.34 .42626 L
.344 .4262 L
.348 .42615 L
.352 .42612 L
.356 .42609 L
.36 .42605 L
.364 .42599 L
.368 .42592 L
.372 .42588 L
.376 .42586 L
.38 .42584 L
.384 .42579 L
.388 .42571 L
.392 .42564 L
.396 .42562 L
.4 .42561 L
Mistroke
.404 .42559 L
.408 .42552 L
.412 .42543 L
.416 .42536 L
.42 .42536 L
.424 .42537 L
.428 .42534 L
.432 .42525 L
.436 .42514 L
.44 .42508 L
.444 .42509 L
.448 .42513 L
.452 .4251 L
.456 .42499 L
.46 .42485 L
.464 .42479 L
.468 .42482 L
.472 .42488 L
.476 .42487 L
.48 .42474 L
.484 .42458 L
.488 .42448 L
.492 .42452 L
.496 .42462 L
.5 .42464 L
.504 .42453 L
.508 .42434 L
.512 .42419 L
.516 .42419 L
.52 .42429 L
.524 .42438 L
.528 .42434 L
.532 .42416 L
.536 .42396 L
.54 .42386 L
.544 .42391 L
.548 .42402 L
.552 .42409 L
.556 .42403 L
.56 .42385 L
.564 .42366 L
.568 .42355 L
.572 .42357 L
.576 .42366 L
.58 .42375 L
.584 .42375 L
.588 .42364 L
.592 .42346 L
.596 .42328 L
.6 .42317 L
Mistroke
.604 .42317 L
.608 .42328 L
.612 .42342 L
.616 .4235 L
.62 .42342 L
.624 .42317 L
.628 .42286 L
.632 .42263 L
.636 .42262 L
.64 .42283 L
.644 .42316 L
.648 .42338 L
.652 .42334 L
.656 .42298 L
.66 .42247 L
.664 .42205 L
.668 .42193 L
.672 .42219 L
.676 .42268 L
.68 .42314 L
.684 .4233 L
.688 .42306 L
.692 .42251 L
.696 .42189 L
.7 .42146 L
.704 .42137 L
.708 .42163 L
.712 .42209 L
.716 .42255 L
.72 .42284 L
.724 .42287 L
.728 .42267 L
.732 .42229 L
.736 .42182 L
.74 .42133 L
.744 .4209 L
.748 .42062 L
.752 .42059 L
.756 .42086 L
.76 .42145 L
.764 .42225 L
.768 .42304 L
.772 .42358 L
.776 .42361 L
.78 .42305 L
.784 .42195 L
.788 .42054 L
.792 .41915 L
.796 .41814 L
.8 .41772 L
Mistroke
.804 .41799 L
.808 .41886 L
.812 .42013 L
.816 .42157 L
.82 .42297 L
.824 .42422 L
.828 .42525 L
.832 .42605 L
.836 .4266 L
.84 .42682 L
.844 .42658 L
.848 .4257 L
.852 .42401 L
.856 .42142 L
.86 .4179 L
.864 .41356 L
.868 .40859 L
.872 .40324 L
.876 .39774 L
.88 .39225 L
.884 .38684 L
.888 .38149 L
.892 .37609 L
.896 .37049 L
.9 .36457 L
.904 .35825 L
.908 .35153 L
.912 .3445 L
.916 .3373 L
.92 .33013 L
.924 .32315 L
.928 .31651 L
.932 .31028 L
.936 .30446 L
.94 .29897 L
.944 .29369 L
.948 .28844 L
.952 .28306 L
.956 .27743 L
.96 .27144 L
.964 .26508 L
.968 .25837 L
.972 .25141 L
.976 .24434 L
.98 .23735 L
.984 .23061 L
.988 .22432 L
.992 .21863 L
.996 .21367 L
1 .20957 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00<007ooOol00P0000Eoo`00Oomoo`0000=oo`07001oogooOol007oo00001Woo00@0
07ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@0
07ooOomoo`D000=oo`8000Aoo`<0009oo`03001oo`0000@00003Ool0000000Eoo`<0009oo`D000=o
o`8000Ioo`008Woo00<007ooOol0?goo00<007ooOol00P000goo0P000Woo00<007ooOol00P0077oo
000ROol2000SOol01P00Ool007oo001oo`@00003Ool007oo00800003Ool0000000<00004Ool00000
Ool200001Goo00000000Ool00P000Woo0`000Woo00D007ooOomoo`0001aoo`008WooH`0037oo000R
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`00009oo`09001oo`00Ool007oo001oo`0000=oo`05001oo`00Ool00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`03001oogoo00Yoo`008Woo0P00BWoo0P001Goo00<007ooOol06Goo
000ROol00`00Oomoo`1:Ool00`00Oomoo`03Ool00`00Oomoo`0IOol0029oo`80055oo`03001oogoo
01Uoo`008Woo0P00DGoo00<007ooOol06Goo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003
Ool00`00Oomoo`1AOol00`00Oomoo`0HOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P00DWoo00<007ooOol067oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`80059oo`03001oogoo01Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1AOol00`00Oomoo`0HOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P00DWoo00<007ooOol067oo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000Aoo`80059oo`03001oogoo01Qoo`002goo0P002Woo0P0017oo00<007ooOol00Woo
00<007ooOol0DWoo0`005goo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001EOol0
0`00Oomoo`02Ool00`00Oomoo`0@Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool0009oo`8005Ioo`03001oogoo0080019oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1EOol01P00Oomoo`00Ool0015oo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01000Oomoogoo0P00EWoo00H007ooOol007oo000AOol000Yoo`04001oogoo0008
Ool01P00Oomoo`00Ool000=oo`03001oogoo008005Moo`80009oo`03001oogoo00moo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol005Qoo`03001oogoo009oo`03001oogoo
00ioo`002goo0P002Woo0P000goo0`000goo0P00G7oo00<007ooOol03Woo000ROol00`00Oomoo`1K
Ool00`00Oomoo`0>Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8005aoo`03001o
ogoo00ioo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00G7oo00<0
07ooOol03Woo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001NOol01000Oomo
o`0037oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8005eoo`03001oo`0000eo
o`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001NOol2000=Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<0
00=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomo
ogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomo
o`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00
Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003
Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04
001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool3
0004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol0
0002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00
Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Ao
o`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04
001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<0
00=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool2
0004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001o
o`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@0
07ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P00
17oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol0
3goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol0
2Woo000XOol00`00Oomoo`1HOol2000<Ool002Qoo`03001oogoo05Qoo`03001oogoo00]oo`00:7oo
00<007ooOol0Egoo00<007ooOol037oo000XOol00`00Oomoo`1GOol00`00Oomoo`0<Ool002Qoo`03
001oogoo05Ioo`03001oogoo00eoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`00
0goo00<007ooOol0EGoo0P003goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`000goo00@007ooOol005Moo`03001oogoo00ioo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOol005Ioo`03001oogoo00moo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00E7oo00<007ooOol047oo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1BOol2000B
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1A
Ool2000COol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo055oo`03001oogoo019o
o`00:7oo00<007ooOol0D7oo0P0057oo000XOol00`00Oomoo`1?Ool2000EOol0015oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`03001oogoo04ioo`8001Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1=Ool2000GOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0C7oo0P0067oo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009ooe0001Uoo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1:Ool00`00Oomoo`0IOol0011oo`04001oogoo0008Ool01000
Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002
Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Ao
o`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool3
0004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool2
0005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`00
2Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@0
07ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eo
o`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo
00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03
001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005
Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1UOol00`00Oomoo`0:Ool001aoo`8006Eoo`03001oogoo00]oo`00
77oo00<007ooOol0Hgoo00<007ooOol037oo000LOol00`00Oomoo`1ROol00`00Oomoo`0=Ool001ao
o`8006=oo`03001oogoo00eoo`0077oo00<007ooOol0HGoo0P003goo000LOol2001ROol00`00Oomo
o`0>Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo061oo`03001oogoo00moo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1OOol2000AOol000Yoo`04001o
ogoo000;Ool00`00Oomoo`02001POol00`00Oomoo`0@Ool000Yoo`04001oogoo000;Ool01000Oomo
o`00H7oo00<007ooOol04Goo000:Ool01000Oomoo`001goo10000goo00<007ooOol0GGoo0P004goo
000:Ool01000Oomoo`001goo00<007ooOol017oo0P00GWoo00<007ooOol04Woo000;Ool20008Ool5
0002Ool00`00Oomoo`1LOol00`00Oomoo`0COol001aoo`03001oogoo05]oo`03001oogoo01Aoo`00
77oo0P00G7oo00<007ooOol057oo000LOol00`00Oomoo`1JOol2000FOol001aoo`8005Yoo`8001Mo
o`0077oo00<007ooOol0FGoo00<007ooOol05Woo000LOol00`00Oomoo`1HOol2000HOol001aoo`80
05Qoo`8001Uoo`005Woo0`000goo00<007ooOol0Egoo00<007ooOol067oo000GOol00`00Oomoo`02
Ool00`00Oomoo`0_OolT0002Ool2000KOol001Moo`03001oogoo009ooc<002=oo`<001aoo`005goo
00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`80
00Aoo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol0
00]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007oo
Ool0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0
009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(6346\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29749 m
.008 .29895 L
.012 .3005 L
.016 .3007 L
.02 .2995 L
.024 .29919 L
.028 .29981 L
.032 .29999 L
.036 .29969 L
.04 .29959 L
.044 .29972 L
.048 .29975 L
.052 .29969 L
.056 .29966 L
.06 .29969 L
.064 .29969 L
.068 .29966 L
.072 .29965 L
.076 .29967 L
.08 .29967 L
.084 .29964 L
.088 .29962 L
.092 .29964 L
.096 .29965 L
.1 .29962 L
.104 .29959 L
.108 .29961 L
.112 .29963 L
.116 .29961 L
.12 .29956 L
.124 .29956 L
.128 .29961 L
.132 .2996 L
.136 .29954 L
.14 .29952 L
.144 .29957 L
.148 .2996 L
.152 .29955 L
.156 .29947 L
.16 .2995 L
.164 .29959 L
.168 .29957 L
.172 .29946 L
.176 .29943 L
.18 .29953 L
.184 .29958 L
.188 .29949 L
.192 .29938 L
.196 .29943 L
.2 .29956 L
Mistroke
.204 .29955 L
.208 .2994 L
.212 .29933 L
.216 .29945 L
.22 .29958 L
.224 .29949 L
.228 .29931 L
.232 .29929 L
.236 .29948 L
.24 .29958 L
.244 .29942 L
.248 .29922 L
.252 .29927 L
.256 .2995 L
.26 .29957 L
.264 .29936 L
.268 .29916 L
.272 .29925 L
.276 .29951 L
.28 .29956 L
.284 .29931 L
.288 .2991 L
.292 .2992 L
.296 .29948 L
.3 .29956 L
.304 .29931 L
.308 .29905 L
.312 .29911 L
.316 .29942 L
.32 .29957 L
.324 .29937 L
.328 .29904 L
.332 .29899 L
.336 .29928 L
.34 .29956 L
.344 .29949 L
.348 .29912 L
.352 .29887 L
.356 .29903 L
.36 .29945 L
.364 .29964 L
.368 .29936 L
.372 .29886 L
.376 .29871 L
.38 .29912 L
.384 .29969 L
.388 .29974 L
.392 .29914 L
.396 .29849 L
.4 .29855 L
Mistroke
.404 .29935 L
.408 .30005 L
.412 .2998 L
.416 .29874 L
.42 .29798 L
.424 .29845 L
.428 .29976 L
.432 .30053 L
.436 .29979 L
.44 .29818 L
.444 .29739 L
.448 .2984 L
.452 .3003 L
.456 .3011 L
.46 .29979 L
.464 .29756 L
.468 .2967 L
.472 .29825 L
.476 .30079 L
.48 .30177 L
.484 .30004 L
.488 .29714 L
.492 .2959 L
.496 .29768 L
.5 .3009 L
.504 .3025 L
.508 .30084 L
.512 .29733 L
.516 .2952 L
.52 .29649 L
.524 .3001 L
.528 .30282 L
.532 .30219 L
.536 .29871 L
.54 .29539 L
.544 .29507 L
.548 .29799 L
.552 .30167 L
.556 .30308 L
.56 .30117 L
.564 .29759 L
.568 .29516 L
.572 .29561 L
.576 .29839 L
.58 .30131 L
.584 .30237 L
.588 .30111 L
.592 .29861 L
.596 .2965 L
.6 .29586 L
Mistroke
.604 .29681 L
.608 .29873 L
.612 .30075 L
.616 .30203 L
.62 .30187 L
.624 .30001 L
.628 .29702 L
.632 .29435 L
.636 .29381 L
.64 .29634 L
.644 .30105 L
.648 .30535 L
.652 .30628 L
.656 .30257 L
.66 .2958 L
.664 .2898 L
.668 .28848 L
.672 .29326 L
.676 .30189 L
.68 .30957 L
.684 .31169 L
.688 .30664 L
.692 .29688 L
.696 .28762 L
.7 .28387 L
.704 .28768 L
.708 .29702 L
.712 .3071 L
.716 .31298 L
.72 .31212 L
.724 .30548 L
.728 .29655 L
.732 .28939 L
.736 .28655 L
.74 .28821 L
.744 .29272 L
.748 .29789 L
.752 .30223 L
.756 .30538 L
.76 .30762 L
.764 .30902 L
.768 .30895 L
.772 .30626 L
.776 .3002 L
.78 .29134 L
.784 .28197 L
.788 .27551 L
.792 .27519 L
.796 .2825 L
.8 .29627 L
Mistroke
.804 .3128 L
.808 .32706 L
.812 .33455 L
.816 .33286 L
.82 .3225 L
.824 .30657 L
.828 .28948 L
.832 .27537 L
.836 .26676 L
.84 .26399 L
.844 .26557 L
.848 .26921 L
.852 .27302 L
.856 .27635 L
.86 .28004 L
.864 .28601 L
.868 .29628 L
.872 .31205 L
.876 .33307 L
.88 .35747 L
.884 .38226 L
.888 .40418 L
.892 .42063 L
.896 .4304 L
.9 .43395 L
.904 .43325 L
.908 .43111 L
.912 .43042 L
.916 .4334 L
.92 .44102 L
.924 .4529 L
.928 .46747 L
.932 .48248 L
.936 .49559 L
.94 .50497 L
.944 .50968 L
.948 .50988 L
.952 .50676 L
.956 .50211 L
.96 .49822 L
.964 .4969 L
.968 .49989 L
.972 .50757 L
.976 .52012 L
.98 .53617 L
.984 .55447 L
.988 .57275 L
.992 .58913 L
.996 .60188 L
1 .60929 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51502 m
.008 .51603 L
.012 .51651 L
.016 .51633 L
.02 .51614 L
.024 .5161 L
.028 .51622 L
.032 .51622 L
.036 .5162 L
.04 .51617 L
.044 .5162 L
.048 .51619 L
.052 .5162 L
.056 .51618 L
.06 .5162 L
.064 .51619 L
.068 .5162 L
.072 .51619 L
.076 .5162 L
.08 .51619 L
.084 .5162 L
.088 .51619 L
.092 .5162 L
.096 .51619 L
.1 .51619 L
.104 .51619 L
.108 .51619 L
.112 .51619 L
.116 .51619 L
.12 .51619 L
.124 .51619 L
.128 .51619 L
.132 .51619 L
.136 .51619 L
.14 .51619 L
.144 .51619 L
.148 .51619 L
.152 .51619 L
.156 .51619 L
.16 .51619 L
.164 .51619 L
.168 .51619 L
.172 .51619 L
.176 .51619 L
.18 .51619 L
.184 .51619 L
.188 .51619 L
.192 .51619 L
.196 .51619 L
.2 .51619 L
Mistroke
.204 .51619 L
.208 .51619 L
.212 .51619 L
.216 .51619 L
.22 .51619 L
.224 .51618 L
.228 .51619 L
.232 .51619 L
.236 .51619 L
.24 .51619 L
.244 .51618 L
.248 .51619 L
.252 .51619 L
.256 .51619 L
.26 .51619 L
.264 .51618 L
.268 .51618 L
.272 .51619 L
.276 .51619 L
.28 .51618 L
.284 .51618 L
.288 .51618 L
.292 .51619 L
.296 .51619 L
.3 .51618 L
.304 .51618 L
.308 .51618 L
.312 .51619 L
.316 .51619 L
.32 .51618 L
.324 .51617 L
.328 .51618 L
.332 .51619 L
.336 .51619 L
.34 .51619 L
.344 .51617 L
.348 .51617 L
.352 .51618 L
.356 .51619 L
.36 .51619 L
.364 .51618 L
.368 .51617 L
.372 .51617 L
.376 .51619 L
.38 .5162 L
.384 .51619 L
.388 .51617 L
.392 .51616 L
.396 .51617 L
.4 .5162 L
Mistroke
.404 .5162 L
.408 .51618 L
.412 .51615 L
.416 .51615 L
.42 .51618 L
.424 .51621 L
.428 .51621 L
.432 .51617 L
.436 .51613 L
.44 .51614 L
.444 .51619 L
.448 .51623 L
.452 .51621 L
.456 .51616 L
.46 .51611 L
.464 .51613 L
.468 .5162 L
.472 .51625 L
.476 .51623 L
.48 .51615 L
.484 .51609 L
.488 .51611 L
.492 .51619 L
.496 .51626 L
.5 .51625 L
.504 .51616 L
.508 .51607 L
.512 .51607 L
.516 .51616 L
.52 .51626 L
.524 .51629 L
.528 .5162 L
.532 .51609 L
.536 .51604 L
.54 .51609 L
.544 .51622 L
.548 .5163 L
.552 .51628 L
.556 .51616 L
.56 .51605 L
.564 .51603 L
.568 .51611 L
.572 .51623 L
.576 .5163 L
.58 .51628 L
.584 .51618 L
.588 .51607 L
.592 .51602 L
.596 .51606 L
.6 .51616 L
Mistroke
.604 .51626 L
.608 .51631 L
.612 .51627 L
.616 .51617 L
.62 .51605 L
.624 .51598 L
.628 .516 L
.632 .51613 L
.636 .51629 L
.64 .5164 L
.644 .51639 L
.648 .51622 L
.652 .51599 L
.656 .51582 L
.66 .51582 L
.664 .51603 L
.668 .51634 L
.672 .51658 L
.676 .5166 L
.68 .51637 L
.684 .51599 L
.688 .51566 L
.692 .51557 L
.696 .51578 L
.7 .51619 L
.704 .5166 L
.708 .51681 L
.712 .51671 L
.716 .51635 L
.72 .51591 L
.724 .51557 L
.728 .51547 L
.732 .51563 L
.736 .51597 L
.74 .51635 L
.744 .51665 L
.748 .51679 L
.752 .51676 L
.756 .51658 L
.76 .51628 L
.764 .51591 L
.768 .51555 L
.772 .51526 L
.776 .51514 L
.78 .51529 L
.784 .51572 L
.788 .51638 L
.792 .51712 L
.796 .51771 L
.8 .51797 L
Mistroke
.804 .51774 L
.808 .51704 L
.812 .51601 L
.816 .5149 L
.82 .51398 L
.824 .51346 L
.828 .51346 L
.832 .51395 L
.836 .51481 L
.84 .51589 L
.844 .51701 L
.848 .51808 L
.852 .51904 L
.856 .51986 L
.86 .52054 L
.864 .521 L
.868 .52115 L
.872 .52086 L
.876 .51996 L
.88 .51836 L
.884 .516 L
.888 .51293 L
.892 .50928 L
.896 .50523 L
.9 .50096 L
.904 .49663 L
.908 .49232 L
.912 .48804 L
.916 .48373 L
.92 .47928 L
.924 .47457 L
.928 .4695 L
.932 .46404 L
.936 .45821 L
.94 .45211 L
.944 .44582 L
.948 .4395 L
.952 .43324 L
.956 .42711 L
.96 .42112 L
.964 .41522 L
.968 .40932 L
.972 .40327 L
.976 .39697 L
.98 .39027 L
.984 .38314 L
.988 .37549 L
.992 .36742 L
.996 .35892 L
1 .35021 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42534 L
.012 .42988 L
.016 .4314 L
.02 .42975 L
.024 .42923 L
.028 .42968 L
.032 .42984 L
.036 .42959 L
.04 .42951 L
.044 .42951 L
.048 .42951 L
.052 .42942 L
.056 .42939 L
.06 .42933 L
.064 .42931 L
.068 .42925 L
.072 .42922 L
.076 .42916 L
.08 .42913 L
.084 .42907 L
.088 .42904 L
.092 .42899 L
.096 .42895 L
.1 .4289 L
.104 .42886 L
.108 .42881 L
.112 .42877 L
.116 .42872 L
.12 .42868 L
.124 .42864 L
.128 .4286 L
.132 .42855 L
.136 .42851 L
.14 .42846 L
.144 .42842 L
.148 .42837 L
.152 .42833 L
.156 .42828 L
.16 .42824 L
.164 .4282 L
.168 .42815 L
.172 .42811 L
.176 .42807 L
.18 .42802 L
.184 .42798 L
.188 .42793 L
.192 .42789 L
.196 .42785 L
.2 .4278 L
Mistroke
.204 .42775 L
.208 .42771 L
.212 .42767 L
.216 .42763 L
.22 .42758 L
.224 .42753 L
.228 .42749 L
.232 .42745 L
.236 .42741 L
.24 .42736 L
.244 .42731 L
.248 .42727 L
.252 .42723 L
.256 .42719 L
.26 .42714 L
.264 .42709 L
.268 .42705 L
.272 .42701 L
.276 .42697 L
.28 .42691 L
.284 .42686 L
.288 .42683 L
.292 .42679 L
.296 .42675 L
.3 .42669 L
.304 .42664 L
.308 .4266 L
.312 .42657 L
.316 .42653 L
.32 .42648 L
.324 .42642 L
.328 .42638 L
.332 .42635 L
.336 .42631 L
.34 .42626 L
.344 .4262 L
.348 .42615 L
.352 .42612 L
.356 .42609 L
.36 .42605 L
.364 .42599 L
.368 .42593 L
.372 .42589 L
.376 .42587 L
.38 .42584 L
.384 .42578 L
.388 .42571 L
.392 .42566 L
.396 .42563 L
.4 .42562 L
Mistroke
.404 .42558 L
.408 .42551 L
.412 .42543 L
.416 .42538 L
.42 .42538 L
.424 .42537 L
.428 .42532 L
.432 .42523 L
.436 .42514 L
.44 .42511 L
.444 .42513 L
.448 .42513 L
.452 .42507 L
.456 .42495 L
.46 .42485 L
.464 .42483 L
.468 .42487 L
.472 .42489 L
.476 .42482 L
.48 .42468 L
.484 .42456 L
.488 .42454 L
.492 .4246 L
.496 .42465 L
.5 .42459 L
.504 .42443 L
.508 .42428 L
.512 .42424 L
.516 .4243 L
.52 .42439 L
.524 .42437 L
.528 .42423 L
.532 .42404 L
.536 .42393 L
.54 .42396 L
.544 .42407 L
.548 .42413 L
.552 .42405 L
.556 .42387 L
.56 .42369 L
.564 .42361 L
.568 .42367 L
.572 .42378 L
.576 .42382 L
.58 .42375 L
.584 .42358 L
.588 .4234 L
.592 .4233 L
.596 .42331 L
.6 .42339 L
Mistroke
.604 .42347 L
.608 .42348 L
.612 .42339 L
.616 .42322 L
.62 .42303 L
.624 .4229 L
.628 .42289 L
.632 .423 L
.636 .42316 L
.64 .42326 L
.644 .42319 L
.648 .42294 L
.652 .42261 L
.656 .42235 L
.66 .42232 L
.664 .42253 L
.668 .42288 L
.672 .42313 L
.676 .42311 L
.68 .42278 L
.684 .42226 L
.688 .42181 L
.692 .42165 L
.696 .42187 L
.7 .42234 L
.704 .42281 L
.708 .42302 L
.712 .42285 L
.716 .42236 L
.72 .42176 L
.724 .4213 L
.728 .42113 L
.732 .42129 L
.736 .42167 L
.74 .42211 L
.744 .42244 L
.748 .42257 L
.752 .42248 L
.756 .42221 L
.76 .42179 L
.764 .4213 L
.768 .4208 L
.772 .42039 L
.776 .42021 L
.78 .42034 L
.784 .42084 L
.788 .42162 L
.792 .42249 L
.796 .4232 L
.8 .42346 L
Mistroke
.804 .42314 L
.808 .42222 L
.812 .4209 L
.816 .41947 L
.82 .41828 L
.824 .41759 L
.828 .41754 L
.832 .41811 L
.836 .41915 L
.84 .42044 L
.844 .42181 L
.848 .42309 L
.852 .42424 L
.856 .42523 L
.86 .42602 L
.864 .42655 L
.868 .4267 L
.872 .42629 L
.876 .42514 L
.88 .4231 L
.884 .42013 L
.888 .41628 L
.892 .41171 L
.896 .40666 L
.9 .40135 L
.904 .39599 L
.908 .39069 L
.912 .38547 L
.916 .38026 L
.92 .37495 L
.924 .3694 L
.928 .36353 L
.932 .35732 L
.936 .35084 L
.94 .34423 L
.944 .33767 L
.948 .33138 L
.952 .32554 L
.956 .32027 L
.96 .31563 L
.964 .31158 L
.968 .30805 L
.972 .30486 L
.976 .30187 L
.98 .29883 L
.984 .29566 L
.988 .29214 L
.992 .28831 L
.996 .28403 L
1 .27943 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20002Ool01000Ool000001Goo0`000Woo1@000goo0P001Woo
000ROol00`00Oomoo`0nOol00`00Oomoo`020002Ool00`00Oomoo`02Ool20002Ool01000Oomoo`00
6Woo000ROol2000SOol01P00Ool007oo001oo`@00003Ool007oo00L00004Ool00000Ool200001Goo
00000000Ool00P0000Aoo`00Ool0009oo`03001oo`00009oo`05001oogooOol0000IOol0029oof<0
00aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@0
07ooOol000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00002Ool01000Oomoogoo0P000Woo00D007ooOomoo`0000=oo`05001oo`00Ool00002
Ool20003Ool01@00Oomoogoo00000goo00<007ooOol02Woo000ROol2001=Ool20004Ool00`00Oomo
o`0GOol0029oo`03001oogoo04aoo`8000Aoo`03001oogoo01Moo`008Woo0P00Dgoo00<007ooOol0
5goo000ROol2001DOol00`00Oomoo`0FOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`03001oogoo05=oo`03001oogoo01Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2001DOol00`00Oomoo`0FOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P00E7oo00<007ooOol05Woo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo05=oo`03001oogoo01Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool2001EOol00`00Oomoo`0EOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo0P0017oo0P00EGoo00<007ooOol05Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool0
0`00Oomoo`1DOol00`00Ool0000EOol000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`80
05Ioo`<001Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00F7oo
00<007ooOol04Woo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo05Moo`03001oogoo019oo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo
0P00FGoo00<007ooOol04Goo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomo
o`02001IOol00`00Oomoo`0AOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001o
ogoo001JOol00`00Oomoo`0AOol000]oo`8000Yoo`8000=oo`<000=oo`8005Uoo`04001oo`00000@
Ool0029oo`03001oogoo05Uoo`800003Ool007oo00ioo`002goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo0P00GGoo00<007ooOol03Goo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001MOol00`00Oomoo`0=Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo
00@007ooOol005moo`03001oogoo00aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003
Ool2001NOol00`00Oomoo`0<Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol0
0P00GWoo00<007ooOol037oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomo
o`00Ggoo00<007ooOol037oo000;Ool2000:Ool20003Ool30003Ool2001NOol00`00Oomoo`0<Ool0
029oo`8005moo`03001oogoo00]oo`008Woo00<007ooOol0GWoo00<007ooOol02goo000ROol2001P
Ool00`00Oomoo`0:Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004
Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007oo
Ool00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P00
17oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo
0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo
0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003
Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@0
07ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo
000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`00
0Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomo
o`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool0
0`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003
Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`80
00Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004
Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo
00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo05Uoo`03001oogoo00Yoo`00:7oo00<007ooOol0F7oo00<007ooOol02goo
000XOol00`00Oomoo`1GOol00`00Oomoo`0<Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`80
00=oo`<000=oo`03001oogoo05Moo`03001oogoo00aoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001HOol2000>Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001HOol00`00Oomoo`0=Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008005Ioo`03001oogoo00io
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0
E7oo0P0047oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<0
07ooOol0E7oo00<007ooOol03goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1C
Ool00`00Oomoo`0@Ool002Qoo`03001oogoo059oo`80019oo`00:7oo00<007ooOol0DWoo00<007oo
Ool04Goo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1AOol00`00Oomo
o`0BOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0D7oo
00<007ooOol04goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo04moo`03001oogoo01Aoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
OomB000GOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P00
2Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3
0003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`00
00=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo
00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03
001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P00
17oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo
00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo
00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001o
ogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo
0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool0
1@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo
0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool0
1000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007oo
Oomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000
Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool0
1000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007oo
Oomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03
Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo
1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000L
Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1UOol00`00Oomo
o`0:Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0I7oo00<007ooOol0
2goo000:Ool01000Oomoo`002goo00<007ooOol00P00Hgoo0P003Woo000:Ool01000Oomoo`002goo
00@007ooOol006=oo`8000moo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo061oo`80011o
o`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80065oo`03001oogoo00moo`002goo0P0027oo
1@000Woo00<007ooOol0Ggoo00<007ooOol047oo000LOol00`00Oomoo`1NOol2000BOol001aoo`80
05moo`03001oogoo015oo`0077oo00<007ooOol0GGoo0P004goo000LOol2001MOol2000DOol001ao
o`03001oogoo05]oo`8001Eoo`0077oo00<007ooOol0Fgoo00<007ooOol057oo000LOol2001KOol2
000FOol001Ioo`<000=oo`03001oogoo05Uoo`8001Moo`005goo00<007ooOol00Woo00<007ooOol0
;goo9`000Woo0P0067oo000GOol00`00Oomoo`02Oolb000WOol3000IOol001Moo`03001oogoo009o
o`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000FOol20004Ool2001cOol0
01Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00
2Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo
00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomo
o`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo
0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(6513\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29933 m
.008 .30022 L
.012 .29981 L
.016 .29974 L
.02 .29988 L
.024 .29978 L
.028 .29968 L
.032 .29976 L
.036 .29981 L
.04 .29975 L
.044 .29972 L
.048 .29974 L
.052 .29974 L
.056 .29972 L
.06 .29972 L
.064 .29972 L
.068 .2997 L
.072 .29969 L
.076 .2997 L
.08 .2997 L
.084 .29968 L
.088 .29966 L
.092 .29967 L
.096 .29968 L
.1 .29966 L
.104 .29963 L
.108 .29963 L
.112 .29966 L
.116 .29965 L
.12 .29961 L
.124 .29959 L
.128 .29963 L
.132 .29964 L
.136 .2996 L
.14 .29955 L
.144 .29958 L
.148 .29963 L
.152 .2996 L
.156 .29953 L
.16 .29953 L
.164 .2996 L
.168 .29961 L
.172 .29952 L
.176 .29947 L
.18 .29954 L
.184 .29961 L
.188 .29955 L
.192 .29944 L
.196 .29945 L
.2 .29956 L
Mistroke
.204 .29959 L
.208 .29947 L
.212 .29937 L
.216 .29945 L
.22 .29958 L
.224 .29955 L
.228 .29938 L
.232 .29933 L
.236 .29948 L
.24 .29959 L
.244 .29949 L
.248 .2993 L
.252 .2993 L
.256 .29949 L
.26 .29959 L
.264 .29943 L
.268 .29922 L
.272 .29927 L
.276 .2995 L
.28 .29958 L
.284 .29938 L
.288 .29916 L
.292 .29923 L
.296 .29949 L
.3 .29958 L
.304 .29936 L
.308 .29911 L
.312 .29917 L
.316 .29944 L
.32 .29958 L
.324 .29938 L
.328 .29909 L
.332 .29907 L
.336 .29934 L
.34 .29957 L
.344 .29947 L
.348 .29913 L
.352 .29896 L
.356 .29915 L
.36 .2995 L
.364 .29959 L
.368 .29929 L
.372 .2989 L
.376 .29888 L
.38 .29928 L
.384 .29967 L
.388 .29958 L
.392 .29904 L
.396 .29863 L
.4 .29884 L
Mistroke
.404 .29952 L
.408 .29991 L
.412 .29951 L
.416 .29865 L
.42 .29828 L
.424 .2989 L
.428 .29992 L
.432 .3002 L
.436 .2993 L
.44 .29809 L
.444 .29791 L
.448 .2991 L
.452 .30048 L
.456 .30051 L
.46 .29899 L
.464 .29741 L
.468 .29751 L
.472 .29934 L
.476 .30111 L
.48 .3009 L
.484 .29874 L
.488 .29671 L
.492 .29695 L
.496 .29938 L
.5 .30169 L
.504 .30152 L
.508 .29886 L
.512 .29618 L
.516 .2961 L
.52 .29885 L
.524 .30192 L
.528 .3024 L
.532 .29973 L
.536 .29627 L
.54 .29515 L
.544 .29745 L
.548 .30117 L
.552 .30304 L
.556 .30142 L
.56 .29771 L
.564 .29504 L
.568 .2956 L
.572 .29885 L
.576 .30209 L
.58 .30278 L
.584 .30053 L
.588 .2972 L
.592 .29531 L
.596 .29605 L
.6 .29864 L
Mistroke
.604 .30117 L
.608 .30205 L
.612 .30099 L
.616 .29886 L
.62 .29688 L
.624 .29596 L
.628 .29645 L
.632 .29815 L
.636 .30044 L
.64 .30231 L
.644 .30261 L
.648 .3007 L
.652 .29714 L
.656 .29377 L
.66 .29287 L
.664 .29563 L
.668 .30103 L
.672 .30603 L
.676 .30728 L
.68 .30335 L
.684 .29596 L
.688 .28928 L
.692 .28754 L
.696 .29231 L
.7 .30132 L
.704 .30963 L
.708 .31239 L
.712 .30777 L
.716 .29804 L
.72 .28834 L
.724 .28377 L
.728 .28666 L
.732 .29538 L
.736 .30545 L
.74 .31202 L
.744 .31235 L
.748 .30694 L
.752 .29878 L
.756 .29159 L
.76 .28789 L
.764 .28816 L
.768 .29123 L
.772 .29536 L
.776 .2994 L
.78 .30306 L
.784 .3065 L
.788 .3095 L
.792 .31108 L
.796 .30969 L
.8 .30421 L
Mistroke
.804 .29494 L
.808 .28411 L
.812 .27535 L
.816 .27239 L
.82 .27741 L
.824 .28996 L
.828 .30679 L
.832 .32295 L
.836 .33353 L
.84 .33536 L
.844 .32806 L
.848 .31402 L
.852 .29731 L
.856 .28221 L
.86 .27168 L
.864 .2667 L
.868 .2663 L
.872 .26846 L
.876 .27126 L
.88 .2738 L
.884 .27668 L
.888 .28167 L
.892 .29096 L
.896 .30617 L
.9 .3276 L
.904 .35391 L
.908 .38244 L
.912 .4099 L
.916 .43335 L
.92 .451 L
.924 .46261 L
.928 .4696 L
.932 .47432 L
.936 .47967 L
.94 .48785 L
.944 .50026 L
.948 .51653 L
.952 .53538 L
.956 .55416 L
.96 .57025 L
.964 .58106 L
.968 .58497 L
.972 .58164 L
.976 .57158 L
.98 .55715 L
.984 .54033 L
.988 .52471 L
.992 .51224 L
.996 .50556 L
1 .50557 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .52221 m
.008 .51591 L
.012 .51388 L
.016 .51598 L
.02 .51669 L
.024 .51594 L
.028 .51573 L
.032 .51596 L
.036 .51606 L
.04 .51595 L
.044 .51594 L
.048 .51596 L
.052 .51598 L
.056 .51596 L
.06 .51597 L
.064 .51596 L
.068 .51597 L
.072 .51596 L
.076 .51597 L
.08 .51596 L
.084 .51597 L
.088 .51596 L
.092 .51597 L
.096 .51596 L
.1 .51597 L
.104 .51596 L
.108 .51597 L
.112 .51596 L
.116 .51596 L
.12 .51596 L
.124 .51596 L
.128 .51596 L
.132 .51596 L
.136 .51596 L
.14 .51596 L
.144 .51596 L
.148 .51596 L
.152 .51596 L
.156 .51596 L
.16 .51596 L
.164 .51596 L
.168 .51596 L
.172 .51596 L
.176 .51596 L
.18 .51596 L
.184 .51596 L
.188 .51596 L
.192 .51596 L
.196 .51596 L
.2 .51596 L
Mistroke
.204 .51596 L
.208 .51596 L
.212 .51596 L
.216 .51596 L
.22 .51596 L
.224 .51596 L
.228 .51596 L
.232 .51596 L
.236 .51596 L
.24 .51596 L
.244 .51596 L
.248 .51596 L
.252 .51596 L
.256 .51596 L
.26 .51596 L
.264 .51595 L
.268 .51596 L
.272 .51596 L
.276 .51596 L
.28 .51596 L
.284 .51595 L
.288 .51595 L
.292 .51596 L
.296 .51596 L
.3 .51595 L
.304 .51595 L
.308 .51595 L
.312 .51596 L
.316 .51596 L
.32 .51595 L
.324 .51595 L
.328 .51595 L
.332 .51596 L
.336 .51596 L
.34 .51596 L
.344 .51595 L
.348 .51595 L
.352 .51595 L
.356 .51596 L
.36 .51596 L
.364 .51595 L
.368 .51594 L
.372 .51595 L
.376 .51596 L
.38 .51597 L
.384 .51595 L
.388 .51594 L
.392 .51594 L
.396 .51595 L
.4 .51597 L
Mistroke
.404 .51597 L
.408 .51594 L
.412 .51593 L
.416 .51593 L
.42 .51596 L
.424 .51598 L
.428 .51596 L
.432 .51593 L
.436 .51591 L
.44 .51593 L
.444 .51597 L
.448 .51599 L
.452 .51596 L
.456 .51592 L
.46 .5159 L
.464 .51593 L
.468 .51598 L
.472 .516 L
.476 .51596 L
.48 .5159 L
.484 .51588 L
.488 .51592 L
.492 .51599 L
.496 .51602 L
.5 .51597 L
.504 .51589 L
.508 .51585 L
.512 .5159 L
.516 .51599 L
.52 .51604 L
.524 .516 L
.528 .5159 L
.532 .51583 L
.536 .51586 L
.54 .51596 L
.544 .51605 L
.548 .51604 L
.552 .51594 L
.556 .51584 L
.56 .51581 L
.564 .51589 L
.568 .51601 L
.572 .51607 L
.576 .51602 L
.58 .51591 L
.584 .51582 L
.588 .51581 L
.592 .51589 L
.596 .516 L
.6 .51606 L
Mistroke
.604 .51604 L
.608 .51594 L
.612 .51584 L
.616 .5158 L
.62 .51583 L
.624 .51592 L
.628 .51602 L
.632 .51608 L
.636 .51605 L
.64 .51595 L
.644 .51582 L
.648 .51573 L
.652 .51575 L
.656 .51587 L
.66 .51606 L
.664 .51619 L
.668 .51618 L
.672 .51602 L
.676 .51577 L
.68 .51557 L
.684 .51556 L
.688 .51577 L
.692 .51609 L
.696 .51635 L
.7 .5164 L
.704 .51618 L
.708 .5158 L
.712 .51546 L
.716 .51533 L
.72 .5155 L
.724 .51589 L
.728 .5163 L
.732 .51654 L
.736 .5165 L
.74 .5162 L
.744 .51578 L
.748 .51543 L
.752 .51527 L
.756 .51535 L
.76 .51563 L
.764 .51598 L
.768 .51629 L
.772 .51649 L
.776 .51655 L
.78 .51646 L
.784 .51622 L
.788 .51588 L
.792 .51548 L
.796 .5151 L
.8 .51487 L
Mistroke
.804 .51489 L
.808 .51522 L
.812 .51583 L
.816 .5166 L
.82 .51731 L
.824 .51773 L
.828 .5177 L
.832 .51718 L
.836 .51626 L
.84 .51517 L
.844 .51415 L
.848 .51344 L
.852 .5132 L
.856 .51344 L
.86 .51409 L
.864 .515 L
.868 .51604 L
.872 .51707 L
.876 .51805 L
.88 .51893 L
.884 .5197 L
.888 .5203 L
.892 .52063 L
.896 .52055 L
.9 .51988 L
.904 .51848 L
.908 .51627 L
.912 .51323 L
.916 .50945 L
.92 .50506 L
.924 .50025 L
.928 .49514 L
.932 .48985 L
.936 .48441 L
.94 .47877 L
.944 .47285 L
.948 .46654 L
.952 .45977 L
.956 .45248 L
.96 .44476 L
.964 .43667 L
.968 .42842 L
.972 .42016 L
.976 .41213 L
.98 .40442 L
.984 .39717 L
.988 .39036 L
.992 .38394 L
.996 .37781 L
1 .37177 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42877 L
.012 .42964 L
.016 .43017 L
.02 .42991 L
.024 .42967 L
.028 .42961 L
.032 .42969 L
.036 .42963 L
.04 .42957 L
.044 .4295 L
.048 .42949 L
.052 .42943 L
.056 .4294 L
.06 .42933 L
.064 .42931 L
.068 .42925 L
.072 .42922 L
.076 .42916 L
.08 .42913 L
.084 .42907 L
.088 .42904 L
.092 .42899 L
.096 .42895 L
.1 .4289 L
.104 .42886 L
.108 .42881 L
.112 .42877 L
.116 .42872 L
.12 .42868 L
.124 .42864 L
.128 .4286 L
.132 .42855 L
.136 .42851 L
.14 .42846 L
.144 .42842 L
.148 .42837 L
.152 .42833 L
.156 .42828 L
.16 .42824 L
.164 .4282 L
.168 .42815 L
.172 .42811 L
.176 .42807 L
.18 .42802 L
.184 .42798 L
.188 .42793 L
.192 .42789 L
.196 .42785 L
.2 .4278 L
Mistroke
.204 .42775 L
.208 .42771 L
.212 .42767 L
.216 .42763 L
.22 .42758 L
.224 .42753 L
.228 .42749 L
.232 .42745 L
.236 .42741 L
.24 .42736 L
.244 .42731 L
.248 .42727 L
.252 .42723 L
.256 .42719 L
.26 .42714 L
.264 .42709 L
.268 .42705 L
.272 .42701 L
.276 .42697 L
.28 .42692 L
.284 .42687 L
.288 .42683 L
.292 .42679 L
.296 .42675 L
.3 .4267 L
.304 .42665 L
.308 .42661 L
.312 .42657 L
.316 .42653 L
.32 .42648 L
.324 .42642 L
.328 .42638 L
.332 .42635 L
.336 .42631 L
.34 .42626 L
.344 .4262 L
.348 .42616 L
.352 .42613 L
.356 .42609 L
.36 .42605 L
.364 .42599 L
.368 .42593 L
.372 .4259 L
.376 .42587 L
.38 .42583 L
.384 .42578 L
.388 .42571 L
.392 .42567 L
.396 .42564 L
.4 .42562 L
Mistroke
.404 .42557 L
.408 .4255 L
.412 .42544 L
.416 .4254 L
.42 .42539 L
.424 .42537 L
.428 .42531 L
.432 .42522 L
.436 .42516 L
.44 .42514 L
.444 .42514 L
.448 .42512 L
.452 .42504 L
.456 .42494 L
.46 .42488 L
.464 .42487 L
.468 .42489 L
.472 .42487 L
.476 .42478 L
.48 .42466 L
.484 .42459 L
.488 .4246 L
.492 .42465 L
.496 .42463 L
.5 .42453 L
.504 .42438 L
.508 .4243 L
.512 .42431 L
.516 .42438 L
.52 .4244 L
.524 .4243 L
.528 .42413 L
.532 .42401 L
.536 .424 L
.54 .42408 L
.544 .42415 L
.548 .42409 L
.552 .42393 L
.556 .42375 L
.56 .42368 L
.564 .42373 L
.568 .42383 L
.572 .42386 L
.576 .42377 L
.58 .42358 L
.584 .42342 L
.588 .42337 L
.592 .42343 L
.596 .42352 L
.6 .42355 L
Mistroke
.604 .42348 L
.608 .42332 L
.612 .42315 L
.616 .42305 L
.62 .42305 L
.624 .42312 L
.628 .4232 L
.632 .42322 L
.636 .42315 L
.64 .42298 L
.644 .42278 L
.648 .42262 L
.652 .4226 L
.656 .42271 L
.66 .42289 L
.664 .42302 L
.668 .42296 L
.672 .42271 L
.676 .42236 L
.68 .42207 L
.684 .42202 L
.688 .42223 L
.692 .42259 L
.696 .42287 L
.7 .42288 L
.704 .42257 L
.708 .42205 L
.712 .42158 L
.716 .42138 L
.72 .42155 L
.724 .42199 L
.728 .42246 L
.732 .42272 L
.736 .42262 L
.74 .42221 L
.744 .42164 L
.748 .42115 L
.752 .42091 L
.756 .42098 L
.76 .42127 L
.764 .42167 L
.768 .42201 L
.772 .42222 L
.776 .42225 L
.78 .42209 L
.784 .42175 L
.788 .42128 L
.792 .42074 L
.796 .42023 L
.8 .4199 L
Mistroke
.804 .41988 L
.808 .42025 L
.812 .42097 L
.816 .42188 L
.82 .42272 L
.824 .4232 L
.828 .42312 L
.832 .42243 L
.836 .42124 L
.84 .41983 L
.844 .41852 L
.848 .41761 L
.852 .41727 L
.856 .41755 L
.86 .41833 L
.864 .41945 L
.868 .42073 L
.872 .42203 L
.876 .42327 L
.88 .42443 L
.884 .42548 L
.888 .42637 L
.892 .42699 L
.896 .42718 L
.9 .42675 L
.904 .42555 L
.908 .42351 L
.912 .42065 L
.916 .41712 L
.92 .41314 L
.924 .40897 L
.928 .40483 L
.932 .40091 L
.936 .39727 L
.94 .39389 L
.944 .39068 L
.948 .38747 L
.952 .38417 L
.956 .38065 L
.96 .37693 L
.964 .37299 L
.968 .36899 L
.972 .36497 L
.976 .3611 L
.98 .35741 L
.984 .35397 L
.988 .35072 L
.992 .3476 L
.996 .34451 L
1 .34129 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oo`000003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool40002Ool40003Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo045oo`04001oo`000002Ool20003Ool20003Ool01000Oomoo`005goo000ROol2000UOol0
1P00Ool007oo001oo`@00003Ool007oo00800003Ool007oo00<00004Ool00000Ool2000017oo0000
07oo0P000Woo0P000Woo00<007oo00000Woo00D007ooOomoo`0001Moo`008WooH`0037oo000ROol0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoo`000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
009oo`05001oogooOol00002Ool2000017oo000000000Woo0P000Woo0`000Woo0P000Woo00D007oo
Oomoo`0000=oo`03001oogoo00Yoo`008Woo0P00Cgoo0P001Goo00<007ooOol057oo000ROol00`00
Oomoo`1?Ool00`00Oomoo`03Ool00`00Oomoo`0DOol0029oo`8005Ioo`03001oogoo01Aoo`008Woo
0P00EWoo00<007ooOol057oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomo
o`1EOol00`00Oomoo`0DOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00Egoo00<007ooOol04goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8005Moo`03001oogoo01=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1FOol00`00Oomoo`0COol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P00Egoo00<007ooOol04goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`8005Moo`03001oogoo01=oo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0
EWoo00<007ooOol04goo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001GOol00`00
Oomoo`0COol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8005Qoo`03
001oogoo019oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1GOol00`00Oomoo`0BOol000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`80
05Uoo`03001oogoo015oo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol0
0P00FGoo00<007ooOol04Goo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomo
o`00Fgoo00<007ooOol047oo000;Ool2000:Ool20003Ool30003Ool2001JOol00`00Oomoo`0@Ool0
029oo`03001oogoo05Uoo`03001oogoo009oo`8000aoo`002goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo0P00FWoo00<007ooOol00Woo00<007ooOol02goo000:Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool00`00Oomoo`02001JOol01@00Oomoogoo00003Woo000:Ool01000Oomoo`00
27oo00@007ooOol000Eoo`04001oogoo001LOol01000Oomoo`003Woo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`8000=oo`8005]oo`04001oogoo000>Ool000Yoo`04001oogoo0008Ool01000
Oomoo`001Goo00<007ooOol00P00Fgoo00@007ooOol000ioo`002Woo00@007ooOol000Qoo`06001o
ogoo001oo`000goo00@007ooOol005eoo`8000moo`002goo0P002Woo0P000goo0`000goo0P00G7oo
0P003goo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo
0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol0
0003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eo
o`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000
0goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo
00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P00
17oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00
Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool0
00=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Ao
o`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009o
o`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogoo
Ool00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo
00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`00
17oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P00
0Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009o
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001o
o`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo
00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Ao
o`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomo
o`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool0
1000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool0
0`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0F7oo0P0037oo000;Ool20004Ool00`00Oomoo`03Ool20004Ool2
0003Ool30003Ool00`00Oomoo`1HOol00`00Oomoo`0;Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00H007ooOol007oo0003Ool01000Oomoo`00FGoo00<007ooOol037oo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00FGoo00<007ooOol037oo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001GOol00`00
Oomoo`0=Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03
001oogoo05Ioo`03001oogoo00eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000Ioo`03001oogoo05Eoo`03001oogoo00ioo`002goo0P002Woo0P0017oo0P000Woo1@00
0Woo00<007ooOol0EGoo00<007ooOol03Woo000XOol00`00Oomoo`1DOol00`00Oomoo`0?Ool002Qo
o`03001oogoo05=oo`80015oo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007oo
Ool0Dgoo00<007ooOol047oo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo059oo`03001oogoo015oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1AOol2000COol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00WooE@0057oo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0
015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001o
ogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@0
06aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`80
00Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]o
o`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001c
Ool000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002
Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eo
o`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo
0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`00
0Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<0
07ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool0
1000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo
10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Ao
o`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol0
17oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007oo
Ool017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Ao
o`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<0
07ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Io
o`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT0
00aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol0
00]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001o
ogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001c
Ool000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0I7oo0P0037oo000LOol2
001TOol2000=Ool001aoo`03001oogoo069oo`03001oogoo00eoo`0077oo0P00HWoo00<007ooOol0
3Woo000LOol00`00Oomoo`1POol00`00Oomoo`0?Ool001aoo`03001oogoo05ioo`80019oo`0077oo
0P00GWoo0P004goo000FOol30003Ool00`00Oomoo`1LOol2000DOol001Moo`03001oogoo009oo`03
001oogoo02moobX0009oo`8001Eoo`005goo00<007ooOol00Woo<P00:Woo0`005Woo000GOol00`00
Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo
0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo
00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1b
Ool000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(6680\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30202 m
.008 .30071 L
.012 .29909 L
.016 .29887 L
.02 .30007 L
.024 .30035 L
.028 .29971 L
.032 .29953 L
.036 .29982 L
.04 .2999 L
.044 .29977 L
.048 .29973 L
.052 .29977 L
.056 .29977 L
.06 .29975 L
.064 .29974 L
.068 .29974 L
.072 .29973 L
.076 .29973 L
.08 .29973 L
.084 .29972 L
.088 .2997 L
.092 .2997 L
.096 .29971 L
.1 .2997 L
.104 .29968 L
.108 .29966 L
.112 .29968 L
.116 .29969 L
.12 .29966 L
.124 .29963 L
.128 .29965 L
.132 .29968 L
.136 .29965 L
.14 .2996 L
.144 .29961 L
.148 .29965 L
.152 .29964 L
.156 .29958 L
.16 .29956 L
.164 .29961 L
.168 .29964 L
.172 .29958 L
.176 .29952 L
.18 .29955 L
.184 .29962 L
.188 .2996 L
.192 .2995 L
.196 .29948 L
.2 .29957 L
Mistroke
.204 .29962 L
.208 .29954 L
.212 .29943 L
.216 .29947 L
.22 .29959 L
.224 .29959 L
.228 .29945 L
.232 .29937 L
.236 .29948 L
.24 .2996 L
.244 .29954 L
.248 .29937 L
.252 .29933 L
.256 .29949 L
.26 .29961 L
.264 .29949 L
.268 .29929 L
.272 .2993 L
.276 .2995 L
.28 .2996 L
.284 .29944 L
.288 .29923 L
.292 .29927 L
.296 .2995 L
.3 .29959 L
.304 .29941 L
.308 .29918 L
.312 .29921 L
.316 .29946 L
.32 .29959 L
.324 .29941 L
.328 .29915 L
.332 .29913 L
.336 .29938 L
.34 .29958 L
.344 .29946 L
.348 .29916 L
.352 .29904 L
.356 .29924 L
.36 .29954 L
.364 .29956 L
.368 .29926 L
.372 .29897 L
.376 .29902 L
.38 .29939 L
.384 .29965 L
.388 .29947 L
.392 .29902 L
.396 .29878 L
.4 .29906 L
Mistroke
.404 .2996 L
.408 .29977 L
.412 .29932 L
.416 .29868 L
.42 .29858 L
.424 .29921 L
.428 .29993 L
.432 .29989 L
.436 .29902 L
.44 .29821 L
.444 .29841 L
.448 .29953 L
.452 .30038 L
.456 .29995 L
.46 .29855 L
.464 .29764 L
.468 .2983 L
.472 .29997 L
.476 .3009 L
.48 .29999 L
.484 .29801 L
.488 .29701 L
.492 .29814 L
.496 .30041 L
.5 .30151 L
.504 .30019 L
.508 .2976 L
.512 .2963 L
.516 .2977 L
.52 .30058 L
.524 .30216 L
.528 .30079 L
.532 .29763 L
.536 .29563 L
.54 .29676 L
.544 .30008 L
.548 .30256 L
.552 .30188 L
.556 .29856 L
.56 .29553 L
.564 .29549 L
.568 .2985 L
.572 .30196 L
.576 .30291 L
.58 .30058 L
.584 .29694 L
.588 .29498 L
.592 .29621 L
.596 .29952 L
.6 .30225 L
Mistroke
.604 .30239 L
.608 .30003 L
.612 .29706 L
.616 .29557 L
.62 .29638 L
.624 .29868 L
.628 .3009 L
.632 .30179 L
.636 .30107 L
.64 .29926 L
.644 .29725 L
.648 .29593 L
.652 .29594 L
.656 .29752 L
.66 .30019 L
.664 .3027 L
.668 .30342 L
.672 .30139 L
.676 .29722 L
.68 .29316 L
.684 .29192 L
.688 .29492 L
.692 .30096 L
.696 .30664 L
.7 .30824 L
.704 .30417 L
.708 .29625 L
.712 .28893 L
.716 .28669 L
.72 .29131 L
.724 .30057 L
.728 .30944 L
.732 .31291 L
.736 .30888 L
.74 .29936 L
.744 .28933 L
.748 .28396 L
.752 .28583 L
.756 .29374 L
.76 .3036 L
.764 .31072 L
.768 .31221 L
.772 .30812 L
.776 .30094 L
.78 .29397 L
.784 .28964 L
.788 .28865 L
.792 .29023 L
.796 .29314 L
.8 .29654 L
Mistroke
.804 .30036 L
.808 .30471 L
.812 .30922 L
.816 .31258 L
.82 .31285 L
.824 .30846 L
.828 .29935 L
.832 .28755 L
.836 .27678 L
.84 .27123 L
.844 .27381 L
.848 .28484 L
.852 .30174 L
.856 .31983 L
.86 .33395 L
.864 .3403 L
.868 .33769 L
.872 .32774 L
.876 .31414 L
.88 .30117 L
.884 .29224 L
.888 .28892 L
.892 .29083 L
.896 .29626 L
.9 .30324 L
.904 .31061 L
.908 .31844 L
.912 .32817 L
.916 .34164 L
.92 .36055 L
.924 .38515 L
.928 .41431 L
.932 .44517 L
.936 .47421 L
.94 .4979 L
.944 .51366 L
.948 .52081 L
.952 .52008 L
.956 .51436 L
.96 .50663 L
.964 .50077 L
.968 .49908 L
.972 .50316 L
.976 .51289 L
.98 .52642 L
.984 .54201 L
.988 .55588 L
.992 .5667 L
.996 .57149 L
1 .57049 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51809 m
.008 .51586 L
.012 .51507 L
.016 .51558 L
.02 .51595 L
.024 .5158 L
.028 .51569 L
.032 .51569 L
.036 .51576 L
.04 .51574 L
.044 .51574 L
.048 .51572 L
.052 .51574 L
.056 .51573 L
.06 .51574 L
.064 .51573 L
.068 .51574 L
.072 .51573 L
.076 .51574 L
.08 .51573 L
.084 .51574 L
.088 .51573 L
.092 .51574 L
.096 .51573 L
.1 .51574 L
.104 .51573 L
.108 .51574 L
.112 .51573 L
.116 .51574 L
.12 .51573 L
.124 .51574 L
.128 .51573 L
.132 .51574 L
.136 .51573 L
.14 .51574 L
.144 .51573 L
.148 .51574 L
.152 .51573 L
.156 .51573 L
.16 .51573 L
.164 .51574 L
.168 .51573 L
.172 .51573 L
.176 .51573 L
.18 .51574 L
.184 .51573 L
.188 .51573 L
.192 .51573 L
.196 .51573 L
.2 .51573 L
Mistroke
.204 .51573 L
.208 .51573 L
.212 .51573 L
.216 .51573 L
.22 .51573 L
.224 .51573 L
.228 .51573 L
.232 .51573 L
.236 .51573 L
.24 .51573 L
.244 .51573 L
.248 .51573 L
.252 .51573 L
.256 .51573 L
.26 .51573 L
.264 .51573 L
.268 .51573 L
.272 .51573 L
.276 .51573 L
.28 .51573 L
.284 .51572 L
.288 .51573 L
.292 .51573 L
.296 .51573 L
.3 .51573 L
.304 .51572 L
.308 .51573 L
.312 .51573 L
.316 .51573 L
.32 .51573 L
.324 .51572 L
.328 .51572 L
.332 .51573 L
.336 .51573 L
.34 .51573 L
.344 .51572 L
.348 .51572 L
.352 .51573 L
.356 .51573 L
.36 .51573 L
.364 .51572 L
.368 .51571 L
.372 .51572 L
.376 .51573 L
.38 .51573 L
.384 .51572 L
.388 .51571 L
.392 .51571 L
.396 .51573 L
.4 .51574 L
Mistroke
.404 .51573 L
.408 .51571 L
.412 .5157 L
.416 .51571 L
.42 .51573 L
.424 .51574 L
.428 .51573 L
.432 .5157 L
.436 .5157 L
.44 .51572 L
.444 .51574 L
.448 .51575 L
.452 .51572 L
.456 .51569 L
.46 .51569 L
.464 .51572 L
.468 .51576 L
.472 .51575 L
.476 .51571 L
.48 .51567 L
.484 .51568 L
.488 .51573 L
.492 .51577 L
.496 .51576 L
.5 .5157 L
.504 .51565 L
.508 .51566 L
.512 .51572 L
.516 .51578 L
.52 .51578 L
.524 .51571 L
.528 .51563 L
.532 .51563 L
.536 .5157 L
.54 .51579 L
.544 .51581 L
.548 .51574 L
.552 .51564 L
.556 .5156 L
.56 .51566 L
.564 .51576 L
.568 .51582 L
.572 .51579 L
.576 .51568 L
.58 .5156 L
.584 .5156 L
.588 .51568 L
.592 .51579 L
.596 .51583 L
.6 .51578 L
Mistroke
.604 .51567 L
.608 .51559 L
.612 .51559 L
.616 .51567 L
.62 .51577 L
.624 .51582 L
.628 .5158 L
.632 .51572 L
.636 .51562 L
.64 .51557 L
.644 .51559 L
.648 .51568 L
.652 .51578 L
.656 .51585 L
.66 .51584 L
.664 .51574 L
.668 .5156 L
.672 .51549 L
.676 .51549 L
.68 .51562 L
.684 .51582 L
.688 .51597 L
.692 .51598 L
.696 .51581 L
.7 .51555 L
.704 .51533 L
.708 .51531 L
.712 .5155 L
.716 .51583 L
.72 .51611 L
.724 .51618 L
.728 .51599 L
.732 .51562 L
.736 .51526 L
.74 .5151 L
.744 .51523 L
.748 .51558 L
.752 .51599 L
.756 .51627 L
.76 .51628 L
.764 .51604 L
.768 .51566 L
.772 .5153 L
.776 .5151 L
.78 .51511 L
.784 .5153 L
.788 .5156 L
.792 .51592 L
.796 .51617 L
.8 .5163 L
Mistroke
.804 .5163 L
.808 .51615 L
.812 .51584 L
.816 .51543 L
.82 .51499 L
.824 .51465 L
.828 .51453 L
.832 .51474 L
.836 .51527 L
.84 .51601 L
.844 .51678 L
.848 .51732 L
.852 .51745 L
.856 .51707 L
.86 .51623 L
.864 .5151 L
.868 .5139 L
.872 .51289 L
.876 .51222 L
.88 .51194 L
.884 .51201 L
.888 .51229 L
.892 .51265 L
.896 .51294 L
.9 .51309 L
.904 .51303 L
.908 .51275 L
.912 .51218 L
.916 .51123 L
.92 .50977 L
.924 .50764 L
.928 .50473 L
.932 .50093 L
.936 .49628 L
.94 .49086 L
.944 .48488 L
.948 .47852 L
.952 .47206 L
.956 .46563 L
.96 .45936 L
.964 .45325 L
.968 .44722 L
.972 .44117 L
.976 .43492 L
.98 .42839 L
.984 .42149 L
.988 .4142 L
.992 .40665 L
.996 .39886 L
1 .39111 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43431 L
.012 .42978 L
.016 .42836 L
.02 .42981 L
.024 .43026 L
.028 .42966 L
.032 .42949 L
.036 .4296 L
.04 .42963 L
.044 .42951 L
.048 .42946 L
.052 .42942 L
.056 .4294 L
.06 .42934 L
.064 .4293 L
.068 .42925 L
.072 .42922 L
.076 .42916 L
.08 .42913 L
.084 .42907 L
.088 .42904 L
.092 .42899 L
.096 .42895 L
.1 .4289 L
.104 .42886 L
.108 .42881 L
.112 .42877 L
.116 .42872 L
.12 .42868 L
.124 .42864 L
.128 .4286 L
.132 .42855 L
.136 .42851 L
.14 .42846 L
.144 .42842 L
.148 .42837 L
.152 .42833 L
.156 .42828 L
.16 .42824 L
.164 .4282 L
.168 .42815 L
.172 .42811 L
.176 .42807 L
.18 .42802 L
.184 .42798 L
.188 .42793 L
.192 .42789 L
.196 .42785 L
.2 .4278 L
Mistroke
.204 .42776 L
.208 .42771 L
.212 .42767 L
.216 .42763 L
.22 .42758 L
.224 .42754 L
.228 .42749 L
.232 .42745 L
.236 .42741 L
.24 .42736 L
.244 .42731 L
.248 .42727 L
.252 .42723 L
.256 .42719 L
.26 .42714 L
.264 .42709 L
.268 .42705 L
.272 .42701 L
.276 .42697 L
.28 .42692 L
.284 .42687 L
.288 .42683 L
.292 .42679 L
.296 .42675 L
.3 .4267 L
.304 .42665 L
.308 .42661 L
.312 .42657 L
.316 .42653 L
.32 .42648 L
.324 .42643 L
.328 .42639 L
.332 .42635 L
.336 .42631 L
.34 .42626 L
.344 .42621 L
.348 .42616 L
.352 .42613 L
.356 .42609 L
.36 .42605 L
.364 .42599 L
.368 .42594 L
.372 .4259 L
.376 .42587 L
.38 .42583 L
.384 .42577 L
.388 .42572 L
.392 .42567 L
.396 .42565 L
.4 .42562 L
Mistroke
.404 .42557 L
.408 .4255 L
.412 .42544 L
.416 .42541 L
.42 .42539 L
.424 .42536 L
.428 .4253 L
.432 .42522 L
.436 .42517 L
.44 .42515 L
.444 .42514 L
.448 .4251 L
.452 .42502 L
.456 .42494 L
.46 .4249 L
.464 .4249 L
.468 .4249 L
.472 .42485 L
.476 .42475 L
.48 .42466 L
.484 .42462 L
.488 .42464 L
.492 .42465 L
.496 .4246 L
.5 .42448 L
.504 .42437 L
.508 .42434 L
.512 .42438 L
.516 .42441 L
.52 .42436 L
.524 .42423 L
.528 .42409 L
.532 .42404 L
.536 .42409 L
.54 .42415 L
.544 .42413 L
.548 .424 L
.552 .42384 L
.556 .42374 L
.56 .42377 L
.564 .42386 L
.568 .42389 L
.572 .42381 L
.576 .42363 L
.58 .42348 L
.584 .42344 L
.588 .4235 L
.592 .42359 L
.596 .4236 L
.6 .42348 L
Mistroke
.604 .42331 L
.608 .42316 L
.612 .42312 L
.616 .42318 L
.62 .42326 L
.624 .42328 L
.628 .42321 L
.632 .42306 L
.636 .4229 L
.64 .4228 L
.644 .42278 L
.648 .42284 L
.652 .42293 L
.656 .42297 L
.66 .42291 L
.664 .42274 L
.668 .42252 L
.672 .42235 L
.676 .42231 L
.68 .42243 L
.684 .42263 L
.688 .42277 L
.692 .42273 L
.696 .42248 L
.7 .42211 L
.704 .4218 L
.708 .42173 L
.712 .42193 L
.716 .42229 L
.72 .4226 L
.724 .42265 L
.728 .42236 L
.732 .42186 L
.736 .42137 L
.74 .42113 L
.744 .42124 L
.748 .42164 L
.752 .42211 L
.756 .4224 L
.76 .42238 L
.764 .42204 L
.768 .42152 L
.772 .42102 L
.776 .42073 L
.78 .42069 L
.784 .4209 L
.788 .42123 L
.792 .42158 L
.796 .42185 L
.8 .42197 L
Mistroke
.804 .42193 L
.808 .42169 L
.812 .42127 L
.816 .42072 L
.82 .42013 L
.824 .41967 L
.828 .4195 L
.832 .41972 L
.836 .42036 L
.84 .42128 L
.844 .42224 L
.848 .42294 L
.852 .42315 L
.856 .42277 L
.86 .42185 L
.864 .42063 L
.868 .41942 L
.872 .41854 L
.876 .41821 L
.88 .41854 L
.884 .4195 L
.888 .42096 L
.892 .4228 L
.896 .42489 L
.9 .42718 L
.904 .42964 L
.908 .43227 L
.912 .43504 L
.916 .43784 L
.92 .44051 L
.924 .44283 L
.928 .4446 L
.932 .44564 L
.936 .4459 L
.94 .44535 L
.944 .44416 L
.948 .44243 L
.952 .44037 L
.956 .43807 L
.96 .43563 L
.964 .43301 L
.968 .43016 L
.972 .427 L
.976 .42343 L
.98 .41946 L
.984 .41511 L
.988 .41048 L
.992 .4058 L
.996 .40113 L
1 .39678 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20003Ool30005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo04=oo`04001oogoo0007Ool00`00Ool0000KOol0029oo`8002Moo`04001oo`00Ool40000
0goo001oo`04000017oo000007oo0P0000Aoo`00001oo`800003Ool00000009oo`800004Ool00000
0002Ool00`00Ool00002Ool2000GOol0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00002Ool01@00Oomoogoo00000goo
0P000Woo0P000Woo0`0000Aoo`00001oo`800004Ool000000003Ool01@00Oomoogoo000037oo000R
Ool2001BOol20003Ool00`00Oomoo`0COol0029oo`03001oogoo055oo`8000=oo`03001oogoo01=o
o`008Woo0P00DWoo00<007ooOol00Woo00<007ooOol04goo000ROol2001GOol00`00Oomoo`0COol0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo05Moo`03001oogoo019oo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001HOol00`00Oomoo`0BOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00F7oo00<007ooOol04Woo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo05Moo`03001o
ogoo019oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001IOol00`00
Oomoo`0AOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00FGoo00<007ooOol0
4Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1HOol00`00Oomoo`0AOol000]o
o`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8005Uoo`03001oogoo015oo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00FGoo00<007ooOol04Goo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo05Qoo`03001oogoo015oo`00
2Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00FGoo00<007ooOol04Goo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001IOol00`00Oomoo`0AOol0
00Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001JOol00`00Oomoo`0AOol0
00]oo`8000Yoo`8000=oo`<000=oo`8005Yoo`04001oo`00000?Ool0029oo`03001oogoo05Uoo`@0
00moo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00FWoo0P0000=oo`00Ool03Woo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001NOol00`00Oomoo`0<
Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol005moo`03001oogoo00aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001NOol00`00Oomoo`0<Ool000Yoo`04
001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00GWoo00<007ooOol037oo000:Ool01000
Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00H7oo0P0037oo000;Ool2000:Ool20003
Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03
001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00
Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D0
07ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001o
ogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo
00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo
0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001o
ogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`00
0goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomo
ogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eo
o`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04
001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool2
0004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`00
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool0
00030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`00
1Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Io
o`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Ao
o`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool2
0006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qoo`03001o
ogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001o
ogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Ao
o`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00
Oomoo`00Ool000=oo`04001oogoo001JOol2000<Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogoo001JOol00`00Oomoo`0;Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008005Qoo`03001oogoo00aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0Egoo00<007oo
Ool037oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007oo
Ool0EWoo00<007ooOol03Goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1EOol2
000?Ool002Qoo`03001oogoo05Eoo`03001oogoo00ioo`00:7oo00<007ooOol0E7oo00<007ooOol0
3goo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1COol2000AOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0Dgoo00<007ooOol0
47oo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo055oo`80
01=oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02OomE000DOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007oo
Ool00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1V
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001X
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D0
06]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00
0goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079o
o`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04
001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<0
07ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@00
0goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo
00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomo
o`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03
001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool0
1000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo
00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool0
1000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo0000
0goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000;
Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:
Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2
001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001UOol2000<Ool001Io
o`<000=oo`03001oogoo06=oo`8000eoo`005goo00<007ooOol00Woo00<007ooOol0;goo:`0027oo
0P003Woo000GOol00`00Oomoo`02Oolb000[Ool20005Ool2000?Ool001Moo`03001oogoo009oo`03
001oogoo05]oo`<00003Ool00000015oo`005goo00<007ooOol00Woo00<007ooOol0GGoo0`004Woo
000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00
Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomo
o`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=o
o`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomo
o`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(6847\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30074 m
.008 .2996 L
.012 .29971 L
.016 .29973 L
.02 .29979 L
.024 .29993 L
.028 .29991 L
.032 .29979 L
.036 .29977 L
.04 .29983 L
.044 .29984 L
.048 .2998 L
.052 .29979 L
.056 .29979 L
.06 .29979 L
.064 .29979 L
.068 .29978 L
.072 .29976 L
.076 .29976 L
.08 .29976 L
.084 .29976 L
.088 .29974 L
.092 .29973 L
.096 .29974 L
.1 .29974 L
.104 .29972 L
.108 .2997 L
.112 .29971 L
.116 .29972 L
.12 .2997 L
.124 .29967 L
.128 .29967 L
.132 .2997 L
.136 .29969 L
.14 .29964 L
.144 .29964 L
.148 .29968 L
.152 .29968 L
.156 .29963 L
.16 .2996 L
.164 .29963 L
.168 .29967 L
.172 .29963 L
.176 .29957 L
.18 .29957 L
.184 .29964 L
.188 .29965 L
.192 .29956 L
.196 .29952 L
.2 .29958 L
Mistroke
.204 .29964 L
.208 .29959 L
.212 .29949 L
.216 .29949 L
.22 .2996 L
.224 .29963 L
.228 .29952 L
.232 .29942 L
.236 .29949 L
.24 .29961 L
.244 .29959 L
.248 .29944 L
.252 .29937 L
.256 .29949 L
.26 .29962 L
.264 .29955 L
.268 .29936 L
.272 .29934 L
.276 .2995 L
.28 .29962 L
.284 .2995 L
.288 .2993 L
.292 .2993 L
.296 .2995 L
.3 .29961 L
.304 .29946 L
.308 .29924 L
.312 .29925 L
.316 .29948 L
.32 .2996 L
.324 .29945 L
.328 .29921 L
.332 .29919 L
.336 .29942 L
.34 .29959 L
.344 .29948 L
.348 .2992 L
.352 .29911 L
.356 .29931 L
.36 .29956 L
.364 .29954 L
.368 .29926 L
.372 .29903 L
.376 .29914 L
.38 .29946 L
.384 .29962 L
.388 .29941 L
.392 .29904 L
.396 .29892 L
.4 .29922 L
Mistroke
.404 .29962 L
.408 .29965 L
.412 .29921 L
.416 .29876 L
.42 .29883 L
.424 .2994 L
.428 .29986 L
.432 .29964 L
.436 .29889 L
.44 .29842 L
.444 .29881 L
.448 .29973 L
.452 .30016 L
.456 .29952 L
.46 .2984 L
.464 .29803 L
.468 .29892 L
.472 .30021 L
.476 .30048 L
.48 .29929 L
.484 .2978 L
.488 .29762 L
.492 .29909 L
.496 .30077 L
.5 .30086 L
.504 .29909 L
.508 .29716 L
.512 .29711 L
.516 .29914 L
.52 .30131 L
.524 .30139 L
.528 .29913 L
.532 .29664 L
.536 .2964 L
.54 .29877 L
.544 .30159 L
.548 .30213 L
.552 .29974 L
.556 .29656 L
.56 .29555 L
.564 .29772 L
.568 .30117 L
.572 .30279 L
.576 .30108 L
.58 .2975 L
.584 .29516 L
.588 .29609 L
.592 .29947 L
.596 .30244 L
.6 .30254 L
Mistroke
.604 .29977 L
.608 .29642 L
.612 .29515 L
.616 .29681 L
.62 .29997 L
.624 .3022 L
.628 .30199 L
.632 .29972 L
.636 .29711 L
.64 .29586 L
.644 .29656 L
.648 .29854 L
.652 .30056 L
.656 .30162 L
.66 .3013 L
.664 .29976 L
.668 .2976 L
.672 .29578 L
.676 .29532 L
.68 .29686 L
.684 .3 L
.688 .30315 L
.692 .30426 L
.696 .30208 L
.7 .29731 L
.704 .29257 L
.708 .291 L
.712 .29419 L
.716 .30082 L
.72 .30715 L
.724 .30914 L
.728 .30502 L
.732 .29668 L
.736 .28875 L
.74 .28596 L
.744 .29029 L
.748 .29965 L
.752 .30901 L
.756 .31323 L
.76 .30993 L
.764 .3008 L
.768 .2906 L
.772 .28446 L
.776 .28524 L
.78 .29218 L
.784 .30164 L
.788 .30916 L
.792 .31176 L
.796 .30909 L
.8 .30311 L
Mistroke
.804 .29671 L
.808 .29214 L
.812 .29024 L
.816 .2906 L
.82 .29242 L
.824 .29532 L
.828 .29948 L
.832 .30515 L
.836 .31194 L
.84 .31836 L
.844 .32213 L
.848 .32127 L
.852 .3153 L
.856 .30597 L
.86 .29703 L
.864 .29301 L
.868 .2975 L
.872 .31167 L
.876 .33357 L
.88 .3588 L
.884 .38186 L
.888 .39819 L
.892 .4053 L
.896 .40367 L
.9 .39588 L
.904 .38565 L
.908 .37619 L
.912 .36927 L
.916 .36485 L
.92 .3615 L
.924 .35766 L
.928 .35217 L
.932 .34571 L
.936 .33997 L
.94 .33802 L
.944 .34249 L
.948 .35517 L
.952 .37615 L
.956 .40323 L
.96 .43355 L
.964 .46243 L
.968 .48693 L
.972 .50393 L
.976 .51313 L
.98 .51545 L
.984 .51285 L
.988 .5092 L
.992 .50628 L
.996 .50747 L
1 .51274 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .50974 m
.008 .51556 L
.012 .5175 L
.016 .51544 L
.02 .51485 L
.024 .51552 L
.028 .51575 L
.032 .51549 L
.036 .51544 L
.04 .5155 L
.044 .51554 L
.048 .5155 L
.052 .51551 L
.056 .5155 L
.06 .51552 L
.064 .5155 L
.068 .51551 L
.072 .5155 L
.076 .51551 L
.08 .5155 L
.084 .51551 L
.088 .5155 L
.092 .51551 L
.096 .5155 L
.1 .51551 L
.104 .5155 L
.108 .51551 L
.112 .51551 L
.116 .51551 L
.12 .51551 L
.124 .51551 L
.128 .51551 L
.132 .51551 L
.136 .51551 L
.14 .51551 L
.144 .51551 L
.148 .51551 L
.152 .51551 L
.156 .51551 L
.16 .51551 L
.164 .51551 L
.168 .51551 L
.172 .51551 L
.176 .5155 L
.18 .51551 L
.184 .51551 L
.188 .51551 L
.192 .5155 L
.196 .51551 L
.2 .51551 L
Mistroke
.204 .51551 L
.208 .5155 L
.212 .5155 L
.216 .51551 L
.22 .51551 L
.224 .5155 L
.228 .5155 L
.232 .5155 L
.236 .51551 L
.24 .5155 L
.244 .5155 L
.248 .5155 L
.252 .5155 L
.256 .51551 L
.26 .5155 L
.264 .5155 L
.268 .5155 L
.272 .5155 L
.276 .51551 L
.28 .5155 L
.284 .5155 L
.288 .5155 L
.292 .5155 L
.296 .5155 L
.3 .5155 L
.304 .5155 L
.308 .5155 L
.312 .5155 L
.316 .5155 L
.32 .5155 L
.324 .51549 L
.328 .5155 L
.332 .5155 L
.336 .5155 L
.34 .5155 L
.344 .51549 L
.348 .51549 L
.352 .5155 L
.356 .5155 L
.36 .5155 L
.364 .51549 L
.368 .51549 L
.372 .5155 L
.376 .5155 L
.38 .5155 L
.384 .51549 L
.388 .51549 L
.392 .51549 L
.396 .5155 L
.4 .51551 L
Mistroke
.404 .5155 L
.408 .51549 L
.412 .51548 L
.416 .51549 L
.42 .51551 L
.424 .51551 L
.428 .51549 L
.432 .51548 L
.436 .51548 L
.44 .5155 L
.444 .51551 L
.448 .51551 L
.452 .51548 L
.456 .51546 L
.46 .51547 L
.464 .5155 L
.468 .51552 L
.472 .51551 L
.476 .51547 L
.48 .51545 L
.484 .51547 L
.488 .51551 L
.492 .51553 L
.496 .51551 L
.5 .51546 L
.504 .51543 L
.508 .51546 L
.512 .51552 L
.516 .51555 L
.52 .51551 L
.524 .51544 L
.528 .51541 L
.532 .51545 L
.536 .51552 L
.54 .51556 L
.544 .51553 L
.548 .51545 L
.552 .51539 L
.556 .51542 L
.56 .5155 L
.564 .51557 L
.568 .51556 L
.572 .51548 L
.576 .51539 L
.58 .51538 L
.584 .51545 L
.588 .51555 L
.592 .51559 L
.596 .51554 L
.6 .51543 L
Mistroke
.604 .51536 L
.608 .51538 L
.612 .51547 L
.616 .51557 L
.62 .51559 L
.624 .51553 L
.628 .51543 L
.632 .51536 L
.636 .51537 L
.64 .51544 L
.644 .51553 L
.648 .51559 L
.652 .51557 L
.656 .51549 L
.66 .5154 L
.664 .51534 L
.668 .51535 L
.672 .51543 L
.676 .51555 L
.68 .51563 L
.684 .51563 L
.688 .51553 L
.692 .51537 L
.696 .51525 L
.7 .51524 L
.704 .51537 L
.708 .51558 L
.712 .51575 L
.716 .51577 L
.72 .5156 L
.724 .51533 L
.728 .5151 L
.732 .51506 L
.736 .51524 L
.74 .51557 L
.744 .51586 L
.748 .51596 L
.752 .5158 L
.756 .51545 L
.76 .51508 L
.764 .51489 L
.768 .51497 L
.772 .51528 L
.776 .51568 L
.78 .51598 L
.784 .51605 L
.788 .51587 L
.792 .51553 L
.796 .51517 L
.8 .51493 L
Mistroke
.804 .51486 L
.808 .51497 L
.812 .5152 L
.816 .51548 L
.82 .51573 L
.824 .5159 L
.828 .51594 L
.832 .51581 L
.836 .51548 L
.84 .51496 L
.844 .51433 L
.848 .51369 L
.852 .51318 L
.856 .51291 L
.86 .51291 L
.864 .51308 L
.868 .51324 L
.872 .51312 L
.876 .51249 L
.88 .51121 L
.884 .50926 L
.888 .50677 L
.892 .50396 L
.896 .50107 L
.9 .49831 L
.904 .49583 L
.908 .49363 L
.912 .4917 L
.916 .48995 L
.92 .48836 L
.924 .48687 L
.928 .48551 L
.932 .48428 L
.936 .48317 L
.94 .48209 L
.944 .48089 L
.948 .4794 L
.952 .47739 L
.956 .47468 L
.96 .47117 L
.964 .46682 L
.968 .46175 L
.972 .45606 L
.976 .45003 L
.98 .44377 L
.984 .43753 L
.988 .4313 L
.992 .42517 L
.996 .41903 L
1 .41282 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43191 L
.012 .43005 L
.016 .42925 L
.02 .42963 L
.024 .42993 L
.028 .42975 L
.032 .42961 L
.036 .42956 L
.04 .42959 L
.044 .42952 L
.048 .42948 L
.052 .42942 L
.056 .4294 L
.06 .42934 L
.064 .42931 L
.068 .42925 L
.072 .42922 L
.076 .42916 L
.08 .42913 L
.084 .42907 L
.088 .42904 L
.092 .42899 L
.096 .42895 L
.1 .4289 L
.104 .42886 L
.108 .42881 L
.112 .42877 L
.116 .42872 L
.12 .42868 L
.124 .42864 L
.128 .4286 L
.132 .42855 L
.136 .42851 L
.14 .42846 L
.144 .42842 L
.148 .42837 L
.152 .42833 L
.156 .42828 L
.16 .42824 L
.164 .4282 L
.168 .42816 L
.172 .42811 L
.176 .42807 L
.18 .42802 L
.184 .42798 L
.188 .42793 L
.192 .42789 L
.196 .42785 L
.2 .4278 L
Mistroke
.204 .42776 L
.208 .42771 L
.212 .42767 L
.216 .42763 L
.22 .42758 L
.224 .42754 L
.228 .42749 L
.232 .42745 L
.236 .42741 L
.24 .42736 L
.244 .42732 L
.248 .42727 L
.252 .42723 L
.256 .42719 L
.26 .42714 L
.264 .42709 L
.268 .42705 L
.272 .42701 L
.276 .42697 L
.28 .42692 L
.284 .42687 L
.288 .42683 L
.292 .42679 L
.296 .42675 L
.3 .4267 L
.304 .42665 L
.308 .42661 L
.312 .42657 L
.316 .42653 L
.32 .42648 L
.324 .42643 L
.328 .42639 L
.332 .42635 L
.336 .42631 L
.34 .42626 L
.344 .42621 L
.348 .42617 L
.352 .42613 L
.356 .42609 L
.36 .42605 L
.364 .42599 L
.368 .42594 L
.372 .42591 L
.376 .42587 L
.38 .42583 L
.384 .42577 L
.388 .42572 L
.392 .42568 L
.396 .42565 L
.4 .42562 L
Mistroke
.404 .42556 L
.408 .4255 L
.412 .42545 L
.416 .42542 L
.42 .4254 L
.424 .42535 L
.428 .42529 L
.432 .42523 L
.436 .42518 L
.44 .42517 L
.444 .42514 L
.448 .42509 L
.452 .42502 L
.456 .42495 L
.46 .42492 L
.464 .42491 L
.468 .42489 L
.472 .42483 L
.476 .42474 L
.48 .42467 L
.484 .42465 L
.488 .42466 L
.492 .42464 L
.496 .42457 L
.5 .42446 L
.504 .42439 L
.508 .42439 L
.512 .42441 L
.516 .4244 L
.52 .42431 L
.524 .42419 L
.528 .4241 L
.532 .4241 L
.536 .42415 L
.54 .42416 L
.544 .42407 L
.548 .42393 L
.552 .42382 L
.556 .42381 L
.56 .42387 L
.564 .42391 L
.568 .42385 L
.572 .4237 L
.576 .42355 L
.58 .42349 L
.584 .42354 L
.588 .42362 L
.592 .42363 L
.596 .42352 L
.6 .42334 L
Mistroke
.604 .42321 L
.608 .42319 L
.612 .42326 L
.616 .42334 L
.62 .42332 L
.624 .4232 L
.628 .42304 L
.632 .42291 L
.636 .42288 L
.64 .42292 L
.644 .42299 L
.648 .42301 L
.652 .42295 L
.656 .42281 L
.66 .42265 L
.664 .42254 L
.668 .42251 L
.672 .42256 L
.676 .42266 L
.68 .42272 L
.684 .42267 L
.688 .4225 L
.692 .42227 L
.696 .42207 L
.7 .42202 L
.704 .42214 L
.708 .42236 L
.712 .42253 L
.716 .4225 L
.72 .42225 L
.724 .42187 L
.728 .42154 L
.732 .42144 L
.736 .42163 L
.74 .42199 L
.744 .42232 L
.748 .4224 L
.752 .42215 L
.756 .42167 L
.76 .42117 L
.764 .42088 L
.768 .42094 L
.772 .42129 L
.776 .42174 L
.78 .42207 L
.784 .42212 L
.788 .42185 L
.792 .42139 L
.796 .42091 L
.8 .42058 L
Mistroke
.804 .42047 L
.808 .42058 L
.812 .42086 L
.816 .42121 L
.82 .42154 L
.824 .4218 L
.828 .42192 L
.832 .42188 L
.836 .42165 L
.84 .42126 L
.844 .42083 L
.848 .42051 L
.852 .4205 L
.856 .42099 L
.86 .42203 L
.864 .42356 L
.868 .42538 L
.872 .42722 L
.876 .42883 L
.88 .43007 L
.884 .43097 L
.888 .43168 L
.892 .4325 L
.896 .43371 L
.9 .43554 L
.904 .43809 L
.908 .44131 L
.912 .44506 L
.916 .44914 L
.92 .45337 L
.924 .45759 L
.928 .46172 L
.932 .46569 L
.936 .46944 L
.94 .47289 L
.944 .47588 L
.948 .47829 L
.952 .47994 L
.956 .48075 L
.96 .4807 L
.964 .47985 L
.968 .4784 L
.972 .47647 L
.976 .47437 L
.98 .47211 L
.984 .46988 L
.988 .46754 L
.992 .46508 L
.996 .4623 L
1 .4591 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo04Eoo`03001oogoo0080029oo`008Woo0P009goo00H007oo001oo`00Ool200001Goo001o
o`00Ool00P0000=oo`00Ool00P0000Aoo`00001oo`800003Ool0000000@00004Ool00000Ool30003
Ool2000IOol0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00002Ool01@00Oomoogoo00000goo0P000Woo00<007ooOol0
0P000goo0P0000=oo`0000000goo00D007ooOomoo`0000=oo`03001oogoo00Yoo`008Woo0P00D7oo
0P0000=oo`00Ool067oo000ROol00`00Oomoo`1BOol00`00Oomoo`04Ool00`00Oomoo`0@Ool0029o
o`8005=oo`03001oogoo00=oo`80019oo`008Woo0P00E7oo00@007ooOomoo`<0019oo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0Dgoo00<007ooOol00P0000=oo`00Ool0
4Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8005Aoo`04001oogoo
0003Ool00`00Oomoo`0?Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00E7oo00<007oo000017oo00<007ooOol03goo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo05Aoo`8000Aoo`03001oogoo00moo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001EOol00`00Oomoo`03Ool00`00Oomoo`0?Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00Fgoo00<007ooOol03goo000;Ool2000:
Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1KOol00`00Oomoo`0>Ool000]oo`8000Aoo`03001o
ogoo00=oo`80009oo`D0009oo`8005aoo`03001oogoo00ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`000Woo0P00G7oo00<007ooOol03Woo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo05]oo`03001oogoo00ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0004Ool01000Oomoogoo0P00G7oo00<007ooOol03Woo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool00`00Oomoo`02001LOol00`00Oomoo`0>Ool000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001MOol00`00Oomoo`0>Ool000]oo`8000Yoo`80
00=oo`<000=oo`8005eoo`03001oogoo00eoo`008Woo00<007ooOol0G7oo100037oo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool2001NOol00`00Oomoo`0<Ool000Yoo`04001oogoo0008
Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo
0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eo
o`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`80
06eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo0000
0goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool0
0`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=o
o`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04
Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007oo
Ool0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003
Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003
Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool2
0002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool0
1000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05
001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0
009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo
Ool01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Ao
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009o
o`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo
0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool0
00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04
001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool0
1000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol0
00Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@0
07ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<0
07ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`00
0goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`00
0goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol00P00FGoo0P0037oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001o
o`040003Ool00`00Oomoo`1GOol2000=Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0006Ool00`00Oomoo`1GOol00`00Oomoo`0<Ool000]oo`8000Yoo`8000Aoo`80009o
o`D0009oo`03001oogoo05Ioo`03001oogoo00eoo`00:7oo00<007ooOol0EWoo00<007ooOol03Goo
000XOol00`00Oomoo`1DOol2000@Ool0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03
001oogoo055oo`@0015oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1?Ool3000DOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0CWoo0P005Woo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
oe8001Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:
Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo0000
0goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool0
0`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<0
07ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004
Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool0
0`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool0
1000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007oo
Ool0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool3
0004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05
001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001o
ogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol0
00Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomo
ogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001o
ogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomo
ogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=o
o`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool5
0003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001ao
o`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00
Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo
10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool2
0008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`0_OolY000J
Ool001Moo`03001oogoo009ooc8002Qoo`@001Moo`005goo00<007ooOol00Woo00<007ooOol0FWoo
0P005Woo000GOol00`00Oomoo`02Ool00`00Oomoo`1KOol2000EOol001Ioo`8000Aoo`8005ioo`03
001oogoo00Aoo`8000aoo`005goo00<007ooOol00Woo00<007ooOol0GWoo00@007ooOomoo`<000eo
o`0077oo00<007ooOol0Ggoo10003goo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo
0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;
Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol0
00]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<0
07ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo
00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(7014\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29789 m
.008 .29897 L
.012 .3006 L
.016 .30082 L
.02 .29962 L
.024 .29935 L
.028 .29998 L
.032 .30012 L
.036 .29982 L
.04 .29974 L
.044 .29986 L
.048 .29989 L
.052 .29983 L
.056 .29981 L
.06 .29982 L
.064 .29983 L
.068 .29982 L
.072 .2998 L
.076 .29979 L
.08 .29979 L
.084 .2998 L
.088 .29978 L
.092 .29977 L
.096 .29977 L
.1 .29978 L
.104 .29976 L
.108 .29974 L
.112 .29974 L
.116 .29976 L
.12 .29974 L
.124 .29971 L
.128 .2997 L
.132 .29973 L
.136 .29973 L
.14 .29969 L
.144 .29967 L
.148 .2997 L
.152 .29972 L
.156 .29968 L
.16 .29964 L
.164 .29965 L
.168 .29969 L
.172 .29968 L
.176 .29962 L
.18 .2996 L
.184 .29965 L
.188 .29968 L
.192 .29962 L
.196 .29956 L
.2 .29959 L
Mistroke
.204 .29966 L
.208 .29964 L
.212 .29955 L
.216 .29952 L
.22 .2996 L
.224 .29966 L
.228 .29958 L
.232 .29948 L
.236 .2995 L
.24 .29962 L
.244 .29963 L
.248 .29951 L
.252 .29942 L
.256 .2995 L
.26 .29963 L
.264 .2996 L
.268 .29943 L
.272 .29938 L
.276 .29951 L
.28 .29963 L
.284 .29955 L
.288 .29937 L
.292 .29934 L
.296 .29951 L
.3 .29963 L
.304 .29951 L
.308 .29931 L
.312 .29929 L
.316 .29949 L
.32 .29962 L
.324 .29949 L
.328 .29927 L
.332 .29924 L
.336 .29944 L
.34 .29961 L
.344 .2995 L
.348 .29925 L
.352 .29917 L
.356 .29936 L
.36 .29958 L
.364 .29954 L
.368 .29928 L
.372 .2991 L
.376 .29922 L
.38 .29951 L
.384 .2996 L
.388 .29938 L
.392 .29907 L
.396 .29904 L
.4 .29933 L
Mistroke
.404 .29963 L
.408 .29957 L
.412 .29917 L
.416 .29887 L
.42 .29903 L
.424 .29951 L
.428 .29978 L
.432 .29947 L
.436 .29887 L
.44 .29864 L
.444 .29911 L
.448 .2998 L
.452 .29993 L
.456 .29925 L
.46 .29844 L
.464 .29843 L
.468 .29933 L
.472 .30021 L
.476 .30004 L
.48 .29888 L
.484 .29791 L
.488 .29826 L
.492 .29969 L
.496 .3007 L
.5 .30013 L
.504 .29842 L
.508 .29732 L
.512 .29808 L
.516 .30006 L
.52 .30125 L
.524 .30031 L
.528 .29803 L
.532 .29667 L
.536 .29771 L
.54 .30025 L
.544 .30183 L
.548 .30078 L
.552 .29797 L
.556 .29606 L
.56 .29697 L
.564 .29995 L
.568 .30225 L
.572 .30165 L
.576 .29859 L
.58 .29582 L
.584 .29588 L
.588 .29879 L
.592 .30199 L
.596 .30264 L
.6 .30015 L
Mistroke
.604 .29666 L
.608 .29512 L
.612 .29681 L
.616 .30027 L
.62 .30263 L
.624 .30205 L
.628 .2991 L
.632 .29616 L
.636 .29544 L
.64 .2973 L
.644 .3002 L
.648 .30203 L
.652 .30166 L
.656 .29959 L
.66 .2973 L
.664 .29613 L
.668 .29659 L
.672 .29823 L
.676 .3002 L
.68 .30156 L
.684 .30168 L
.688 .30033 L
.692 .29791 L
.696 .29552 L
.7 .29463 L
.704 .2962 L
.708 .29984 L
.712 .30365 L
.716 .30512 L
.72 .30277 L
.724 .29741 L
.728 .29202 L
.732 .29011 L
.736 .29344 L
.74 .3006 L
.744 .30755 L
.748 .30998 L
.752 .30594 L
.756 .29731 L
.76 .28883 L
.764 .28545 L
.768 .28939 L
.772 .29875 L
.776 .3086 L
.78 .3137 L
.784 .31141 L
.788 .30307 L
.792 .29315 L
.796 .28674 L
.8 .28694 L
Mistroke
.804 .2935 L
.808 .30329 L
.812 .31222 L
.816 .31733 L
.82 .31798 L
.824 .31571 L
.828 .31299 L
.832 .31189 L
.836 .31331 L
.84 .31712 L
.844 .3229 L
.848 .3306 L
.852 .34057 L
.856 .35314 L
.86 .36766 L
.864 .38221 L
.868 .39379 L
.872 .39953 L
.876 .3979 L
.88 .38979 L
.884 .3784 L
.888 .36821 L
.892 .36336 L
.896 .36589 L
.9 .37514 L
.904 .38765 L
.908 .39893 L
.912 .40466 L
.916 .40273 L
.92 .39352 L
.924 .37975 L
.928 .36544 L
.932 .35392 L
.936 .34751 L
.94 .34575 L
.944 .34723 L
.948 .34903 L
.952 .34914 L
.956 .34687 L
.96 .3428 L
.964 .33996 L
.968 .34061 L
.972 .34798 L
.976 .3628 L
.98 .38428 L
.984 .41052 L
.988 .43662 L
.992 .46014 L
.996 .47635 L
1 .48454 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51191 m
.008 .51513 L
.012 .51634 L
.016 .5154 L
.02 .51497 L
.024 .51519 L
.028 .51539 L
.032 .51531 L
.036 .51526 L
.04 .51526 L
.044 .5153 L
.048 .51528 L
.052 .51529 L
.056 .51527 L
.06 .51529 L
.064 .51528 L
.068 .51529 L
.072 .51528 L
.076 .51529 L
.08 .51528 L
.084 .51528 L
.088 .51528 L
.092 .51528 L
.096 .51528 L
.1 .51528 L
.104 .51528 L
.108 .51528 L
.112 .51528 L
.116 .51528 L
.12 .51528 L
.124 .51528 L
.128 .51528 L
.132 .51528 L
.136 .51528 L
.14 .51528 L
.144 .51528 L
.148 .51528 L
.152 .51528 L
.156 .51528 L
.16 .51528 L
.164 .51528 L
.168 .51528 L
.172 .51528 L
.176 .51528 L
.18 .51528 L
.184 .51528 L
.188 .51528 L
.192 .51528 L
.196 .51528 L
.2 .51528 L
Mistroke
.204 .51528 L
.208 .51528 L
.212 .51528 L
.216 .51528 L
.22 .51528 L
.224 .51528 L
.228 .51528 L
.232 .51528 L
.236 .51528 L
.24 .51528 L
.244 .51528 L
.248 .51527 L
.252 .51528 L
.256 .51528 L
.26 .51528 L
.264 .51527 L
.268 .51527 L
.272 .51528 L
.276 .51528 L
.28 .51528 L
.284 .51527 L
.288 .51527 L
.292 .51528 L
.296 .51528 L
.3 .51527 L
.304 .51527 L
.308 .51527 L
.312 .51527 L
.316 .51528 L
.32 .51527 L
.324 .51527 L
.328 .51527 L
.332 .51527 L
.336 .51528 L
.34 .51527 L
.344 .51527 L
.348 .51527 L
.352 .51527 L
.356 .51528 L
.36 .51527 L
.364 .51527 L
.368 .51526 L
.372 .51527 L
.376 .51528 L
.38 .51527 L
.384 .51527 L
.388 .51526 L
.392 .51526 L
.396 .51527 L
.4 .51528 L
Mistroke
.404 .51527 L
.408 .51526 L
.412 .51526 L
.416 .51527 L
.42 .51528 L
.424 .51528 L
.428 .51526 L
.432 .51525 L
.436 .51526 L
.44 .51527 L
.444 .51528 L
.448 .51527 L
.452 .51525 L
.456 .51524 L
.46 .51526 L
.464 .51528 L
.468 .51529 L
.472 .51527 L
.476 .51524 L
.48 .51523 L
.484 .51526 L
.488 .51529 L
.492 .51529 L
.496 .51526 L
.5 .51522 L
.504 .51522 L
.508 .51526 L
.512 .5153 L
.516 .5153 L
.52 .51525 L
.524 .51521 L
.528 .51521 L
.532 .51526 L
.536 .51531 L
.54 .51531 L
.544 .51526 L
.548 .51519 L
.552 .51519 L
.556 .51525 L
.56 .51532 L
.564 .51533 L
.568 .51527 L
.572 .51519 L
.576 .51516 L
.58 .51521 L
.584 .5153 L
.588 .51535 L
.592 .51531 L
.596 .51522 L
.6 .51515 L
Mistroke
.604 .51516 L
.608 .51525 L
.612 .51534 L
.616 .51535 L
.62 .51529 L
.624 .51519 L
.628 .51514 L
.632 .51517 L
.636 .51526 L
.64 .51534 L
.644 .51535 L
.648 .51529 L
.652 .5152 L
.656 .51514 L
.66 .51515 L
.664 .51521 L
.668 .5153 L
.672 .51535 L
.676 .51534 L
.68 .51527 L
.684 .51518 L
.688 .51511 L
.692 .51511 L
.696 .51519 L
.7 .51531 L
.704 .51541 L
.708 .51541 L
.712 .51531 L
.716 .51515 L
.72 .51501 L
.724 .51499 L
.728 .51512 L
.732 .51534 L
.736 .51553 L
.74 .51556 L
.744 .5154 L
.748 .51512 L
.752 .51487 L
.756 .51481 L
.76 .51497 L
.764 .51529 L
.768 .5156 L
.772 .51573 L
.776 .51559 L
.78 .51525 L
.784 .51487 L
.788 .51463 L
.792 .51464 L
.796 .51487 L
.8 .5152 L
Mistroke
.804 .51546 L
.808 .51549 L
.812 .51527 L
.816 .51483 L
.82 .5143 L
.824 .51378 L
.828 .51334 L
.832 .51297 L
.836 .51264 L
.84 .51226 L
.844 .51178 L
.848 .51111 L
.852 .51017 L
.856 .50891 L
.86 .50726 L
.864 .50522 L
.868 .50285 L
.872 .50029 L
.876 .4977 L
.88 .49528 L
.884 .49312 L
.888 .49126 L
.892 .48956 L
.896 .48787 L
.9 .486 L
.904 .4838 L
.908 .48126 L
.912 .47846 L
.916 .47559 L
.92 .47284 L
.924 .47038 L
.928 .4683 L
.932 .46657 L
.936 .46513 L
.94 .46383 L
.944 .4626 L
.948 .46134 L
.952 .46011 L
.956 .45887 L
.96 .45771 L
.964 .45656 L
.968 .45538 L
.972 .45402 L
.976 .45231 L
.98 .45007 L
.984 .44718 L
.988 .44354 L
.992 .43929 L
.996 .43442 L
1 .42932 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42593 L
.012 .42996 L
.016 .43122 L
.02 .4297 L
.024 .42928 L
.028 .42971 L
.032 .42983 L
.036 .42958 L
.04 .42952 L
.044 .42951 L
.048 .42951 L
.052 .42942 L
.056 .42939 L
.06 .42934 L
.064 .42931 L
.068 .42925 L
.072 .42922 L
.076 .42916 L
.08 .42913 L
.084 .42908 L
.088 .42904 L
.092 .42899 L
.096 .42895 L
.1 .4289 L
.104 .42886 L
.108 .42881 L
.112 .42877 L
.116 .42873 L
.12 .42869 L
.124 .42864 L
.128 .4286 L
.132 .42855 L
.136 .42851 L
.14 .42846 L
.144 .42842 L
.148 .42837 L
.152 .42833 L
.156 .42829 L
.16 .42824 L
.164 .4282 L
.168 .42816 L
.172 .42811 L
.176 .42807 L
.18 .42802 L
.184 .42798 L
.188 .42793 L
.192 .42789 L
.196 .42785 L
.2 .42781 L
Mistroke
.204 .42776 L
.208 .42771 L
.212 .42767 L
.216 .42763 L
.22 .42758 L
.224 .42754 L
.228 .42749 L
.232 .42745 L
.236 .42741 L
.24 .42737 L
.244 .42732 L
.248 .42727 L
.252 .42723 L
.256 .42719 L
.26 .42714 L
.264 .4271 L
.268 .42705 L
.272 .42701 L
.276 .42697 L
.28 .42692 L
.284 .42688 L
.288 .42683 L
.292 .42679 L
.296 .42675 L
.3 .4267 L
.304 .42665 L
.308 .42661 L
.312 .42657 L
.316 .42653 L
.32 .42648 L
.324 .42643 L
.328 .42639 L
.332 .42635 L
.336 .42631 L
.34 .42626 L
.344 .42621 L
.348 .42617 L
.352 .42613 L
.356 .42609 L
.36 .42605 L
.364 .42599 L
.368 .42595 L
.372 .42591 L
.376 .42587 L
.38 .42583 L
.384 .42578 L
.388 .42573 L
.392 .42569 L
.396 .42565 L
.4 .42561 L
Mistroke
.404 .42556 L
.408 .4255 L
.412 .42546 L
.416 .42543 L
.42 .4254 L
.424 .42535 L
.428 .42529 L
.432 .42523 L
.436 .4252 L
.44 .42517 L
.444 .42514 L
.448 .42509 L
.452 .42502 L
.456 .42496 L
.46 .42493 L
.464 .42492 L
.468 .42488 L
.472 .42482 L
.476 .42474 L
.48 .42469 L
.484 .42468 L
.488 .42467 L
.492 .42463 L
.496 .42455 L
.5 .42446 L
.504 .42441 L
.508 .42442 L
.512 .42442 L
.516 .42438 L
.52 .42428 L
.524 .42418 L
.528 .42414 L
.532 .42416 L
.536 .42418 L
.54 .42413 L
.544 .42402 L
.548 .4239 L
.552 .42385 L
.556 .42388 L
.56 .42392 L
.564 .4239 L
.568 .42378 L
.572 .42364 L
.576 .42356 L
.58 .42357 L
.584 .42364 L
.588 .42366 L
.592 .42357 L
.596 .42341 L
.6 .42328 L
Mistroke
.604 .42325 L
.608 .42331 L
.612 .42338 L
.616 .42336 L
.62 .42323 L
.624 .42307 L
.628 .42296 L
.632 .42295 L
.636 .42302 L
.64 .42308 L
.644 .42305 L
.648 .42293 L
.652 .42278 L
.656 .42266 L
.66 .42262 L
.664 .42266 L
.668 .42273 L
.672 .42275 L
.676 .42269 L
.68 .42256 L
.684 .4224 L
.688 .42227 L
.692 .42223 L
.696 .42229 L
.7 .42239 L
.704 .42247 L
.708 .42243 L
.712 .42226 L
.716 .42201 L
.72 .4218 L
.724 .42173 L
.728 .42186 L
.732 .42209 L
.736 .42228 L
.74 .42227 L
.744 .42203 L
.748 .42164 L
.752 .42129 L
.756 .42116 L
.76 .42133 L
.764 .42169 L
.768 .42204 L
.772 .42216 L
.776 .42196 L
.78 .42151 L
.784 .42102 L
.788 .42072 L
.792 .42075 L
.796 .42109 L
.8 .42157 L
Mistroke
.804 .422 L
.808 .42221 L
.812 .42217 L
.816 .42196 L
.82 .42174 L
.824 .42168 L
.828 .42189 L
.832 .42242 L
.836 .42324 L
.84 .42431 L
.844 .42559 L
.848 .42702 L
.852 .42856 L
.856 .43016 L
.86 .43176 L
.864 .43338 L
.868 .43507 L
.872 .43698 L
.876 .43928 L
.88 .44211 L
.884 .44552 L
.888 .44941 L
.892 .45354 L
.896 .45757 L
.9 .46115 L
.904 .46404 L
.908 .46616 L
.912 .4676 L
.916 .46862 L
.92 .46953 L
.924 .47066 L
.928 .47222 L
.932 .47432 L
.936 .47697 L
.94 .48007 L
.944 .48356 L
.948 .48728 L
.952 .49122 L
.956 .49522 L
.96 .49925 L
.964 .50311 L
.968 .50665 L
.972 .50964 L
.976 .51186 L
.98 .51317 L
.984 .51349 L
.988 .5128 L
.992 .51133 L
.996 .50907 L
1 .50644 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo04Qoo`04001oogoo000POol0029oo`8002Uoo`04001oo`00Ool400000goo001oo`040000
1Woo000007oo001oo`<00004Ool00000Ool2000017oo000007oo0P0087oo000ROomS000<Ool0029o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`04001oogoo0003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000Woo00D007ooOomoo`0000=oo`03001oogoo00800003Ool0000000D000=oo`05001oogooOol0
0003Ool01@00Oomoogoo000037oo000ROol2001@Ool00`00Oomoo`0JOol0029oo`03001oogoo051o
o`03001oogoo01Uoo`008Woo0P00DGoo00<007ooOol01Goo1@003goo000ROol2001BOol00`00Oomo
o`04Ool01@00Oomoogoo00003goo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00
Oomoo`1AOol01000Oomoo`000goo00D007ooOomoo`0000moo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2001BOol01`00Ool007oo001oo`0000Aoo`03001oogoo00eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001BOol01`00Ool007oo001o
o`0000Eoo`03001oogoo00aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1BOol01000Oomoogoo0P001Goo00<007ooOol037oo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8005Moo`03001oogoo00Aoo`03001oogoo00aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001NOol00`00Oomoo`0<Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`03001oogoo05eoo`03001oogoo00aoo`002goo0P0017oo00<007oo
Ool00goo0P000Woo1@000Woo0P00GWoo00<007ooOol037oo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`04001oogoo0002Ool2001NOol00`00Oomoo`0<Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0GWoo00<007ooOol02goo000:Ool01000Oomoo`00
27oo00@007ooOol000Aoo`04001oogooOol2001OOol00`00Oomoo`0;Ool000Yoo`04001oogoo0008
Ool01P00Oomoo`00Ool000=oo`03001oogoo008005moo`03001oogoo00]oo`002Woo00@007ooOol0
00Qoo`06001oogoo001oo`000goo00@007ooOol0065oo`03001oogoo00Yoo`002goo0P002Woo0P00
0goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eo
o`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol0
06ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06ao
o`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo
00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007oo
Ool0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Io
o`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo
009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Ao
o`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<0
00Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<0
00Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo
00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`00
00Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009o
o`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<0
07ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol0
2Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<0
07ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo
00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008
Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo
0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?
Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004
Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo05Uoo`03001oogoo00Yoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo05Moo`8000eo
o`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0EWoo0P003Woo000XOol00`00Oomo
o`1COol3000@Ool002Qoo`03001oogoo055oo`8001=oo`004Goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo00<007ooOol0Cgoo0`0057oo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo04eoo`<001Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1;Ool3000HOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00WooC`006Woo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1V
Ool0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05
001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomo
o`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]o
o`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
00]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02
001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool5
0002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`80
00Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`00
77oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomo
o`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo
00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003
Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomo
ogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0
00Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007oo
Ool017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<0
07ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0
00Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo
00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`80
00Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001ao
ofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007oo
Ool000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04
001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2
001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001o
ogoo02moobH001eoo`005goo00<007ooOol00Woo<`0097oo10006Woo000GOol00`00Oomoo`02Ool0
0`00Oomoo`1GOol2000IOol001Moo`03001oogoo009oo`03001oogoo05Uoo`03001oogoo01Ioo`00
5Woo0P0017oo0P00Fgoo00<007ooOol05Goo000GOol00`00Oomoo`02Ool00`00Oomoo`1KOol3000D
Ool001aoo`03001oogoo05ioo`03001oogoo015oo`0077oo0P00H7oo0P004Goo000LOol00`00Oomo
o`1POol00`00Oomoo`0?Ool001aoo`80069oo`800003Ool0000000aoo`0077oo00<007ooOol0HWoo
0P003Woo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`00
2goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo
00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07
Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo
00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(7181\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .2987 m
.008 .30003 L
.012 .30021 L
.016 .30022 L
.02 .29993 L
.024 .29972 L
.028 .29985 L
.032 .29999 L
.036 .29994 L
.04 .29985 L
.044 .29985 L
.048 .29989 L
.052 .29989 L
.056 .29986 L
.06 .29985 L
.064 .29985 L
.068 .29986 L
.072 .29984 L
.076 .29983 L
.08 .29983 L
.084 .29983 L
.088 .29982 L
.092 .2998 L
.096 .2998 L
.1 .29981 L
.104 .2998 L
.108 .29978 L
.112 .29977 L
.116 .29979 L
.12 .29978 L
.124 .29975 L
.128 .29974 L
.132 .29976 L
.136 .29976 L
.14 .29974 L
.144 .29971 L
.148 .29972 L
.152 .29974 L
.156 .29973 L
.16 .29968 L
.164 .29968 L
.168 .29972 L
.172 .29972 L
.176 .29967 L
.18 .29964 L
.184 .29967 L
.188 .29971 L
.192 .29967 L
.196 .29961 L
.2 .29961 L
Mistroke
.204 .29968 L
.208 .29969 L
.212 .29961 L
.216 .29956 L
.22 .29962 L
.224 .29968 L
.228 .29964 L
.232 .29954 L
.236 .29953 L
.24 .29963 L
.244 .29967 L
.248 .29957 L
.252 .29947 L
.256 .29952 L
.26 .29964 L
.264 .29964 L
.268 .2995 L
.272 .29942 L
.276 .29952 L
.28 .29964 L
.284 .2996 L
.288 .29943 L
.292 .29938 L
.296 .29951 L
.3 .29964 L
.304 .29956 L
.308 .29937 L
.312 .29934 L
.316 .2995 L
.32 .29963 L
.324 .29953 L
.328 .29933 L
.332 .29929 L
.336 .29947 L
.34 .29962 L
.344 .29953 L
.348 .2993 L
.352 .29923 L
.356 .2994 L
.36 .2996 L
.364 .29955 L
.368 .29931 L
.372 .29916 L
.376 .29929 L
.38 .29954 L
.384 .29959 L
.388 .29937 L
.392 .29912 L
.396 .29914 L
.4 .29942 L
Mistroke
.404 .29963 L
.408 .29951 L
.412 .29917 L
.416 .29898 L
.42 .29918 L
.424 .29957 L
.428 .29969 L
.432 .29936 L
.436 .29891 L
.44 .29885 L
.444 .29931 L
.448 .2998 L
.452 .29973 L
.456 .2991 L
.46 .29857 L
.464 .29877 L
.468 .29957 L
.472 .30009 L
.476 .29969 L
.48 .29869 L
.484 .29818 L
.488 .2988 L
.492 .29997 L
.496 .30042 L
.5 .29954 L
.504 .29816 L
.508 .29776 L
.512 .29889 L
.516 .30046 L
.52 .30079 L
.524 .29939 L
.528 .29759 L
.532 .29728 L
.536 .29892 L
.54 .30094 L
.544 .30126 L
.548 .29939 L
.552 .2971 L
.556 .29667 L
.56 .29867 L
.564 .30125 L
.568 .30188 L
.572 .29982 L
.576 .29692 L
.58 .29593 L
.584 .29787 L
.588 .30103 L
.592 .3025 L
.596 .30086 L
.6 .29751 L
Mistroke
.604 .29544 L
.608 .29651 L
.612 .29982 L
.616 .30249 L
.62 .30222 L
.624 .29924 L
.628 .29608 L
.632 .29534 L
.636 .29755 L
.64 .30085 L
.644 .3026 L
.648 .30153 L
.652 .2986 L
.656 .2961 L
.66 .29578 L
.664 .29765 L
.668 .30024 L
.672 .30178 L
.676 .30144 L
.68 .29965 L
.684 .29758 L
.688 .29634 L
.692 .29646 L
.696 .29782 L
.7 .29984 L
.704 .30161 L
.708 .30218 L
.712 .30095 L
.716 .29818 L
.72 .29521 L
.724 .29392 L
.728 .29557 L
.732 .29975 L
.736 .30423 L
.74 .30609 L
.744 .30365 L
.748 .29781 L
.752 .29191 L
.756 .28979 L
.76 .2934 L
.764 .30128 L
.768 .30922 L
.772 .31266 L
.776 .30952 L
.78 .30161 L
.784 .2938 L
.788 .29127 L
.792 .29652 L
.796 .308 L
.8 .321 L
Mistroke
.804 .33028 L
.808 .33299 L
.812 .33009 L
.816 .32565 L
.82 .32457 L
.824 .33007 L
.828 .34213 L
.832 .35794 L
.836 .37347 L
.84 .38544 L
.844 .39254 L
.848 .3954 L
.852 .39557 L
.856 .39445 L
.86 .39258 L
.864 .38984 L
.868 .38617 L
.872 .38207 L
.876 .37883 L
.88 .37761 L
.884 .3789 L
.888 .38159 L
.892 .38346 L
.896 .38198 L
.9 .37565 L
.904 .36522 L
.908 .35337 L
.912 .34448 L
.916 .34221 L
.92 .34872 L
.924 .36292 L
.928 .38114 L
.932 .39827 L
.936 .40904 L
.94 .41077 L
.944 .4028 L
.948 .38796 L
.952 .3702 L
.956 .35354 L
.96 .34129 L
.964 .33329 L
.968 .32906 L
.972 .32519 L
.976 .31955 L
.98 .3111 L
.984 .2995 L
.988 .28875 L
.992 .28049 L
.996 .2797 L
1 .28758 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .52022 m
.008 .51495 L
.012 .51329 L
.016 .51512 L
.02 .51568 L
.024 .515 L
.028 .51485 L
.032 .51506 L
.036 .51514 L
.04 .51504 L
.044 .51504 L
.048 .51505 L
.052 .51507 L
.056 .51505 L
.06 .51506 L
.064 .51505 L
.068 .51506 L
.072 .51505 L
.076 .51506 L
.08 .51505 L
.084 .51506 L
.088 .51505 L
.092 .51506 L
.096 .51505 L
.1 .51506 L
.104 .51505 L
.108 .51506 L
.112 .51505 L
.116 .51506 L
.12 .51505 L
.124 .51505 L
.128 .51505 L
.132 .51505 L
.136 .51505 L
.14 .51505 L
.144 .51505 L
.148 .51505 L
.152 .51505 L
.156 .51505 L
.16 .51505 L
.164 .51505 L
.168 .51505 L
.172 .51505 L
.176 .51505 L
.18 .51505 L
.184 .51505 L
.188 .51505 L
.192 .51505 L
.196 .51505 L
.2 .51505 L
Mistroke
.204 .51505 L
.208 .51505 L
.212 .51505 L
.216 .51505 L
.22 .51505 L
.224 .51505 L
.228 .51505 L
.232 .51505 L
.236 .51505 L
.24 .51505 L
.244 .51505 L
.248 .51505 L
.252 .51505 L
.256 .51505 L
.26 .51505 L
.264 .51505 L
.268 .51505 L
.272 .51505 L
.276 .51505 L
.28 .51505 L
.284 .51505 L
.288 .51505 L
.292 .51505 L
.296 .51505 L
.3 .51505 L
.304 .51504 L
.308 .51504 L
.312 .51505 L
.316 .51505 L
.32 .51505 L
.324 .51504 L
.328 .51504 L
.332 .51505 L
.336 .51505 L
.34 .51505 L
.344 .51504 L
.348 .51504 L
.352 .51504 L
.356 .51505 L
.36 .51505 L
.364 .51504 L
.368 .51504 L
.372 .51504 L
.376 .51505 L
.38 .51505 L
.384 .51504 L
.388 .51503 L
.392 .51504 L
.396 .51505 L
.4 .51505 L
Mistroke
.404 .51504 L
.408 .51503 L
.412 .51503 L
.416 .51504 L
.42 .51505 L
.424 .51504 L
.428 .51503 L
.432 .51503 L
.436 .51503 L
.44 .51505 L
.444 .51505 L
.448 .51504 L
.452 .51502 L
.456 .51502 L
.46 .51504 L
.464 .51505 L
.468 .51505 L
.472 .51503 L
.476 .51501 L
.48 .51502 L
.484 .51504 L
.488 .51506 L
.492 .51505 L
.496 .51502 L
.5 .515 L
.504 .51501 L
.508 .51505 L
.512 .51507 L
.516 .51505 L
.52 .51501 L
.524 .51499 L
.528 .51501 L
.532 .51505 L
.536 .51508 L
.54 .51505 L
.544 .515 L
.548 .51497 L
.552 .515 L
.556 .51506 L
.56 .51509 L
.564 .51507 L
.568 .515 L
.572 .51495 L
.576 .51497 L
.58 .51504 L
.584 .5151 L
.588 .51509 L
.592 .51502 L
.596 .51495 L
.6 .51494 L
Mistroke
.604 .51501 L
.608 .51509 L
.612 .51512 L
.616 .51506 L
.62 .51497 L
.624 .51492 L
.628 .51495 L
.632 .51504 L
.636 .51511 L
.64 .51511 L
.644 .51504 L
.648 .51495 L
.652 .51491 L
.656 .51495 L
.66 .51504 L
.664 .51511 L
.668 .51511 L
.672 .51506 L
.676 .51497 L
.68 .51492 L
.684 .51492 L
.688 .51498 L
.692 .51506 L
.696 .51512 L
.7 .51512 L
.704 .51505 L
.708 .51495 L
.712 .51488 L
.716 .51487 L
.72 .51494 L
.724 .51507 L
.728 .51518 L
.732 .5152 L
.736 .51509 L
.74 .51491 L
.744 .51476 L
.748 .51472 L
.752 .51485 L
.756 .51507 L
.76 .51525 L
.764 .51527 L
.768 .51509 L
.772 .51476 L
.776 .51445 L
.78 .51428 L
.784 .51432 L
.788 .51449 L
.792 .51463 L
.796 .51455 L
.8 .51414 L
Mistroke
.804 .51345 L
.808 .5126 L
.812 .51175 L
.816 .51101 L
.82 .51035 L
.824 .50965 L
.828 .50874 L
.832 .50748 L
.836 .50581 L
.84 .50377 L
.844 .50146 L
.848 .49902 L
.852 .49653 L
.856 .49407 L
.86 .49168 L
.864 .48938 L
.868 .48717 L
.872 .48503 L
.876 .48295 L
.88 .48088 L
.884 .47876 L
.888 .47655 L
.892 .47429 L
.896 .47202 L
.9 .46989 L
.904 .468 L
.908 .46641 L
.912 .4651 L
.916 .46392 L
.92 .46268 L
.924 .46115 L
.928 .4592 L
.932 .45676 L
.936 .45396 L
.94 .45095 L
.944 .44801 L
.948 .44533 L
.952 .44307 L
.956 .44126 L
.96 .43987 L
.964 .43876 L
.968 .43792 L
.972 .43718 L
.976 .43668 L
.98 .43632 L
.984 .43626 L
.988 .43643 L
.992 .43683 L
.996 .43729 L
1 .43762 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42724 L
.012 .42967 L
.016 .43069 L
.02 .42989 L
.024 .42949 L
.028 .42962 L
.032 .42975 L
.036 .42962 L
.04 .42955 L
.044 .4295 L
.048 .42949 L
.052 .42943 L
.056 .42939 L
.06 .42933 L
.064 .42931 L
.068 .42925 L
.072 .42922 L
.076 .42916 L
.08 .42913 L
.084 .42908 L
.088 .42904 L
.092 .42899 L
.096 .42895 L
.1 .4289 L
.104 .42886 L
.108 .42881 L
.112 .42878 L
.116 .42873 L
.12 .42869 L
.124 .42864 L
.128 .4286 L
.132 .42855 L
.136 .42851 L
.14 .42846 L
.144 .42842 L
.148 .42838 L
.152 .42833 L
.156 .42829 L
.16 .42825 L
.164 .4282 L
.168 .42816 L
.172 .42811 L
.176 .42807 L
.18 .42802 L
.184 .42798 L
.188 .42794 L
.192 .42789 L
.196 .42785 L
.2 .42781 L
Mistroke
.204 .42776 L
.208 .42772 L
.212 .42767 L
.216 .42763 L
.22 .42759 L
.224 .42754 L
.228 .42749 L
.232 .42745 L
.236 .42741 L
.24 .42737 L
.244 .42732 L
.248 .42727 L
.252 .42723 L
.256 .42719 L
.26 .42715 L
.264 .4271 L
.268 .42705 L
.272 .42701 L
.276 .42697 L
.28 .42693 L
.284 .42688 L
.288 .42683 L
.292 .42679 L
.296 .42675 L
.3 .42671 L
.304 .42666 L
.308 .42661 L
.312 .42657 L
.316 .42653 L
.32 .42649 L
.324 .42644 L
.328 .42639 L
.332 .42636 L
.336 .42631 L
.34 .42627 L
.344 .42622 L
.348 .42617 L
.352 .42613 L
.356 .4261 L
.36 .42605 L
.364 .426 L
.368 .42595 L
.372 .42591 L
.376 .42588 L
.38 .42583 L
.384 .42578 L
.388 .42573 L
.392 .42569 L
.396 .42566 L
.4 .42561 L
Mistroke
.404 .42556 L
.408 .42551 L
.412 .42546 L
.416 .42543 L
.42 .4254 L
.424 .42535 L
.428 .42529 L
.432 .42524 L
.436 .4252 L
.44 .42518 L
.444 .42514 L
.448 .42508 L
.452 .42502 L
.456 .42497 L
.46 .42495 L
.464 .42492 L
.468 .42488 L
.472 .42481 L
.476 .42474 L
.48 .42471 L
.484 .42469 L
.488 .42467 L
.492 .42462 L
.496 .42454 L
.5 .42447 L
.504 .42444 L
.508 .42444 L
.512 .42442 L
.516 .42435 L
.52 .42426 L
.524 .42419 L
.528 .42417 L
.532 .42418 L
.536 .42417 L
.54 .4241 L
.544 .42399 L
.548 .42391 L
.552 .4239 L
.556 .42393 L
.56 .42393 L
.564 .42385 L
.568 .42373 L
.572 .42362 L
.576 .42361 L
.58 .42365 L
.584 .42368 L
.588 .42362 L
.592 .42349 L
.596 .42335 L
.6 .42331 L
Mistroke
.604 .42335 L
.608 .4234 L
.612 .42339 L
.616 .42328 L
.62 .42312 L
.624 .42302 L
.628 .42301 L
.632 .42308 L
.636 .42313 L
.64 .42308 L
.644 .42295 L
.648 .4228 L
.652 .4227 L
.656 .42271 L
.66 .42277 L
.664 .42281 L
.668 .42278 L
.672 .42267 L
.676 .42252 L
.68 .4224 L
.684 .42237 L
.688 .4224 L
.692 .42246 L
.696 .42249 L
.7 .42244 L
.704 .42231 L
.708 .42215 L
.712 .42201 L
.716 .42196 L
.72 .42201 L
.724 .42213 L
.728 .42222 L
.732 .4222 L
.736 .42203 L
.74 .42177 L
.744 .42154 L
.748 .42147 L
.752 .4216 L
.756 .42186 L
.76 .42209 L
.764 .42213 L
.768 .42193 L
.772 .42159 L
.776 .4213 L
.78 .42125 L
.784 .42152 L
.788 .42204 L
.792 .42263 L
.796 .42307 L
.8 .42329 L
Mistroke
.804 .42335 L
.808 .42345 L
.812 .42385 L
.816 .4247 L
.82 .42603 L
.824 .42773 L
.828 .42962 L
.832 .43155 L
.836 .43347 L
.84 .43541 L
.844 .43748 L
.848 .43981 L
.852 .44244 L
.856 .4454 L
.86 .4486 L
.864 .45197 L
.868 .45538 L
.872 .45873 L
.876 .46189 L
.88 .46472 L
.884 .46714 L
.888 .46912 L
.892 .47073 L
.896 .47215 L
.9 .47364 L
.904 .47547 L
.908 .47783 L
.912 .48078 L
.916 .48418 L
.92 .4878 L
.924 .49127 L
.928 .49436 L
.932 .49683 L
.936 .49871 L
.94 .50011 L
.944 .50127 L
.948 .50243 L
.952 .50381 L
.956 .50552 L
.96 .50762 L
.964 .51001 L
.968 .51269 L
.972 .51546 L
.976 .51837 L
.98 .52118 L
.984 .52394 L
.988 .52637 L
.992 .52838 L
.996 .52975 L
1 .53027 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo05ioo`8000aoo`008Woo0P00:goo00@007oo001oo`800003Ool007oo00@00003Ool007oo
00800004Ool00000Ool2000017oo000007oo0P000Woo00<007ooOol047oo00<007ooOol037oo000R
OomS000<Ool0029oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`04001oogoo0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000=oo`04001oogooOol300000goo001oo`02Ool0
1@00Oomoogoo00000goo00T007ooOomoo`00Ool007oo000037oo000ROol2001<Ool00`00Ool0000=
Ool2000?Ool0029oo`03001oogoo04]oo`<000eoo`03001oogoo00ioo`008Woo0P00Cgoo00<007oo
Ool01Goo0P000goo00<007ooOol03Woo000ROol2001?Ool00`00Oomoo`05Ool20002Ool00`00Oomo
o`0?Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo04ioo`03001oogoo
00Aoo`03001oo`00009oo`03001oogoo00moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool2001@Ool00`00Oomoo`02000017oo001oo`000Woo00<007ooOol03goo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80051oo`06001oo`00001oo`000goo
0P004Woo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo04mo
o`<000Ioo`80019oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001I
Ool2000BOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:
Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009o
o`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<0
07ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=o
o`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<0
00=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomo
ogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomo
o`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00
Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003
Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04
001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool3
0004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol0
0002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00
Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Ao
o`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04
001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<0
00=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool2
0004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001o
o`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@0
07ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P00
17oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol0
3goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol0
2Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P00
0goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001o
o`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0006Ool00`00Oomoo`1DOol6000<Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001o
ogoo05=oo`80015oo`00:7oo00<007ooOol0D7oo0`004goo000XOol00`00Oomoo`1>Ool3000EOol0
015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo04aoo`<001Moo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1;Ool2000IOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0B7oo0`006goo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009ood`001eoo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002
Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Ao
o`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool3
0004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool2
0005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`00
2Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@0
07ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eo
o`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo
00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03
001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005
Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03
001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo
000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0
LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`0`OolR000POol001Moo`03001oogoo009ooc<0029o
o`<001eoo`005goo00<007ooOol00Woo00<007ooOol0E7oo0P0077oo000GOol00`00Oomoo`02Ool0
0`00Oomoo`1FOol2000JOol001Ioo`8000Aoo`8005Qoo`8001Uoo`005goo00<007ooOol00Woo00<0
07ooOol0F7oo0`005goo000LOol00`00Oomoo`1JOol2000FOol001aoo`8005eoo`8001Aoo`0077oo
00<007ooOol0GGoo0`004Woo000LOol2001POol3000@Ool001aoo`03001oogoo065oo`8000moo`00
77oo00<007ooOol0Hgoo0`0037oo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]o
o`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04
001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo
10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03
001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(7348\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30177 m
.008 .30092 L
.012 .29931 L
.016 .29909 L
.02 .30022 L
.024 .30044 L
.028 .29983 L
.032 .2997 L
.036 .29998 L
.04 .30003 L
.044 .2999 L
.048 .29986 L
.052 .29992 L
.056 .29992 L
.06 .29989 L
.064 .29988 L
.068 .29989 L
.072 .29988 L
.076 .29986 L
.08 .29986 L
.084 .29986 L
.088 .29986 L
.092 .29984 L
.096 .29983 L
.1 .29984 L
.104 .29984 L
.108 .29982 L
.112 .2998 L
.116 .29981 L
.12 .29982 L
.124 .29979 L
.128 .29978 L
.132 .29979 L
.136 .2998 L
.14 .29978 L
.144 .29975 L
.148 .29975 L
.152 .29977 L
.156 .29977 L
.16 .29973 L
.164 .29971 L
.168 .29974 L
.172 .29976 L
.176 .29972 L
.18 .29968 L
.184 .2997 L
.188 .29974 L
.192 .29972 L
.196 .29966 L
.2 .29964 L
Mistroke
.204 .2997 L
.208 .29972 L
.212 .29966 L
.216 .2996 L
.22 .29963 L
.224 .2997 L
.228 .29968 L
.232 .2996 L
.236 .29956 L
.24 .29964 L
.244 .29969 L
.248 .29963 L
.252 .29953 L
.256 .29954 L
.26 .29965 L
.264 .29967 L
.268 .29956 L
.272 .29947 L
.276 .29953 L
.28 .29965 L
.284 .29964 L
.288 .2995 L
.292 .29942 L
.296 .29953 L
.3 .29965 L
.304 .29961 L
.308 .29944 L
.312 .29938 L
.316 .29951 L
.32 .29965 L
.324 .29958 L
.328 .29939 L
.332 .29933 L
.336 .29949 L
.34 .29963 L
.344 .29956 L
.348 .29936 L
.352 .29928 L
.356 .29944 L
.36 .29961 L
.364 .29957 L
.368 .29935 L
.372 .29922 L
.376 .29935 L
.38 .29957 L
.384 .2996 L
.388 .29938 L
.392 .29918 L
.396 .29923 L
.4 .29948 L
Mistroke
.404 .29963 L
.408 .29948 L
.412 .29919 L
.416 .29908 L
.42 .2993 L
.424 .2996 L
.428 .29963 L
.432 .29931 L
.436 .29898 L
.44 .29903 L
.444 .29944 L
.448 .29976 L
.452 .29958 L
.456 .29905 L
.46 .29873 L
.464 .29904 L
.468 .29968 L
.472 .29994 L
.476 .29944 L
.48 .29867 L
.484 .29849 L
.488 .29918 L
.492 .30005 L
.496 .30009 L
.5 .29916 L
.504 .29818 L
.508 .29827 L
.512 .29945 L
.516 .3005 L
.52 .30023 L
.524 .29878 L
.528 .29763 L
.532 .29806 L
.536 .29976 L
.54 .301 L
.544 .30041 L
.548 .29844 L
.552 .29704 L
.556 .29773 L
.56 .29995 L
.564 .30152 L
.568 .30078 L
.572 .29832 L
.576 .29648 L
.58 .29713 L
.584 .29977 L
.588 .30193 L
.592 .30148 L
.596 .29872 L
.6 .29617 L
Mistroke
.604 .29623 L
.608 .29893 L
.612 .30186 L
.616 .30235 L
.62 .2999 L
.624 .29664 L
.628 .29541 L
.632 .29731 L
.636 .30069 L
.64 .30268 L
.644 .30163 L
.648 .29845 L
.652 .29577 L
.656 .2957 L
.66 .2982 L
.664 .3012 L
.668 .30241 L
.672 .30106 L
.676 .2983 L
.68 .2962 L
.684 .2961 L
.688 .29785 L
.692 .30015 L
.696 .30155 L
.7 .30138 L
.704 .29991 L
.708 .298 L
.712 .29659 L
.716 .29637 L
.72 .29757 L
.724 .29985 L
.728 .30225 L
.732 .30347 L
.736 .30257 L
.74 .29977 L
.744 .29671 L
.748 .2957 L
.752 .29832 L
.756 .30416 L
.76 .3107 L
.764 .31472 L
.768 .31442 L
.772 .31085 L
.776 .30766 L
.78 .30908 L
.784 .31723 L
.788 .33067 L
.792 .34499 L
.796 .35532 L
.8 .35922 L
Mistroke
.804 .35816 L
.808 .35673 L
.812 .35985 L
.816 .36995 L
.82 .38534 L
.824 .40111 L
.828 .41162 L
.832 .41345 L
.836 .40691 L
.84 .39561 L
.844 .38444 L
.848 .37704 L
.852 .3745 L
.856 .37524 L
.86 .37663 L
.864 .37644 L
.868 .37412 L
.872 .37063 L
.876 .36754 L
.88 .3661 L
.884 .36636 L
.888 .36783 L
.892 .36961 L
.896 .37162 L
.9 .37428 L
.904 .37818 L
.908 .3834 L
.912 .38845 L
.916 .39119 L
.92 .38879 L
.924 .37993 L
.928 .36524 L
.932 .3475 L
.936 .33159 L
.94 .32137 L
.944 .32001 L
.948 .32684 L
.952 .33877 L
.956 .35115 L
.96 .35814 L
.964 .35739 L
.968 .34715 L
.972 .33038 L
.976 .31066 L
.98 .29189 L
.984 .27804 L
.988 .26887 L
.992 .26453 L
.996 .26227 L
1 .2597 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51917 m
.008 .51492 L
.012 .51348 L
.016 .5147 L
.02 .51527 L
.024 .51488 L
.028 .5147 L
.032 .51478 L
.036 .51488 L
.04 .51483 L
.044 .51482 L
.048 .51481 L
.052 .51484 L
.056 .51482 L
.06 .51483 L
.064 .51482 L
.068 .51483 L
.072 .51482 L
.076 .51483 L
.08 .51482 L
.084 .51483 L
.088 .51482 L
.092 .51483 L
.096 .51482 L
.1 .51483 L
.104 .51482 L
.108 .51483 L
.112 .51482 L
.116 .51483 L
.12 .51482 L
.124 .51483 L
.128 .51483 L
.132 .51483 L
.136 .51483 L
.14 .51483 L
.144 .51482 L
.148 .51483 L
.152 .51483 L
.156 .51483 L
.16 .51482 L
.164 .51483 L
.168 .51483 L
.172 .51483 L
.176 .51482 L
.18 .51483 L
.184 .51483 L
.188 .51483 L
.192 .51482 L
.196 .51482 L
.2 .51482 L
Mistroke
.204 .51483 L
.208 .51482 L
.212 .51482 L
.216 .51482 L
.22 .51482 L
.224 .51482 L
.228 .51482 L
.232 .51482 L
.236 .51482 L
.24 .51482 L
.244 .51482 L
.248 .51482 L
.252 .51482 L
.256 .51482 L
.26 .51482 L
.264 .51482 L
.268 .51482 L
.272 .51482 L
.276 .51482 L
.28 .51482 L
.284 .51482 L
.288 .51482 L
.292 .51482 L
.296 .51482 L
.3 .51482 L
.304 .51482 L
.308 .51482 L
.312 .51482 L
.316 .51482 L
.32 .51482 L
.324 .51482 L
.328 .51482 L
.332 .51482 L
.336 .51482 L
.34 .51482 L
.344 .51481 L
.348 .51481 L
.352 .51482 L
.356 .51482 L
.36 .51482 L
.364 .51481 L
.368 .51481 L
.372 .51482 L
.376 .51482 L
.38 .51482 L
.384 .51481 L
.388 .51481 L
.392 .51481 L
.396 .51482 L
.4 .51482 L
Mistroke
.404 .51481 L
.408 .51481 L
.412 .51481 L
.416 .51482 L
.42 .51482 L
.424 .51482 L
.428 .51481 L
.432 .5148 L
.436 .51481 L
.44 .51482 L
.444 .51482 L
.448 .51481 L
.452 .5148 L
.456 .5148 L
.46 .51481 L
.464 .51482 L
.468 .51482 L
.472 .5148 L
.476 .51479 L
.48 .5148 L
.484 .51482 L
.488 .51483 L
.492 .51481 L
.496 .51479 L
.5 .51478 L
.504 .5148 L
.508 .51483 L
.512 .51483 L
.516 .51481 L
.52 .51478 L
.524 .51477 L
.528 .5148 L
.532 .51483 L
.536 .51484 L
.54 .5148 L
.544 .51477 L
.548 .51476 L
.552 .5148 L
.556 .51484 L
.56 .51485 L
.564 .5148 L
.568 .51475 L
.572 .51474 L
.576 .51479 L
.58 .51485 L
.584 .51486 L
.588 .51482 L
.592 .51475 L
.596 .51472 L
.6 .51477 L
Mistroke
.604 .51484 L
.608 .51488 L
.612 .51484 L
.616 .51476 L
.62 .51471 L
.624 .51473 L
.628 .5148 L
.632 .51487 L
.636 .51488 L
.64 .51481 L
.644 .51473 L
.648 .51469 L
.652 .51474 L
.656 .51482 L
.66 .51488 L
.664 .51487 L
.668 .5148 L
.672 .51472 L
.676 .51469 L
.68 .51473 L
.684 .51481 L
.688 .51487 L
.692 .51488 L
.696 .51482 L
.7 .51474 L
.704 .51469 L
.708 .51468 L
.712 .51474 L
.716 .51481 L
.72 .51487 L
.724 .51487 L
.728 .5148 L
.732 .51468 L
.736 .51457 L
.74 .51452 L
.744 .51456 L
.748 .51464 L
.752 .51469 L
.756 .51462 L
.76 .51438 L
.764 .51402 L
.768 .51363 L
.772 .51331 L
.776 .51307 L
.78 .51285 L
.784 .5125 L
.788 .51187 L
.792 .51089 L
.796 .50961 L
.8 .50817 L
Mistroke
.804 .5067 L
.808 .50526 L
.812 .50381 L
.816 .5022 L
.82 .50026 L
.824 .49793 L
.828 .49527 L
.832 .49244 L
.836 .48966 L
.84 .4871 L
.844 .48482 L
.848 .48277 L
.852 .48085 L
.856 .47894 L
.86 .47699 L
.864 .47499 L
.868 .47298 L
.872 .47102 L
.876 .46914 L
.88 .46732 L
.884 .46555 L
.888 .4638 L
.892 .46203 L
.896 .46021 L
.9 .4583 L
.904 .45628 L
.908 .4541 L
.912 .45177 L
.916 .44933 L
.92 .44689 L
.924 .44461 L
.928 .44265 L
.932 .44112 L
.936 .44003 L
.94 .43926 L
.944 .43866 L
.948 .43797 L
.952 .43708 L
.956 .43586 L
.96 .43442 L
.964 .43288 L
.968 .43148 L
.972 .43041 L
.976 .4298 L
.98 .42971 L
.984 .43007 L
.988 .43076 L
.992 .43172 L
.996 .43277 L
1 .43397 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43344 L
.012 .42972 L
.016 .42863 L
.02 .42985 L
.024 .43018 L
.028 .42964 L
.032 .42952 L
.036 .42961 L
.04 .42963 L
.044 .4295 L
.048 .42947 L
.052 .42943 L
.056 .4294 L
.06 .42934 L
.064 .42931 L
.068 .42925 L
.072 .42922 L
.076 .42916 L
.08 .42913 L
.084 .42908 L
.088 .42904 L
.092 .42899 L
.096 .42895 L
.1 .4289 L
.104 .42886 L
.108 .42881 L
.112 .42878 L
.116 .42873 L
.12 .42869 L
.124 .42864 L
.128 .4286 L
.132 .42855 L
.136 .42851 L
.14 .42846 L
.144 .42842 L
.148 .42838 L
.152 .42833 L
.156 .42829 L
.16 .42825 L
.164 .4282 L
.168 .42816 L
.172 .42811 L
.176 .42807 L
.18 .42802 L
.184 .42798 L
.188 .42794 L
.192 .42789 L
.196 .42785 L
.2 .42781 L
Mistroke
.204 .42776 L
.208 .42772 L
.212 .42767 L
.216 .42763 L
.22 .42759 L
.224 .42754 L
.228 .4275 L
.232 .42745 L
.236 .42741 L
.24 .42737 L
.244 .42732 L
.248 .42728 L
.252 .42723 L
.256 .42719 L
.26 .42715 L
.264 .4271 L
.268 .42706 L
.272 .42701 L
.276 .42697 L
.28 .42693 L
.284 .42688 L
.288 .42684 L
.292 .4268 L
.296 .42675 L
.3 .42671 L
.304 .42666 L
.308 .42662 L
.312 .42658 L
.316 .42653 L
.32 .42649 L
.324 .42644 L
.328 .4264 L
.332 .42636 L
.336 .42632 L
.34 .42627 L
.344 .42622 L
.348 .42618 L
.352 .42614 L
.356 .4261 L
.36 .42605 L
.364 .426 L
.368 .42595 L
.372 .42592 L
.376 .42588 L
.38 .42583 L
.384 .42578 L
.388 .42573 L
.392 .42569 L
.396 .42566 L
.4 .42561 L
Mistroke
.404 .42556 L
.408 .42551 L
.412 .42547 L
.416 .42544 L
.42 .4254 L
.424 .42535 L
.428 .42529 L
.432 .42525 L
.436 .42521 L
.44 .42518 L
.444 .42514 L
.448 .42508 L
.452 .42502 L
.456 .42498 L
.46 .42495 L
.464 .42492 L
.468 .42487 L
.472 .42481 L
.476 .42475 L
.48 .42472 L
.484 .4247 L
.488 .42467 L
.492 .42461 L
.496 .42453 L
.5 .42448 L
.504 .42446 L
.508 .42445 L
.512 .42441 L
.516 .42434 L
.52 .42426 L
.524 .42421 L
.528 .4242 L
.532 .4242 L
.536 .42416 L
.54 .42407 L
.544 .42398 L
.548 .42393 L
.552 .42393 L
.556 .42395 L
.56 .42391 L
.564 .42381 L
.568 .4237 L
.572 .42365 L
.576 .42366 L
.58 .42369 L
.584 .42367 L
.588 .42356 L
.592 .42344 L
.596 .42336 L
.6 .42337 L
Mistroke
.604 .42342 L
.608 .42342 L
.612 .42334 L
.616 .4232 L
.62 .42308 L
.624 .42306 L
.628 .42312 L
.632 .42316 L
.636 .42312 L
.64 .42299 L
.644 .42285 L
.648 .42276 L
.652 .42278 L
.656 .42284 L
.66 .42287 L
.664 .42281 L
.668 .42267 L
.672 .42253 L
.676 .42245 L
.68 .42246 L
.684 .42252 L
.688 .42255 L
.692 .42251 L
.696 .42241 L
.7 .42227 L
.704 .42215 L
.708 .42211 L
.712 .42214 L
.716 .4222 L
.72 .42225 L
.724 .42222 L
.728 .42211 L
.732 .42196 L
.736 .42183 L
.74 .4218 L
.744 .42191 L
.748 .42211 L
.752 .42231 L
.756 .42242 L
.76 .42241 L
.764 .42235 L
.768 .42238 L
.772 .42265 L
.776 .42322 L
.78 .42404 L
.784 .42497 L
.788 .42587 L
.792 .42669 L
.796 .42754 L
.8 .42862 L
Mistroke
.804 .43014 L
.808 .43219 L
.812 .4347 L
.816 .43748 L
.82 .4403 L
.824 .44302 L
.828 .44561 L
.832 .44821 L
.836 .45097 L
.84 .45398 L
.844 .45721 L
.848 .46051 L
.852 .46367 L
.856 .4665 L
.86 .46892 L
.864 .47097 L
.868 .47278 L
.872 .4745 L
.876 .4763 L
.88 .4783 L
.884 .48055 L
.888 .4831 L
.892 .4859 L
.896 .48891 L
.9 .49198 L
.904 .49498 L
.908 .49771 L
.912 .50006 L
.916 .50198 L
.92 .50358 L
.924 .50506 L
.928 .50665 L
.932 .50858 L
.936 .51095 L
.94 .51366 L
.944 .51654 L
.948 .51921 L
.952 .52143 L
.956 .52287 L
.96 .52352 L
.964 .5234 L
.968 .52274 L
.972 .52178 L
.976 .52077 L
.98 .51992 L
.984 .51934 L
.988 .51903 L
.992 .51905 L
.996 .51928 L
1 .5198 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool02000Oomoogoo001oo`00Ool20003Ool0
1000Oomoo`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000R
Ool00`00Oomoo`1MOol00`00Oomoo`0<Ool0029oo`8002]oo`04001oo`00Ool200001Goo001oo`00
Ool0100000=oo`0000000P0000Aoo`00001oo`80009oo`03001oogoo01Aoo`03001oogoo00aoo`00
8WooH`0037oo000ROol01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`00009oo`05001oogooOol00003Ool01000Oomoogoo1@000goo00D007ooOomo
o`0000=oo`04001oogooOol20002Ool00`00Oomoo`0:Ool0029oo`8004]oo`03001oogoo00aoo`04
001oogoo000?Ool0029oo`03001oogoo04Yoo`03001oogoo00]oo`05001oo`00Ool0000?Ool0029o
o`8004]oo`03001oogoo00]oo`04001oo`00000@Ool0029oo`8004aoo`8000]oo`04001oo`00000@
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo04eoo`03001oogoo009o
o`<000=oo`03001oogoo015oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool2001>Ool00`00Oomoo`0300001Goo000007oo000057oo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8004ioo`03001oo`0000Ioo`8001Aoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1=Ool00`00Ool00006Ool00`00Oomoo`0C
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Cgoo0P0077oo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8004moo`03001oogoo01]oo`002goo0P00
2Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002
Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`80
06eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol0
00Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007oo
Ool007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03
001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000
Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool3
0003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001o
ogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007oo
Oomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogoo
Ool40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<0
07ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000A
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Ao
o`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P00
0goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo
0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo
00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D0
07ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04
001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=o
o`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001o
ogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004
Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00003
0003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo
0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00
Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04
001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`80
00Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo
00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo
00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`80
00=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00
Ool010000goo00<007ooOol0EGoo10003Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06
001oogoo001oo`001Woo00<007ooOol0DWoo10000goo00<007ooOol02Woo000;Ool2000:Ool20004
Ool20002Ool50002Ool00`00Oomoo`1@Ool2000DOol002Qoo`03001oogoo04ioo`<001Eoo`00:7oo
00<007ooOol0C7oo0`005goo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomo
o`1:Ool2000JOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0B7oo0`006goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo04Ioo`<001eoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Oom:000O
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P00
17oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool0
0`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04
001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007oo
Ool00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@0
07ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007oo
Ool00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007oo
Ool000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079o
o`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo
0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomo
ogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomo
o`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00
Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`00
27oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomo
o`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00
Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004
Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo
0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00
Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol0
0P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo
1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0<7oo7`008goo000G
Ool00`00Oomoo`02Oolc000NOol4000POol001Moo`03001oogoo009oo`03001oogoo055oo`8001mo
o`005goo00<007ooOol00Woo00<007ooOol0Dgoo0P007Goo000FOol20004Ool2001EOol2000LOol0
01Moo`03001oogoo009oo`03001oogoo05Eoo`<001Yoo`0077oo00<007ooOol0Egoo0`0067oo000L
Ool2001JOol2000GOol001aoo`03001oogoo05]oo`8001Eoo`0077oo0P00GGoo0`004goo000LOol0
0`00Oomoo`1NOol300000goo00000002000<Ool001aoo`03001oogoo061oo`<000moo`002Woo0`00
17oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool0
0`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo
00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(7515\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30158 m
.008 .30009 L
.012 .2996 L
.016 .29954 L
.02 .30003 L
.024 .30026 L
.028 .30001 L
.032 .29984 L
.036 .29993 L
.04 .30002 L
.044 .29997 L
.048 .29992 L
.052 .29993 L
.056 .29994 L
.06 .29993 L
.064 .29992 L
.068 .29992 L
.072 .29991 L
.076 .2999 L
.08 .29989 L
.084 .2999 L
.088 .29989 L
.092 .29988 L
.096 .29987 L
.1 .29987 L
.104 .29987 L
.108 .29986 L
.112 .29984 L
.116 .29985 L
.12 .29985 L
.124 .29984 L
.128 .29981 L
.132 .29981 L
.136 .29983 L
.14 .29982 L
.144 .29979 L
.148 .29978 L
.152 .2998 L
.156 .2998 L
.16 .29977 L
.164 .29975 L
.168 .29976 L
.172 .29979 L
.176 .29976 L
.18 .29972 L
.184 .29972 L
.188 .29976 L
.192 .29976 L
.196 .29971 L
.2 .29968 L
Mistroke
.204 .29972 L
.208 .29975 L
.212 .29971 L
.216 .29965 L
.22 .29966 L
.224 .29972 L
.228 .29972 L
.232 .29965 L
.236 .2996 L
.24 .29965 L
.244 .29972 L
.248 .29968 L
.252 .29959 L
.256 .29957 L
.26 .29966 L
.264 .2997 L
.268 .29962 L
.272 .29953 L
.276 .29955 L
.28 .29966 L
.284 .29968 L
.288 .29956 L
.292 .29947 L
.296 .29954 L
.3 .29966 L
.304 .29965 L
.308 .2995 L
.312 .29943 L
.316 .29953 L
.32 .29966 L
.324 .29962 L
.328 .29945 L
.332 .29938 L
.336 .29951 L
.34 .29965 L
.344 .2996 L
.348 .29941 L
.352 .29933 L
.356 .29947 L
.36 .29963 L
.364 .29959 L
.368 .29939 L
.372 .29928 L
.376 .2994 L
.38 .29959 L
.384 .29961 L
.388 .29941 L
.392 .29923 L
.396 .2993 L
.4 .29952 L
Mistroke
.404 .29963 L
.408 .29947 L
.412 .29922 L
.416 .29917 L
.42 .29939 L
.424 .29962 L
.428 .29959 L
.432 .29929 L
.436 .29906 L
.44 .29917 L
.444 .29952 L
.448 .29971 L
.452 .29949 L
.456 .29905 L
.46 .2989 L
.464 .29924 L
.468 .29972 L
.472 .29979 L
.476 .29929 L
.48 .29873 L
.484 .29877 L
.488 .29943 L
.492 .30001 L
.496 .2998 L
.5 .29895 L
.504 .29835 L
.508 .29873 L
.512 .29976 L
.516 .30034 L
.52 .29974 L
.524 .2985 L
.528 .29794 L
.532 .29875 L
.536 .30018 L
.54 .3007 L
.544 .29963 L
.548 .29799 L
.552 .29748 L
.556 .29875 L
.56 .30061 L
.564 .30112 L
.568 .29963 L
.572 .29753 L
.576 .29693 L
.58 .29856 L
.584 .3009 L
.588 .30165 L
.592 .29994 L
.596 .29731 L
.6 .29629 L
Mistroke
.604 .29795 L
.608 .30082 L
.612 .30221 L
.616 .30073 L
.62 .29766 L
.624 .29578 L
.628 .29685 L
.632 .29997 L
.636 .30237 L
.64 .3019 L
.644 .29894 L
.648 .29603 L
.652 .29567 L
.656 .29814 L
.66 .30135 L
.664 .30263 L
.668 .30101 L
.672 .29786 L
.676 .29573 L
.68 .29622 L
.684 .29883 L
.688 .30152 L
.692 .30239 L
.696 .30103 L
.7 .29867 L
.704 .29706 L
.708 .29729 L
.712 .2992 L
.716 .30173 L
.72 .30376 L
.724 .3047 L
.728 .30461 L
.732 .30411 L
.736 .30414 L
.74 .30566 L
.744 .30935 L
.748 .31509 L
.752 .32182 L
.756 .32791 L
.76 .33212 L
.764 .33461 L
.768 .33723 L
.772 .34257 L
.776 .35224 L
.78 .3655 L
.784 .37925 L
.788 .38952 L
.792 .39393 L
.796 .39314 L
.8 .39063 L
Mistroke
.804 .39052 L
.808 .39487 L
.812 .40219 L
.816 .40805 L
.82 .40771 L
.824 .399 L
.828 .38395 L
.832 .36789 L
.836 .35684 L
.84 .35443 L
.844 .36018 L
.848 .37011 L
.852 .37893 L
.856 .38299 L
.86 .38164 L
.864 .37733 L
.868 .37354 L
.872 .37292 L
.876 .37579 L
.88 .38023 L
.884 .38355 L
.888 .38346 L
.892 .37965 L
.896 .37314 L
.9 .36584 L
.904 .3593 L
.908 .35384 L
.912 .34938 L
.916 .34499 L
.92 .34086 L
.924 .33735 L
.928 .33517 L
.932 .33483 L
.936 .33482 L
.94 .33369 L
.944 .32832 L
.948 .31745 L
.952 .30127 L
.956 .28195 L
.96 .2644 L
.964 .2524 L
.968 .24992 L
.972 .25762 L
.976 .27334 L
.98 .29375 L
.984 .31342 L
.988 .32854 L
.992 .33735 L
.996 .33809 L
1 .33413 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51027 m
.008 .51469 L
.012 .51614 L
.016 .51448 L
.02 .51408 L
.024 .51464 L
.028 .5148 L
.032 .51457 L
.036 .51455 L
.04 .5146 L
.044 .51463 L
.048 .51459 L
.052 .5146 L
.056 .5146 L
.06 .51461 L
.064 .5146 L
.068 .51461 L
.072 .5146 L
.076 .51461 L
.08 .5146 L
.084 .5146 L
.088 .5146 L
.092 .5146 L
.096 .5146 L
.1 .5146 L
.104 .5146 L
.108 .5146 L
.112 .5146 L
.116 .5146 L
.12 .5146 L
.124 .5146 L
.128 .5146 L
.132 .5146 L
.136 .5146 L
.14 .5146 L
.144 .5146 L
.148 .5146 L
.152 .5146 L
.156 .5146 L
.16 .5146 L
.164 .5146 L
.168 .5146 L
.172 .5146 L
.176 .5146 L
.18 .5146 L
.184 .5146 L
.188 .5146 L
.192 .5146 L
.196 .5146 L
.2 .5146 L
Mistroke
.204 .5146 L
.208 .5146 L
.212 .5146 L
.216 .5146 L
.22 .5146 L
.224 .5146 L
.228 .5146 L
.232 .5146 L
.236 .5146 L
.24 .5146 L
.244 .5146 L
.248 .5146 L
.252 .5146 L
.256 .5146 L
.26 .5146 L
.264 .5146 L
.268 .51459 L
.272 .51459 L
.276 .5146 L
.28 .5146 L
.284 .51459 L
.288 .51459 L
.292 .51459 L
.296 .5146 L
.3 .5146 L
.304 .51459 L
.308 .51459 L
.312 .51459 L
.316 .5146 L
.32 .51459 L
.324 .51459 L
.328 .51459 L
.332 .51459 L
.336 .51459 L
.34 .51459 L
.344 .51459 L
.348 .51459 L
.352 .51459 L
.356 .51459 L
.36 .51459 L
.364 .51459 L
.368 .51459 L
.372 .51459 L
.376 .51459 L
.38 .51459 L
.384 .51459 L
.388 .51458 L
.392 .51459 L
.396 .51459 L
.4 .51459 L
Mistroke
.404 .51459 L
.408 .51458 L
.412 .51458 L
.416 .51459 L
.42 .51459 L
.424 .51459 L
.428 .51458 L
.432 .51458 L
.436 .51459 L
.44 .51459 L
.444 .51459 L
.448 .51458 L
.452 .51457 L
.456 .51458 L
.46 .51459 L
.464 .51459 L
.468 .51459 L
.472 .51457 L
.476 .51457 L
.48 .51458 L
.484 .51459 L
.488 .5146 L
.492 .51458 L
.496 .51457 L
.5 .51456 L
.504 .51458 L
.508 .5146 L
.512 .5146 L
.516 .51457 L
.52 .51455 L
.524 .51456 L
.528 .51459 L
.532 .51461 L
.536 .5146 L
.54 .51456 L
.544 .51454 L
.548 .51455 L
.552 .51459 L
.556 .51461 L
.56 .5146 L
.564 .51456 L
.568 .51453 L
.572 .51454 L
.576 .51459 L
.58 .51462 L
.584 .51461 L
.588 .51455 L
.592 .51451 L
.596 .51453 L
.6 .51458 L
Mistroke
.604 .51463 L
.608 .51462 L
.612 .51456 L
.616 .51451 L
.62 .5145 L
.624 .51456 L
.628 .51463 L
.632 .51464 L
.636 .51459 L
.64 .51452 L
.644 .51448 L
.648 .51452 L
.652 .51459 L
.656 .51465 L
.66 .51463 L
.664 .51456 L
.668 .51449 L
.672 .51447 L
.676 .51452 L
.68 .5146 L
.684 .51464 L
.688 .51462 L
.692 .51454 L
.696 .51447 L
.7 .51444 L
.704 .51446 L
.708 .51451 L
.712 .51454 L
.716 .51451 L
.72 .51441 L
.724 .51427 L
.728 .51412 L
.732 .51398 L
.736 .51387 L
.74 .51374 L
.744 .51354 L
.748 .51322 L
.752 .51272 L
.756 .51208 L
.76 .51133 L
.764 .51051 L
.768 .50963 L
.772 .50866 L
.776 .5075 L
.78 .50604 L
.784 .50425 L
.788 .50218 L
.792 .49994 L
.796 .49768 L
.8 .49545 L
Mistroke
.804 .49324 L
.808 .49097 L
.812 .48854 L
.816 .48594 L
.82 .48327 L
.824 .4807 L
.828 .47841 L
.832 .47649 L
.836 .47488 L
.84 .47343 L
.844 .47194 L
.848 .47024 L
.852 .46831 L
.856 .46621 L
.86 .46407 L
.864 .462 L
.868 .46004 L
.872 .45815 L
.876 .45624 L
.88 .45426 L
.884 .45217 L
.888 .45001 L
.892 .44786 L
.896 .4458 L
.9 .4439 L
.904 .44219 L
.908 .44064 L
.912 .43927 L
.916 .43803 L
.92 .43693 L
.924 .43591 L
.928 .43496 L
.932 .434 L
.936 .43305 L
.94 .43211 L
.944 .43128 L
.948 .43069 L
.952 .43046 L
.956 .43072 L
.96 .43145 L
.964 .43255 L
.968 .43386 L
.972 .43507 L
.976 .43601 L
.98 .43647 L
.984 .43642 L
.988 .4359 L
.992 .43507 L
.996 .43404 L
1 .43311 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43327 L
.012 .43 L
.016 .42878 L
.02 .42966 L
.024 .4301 L
.028 .42974 L
.032 .42956 L
.036 .42957 L
.04 .42961 L
.044 .42952 L
.048 .42948 L
.052 .42942 L
.056 .4294 L
.06 .42934 L
.064 .42931 L
.068 .42925 L
.072 .42922 L
.076 .42916 L
.08 .42913 L
.084 .42908 L
.088 .42904 L
.092 .42899 L
.096 .42895 L
.1 .4289 L
.104 .42886 L
.108 .42881 L
.112 .42878 L
.116 .42873 L
.12 .42869 L
.124 .42864 L
.128 .4286 L
.132 .42855 L
.136 .42851 L
.14 .42846 L
.144 .42842 L
.148 .42838 L
.152 .42834 L
.156 .42829 L
.16 .42825 L
.164 .4282 L
.168 .42816 L
.172 .42811 L
.176 .42807 L
.18 .42803 L
.184 .42798 L
.188 .42794 L
.192 .42789 L
.196 .42785 L
.2 .42781 L
Mistroke
.204 .42776 L
.208 .42772 L
.212 .42767 L
.216 .42763 L
.22 .42759 L
.224 .42754 L
.228 .4275 L
.232 .42745 L
.236 .42741 L
.24 .42737 L
.244 .42732 L
.248 .42728 L
.252 .42723 L
.256 .42719 L
.26 .42715 L
.264 .4271 L
.268 .42706 L
.272 .42702 L
.276 .42697 L
.28 .42693 L
.284 .42688 L
.288 .42684 L
.292 .4268 L
.296 .42675 L
.3 .42671 L
.304 .42666 L
.308 .42662 L
.312 .42658 L
.316 .42654 L
.32 .42649 L
.324 .42644 L
.328 .4264 L
.332 .42636 L
.336 .42632 L
.34 .42627 L
.344 .42622 L
.348 .42618 L
.352 .42614 L
.356 .4261 L
.36 .42605 L
.364 .426 L
.368 .42596 L
.372 .42592 L
.376 .42588 L
.38 .42583 L
.384 .42578 L
.388 .42574 L
.392 .4257 L
.396 .42566 L
.4 .42562 L
Mistroke
.404 .42557 L
.408 .42552 L
.412 .42547 L
.416 .42544 L
.42 .4254 L
.424 .42535 L
.428 .4253 L
.432 .42525 L
.436 .42521 L
.44 .42518 L
.444 .42513 L
.448 .42508 L
.452 .42503 L
.456 .42499 L
.46 .42496 L
.464 .42492 L
.468 .42487 L
.472 .42481 L
.476 .42476 L
.48 .42473 L
.484 .4247 L
.488 .42466 L
.492 .4246 L
.496 .42454 L
.5 .42449 L
.504 .42447 L
.508 .42445 L
.512 .4244 L
.516 .42433 L
.52 .42426 L
.524 .42423 L
.528 .42422 L
.532 .4242 L
.536 .42414 L
.54 .42406 L
.544 .42399 L
.548 .42396 L
.552 .42396 L
.556 .42395 L
.56 .42388 L
.564 .42379 L
.568 .42371 L
.572 .42369 L
.576 .4237 L
.58 .4237 L
.584 .42363 L
.588 .42352 L
.592 .42343 L
.596 .4234 L
.6 .42343 L
Mistroke
.604 .42345 L
.608 .42339 L
.612 .42327 L
.616 .42316 L
.62 .42311 L
.624 .42314 L
.628 .42318 L
.632 .42316 L
.636 .42305 L
.64 .42291 L
.644 .42282 L
.648 .42283 L
.652 .42288 L
.656 .42291 L
.66 .42284 L
.664 .42271 L
.668 .42258 L
.672 .42251 L
.676 .42254 L
.68 .4226 L
.684 .42261 L
.688 .42255 L
.692 .42242 L
.696 .4223 L
.7 .42224 L
.704 .42227 L
.708 .42234 L
.712 .4224 L
.716 .42241 L
.72 .42238 L
.724 .42233 L
.728 .42233 L
.732 .42243 L
.736 .42265 L
.74 .42298 L
.744 .42336 L
.748 .42376 L
.752 .42418 L
.756 .42467 L
.76 .42532 L
.764 .42623 L
.768 .42747 L
.772 .429 L
.776 .43075 L
.78 .43261 L
.784 .43454 L
.788 .4366 L
.792 .4389 L
.796 .44156 L
.8 .4446 L
Mistroke
.804 .4479 L
.808 .45126 L
.812 .45444 L
.816 .45733 L
.82 .45994 L
.824 .4624 L
.828 .46489 L
.832 .46749 L
.836 .47016 L
.84 .47274 L
.844 .47508 L
.848 .47711 L
.852 .47889 L
.856 .48063 L
.86 .48256 L
.864 .48485 L
.868 .48755 L
.872 .49056 L
.876 .49367 L
.88 .49668 L
.884 .49941 L
.888 .50183 L
.892 .50393 L
.896 .50582 L
.9 .50759 L
.904 .50933 L
.908 .51112 L
.912 .51304 L
.916 .51506 L
.92 .51719 L
.924 .51925 L
.928 .52113 L
.932 .52257 L
.936 .52344 L
.94 .52364 L
.944 .52326 L
.948 .5225 L
.952 .52164 L
.956 .52098 L
.96 .52072 L
.964 .52086 L
.968 .52131 L
.972 .52178 L
.976 .52207 L
.98 .52191 L
.984 .5213 L
.988 .52028 L
.992 .51914 L
.996 .51802 L
1 .51733 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01000Oomoogoo1P000goo00@007ooOol000Eoo`002goo0P002Woo0P00
17oo00<007ooOol00Woo0P0037oo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo
0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol30006Ool01000Oomoo`001Goo
000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@00
0goo0P0017oo0`0017oo0P0017oo0P001Goo0`0000=oo`00000010000goo0P001Woo000ROol00`00
Oomoo`1JOol00`00Ool0000?Ool0029oo`8002eoo`03001oo`0000<00003Ool007oo00@00003Ool0
07oo00800003Ool007oo008001Moo`04001oogoo000>Ool0029oof<000aoo`008Woo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00002Ool01@00
Oomoogoo00000goo00<007ooOol00P000goo00D007ooOomoo`0000=oo`0=001oogooOol007oo001o
o`00Ool007oo000037oo000ROol20017Ool2000AOol01@00Oomoogoo00003Woo000ROol00`00Oomo
o`17Ool2000>Ool30004Ool2000<Ool0029oo`8004Uoo`03001oogoo00]oo`8001Aoo`008Woo0P00
BWoo00<007ooOol00goo00<007ooOol00goo0P005Goo000;Ool20004Ool00`00Oomoo`03Ool20003
Ool30003Ool00`00Oomoo`19Ool00`00Oomoo`02Ool00`00Ool00004Ool00`00Oomoo`0DOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Bgoo00H007ooOomoo`00Ool5
000GOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Bgoo0P000Woo
00D007ooOol007oo008001Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1:Ool4000NOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P00CGoo0P007Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`00
2goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03
Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0
029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool2
0003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029o
o`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04
001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P00
0goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P00
17oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06
001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo
0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00
Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo
00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009o
o`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:
Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomo
o`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo
00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00
Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomo
o`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00
Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`00
00Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`80
00Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003
Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qoo`03
001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03
001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`80
00Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00
Oomoo`00Ool010000goo00<007ooOol0Dgoo0`000goo00<007ooOol02Woo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0Cgoo10000goo0`003Goo000;
Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1>Ool2000FOol002Qoo`03001oogoo04]o
o`<001Qoo`00:7oo00<007ooOol0BGoo0`006Woo000AOol20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool00`00Oomoo`18Ool2000LOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0AWoo0P007Woo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo04=oo`@001moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Oom7000ROol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`00
4Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007oo
Oomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000
K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P00
2Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo
0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=o
o`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009o
o`03001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo
0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2
000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo
00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04
001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol4
0003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04
Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomo
o`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00
Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo
0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@00
37oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2
001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`00
2goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007oo
Ool000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=o
o`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0
<7oo70009Woo000GOol00`00Oomoo`02Oolc000LOol3000SOol001Moo`03001oogoo009oo`03001o
ogoo04ioo`80029oo`005goo00<007ooOol00Woo00<007ooOol0D7oo0P0087oo000FOol20004Ool2
001BOol2000OOol001Moo`03001oogoo009oo`03001oogoo05=oo`8001eoo`0077oo00<007ooOol0
E7oo0`006goo000LOol2001HOol00`00Oomoo`0HOol001aoo`03001oogoo05Qoo`8001Qoo`0077oo
0P00FWoo0`005Woo000LOol00`00Oomoo`1KOol30002Ool2000017oo0000000037oo000LOol00`00
Oomoo`1NOol300000goo001oo`0>Ool000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`00
2goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo
00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07
Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo
00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(7682\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29855 m
.008 .29912 L
.012 .30062 L
.016 .30081 L
.02 .29976 L
.024 .29958 L
.028 .30013 L
.032 .30022 L
.036 .29995 L
.04 .2999 L
.044 .30001 L
.048 .30002 L
.052 .29997 L
.056 .29995 L
.06 .29997 L
.064 .29996 L
.068 .29995 L
.072 .29995 L
.076 .29994 L
.08 .29993 L
.084 .29993 L
.088 .29993 L
.092 .29992 L
.096 .2999 L
.1 .2999 L
.104 .2999 L
.108 .29989 L
.112 .29988 L
.116 .29988 L
.12 .29988 L
.124 .29987 L
.128 .29985 L
.132 .29985 L
.136 .29986 L
.14 .29986 L
.144 .29983 L
.148 .29982 L
.152 .29983 L
.156 .29984 L
.16 .29982 L
.164 .29979 L
.168 .29979 L
.172 .29982 L
.176 .29981 L
.18 .29977 L
.184 .29975 L
.188 .29978 L
.192 .29979 L
.196 .29976 L
.2 .29972 L
Mistroke
.204 .29974 L
.208 .29977 L
.212 .29976 L
.216 .2997 L
.22 .29969 L
.224 .29973 L
.228 .29976 L
.232 .2997 L
.236 .29965 L
.24 .29967 L
.244 .29974 L
.248 .29972 L
.252 .29964 L
.256 .29961 L
.26 .29967 L
.264 .29973 L
.268 .29968 L
.272 .29958 L
.276 .29958 L
.28 .29967 L
.284 .29971 L
.288 .29962 L
.292 .29952 L
.296 .29956 L
.3 .29968 L
.304 .29968 L
.308 .29956 L
.312 .29948 L
.316 .29955 L
.32 .29967 L
.324 .29966 L
.328 .29951 L
.332 .29943 L
.336 .29953 L
.34 .29966 L
.344 .29963 L
.348 .29947 L
.352 .29938 L
.356 .29949 L
.36 .29964 L
.364 .29962 L
.368 .29944 L
.372 .29933 L
.376 .29944 L
.38 .29961 L
.384 .29962 L
.388 .29944 L
.392 .29929 L
.396 .29936 L
.4 .29956 L
Mistroke
.404 .29964 L
.408 .29948 L
.412 .29927 L
.416 .29925 L
.42 .29945 L
.424 .29963 L
.428 .29956 L
.432 .2993 L
.436 .29914 L
.44 .29928 L
.444 .29957 L
.448 .29967 L
.452 .29943 L
.456 .2991 L
.46 .29905 L
.464 .29938 L
.468 .29972 L
.472 .29967 L
.476 .29922 L
.48 .29885 L
.484 .29901 L
.488 .29958 L
.492 .29991 L
.496 .29959 L
.5 .29888 L
.504 .29858 L
.508 .29908 L
.512 .29989 L
.516 .3001 L
.52 .29939 L
.524 .29845 L
.528 .29833 L
.532 .29926 L
.536 .3003 L
.54 .30027 L
.544 .29909 L
.548 .29794 L
.552 .29809 L
.556 .2995 L
.56 .30075 L
.564 .30046 L
.568 .2988 L
.572 .2974 L
.576 .29778 L
.58 .29967 L
.584 .30122 L
.588 .30078 L
.592 .29866 L
.596 .29689 L
.6 .29728 L
Mistroke
.604 .29957 L
.608 .3016 L
.612 .30134 L
.616 .29891 L
.62 .29655 L
.624 .29653 L
.628 .29896 L
.632 .30166 L
.636 .3021 L
.64 .29981 L
.644 .29681 L
.648 .2958 L
.652 .29774 L
.656 .30098 L
.66 .30271 L
.664 .30148 L
.668 .2984 L
.672 .29618 L
.676 .29677 L
.68 .29982 L
.684 .30302 L
.688 .30412 L
.692 .30275 L
.696 .30059 L
.7 .3 L
.704 .30217 L
.708 .30638 L
.712 .31081 L
.716 .31397 L
.72 .31576 L
.724 .31736 L
.728 .32028 L
.732 .32542 L
.736 .33268 L
.74 .34123 L
.744 .35006 L
.748 .3583 L
.752 .36551 L
.756 .37175 L
.76 .3776 L
.764 .38392 L
.768 .39128 L
.772 .39926 L
.776 .40624 L
.78 .4099 L
.784 .40857 L
.788 .40244 L
.792 .39384 L
.796 .38619 L
.8 .38194 L
Mistroke
.804 .38115 L
.808 .38137 L
.812 .37935 L
.816 .3734 L
.82 .36494 L
.824 .35809 L
.828 .35726 L
.832 .36449 L
.836 .37766 L
.84 .39145 L
.844 .39979 L
.848 .39914 L
.852 .39026 L
.856 .37757 L
.86 .36683 L
.864 .36187 L
.868 .36313 L
.872 .36754 L
.876 .37075 L
.88 .36959 L
.884 .36343 L
.888 .35449 L
.892 .34573 L
.896 .33964 L
.9 .33646 L
.904 .33448 L
.908 .33155 L
.912 .32564 L
.916 .31703 L
.92 .30674 L
.924 .29687 L
.928 .28892 L
.932 .28296 L
.936 .27894 L
.94 .27578 L
.944 .27395 L
.948 .27442 L
.952 .27849 L
.956 .2875 L
.96 .30048 L
.964 .31495 L
.968 .32747 L
.972 .33312 L
.976 .33059 L
.98 .31903 L
.984 .30143 L
.988 .28373 L
.992 .26894 L
.996 .26402 L
1 .26793 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .50929 m
.008 .51427 L
.012 .51603 L
.016 .51446 L
.02 .51386 L
.024 .51431 L
.028 .51456 L
.032 .51439 L
.036 .51433 L
.04 .51435 L
.044 .5144 L
.048 .51437 L
.052 .51438 L
.056 .51437 L
.06 .51438 L
.064 .51437 L
.068 .51438 L
.072 .51437 L
.076 .51438 L
.08 .51437 L
.084 .51438 L
.088 .51437 L
.092 .51438 L
.096 .51437 L
.1 .51438 L
.104 .51437 L
.108 .51438 L
.112 .51437 L
.116 .51438 L
.12 .51437 L
.124 .51438 L
.128 .51437 L
.132 .51438 L
.136 .51437 L
.14 .51438 L
.144 .51437 L
.148 .51438 L
.152 .51437 L
.156 .51437 L
.16 .51437 L
.164 .51437 L
.168 .51437 L
.172 .51437 L
.176 .51437 L
.18 .51437 L
.184 .51437 L
.188 .51437 L
.192 .51437 L
.196 .51437 L
.2 .51437 L
Mistroke
.204 .51437 L
.208 .51437 L
.212 .51437 L
.216 .51437 L
.22 .51437 L
.224 .51437 L
.228 .51437 L
.232 .51437 L
.236 .51437 L
.24 .51437 L
.244 .51437 L
.248 .51437 L
.252 .51437 L
.256 .51437 L
.26 .51437 L
.264 .51437 L
.268 .51437 L
.272 .51437 L
.276 .51437 L
.28 .51437 L
.284 .51437 L
.288 .51437 L
.292 .51437 L
.296 .51437 L
.3 .51437 L
.304 .51437 L
.308 .51437 L
.312 .51437 L
.316 .51437 L
.32 .51437 L
.324 .51437 L
.328 .51436 L
.332 .51437 L
.336 .51437 L
.34 .51437 L
.344 .51436 L
.348 .51436 L
.352 .51437 L
.356 .51437 L
.36 .51437 L
.364 .51436 L
.368 .51436 L
.372 .51436 L
.376 .51437 L
.38 .51437 L
.384 .51436 L
.388 .51436 L
.392 .51436 L
.396 .51437 L
.4 .51437 L
Mistroke
.404 .51436 L
.408 .51436 L
.412 .51436 L
.416 .51436 L
.42 .51437 L
.424 .51436 L
.428 .51436 L
.432 .51435 L
.436 .51436 L
.44 .51437 L
.444 .51436 L
.448 .51436 L
.452 .51435 L
.456 .51435 L
.46 .51436 L
.464 .51437 L
.468 .51436 L
.472 .51435 L
.476 .51435 L
.48 .51436 L
.484 .51437 L
.488 .51436 L
.492 .51435 L
.496 .51434 L
.5 .51435 L
.504 .51436 L
.508 .51437 L
.512 .51436 L
.516 .51434 L
.52 .51433 L
.524 .51434 L
.528 .51437 L
.532 .51437 L
.536 .51436 L
.54 .51433 L
.544 .51432 L
.548 .51434 L
.552 .51437 L
.556 .51438 L
.56 .51435 L
.564 .51432 L
.568 .51431 L
.572 .51434 L
.576 .51438 L
.58 .51439 L
.584 .51435 L
.588 .51431 L
.592 .5143 L
.596 .51433 L
.6 .51438 L
Mistroke
.604 .5144 L
.608 .51436 L
.612 .51431 L
.616 .51428 L
.62 .51432 L
.624 .51438 L
.628 .51441 L
.632 .51438 L
.636 .51431 L
.64 .51427 L
.644 .51429 L
.648 .51435 L
.652 .5144 L
.656 .5144 L
.66 .51433 L
.664 .51426 L
.668 .51424 L
.672 .51427 L
.676 .51434 L
.68 .51436 L
.684 .5143 L
.688 .51419 L
.692 .51408 L
.696 .51401 L
.7 .51398 L
.704 .51394 L
.708 .51382 L
.712 .5136 L
.716 .51327 L
.72 .51289 L
.724 .51246 L
.728 .51199 L
.732 .51144 L
.736 .51075 L
.74 .50985 L
.744 .50874 L
.748 .50743 L
.752 .50594 L
.756 .5043 L
.76 .50253 L
.764 .50062 L
.768 .49854 L
.772 .49626 L
.776 .49379 L
.78 .49119 L
.784 .48857 L
.788 .48605 L
.792 .4837 L
.796 .48152 L
.8 .47946 L
Mistroke
.804 .47743 L
.808 .4754 L
.812 .47338 L
.816 .47146 L
.82 .46972 L
.824 .46815 L
.828 .46667 L
.832 .4651 L
.836 .46328 L
.84 .46115 L
.844 .45876 L
.848 .45629 L
.852 .45392 L
.856 .4518 L
.86 .44996 L
.864 .44829 L
.868 .44666 L
.872 .44496 L
.876 .44317 L
.88 .44134 L
.884 .43959 L
.888 .43803 L
.892 .4367 L
.896 .43558 L
.9 .4346 L
.904 .43372 L
.908 .43291 L
.912 .43221 L
.916 .43166 L
.92 .43132 L
.924 .43122 L
.928 .43136 L
.932 .43171 L
.936 .43224 L
.94 .43288 L
.944 .43361 L
.948 .43433 L
.952 .43498 L
.956 .43541 L
.96 .43554 L
.964 .43531 L
.968 .43476 L
.972 .43398 L
.976 .43323 L
.98 .43261 L
.984 .43243 L
.988 .43262 L
.992 .43324 L
.996 .43408 L
1 .43492 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42706 L
.012 .43002 L
.016 .43087 L
.02 .42966 L
.024 .42939 L
.028 .42973 L
.032 .42979 L
.036 .42957 L
.04 .42953 L
.044 .42952 L
.048 .4295 L
.052 .42942 L
.056 .42939 L
.06 .42934 L
.064 .42931 L
.068 .42925 L
.072 .42922 L
.076 .42916 L
.08 .42913 L
.084 .42908 L
.088 .42904 L
.092 .42899 L
.096 .42895 L
.1 .4289 L
.104 .42887 L
.108 .42882 L
.112 .42878 L
.116 .42873 L
.12 .42869 L
.124 .42864 L
.128 .4286 L
.132 .42855 L
.136 .42851 L
.14 .42847 L
.144 .42842 L
.148 .42838 L
.152 .42834 L
.156 .42829 L
.16 .42825 L
.164 .4282 L
.168 .42816 L
.172 .42811 L
.176 .42807 L
.18 .42803 L
.184 .42798 L
.188 .42794 L
.192 .4279 L
.196 .42785 L
.2 .42781 L
Mistroke
.204 .42776 L
.208 .42772 L
.212 .42768 L
.216 .42763 L
.22 .42759 L
.224 .42755 L
.228 .4275 L
.232 .42746 L
.236 .42741 L
.24 .42737 L
.244 .42733 L
.248 .42728 L
.252 .42724 L
.256 .42719 L
.26 .42715 L
.264 .42711 L
.268 .42706 L
.272 .42702 L
.276 .42697 L
.28 .42693 L
.284 .42689 L
.288 .42684 L
.292 .4268 L
.296 .42676 L
.3 .42671 L
.304 .42667 L
.308 .42662 L
.312 .42658 L
.316 .42654 L
.32 .42649 L
.324 .42645 L
.328 .4264 L
.332 .42636 L
.336 .42632 L
.34 .42627 L
.344 .42623 L
.348 .42618 L
.352 .42614 L
.356 .4261 L
.36 .42605 L
.364 .42601 L
.368 .42596 L
.372 .42592 L
.376 .42588 L
.38 .42583 L
.384 .42579 L
.388 .42574 L
.392 .4257 L
.396 .42566 L
.4 .42562 L
Mistroke
.404 .42557 L
.408 .42552 L
.412 .42548 L
.416 .42544 L
.42 .4254 L
.424 .42535 L
.428 .4253 L
.432 .42526 L
.436 .42522 L
.44 .42518 L
.444 .42513 L
.448 .42508 L
.452 .42503 L
.456 .42499 L
.46 .42496 L
.464 .42492 L
.468 .42487 L
.472 .42481 L
.476 .42477 L
.48 .42473 L
.484 .4247 L
.488 .42466 L
.492 .4246 L
.496 .42454 L
.5 .4245 L
.504 .42448 L
.508 .42445 L
.512 .42439 L
.516 .42433 L
.52 .42427 L
.524 .42424 L
.528 .42422 L
.532 .42419 L
.536 .42413 L
.54 .42405 L
.544 .424 L
.548 .42398 L
.552 .42397 L
.556 .42394 L
.56 .42386 L
.564 .42378 L
.568 .42373 L
.572 .42372 L
.576 .42372 L
.58 .42369 L
.584 .4236 L
.588 .42351 L
.592 .42345 L
.596 .42345 L
.6 .42346 L
Mistroke
.604 .42344 L
.608 .42335 L
.612 .42324 L
.616 .42317 L
.62 .42317 L
.624 .4232 L
.628 .42319 L
.632 .42311 L
.636 .42299 L
.64 .42289 L
.644 .42287 L
.648 .42291 L
.652 .42294 L
.656 .42289 L
.66 .42278 L
.664 .42265 L
.668 .4226 L
.672 .42263 L
.676 .42269 L
.68 .42272 L
.684 .42268 L
.688 .42259 L
.692 .42253 L
.696 .42256 L
.7 .4227 L
.704 .42289 L
.708 .42308 L
.712 .42326 L
.716 .42345 L
.72 .42373 L
.724 .42417 L
.728 .4248 L
.732 .42562 L
.736 .42658 L
.74 .42767 L
.744 .42891 L
.748 .43032 L
.752 .43199 L
.756 .43395 L
.76 .43623 L
.764 .43878 L
.768 .44154 L
.772 .4444 L
.776 .44729 L
.78 .45019 L
.784 .45314 L
.788 .45617 L
.792 .45925 L
.796 .46231 L
.8 .46521 L
Mistroke
.804 .46781 L
.808 .47006 L
.812 .47204 L
.816 .47392 L
.82 .4759 L
.824 .4781 L
.828 .48052 L
.832 .48303 L
.836 .4855 L
.84 .48785 L
.844 .49013 L
.848 .49247 L
.852 .495 L
.856 .49778 L
.86 .50069 L
.864 .50354 L
.868 .5061 L
.872 .50824 L
.876 .50996 L
.88 .51142 L
.884 .51284 L
.888 .51442 L
.892 .5162 L
.896 .51815 L
.9 .52005 L
.904 .52173 L
.908 .52299 L
.912 .52375 L
.916 .524 L
.92 .52382 L
.924 .52332 L
.928 .52263 L
.932 .52191 L
.936 .52128 L
.94 .52083 L
.944 .52062 L
.948 .52056 L
.952 .5206 L
.956 .52055 L
.96 .52032 L
.964 .51984 L
.968 .51921 L
.972 .51855 L
.976 .51819 L
.98 .51818 L
.984 .51875 L
.988 .51967 L
.992 .52084 L
.996 .52189 L
1 .52251 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool02000Oomoogoo001oo`00Ool20003Ool0
1000Oomoo`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000R
Ool00`00Oomoo`1HOol00`00Ool00002Ool00`00Oomoo`0<Ool0029oo`8002moo`09001oo`00001o
o`00Ool007oo00800003Ool007oo00@001Moo`800005Ool007ooOol0000>Ool0029oof<000aoo`00
8Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol0
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00002Ool01@00Oomoogoo00000goo0P000Woo00D007ooOomoo`0000=oo`05001oogooOol00002
Ool20003Ool01@00Ool007oo000037oo000ROol20015Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool0
0`00Ool0000>Ool0029oo`03001oogoo04Eoo`03001oogoo00aoo`<000Eoo`03001oogoo00eoo`00
8Woo0P00AWoo0P003Goo00<007ooOol05Goo000ROol20017Ool00`00Oomoo`04Ool20005Ool00`00
Oomoo`0EOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo04Ioo`03001o
ogoo00Aoo`80009oo`<001Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool20018Ool00`00Oomoo`02Ool200000goo001oo`02000IOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P00BGoo00<007ooOol00P000Woo0P006goo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo04Qoo`03001oo`0000Aoo`8001]o
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001:Ool2000QOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00
Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04
001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool0
1000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool0
1P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`00
8Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<0
07ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03
001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00
Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo
000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00
Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000
Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool0
1000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool5
0003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogoo
Ool00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo
00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009o
o`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool0
0`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo
0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomo
o`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00
:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomo
o`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol0
47oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<0
07ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@0
07ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Ool006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
0P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00
Oomoo`1@Ool40002Ool3000=Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0006Ool00`00Oomoo`1=Ool30004Ool300000goo0000000<Ool000]oo`8000Yoo`8000Aoo`80
009oo`D0009oo`03001oogoo04]oo`<001Qoo`00:7oo00<007ooOol0BGoo0`006Woo000XOol00`00
Oomoo`17Ool3000LOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo04Eo
o`8001moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`13
Ool3000POol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
@Goo0`008Woo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009ood@002Eoo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007oo
Ool006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02
001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomo
ogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02
Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`00
2goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000L
Ool00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005
Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol0
0002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00
Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`00
77oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo
00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@0
00=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool2
0004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`00
00Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`80
00Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006
Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogoo
Ool00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001c
Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001c
Ool000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`005Woo
0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`0`OolI000YOol001Moo`03
001oogoo009ooc<001Qoo`@002Ioo`005goo00<007ooOol00Woo00<007ooOol0C7oo0P0097oo000G
Ool00`00Oomoo`02Ool00`00Oomoo`1=Ool2000SOol001Ioo`8000Aoo`80051oo`03001oogoo021o
o`005goo00<007ooOol00Woo00<007ooOol0D7oo0P0087oo000LOol00`00Oomoo`1BOol2000NOol0
01aoo`8005Aoo`8001eoo`0077oo00<007ooOol0EGoo0P006goo000LOol2001HOol2000IOol001ao
o`03001oogoo05Uoo`8000=oo`L000eoo`0077oo00<007ooOol0Fgoo10001Goo0P0037oo000:Ool3
0004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]o
o`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009
Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(7849\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29825 m
.008 .29983 L
.012 .30057 L
.016 .30066 L
.02 .29997 L
.024 .29969 L
.028 .30003 L
.032 .30021 L
.036 .30006 L
.04 .29996 L
.044 .3 L
.048 .30004 L
.052 .30002 L
.056 .29999 L
.06 .29999 L
.064 .29999 L
.068 .29999 L
.072 .29998 L
.076 .29997 L
.08 .29996 L
.084 .29996 L
.088 .29996 L
.092 .29995 L
.096 .29994 L
.1 .29994 L
.104 .29994 L
.108 .29993 L
.112 .29992 L
.116 .29991 L
.12 .29991 L
.124 .29991 L
.128 .29989 L
.132 .29988 L
.136 .29989 L
.14 .29989 L
.144 .29987 L
.148 .29985 L
.152 .29986 L
.156 .29987 L
.16 .29986 L
.164 .29983 L
.168 .29982 L
.172 .29984 L
.176 .29984 L
.18 .29981 L
.184 .29979 L
.188 .29981 L
.192 .29983 L
.196 .2998 L
.2 .29976 L
Mistroke
.204 .29977 L
.208 .2998 L
.212 .2998 L
.216 .29975 L
.22 .29972 L
.224 .29976 L
.228 .29979 L
.232 .29975 L
.236 .29969 L
.24 .2997 L
.244 .29975 L
.248 .29976 L
.252 .2997 L
.256 .29965 L
.26 .29969 L
.264 .29975 L
.268 .29972 L
.272 .29964 L
.276 .29961 L
.28 .29969 L
.284 .29974 L
.288 .29967 L
.292 .29958 L
.296 .29959 L
.3 .29969 L
.304 .29972 L
.308 .29962 L
.312 .29953 L
.316 .29957 L
.32 .29968 L
.324 .29969 L
.328 .29957 L
.332 .29948 L
.336 .29955 L
.34 .29968 L
.344 .29967 L
.348 .29952 L
.352 .29943 L
.356 .29952 L
.36 .29966 L
.364 .29965 L
.368 .29949 L
.372 .29939 L
.376 .29947 L
.38 .29963 L
.384 .29965 L
.388 .29948 L
.392 .29934 L
.396 .29941 L
.4 .29959 L
Mistroke
.404 .29965 L
.408 .2995 L
.412 .29931 L
.416 .29932 L
.42 .29951 L
.424 .29965 L
.428 .29956 L
.432 .29932 L
.436 .29922 L
.44 .29937 L
.444 .29961 L
.448 .29964 L
.452 .29941 L
.456 .29915 L
.46 .29918 L
.464 .29947 L
.468 .29971 L
.472 .29958 L
.476 .2992 L
.48 .29897 L
.484 .2992 L
.488 .29965 L
.492 .29981 L
.496 .29944 L
.5 .2989 L
.504 .29881 L
.508 .29932 L
.512 .29991 L
.516 .29988 L
.52 .29918 L
.524 .29854 L
.528 .29871 L
.532 .29958 L
.536 .30023 L
.54 .29988 L
.544 .2988 L
.548 .29813 L
.552 .29867 L
.556 .29993 L
.56 .30058 L
.564 .29983 L
.568 .29835 L
.572 .29769 L
.576 .29863 L
.58 .3003 L
.584 .30097 L
.588 .29984 L
.592 .29794 L
.596 .2972 L
.6 .29847 L
Mistroke
.604 .30059 L
.608 .30145 L
.612 .30009 L
.616 .29773 L
.62 .29668 L
.624 .29807 L
.628 .30068 L
.632 .30208 L
.636 .30089 L
.64 .2982 L
.644 .29659 L
.648 .29774 L
.652 .30087 L
.656 .30338 L
.66 .30331 L
.664 .30108 L
.668 .29922 L
.672 .3001 L
.676 .30392 L
.68 .30857 L
.684 .31154 L
.688 .31215 L
.692 .31211 L
.696 .31408 L
.7 .3195 L
.704 .32751 L
.708 .33579 L
.712 .34246 L
.716 .34753 L
.72 .35262 L
.724 .35957 L
.728 .36889 L
.732 .37943 L
.736 .38917 L
.74 .39653 L
.744 .40107 L
.748 .40338 L
.752 .40439 L
.756 .40469 L
.76 .4043 L
.764 .40284 L
.768 .39974 L
.772 .3946 L
.776 .3874 L
.78 .37893 L
.784 .37081 L
.788 .36518 L
.792 .36375 L
.796 .36677 L
.8 .37263 L
Mistroke
.804 .37851 L
.808 .38202 L
.812 .38248 L
.816 .38148 L
.82 .38154 L
.824 .38425 L
.828 .38873 L
.832 .39171 L
.836 .38956 L
.84 .38062 L
.844 .36689 L
.848 .35331 L
.852 .34527 L
.856 .34565 L
.86 .35285 L
.864 .3617 L
.868 .3658 L
.872 .36109 L
.876 .34768 L
.88 .32952 L
.884 .31249 L
.888 .30078 L
.892 .29584 L
.896 .29541 L
.9 .29584 L
.904 .29419 L
.908 .2894 L
.912 .2833 L
.916 .27834 L
.92 .27696 L
.924 .27987 L
.928 .28594 L
.932 .29362 L
.936 .30113 L
.94 .30763 L
.944 .31331 L
.948 .31741 L
.952 .31984 L
.956 .31884 L
.96 .31305 L
.964 .30336 L
.968 .29021 L
.972 .27906 L
.976 .2729 L
.98 .27514 L
.984 .28718 L
.988 .30357 L
.992 .32162 L
.996 .33254 L
1 .33293 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51757 m
.008 .51401 L
.012 .51295 L
.016 .51426 L
.02 .5146 L
.024 .51407 L
.028 .51401 L
.032 .51417 L
.036 .51422 L
.04 .51413 L
.044 .51414 L
.048 .51415 L
.052 .51416 L
.056 .51414 L
.06 .51415 L
.064 .51415 L
.068 .51416 L
.072 .51415 L
.076 .51415 L
.08 .51415 L
.084 .51415 L
.088 .51415 L
.092 .51415 L
.096 .51415 L
.1 .51415 L
.104 .51415 L
.108 .51415 L
.112 .51415 L
.116 .51415 L
.12 .51415 L
.124 .51415 L
.128 .51415 L
.132 .51415 L
.136 .51415 L
.14 .51415 L
.144 .51415 L
.148 .51415 L
.152 .51415 L
.156 .51415 L
.16 .51415 L
.164 .51415 L
.168 .51415 L
.172 .51415 L
.176 .51415 L
.18 .51415 L
.184 .51415 L
.188 .51415 L
.192 .51415 L
.196 .51415 L
.2 .51415 L
Mistroke
.204 .51415 L
.208 .51415 L
.212 .51415 L
.216 .51415 L
.22 .51415 L
.224 .51415 L
.228 .51415 L
.232 .51415 L
.236 .51415 L
.24 .51415 L
.244 .51415 L
.248 .51414 L
.252 .51414 L
.256 .51415 L
.26 .51415 L
.264 .51414 L
.268 .51414 L
.272 .51414 L
.276 .51414 L
.28 .51414 L
.284 .51414 L
.288 .51414 L
.292 .51414 L
.296 .51414 L
.3 .51414 L
.304 .51414 L
.308 .51414 L
.312 .51414 L
.316 .51414 L
.32 .51414 L
.324 .51414 L
.328 .51414 L
.332 .51414 L
.336 .51414 L
.34 .51414 L
.344 .51414 L
.348 .51414 L
.352 .51414 L
.356 .51414 L
.36 .51414 L
.364 .51414 L
.368 .51414 L
.372 .51414 L
.376 .51414 L
.38 .51414 L
.384 .51414 L
.388 .51413 L
.392 .51414 L
.396 .51414 L
.4 .51414 L
Mistroke
.404 .51414 L
.408 .51413 L
.412 .51413 L
.416 .51414 L
.42 .51414 L
.424 .51414 L
.428 .51413 L
.432 .51413 L
.436 .51414 L
.44 .51414 L
.444 .51414 L
.448 .51413 L
.452 .51413 L
.456 .51413 L
.46 .51414 L
.464 .51414 L
.468 .51413 L
.472 .51412 L
.476 .51412 L
.48 .51413 L
.484 .51414 L
.488 .51414 L
.492 .51413 L
.496 .51412 L
.5 .51412 L
.504 .51414 L
.508 .51414 L
.512 .51413 L
.516 .51412 L
.52 .51411 L
.524 .51413 L
.528 .51414 L
.532 .51414 L
.536 .51412 L
.54 .51411 L
.544 .51411 L
.548 .51413 L
.552 .51415 L
.556 .51414 L
.56 .51412 L
.564 .5141 L
.568 .5141 L
.572 .51413 L
.576 .51415 L
.58 .51414 L
.584 .51411 L
.588 .51408 L
.592 .51409 L
.596 .51413 L
.6 .51416 L
Mistroke
.604 .51415 L
.608 .51411 L
.612 .51407 L
.616 .51408 L
.62 .51412 L
.624 .51416 L
.628 .51415 L
.632 .5141 L
.636 .51405 L
.64 .51404 L
.644 .51408 L
.648 .51412 L
.652 .51412 L
.656 .51405 L
.66 .51395 L
.664 .51388 L
.668 .51385 L
.672 .51383 L
.676 .51377 L
.68 .5136 L
.684 .51335 L
.688 .51305 L
.692 .51274 L
.696 .51241 L
.7 .51201 L
.704 .51144 L
.708 .51069 L
.712 .50977 L
.716 .5087 L
.72 .50752 L
.724 .5062 L
.728 .50471 L
.732 .50298 L
.736 .50102 L
.74 .49885 L
.744 .49654 L
.748 .49415 L
.752 .49172 L
.756 .48929 L
.76 .48685 L
.764 .48441 L
.768 .482 L
.772 .47967 L
.776 .47748 L
.78 .47547 L
.784 .47366 L
.788 .47199 L
.792 .47038 L
.796 .46874 L
.8 .46699 L
Mistroke
.804 .4651 L
.808 .46312 L
.812 .46111 L
.816 .45911 L
.82 .45711 L
.824 .45507 L
.828 .45293 L
.832 .45069 L
.836 .44845 L
.84 .44634 L
.844 .44449 L
.848 .44295 L
.852 .44165 L
.856 .44044 L
.86 .43914 L
.864 .43768 L
.868 .43609 L
.872 .43453 L
.876 .43319 L
.88 .43224 L
.884 .4317 L
.888 .43152 L
.892 .43154 L
.896 .43165 L
.9 .43176 L
.904 .4319 L
.908 .43212 L
.912 .43247 L
.916 .43296 L
.92 .43355 L
.924 .43413 L
.928 .43462 L
.932 .43493 L
.936 .43504 L
.94 .43493 L
.944 .43465 L
.948 .43421 L
.952 .43374 L
.956 .43324 L
.96 .4329 L
.964 .43275 L
.968 .4329 L
.972 .43333 L
.976 .43392 L
.98 .43455 L
.984 .43497 L
.988 .43504 L
.992 .43476 L
.996 .43408 L
1 .43339 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42609 L
.012 .42973 L
.016 .43109 L
.02 .42985 L
.024 .42935 L
.028 .42964 L
.032 .4298 L
.036 .42962 L
.04 .42953 L
.044 .4295 L
.048 .4295 L
.052 .42943 L
.056 .42939 L
.06 .42934 L
.064 .42931 L
.068 .42925 L
.072 .42922 L
.076 .42916 L
.08 .42913 L
.084 .42908 L
.088 .42904 L
.092 .42899 L
.096 .42895 L
.1 .4289 L
.104 .42887 L
.108 .42882 L
.112 .42878 L
.116 .42873 L
.12 .42869 L
.124 .42864 L
.128 .4286 L
.132 .42855 L
.136 .42851 L
.14 .42847 L
.144 .42842 L
.148 .42838 L
.152 .42834 L
.156 .42829 L
.16 .42825 L
.164 .4282 L
.168 .42816 L
.172 .42812 L
.176 .42807 L
.18 .42803 L
.184 .42799 L
.188 .42794 L
.192 .4279 L
.196 .42785 L
.2 .42781 L
Mistroke
.204 .42777 L
.208 .42772 L
.212 .42768 L
.216 .42763 L
.22 .42759 L
.224 .42755 L
.228 .4275 L
.232 .42746 L
.236 .42741 L
.24 .42737 L
.244 .42733 L
.248 .42728 L
.252 .42724 L
.256 .4272 L
.26 .42715 L
.264 .42711 L
.268 .42706 L
.272 .42702 L
.276 .42698 L
.28 .42693 L
.284 .42689 L
.288 .42684 L
.292 .4268 L
.296 .42676 L
.3 .42671 L
.304 .42667 L
.308 .42662 L
.312 .42658 L
.316 .42654 L
.32 .42649 L
.324 .42645 L
.328 .4264 L
.332 .42636 L
.336 .42632 L
.34 .42627 L
.344 .42623 L
.348 .42618 L
.352 .42614 L
.356 .4261 L
.36 .42606 L
.364 .42601 L
.368 .42596 L
.372 .42592 L
.376 .42588 L
.38 .42584 L
.384 .42579 L
.388 .42574 L
.392 .4257 L
.396 .42566 L
.4 .42562 L
Mistroke
.404 .42557 L
.408 .42552 L
.412 .42548 L
.416 .42544 L
.42 .4254 L
.424 .42535 L
.428 .4253 L
.432 .42526 L
.436 .42522 L
.44 .42518 L
.444 .42514 L
.448 .42508 L
.452 .42504 L
.456 .425 L
.46 .42496 L
.464 .42492 L
.468 .42487 L
.472 .42482 L
.476 .42477 L
.48 .42474 L
.484 .4247 L
.488 .42466 L
.492 .4246 L
.496 .42455 L
.5 .42451 L
.504 .42448 L
.508 .42445 L
.512 .42439 L
.516 .42433 L
.52 .42428 L
.524 .42425 L
.528 .42423 L
.532 .42419 L
.536 .42412 L
.54 .42406 L
.544 .42401 L
.548 .424 L
.552 .42397 L
.556 .42393 L
.56 .42385 L
.564 .42378 L
.568 .42375 L
.572 .42374 L
.576 .42372 L
.58 .42367 L
.584 .42358 L
.588 .42351 L
.592 .42348 L
.596 .42348 L
.6 .42347 L
Mistroke
.604 .42342 L
.608 .42332 L
.612 .42323 L
.616 .4232 L
.62 .42322 L
.624 .42322 L
.628 .42318 L
.632 .42308 L
.636 .42298 L
.64 .42294 L
.644 .42297 L
.648 .42301 L
.652 .423 L
.656 .42293 L
.66 .42285 L
.664 .42284 L
.668 .42291 L
.672 .42306 L
.676 .4232 L
.68 .42331 L
.684 .42342 L
.688 .4236 L
.692 .42394 L
.696 .42444 L
.7 .42508 L
.704 .4258 L
.708 .4266 L
.712 .42754 L
.716 .42869 L
.72 .43014 L
.724 .43188 L
.728 .43386 L
.732 .43604 L
.736 .43838 L
.74 .44088 L
.744 .44358 L
.748 .44648 L
.752 .44954 L
.756 .4527 L
.76 .45584 L
.764 .45888 L
.768 .46175 L
.772 .46443 L
.776 .46696 L
.78 .46937 L
.784 .47171 L
.788 .47398 L
.792 .47617 L
.796 .47825 L
.8 .48026 L
Mistroke
.804 .48227 L
.808 .48441 L
.812 .48678 L
.816 .48943 L
.82 .49228 L
.824 .49519 L
.828 .49796 L
.832 .50048 L
.836 .50273 L
.84 .50484 L
.844 .50692 L
.848 .50907 L
.852 .51125 L
.856 .51335 L
.86 .51521 L
.864 .51679 L
.868 .51811 L
.872 .51931 L
.876 .52051 L
.88 .52177 L
.884 .52298 L
.888 .52397 L
.892 .52452 L
.896 .5245 L
.9 .52395 L
.904 .52303 L
.908 .522 L
.912 .52112 L
.916 .5205 L
.92 .5202 L
.924 .52009 L
.928 .52007 L
.932 .52003 L
.936 .51993 L
.94 .51976 L
.944 .51962 L
.948 .51952 L
.952 .51957 L
.956 .51971 L
.96 .52002 L
.964 .52037 L
.968 .52078 L
.972 .52113 L
.976 .5213 L
.98 .52126 L
.984 .52091 L
.988 .52027 L
.992 .51952 L
.996 .51865 L
1 .51812 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo05Ioo`<000=oo`8000ioo`008Woo0P00<Goo0P0000Eoo`00000007oo00H001Moo`<00007
Ool007ooOol007oo00003Woo000ROomS000<Ool0029oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`04001oogoo0003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo00@007ooOomoo`<00003Ool007oo
009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo00000P0000Aoo`00Ool000ao
o`008Woo0P00@Woo0P0047oo00<007ooOol017oo00D007ooOomoo`0000eoo`008Woo00<007ooOol0
@Woo00<007ooOol03Woo00<007ooOol027oo0P0037oo000ROol20014Ool00`00Oomoo`0:Ool3000I
Ool0029oo`8004Aoo`8000]oo`<001Uoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo
00<007ooOol0A7oo00<007ooOol00goo0P000goo00@007oo000001Uoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool20015Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`0J
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00AWoo00D007ooOomo
o`00009oo`@001aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`15Ool200000goo001oo`04Ool00`00Oomoo`0KOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P00Agoo0`008goo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool2
0004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomo
o`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003
Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]
Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo
00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00
KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo
000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool0
1000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomo
o`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo
0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`00
27oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol0
0Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo
00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`00
17oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`00
17oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool0
0`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00
Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo0000
17oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09
Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool0
1000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00
Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool0
0`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qo
o`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool2
0004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
OomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00mo
o`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Ao
o`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0CGoo1@000goo0P000Woo00<007oo
Ool02Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007oo
Ool0BWoo100017oo0`0000Aoo`00000000eoo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<0
07ooOol0B7oo0`006goo000XOol00`00Oomoo`17Ool2000MOol002Qoo`03001oogoo04Aoo`<001mo
o`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0@goo0P008Goo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo045oo`8002=oo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0nOol3000UOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo@P009goo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0
009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00
M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<0
07ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eo
o`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Ao
o`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo
0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool0
1000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@
Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000L
Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007oo
Oomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo
00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol0
00Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo
0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol0
00Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomo
o`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001o
ogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001o
ogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
0`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo
00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007oo
Ool000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000L
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomo
o`1bOol001Moo`03001oogoo009oo`03001oogoo031ooaH002aoo`005goo00<007ooOol00Woo<`00
5Woo0`00:Goo000GOol00`00Oomoo`02Ool00`00Oomoo`19Ool2000WOol001Moo`03001oogoo009o
o`03001oogoo04]oo`03001oogoo02Aoo`005Woo0P0017oo0P00CGoo0P0097oo000GOol00`00Oomo
o`02Ool00`00Oomoo`1=Ool2000SOol001aoo`03001oogoo04moo`80025oo`0077oo0P00DWoo0P00
7goo000LOol00`00Oomoo`1BOol2000NOol001aoo`8005Eoo`8001aoo`0077oo00<007ooOol0EWoo
0`000Woo2`0037oo000LOol00`00Oomoo`1HOol4000FOol000Yoo`<000Aoo`03001oogoo009oo`<0
00=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo
00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;
Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001o
ogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03
001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(8016\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30128 m
.008 .30099 L
.012 .29962 L
.016 .29942 L
.02 .30034 L
.024 .30046 L
.028 .29996 L
.032 .29989 L
.036 .30013 L
.04 .30015 L
.044 .30003 L
.048 .30001 L
.052 .30006 L
.056 .30005 L
.06 .30003 L
.064 .30002 L
.068 .30002 L
.072 .30002 L
.076 .30001 L
.08 .3 L
.084 .3 L
.088 .29999 L
.092 .29999 L
.096 .29998 L
.1 .29997 L
.104 .29997 L
.108 .29997 L
.112 .29995 L
.116 .29994 L
.12 .29994 L
.124 .29995 L
.128 .29993 L
.132 .29992 L
.136 .29992 L
.14 .29992 L
.144 .29991 L
.148 .29989 L
.152 .29989 L
.156 .2999 L
.16 .29989 L
.164 .29987 L
.168 .29986 L
.172 .29987 L
.176 .29988 L
.18 .29985 L
.184 .29983 L
.188 .29984 L
.192 .29985 L
.196 .29984 L
.2 .29981 L
Mistroke
.204 .2998 L
.208 .29982 L
.212 .29983 L
.216 .2998 L
.22 .29976 L
.224 .29978 L
.228 .29981 L
.232 .2998 L
.236 .29974 L
.24 .29973 L
.244 .29977 L
.248 .2998 L
.252 .29975 L
.256 .29969 L
.26 .29971 L
.264 .29977 L
.268 .29976 L
.272 .29969 L
.276 .29965 L
.28 .2997 L
.284 .29976 L
.288 .29972 L
.292 .29963 L
.296 .29962 L
.3 .2997 L
.304 .29975 L
.308 .29967 L
.312 .29958 L
.316 .2996 L
.32 .2997 L
.324 .29972 L
.328 .29962 L
.332 .29953 L
.336 .29957 L
.34 .29969 L
.344 .2997 L
.348 .29958 L
.352 .29948 L
.356 .29955 L
.36 .29968 L
.364 .29968 L
.368 .29954 L
.372 .29944 L
.376 .29951 L
.38 .29965 L
.384 .29967 L
.388 .29952 L
.392 .2994 L
.396 .29945 L
.4 .29961 L
Mistroke
.404 .29967 L
.408 .29953 L
.412 .29936 L
.416 .29938 L
.42 .29955 L
.424 .29966 L
.428 .29956 L
.432 .29936 L
.436 .29929 L
.44 .29944 L
.444 .29963 L
.448 .29963 L
.452 .29941 L
.456 .29922 L
.46 .29928 L
.464 .29954 L
.468 .29969 L
.472 .29953 L
.476 .29921 L
.48 .2991 L
.484 .29934 L
.488 .29968 L
.492 .29972 L
.496 .29936 L
.5 .29897 L
.504 .29901 L
.508 .29949 L
.512 .29987 L
.516 .2997 L
.52 .29909 L
.524 .2987 L
.528 .29902 L
.532 .29975 L
.536 .30008 L
.54 .29957 L
.544 .2987 L
.548 .29842 L
.552 .29912 L
.556 .3001 L
.56 .30028 L
.564 .29935 L
.568 .29825 L
.572 .29816 L
.576 .2993 L
.58 .30053 L
.584 .3005 L
.588 .29914 L
.592 .2978 L
.596 .29792 L
.6 .29953 L
Mistroke
.604 .30108 L
.608 .30098 L
.612 .29928 L
.616 .29771 L
.62 .29803 L
.624 .30023 L
.628 .30246 L
.632 .30283 L
.636 .3013 L
.64 .29987 L
.644 .3007 L
.648 .30408 L
.652 .30813 L
.656 .31057 L
.66 .31094 L
.664 .31118 L
.668 .31386 L
.672 .31996 L
.676 .32791 L
.68 .33511 L
.684 .34019 L
.688 .34429 L
.692 .34996 L
.696 .35883 L
.7 .3701 L
.704 .38109 L
.708 .38932 L
.712 .39434 L
.716 .39773 L
.72 .40151 L
.724 .4062 L
.728 .41035 L
.732 .41166 L
.736 .40876 L
.74 .40226 L
.744 .39422 L
.748 .38688 L
.752 .38134 L
.756 .37743 L
.76 .37438 L
.764 .37171 L
.768 .36966 L
.772 .36899 L
.776 .37046 L
.78 .37428 L
.784 .38003 L
.788 .38657 L
.792 .39225 L
.796 .39524 L
.8 .3942 L
Mistroke
.804 .38902 L
.808 .38109 L
.812 .37297 L
.816 .36706 L
.82 .36437 L
.824 .36383 L
.828 .36304 L
.832 .3599 L
.836 .35403 L
.84 .34723 L
.844 .34207 L
.848 .33997 L
.852 .33975 L
.856 .3378 L
.86 .33042 L
.864 .31603 L
.868 .29716 L
.872 .27926 L
.876 .26836 L
.88 .26786 L
.884 .27636 L
.888 .28884 L
.892 .29872 L
.896 .30171 L
.9 .2977 L
.904 .2904 L
.908 .2855 L
.912 .28709 L
.916 .29576 L
.92 .30868 L
.924 .3203 L
.928 .32625 L
.932 .3242 L
.936 .31489 L
.94 .30239 L
.944 .28989 L
.948 .28169 L
.952 .27881 L
.956 .28115 L
.96 .28842 L
.964 .29724 L
.968 .3074 L
.972 .3154 L
.976 .31951 L
.98 .31912 L
.984 .31179 L
.988 .30116 L
.992 .2884 L
.996 .27813 L
1 .275 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51966 m
.008 .51398 L
.012 .51208 L
.016 .51384 L
.02 .51455 L
.024 .51396 L
.028 .51374 L
.032 .51389 L
.036 .514 L
.04 .51393 L
.044 .51391 L
.048 .51391 L
.052 .51394 L
.056 .51392 L
.06 .51393 L
.064 .51392 L
.068 .51393 L
.072 .51392 L
.076 .51393 L
.08 .51392 L
.084 .51393 L
.088 .51392 L
.092 .51393 L
.096 .51392 L
.1 .51393 L
.104 .51392 L
.108 .51393 L
.112 .51392 L
.116 .51393 L
.12 .51392 L
.124 .51393 L
.128 .51392 L
.132 .51393 L
.136 .51392 L
.14 .51393 L
.144 .51392 L
.148 .51392 L
.152 .51392 L
.156 .51392 L
.16 .51392 L
.164 .51392 L
.168 .51392 L
.172 .51392 L
.176 .51392 L
.18 .51392 L
.184 .51392 L
.188 .51392 L
.192 .51392 L
.196 .51392 L
.2 .51392 L
Mistroke
.204 .51392 L
.208 .51392 L
.212 .51392 L
.216 .51392 L
.22 .51392 L
.224 .51392 L
.228 .51392 L
.232 .51392 L
.236 .51392 L
.24 .51392 L
.244 .51392 L
.248 .51392 L
.252 .51392 L
.256 .51392 L
.26 .51392 L
.264 .51392 L
.268 .51392 L
.272 .51392 L
.276 .51392 L
.28 .51392 L
.284 .51392 L
.288 .51392 L
.292 .51392 L
.296 .51392 L
.3 .51392 L
.304 .51392 L
.308 .51392 L
.312 .51392 L
.316 .51392 L
.32 .51392 L
.324 .51392 L
.328 .51392 L
.332 .51392 L
.336 .51392 L
.34 .51392 L
.344 .51391 L
.348 .51391 L
.352 .51391 L
.356 .51392 L
.36 .51392 L
.364 .51391 L
.368 .51391 L
.372 .51391 L
.376 .51392 L
.38 .51391 L
.384 .51391 L
.388 .51391 L
.392 .51391 L
.396 .51391 L
.4 .51391 L
Mistroke
.404 .51391 L
.408 .51391 L
.412 .51391 L
.416 .51391 L
.42 .51391 L
.424 .51391 L
.428 .51391 L
.432 .51391 L
.436 .51391 L
.44 .51391 L
.444 .51391 L
.448 .51391 L
.452 .5139 L
.456 .51391 L
.46 .51391 L
.464 .51391 L
.468 .51391 L
.472 .5139 L
.476 .5139 L
.48 .51391 L
.484 .51391 L
.488 .51391 L
.492 .5139 L
.496 .5139 L
.5 .5139 L
.504 .51391 L
.508 .51391 L
.512 .5139 L
.516 .51389 L
.52 .51389 L
.524 .5139 L
.528 .51391 L
.532 .51391 L
.536 .5139 L
.54 .51389 L
.544 .51389 L
.548 .51391 L
.552 .51392 L
.556 .51391 L
.56 .51389 L
.564 .51388 L
.568 .51389 L
.572 .51391 L
.576 .51392 L
.58 .5139 L
.584 .51388 L
.588 .51387 L
.592 .51388 L
.596 .51391 L
.6 .51392 L
Mistroke
.604 .51389 L
.608 .51385 L
.612 .51384 L
.616 .51385 L
.62 .51388 L
.624 .51388 L
.628 .51383 L
.632 .51375 L
.636 .51369 L
.64 .51365 L
.644 .51363 L
.648 .51355 L
.652 .51339 L
.656 .51316 L
.66 .5129 L
.664 .51263 L
.668 .51232 L
.672 .51191 L
.676 .51135 L
.68 .51062 L
.684 .50975 L
.688 .50877 L
.692 .50769 L
.696 .50644 L
.7 .50496 L
.704 .50324 L
.708 .5013 L
.712 .4992 L
.716 .49701 L
.72 .49473 L
.724 .49236 L
.728 .48989 L
.732 .48735 L
.736 .48481 L
.74 .48237 L
.744 .48008 L
.748 .47796 L
.752 .47598 L
.756 .4741 L
.76 .47228 L
.764 .4705 L
.768 .46877 L
.772 .46708 L
.776 .46538 L
.78 .46363 L
.784 .46177 L
.788 .45977 L
.792 .45762 L
.796 .45536 L
.8 .45309 L
Mistroke
.804 .4509 L
.808 .44886 L
.812 .44699 L
.816 .44525 L
.82 .4436 L
.824 .44197 L
.828 .44037 L
.832 .43884 L
.836 .43743 L
.84 .43618 L
.844 .43507 L
.848 .43406 L
.852 .43308 L
.856 .43214 L
.86 .43133 L
.864 .4308 L
.868 .43065 L
.872 .43093 L
.876 .43154 L
.88 .43229 L
.884 .43296 L
.888 .43342 L
.892 .43363 L
.896 .4337 L
.9 .43378 L
.904 .43396 L
.908 .43426 L
.912 .43458 L
.916 .43477 L
.92 .43472 L
.924 .43438 L
.928 .43385 L
.932 .43325 L
.936 .4328 L
.94 .43259 L
.944 .4327 L
.948 .43306 L
.952 .43356 L
.956 .43407 L
.96 .43447 L
.964 .43465 L
.968 .43462 L
.972 .43431 L
.976 .43391 L
.98 .43343 L
.984 .43311 L
.988 .43299 L
.992 .43316 L
.996 .43359 L
1 .43417 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43211 L
.012 .42967 L
.016 .42906 L
.02 .42989 L
.024 .43004 L
.028 .42962 L
.032 .42956 L
.036 .42962 L
.04 .42961 L
.044 .4295 L
.048 .42947 L
.052 .42943 L
.056 .4294 L
.06 .42934 L
.064 .42931 L
.068 .42925 L
.072 .42922 L
.076 .42916 L
.08 .42913 L
.084 .42908 L
.088 .42904 L
.092 .42899 L
.096 .42895 L
.1 .4289 L
.104 .42887 L
.108 .42882 L
.112 .42878 L
.116 .42873 L
.12 .42869 L
.124 .42864 L
.128 .4286 L
.132 .42855 L
.136 .42851 L
.14 .42847 L
.144 .42843 L
.148 .42838 L
.152 .42834 L
.156 .42829 L
.16 .42825 L
.164 .4282 L
.168 .42816 L
.172 .42812 L
.176 .42807 L
.18 .42803 L
.184 .42799 L
.188 .42794 L
.192 .4279 L
.196 .42785 L
.2 .42781 L
Mistroke
.204 .42777 L
.208 .42772 L
.212 .42768 L
.216 .42763 L
.22 .42759 L
.224 .42755 L
.228 .4275 L
.232 .42746 L
.236 .42741 L
.24 .42737 L
.244 .42733 L
.248 .42728 L
.252 .42724 L
.256 .4272 L
.26 .42715 L
.264 .42711 L
.268 .42706 L
.272 .42702 L
.276 .42698 L
.28 .42693 L
.284 .42689 L
.288 .42684 L
.292 .4268 L
.296 .42676 L
.3 .42671 L
.304 .42667 L
.308 .42662 L
.312 .42658 L
.316 .42654 L
.32 .4265 L
.324 .42645 L
.328 .4264 L
.332 .42636 L
.336 .42632 L
.34 .42628 L
.344 .42623 L
.348 .42619 L
.352 .42614 L
.356 .4261 L
.36 .42606 L
.364 .42601 L
.368 .42597 L
.372 .42592 L
.376 .42588 L
.38 .42584 L
.384 .42579 L
.388 .42575 L
.392 .4257 L
.396 .42566 L
.4 .42562 L
Mistroke
.404 .42557 L
.408 .42553 L
.412 .42548 L
.416 .42544 L
.42 .4254 L
.424 .42535 L
.428 .42531 L
.432 .42526 L
.436 .42522 L
.44 .42518 L
.444 .42514 L
.448 .42509 L
.452 .42504 L
.456 .425 L
.46 .42496 L
.464 .42492 L
.468 .42487 L
.472 .42482 L
.476 .42478 L
.48 .42474 L
.484 .4247 L
.488 .42466 L
.492 .4246 L
.496 .42455 L
.5 .42452 L
.504 .42449 L
.508 .42444 L
.512 .42439 L
.516 .42433 L
.52 .42429 L
.524 .42426 L
.528 .42423 L
.532 .42418 L
.536 .42412 L
.54 .42406 L
.544 .42403 L
.548 .424 L
.552 .42397 L
.556 .42392 L
.56 .42385 L
.564 .42379 L
.568 .42377 L
.572 .42375 L
.576 .42372 L
.58 .42365 L
.584 .42358 L
.588 .42352 L
.592 .42351 L
.596 .4235 L
.6 .42347 L
Mistroke
.604 .4234 L
.608 .42332 L
.612 .42327 L
.616 .42327 L
.62 .42329 L
.624 .42328 L
.628 .42324 L
.632 .42318 L
.636 .42316 L
.64 .42322 L
.644 .42334 L
.648 .42346 L
.652 .42355 L
.656 .42366 L
.66 .42386 L
.664 .42419 L
.668 .42467 L
.672 .42524 L
.676 .42588 L
.68 .42662 L
.684 .42752 L
.688 .42867 L
.692 .4301 L
.696 .43177 L
.7 .43363 L
.704 .43565 L
.708 .43786 L
.712 .44032 L
.716 .44304 L
.72 .44598 L
.724 .44905 L
.728 .45212 L
.732 .45515 L
.736 .45811 L
.74 .46101 L
.744 .46385 L
.748 .46659 L
.752 .46917 L
.756 .47155 L
.76 .47372 L
.764 .47574 L
.768 .47773 L
.772 .47976 L
.776 .48192 L
.78 .48422 L
.784 .48665 L
.788 .48916 L
.792 .49172 L
.796 .49432 L
.8 .49693 L
Mistroke
.804 .49956 L
.808 .50218 L
.812 .50472 L
.816 .5071 L
.82 .50922 L
.824 .51108 L
.828 .51272 L
.832 .51428 L
.836 .51589 L
.84 .5176 L
.844 .51936 L
.848 .52102 L
.852 .52237 L
.856 .52329 L
.86 .52376 L
.864 .52389 L
.868 .52382 L
.872 .52367 L
.876 .52346 L
.88 .52313 L
.884 .52259 L
.888 .52184 L
.892 .52095 L
.896 .52011 L
.9 .51951 L
.904 .51927 L
.908 .51936 L
.912 .51969 L
.916 .52005 L
.92 .52033 L
.924 .52043 L
.928 .52045 L
.932 .52043 L
.936 .5205 L
.94 .52063 L
.944 .5208 L
.948 .52089 L
.952 .52083 L
.956 .52062 L
.96 .52028 L
.964 .51989 L
.968 .5196 L
.972 .51934 L
.976 .51929 L
.98 .51926 L
.984 .51937 L
.988 .51953 L
.992 .51976 L
.996 .52005 L
1 .52035 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`03001oogoo0080009oo`07001oogooOol007oo00001Woo00@0
07ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@0
07ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`@000=oo`<0009oo`D000=oo`8000Ioo`008Woo
00<007ooOol0DWoo0P000Woo00<007ooOol00`000Woo00<007ooOol02goo000ROol2000aOol00`00
Ool0000300000goo001oo`02000GOol00`00Ool000020002Ool00`00Ool00002Ool00`00Oomoo`0;
Ool0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00@007ooOol000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00002Ool00`00Ool000020003Ool01@00Oomoogoo00000goo00T007oo
Oomoo`00Ool007oo00000goo0P000Woo0`0000=oo`00Ool02goo000ROol20010Ool00`00Oomoo`0?
Ool00`00Oomoo`03Ool20003Ool00`00Oomoo`0=Ool0029oo`03001oogoo03moo`03001oogoo00io
o`8001Yoo`008Woo0P00@Goo0P003Goo0P006goo000ROol20012Ool00`00Oomoo`0:Ool2000LOol0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo045oo`03001oogoo00Aoo`80
00=oo`8001eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20012Ool0
0`00Oomoo`03Ool400000goo001oo`0NOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P00@goo00D007ooOomoo`0000=oo`<001moo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`13Ool01000Oomoo`000goo0P0087oo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8004Aoo`<002Ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03
001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007oo
Ool000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006io
o`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`00
0goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001o
o`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0
029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol0
00=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`00
2goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Io
o`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yo
o`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol0
00=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001X
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]o
o`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Ao
o`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00
Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03
001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0
3Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool0
1000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=o
o`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo
00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000
Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomo
o`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P00
0goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomo
o`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo04]oo`D0
009oo`<0009oo`8000eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool0
00Ioo`03001oogoo04Qoo`@000=oo`@0009oo`80009oo`03001oogoo00Yoo`002goo0P002Woo0P00
17oo0P000Woo1@000Woo00<007ooOol0AWoo0`007Goo000XOol00`00Oomoo`14Ool3000OOol002Qo
o`03001oogoo049oo`<0025oo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007oo
Ool0@7oo0`008goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo03ioo`<002Eoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`0lOol3000WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo?`00
:Woo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`80
00Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo
00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool0
1000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001o
ogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04
001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001o
ogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1b
Ool001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Ao
o`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007oo
Oomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol0
0goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol0
07oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol0
00Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol0
07oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P00
17oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=o
o`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D0
07ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo
008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qo
o`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo031ooa<002moo`00
5goo00<007ooOol00Woo<`004goo1000:goo000GOol00`00Oomoo`02Ool00`00Oomoo`16Ool2000Z
Ool001Moo`03001oogoo009oo`03001oogoo04Qoo`03001oogoo02Moo`005Woo0P0017oo0P00BWoo
0P009goo000GOol00`00Oomoo`02Ool00`00Oomoo`1:Ool2000VOol001aoo`03001oogoo04aoo`80
02Aoo`0077oo0P00Cgoo0P008Woo000LOol00`00Oomoo`1?Ool2000QOol001aoo`80059oo`8001mo
o`0077oo00<007ooOol0Dgoo0`000goo3@0037oo000LOol00`00Oomoo`1EOol5000HOol000Yoo`<0
00Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009o
o`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo
00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uo
o`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(8183\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30219 m
.008 .30055 L
.012 .29955 L
.016 .29942 L
.02 .30026 L
.024 .30055 L
.028 .30011 L
.032 .29991 L
.036 .30009 L
.04 .30019 L
.044 .30011 L
.048 .30005 L
.052 .30007 L
.056 .30009 L
.06 .30007 L
.064 .30005 L
.068 .30005 L
.072 .30005 L
.076 .30005 L
.08 .30004 L
.084 .30003 L
.088 .30003 L
.092 .30002 L
.096 .30001 L
.1 .3 L
.104 .3 L
.108 .3 L
.112 .29999 L
.116 .29998 L
.12 .29998 L
.124 .29998 L
.128 .29997 L
.132 .29995 L
.136 .29995 L
.14 .29996 L
.144 .29995 L
.148 .29993 L
.152 .29992 L
.156 .29993 L
.16 .29993 L
.164 .29991 L
.168 .29989 L
.172 .2999 L
.176 .29991 L
.18 .29989 L
.184 .29987 L
.188 .29987 L
.192 .29988 L
.196 .29988 L
.2 .29985 L
Mistroke
.204 .29983 L
.208 .29985 L
.212 .29987 L
.216 .29984 L
.22 .2998 L
.224 .29981 L
.228 .29984 L
.232 .29984 L
.236 .29979 L
.24 .29976 L
.244 .2998 L
.248 .29982 L
.252 .29979 L
.256 .29974 L
.26 .29974 L
.264 .29979 L
.268 .2998 L
.272 .29974 L
.276 .29969 L
.28 .29973 L
.284 .29978 L
.288 .29977 L
.292 .29969 L
.296 .29966 L
.3 .29972 L
.304 .29977 L
.308 .29972 L
.312 .29963 L
.316 .29963 L
.32 .29971 L
.324 .29975 L
.328 .29967 L
.332 .29958 L
.336 .2996 L
.34 .29971 L
.344 .29973 L
.348 .29963 L
.352 .29953 L
.356 .29957 L
.36 .29969 L
.364 .29971 L
.368 .29959 L
.372 .29949 L
.376 .29954 L
.38 .29967 L
.384 .2997 L
.388 .29957 L
.392 .29945 L
.396 .29949 L
.4 .29964 L
Mistroke
.404 .29969 L
.408 .29956 L
.412 .29941 L
.416 .29943 L
.42 .29958 L
.424 .29968 L
.428 .29958 L
.432 .2994 L
.436 .29935 L
.44 .2995 L
.444 .29966 L
.448 .29962 L
.452 .29942 L
.456 .29928 L
.46 .29937 L
.464 .29959 L
.468 .29968 L
.472 .29951 L
.476 .29925 L
.48 .29921 L
.484 .29944 L
.488 .2997 L
.492 .29966 L
.496 .29933 L
.5 .29906 L
.504 .29918 L
.508 .29958 L
.512 .29982 L
.516 .29957 L
.52 .29907 L
.524 .29888 L
.528 .29925 L
.532 .29982 L
.536 .29992 L
.54 .29938 L
.544 .29874 L
.548 .29874 L
.552 .29945 L
.556 .30013 L
.56 .3 L
.564 .29911 L
.568 .29841 L
.572 .29873 L
.576 .29986 L
.58 .30065 L
.584 .30027 L
.588 .2991 L
.592 .29851 L
.596 .29937 L
.6 .30115 L
Mistroke
.604 .30235 L
.608 .30209 L
.612 .30112 L
.616 .3012 L
.62 .30334 L
.624 .30675 L
.628 .30959 L
.632 .31091 L
.636 .31169 L
.64 .31406 L
.644 .31927 L
.648 .32643 L
.652 .33335 L
.656 .33868 L
.66 .34323 L
.664 .34926 L
.668 .35825 L
.672 .36932 L
.676 .37986 L
.68 .38768 L
.684 .39279 L
.688 .39717 L
.692 .40265 L
.696 .40899 L
.7 .41381 L
.704 .41454 L
.708 .41058 L
.712 .40383 L
.716 .39718 L
.72 .39227 L
.724 .38856 L
.728 .38426 L
.732 .37837 L
.736 .37192 L
.74 .36741 L
.744 .36701 L
.748 .37099 L
.752 .37754 L
.756 .38401 L
.76 .38852 L
.764 .39072 L
.768 .39136 L
.772 .39122 L
.776 .39036 L
.78 .38821 L
.784 .38406 L
.788 .37788 L
.792 .37037 L
.796 .36285 L
.8 .35671 L
Mistroke
.804 .35296 L
.808 .35189 L
.812 .3527 L
.816 .3536 L
.82 .35216 L
.824 .34638 L
.828 .33577 L
.832 .32184 L
.836 .30773 L
.84 .2965 L
.844 .28975 L
.848 .28671 L
.852 .28504 L
.856 .28269 L
.86 .27926 L
.864 .27675 L
.868 .27788 L
.872 .28422 L
.876 .29463 L
.88 .30528 L
.884 .31198 L
.888 .31237 L
.892 .30751 L
.896 .30159 L
.9 .29893 L
.904 .30189 L
.908 .3089 L
.912 .31514 L
.916 .31609 L
.92 .30881 L
.924 .29575 L
.928 .28208 L
.932 .2739 L
.936 .27589 L
.94 .28667 L
.944 .3028 L
.948 .31716 L
.952 .32423 L
.956 .32268 L
.96 .31283 L
.964 .30052 L
.968 .28961 L
.972 .28352 L
.976 .2839 L
.98 .28805 L
.984 .29508 L
.988 .30201 L
.992 .30761 L
.996 .31193 L
1 .31373 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51137 m
.008 .51382 L
.012 .51459 L
.016 .51355 L
.02 .51339 L
.024 .51376 L
.028 .51383 L
.032 .51366 L
.036 .51367 L
.04 .51371 L
.044 .51373 L
.048 .51369 L
.052 .5137 L
.056 .5137 L
.06 .51371 L
.064 .51369 L
.068 .51371 L
.072 .5137 L
.076 .51371 L
.08 .5137 L
.084 .5137 L
.088 .5137 L
.092 .5137 L
.096 .5137 L
.1 .5137 L
.104 .5137 L
.108 .5137 L
.112 .5137 L
.116 .5137 L
.12 .5137 L
.124 .5137 L
.128 .5137 L
.132 .5137 L
.136 .5137 L
.14 .5137 L
.144 .5137 L
.148 .5137 L
.152 .5137 L
.156 .5137 L
.16 .5137 L
.164 .5137 L
.168 .5137 L
.172 .5137 L
.176 .5137 L
.18 .5137 L
.184 .5137 L
.188 .5137 L
.192 .5137 L
.196 .5137 L
.2 .5137 L
Mistroke
.204 .5137 L
.208 .5137 L
.212 .5137 L
.216 .5137 L
.22 .5137 L
.224 .5137 L
.228 .5137 L
.232 .5137 L
.236 .5137 L
.24 .5137 L
.244 .5137 L
.248 .5137 L
.252 .5137 L
.256 .5137 L
.26 .5137 L
.264 .5137 L
.268 .51369 L
.272 .51369 L
.276 .51369 L
.28 .5137 L
.284 .51369 L
.288 .51369 L
.292 .51369 L
.296 .51369 L
.3 .51369 L
.304 .51369 L
.308 .51369 L
.312 .51369 L
.316 .51369 L
.32 .51369 L
.324 .51369 L
.328 .51369 L
.332 .51369 L
.336 .51369 L
.34 .51369 L
.344 .51369 L
.348 .51369 L
.352 .51369 L
.356 .51369 L
.36 .51369 L
.364 .51369 L
.368 .51369 L
.372 .51369 L
.376 .51369 L
.38 .51369 L
.384 .51369 L
.388 .51369 L
.392 .51369 L
.396 .51369 L
.4 .51369 L
Mistroke
.404 .51369 L
.408 .51368 L
.412 .51369 L
.416 .51369 L
.42 .51369 L
.424 .51369 L
.428 .51368 L
.432 .51368 L
.436 .51369 L
.44 .51369 L
.444 .51369 L
.448 .51368 L
.452 .51368 L
.456 .51368 L
.46 .51369 L
.464 .51369 L
.468 .51368 L
.472 .51368 L
.476 .51368 L
.48 .51368 L
.484 .51369 L
.488 .51368 L
.492 .51368 L
.496 .51367 L
.5 .51368 L
.504 .51369 L
.508 .51368 L
.512 .51368 L
.516 .51367 L
.52 .51367 L
.524 .51368 L
.528 .51369 L
.532 .51368 L
.536 .51367 L
.54 .51366 L
.544 .51367 L
.548 .51368 L
.552 .51369 L
.556 .51367 L
.56 .51366 L
.564 .51366 L
.568 .51367 L
.572 .51368 L
.576 .51368 L
.58 .51366 L
.584 .51363 L
.588 .51363 L
.592 .51364 L
.596 .51364 L
.6 .51361 L
Mistroke
.604 .51356 L
.608 .5135 L
.612 .51344 L
.616 .5134 L
.62 .51333 L
.624 .51319 L
.628 .513 L
.632 .51275 L
.636 .51249 L
.64 .51218 L
.644 .51179 L
.648 .51126 L
.652 .51058 L
.656 .50977 L
.66 .50884 L
.664 .5078 L
.668 .50659 L
.672 .50515 L
.676 .50349 L
.68 .50162 L
.684 .49961 L
.688 .49749 L
.692 .49525 L
.696 .49289 L
.7 .4904 L
.704 .48785 L
.708 .48532 L
.712 .4829 L
.716 .48061 L
.72 .47844 L
.724 .47637 L
.728 .47437 L
.732 .47247 L
.736 .47069 L
.74 .46903 L
.744 .46742 L
.748 .46577 L
.752 .46401 L
.756 .4621 L
.76 .46007 L
.764 .45796 L
.768 .45582 L
.772 .45369 L
.776 .45156 L
.78 .44947 L
.784 .44743 L
.788 .44548 L
.792 .44368 L
.796 .44205 L
.8 .44058 L
Mistroke
.804 .43923 L
.808 .43794 L
.812 .43665 L
.816 .43536 L
.82 .43409 L
.824 .43293 L
.828 .43198 L
.832 .43133 L
.836 .43099 L
.84 .43093 L
.844 .43107 L
.848 .43133 L
.852 .43166 L
.856 .43207 L
.86 .43256 L
.864 .43313 L
.868 .43371 L
.872 .43419 L
.876 .43447 L
.88 .4345 L
.884 .43433 L
.888 .43408 L
.892 .43386 L
.896 .43375 L
.9 .43372 L
.904 .4337 L
.908 .43356 L
.912 .43332 L
.916 .433 L
.92 .43276 L
.924 .43274 L
.928 .43301 L
.932 .43351 L
.936 .43409 L
.94 .43452 L
.944 .43469 L
.948 .43448 L
.952 .43407 L
.956 .43354 L
.96 .43313 L
.964 .43296 L
.968 .43305 L
.972 .43336 L
.976 .43377 L
.98 .43414 L
.984 .43441 L
.988 .43446 L
.992 .43439 L
.996 .43411 L
1 .43382 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43417 L
.012 .42994 L
.016 .42846 L
.02 .4297 L
.024 .43021 L
.028 .42972 L
.032 .42952 L
.036 .42958 L
.04 .42963 L
.044 .42952 L
.048 .42947 L
.052 .42942 L
.056 .4294 L
.06 .42934 L
.064 .42931 L
.068 .42925 L
.072 .42922 L
.076 .42917 L
.08 .42913 L
.084 .42908 L
.088 .42904 L
.092 .42899 L
.096 .42896 L
.1 .4289 L
.104 .42887 L
.108 .42882 L
.112 .42878 L
.116 .42873 L
.12 .42869 L
.124 .42864 L
.128 .4286 L
.132 .42856 L
.136 .42851 L
.14 .42847 L
.144 .42843 L
.148 .42838 L
.152 .42834 L
.156 .42829 L
.16 .42825 L
.164 .42821 L
.168 .42816 L
.172 .42812 L
.176 .42808 L
.18 .42803 L
.184 .42799 L
.188 .42794 L
.192 .4279 L
.196 .42785 L
.2 .42781 L
Mistroke
.204 .42777 L
.208 .42772 L
.212 .42768 L
.216 .42764 L
.22 .42759 L
.224 .42755 L
.228 .4275 L
.232 .42746 L
.236 .42742 L
.24 .42737 L
.244 .42733 L
.248 .42729 L
.252 .42724 L
.256 .4272 L
.26 .42715 L
.264 .42711 L
.268 .42707 L
.272 .42702 L
.276 .42698 L
.28 .42694 L
.284 .42689 L
.288 .42685 L
.292 .4268 L
.296 .42676 L
.3 .42672 L
.304 .42667 L
.308 .42663 L
.312 .42658 L
.316 .42654 L
.32 .4265 L
.324 .42645 L
.328 .42641 L
.332 .42636 L
.336 .42632 L
.34 .42628 L
.344 .42623 L
.348 .42619 L
.352 .42615 L
.356 .4261 L
.36 .42606 L
.364 .42601 L
.368 .42597 L
.372 .42593 L
.376 .42588 L
.38 .42584 L
.384 .42579 L
.388 .42575 L
.392 .42571 L
.396 .42567 L
.4 .42562 L
Mistroke
.404 .42557 L
.408 .42553 L
.412 .42549 L
.416 .42545 L
.42 .4254 L
.424 .42536 L
.428 .42531 L
.432 .42527 L
.436 .42523 L
.44 .42519 L
.444 .42514 L
.448 .42509 L
.452 .42505 L
.456 .42501 L
.46 .42497 L
.464 .42492 L
.468 .42487 L
.472 .42482 L
.476 .42478 L
.48 .42475 L
.484 .42471 L
.488 .42466 L
.492 .42461 L
.496 .42456 L
.5 .42452 L
.504 .42449 L
.508 .42444 L
.512 .42439 L
.516 .42434 L
.52 .4243 L
.524 .42427 L
.528 .42423 L
.532 .42418 L
.536 .42412 L
.54 .42407 L
.544 .42404 L
.548 .42401 L
.552 .42397 L
.556 .42391 L
.56 .42385 L
.564 .42381 L
.568 .42378 L
.572 .42376 L
.576 .42372 L
.58 .42366 L
.584 .4236 L
.588 .42357 L
.592 .42357 L
.596 .42357 L
.6 .42355 L
Mistroke
.604 .42351 L
.608 .42349 L
.612 .42352 L
.616 .4236 L
.62 .42371 L
.624 .42382 L
.628 .42394 L
.632 .42413 L
.636 .42443 L
.64 .42485 L
.644 .42538 L
.648 .42599 L
.652 .4267 L
.656 .42757 L
.66 .42867 L
.664 .43002 L
.668 .4316 L
.672 .43337 L
.676 .43531 L
.68 .43746 L
.684 .43988 L
.688 .44256 L
.692 .44544 L
.696 .44843 L
.7 .45144 L
.704 .45444 L
.708 .45744 L
.712 .46043 L
.716 .46338 L
.72 .46618 L
.724 .46877 L
.728 .47112 L
.732 .47329 L
.736 .47539 L
.74 .47748 L
.744 .4796 L
.748 .48175 L
.752 .48392 L
.756 .48616 L
.76 .48851 L
.764 .49101 L
.768 .49367 L
.772 .49643 L
.776 .49918 L
.78 .50182 L
.784 .50428 L
.788 .50653 L
.792 .50861 L
.796 .51057 L
.8 .51244 L
Mistroke
.804 .51425 L
.808 .51598 L
.812 .51761 L
.816 .51912 L
.82 .52048 L
.824 .5217 L
.828 .52277 L
.832 .52366 L
.836 .52431 L
.84 .52462 L
.844 .52453 L
.848 .52404 L
.852 .52327 L
.856 .52239 L
.86 .5216 L
.864 .52105 L
.868 .52072 L
.872 .52053 L
.876 .52034 L
.88 .52007 L
.884 .51974 L
.888 .5195 L
.892 .51948 L
.896 .51978 L
.9 .52034 L
.904 .52099 L
.908 .52148 L
.912 .52168 L
.916 .5215 L
.92 .52106 L
.924 .52054 L
.928 .5201 L
.932 .51987 L
.936 .51983 L
.94 .5199 L
.944 .52001 L
.948 .52002 L
.952 .52002 L
.956 .51994 L
.96 .5199 L
.964 .5199 L
.968 .51993 L
.972 .51998 L
.976 .52001 L
.98 .52 L
.984 .51998 L
.988 .51986 L
.992 .51976 L
.996 .51954 L
1 .51935 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool30004Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo051oo`<000Eoo`80009oo`8000ioo`008Woo0P00<goo100000=oo`00Ool05Woo00@007oo
Ool000Aoo`07001oo`00Ool007oo00003Woo000ROomS000<Ool0029oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`04001oogoo0003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01P00Oomoogoo001oo`<0009oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00@007ooOomoo`800007Ool00000Ool007oo00000Woo0P00
37oo000ROol2000mOol00`00Oomoo`0?Ool00`00Oomoo`09Ool00`00Oomoo`0?Ool0029oo`03001o
ogoo03eoo`03001oogoo00ioo`03001oogoo01]oo`008Woo0P00?Woo0P003Woo00<007ooOol077oo
000ROol2000oOol00`00Oomoo`0:Ool3000NOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`03001oogoo03moo`03001oogoo00=oo`8000=oo`80021oo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool20010Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`0OOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00@7oo00<007ooOol00Woo
00<007ooOol010008Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo041oo`04001oogoo0004Ool00`00Oomoo`0QOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P00@Woo0`00:7oo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`80049oo`8002Uoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo
000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@0
07ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:
Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo
0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomo
o`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000
Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool2
0004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Mo
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<0
07ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo
0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P00
1goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@00
0Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`04
0003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo
00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00
Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomo
ogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002
Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00
Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09
Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool2
0003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=o
o`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool2
0004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001o
ogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]o
o`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0B7oo1@000Woo10000Woo
0P003goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007oo
Ool0AWoo0`0017oo0`000goo0P0000=oo`0000000P0037oo000;Ool2000:Ool20004Ool20002Ool5
0002Ool00`00Oomoo`14Ool2000POol002Qoo`03001oogoo049oo`80029oo`00:7oo00<007ooOol0
?goo0`0097oo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0mOol3000V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0?7oo0P00
:7oo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo03Uoo`@0
02Uoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Oolm000/Ool0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007oo
Ool00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1V
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001X
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D0
06]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00
0goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079o
o`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04
001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<0
07ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@00
0goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo
00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomo
o`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03
001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool0
1000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo
00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool0
1000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo0000
0goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000;
Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:
Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2
001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Ioo`<000=o
o`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0<7oo4000<Woo000GOol00`00Oomo
o`02Oolc000?Ool5000^Ool001Moo`03001oogoo009oo`03001oogoo04=oo`8002eoo`005goo00<0
07ooOol00Woo00<007ooOol0AGoo0P00:goo000FOol20004Ool20017Ool2000ZOol001Moo`03001o
ogoo009oo`03001oogoo04Qoo`03001oogoo02Moo`0077oo00<007ooOol0BGoo0`009Woo000LOol2
001<Ool2000UOol001aoo`03001oogoo04eoo`8002=oo`0077oo0P00Cgoo0P008Woo000LOol00`00
Oomoo`1@Ool30004Ool?000<Ool001aoo`03001oogoo059oo`D000Aoo`8001Eoo`002Woo0`0017oo
00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00
Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<0
07ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001o
ogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(8350\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .2994 m
.008 .29938 L
.012 .30055 L
.016 .30071 L
.02 .29994 L
.024 .29986 L
.028 .30027 L
.032 .30029 L
.036 .30008 L
.04 .30007 L
.044 .30016 L
.048 .30015 L
.052 .3001 L
.056 .30009 L
.06 .30011 L
.064 .3001 L
.068 .30009 L
.072 .30008 L
.076 .30008 L
.08 .30007 L
.084 .30006 L
.088 .30006 L
.092 .30006 L
.096 .30005 L
.1 .30004 L
.104 .30003 L
.108 .30004 L
.112 .30003 L
.116 .30002 L
.12 .30001 L
.124 .30001 L
.128 .30001 L
.132 .29999 L
.136 .29998 L
.14 .29999 L
.144 .29998 L
.148 .29997 L
.152 .29996 L
.156 .29996 L
.16 .29996 L
.164 .29995 L
.168 .29993 L
.172 .29993 L
.176 .29994 L
.18 .29993 L
.184 .29991 L
.188 .2999 L
.192 .29991 L
.196 .29992 L
.2 .29989 L
Mistroke
.204 .29987 L
.208 .29988 L
.212 .2999 L
.216 .29988 L
.22 .29985 L
.224 .29984 L
.228 .29986 L
.232 .29987 L
.236 .29984 L
.24 .2998 L
.244 .29982 L
.248 .29985 L
.252 .29984 L
.256 .29979 L
.26 .29977 L
.264 .29981 L
.268 .29983 L
.272 .29979 L
.276 .29974 L
.28 .29975 L
.284 .2998 L
.288 .2998 L
.292 .29974 L
.296 .2997 L
.3 .29974 L
.304 .29979 L
.308 .29977 L
.312 .29968 L
.316 .29966 L
.32 .29973 L
.324 .29978 L
.328 .29972 L
.332 .29963 L
.336 .29963 L
.34 .29972 L
.344 .29976 L
.348 .29968 L
.352 .29958 L
.356 .2996 L
.36 .29971 L
.364 .29974 L
.368 .29964 L
.372 .29954 L
.376 .29957 L
.38 .29969 L
.384 .29972 L
.388 .29961 L
.392 .2995 L
.396 .29953 L
.4 .29966 L
Mistroke
.404 .29971 L
.408 .2996 L
.412 .29946 L
.416 .29948 L
.42 .29962 L
.424 .2997 L
.428 .2996 L
.432 .29944 L
.436 .29941 L
.44 .29955 L
.444 .29968 L
.448 .29963 L
.452 .29945 L
.456 .29934 L
.46 .29944 L
.464 .29963 L
.468 .29967 L
.472 .2995 L
.476 .2993 L
.48 .2993 L
.484 .29952 L
.488 .2997 L
.492 .29962 L
.496 .29933 L
.5 .29916 L
.504 .29932 L
.508 .29964 L
.512 .29976 L
.516 .2995 L
.52 .29911 L
.524 .29906 L
.528 .29944 L
.532 .29985 L
.536 .29982 L
.54 .29933 L
.544 .29893 L
.548 .29913 L
.552 .29982 L
.556 .30032 L
.56 .30011 L
.564 .2995 L
.568 .29933 L
.572 .30011 L
.576 .3014 L
.58 .30225 L
.584 .30225 L
.588 .30211 L
.592 .303 L
.596 .30533 L
.6 .30832 L
Mistroke
.604 .31077 L
.608 .31246 L
.612 .31454 L
.616 .31843 L
.62 .32443 L
.624 .33131 L
.628 .33759 L
.632 .34305 L
.636 .34904 L
.64 .3571 L
.644 .36724 L
.648 .37768 L
.652 .38632 L
.656 .3926 L
.66 .39781 L
.664 .40359 L
.668 .40997 L
.672 .41499 L
.676 .4163 L
.68 .41327 L
.684 .40762 L
.688 .40197 L
.692 .39762 L
.696 .39367 L
.7 .38832 L
.704 .381 L
.708 .3735 L
.712 .36884 L
.716 .36895 L
.72 .37316 L
.724 .37879 L
.728 .38327 L
.732 .38593 L
.736 .38798 L
.74 .39083 L
.744 .39431 L
.748 .39648 L
.752 .39495 L
.756 .38889 L
.76 .37977 L
.764 .37054 L
.768 .36372 L
.772 .36009 L
.776 .3586 L
.78 .35747 L
.784 .35542 L
.788 .35216 L
.792 .34799 L
.796 .3431 L
.8 .33715 L
Mistroke
.804 .32955 L
.808 .31989 L
.812 .3085 L
.816 .29641 L
.82 .28525 L
.824 .27686 L
.828 .27274 L
.832 .27366 L
.836 .27892 L
.84 .28658 L
.844 .29376 L
.848 .29806 L
.852 .29882 L
.856 .29753 L
.86 .29714 L
.864 .30018 L
.868 .3069 L
.872 .31491 L
.876 .32001 L
.88 .31896 L
.884 .31135 L
.888 .29995 L
.892 .28991 L
.896 .28498 L
.9 .28661 L
.904 .29255 L
.908 .29859 L
.912 .30191 L
.916 .30117 L
.92 .29899 L
.924 .29824 L
.928 .30069 L
.932 .30632 L
.936 .31116 L
.94 .31256 L
.944 .30818 L
.948 .29914 L
.952 .28985 L
.956 .28375 L
.96 .28452 L
.964 .29147 L
.968 .30148 L
.972 .31081 L
.976 .31534 L
.98 .31424 L
.984 .30851 L
.988 .30073 L
.992 .2936 L
.996 .28939 L
1 .28816 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .50737 m
.008 .51342 L
.012 .51551 L
.016 .51351 L
.02 .51282 L
.024 .51343 L
.028 .51371 L
.032 .51348 L
.036 .51341 L
.04 .51346 L
.044 .51351 L
.048 .51347 L
.052 .51348 L
.056 .51347 L
.06 .51349 L
.064 .51347 L
.068 .51348 L
.072 .51347 L
.076 .51348 L
.08 .51347 L
.084 .51348 L
.088 .51347 L
.092 .51348 L
.096 .51347 L
.1 .51348 L
.104 .51347 L
.108 .51348 L
.112 .51347 L
.116 .51348 L
.12 .51347 L
.124 .51348 L
.128 .51347 L
.132 .51348 L
.136 .51347 L
.14 .51348 L
.144 .51347 L
.148 .51348 L
.152 .51347 L
.156 .51348 L
.16 .51347 L
.164 .51348 L
.168 .51347 L
.172 .51348 L
.176 .51347 L
.18 .51347 L
.184 .51347 L
.188 .51347 L
.192 .51347 L
.196 .51347 L
.2 .51347 L
Mistroke
.204 .51347 L
.208 .51347 L
.212 .51347 L
.216 .51347 L
.22 .51347 L
.224 .51347 L
.228 .51347 L
.232 .51347 L
.236 .51347 L
.24 .51347 L
.244 .51347 L
.248 .51347 L
.252 .51347 L
.256 .51347 L
.26 .51347 L
.264 .51347 L
.268 .51347 L
.272 .51347 L
.276 .51347 L
.28 .51347 L
.284 .51347 L
.288 .51347 L
.292 .51347 L
.296 .51347 L
.3 .51347 L
.304 .51347 L
.308 .51347 L
.312 .51347 L
.316 .51347 L
.32 .51347 L
.324 .51347 L
.328 .51347 L
.332 .51347 L
.336 .51347 L
.34 .51347 L
.344 .51347 L
.348 .51347 L
.352 .51347 L
.356 .51347 L
.36 .51347 L
.364 .51347 L
.368 .51346 L
.372 .51346 L
.376 .51347 L
.38 .51347 L
.384 .51346 L
.388 .51346 L
.392 .51346 L
.396 .51346 L
.4 .51346 L
Mistroke
.404 .51346 L
.408 .51346 L
.412 .51346 L
.416 .51346 L
.42 .51346 L
.424 .51346 L
.428 .51346 L
.432 .51346 L
.436 .51346 L
.44 .51346 L
.444 .51346 L
.448 .51346 L
.452 .51346 L
.456 .51346 L
.46 .51346 L
.464 .51346 L
.468 .51346 L
.472 .51345 L
.476 .51346 L
.48 .51346 L
.484 .51346 L
.488 .51346 L
.492 .51345 L
.496 .51345 L
.5 .51346 L
.504 .51346 L
.508 .51346 L
.512 .51345 L
.516 .51345 L
.52 .51345 L
.524 .51346 L
.528 .51346 L
.532 .51345 L
.536 .51344 L
.54 .51344 L
.544 .51345 L
.548 .51345 L
.552 .51345 L
.556 .51343 L
.56 .51341 L
.564 .5134 L
.568 .5134 L
.572 .51339 L
.576 .51336 L
.58 .5133 L
.584 .51324 L
.588 .51318 L
.592 .51311 L
.596 .513 L
.6 .51283 L
Mistroke
.604 .51261 L
.608 .51234 L
.612 .51203 L
.616 .51165 L
.62 .51116 L
.624 .51054 L
.628 .50978 L
.632 .50889 L
.636 .50787 L
.64 .5067 L
.644 .50533 L
.648 .50375 L
.652 .50196 L
.656 .50001 L
.66 .49793 L
.664 .49572 L
.668 .49338 L
.672 .49092 L
.676 .48839 L
.68 .48587 L
.684 .48344 L
.688 .48111 L
.692 .47888 L
.696 .47673 L
.7 .47468 L
.704 .47275 L
.708 .47097 L
.712 .46931 L
.716 .46769 L
.72 .46603 L
.724 .46427 L
.728 .46239 L
.732 .46044 L
.736 .45843 L
.74 .45638 L
.744 .45426 L
.748 .45208 L
.752 .44989 L
.756 .44777 L
.76 .4458 L
.764 .44402 L
.768 .44242 L
.772 .44093 L
.776 .4395 L
.78 .4381 L
.784 .43675 L
.788 .43547 L
.792 .43429 L
.796 .43324 L
.8 .43233 L
Mistroke
.804 .43157 L
.808 .43102 L
.812 .43069 L
.816 .43063 L
.82 .43084 L
.824 .43128 L
.828 .43187 L
.832 .43251 L
.836 .43308 L
.84 .43351 L
.844 .43378 L
.848 .43394 L
.852 .43403 L
.856 .43412 L
.86 .4342 L
.864 .43422 L
.868 .43412 L
.872 .43385 L
.876 .43345 L
.88 .43304 L
.884 .43273 L
.888 .43265 L
.892 .43278 L
.896 .43308 L
.9 .4334 L
.904 .43364 L
.908 .43376 L
.912 .4338 L
.916 .43379 L
.92 .43383 L
.924 .43386 L
.928 .43389 L
.932 .43381 L
.936 .43363 L
.94 .43338 L
.944 .43317 L
.948 .43311 L
.952 .43324 L
.956 .43354 L
.96 .43392 L
.964 .4342 L
.968 .43433 L
.972 .43421 L
.976 .43396 L
.98 .43362 L
.984 .43337 L
.988 .43324 L
.992 .43332 L
.996 .43352 L
1 .43383 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42855 L
.012 .43005 L
.016 .43038 L
.02 .42964 L
.024 .42955 L
.028 .42975 L
.032 .42974 L
.036 .42957 L
.04 .42955 L
.044 .42952 L
.048 .4295 L
.052 .42942 L
.056 .42939 L
.06 .42934 L
.064 .42931 L
.068 .42925 L
.072 .42922 L
.076 .42917 L
.08 .42913 L
.084 .42908 L
.088 .42904 L
.092 .42899 L
.096 .42896 L
.1 .4289 L
.104 .42887 L
.108 .42882 L
.112 .42878 L
.116 .42873 L
.12 .42869 L
.124 .42864 L
.128 .4286 L
.132 .42856 L
.136 .42852 L
.14 .42847 L
.144 .42843 L
.148 .42838 L
.152 .42834 L
.156 .42829 L
.16 .42825 L
.164 .42821 L
.168 .42816 L
.172 .42812 L
.176 .42808 L
.18 .42803 L
.184 .42799 L
.188 .42794 L
.192 .4279 L
.196 .42786 L
.2 .42781 L
Mistroke
.204 .42777 L
.208 .42773 L
.212 .42768 L
.216 .42764 L
.22 .42759 L
.224 .42755 L
.228 .42751 L
.232 .42746 L
.236 .42742 L
.24 .42737 L
.244 .42733 L
.248 .42729 L
.252 .42724 L
.256 .4272 L
.26 .42716 L
.264 .42711 L
.268 .42707 L
.272 .42702 L
.276 .42698 L
.28 .42694 L
.284 .42689 L
.288 .42685 L
.292 .4268 L
.296 .42676 L
.3 .42672 L
.304 .42667 L
.308 .42663 L
.312 .42659 L
.316 .42654 L
.32 .4265 L
.324 .42645 L
.328 .42641 L
.332 .42637 L
.336 .42632 L
.34 .42628 L
.344 .42624 L
.348 .42619 L
.352 .42615 L
.356 .42611 L
.36 .42606 L
.364 .42602 L
.368 .42597 L
.372 .42593 L
.376 .42589 L
.38 .42584 L
.384 .4258 L
.388 .42575 L
.392 .42571 L
.396 .42567 L
.4 .42562 L
Mistroke
.404 .42558 L
.408 .42553 L
.412 .42549 L
.416 .42545 L
.42 .42541 L
.424 .42536 L
.428 .42531 L
.432 .42527 L
.436 .42523 L
.44 .42519 L
.444 .42514 L
.448 .42509 L
.452 .42505 L
.456 .42501 L
.46 .42497 L
.464 .42492 L
.468 .42487 L
.472 .42483 L
.476 .42479 L
.48 .42475 L
.484 .42471 L
.488 .42466 L
.492 .42461 L
.496 .42457 L
.5 .42453 L
.504 .42449 L
.508 .42444 L
.512 .42439 L
.516 .42434 L
.52 .4243 L
.524 .42427 L
.528 .42423 L
.532 .42418 L
.536 .42413 L
.54 .42408 L
.544 .42405 L
.548 .42402 L
.552 .42398 L
.556 .42393 L
.56 .42389 L
.564 .42386 L
.568 .42385 L
.572 .42384 L
.576 .42383 L
.58 .42381 L
.584 .42382 L
.588 .42387 L
.592 .42397 L
.596 .42409 L
.6 .42422 L
Mistroke
.604 .4244 L
.608 .42466 L
.612 .42504 L
.616 .42553 L
.62 .42612 L
.624 .42681 L
.628 .42765 L
.632 .42868 L
.636 .42995 L
.64 .43144 L
.644 .43314 L
.648 .43503 L
.652 .43713 L
.656 .43947 L
.66 .44207 L
.664 .44487 L
.668 .4478 L
.672 .45079 L
.676 .45379 L
.68 .45682 L
.684 .45985 L
.688 .46283 L
.692 .46566 L
.696 .46828 L
.7 .47069 L
.704 .47294 L
.708 .47512 L
.712 .47725 L
.716 .47937 L
.72 .48145 L
.724 .48353 L
.728 .48569 L
.732 .488 L
.736 .49052 L
.74 .49318 L
.744 .49591 L
.748 .4986 L
.752 .50119 L
.756 .50365 L
.76 .50602 L
.764 .50827 L
.768 .51038 L
.772 .51232 L
.776 .51407 L
.78 .51567 L
.784 .5172 L
.788 .51869 L
.792 .52016 L
.796 .52157 L
.8 .52281 L
Mistroke
.804 .52377 L
.808 .52439 L
.812 .52464 L
.816 .52455 L
.82 .52421 L
.824 .52369 L
.828 .52308 L
.832 .52242 L
.836 .52176 L
.84 .52113 L
.844 .52056 L
.848 .52012 L
.852 .51987 L
.856 .51983 L
.86 .51996 L
.864 .5202 L
.868 .52043 L
.872 .5206 L
.876 .52072 L
.88 .52085 L
.884 .52104 L
.888 .52129 L
.892 .52151 L
.896 .52157 L
.9 .52136 L
.904 .52085 L
.908 .52017 L
.912 .51956 L
.916 .51923 L
.92 .51933 L
.924 .51975 L
.928 .52035 L
.932 .52082 L
.936 .52099 L
.94 .52078 L
.944 .52033 L
.948 .51983 L
.952 .51949 L
.956 .5194 L
.96 .51958 L
.964 .51981 L
.968 .52004 L
.972 .52006 L
.976 .51995 L
.98 .51969 L
.984 .51945 L
.988 .51927 L
.992 .51923 L
.996 .51927 L
1 .51939 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool2000017oo000007oo0P001Goo0`000Woo1@000goo0P001Woo
000ROol00`00Oomoo`1=Ool00`00Ool00004Ool20004Ool20003Ool00`00Oomoo`0:Ool0029oo`80
04ioo`03001oo`000080009oo`@0009oo`80009oo`03001oogoo00]oo`008WooH`0037oo000ROol0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoo`000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOomoo`80
0003Ool007oo009oo`05001oogooOol00003Ool01000Oomoogoo0P000Woo00<007ooOol00P000goo
0`0000Ioo`00000007oo000<Ool0029oo`8003]oo`03001oogoo00ioo`8000Eoo`03001oogoo01Mo
o`008Woo00<007ooOol0>Woo00<007ooOol03Woo00<007ooOol07Woo000ROol2000lOol00`00Oomo
o`0<Ool2000POol0029oo`8003aoo`03001oogoo00Yoo`<0025oo`002goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo00<007ooOol0?7oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0
8Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8003eoo`03001oogoo
00=oo`<0009oo`03001oogoo029oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2000nOol01000Oomoogoo0P0000Eoo`00001oo`0002Aoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0mOol01@00Oomoogoo000017oo00<007ooOol0
8goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8003moo`03001oo`00
02]oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool20010Ool00`00Oomoo`0ZOol0
00]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol0
0goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qo
o`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo
000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo
0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000R
Ool00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo
00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`80
00Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=o
o`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D0
07ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomo
o`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002
Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P00
2Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007oo
Ool017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007oo
Ool000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=o
o`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<0
07oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007oo
Ool000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool0
0006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool2
0004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@00
0goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol0
0`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool0
0`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool2
0004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04
001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D0
07ooOol007oo00@000=oo`03001oogoo04Ioo`D0009oo`@0009oo`<00003Ool0000000eoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo04=oo`@000=o
o`@0009oo`<0009oo`80009oo`03001oogoo00Yoo`002goo0P002Woo0P0017oo0P000Woo1@000Woo
00<007ooOol0@Goo0`008Woo000XOol00`00Oomoo`0oOol3000TOol002Qoo`03001oogoo03eoo`<0
02Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0>goo0P00:Goo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo03Uoo`<002Yoo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0gOol3000/Ool0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo>P00;goo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=o
o`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomo
o`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo
00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`80
00Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001o
ogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003
Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomo
o`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo
000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D0
07ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`00
0Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007oo
Ool000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001o
ogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007oo
Ool000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007oo
Oomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03
001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03
001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P00
17oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@0
07ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo
079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00
Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo031oo`d003Eoo`005goo00<007ooOol00Woo
<`0037oo1@00<Goo000GOol00`00Oomoo`02Ool00`00Oomoo`10Ool2000`Ool001Moo`03001oogoo
009oo`03001oogoo049oo`8002ioo`005Woo0P0017oo0P00A7oo0P00;Goo000GOol00`00Oomoo`02
Ool00`00Oomoo`15Ool2000[Ool001aoo`03001oogoo04Ioo`<002Uoo`0077oo0P00BGoo0P00:7oo
000LOol00`00Oomoo`1:Ool2000VOol001aoo`8004aoo`<002Aoo`0077oo00<007ooOol0CGoo0`00
17oo4P0037oo000LOol00`00Oomoo`1?Ool60004Ool2000GOol000Yoo`<000Aoo`03001oogoo009o
o`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo
000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03
001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(8517\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29804 m
.008 .29966 L
.012 .30087 L
.016 .30102 L
.02 .30002 L
.024 .29971 L
.028 .30022 L
.032 .30041 L
.036 .30018 L
.04 .30007 L
.044 .30015 L
.048 .3002 L
.052 .30015 L
.056 .30012 L
.06 .30014 L
.064 .30014 L
.068 .30013 L
.072 .30011 L
.076 .30011 L
.08 .30011 L
.084 .3001 L
.088 .30009 L
.092 .30009 L
.096 .30008 L
.1 .30008 L
.104 .30007 L
.108 .30007 L
.112 .30006 L
.116 .30005 L
.12 .30004 L
.124 .30004 L
.128 .30004 L
.132 .30003 L
.136 .30002 L
.14 .30002 L
.144 .30002 L
.148 .30001 L
.152 .29999 L
.156 .29999 L
.16 .29999 L
.164 .29999 L
.168 .29997 L
.172 .29996 L
.176 .29997 L
.18 .29997 L
.184 .29995 L
.188 .29993 L
.192 .29994 L
.196 .29995 L
.2 .29993 L
Mistroke
.204 .29991 L
.208 .29991 L
.212 .29992 L
.216 .29992 L
.22 .29989 L
.224 .29987 L
.228 .29989 L
.232 .2999 L
.236 .29988 L
.24 .29984 L
.244 .29985 L
.248 .29988 L
.252 .29988 L
.256 .29983 L
.26 .29981 L
.264 .29983 L
.268 .29986 L
.272 .29984 L
.276 .29978 L
.28 .29978 L
.284 .29983 L
.288 .29984 L
.292 .29979 L
.296 .29974 L
.3 .29976 L
.304 .29982 L
.308 .29981 L
.312 .29973 L
.316 .2997 L
.32 .29975 L
.324 .2998 L
.328 .29977 L
.332 .29968 L
.336 .29967 L
.34 .29974 L
.344 .29979 L
.348 .29973 L
.352 .29964 L
.356 .29964 L
.36 .29973 L
.364 .29977 L
.368 .29969 L
.372 .29959 L
.376 .2996 L
.38 .29971 L
.384 .29975 L
.388 .29966 L
.392 .29955 L
.396 .29957 L
.4 .29968 L
Mistroke
.404 .29973 L
.408 .29964 L
.412 .29951 L
.416 .29952 L
.42 .29964 L
.424 .29972 L
.428 .29963 L
.432 .29949 L
.436 .29946 L
.44 .29959 L
.444 .2997 L
.448 .29964 L
.452 .29948 L
.456 .2994 L
.46 .2995 L
.464 .29966 L
.468 .29968 L
.472 .29951 L
.476 .29935 L
.48 .29938 L
.484 .29958 L
.488 .29971 L
.492 .2996 L
.496 .29937 L
.5 .29927 L
.504 .29945 L
.508 .29972 L
.512 .29978 L
.516 .29954 L
.52 .2993 L
.524 .29939 L
.528 .2998 L
.532 .30019 L
.536 .30021 L
.54 .29998 L
.544 .3 L
.548 .30062 L
.552 .30164 L
.556 .30251 L
.56 .30297 L
.564 .30346 L
.568 .30472 L
.572 .30703 L
.576 .30988 L
.58 .3126 L
.584 .31512 L
.588 .31828 L
.592 .32295 L
.596 .32916 L
.6 .336 L
Mistroke
.604 .34258 L
.608 .34899 L
.612 .35626 L
.616 .36515 L
.62 .37516 L
.624 .38471 L
.628 .39252 L
.632 .39868 L
.636 .40433 L
.64 .41013 L
.644 .41524 L
.648 .41778 L
.652 .41654 L
.656 .41222 L
.66 .40683 L
.664 .40194 L
.668 .39741 L
.672 .3919 L
.676 .38474 L
.68 .37721 L
.684 .37196 L
.688 .37095 L
.692 .3738 L
.696 .37822 L
.7 .38198 L
.704 .38466 L
.708 .38755 L
.712 .3918 L
.716 .39669 L
.72 .39962 L
.724 .39808 L
.728 .39173 L
.732 .38283 L
.736 .37461 L
.74 .36899 L
.744 .36553 L
.748 .36237 L
.752 .35822 L
.756 .35347 L
.76 .34966 L
.764 .34769 L
.768 .34656 L
.772 .3437 L
.776 .3367 L
.78 .32507 L
.784 .31066 L
.788 .29671 L
.792 .28595 L
.796 .27953 L
.8 .27695 L
Mistroke
.804 .27698 L
.808 .27865 L
.812 .28147 L
.816 .28537 L
.82 .29014 L
.824 .29532 L
.828 .3003 L
.832 .3045 L
.836 .30756 L
.84 .30932 L
.844 .30984 L
.848 .30951 L
.852 .30881 L
.856 .30812 L
.86 .30732 L
.864 .30539 L
.868 .30148 L
.872 .2951 L
.876 .28774 L
.88 .28237 L
.884 .28209 L
.888 .28884 L
.892 .30067 L
.896 .3133 L
.9 .32102 L
.904 .3199 L
.908 .31078 L
.912 .29758 L
.916 .28717 L
.92 .28418 L
.924 .28921 L
.928 .29915 L
.932 .30756 L
.936 .31036 L
.94 .30638 L
.944 .29856 L
.948 .29242 L
.952 .29152 L
.956 .29676 L
.96 .30498 L
.964 .3112 L
.968 .31159 L
.972 .30568 L
.976 .29622 L
.98 .28815 L
.984 .28606 L
.988 .29015 L
.992 .29944 L
.996 .30876 L
1 .31334 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51449 m
.008 .51309 L
.012 .51277 L
.016 .51338 L
.02 .51347 L
.024 .51316 L
.028 .51319 L
.032 .51328 L
.036 .51329 L
.04 .51323 L
.044 .51325 L
.048 .51325 L
.052 .51326 L
.056 .51324 L
.06 .51326 L
.064 .51325 L
.068 .51326 L
.072 .51325 L
.076 .51326 L
.08 .51325 L
.084 .51326 L
.088 .51325 L
.092 .51326 L
.096 .51325 L
.1 .51325 L
.104 .51325 L
.108 .51325 L
.112 .51325 L
.116 .51325 L
.12 .51325 L
.124 .51325 L
.128 .51325 L
.132 .51325 L
.136 .51325 L
.14 .51325 L
.144 .51325 L
.148 .51325 L
.152 .51325 L
.156 .51325 L
.16 .51325 L
.164 .51325 L
.168 .51325 L
.172 .51325 L
.176 .51325 L
.18 .51325 L
.184 .51325 L
.188 .51325 L
.192 .51325 L
.196 .51325 L
.2 .51325 L
Mistroke
.204 .51325 L
.208 .51325 L
.212 .51325 L
.216 .51325 L
.22 .51325 L
.224 .51325 L
.228 .51325 L
.232 .51325 L
.236 .51325 L
.24 .51325 L
.244 .51325 L
.248 .51325 L
.252 .51325 L
.256 .51325 L
.26 .51325 L
.264 .51325 L
.268 .51325 L
.272 .51325 L
.276 .51325 L
.28 .51325 L
.284 .51325 L
.288 .51325 L
.292 .51325 L
.296 .51325 L
.3 .51325 L
.304 .51325 L
.308 .51324 L
.312 .51324 L
.316 .51324 L
.32 .51325 L
.324 .51324 L
.328 .51324 L
.332 .51324 L
.336 .51324 L
.34 .51324 L
.344 .51324 L
.348 .51324 L
.352 .51324 L
.356 .51324 L
.36 .51324 L
.364 .51324 L
.368 .51324 L
.372 .51324 L
.376 .51324 L
.38 .51324 L
.384 .51324 L
.388 .51324 L
.392 .51324 L
.396 .51324 L
.4 .51324 L
Mistroke
.404 .51324 L
.408 .51324 L
.412 .51324 L
.416 .51324 L
.42 .51324 L
.424 .51324 L
.428 .51324 L
.432 .51324 L
.436 .51324 L
.44 .51324 L
.444 .51324 L
.448 .51323 L
.452 .51323 L
.456 .51324 L
.46 .51324 L
.464 .51324 L
.468 .51323 L
.472 .51323 L
.476 .51323 L
.48 .51324 L
.484 .51324 L
.488 .51323 L
.492 .51323 L
.496 .51323 L
.5 .51323 L
.504 .51323 L
.508 .51323 L
.512 .51322 L
.516 .51322 L
.52 .51322 L
.524 .51322 L
.528 .51322 L
.532 .5132 L
.536 .51319 L
.54 .51317 L
.544 .51316 L
.548 .51314 L
.552 .5131 L
.556 .51304 L
.56 .51297 L
.564 .51289 L
.568 .51279 L
.572 .51265 L
.576 .51245 L
.58 .5122 L
.584 .51189 L
.588 .51152 L
.592 .51106 L
.596 .51048 L
.6 .50977 L
Mistroke
.604 .50893 L
.608 .50794 L
.612 .5068 L
.616 .50549 L
.62 .50399 L
.624 .50227 L
.628 .50038 L
.632 .49834 L
.636 .49616 L
.64 .49386 L
.644 .49145 L
.648 .48895 L
.652 .48644 L
.656 .48397 L
.66 .4816 L
.664 .47932 L
.668 .47713 L
.672 .47504 L
.676 .47308 L
.68 .47126 L
.684 .46957 L
.688 .46793 L
.692 .46627 L
.696 .46453 L
.7 .46272 L
.704 .46083 L
.708 .45889 L
.712 .45686 L
.716 .45475 L
.72 .45255 L
.724 .45035 L
.728 .44821 L
.732 .44623 L
.736 .44441 L
.74 .44274 L
.744 .44117 L
.748 .43967 L
.752 .43826 L
.756 .43694 L
.76 .43573 L
.764 .43459 L
.768 .43352 L
.772 .43251 L
.776 .43163 L
.78 .43095 L
.784 .43056 L
.788 .43048 L
.792 .43067 L
.796 .43106 L
.8 .43156 L
Mistroke
.804 .43209 L
.808 .43261 L
.812 .43309 L
.816 .43351 L
.82 .43385 L
.824 .43407 L
.828 .43417 L
.832 .43414 L
.836 .43401 L
.84 .43381 L
.844 .43359 L
.848 .43338 L
.852 .43319 L
.856 .43302 L
.86 .43286 L
.864 .43274 L
.868 .43269 L
.872 .43277 L
.876 .43299 L
.88 .43335 L
.884 .43375 L
.888 .43408 L
.892 .43419 L
.896 .43405 L
.9 .4337 L
.904 .4333 L
.908 .43301 L
.912 .43294 L
.916 .4331 L
.92 .4334 L
.924 .43368 L
.928 .43382 L
.932 .43378 L
.936 .43365 L
.94 .43351 L
.944 .43349 L
.948 .43358 L
.952 .43375 L
.956 .43386 L
.96 .43386 L
.964 .4337 L
.968 .43351 L
.972 .43335 L
.976 .43337 L
.98 .43353 L
.984 .43383 L
.988 .43406 L
.992 .43422 L
.996 .43413 L
1 .43396 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42546 L
.012 .4298 L
.016 .43133 L
.02 .42981 L
.024 .42926 L
.028 .42966 L
.032 .42983 L
.036 .42961 L
.04 .42952 L
.044 .42951 L
.048 .42951 L
.052 .42943 L
.056 .42939 L
.06 .42934 L
.064 .42931 L
.068 .42925 L
.072 .42922 L
.076 .42917 L
.08 .42913 L
.084 .42908 L
.088 .42904 L
.092 .42899 L
.096 .42896 L
.1 .42891 L
.104 .42887 L
.108 .42882 L
.112 .42878 L
.116 .42873 L
.12 .42869 L
.124 .42864 L
.128 .4286 L
.132 .42856 L
.136 .42852 L
.14 .42847 L
.144 .42843 L
.148 .42838 L
.152 .42834 L
.156 .42829 L
.16 .42825 L
.164 .42821 L
.168 .42817 L
.172 .42812 L
.176 .42808 L
.18 .42803 L
.184 .42799 L
.188 .42794 L
.192 .4279 L
.196 .42786 L
.2 .42781 L
Mistroke
.204 .42777 L
.208 .42773 L
.212 .42768 L
.216 .42764 L
.22 .42759 L
.224 .42755 L
.228 .42751 L
.232 .42746 L
.236 .42742 L
.24 .42738 L
.244 .42733 L
.248 .42729 L
.252 .42724 L
.256 .4272 L
.26 .42716 L
.264 .42711 L
.268 .42707 L
.272 .42703 L
.276 .42698 L
.28 .42694 L
.284 .42689 L
.288 .42685 L
.292 .42681 L
.296 .42676 L
.3 .42672 L
.304 .42668 L
.308 .42663 L
.312 .42659 L
.316 .42654 L
.32 .4265 L
.324 .42646 L
.328 .42641 L
.332 .42637 L
.336 .42633 L
.34 .42628 L
.344 .42624 L
.348 .42619 L
.352 .42615 L
.356 .42611 L
.36 .42606 L
.364 .42602 L
.368 .42597 L
.372 .42593 L
.376 .42589 L
.38 .42584 L
.384 .4258 L
.388 .42575 L
.392 .42571 L
.396 .42567 L
.4 .42563 L
Mistroke
.404 .42558 L
.408 .42553 L
.412 .42549 L
.416 .42545 L
.42 .42541 L
.424 .42536 L
.428 .42532 L
.432 .42527 L
.436 .42523 L
.44 .42519 L
.444 .42514 L
.448 .4251 L
.452 .42505 L
.456 .42501 L
.46 .42497 L
.464 .42493 L
.468 .42488 L
.472 .42483 L
.476 .42479 L
.48 .42475 L
.484 .42471 L
.488 .42466 L
.492 .42461 L
.496 .42457 L
.5 .42453 L
.504 .42449 L
.508 .42445 L
.512 .4244 L
.516 .42435 L
.52 .42432 L
.524 .42429 L
.528 .42425 L
.532 .42421 L
.536 .42417 L
.54 .42414 L
.544 .42413 L
.548 .42413 L
.552 .42413 L
.556 .42413 L
.56 .42416 L
.564 .42423 L
.568 .42434 L
.572 .42449 L
.576 .42467 L
.58 .42491 L
.584 .42524 L
.588 .42569 L
.592 .42625 L
.596 .42692 L
.6 .42773 L
Mistroke
.604 .42871 L
.608 .42989 L
.612 .4313 L
.616 .43293 L
.62 .43477 L
.624 .43681 L
.628 .43908 L
.632 .44159 L
.636 .44431 L
.64 .44719 L
.644 .45016 L
.648 .45317 L
.652 .4562 L
.656 .45924 L
.66 .46223 L
.664 .4651 L
.668 .46779 L
.672 .47028 L
.676 .47261 L
.68 .47483 L
.684 .47698 L
.688 .47908 L
.692 .48114 L
.696 .48319 L
.7 .48531 L
.704 .48759 L
.708 .49005 L
.712 .49265 L
.716 .49532 L
.72 .49797 L
.724 .50057 L
.728 .50311 L
.732 .50557 L
.736 .50792 L
.74 .51009 L
.744 .51203 L
.748 .51377 L
.752 .51537 L
.756 .51693 L
.76 .51848 L
.764 .52 L
.768 .52141 L
.772 .52261 L
.776 .52357 L
.78 .52426 L
.784 .52468 L
.788 .52484 L
.792 .5247 L
.796 .52429 L
.8 .52363 L
Mistroke
.804 .52284 L
.808 .52203 L
.812 .52133 L
.816 .52081 L
.82 .52048 L
.824 .5203 L
.828 .52022 L
.832 .52018 L
.836 .52019 L
.84 .52026 L
.844 .52044 L
.848 .52073 L
.852 .52109 L
.856 .52146 L
.86 .52171 L
.864 .52177 L
.868 .5216 L
.872 .52124 L
.876 .52082 L
.88 .52044 L
.884 .52018 L
.888 .52006 L
.892 .52003 L
.896 .52005 L
.9 .52009 L
.904 .52019 L
.908 .52035 L
.912 .52056 L
.916 .52075 L
.92 .52082 L
.924 .52069 L
.928 .52034 L
.932 .51987 L
.936 .51947 L
.94 .51926 L
.944 .51937 L
.948 .51969 L
.952 .52011 L
.956 .52038 L
.96 .5204 L
.964 .52013 L
.968 .51971 L
.972 .51928 L
.976 .51903 L
.98 .51901 L
.984 .51923 L
.988 .51949 L
.992 .51978 L
.996 .51982 L
1 .51975 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo04Yoo`@000Aoo`80009oo`8000Eoo`03001oogoo00aoo`008Woo0P00Bgoo00@007ooOol0
00Aoo`04001oo`00Ool2000017oo000007oo0P003Woo000ROomS000<Ool0029oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`04001oogoo0003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool300001Goo001oogoo00000goo00D0
07ooOomoo`0000=oo`03001oogoo008000=oo`80009oo`800004Ool000000002Ool01@00Oomoogoo
000037oo000ROol2000hOol00`00Oomoo`0?Ool00`00Oomoo`09Ool00`00Oomoo`0DOol0029oo`03
001oogoo03Qoo`03001oogoo00ioo`03001oogoo021oo`008Woo0P00>Goo00<007ooOol037oo0P00
8goo000ROol2000jOol00`00Oomoo`0:Ool2000TOol000]oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`03001oogoo03Uoo`03001oogoo00Uoo`8002Eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2000kOol00`00Oomoo`02Ool30003Ool00`00Oomoo`0TOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00>goo00<007ooOol00Woo00H0
07oo000007oo000WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0>Woo0P000Woo0P000goo0P009goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8003aoo`04001oo`00000]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
0P0017oo0P00?Goo0P00;Woo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool0
00]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000
Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]
Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yo
o`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo
0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001o
ogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomo
o`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`80
00Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool2
0004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007
Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002
Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@0
00=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001o
ogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogoo
Ool00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo
0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001o
ogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uo
o`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`80
00=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo
0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`80
00Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007oo
Ool03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo
0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`13Ool600000goo0000000<
000>Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomo
o`10Ool40004Ool30003Ool20002Ool01@00Ool00000Ool00`0037oo000;Ool2000:Ool20004Ool2
0002Ool50002Ool00`00Oomoo`0oOol2000UOol002Qoo`03001oogoo03aoo`<002Moo`00:7oo00<0
07ooOol0>Woo0`00:Goo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0i
Ool2000[Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
=goo0P00;Goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
03Aoo`@002ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Oolh000aOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo
00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00
Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001o
ogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0
0P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007oo
Oomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol0
0Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol0
00]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`00
77oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P00
1Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo
00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D0
07ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool0
01aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Ao
o`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool4
0003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo
0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool0
0006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool2
0006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P00
1Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomo
ogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2
001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00
Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@00
0Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Io
o`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0<7oo2P00>7oo000GOol0
0`00Oomoo`02Oolc0009Ool5000dOol001Moo`03001oogoo009oo`03001oogoo03eoo`<0039oo`00
5goo00<007ooOol00Woo00<007ooOol0?goo0P00<Goo000FOol20004Ool20012Ool00`00Oomoo`0^
Ool001Moo`03001oogoo009oo`03001oogoo049oo`8002ioo`0077oo00<007ooOol0@goo0`00;7oo
000LOol20016Ool2000[Ool001aoo`03001oogoo04Moo`8002Uoo`0077oo0P00BGoo0`009goo000L
Ool00`00Oomoo`1:Ool40003OolE000<Ool001aoo`03001oogoo04eoo`D000Aoo`8001Yoo`002Woo
0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;
Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P00
2Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001ao
o`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(8684\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30064 m
.008 .30095 L
.012 .29999 L
.016 .29985 L
.02 .30042 L
.024 .30043 L
.028 .3001 L
.032 .30011 L
.036 .30027 L
.04 .30025 L
.044 .30017 L
.048 .30017 L
.052 .3002 L
.056 .30019 L
.06 .30017 L
.064 .30016 L
.068 .30016 L
.072 .30015 L
.076 .30015 L
.08 .30014 L
.084 .30014 L
.088 .30013 L
.092 .30013 L
.096 .30012 L
.1 .30011 L
.104 .3001 L
.108 .3001 L
.112 .3001 L
.116 .30009 L
.12 .30008 L
.124 .30008 L
.128 .30007 L
.132 .30007 L
.136 .30005 L
.14 .30005 L
.144 .30005 L
.148 .30004 L
.152 .30003 L
.156 .30002 L
.16 .30003 L
.164 .30002 L
.168 .30001 L
.172 .3 L
.176 .3 L
.18 .3 L
.184 .29999 L
.188 .29997 L
.192 .29997 L
.196 .29998 L
.2 .29997 L
Mistroke
.204 .29995 L
.208 .29994 L
.212 .29995 L
.216 .29995 L
.22 .29993 L
.224 .29991 L
.228 .29992 L
.232 .29993 L
.236 .29992 L
.24 .29989 L
.244 .29988 L
.248 .2999 L
.252 .29991 L
.256 .29988 L
.26 .29985 L
.264 .29986 L
.268 .29989 L
.272 .29988 L
.276 .29983 L
.28 .29981 L
.284 .29985 L
.288 .29987 L
.292 .29983 L
.296 .29978 L
.3 .29979 L
.304 .29984 L
.308 .29984 L
.312 .29978 L
.316 .29974 L
.32 .29977 L
.324 .29983 L
.328 .29981 L
.332 .29973 L
.336 .2997 L
.34 .29976 L
.344 .29981 L
.348 .29977 L
.352 .29969 L
.356 .29967 L
.36 .29975 L
.364 .29979 L
.368 .29974 L
.372 .29964 L
.376 .29964 L
.38 .29973 L
.384 .29978 L
.388 .2997 L
.392 .2996 L
.396 .2996 L
.4 .29971 L
Mistroke
.404 .29976 L
.408 .29968 L
.412 .29956 L
.416 .29956 L
.42 .29967 L
.424 .29974 L
.428 .29966 L
.432 .29953 L
.436 .29951 L
.44 .29962 L
.444 .29972 L
.448 .29967 L
.452 .29952 L
.456 .29946 L
.46 .29956 L
.464 .29969 L
.468 .2997 L
.472 .29955 L
.476 .29943 L
.48 .29949 L
.484 .29968 L
.488 .29979 L
.492 .29972 L
.496 .29957 L
.5 .2996 L
.504 .29987 L
.508 .30022 L
.512 .3004 L
.516 .30043 L
.52 .3006 L
.524 .30115 L
.528 .30208 L
.532 .30307 L
.536 .30395 L
.54 .30493 L
.544 .30649 L
.548 .30886 L
.552 .31185 L
.556 .31505 L
.56 .31841 L
.564 .32241 L
.568 .32762 L
.572 .33407 L
.576 .34121 L
.58 .34844 L
.584 .3558 L
.588 .36385 L
.592 .37295 L
.596 .38258 L
.6 .39159 L
Mistroke
.604 .39912 L
.608 .40523 L
.612 .41058 L
.616 .41534 L
.62 .41866 L
.624 .41924 L
.628 .41663 L
.632 .41177 L
.636 .40623 L
.64 .40088 L
.644 .39533 L
.648 .38886 L
.652 .38178 L
.656 .37582 L
.66 .37301 L
.664 .37394 L
.668 .37734 L
.672 .38119 L
.676 .38452 L
.68 .38789 L
.684 .39225 L
.688 .39724 L
.692 .40077 L
.696 .40041 L
.7 .39548 L
.704 .38771 L
.708 .37995 L
.712 .37397 L
.716 .36939 L
.72 .36467 L
.724 .35904 L
.728 .35353 L
.732 .34999 L
.736 .34911 L
.74 .34914 L
.744 .34684 L
.748 .33973 L
.752 .32795 L
.756 .31413 L
.76 .30148 L
.764 .29179 L
.768 .28478 L
.772 .27934 L
.776 .27518 L
.78 .27331 L
.784 .27525 L
.788 .28126 L
.792 .2897 L
.796 .29766 L
.8 .30273 L
Mistroke
.804 .30445 L
.808 .30428 L
.812 .30445 L
.816 .30633 L
.82 .30963 L
.824 .31275 L
.828 .31375 L
.832 .31149 L
.836 .30615 L
.84 .29892 L
.844 .29185 L
.848 .28684 L
.852 .28537 L
.856 .28787 L
.86 .29331 L
.864 .30006 L
.868 .30577 L
.872 .30915 L
.876 .30991 L
.88 .30861 L
.884 .30655 L
.888 .30383 L
.892 .30056 L
.896 .29649 L
.9 .29207 L
.904 .28934 L
.908 .28989 L
.912 .29494 L
.916 .3031 L
.92 .3108 L
.924 .31445 L
.928 .31151 L
.932 .30321 L
.936 .29353 L
.94 .28732 L
.944 .28782 L
.948 .29463 L
.952 .30391 L
.956 .31063 L
.96 .31158 L
.964 .30614 L
.968 .29813 L
.972 .29181 L
.976 .29006 L
.98 .29453 L
.984 .30105 L
.988 .30705 L
.992 .30967 L
.996 .30637 L
1 .30181 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51938 m
.008 .51303 L
.012 .51094 L
.016 .51299 L
.02 .51374 L
.024 .51303 L
.028 .51281 L
.032 .51301 L
.036 .51312 L
.04 .51303 L
.044 .51301 L
.048 .51302 L
.052 .51305 L
.056 .51302 L
.06 .51303 L
.064 .51302 L
.068 .51304 L
.072 .51302 L
.076 .51303 L
.08 .51302 L
.084 .51303 L
.088 .51303 L
.092 .51303 L
.096 .51303 L
.1 .51303 L
.104 .51303 L
.108 .51303 L
.112 .51303 L
.116 .51303 L
.12 .51303 L
.124 .51303 L
.128 .51303 L
.132 .51303 L
.136 .51303 L
.14 .51303 L
.144 .51303 L
.148 .51303 L
.152 .51303 L
.156 .51303 L
.16 .51303 L
.164 .51303 L
.168 .51303 L
.172 .51303 L
.176 .51303 L
.18 .51303 L
.184 .51303 L
.188 .51303 L
.192 .51303 L
.196 .51303 L
.2 .51303 L
Mistroke
.204 .51303 L
.208 .51303 L
.212 .51303 L
.216 .51303 L
.22 .51303 L
.224 .51303 L
.228 .51303 L
.232 .51302 L
.236 .51302 L
.24 .51302 L
.244 .51302 L
.248 .51302 L
.252 .51302 L
.256 .51302 L
.26 .51302 L
.264 .51302 L
.268 .51302 L
.272 .51302 L
.276 .51302 L
.28 .51302 L
.284 .51302 L
.288 .51302 L
.292 .51302 L
.296 .51302 L
.3 .51302 L
.304 .51302 L
.308 .51302 L
.312 .51302 L
.316 .51302 L
.32 .51302 L
.324 .51302 L
.328 .51302 L
.332 .51302 L
.336 .51302 L
.34 .51302 L
.344 .51302 L
.348 .51302 L
.352 .51302 L
.356 .51302 L
.36 .51302 L
.364 .51302 L
.368 .51302 L
.372 .51302 L
.376 .51302 L
.38 .51302 L
.384 .51302 L
.388 .51302 L
.392 .51302 L
.396 .51302 L
.4 .51302 L
Mistroke
.404 .51302 L
.408 .51301 L
.412 .51301 L
.416 .51302 L
.42 .51302 L
.424 .51301 L
.428 .51301 L
.432 .51301 L
.436 .51301 L
.44 .51301 L
.444 .51301 L
.448 .51301 L
.452 .51301 L
.456 .51301 L
.46 .51301 L
.464 .51301 L
.468 .51301 L
.472 .51301 L
.476 .51301 L
.48 .51301 L
.484 .51301 L
.488 .513 L
.492 .513 L
.496 .513 L
.5 .51299 L
.504 .51299 L
.508 .51298 L
.512 .51296 L
.516 .51294 L
.52 .51292 L
.524 .51289 L
.528 .51284 L
.532 .51277 L
.536 .51269 L
.54 .51258 L
.544 .51245 L
.548 .51228 L
.552 .51204 L
.556 .51175 L
.56 .51139 L
.564 .51095 L
.568 .51041 L
.572 .50975 L
.576 .50895 L
.58 .508 L
.584 .5069 L
.588 .50564 L
.592 .5042 L
.596 .50256 L
.6 .50073 L
Mistroke
.604 .49874 L
.608 .4966 L
.612 .49433 L
.616 .49196 L
.62 .4895 L
.624 .487 L
.628 .48451 L
.632 .48209 L
.636 .47977 L
.64 .47755 L
.644 .47543 L
.648 .47343 L
.652 .47156 L
.656 .46982 L
.66 .46815 L
.664 .4665 L
.668 .46481 L
.672 .46304 L
.676 .4612 L
.68 .45929 L
.684 .4573 L
.688 .45522 L
.692 .45305 L
.696 .45085 L
.7 .4487 L
.704 .44667 L
.708 .44479 L
.712 .44305 L
.716 .44142 L
.72 .43988 L
.724 .43846 L
.728 .43716 L
.732 .43596 L
.736 .43482 L
.74 .43372 L
.744 .43267 L
.748 .43174 L
.752 .43102 L
.756 .43056 L
.76 .4304 L
.764 .43047 L
.768 .43074 L
.772 .43114 L
.776 .43165 L
.78 .43224 L
.784 .43282 L
.788 .43334 L
.792 .43372 L
.796 .43392 L
.8 .43397 L
Mistroke
.804 .43393 L
.808 .43385 L
.812 .43376 L
.816 .43364 L
.82 .43346 L
.824 .43322 L
.828 .43294 L
.832 .43268 L
.836 .43252 L
.84 .4325 L
.844 .43264 L
.848 .4329 L
.852 .43322 L
.856 .43352 L
.86 .43372 L
.864 .43381 L
.868 .43377 L
.872 .43365 L
.876 .43348 L
.88 .43331 L
.884 .43316 L
.888 .43305 L
.892 .433 L
.896 .43305 L
.9 .4332 L
.904 .43343 L
.908 .43368 L
.912 .43387 L
.916 .43389 L
.92 .43377 L
.924 .43351 L
.928 .43327 L
.932 .43313 L
.936 .43319 L
.94 .4334 L
.944 .43367 L
.948 .43386 L
.952 .43391 L
.956 .43378 L
.96 .4336 L
.964 .43342 L
.968 .4334 L
.972 .43349 L
.976 .4337 L
.98 .43386 L
.984 .43394 L
.988 .43389 L
.992 .43376 L
.996 .43359 L
1 .43355 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .4305 L
.012 .42964 L
.016 .42959 L
.02 .42991 L
.024 .42987 L
.028 .42961 L
.032 .42962 L
.036 .42963 L
.04 .4296 L
.044 .4295 L
.048 .42948 L
.052 .42943 L
.056 .4294 L
.06 .42934 L
.064 .42931 L
.068 .42925 L
.072 .42922 L
.076 .42917 L
.08 .42913 L
.084 .42908 L
.088 .42904 L
.092 .42899 L
.096 .42896 L
.1 .42891 L
.104 .42887 L
.108 .42882 L
.112 .42878 L
.116 .42873 L
.12 .42869 L
.124 .42864 L
.128 .4286 L
.132 .42856 L
.136 .42852 L
.14 .42847 L
.144 .42843 L
.148 .42838 L
.152 .42834 L
.156 .4283 L
.16 .42825 L
.164 .42821 L
.168 .42817 L
.172 .42812 L
.176 .42808 L
.18 .42803 L
.184 .42799 L
.188 .42795 L
.192 .4279 L
.196 .42786 L
.2 .42782 L
Mistroke
.204 .42777 L
.208 .42773 L
.212 .42768 L
.216 .42764 L
.22 .4276 L
.224 .42755 L
.228 .42751 L
.232 .42747 L
.236 .42742 L
.24 .42738 L
.244 .42733 L
.248 .42729 L
.252 .42725 L
.256 .4272 L
.26 .42716 L
.264 .42712 L
.268 .42707 L
.272 .42703 L
.276 .42698 L
.28 .42694 L
.284 .4269 L
.288 .42685 L
.292 .42681 L
.296 .42676 L
.3 .42672 L
.304 .42668 L
.308 .42663 L
.312 .42659 L
.316 .42655 L
.32 .4265 L
.324 .42646 L
.328 .42641 L
.332 .42637 L
.336 .42633 L
.34 .42628 L
.344 .42624 L
.348 .42619 L
.352 .42615 L
.356 .42611 L
.36 .42607 L
.364 .42602 L
.368 .42598 L
.372 .42593 L
.376 .42589 L
.38 .42585 L
.384 .4258 L
.388 .42576 L
.392 .42571 L
.396 .42567 L
.4 .42563 L
Mistroke
.404 .42558 L
.408 .42554 L
.412 .42549 L
.416 .42545 L
.42 .42541 L
.424 .42536 L
.428 .42532 L
.432 .42527 L
.436 .42523 L
.44 .42519 L
.444 .42515 L
.448 .4251 L
.452 .42506 L
.456 .42501 L
.46 .42497 L
.464 .42493 L
.468 .42488 L
.472 .42484 L
.476 .4248 L
.48 .42476 L
.484 .42471 L
.488 .42467 L
.492 .42463 L
.496 .42459 L
.5 .42455 L
.504 .42452 L
.508 .42449 L
.512 .42445 L
.516 .42443 L
.52 .42442 L
.524 .42443 L
.528 .42444 L
.532 .42447 L
.536 .42452 L
.54 .42461 L
.544 .42475 L
.548 .42493 L
.552 .42516 L
.556 .42547 L
.56 .42587 L
.564 .42639 L
.568 .42704 L
.572 .42782 L
.576 .42875 L
.58 .42987 L
.584 .4312 L
.588 .43275 L
.592 .43452 L
.596 .43651 L
.6 .43872 L
Mistroke
.604 .44114 L
.608 .44378 L
.612 .44659 L
.616 .44954 L
.62 .45255 L
.624 .45558 L
.628 .45862 L
.632 .46161 L
.636 .46452 L
.64 .46728 L
.644 .46986 L
.648 .47225 L
.652 .47452 L
.656 .47669 L
.66 .47879 L
.664 .48085 L
.668 .48289 L
.672 .48499 L
.676 .4872 L
.68 .48958 L
.684 .49211 L
.688 .49472 L
.692 .49736 L
.696 .49999 L
.7 .50257 L
.704 .50509 L
.708 .50749 L
.712 .50971 L
.716 .51171 L
.72 .5135 L
.724 .51515 L
.728 .51673 L
.732 .51829 L
.736 .51978 L
.74 .52116 L
.744 .52237 L
.748 .52338 L
.752 .5242 L
.756 .52479 L
.76 .52509 L
.764 .52506 L
.768 .52469 L
.772 .52404 L
.776 .52326 L
.78 .52248 L
.784 .5218 L
.788 .52126 L
.792 .52084 L
.796 .52052 L
.8 .52031 L
Mistroke
.804 .52022 L
.808 .52026 L
.812 .52043 L
.816 .52068 L
.82 .52096 L
.824 .52122 L
.828 .52144 L
.832 .52161 L
.836 .52172 L
.84 .52175 L
.844 .52165 L
.848 .52142 L
.852 .52107 L
.856 .52063 L
.86 .52022 L
.864 .51994 L
.868 .51987 L
.872 .52005 L
.876 .52038 L
.88 .52077 L
.884 .52103 L
.888 .52108 L
.892 .52089 L
.896 .52056 L
.9 .52021 L
.904 .51999 L
.908 .51992 L
.912 .52 L
.916 .52008 L
.92 .52011 L
.924 .52002 L
.928 .51992 L
.932 .51985 L
.936 .51989 L
.94 .52001 L
.944 .52014 L
.948 .52013 L
.952 .51994 L
.956 .51959 L
.96 .51926 L
.964 .51905 L
.968 .51913 L
.972 .51939 L
.976 .51977 L
.98 .51999 L
.984 .51997 L
.988 .51965 L
.992 .51919 L
.996 .51873 L
1 .51857 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30003Ool30004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo04Qoo`03001oo`0000Eoo`8000Moo`03001oogoo011oo`008Woo0P00BGoo00@007oo0000
00=oo`03001oo`00009oo`<00004Ool00000Ool3000>Ool0029oof<000aoo`008Woo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`8000=oo`04001oogoo0003Ool0
1@00Oomoogoo00000goo00H007ooOomoo`00Ool30002Ool20003Ool200000goo00000002Ool2000<
Ool0029oo`8003Eoo`03001oogoo00moo`03001oogoo02=oo`008Woo00<007ooOol0=Goo00<007oo
Ool03Woo00<007ooOol08goo000ROol2000fOol2000=Ool3000UOol0029oo`8003Moo`03001oogoo
00]oo`03001oogoo02Eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0
=Woo00<007ooOol02Woo00<007ooOol09Woo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8003Qoo`03001oogoo00=oo`8000=oo`8002Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2000hOol00`00Oomoo`02Ool200001Goo001oogoo0000:Goo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo03Qoo`03001o
ogoo008000=oo`8002Yoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2
000iOol200000goo001oo`0_Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00
>Woo0`00<7oo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Ao
o`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<0
00=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003
Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00
Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool0
00]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029o
o`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001o
ogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Io
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uo
o`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00
Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool2
0004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool2
0006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001o
ogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`00
0Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`00
1Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo
00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@0
00=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001o
ogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo
00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001o
ogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
0goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<0
07ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Ao
o`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed0
00aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<0
07ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<0
07ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`05001oogoo001oo`040003Ool00`00Oomoo`11Ool600000goo00000007000017oo0000
07oo0P0000=oo`00000037oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`001Woo00<007ooOol0?Woo0`001Goo0P0017oo00<007ooOol00Woo00<007ooOol00P0000=oo`00
00003Goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0lOol3000WOol002Qoo`03
001oogoo03Yoo`<002Uoo`00:7oo00<007ooOol0>7oo0P00;7oo000AOol20004Ool00`00Oomoo`03
Ool20003Ool30003Ool00`00Oomoo`0fOol3000]Ool0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0=7oo0`00;goo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo035oo`@0035oo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Oole000dOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001o
ogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03
Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000
Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eo
o`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001o
ogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool4
0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`80
00Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P00
17oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P00
1Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo
0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eo
o`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04
001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000
Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool0
0`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003
Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000
Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2
000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P00
17oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yo
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool0
1000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`00
2Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo
00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo
00<007ooOol0<7oo1P00?7oo000GOol00`00Oomoo`02Oolc0005Ool6000gOol001Moo`03001oogoo
009oo`03001oogoo03Yoo`<003Eoo`005goo00<007ooOol00Woo00<007ooOol0?7oo0P00=7oo000F
Ool20004Ool2000oOol2000bOol001Moo`03001oogoo009oo`03001oogoo03moo`80035oo`0077oo
00<007ooOol0@Goo0P00;goo000LOol20013Ool3000]Ool001aoo`03001oogoo04Aoo`8002aoo`00
77oo0P00Agoo0P00:Woo000LOol00`00Oomoo`18Ool30004Ool500000goo0000000?000<Ool001ao
o`03001oogoo04Yoo`D000Aoo`8001eoo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo
000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;
Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo
00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;
Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(8851\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30253 m
.008 .30096 L
.012 .29957 L
.016 .29939 L
.02 .30047 L
.024 .30077 L
.028 .3002 L
.032 .3 L
.036 .30025 L
.04 .30034 L
.044 .30023 L
.048 .30018 L
.052 .30021 L
.056 .30023 L
.06 .30021 L
.064 .30019 L
.068 .30019 L
.072 .30019 L
.076 .30018 L
.08 .30018 L
.084 .30017 L
.088 .30016 L
.092 .30016 L
.096 .30015 L
.1 .30015 L
.104 .30014 L
.108 .30013 L
.112 .30013 L
.116 .30012 L
.12 .30011 L
.124 .30011 L
.128 .30011 L
.132 .3001 L
.136 .30009 L
.14 .30008 L
.144 .30008 L
.148 .30008 L
.152 .30007 L
.156 .30006 L
.16 .30006 L
.164 .30006 L
.168 .30005 L
.172 .30003 L
.176 .30003 L
.18 .30004 L
.184 .30003 L
.188 .30001 L
.192 .3 L
.196 .30001 L
.2 .30001 L
Mistroke
.204 .29999 L
.208 .29997 L
.212 .29998 L
.216 .29999 L
.22 .29997 L
.224 .29995 L
.228 .29995 L
.232 .29996 L
.236 .29996 L
.24 .29993 L
.244 .29991 L
.248 .29993 L
.252 .29994 L
.256 .29992 L
.26 .29989 L
.264 .29989 L
.268 .29992 L
.272 .29991 L
.276 .29987 L
.28 .29985 L
.284 .29987 L
.288 .2999 L
.292 .29988 L
.296 .29983 L
.3 .29982 L
.304 .29986 L
.308 .29988 L
.312 .29983 L
.316 .29978 L
.32 .2998 L
.324 .29985 L
.328 .29985 L
.332 .29978 L
.336 .29974 L
.34 .29978 L
.344 .29984 L
.348 .29981 L
.352 .29974 L
.356 .29971 L
.36 .29977 L
.364 .29982 L
.368 .29978 L
.372 .29969 L
.376 .29968 L
.38 .29975 L
.384 .2998 L
.388 .29974 L
.392 .29965 L
.396 .29964 L
.4 .29973 L
Mistroke
.404 .29978 L
.408 .29972 L
.412 .29961 L
.416 .2996 L
.42 .2997 L
.424 .29977 L
.428 .2997 L
.432 .29958 L
.436 .29956 L
.44 .29967 L
.444 .29976 L
.448 .29972 L
.452 .2996 L
.456 .29956 L
.46 .29968 L
.464 .29984 L
.468 .29988 L
.472 .29981 L
.476 .29981 L
.48 .30001 L
.484 .30035 L
.488 .30067 L
.492 .30089 L
.496 .30119 L
.5 .30178 L
.504 .30272 L
.508 .30388 L
.512 .30512 L
.516 .30653 L
.52 .30842 L
.524 .31102 L
.528 .31429 L
.532 .31802 L
.536 .32214 L
.54 .3269 L
.544 .33264 L
.548 .33946 L
.552 .34703 L
.556 .35493 L
.56 .36304 L
.564 .37158 L
.568 .38066 L
.572 .38992 L
.576 .39851 L
.58 .40574 L
.584 .41148 L
.588 .41601 L
.592 .41937 L
.596 .42098 L
.6 .42008 L
Mistroke
.604 .4165 L
.608 .41104 L
.612 .40491 L
.616 .39879 L
.62 .39261 L
.624 .38619 L
.628 .38012 L
.632 .37587 L
.636 .37469 L
.64 .37661 L
.644 .38035 L
.648 .38444 L
.652 .38837 L
.656 .39254 L
.66 .3971 L
.664 .40096 L
.668 .40215 L
.672 .39934 L
.676 .39306 L
.68 .38544 L
.684 .37847 L
.688 .37267 L
.692 .36716 L
.696 .3612 L
.7 .35541 L
.704 .35135 L
.708 .34988 L
.712 .34971 L
.716 .34794 L
.72 .34205 L
.724 .33182 L
.728 .31935 L
.732 .30737 L
.736 .29724 L
.74 .28858 L
.744 .28066 L
.748 .27397 L
.752 .27052 L
.756 .27221 L
.76 .27896 L
.764 .28816 L
.768 .29617 L
.772 .30068 L
.776 .30207 L
.78 .30265 L
.784 .30459 L
.788 .30819 L
.792 .31186 L
.796 .31351 L
.8 .31228 L
Mistroke
.804 .3089 L
.808 .30486 L
.812 .30116 L
.816 .29766 L
.82 .29389 L
.824 .2899 L
.828 .28694 L
.832 .28693 L
.836 .29091 L
.84 .29846 L
.844 .30711 L
.848 .31382 L
.852 .31615 L
.856 .31318 L
.86 .30631 L
.864 .29791 L
.868 .2911 L
.872 .28817 L
.876 .28976 L
.88 .29507 L
.884 .30137 L
.888 .30601 L
.892 .30721 L
.896 .30494 L
.9 .30138 L
.904 .29882 L
.908 .29889 L
.912 .30106 L
.916 .30302 L
.92 .30258 L
.924 .2991 L
.928 .29444 L
.932 .29187 L
.936 .29411 L
.94 .30075 L
.944 .30878 L
.948 .31341 L
.952 .311 L
.956 .30265 L
.96 .29167 L
.964 .28459 L
.968 .28591 L
.972 .29442 L
.976 .30736 L
.98 .31659 L
.984 .31712 L
.988 .30977 L
.992 .29589 L
.996 .28504 L
1 .28218 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51277 m
.008 .51294 L
.012 .51294 L
.016 .51264 L
.02 .51275 L
.024 .51288 L
.028 .51285 L
.032 .51276 L
.036 .5128 L
.04 .51281 L
.044 .51282 L
.048 .51279 L
.052 .51281 L
.056 .5128 L
.06 .51281 L
.064 .5128 L
.068 .51281 L
.072 .5128 L
.076 .51281 L
.08 .5128 L
.084 .51281 L
.088 .5128 L
.092 .51281 L
.096 .5128 L
.1 .51281 L
.104 .5128 L
.108 .51281 L
.112 .5128 L
.116 .51281 L
.12 .5128 L
.124 .51281 L
.128 .5128 L
.132 .51281 L
.136 .5128 L
.14 .51281 L
.144 .5128 L
.148 .51281 L
.152 .5128 L
.156 .51281 L
.16 .5128 L
.164 .51281 L
.168 .5128 L
.172 .5128 L
.176 .5128 L
.18 .5128 L
.184 .5128 L
.188 .5128 L
.192 .5128 L
.196 .5128 L
.2 .5128 L
Mistroke
.204 .5128 L
.208 .5128 L
.212 .5128 L
.216 .5128 L
.22 .5128 L
.224 .5128 L
.228 .5128 L
.232 .5128 L
.236 .5128 L
.24 .5128 L
.244 .5128 L
.248 .5128 L
.252 .5128 L
.256 .5128 L
.26 .5128 L
.264 .5128 L
.268 .5128 L
.272 .5128 L
.276 .5128 L
.28 .5128 L
.284 .5128 L
.288 .5128 L
.292 .5128 L
.296 .5128 L
.3 .5128 L
.304 .5128 L
.308 .5128 L
.312 .5128 L
.316 .5128 L
.32 .5128 L
.324 .5128 L
.328 .5128 L
.332 .5128 L
.336 .5128 L
.34 .5128 L
.344 .5128 L
.348 .5128 L
.352 .5128 L
.356 .5128 L
.36 .5128 L
.364 .5128 L
.368 .51279 L
.372 .51279 L
.376 .51279 L
.38 .51279 L
.384 .51279 L
.388 .51279 L
.392 .51279 L
.396 .51279 L
.4 .51279 L
Mistroke
.404 .51279 L
.408 .51279 L
.412 .51279 L
.416 .51279 L
.42 .51279 L
.424 .51279 L
.428 .51279 L
.432 .51279 L
.436 .51279 L
.44 .51279 L
.444 .51279 L
.448 .51279 L
.452 .51279 L
.456 .51279 L
.46 .51279 L
.464 .51278 L
.468 .51278 L
.472 .51277 L
.476 .51277 L
.48 .51276 L
.484 .51275 L
.488 .51273 L
.492 .5127 L
.496 .51267 L
.5 .51263 L
.504 .51257 L
.508 .51249 L
.512 .51239 L
.516 .51226 L
.52 .51209 L
.524 .51188 L
.528 .51161 L
.532 .51126 L
.536 .51084 L
.54 .51032 L
.544 .5097 L
.548 .50895 L
.552 .50805 L
.556 .50699 L
.56 .50578 L
.564 .50439 L
.568 .50282 L
.572 .50106 L
.576 .49912 L
.58 .49703 L
.584 .49479 L
.588 .49246 L
.592 .49003 L
.596 .48755 L
.6 .48506 L
Mistroke
.604 .48261 L
.608 .48024 L
.612 .47798 L
.616 .47583 L
.62 .4738 L
.624 .47188 L
.628 .47009 L
.632 .46839 L
.636 .46673 L
.64 .46507 L
.644 .46335 L
.648 .46155 L
.652 .45968 L
.656 .45772 L
.66 .45567 L
.664 .45354 L
.668 .45136 L
.672 .4492 L
.676 .44713 L
.68 .44518 L
.684 .44337 L
.688 .44169 L
.692 .44013 L
.696 .43869 L
.7 .43737 L
.704 .43616 L
.708 .43501 L
.712 .43391 L
.716 .43286 L
.72 .4319 L
.724 .43113 L
.728 .4306 L
.732 .43032 L
.736 .43027 L
.74 .43044 L
.744 .43078 L
.748 .43128 L
.752 .43189 L
.756 .43252 L
.76 .43307 L
.764 .43348 L
.768 .43371 L
.772 .43381 L
.776 .43383 L
.78 .4338 L
.784 .43373 L
.788 .4336 L
.792 .43338 L
.796 .43312 L
.8 .43285 L
Mistroke
.804 .43263 L
.808 .43251 L
.812 .43247 L
.816 .43253 L
.82 .43266 L
.824 .43286 L
.828 .43312 L
.832 .4334 L
.836 .43364 L
.84 .43377 L
.844 .43374 L
.848 .43356 L
.852 .43327 L
.856 .43299 L
.86 .4328 L
.864 .43277 L
.868 .4329 L
.872 .43313 L
.876 .43337 L
.88 .43355 L
.884 .43361 L
.888 .43357 L
.892 .43347 L
.896 .43338 L
.9 .43333 L
.904 .43334 L
.908 .43335 L
.912 .43335 L
.916 .43332 L
.92 .43331 L
.924 .43334 L
.928 .43345 L
.932 .43361 L
.936 .43376 L
.94 .43379 L
.944 .4337 L
.948 .43349 L
.952 .43329 L
.956 .43319 L
.96 .43329 L
.964 .43354 L
.968 .43384 L
.972 .43402 L
.976 .43404 L
.98 .43379 L
.984 .43352 L
.988 .43327 L
.992 .43325 L
.996 .43345 L
1 .43378 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43451 L
.012 .42986 L
.016 .42832 L
.02 .42975 L
.024 .43027 L
.028 .42969 L
.032 .42949 L
.036 .42959 L
.04 .42964 L
.044 .42952 L
.048 .42947 L
.052 .42942 L
.056 .42941 L
.06 .42934 L
.064 .42931 L
.068 .42925 L
.072 .42922 L
.076 .42917 L
.08 .42913 L
.084 .42908 L
.088 .42905 L
.092 .42899 L
.096 .42896 L
.1 .42891 L
.104 .42887 L
.108 .42882 L
.112 .42878 L
.116 .42873 L
.12 .42869 L
.124 .42865 L
.128 .42861 L
.132 .42856 L
.136 .42852 L
.14 .42847 L
.144 .42843 L
.148 .42838 L
.152 .42834 L
.156 .4283 L
.16 .42825 L
.164 .42821 L
.168 .42817 L
.172 .42812 L
.176 .42808 L
.18 .42803 L
.184 .42799 L
.188 .42795 L
.192 .4279 L
.196 .42786 L
.2 .42782 L
Mistroke
.204 .42777 L
.208 .42773 L
.212 .42768 L
.216 .42764 L
.22 .4276 L
.224 .42755 L
.228 .42751 L
.232 .42747 L
.236 .42742 L
.24 .42738 L
.244 .42733 L
.248 .42729 L
.252 .42725 L
.256 .4272 L
.26 .42716 L
.264 .42712 L
.268 .42707 L
.272 .42703 L
.276 .42698 L
.28 .42694 L
.284 .4269 L
.288 .42685 L
.292 .42681 L
.296 .42677 L
.3 .42672 L
.304 .42668 L
.308 .42663 L
.312 .42659 L
.316 .42655 L
.32 .4265 L
.324 .42646 L
.328 .42642 L
.332 .42637 L
.336 .42633 L
.34 .42629 L
.344 .42624 L
.348 .4262 L
.352 .42615 L
.356 .42611 L
.36 .42607 L
.364 .42602 L
.368 .42598 L
.372 .42593 L
.376 .42589 L
.38 .42585 L
.384 .4258 L
.388 .42576 L
.392 .42572 L
.396 .42567 L
.4 .42563 L
Mistroke
.404 .42559 L
.408 .42554 L
.412 .4255 L
.416 .42545 L
.42 .42541 L
.424 .42537 L
.428 .42532 L
.432 .42528 L
.436 .42524 L
.44 .42519 L
.444 .42515 L
.448 .4251 L
.452 .42506 L
.456 .42502 L
.46 .42498 L
.464 .42494 L
.468 .4249 L
.472 .42486 L
.476 .42482 L
.48 .42479 L
.484 .42477 L
.488 .42474 L
.492 .42472 L
.496 .42472 L
.5 .42474 L
.504 .42476 L
.508 .42481 L
.512 .42489 L
.516 .42501 L
.52 .42518 L
.524 .42541 L
.528 .4257 L
.532 .42607 L
.536 .42655 L
.54 .42716 L
.544 .4279 L
.548 .4288 L
.552 .42987 L
.556 .43112 L
.56 .4326 L
.564 .4343 L
.568 .43622 L
.572 .43837 L
.576 .44072 L
.58 .44328 L
.584 .44603 L
.588 .44892 L
.592 .45192 L
.596 .45496 L
.6 .458 L
Mistroke
.604 .461 L
.608 .46393 L
.612 .46674 L
.616 .46939 L
.62 .47187 L
.624 .47419 L
.628 .47638 L
.632 .47849 L
.636 .48056 L
.64 .4826 L
.644 .48468 L
.648 .48684 L
.652 .48914 L
.656 .49159 L
.66 .49415 L
.664 .49678 L
.668 .49941 L
.672 .50202 L
.676 .50457 L
.68 .50702 L
.684 .5093 L
.688 .51137 L
.692 .51323 L
.696 .51493 L
.7 .51654 L
.704 .51808 L
.708 .51955 L
.712 .52092 L
.716 .52215 L
.72 .52322 L
.724 .52413 L
.728 .52482 L
.732 .52523 L
.736 .52531 L
.74 .52504 L
.744 .52448 L
.748 .52376 L
.752 .523 L
.756 .52229 L
.76 .52166 L
.764 .52113 L
.768 .52072 L
.772 .52046 L
.776 .52037 L
.78 .52045 L
.784 .52063 L
.788 .52084 L
.792 .52104 L
.796 .52123 L
.8 .52144 L
Mistroke
.804 .52167 L
.808 .52189 L
.812 .52202 L
.816 .52198 L
.82 .52175 L
.824 .52135 L
.828 .5209 L
.832 .52051 L
.836 .52026 L
.84 .52019 L
.844 .52027 L
.848 .52047 L
.852 .5207 L
.856 .52091 L
.86 .52104 L
.864 .52107 L
.868 .52099 L
.872 .52081 L
.876 .52055 L
.88 .52028 L
.884 .52005 L
.888 .51992 L
.892 .51991 L
.896 .52004 L
.9 .52023 L
.904 .52041 L
.908 .52048 L
.912 .52039 L
.916 .52017 L
.92 .51991 L
.924 .51969 L
.928 .51962 L
.932 .51967 L
.936 .5198 L
.94 .51988 L
.944 .51989 L
.948 .51975 L
.952 .51958 L
.956 .51944 L
.96 .51941 L
.964 .51947 L
.968 .51956 L
.972 .51957 L
.976 .51951 L
.98 .51928 L
.984 .5191 L
.988 .51895 L
.992 .51895 L
.996 .51908 L
1 .51923 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool50002Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo04Ioo`<000Eoo`05001oogooOol00008Ool00`00Oomoo`02000<Ool0029oo`8004Ioo`04
001oogoo0004Ool01000Ool007oo0`0017oo00<007ooOol00P0000=oo`00Ool037oo000ROomS000<
Ool0029oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`04001o
ogoo0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`04001oogooOol20002Ool01@00
Oomoogoo00000Woo00D007ooOomoo`0000=oo`80009oo`03001oogoo008000=oo`<00003Ool007oo
009oo`03001oo`0000800004Ool007oo000<Ool0029oo`80039oo`80015oo`03001oogoo02Eoo`00
8Woo00<007ooOol0<Woo0P0047oo00<007ooOol09Goo000ROol2000dOol00`00Oomoo`0<Ool2000X
Ool0029oo`8003Aoo`03001oogoo00]oo`8002Uoo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo00<007ooOol0=7oo00<007ooOol02Woo00<007ooOol0:7oo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8003Eoo`03001oogoo00=oo`<000=oo`03001oogoo02Uo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000fOol00`00Oomoo`02
Ool01P00Ool00000Ool002aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`0eOol01000Oomoogoo0P000Woo0`00;7oo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8003Moo`04001oo`000004Ool00`00Oomoo`0[Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo0P0017oo0P00=goo0`00<goo000;Ool2000:Ool20004Ool00`00
Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04
001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool0
1000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool0
1P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`00
8Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<0
07ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03
001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00
Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo
000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00
Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000
Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool0
1000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool5
0003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogoo
Ool00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo
00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009o
o`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool0
0`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo
0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomo
o`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00
:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomo
o`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol0
47oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<0
07ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@0
07ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Ool006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
0P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00
Oomoo`0oOol500000goo0000000?00000goo0000000=Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0lOol30005Ool20004Ool00`00Oomoo`06Ool0
0`00Oomoo`0200000goo001oo`0;Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo
03Yoo`8002Yoo`00:7oo00<007ooOol0>7oo0P00;7oo000XOol00`00Oomoo`0eOol3000^Ool0015o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo03Aoo`80031oo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0bOol2000bOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0;goo0`00=7oo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009ooc8003Moo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool0
1000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`00
2Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo
00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004
Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005
Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007oo
Ool0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06
001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<0
07ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001o
ogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool0
01aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo
00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0
01aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003
Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo
Ool00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;
Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo
000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009ooc`003Uoo`005goo00<0
07ooOol00Woo0P00>Goo0P00>7oo000GOol00`00Oomoo`02Ool00`00Oomoo`0jOol00`00Oomoo`0e
Ool001Ioo`8000Aoo`8003aoo`8003Eoo`005goo00<007ooOol00Woo00<007ooOol0?7oo0P00=7oo
000LOol00`00Oomoo`0nOol2000bOol001aoo`80045oo`80031oo`0077oo00<007ooOol0@Goo0`00
;Woo000LOol20014Ool2000]Ool001aoo`03001oogoo04Eoo`<000Aoo`D00003Ool00000018000ao
o`0077oo00<007ooOol0Agoo1P000goo0`007goo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2
001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001o
ogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<0
07ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1b
Ool000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(9018\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30035 m
.008 .29975 L
.012 .30044 L
.016 .30053 L
.02 .30015 L
.024 .30018 L
.028 .30039 L
.032 .30034 L
.036 .30021 L
.04 .30024 L
.044 .3003 L
.048 .30027 L
.052 .30024 L
.056 .30024 L
.06 .30025 L
.064 .30024 L
.068 .30023 L
.072 .30022 L
.076 .30022 L
.08 .30021 L
.084 .3002 L
.088 .3002 L
.092 .30019 L
.096 .30019 L
.1 .30018 L
.104 .30017 L
.108 .30017 L
.112 .30016 L
.116 .30016 L
.12 .30015 L
.124 .30014 L
.128 .30014 L
.132 .30014 L
.136 .30013 L
.14 .30012 L
.144 .30012 L
.148 .30011 L
.152 .3001 L
.156 .30009 L
.16 .30009 L
.164 .30009 L
.168 .30008 L
.172 .30007 L
.176 .30006 L
.18 .30007 L
.184 .30006 L
.188 .30005 L
.192 .30004 L
.196 .30004 L
.2 .30004 L
Mistroke
.204 .30003 L
.208 .30001 L
.212 .30001 L
.216 .30002 L
.22 .30001 L
.224 .29999 L
.228 .29998 L
.232 .29999 L
.236 .29999 L
.24 .29997 L
.244 .29995 L
.248 .29996 L
.252 .29997 L
.256 .29996 L
.26 .29993 L
.264 .29992 L
.268 .29994 L
.272 .29995 L
.276 .29992 L
.28 .29989 L
.284 .2999 L
.288 .29993 L
.292 .29992 L
.296 .29987 L
.3 .29985 L
.304 .29988 L
.308 .29991 L
.312 .29988 L
.316 .29983 L
.32 .29983 L
.324 .29987 L
.328 .29988 L
.332 .29983 L
.336 .29979 L
.34 .29981 L
.344 .29986 L
.348 .29985 L
.352 .29979 L
.356 .29975 L
.36 .29979 L
.364 .29984 L
.368 .29982 L
.372 .29974 L
.376 .29971 L
.38 .29977 L
.384 .29983 L
.388 .29979 L
.392 .2997 L
.396 .29968 L
.4 .29975 L
Mistroke
.404 .29981 L
.408 .29977 L
.412 .29967 L
.416 .29966 L
.42 .29975 L
.424 .29983 L
.428 .29979 L
.432 .29971 L
.436 .29972 L
.44 .29986 L
.444 .30001 L
.448 .30006 L
.452 .30008 L
.456 .30021 L
.46 .30055 L
.464 .30098 L
.468 .30141 L
.472 .30186 L
.476 .30253 L
.48 .30356 L
.484 .30492 L
.488 .30652 L
.492 .30835 L
.496 .31061 L
.5 .31354 L
.504 .3172 L
.508 .32149 L
.512 .32631 L
.516 .33178 L
.52 .3381 L
.524 .34538 L
.528 .35342 L
.532 .36188 L
.536 .37054 L
.54 .37938 L
.544 .38838 L
.548 .39723 L
.552 .40532 L
.556 .41203 L
.56 .4171 L
.564 .42057 L
.568 .42246 L
.572 .4225 L
.576 .42028 L
.58 .4158 L
.584 .40969 L
.588 .40294 L
.592 .39629 L
.596 .38999 L
.6 .38417 L
Mistroke
.604 .37939 L
.608 .37665 L
.612 .37673 L
.616 .37945 L
.62 .38376 L
.624 .38844 L
.628 .39293 L
.632 .39717 L
.636 .40091 L
.64 .40308 L
.644 .4023 L
.648 .39799 L
.652 .39106 L
.656 .38334 L
.66 .37623 L
.664 .36993 L
.668 .36392 L
.672 .35811 L
.676 .35334 L
.68 .35057 L
.684 .34948 L
.688 .34811 L
.692 .34396 L
.696 .33588 L
.7 .32484 L
.704 .31298 L
.708 .30197 L
.712 .29204 L
.716 .28285 L
.72 .2749 L
.724 .27002 L
.728 .27023 L
.732 .27576 L
.736 .28439 L
.74 .29264 L
.744 .29812 L
.748 .30092 L
.752 .30292 L
.756 .30578 L
.76 .30936 L
.764 .31204 L
.768 .31236 L
.772 .31045 L
.776 .30789 L
.78 .30608 L
.784 .30483 L
.788 .30253 L
.792 .29774 L
.796 .29106 L
.8 .28522 L
Mistroke
.804 .28359 L
.808 .28782 L
.812 .29648 L
.816 .30604 L
.82 .31272 L
.824 .31459 L
.828 .31213 L
.832 .30716 L
.836 .3018 L
.84 .29714 L
.844 .29373 L
.848 .2919 L
.852 .29191 L
.856 .29414 L
.86 .29809 L
.864 .30272 L
.868 .30653 L
.872 .30812 L
.876 .30721 L
.88 .30415 L
.884 .30013 L
.888 .29651 L
.892 .29436 L
.896 .29442 L
.9 .29662 L
.904 .30015 L
.908 .30355 L
.912 .30537 L
.916 .30467 L
.92 .30202 L
.924 .29896 L
.928 .29709 L
.932 .29775 L
.936 .29988 L
.94 .30201 L
.944 .30266 L
.948 .30064 L
.952 .2982 L
.956 .29671 L
.96 .29763 L
.964 .30169 L
.968 .30508 L
.972 .30663 L
.976 .30454 L
.98 .29849 L
.984 .29388 L
.988 .2915 L
.992 .29386 L
.996 .30123 L
1 .30689 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .50627 m
.008 .51258 L
.012 .51472 L
.016 .51257 L
.02 .51188 L
.024 .51257 L
.028 .51284 L
.032 .51258 L
.036 .51251 L
.04 .51257 L
.044 .51262 L
.048 .51258 L
.052 .51258 L
.056 .51258 L
.06 .51259 L
.064 .51258 L
.068 .51259 L
.072 .51258 L
.076 .51259 L
.08 .51258 L
.084 .51259 L
.088 .51258 L
.092 .51259 L
.096 .51258 L
.1 .51259 L
.104 .51258 L
.108 .51259 L
.112 .51258 L
.116 .51258 L
.12 .51258 L
.124 .51258 L
.128 .51258 L
.132 .51258 L
.136 .51258 L
.14 .51258 L
.144 .51258 L
.148 .51258 L
.152 .51258 L
.156 .51258 L
.16 .51258 L
.164 .51258 L
.168 .51258 L
.172 .51258 L
.176 .51258 L
.18 .51258 L
.184 .51258 L
.188 .51258 L
.192 .51258 L
.196 .51258 L
.2 .51258 L
Mistroke
.204 .51258 L
.208 .51258 L
.212 .51258 L
.216 .51258 L
.22 .51258 L
.224 .51258 L
.228 .51258 L
.232 .51258 L
.236 .51258 L
.24 .51258 L
.244 .51258 L
.248 .51258 L
.252 .51258 L
.256 .51258 L
.26 .51258 L
.264 .51258 L
.268 .51258 L
.272 .51258 L
.276 .51258 L
.28 .51258 L
.284 .51258 L
.288 .51258 L
.292 .51258 L
.296 .51258 L
.3 .51258 L
.304 .51258 L
.308 .51258 L
.312 .51258 L
.316 .51258 L
.32 .51258 L
.324 .51258 L
.328 .51257 L
.332 .51257 L
.336 .51257 L
.34 .51257 L
.344 .51257 L
.348 .51257 L
.352 .51257 L
.356 .51257 L
.36 .51257 L
.364 .51257 L
.368 .51257 L
.372 .51257 L
.376 .51257 L
.38 .51257 L
.384 .51257 L
.388 .51257 L
.392 .51257 L
.396 .51257 L
.4 .51257 L
Mistroke
.404 .51257 L
.408 .51257 L
.412 .51257 L
.416 .51257 L
.42 .51257 L
.424 .51257 L
.428 .51256 L
.432 .51256 L
.436 .51256 L
.44 .51256 L
.444 .51255 L
.448 .51255 L
.452 .51254 L
.456 .51253 L
.46 .51251 L
.464 .51249 L
.468 .51245 L
.472 .51241 L
.476 .51236 L
.48 .51229 L
.484 .51219 L
.488 .51207 L
.492 .51191 L
.496 .51171 L
.5 .51145 L
.504 .51113 L
.508 .51073 L
.512 .51024 L
.516 .50964 L
.52 .50893 L
.524 .50808 L
.528 .50707 L
.532 .5059 L
.536 .50456 L
.54 .50305 L
.544 .50136 L
.548 .49948 L
.552 .49744 L
.556 .49525 L
.56 .49294 L
.564 .49055 L
.568 .48809 L
.572 .48561 L
.576 .48314 L
.58 .48074 L
.584 .47843 L
.588 .47624 L
.592 .47417 L
.596 .47222 L
.6 .47038 L
Mistroke
.604 .46864 L
.608 .46696 L
.612 .46531 L
.616 .46363 L
.62 .46188 L
.624 .46004 L
.628 .45812 L
.632 .45611 L
.636 .45402 L
.64 .45187 L
.644 .44971 L
.648 .4476 L
.652 .4456 L
.656 .44373 L
.66 .44199 L
.664 .4404 L
.668 .43892 L
.672 .43758 L
.676 .43634 L
.68 .43519 L
.684 .43409 L
.688 .43305 L
.692 .43208 L
.696 .43126 L
.7 .43065 L
.704 .43026 L
.708 .43012 L
.712 .43019 L
.716 .43047 L
.72 .43093 L
.724 .43152 L
.728 .43216 L
.732 .43275 L
.736 .43321 L
.74 .43351 L
.744 .43368 L
.748 .43374 L
.752 .43374 L
.756 .43367 L
.76 .43352 L
.764 .4333 L
.768 .43305 L
.772 .43281 L
.776 .43262 L
.78 .43249 L
.784 .4324 L
.788 .43237 L
.792 .43242 L
.796 .43257 L
.8 .43284 L
Mistroke
.804 .43317 L
.808 .43347 L
.812 .43364 L
.816 .43364 L
.82 .43348 L
.824 .43324 L
.828 .43299 L
.832 .43281 L
.836 .43274 L
.84 .43277 L
.844 .43287 L
.848 .43303 L
.852 .43321 L
.856 .43337 L
.86 .43348 L
.864 .43352 L
.868 .43346 L
.872 .43334 L
.876 .43319 L
.88 .43308 L
.884 .43304 L
.888 .43309 L
.892 .43321 L
.896 .43336 L
.9 .43348 L
.904 .43354 L
.908 .43351 L
.912 .43344 L
.916 .43335 L
.92 .43332 L
.924 .43333 L
.928 .43339 L
.932 .43345 L
.936 .43349 L
.94 .43349 L
.944 .43348 L
.948 .43346 L
.952 .43352 L
.956 .43357 L
.96 .43365 L
.964 .43365 L
.968 .4336 L
.972 .43351 L
.976 .43344 L
.98 .43343 L
.984 .43355 L
.988 .43367 L
.992 .43386 L
.996 .43389 L
1 .43384 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43021 L
.012 .43006 L
.016 .42983 L
.02 .42963 L
.024 .42974 L
.028 .42975 L
.032 .42968 L
.036 .42957 L
.04 .42957 L
.044 .42953 L
.048 .42949 L
.052 .42942 L
.056 .4294 L
.06 .42934 L
.064 .42931 L
.068 .42925 L
.072 .42922 L
.076 .42917 L
.08 .42913 L
.084 .42908 L
.088 .42905 L
.092 .42899 L
.096 .42896 L
.1 .42891 L
.104 .42887 L
.108 .42882 L
.112 .42878 L
.116 .42873 L
.12 .42869 L
.124 .42865 L
.128 .42861 L
.132 .42856 L
.136 .42852 L
.14 .42847 L
.144 .42843 L
.148 .42838 L
.152 .42834 L
.156 .4283 L
.16 .42826 L
.164 .42821 L
.168 .42817 L
.172 .42812 L
.176 .42808 L
.18 .42804 L
.184 .42799 L
.188 .42795 L
.192 .42791 L
.196 .42786 L
.2 .42782 L
Mistroke
.204 .42777 L
.208 .42773 L
.212 .42769 L
.216 .42764 L
.22 .4276 L
.224 .42756 L
.228 .42751 L
.232 .42747 L
.236 .42742 L
.24 .42738 L
.244 .42734 L
.248 .42729 L
.252 .42725 L
.256 .42721 L
.26 .42716 L
.264 .42712 L
.268 .42707 L
.272 .42703 L
.276 .42699 L
.28 .42694 L
.284 .4269 L
.288 .42686 L
.292 .42681 L
.296 .42677 L
.3 .42672 L
.304 .42668 L
.308 .42664 L
.312 .42659 L
.316 .42655 L
.32 .42651 L
.324 .42646 L
.328 .42642 L
.332 .42637 L
.336 .42633 L
.34 .42629 L
.344 .42624 L
.348 .4262 L
.352 .42616 L
.356 .42611 L
.36 .42607 L
.364 .42603 L
.368 .42598 L
.372 .42594 L
.376 .42589 L
.38 .42585 L
.384 .42581 L
.388 .42576 L
.392 .42572 L
.396 .42568 L
.4 .42563 L
Mistroke
.404 .42559 L
.408 .42554 L
.412 .4255 L
.416 .42546 L
.42 .42542 L
.424 .42537 L
.428 .42533 L
.432 .42529 L
.436 .42525 L
.44 .42521 L
.444 .42517 L
.448 .42513 L
.452 .4251 L
.456 .42507 L
.46 .42505 L
.464 .42503 L
.468 .42502 L
.472 .42503 L
.476 .42505 L
.48 .4251 L
.484 .42518 L
.488 .42528 L
.492 .42543 L
.496 .42564 L
.5 .42592 L
.504 .42628 L
.508 .42673 L
.512 .42729 L
.516 .42799 L
.52 .42885 L
.524 .42987 L
.528 .43107 L
.532 .43248 L
.536 .4341 L
.54 .43595 L
.544 .43803 L
.548 .44032 L
.552 .44281 L
.556 .44549 L
.56 .44833 L
.564 .45129 L
.568 .45432 L
.572 .45737 L
.576 .46039 L
.58 .46334 L
.584 .46619 L
.588 .4689 L
.592 .47145 L
.596 .47383 L
.6 .47607 L
Mistroke
.604 .4782 L
.608 .48027 L
.612 .48231 L
.616 .48438 L
.62 .4865 L
.624 .48873 L
.628 .4911 L
.632 .4936 L
.636 .4962 L
.64 .49883 L
.644 .50146 L
.648 .50403 L
.652 .50651 L
.656 .50885 L
.66 .511 L
.664 .51295 L
.668 .51471 L
.672 .51634 L
.676 .51787 L
.68 .51933 L
.684 .5207 L
.688 .52195 L
.692 .52307 L
.696 .52403 L
.7 .52479 L
.704 .5253 L
.708 .5255 L
.712 .52536 L
.716 .52492 L
.72 .52427 L
.724 .52352 L
.728 .52277 L
.732 .52207 L
.736 .52146 L
.74 .52098 L
.744 .52067 L
.748 .52055 L
.752 .52061 L
.756 .52076 L
.76 .52094 L
.764 .52111 L
.768 .5213 L
.772 .52152 L
.776 .52178 L
.78 .52203 L
.784 .52217 L
.788 .52216 L
.792 .52197 L
.796 .52166 L
.8 .52129 L
Mistroke
.804 .52094 L
.808 .52065 L
.812 .52045 L
.816 .52037 L
.82 .52043 L
.824 .52063 L
.828 .52091 L
.832 .5212 L
.836 .52137 L
.84 .52135 L
.844 .52114 L
.848 .52081 L
.852 .52047 L
.856 .52023 L
.86 .52013 L
.864 .52018 L
.868 .52029 L
.872 .52041 L
.876 .52047 L
.88 .52047 L
.884 .52042 L
.888 .52035 L
.892 .52027 L
.896 .52019 L
.9 .52009 L
.904 .51998 L
.908 .51984 L
.912 .51975 L
.916 .51971 L
.92 .51978 L
.924 .5199 L
.928 .52002 L
.932 .52004 L
.936 .51991 L
.94 .51965 L
.944 .51937 L
.948 .51918 L
.952 .5192 L
.956 .51935 L
.96 .51961 L
.964 .51975 L
.968 .51969 L
.972 .51943 L
.976 .51908 L
.98 .51879 L
.984 .51876 L
.988 .51888 L
.992 .51921 L
.996 .51939 L
1 .51942 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo04=oo`03001oo`0000Eoo`8001moo`008Woo0P00A7oo00@007oo000000=oo`<0009oo`<0
009oo`80009oo`05001oo`00001oo`02000=Ool0029oof<000aoo`008Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo0`0000=oo`00Ool00Woo00D007ooOomoo`00009oo`05001oogooOol0
0002Ool20003Ool20002Ool00`00Ool000020003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00aoo`008Woo0P00<7oo00<007ooOol03goo00<007ooOol0:7oo000ROol00`00Oomoo`0_Ool2000@
Ool00`00Oomoo`0XOol0029oo`80035oo`03001oogoo00eoo`8002Yoo`008Woo0P00<Woo00<007oo
Ool02goo00<007ooOol0:Woo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomo
o`0aOol00`00Oomoo`0:Ool00`00Oomoo`0[Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00<goo00<007ooOol00goo0P000goo00<007ooOol0;7oo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8003=oo`03001oogoo009oo`800005Ool007oo
Ool0000^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
<goo00D007ooOomoo`00009oo`<002moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2000dOol01000Oomoo`0017oo0P00;goo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000Aoo`8003Aoo`@003Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0
=7oo0P00=Woo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomo
o`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<0
07ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo
000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006io
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo
0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`00
8Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`00
0goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;
Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003
Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo
000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo
0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`00
0goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo
0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo
0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001o
ogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<0
07oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002
Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=
Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo
000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol0
0`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001o
ogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo
00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003
Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo
00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0?7oo7000
3Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0
>Goo10001Goo00<007ooOol04goo0P0037oo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00
Oomoo`0gOol3000/Ool002Qoo`03001oogoo03Eoo`<002ioo`00:7oo00<007ooOol0<goo0`00<7oo
000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0aOol3000bOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0<7oo0P00=7oo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo02aoo`@003Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool`000iOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@00
0Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001d
Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00
Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol03Goo
0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo
0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol0
00Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005
Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011o
o`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001ao
o`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool0
0`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`00
1Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0
009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`00
1Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo
1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007oo
Ool00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo
Ool00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03
001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000;Ool20004Ool0
0`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomo
o`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001ao
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Ioo`<000=oo`03001oogoo
079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ooli000lOol001Mo
o`03001oogoo009oo`03001oogoo03Eoo`8003]oo`005goo00<007ooOol00Woo00<007ooOol0=goo
0P00>Goo000FOol20004Ool2000iOol2000hOol001Moo`03001oogoo009oo`03001oogoo03Yoo`03
001oogoo03Eoo`0077oo00<007ooOol0>goo0P00=Goo000LOol2000nOol2000cOol001aoo`03001o
ogoo03moo`80035oo`0077oo0P00@Goo0P00<7oo000LOol00`00Oomoo`12Ool30004Ool50002OolF
000<Ool001aoo`03001oogoo04Aoo`H000=oo`<0029oo`002Woo0`0017oo00<007ooOol00Woo0`00
0goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool0
0`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]o
o`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007oo
Ool0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(9185\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29812 m
.008 .29957 L
.012 .30107 L
.016 .30126 L
.02 .3001 L
.024 .29979 L
.028 .30039 L
.032 .30057 L
.036 .30029 L
.04 .30019 L
.044 .3003 L
.048 .30034 L
.052 .30029 L
.056 .30026 L
.06 .30027 L
.064 .30028 L
.068 .30026 L
.072 .30025 L
.076 .30025 L
.08 .30025 L
.084 .30024 L
.088 .30023 L
.092 .30023 L
.096 .30022 L
.1 .30022 L
.104 .30021 L
.108 .3002 L
.112 .3002 L
.116 .30019 L
.12 .30018 L
.124 .30018 L
.128 .30017 L
.132 .30017 L
.136 .30016 L
.14 .30015 L
.144 .30015 L
.148 .30015 L
.152 .30014 L
.156 .30013 L
.16 .30012 L
.164 .30012 L
.168 .30012 L
.172 .30011 L
.176 .3001 L
.18 .3001 L
.184 .3001 L
.188 .30008 L
.192 .30007 L
.196 .30007 L
.2 .30007 L
Mistroke
.204 .30006 L
.208 .30005 L
.212 .30004 L
.216 .30005 L
.22 .30005 L
.224 .30003 L
.228 .30001 L
.232 .30002 L
.236 .30003 L
.24 .30001 L
.244 .29999 L
.248 .29999 L
.252 .3 L
.256 .3 L
.26 .29997 L
.264 .29995 L
.268 .29997 L
.272 .29998 L
.276 .29996 L
.28 .29993 L
.284 .29993 L
.288 .29995 L
.292 .29995 L
.296 .29992 L
.3 .29989 L
.304 .29991 L
.308 .29994 L
.312 .29992 L
.316 .29987 L
.32 .29986 L
.324 .2999 L
.328 .29991 L
.332 .29988 L
.336 .29983 L
.34 .29984 L
.344 .29988 L
.348 .29989 L
.352 .29983 L
.356 .29979 L
.36 .29982 L
.364 .29987 L
.368 .29986 L
.372 .29979 L
.376 .29976 L
.38 .2998 L
.384 .29986 L
.388 .29984 L
.392 .29977 L
.396 .29975 L
.4 .29983 L
Mistroke
.404 .29991 L
.408 .29991 L
.412 .29987 L
.416 .29991 L
.42 .30008 L
.424 .30027 L
.428 .30041 L
.432 .30055 L
.436 .30083 L
.44 .30133 L
.444 .30196 L
.448 .30265 L
.452 .30347 L
.456 .30461 L
.46 .30618 L
.464 .30814 L
.468 .31044 L
.472 .31314 L
.476 .31646 L
.48 .32057 L
.484 .32543 L
.488 .33096 L
.492 .33712 L
.496 .34403 L
.5 .35179 L
.504 .36028 L
.508 .3692 L
.512 .37823 L
.516 .38722 L
.52 .39603 L
.524 .40439 L
.528 .41183 L
.532 .4178 L
.536 .42195 L
.54 .42424 L
.544 .4247 L
.548 .42326 L
.552 .4198 L
.556 .41445 L
.56 .40776 L
.564 .4006 L
.568 .39376 L
.572 .38772 L
.576 .38278 L
.58 .37935 L
.584 .37805 L
.588 .37927 L
.592 .3828 L
.596 .3877 L
.6 .39285 L
Mistroke
.604 .39749 L
.608 .40125 L
.612 .40373 L
.616 .40417 L
.62 .40175 L
.624 .39632 L
.628 .38879 L
.632 .38069 L
.636 .37321 L
.64 .36667 L
.644 .36084 L
.648 .35577 L
.652 .35192 L
.656 .34956 L
.66 .34785 L
.664 .34496 L
.668 .33912 L
.672 .32991 L
.676 .31852 L
.68 .30675 L
.684 .29573 L
.688 .28575 L
.692 .2771 L
.696 .27097 L
.7 .26909 L
.704 .27237 L
.708 .27969 L
.712 .28826 L
.716 .29537 L
.72 .30007 L
.724 .30327 L
.728 .30635 L
.732 .30953 L
.736 .31174 L
.74 .31188 L
.744 .31018 L
.748 .30812 L
.752 .30702 L
.756 .30655 L
.76 .30482 L
.764 .3002 L
.768 .29314 L
.772 .28652 L
.776 .28379 L
.78 .28662 L
.784 .29375 L
.788 .3019 L
.792 .30816 L
.796 .31132 L
.8 .31189 L
Mistroke
.804 .31079 L
.808 .30806 L
.812 .3034 L
.816 .29703 L
.82 .2908 L
.824 .28749 L
.828 .28902 L
.832 .29516 L
.836 .30298 L
.84 .30882 L
.844 .31031 L
.848 .30747 L
.852 .30269 L
.856 .29861 L
.86 .29683 L
.864 .29721 L
.868 .2984 L
.872 .29921 L
.876 .29922 L
.88 .29896 L
.884 .29927 L
.888 .30062 L
.892 .30265 L
.896 .30446 L
.9 .30495 L
.904 .30331 L
.908 .30001 L
.912 .29608 L
.916 .29354 L
.92 .2942 L
.924 .29795 L
.928 .30381 L
.932 .3085 L
.936 .30909 L
.94 .30527 L
.944 .29784 L
.948 .29152 L
.952 .29004 L
.956 .29397 L
.96 .30265 L
.964 .30993 L
.968 .31173 L
.972 .30748 L
.976 .29769 L
.98 .28989 L
.984 .28818 L
.988 .29289 L
.992 .30371 L
.996 .31186 L
1 .31335 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51128 m
.008 .5122 L
.012 .51265 L
.016 .51249 L
.02 .51232 L
.024 .51227 L
.028 .51238 L
.032 .51239 L
.036 .51237 L
.04 .51234 L
.044 .51237 L
.048 .51236 L
.052 .51237 L
.056 .51235 L
.06 .51237 L
.064 .51236 L
.068 .51237 L
.072 .51236 L
.076 .51237 L
.08 .51236 L
.084 .51236 L
.088 .51236 L
.092 .51236 L
.096 .51236 L
.1 .51236 L
.104 .51236 L
.108 .51236 L
.112 .51236 L
.116 .51236 L
.12 .51236 L
.124 .51236 L
.128 .51236 L
.132 .51236 L
.136 .51236 L
.14 .51236 L
.144 .51236 L
.148 .51236 L
.152 .51236 L
.156 .51236 L
.16 .51236 L
.164 .51236 L
.168 .51236 L
.172 .51236 L
.176 .51236 L
.18 .51236 L
.184 .51236 L
.188 .51236 L
.192 .51236 L
.196 .51236 L
.2 .51236 L
Mistroke
.204 .51236 L
.208 .51236 L
.212 .51236 L
.216 .51236 L
.22 .51236 L
.224 .51236 L
.228 .51236 L
.232 .51236 L
.236 .51236 L
.24 .51236 L
.244 .51236 L
.248 .51236 L
.252 .51236 L
.256 .51236 L
.26 .51236 L
.264 .51236 L
.268 .51236 L
.272 .51236 L
.276 .51235 L
.28 .51235 L
.284 .51235 L
.288 .51235 L
.292 .51235 L
.296 .51235 L
.3 .51235 L
.304 .51235 L
.308 .51235 L
.312 .51235 L
.316 .51235 L
.32 .51235 L
.324 .51235 L
.328 .51235 L
.332 .51235 L
.336 .51235 L
.34 .51235 L
.344 .51235 L
.348 .51235 L
.352 .51235 L
.356 .51235 L
.36 .51235 L
.364 .51235 L
.368 .51235 L
.372 .51235 L
.376 .51235 L
.38 .51235 L
.384 .51235 L
.388 .51235 L
.392 .51235 L
.396 .51235 L
.4 .51235 L
Mistroke
.404 .51234 L
.408 .51234 L
.412 .51234 L
.416 .51233 L
.42 .51233 L
.424 .51232 L
.428 .51231 L
.432 .51229 L
.436 .51227 L
.44 .51224 L
.444 .5122 L
.448 .51215 L
.452 .51208 L
.456 .51199 L
.46 .51188 L
.464 .51173 L
.468 .51154 L
.472 .51129 L
.476 .51099 L
.48 .51062 L
.484 .51015 L
.488 .50958 L
.492 .5089 L
.496 .50809 L
.5 .50713 L
.504 .50602 L
.508 .50473 L
.512 .50327 L
.516 .50163 L
.52 .49982 L
.524 .49784 L
.528 .4957 L
.532 .49343 L
.536 .49106 L
.54 .48862 L
.544 .48615 L
.548 .48368 L
.552 .48125 L
.556 .47891 L
.56 .47667 L
.564 .47455 L
.568 .47256 L
.572 .47068 L
.576 .46891 L
.58 .46721 L
.584 .46555 L
.588 .46389 L
.592 .46218 L
.596 .46039 L
.6 .4585 L
Mistroke
.604 .45653 L
.608 .45447 L
.612 .45236 L
.616 .45021 L
.62 .44809 L
.624 .44604 L
.628 .44411 L
.632 .44232 L
.636 .44067 L
.64 .43917 L
.644 .43779 L
.648 .43652 L
.652 .43535 L
.656 .43426 L
.66 .43322 L
.664 .43226 L
.668 .43141 L
.672 .43072 L
.676 .43025 L
.68 .43001 L
.684 .42999 L
.688 .4302 L
.692 .4306 L
.696 .43114 L
.7 .43177 L
.704 .43239 L
.708 .43292 L
.712 .4333 L
.716 .43353 L
.72 .43364 L
.724 .43366 L
.728 .43359 L
.732 .43344 L
.736 .43323 L
.74 .433 L
.744 .43277 L
.748 .43258 L
.752 .43243 L
.756 .43232 L
.76 .43224 L
.764 .43224 L
.768 .43236 L
.772 .43259 L
.776 .4329 L
.78 .43321 L
.784 .43342 L
.788 .43348 L
.792 .43341 L
.796 .43325 L
.8 .43304 L
Mistroke
.804 .43284 L
.808 .43268 L
.812 .43259 L
.816 .43261 L
.82 .43274 L
.824 .43296 L
.828 .4332 L
.832 .43339 L
.836 .43344 L
.84 .43337 L
.844 .43322 L
.848 .43307 L
.852 .43297 L
.856 .43296 L
.86 .43302 L
.864 .43309 L
.868 .43317 L
.872 .43322 L
.876 .43327 L
.88 .43332 L
.884 .43335 L
.888 .43338 L
.892 .43336 L
.896 .4333 L
.9 .43322 L
.904 .43316 L
.908 .43316 L
.912 .43323 L
.916 .43336 L
.92 .43351 L
.924 .43359 L
.928 .43358 L
.932 .43346 L
.936 .43333 L
.94 .43322 L
.944 .43324 L
.948 .43336 L
.952 .43355 L
.956 .4337 L
.96 .43374 L
.964 .43362 L
.968 .43347 L
.972 .43332 L
.976 .43332 L
.98 .43345 L
.984 .43366 L
.988 .43382 L
.992 .43389 L
.996 .43373 L
1 .43357 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42543 L
.012 .42988 L
.016 .43137 L
.02 .42976 L
.024 .42924 L
.028 .42969 L
.032 .42984 L
.036 .4296 L
.04 .42952 L
.044 .42951 L
.048 .42951 L
.052 .42943 L
.056 .42939 L
.06 .42934 L
.064 .42931 L
.068 .42925 L
.072 .42922 L
.076 .42917 L
.08 .42913 L
.084 .42908 L
.088 .42905 L
.092 .42899 L
.096 .42896 L
.1 .42891 L
.104 .42887 L
.108 .42882 L
.112 .42878 L
.116 .42873 L
.12 .42869 L
.124 .42865 L
.128 .42861 L
.132 .42856 L
.136 .42852 L
.14 .42847 L
.144 .42843 L
.148 .42839 L
.152 .42834 L
.156 .4283 L
.16 .42826 L
.164 .42821 L
.168 .42817 L
.172 .42812 L
.176 .42808 L
.18 .42804 L
.184 .42799 L
.188 .42795 L
.192 .42791 L
.196 .42786 L
.2 .42782 L
Mistroke
.204 .42777 L
.208 .42773 L
.212 .42769 L
.216 .42764 L
.22 .4276 L
.224 .42756 L
.228 .42751 L
.232 .42747 L
.236 .42742 L
.24 .42738 L
.244 .42734 L
.248 .42729 L
.252 .42725 L
.256 .42721 L
.26 .42716 L
.264 .42712 L
.268 .42708 L
.272 .42703 L
.276 .42699 L
.28 .42694 L
.284 .4269 L
.288 .42686 L
.292 .42681 L
.296 .42677 L
.3 .42673 L
.304 .42668 L
.308 .42664 L
.312 .42659 L
.316 .42655 L
.32 .42651 L
.324 .42646 L
.328 .42642 L
.332 .42638 L
.336 .42633 L
.34 .42629 L
.344 .42625 L
.348 .4262 L
.352 .42616 L
.356 .42611 L
.36 .42607 L
.364 .42603 L
.368 .42598 L
.372 .42594 L
.376 .4259 L
.38 .42585 L
.384 .42581 L
.388 .42577 L
.392 .42572 L
.396 .42568 L
.4 .42564 L
Mistroke
.404 .4256 L
.408 .42555 L
.412 .42551 L
.416 .42548 L
.42 .42544 L
.424 .42541 L
.428 .42537 L
.432 .42535 L
.436 .42533 L
.44 .42533 L
.444 .42533 L
.448 .42535 L
.452 .42539 L
.456 .42546 L
.46 .42556 L
.464 .4257 L
.468 .42589 L
.472 .42615 L
.476 .42649 L
.48 .42691 L
.484 .42745 L
.488 .42811 L
.492 .42891 L
.496 .42988 L
.5 .43103 L
.504 .43238 L
.508 .43394 L
.512 .43571 L
.516 .43771 L
.52 .43993 L
.524 .44236 L
.528 .44498 L
.532 .44777 L
.536 .45068 L
.54 .45368 L
.544 .45673 L
.548 .45976 L
.552 .46274 L
.556 .46563 L
.56 .46838 L
.564 .47099 L
.568 .47344 L
.572 .47574 L
.576 .4779 L
.58 .47998 L
.584 .48203 L
.588 .48408 L
.592 .48618 L
.596 .48836 L
.6 .49066 L
Mistroke
.604 .49309 L
.608 .49563 L
.612 .49825 L
.616 .50088 L
.62 .50348 L
.624 .50599 L
.628 .50838 L
.632 .5106 L
.636 .51264 L
.64 .51447 L
.644 .51614 L
.648 .51768 L
.652 .51912 L
.656 .52049 L
.66 .52176 L
.664 .52291 L
.668 .52391 L
.672 .52473 L
.676 .52532 L
.68 .52564 L
.684 .52563 L
.688 .52531 L
.692 .52475 L
.696 .52403 L
.7 .52326 L
.704 .52251 L
.708 .52184 L
.712 .52129 L
.716 .52092 L
.72 .52074 L
.724 .52074 L
.728 .52086 L
.732 .52103 L
.736 .52122 L
.74 .52141 L
.744 .52164 L
.748 .52189 L
.752 .52212 L
.756 .52228 L
.76 .52231 L
.764 .5222 L
.768 .52198 L
.772 .52168 L
.776 .52135 L
.78 .52101 L
.784 .52072 L
.788 .52053 L
.792 .5205 L
.796 .52066 L
.8 .52096 L
Mistroke
.804 .52128 L
.808 .5215 L
.812 .52154 L
.816 .52139 L
.82 .52112 L
.824 .52083 L
.828 .52059 L
.832 .52043 L
.836 .52036 L
.84 .52036 L
.844 .52041 L
.848 .52051 L
.852 .52062 L
.856 .5207 L
.86 .5207 L
.864 .52061 L
.868 .52043 L
.872 .52024 L
.876 .52006 L
.88 .51998 L
.884 .51997 L
.888 .52002 L
.892 .52009 L
.896 .52013 L
.9 .52011 L
.904 .52004 L
.908 .51994 L
.912 .51983 L
.916 .51974 L
.92 .51968 L
.924 .51964 L
.928 .51962 L
.932 .51958 L
.936 .51956 L
.94 .51953 L
.944 .51953 L
.948 .51952 L
.952 .51949 L
.956 .51941 L
.96 .5193 L
.964 .51914 L
.968 .51906 L
.972 .51901 L
.976 .51908 L
.98 .51918 L
.984 .51924 L
.988 .5192 L
.992 .51908 L
.996 .51881 L
1 .51865 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20002Ool50004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo041oo`04001oo`000004Ool20003Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool0029oo`80
045oo`04001oogoo0004Ool00`00Ool00002Ool20002Ool20003Ool2000017oo000007oo0P003Woo
000ROomS000<Ool0029oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`04001oogoo0003Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`8000=oo`05001o
ogooOol00003Ool01000Oomoo`000goo00@007ooOomoo`D000=oo`05001oogooOol00003Ool01000
Oomoogoo0P000Woo00<007ooOol00P0037oo000ROol2000]Ool00`00Oomoo`0@Ool00`00Oomoo`0Z
Ool0029oo`03001oogoo02eoo`03001oogoo00ioo`8002aoo`008Woo0P00;Woo00<007ooOol03Goo
0P00;Goo000ROol2000_Ool00`00Oomoo`0;Ool2000^Ool000]oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`03001oogoo02moo`03001oogoo00Uoo`8002moo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2000`Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomo
o`0^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00<7oo00<007oo
Ool00goo00<007oo00000Woo00<007ooOol0;goo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo031oo`05001oogooOol00003Ool00`00Ool0000aOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00<Goo00D007ooOomoo`0000Aoo`80
035oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2000bOol00`00Ool0000hOol0
00]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo039oo`8003Qoo`002goo0P0017oo00<0
07ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04
001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool0
00Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007oo
Ool000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo
0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`80
06eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo
008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo
0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00
KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo
0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomo
o`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@00
0Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo
00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Ao
o`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Io
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0
2Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool0
0`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001o
ogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`00
2goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo
00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo
00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo
00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomo
o`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
0goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo
00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol0
17oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomo
o`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`00
0Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@0037oo
000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomo
o`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomo
o`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00D007ooOol007oo00@000=oo`03001oogoo03Uooal00003Ool007oo00]oo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo03Moo`<001]oo`04001o
o`00000=Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo03Eoo`8002moo`00:7oo
00<007ooOol0<goo0P00<Goo000XOol00`00Oomoo`0`Ool3000cOol0015oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`03001oogoo02moo`8003Eoo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`0]Ool2000gOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0:Goo1@00>7oo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oobd003aoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04
001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0
KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<0
07ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Mo
o`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo
0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool2
0004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool2
0006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo
00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo
00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001o
ogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007oo
Ool0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`00
0Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P00
3Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04
001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00ao
o`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`80
00=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04
001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=o
o`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool2
0004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol0
2Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yo
o`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo
000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007oo
Ool017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol0
0`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02
Ool00`00Oomoo`1bOol001Moo`03001oogoo009oocH003moo`005goo00<007ooOol00Woo00<007oo
Ool0<Woo0P00?Woo000GOol00`00Oomoo`02Ool00`00Oomoo`0dOol2000lOol001Ioo`8000Aoo`80
03Ioo`8003]oo`005goo00<007ooOol00Woo00<007ooOol0=goo0P00>Goo000LOol00`00Oomoo`0h
Ool3000gOol001aoo`8003]oo`8003Ioo`0077oo00<007ooOol0?7oo0P00=7oo000LOol2000nOol3
000bOol001aoo`03001oogoo03moo`<000Eoo`@0009oo`@00003Ool00000018000aoo`0077oo00<0
07ooOol0@Goo1P000goo10000goo00<007ooOol07Woo000:Ool30004Ool00`00Oomoo`02Ool30003
Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03
001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo
00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomo
o`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(9352\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29995 m
.008 .30081 L
.012 .30038 L
.016 .30031 L
.02 .30047 L
.024 .30037 L
.028 .30026 L
.032 .30034 L
.036 .3004 L
.04 .30034 L
.044 .3003 L
.048 .30032 L
.052 .30034 L
.056 .30032 L
.06 .3003 L
.064 .3003 L
.068 .3003 L
.072 .30029 L
.076 .30028 L
.08 .30028 L
.084 .30027 L
.088 .30027 L
.092 .30026 L
.096 .30025 L
.1 .30025 L
.104 .30024 L
.108 .30024 L
.112 .30023 L
.116 .30023 L
.12 .30022 L
.124 .30021 L
.128 .30021 L
.132 .3002 L
.136 .3002 L
.14 .30019 L
.144 .30018 L
.148 .30018 L
.152 .30017 L
.156 .30016 L
.16 .30016 L
.164 .30016 L
.168 .30015 L
.172 .30014 L
.176 .30013 L
.18 .30013 L
.184 .30013 L
.188 .30012 L
.192 .30011 L
.196 .3001 L
.2 .30011 L
Mistroke
.204 .3001 L
.208 .30008 L
.212 .30008 L
.216 .30008 L
.22 .30008 L
.224 .30006 L
.228 .30005 L
.232 .30005 L
.236 .30006 L
.24 .30005 L
.244 .30003 L
.248 .30002 L
.252 .30003 L
.256 .30003 L
.26 .30001 L
.264 .29999 L
.268 .3 L
.272 .30001 L
.276 .3 L
.28 .29997 L
.284 .29996 L
.288 .29998 L
.292 .29999 L
.296 .29996 L
.3 .29993 L
.304 .29994 L
.308 .29996 L
.312 .29996 L
.316 .29992 L
.32 .2999 L
.324 .29992 L
.328 .29994 L
.332 .29992 L
.336 .29987 L
.34 .29987 L
.344 .29991 L
.348 .29993 L
.352 .29989 L
.356 .29984 L
.36 .29986 L
.364 .29992 L
.368 .29993 L
.372 .29989 L
.376 .29987 L
.38 .29993 L
.384 .30003 L
.388 .30009 L
.392 .30011 L
.396 .3002 L
.4 .30041 L
Mistroke
.404 .30069 L
.408 .30098 L
.412 .3013 L
.416 .3018 L
.42 .30254 L
.424 .3035 L
.428 .30461 L
.432 .30595 L
.436 .30772 L
.44 .31 L
.444 .31279 L
.448 .31604 L
.452 .31986 L
.456 .32443 L
.46 .32984 L
.464 .33605 L
.468 .34293 L
.472 .35045 L
.476 .35867 L
.48 .36753 L
.484 .37678 L
.488 .38606 L
.492 .39504 L
.496 .40352 L
.5 .41127 L
.504 .4179 L
.508 .42293 L
.512 .42601 L
.516 .42702 L
.52 .42607 L
.524 .42325 L
.528 .41866 L
.532 .41254 L
.536 .40542 L
.54 .3981 L
.544 .39142 L
.548 .38595 L
.552 .38205 L
.556 .37999 L
.56 .38008 L
.564 .38242 L
.568 .38668 L
.572 .39202 L
.576 .39733 L
.58 .40172 L
.584 .40463 L
.588 .40568 L
.592 .40444 L
.596 .40053 L
.6 .39409 L
Mistroke
.604 .38598 L
.608 .37754 L
.612 .36986 L
.616 .36341 L
.62 .35808 L
.624 .35377 L
.628 .35046 L
.632 .34795 L
.636 .34529 L
.64 .34102 L
.644 .3339 L
.648 .32385 L
.652 .31203 L
.656 .30004 L
.66 .28907 L
.664 .27974 L
.668 .2727 L
.672 .26904 L
.676 .26985 L
.68 .27514 L
.684 .28329 L
.688 .29174 L
.692 .29851 L
.696 .30319 L
.7 .30659 L
.704 .30942 L
.708 .31148 L
.712 .312 L
.716 .31082 L
.72 .3089 L
.724 .30749 L
.728 .30683 L
.732 .30563 L
.736 .30218 L
.74 .29617 L
.744 .28955 L
.748 .28542 L
.752 .28585 L
.756 .29055 L
.76 .29727 L
.764 .30357 L
.768 .30832 L
.772 .3115 L
.776 .31309 L
.78 .31226 L
.784 .30792 L
.788 .30036 L
.792 .29205 L
.796 .28671 L
.8 .28706 L
Mistroke
.804 .29275 L
.808 .30067 L
.812 .30676 L
.816 .30875 L
.82 .30714 L
.824 .30413 L
.828 .30184 L
.832 .30066 L
.836 .29973 L
.84 .29822 L
.844 .29633 L
.848 .29539 L
.852 .29653 L
.856 .29966 L
.86 .3033 L
.864 .30558 L
.868 .30544 L
.872 .30325 L
.876 .30038 L
.88 .29811 L
.884 .29723 L
.888 .29747 L
.892 .29841 L
.896 .29978 L
.9 .30109 L
.904 .30242 L
.908 .30318 L
.912 .30286 L
.916 .30182 L
.92 .2999 L
.924 .29834 L
.928 .29783 L
.932 .29802 L
.936 .29951 L
.94 .30093 L
.944 .30196 L
.948 .30301 L
.952 .30262 L
.956 .30196 L
.96 .3006 L
.964 .29811 L
.968 .29705 L
.972 .29666 L
.976 .29819 L
.98 .30216 L
.984 .30473 L
.988 .30625 L
.992 .3047 L
.996 .29937 L
1 .29532 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51827 m
.008 .51209 L
.012 .51009 L
.016 .51215 L
.02 .51285 L
.024 .51211 L
.028 .51191 L
.032 .51213 L
.036 .51223 L
.04 .51213 L
.044 .51212 L
.048 .51213 L
.052 .51216 L
.056 .51213 L
.06 .51214 L
.064 .51213 L
.068 .51215 L
.072 .51213 L
.076 .51214 L
.08 .51213 L
.084 .51214 L
.088 .51214 L
.092 .51214 L
.096 .51214 L
.1 .51214 L
.104 .51214 L
.108 .51214 L
.112 .51214 L
.116 .51214 L
.12 .51214 L
.124 .51214 L
.128 .51214 L
.132 .51214 L
.136 .51214 L
.14 .51214 L
.144 .51214 L
.148 .51214 L
.152 .51214 L
.156 .51214 L
.16 .51214 L
.164 .51214 L
.168 .51214 L
.172 .51214 L
.176 .51214 L
.18 .51214 L
.184 .51214 L
.188 .51214 L
.192 .51214 L
.196 .51214 L
.2 .51214 L
Mistroke
.204 .51214 L
.208 .51214 L
.212 .51214 L
.216 .51214 L
.22 .51214 L
.224 .51213 L
.228 .51214 L
.232 .51213 L
.236 .51213 L
.24 .51213 L
.244 .51213 L
.248 .51213 L
.252 .51213 L
.256 .51213 L
.26 .51213 L
.264 .51213 L
.268 .51213 L
.272 .51213 L
.276 .51213 L
.28 .51213 L
.284 .51213 L
.288 .51213 L
.292 .51213 L
.296 .51213 L
.3 .51213 L
.304 .51213 L
.308 .51213 L
.312 .51213 L
.316 .51213 L
.32 .51213 L
.324 .51213 L
.328 .51213 L
.332 .51213 L
.336 .51213 L
.34 .51213 L
.344 .51213 L
.348 .51213 L
.352 .51213 L
.356 .51213 L
.36 .51213 L
.364 .51213 L
.368 .51213 L
.372 .51212 L
.376 .51212 L
.38 .51212 L
.384 .51212 L
.388 .51211 L
.392 .51211 L
.396 .5121 L
.4 .51209 L
Mistroke
.404 .51208 L
.408 .51205 L
.412 .51203 L
.416 .51199 L
.42 .51194 L
.424 .51188 L
.428 .51179 L
.432 .51168 L
.436 .51154 L
.44 .51136 L
.444 .51114 L
.448 .51085 L
.452 .51049 L
.456 .51005 L
.46 .50952 L
.464 .50887 L
.468 .50809 L
.472 .50718 L
.476 .50611 L
.48 .50488 L
.484 .50348 L
.488 .50189 L
.492 .50013 L
.496 .49821 L
.5 .49612 L
.504 .4939 L
.508 .49156 L
.512 .48914 L
.516 .48668 L
.52 .48421 L
.524 .48177 L
.528 .4794 L
.532 .47712 L
.536 .47495 L
.54 .47291 L
.544 .471 L
.548 .46919 L
.552 .46747 L
.556 .4658 L
.56 .46414 L
.564 .46245 L
.568 .46071 L
.572 .45887 L
.576 .45694 L
.58 .45492 L
.584 .45283 L
.588 .45071 L
.592 .44858 L
.596 .4465 L
.6 .44452 L
Mistroke
.604 .44267 L
.608 .44097 L
.612 .43942 L
.616 .43801 L
.62 .43671 L
.624 .43552 L
.628 .43442 L
.632 .43339 L
.636 .43243 L
.64 .43156 L
.644 .43083 L
.648 .43027 L
.652 .42994 L
.656 .42983 L
.66 .42996 L
.664 .43029 L
.668 .43078 L
.672 .43138 L
.676 .43201 L
.68 .43259 L
.684 .43305 L
.688 .43336 L
.692 .43352 L
.696 .43357 L
.7 .43351 L
.704 .43338 L
.708 .43318 L
.712 .43295 L
.716 .43273 L
.72 .43253 L
.724 .43237 L
.728 .43223 L
.732 .43214 L
.736 .43211 L
.74 .43218 L
.744 .43236 L
.748 .43263 L
.752 .43293 L
.756 .43317 L
.76 .43331 L
.764 .43333 L
.768 .43324 L
.772 .43307 L
.776 .43285 L
.78 .43263 L
.784 .43247 L
.788 .43242 L
.792 .43251 L
.796 .43272 L
.8 .43298 L
Mistroke
.804 .43319 L
.808 .43329 L
.812 .43326 L
.816 .43316 L
.82 .43303 L
.824 .43294 L
.828 .43289 L
.832 .43287 L
.836 .43288 L
.84 .43293 L
.844 .43301 L
.848 .43312 L
.852 .43322 L
.856 .43329 L
.86 .43329 L
.864 .43322 L
.868 .43313 L
.872 .43306 L
.876 .43304 L
.88 .43308 L
.884 .43316 L
.888 .43324 L
.892 .43331 L
.896 .43334 L
.9 .43334 L
.904 .43332 L
.908 .43329 L
.912 .43327 L
.916 .43325 L
.92 .43326 L
.924 .43329 L
.928 .43334 L
.932 .43339 L
.936 .43345 L
.94 .43346 L
.944 .43348 L
.948 .43344 L
.952 .43341 L
.956 .43338 L
.96 .43337 L
.964 .4334 L
.968 .43349 L
.972 .43356 L
.976 .43365 L
.98 .43364 L
.984 .4336 L
.988 .4335 L
.992 .43344 L
.996 .43342 L
1 .43353 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42884 L
.012 .42965 L
.016 .43015 L
.02 .42991 L
.024 .42968 L
.028 .42961 L
.032 .42969 L
.036 .42963 L
.04 .42957 L
.044 .4295 L
.048 .42949 L
.052 .42943 L
.056 .4294 L
.06 .42934 L
.064 .42931 L
.068 .42926 L
.072 .42922 L
.076 .42917 L
.08 .42913 L
.084 .42908 L
.088 .42905 L
.092 .42899 L
.096 .42896 L
.1 .42891 L
.104 .42887 L
.108 .42882 L
.112 .42878 L
.116 .42873 L
.12 .4287 L
.124 .42865 L
.128 .42861 L
.132 .42856 L
.136 .42852 L
.14 .42847 L
.144 .42843 L
.148 .42839 L
.152 .42834 L
.156 .4283 L
.16 .42826 L
.164 .42821 L
.168 .42817 L
.172 .42812 L
.176 .42808 L
.18 .42804 L
.184 .42799 L
.188 .42795 L
.192 .42791 L
.196 .42786 L
.2 .42782 L
Mistroke
.204 .42778 L
.208 .42773 L
.212 .42769 L
.216 .42765 L
.22 .4276 L
.224 .42756 L
.228 .42751 L
.232 .42747 L
.236 .42743 L
.24 .42738 L
.244 .42734 L
.248 .4273 L
.252 .42725 L
.256 .42721 L
.26 .42716 L
.264 .42712 L
.268 .42708 L
.272 .42703 L
.276 .42699 L
.28 .42695 L
.284 .4269 L
.288 .42686 L
.292 .42681 L
.296 .42677 L
.3 .42673 L
.304 .42668 L
.308 .42664 L
.312 .4266 L
.316 .42655 L
.32 .42651 L
.324 .42647 L
.328 .42642 L
.332 .42638 L
.336 .42633 L
.34 .42629 L
.344 .42625 L
.348 .4262 L
.352 .42616 L
.356 .42612 L
.36 .42607 L
.364 .42603 L
.368 .42599 L
.372 .42594 L
.376 .4259 L
.38 .42586 L
.384 .42582 L
.388 .42578 L
.392 .42575 L
.396 .42571 L
.4 .42568 L
Mistroke
.404 .42566 L
.408 .42564 L
.412 .42563 L
.416 .42563 L
.42 .42564 L
.424 .42568 L
.428 .42574 L
.432 .42583 L
.436 .42596 L
.44 .42615 L
.444 .42639 L
.448 .4267 L
.452 .4271 L
.456 .42761 L
.46 .42823 L
.464 .42899 L
.468 .42991 L
.472 .43101 L
.476 .43229 L
.48 .43379 L
.484 .43549 L
.488 .43742 L
.492 .43957 L
.496 .44193 L
.5 .44449 L
.504 .44722 L
.508 .45009 L
.512 .45306 L
.516 .45609 L
.52 .45913 L
.524 .46213 L
.528 .46505 L
.532 .46786 L
.536 .47052 L
.54 .47303 L
.544 .47538 L
.548 .4776 L
.552 .4797 L
.556 .48175 L
.56 .48378 L
.564 .48586 L
.568 .488 L
.572 .49025 L
.576 .49261 L
.58 .4951 L
.584 .49767 L
.588 .5003 L
.592 .50292 L
.596 .50546 L
.6 .5079 L
Mistroke
.604 .51018 L
.608 .51228 L
.612 .51419 L
.616 .51592 L
.62 .51749 L
.624 .51894 L
.628 .5203 L
.632 .52157 L
.636 .52274 L
.64 .52378 L
.644 .52465 L
.648 .52531 L
.652 .52572 L
.656 .52584 L
.66 .52566 L
.664 .5252 L
.668 .52454 L
.672 .52377 L
.676 .52298 L
.68 .52225 L
.684 .52165 L
.688 .5212 L
.692 .52094 L
.696 .52087 L
.7 .52095 L
.704 .52112 L
.708 .52132 L
.712 .52153 L
.716 .52176 L
.72 .52199 L
.724 .52221 L
.728 .52239 L
.732 .52246 L
.736 .52242 L
.74 .52226 L
.744 .52202 L
.748 .52171 L
.752 .52137 L
.756 .52103 L
.76 .52077 L
.764 .52066 L
.768 .52074 L
.772 .52099 L
.776 .5213 L
.78 .52155 L
.784 .52168 L
.788 .52163 L
.792 .52146 L
.796 .52122 L
.8 .52095 L
Mistroke
.804 .52071 L
.808 .52053 L
.812 .52045 L
.816 .52048 L
.82 .52061 L
.824 .52078 L
.828 .52091 L
.832 .52093 L
.836 .52082 L
.84 .52064 L
.844 .52045 L
.848 .52032 L
.852 .52025 L
.856 .52023 L
.86 .52022 L
.864 .5202 L
.868 .52018 L
.872 .52019 L
.876 .52021 L
.88 .52023 L
.884 .52019 L
.888 .52009 L
.892 .51992 L
.896 .51976 L
.9 .51965 L
.904 .51965 L
.908 .51971 L
.912 .51983 L
.916 .51989 L
.92 .51985 L
.924 .5197 L
.928 .5195 L
.932 .51931 L
.936 .51924 L
.94 .51927 L
.944 .5194 L
.948 .51949 L
.952 .5195 L
.956 .51938 L
.96 .51917 L
.964 .51896 L
.968 .51889 L
.972 .5189 L
.976 .51907 L
.98 .51915 L
.984 .51916 L
.988 .519 L
.992 .51877 L
.996 .51855 L
1 .51851 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool30003Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo03ioo`03001oo`0000Eoo`03001oogoo009oo`03001oogoo01ioo`008Woo0P00?Woo00<0
07ooOol00P000goo0`000Woo0P000goo0P000Woo0P000Woo0P000Woo0P000Woo00<007ooOol02Woo
000ROomS000<Ool0029oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOomoo`80009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000Woo00D007oo001oo`00009oo`8000=oo`<00003Ool007oo009oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol02Woo000ROol2000ZOol2000AOol0
0`00Oomoo`0]Ool0029oo`03001oogoo02Yoo`03001oogoo00moo`03001oogoo02eoo`008Woo0P00
;7oo00<007ooOol03Goo00<007ooOol0;Woo000ROol2000/Ool2000=Ool00`00Oomoo`0_Ool000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo02aoo`03001oogoo00Yoo`03001o
ogoo031oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000]Ool00`00
Oomoo`04Ool20003Ool00`00Oomoo`0aOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P00;Woo00<007ooOol00goo0P000goo00<007ooOol0<Goo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo02eoo`03001oogoo009oo`05001oogoo
001oo`02000cOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00;Woo
0P000Woo00<007ooOol00Woo0P00=7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Ao
o`8002moo`04001oogoo000jOol000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo02mo
o`8003]oo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol0
00Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001o
ogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`00
2goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`00
0goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029o
o`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=o
o`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo
0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo
0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`80
00Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=o
o`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<0
00Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`80
00=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomo
o`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001o
o`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000
Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00
:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<0
07ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomo
o`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09
Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo
0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?
Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo03Moob<000ao
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo03Ao
o`@002ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0<Woo0`00<Goo000XOol0
0`00Oomoo`0`Ool3000cOol002Qoo`03001oogoo02ioo`<003Eoo`004Goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo00<007ooOol0;7oo0P00>7oo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo02Yoo`<003Uoo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool2000XOol4000kOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo:P00?goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1V
Ool0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05
001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomo
o`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]o
o`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
00]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02
001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool5
0002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`80
00Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`00
77oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomo
o`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo
00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003
Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomo
ogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0
00Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007oo
Ool017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<0
07ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0
00Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo
00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`80
00Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001ao
ofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007oo
Ool000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04
001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2
001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001o
ogoo079oo`005goo00<007ooOol00Woo<`00@Woo000GOol00`00Oomoo`02Ool00`00Oomoo`0_Ool2
0011Ool001Moo`03001oogoo009oo`03001oogoo035oo`8003moo`005Woo0P0017oo0P00=7oo00<0
07ooOol0?7oo000GOol00`00Oomoo`02Ool00`00Oomoo`0dOol2000lOol001aoo`03001oogoo03Eo
o`<003Yoo`0077oo0P00>7oo0P00>Goo000LOol00`00Oomoo`0iOol2000gOol001aoo`8003]oo`<0
03Eoo`0077oo00<007ooOol0?7oo0`001Goo0`0017oo0`0000=oo`0000005@0037oo000LOol00`00
Oomoo`0oOol60002Ool50002Ool2000ROol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=o
o`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol0
2goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomo
o`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`00
2goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(9519\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30257 m
.008 .30128 L
.012 .29969 L
.016 .29948 L
.02 .30065 L
.024 .30093 L
.028 .3003 L
.032 .30012 L
.036 .30041 L
.04 .30048 L
.044 .30036 L
.048 .30031 L
.052 .30036 L
.056 .30037 L
.06 .30034 L
.064 .30033 L
.068 .30033 L
.072 .30033 L
.076 .30032 L
.08 .30031 L
.084 .30031 L
.088 .3003 L
.092 .30029 L
.096 .30029 L
.1 .30028 L
.104 .30028 L
.108 .30027 L
.112 .30026 L
.116 .30026 L
.12 .30025 L
.124 .30025 L
.128 .30024 L
.132 .30024 L
.136 .30023 L
.14 .30022 L
.144 .30022 L
.148 .30021 L
.152 .30021 L
.156 .3002 L
.16 .30019 L
.164 .30019 L
.168 .30019 L
.172 .30018 L
.176 .30017 L
.18 .30016 L
.184 .30016 L
.188 .30016 L
.192 .30014 L
.196 .30014 L
.2 .30014 L
Mistroke
.204 .30014 L
.208 .30012 L
.212 .30011 L
.216 .30011 L
.22 .30011 L
.224 .3001 L
.228 .30009 L
.232 .30008 L
.236 .30009 L
.24 .30008 L
.244 .30007 L
.248 .30005 L
.252 .30006 L
.256 .30007 L
.26 .30005 L
.264 .30003 L
.268 .30003 L
.272 .30004 L
.276 .30004 L
.28 .30001 L
.284 .3 L
.288 .30001 L
.292 .30002 L
.296 .3 L
.3 .29997 L
.304 .29997 L
.308 .29999 L
.312 .29999 L
.316 .29996 L
.32 .29994 L
.324 .29996 L
.328 .29998 L
.332 .29998 L
.336 .29994 L
.34 .29994 L
.344 .29998 L
.348 .30003 L
.352 .30003 L
.356 .30003 L
.36 .30009 L
.364 .30022 L
.368 .30035 L
.372 .30046 L
.376 .30064 L
.38 .30094 L
.384 .30138 L
.388 .30189 L
.392 .30249 L
.396 .3033 L
.4 .30442 L
Mistroke
.404 .30585 L
.408 .30757 L
.412 .30964 L
.416 .31222 L
.42 .31543 L
.424 .31927 L
.428 .32373 L
.432 .32885 L
.436 .33479 L
.44 .34159 L
.444 .34916 L
.448 .35733 L
.452 .366 L
.456 .37512 L
.46 .38453 L
.464 .39387 L
.468 .40274 L
.472 .41077 L
.476 .41774 L
.48 .42337 L
.484 .42731 L
.488 .42921 L
.492 .42893 L
.496 .4266 L
.5 .42249 L
.504 .4169 L
.508 .41018 L
.512 .40284 L
.516 .39564 L
.52 .38941 L
.524 .38475 L
.528 .38202 L
.532 .38134 L
.536 .38275 L
.54 .38612 L
.544 .39098 L
.548 .39651 L
.552 .40164 L
.556 .40542 L
.56 .40723 L
.564 .40678 L
.568 .4039 L
.572 .3986 L
.576 .39124 L
.58 .38267 L
.584 .37407 L
.588 .36644 L
.592 .36029 L
.596 .35552 L
.6 .3518 L
Mistroke
.604 .34873 L
.608 .34577 L
.612 .34206 L
.616 .33646 L
.62 .32821 L
.624 .31741 L
.628 .30521 L
.632 .29319 L
.636 .28271 L
.64 .27466 L
.644 .26972 L
.648 .26858 L
.652 .27164 L
.656 .27839 L
.66 .28711 L
.664 .29558 L
.668 .3022 L
.672 .30666 L
.676 .30955 L
.68 .31141 L
.684 .31219 L
.688 .31164 L
.692 .31001 L
.696 .30817 L
.7 .30682 L
.704 .30562 L
.708 .30332 L
.712 .29895 L
.716 .29311 L
.72 .288 L
.724 .286 L
.728 .28806 L
.732 .29318 L
.736 .29941 L
.74 .30522 L
.744 .31001 L
.748 .31335 L
.752 .31424 L
.756 .31141 L
.76 .30462 L
.764 .29584 L
.768 .28871 L
.772 .28645 L
.776 .28979 L
.78 .29644 L
.784 .30289 L
.788 .30661 L
.792 .30739 L
.796 .30659 L
.8 .30534 L
Mistroke
.804 .30371 L
.808 .30107 L
.812 .29751 L
.816 .29443 L
.82 .29369 L
.824 .29612 L
.828 .30045 L
.832 .30418 L
.836 .30532 L
.84 .30382 L
.844 .30141 L
.848 .30004 L
.852 .30029 L
.856 .30101 L
.86 .30069 L
.864 .29883 L
.868 .29668 L
.872 .2963 L
.876 .29862 L
.88 .30286 L
.884 .30644 L
.888 .30688 L
.892 .30382 L
.896 .29856 L
.9 .29428 L
.904 .29342 L
.908 .29615 L
.912 .30139 L
.916 .30592 L
.92 .30739 L
.924 .30549 L
.928 .30057 L
.932 .2959 L
.936 .29379 L
.94 .29496 L
.944 .29974 L
.948 .30464 L
.952 .30714 L
.956 .30625 L
.96 .30113 L
.964 .29591 L
.968 .29339 L
.972 .29458 L
.976 .30043 L
.98 .30599 L
.984 .30809 L
.988 .30611 L
.992 .29928 L
.996 .29341 L
1 .29201 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51416 m
.008 .51204 L
.012 .51129 L
.016 .51176 L
.02 .51212 L
.024 .51199 L
.028 .51188 L
.032 .51187 L
.036 .51194 L
.04 .51193 L
.044 .51192 L
.048 .5119 L
.052 .51193 L
.056 .51191 L
.06 .51192 L
.064 .51191 L
.068 .51192 L
.072 .51191 L
.076 .51192 L
.08 .51191 L
.084 .51192 L
.088 .51191 L
.092 .51192 L
.096 .51191 L
.1 .51192 L
.104 .51191 L
.108 .51192 L
.112 .51191 L
.116 .51192 L
.12 .51191 L
.124 .51192 L
.128 .51192 L
.132 .51192 L
.136 .51192 L
.14 .51192 L
.144 .51192 L
.148 .51192 L
.152 .51192 L
.156 .51192 L
.16 .51191 L
.164 .51192 L
.168 .51191 L
.172 .51192 L
.176 .51191 L
.18 .51192 L
.184 .51191 L
.188 .51192 L
.192 .51191 L
.196 .51192 L
.2 .51191 L
Mistroke
.204 .51191 L
.208 .51191 L
.212 .51191 L
.216 .51191 L
.22 .51191 L
.224 .51191 L
.228 .51191 L
.232 .51191 L
.236 .51191 L
.24 .51191 L
.244 .51191 L
.248 .51191 L
.252 .51191 L
.256 .51191 L
.26 .51191 L
.264 .51191 L
.268 .51191 L
.272 .51191 L
.276 .51191 L
.28 .51191 L
.284 .51191 L
.288 .51191 L
.292 .51191 L
.296 .51191 L
.3 .51191 L
.304 .51191 L
.308 .51191 L
.312 .51191 L
.316 .51191 L
.32 .51191 L
.324 .51191 L
.328 .51191 L
.332 .51191 L
.336 .51191 L
.34 .51191 L
.344 .51191 L
.348 .5119 L
.352 .5119 L
.356 .5119 L
.36 .51189 L
.364 .51189 L
.368 .51188 L
.372 .51187 L
.376 .51186 L
.38 .51184 L
.384 .51181 L
.388 .51178 L
.392 .51173 L
.396 .51167 L
.4 .51159 L
Mistroke
.404 .51149 L
.408 .51136 L
.412 .51119 L
.416 .51097 L
.42 .5107 L
.424 .51036 L
.428 .50995 L
.432 .50944 L
.436 .50882 L
.44 .50809 L
.444 .50721 L
.448 .50619 L
.452 .50501 L
.456 .50366 L
.46 .50214 L
.464 .50044 L
.468 .49856 L
.472 .49653 L
.476 .49435 L
.48 .49205 L
.484 .48966 L
.488 .48722 L
.492 .48475 L
.496 .4823 L
.5 .4799 L
.504 .47758 L
.508 .47538 L
.512 .47329 L
.516 .47133 L
.52 .46949 L
.524 .46774 L
.528 .46605 L
.532 .46439 L
.536 .46272 L
.54 .46101 L
.544 .45922 L
.548 .45734 L
.552 .45536 L
.556 .4533 L
.56 .45119 L
.564 .44907 L
.568 .44698 L
.572 .44496 L
.576 .44305 L
.58 .44129 L
.584 .43969 L
.588 .43823 L
.592 .43691 L
.596 .43569 L
.6 .43457 L
Mistroke
.604 .43354 L
.608 .43258 L
.612 .4317 L
.616 .43094 L
.62 .43033 L
.624 .42991 L
.628 .42971 L
.632 .42975 L
.636 .43001 L
.64 .43044 L
.644 .431 L
.648 .43163 L
.652 .43224 L
.656 .43276 L
.66 .43315 L
.664 .43338 L
.668 .43347 L
.672 .43344 L
.676 .43332 L
.68 .43313 L
.684 .43291 L
.688 .43268 L
.692 .43247 L
.696 .43229 L
.7 .43215 L
.704 .43205 L
.708 .432 L
.712 .43203 L
.716 .43216 L
.72 .43238 L
.724 .43265 L
.728 .43291 L
.732 .43311 L
.736 .4332 L
.74 .43318 L
.744 .43305 L
.748 .43286 L
.752 .43262 L
.756 .43242 L
.76 .4323 L
.764 .43232 L
.768 .43247 L
.772 .43271 L
.776 .43294 L
.78 .4331 L
.784 .43315 L
.788 .43311 L
.792 .43301 L
.796 .4329 L
.8 .4328 L
Mistroke
.804 .43273 L
.808 .4327 L
.812 .43274 L
.816 .43283 L
.82 .43297 L
.824 .43309 L
.828 .43315 L
.832 .43315 L
.836 .43309 L
.84 .43302 L
.844 .43298 L
.848 .43297 L
.852 .43299 L
.856 .43301 L
.86 .43303 L
.864 .43307 L
.868 .43314 L
.872 .43321 L
.876 .43327 L
.88 .43327 L
.884 .43321 L
.888 .43312 L
.892 .43306 L
.896 .43306 L
.9 .43314 L
.904 .43327 L
.908 .43338 L
.912 .43343 L
.916 .43338 L
.92 .43329 L
.924 .43319 L
.928 .43317 L
.932 .43322 L
.936 .43334 L
.94 .43345 L
.944 .43352 L
.948 .43348 L
.952 .43342 L
.956 .43332 L
.96 .43329 L
.964 .43334 L
.968 .43346 L
.972 .43356 L
.976 .43363 L
.98 .43357 L
.984 .4335 L
.988 .43339 L
.992 .43339 L
.996 .43347 L
1 .43361 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43424 L
.012 .42979 L
.016 .42839 L
.02 .42981 L
.024 .43026 L
.028 .42967 L
.032 .4295 L
.036 .4296 L
.04 .42964 L
.044 .42951 L
.048 .42947 L
.052 .42943 L
.056 .42941 L
.06 .42934 L
.064 .42931 L
.068 .42925 L
.072 .42922 L
.076 .42917 L
.08 .42913 L
.084 .42908 L
.088 .42905 L
.092 .429 L
.096 .42896 L
.1 .42891 L
.104 .42887 L
.108 .42882 L
.112 .42878 L
.116 .42874 L
.12 .4287 L
.124 .42865 L
.128 .42861 L
.132 .42856 L
.136 .42852 L
.14 .42847 L
.144 .42843 L
.148 .42839 L
.152 .42835 L
.156 .4283 L
.16 .42826 L
.164 .42821 L
.168 .42817 L
.172 .42813 L
.176 .42808 L
.18 .42804 L
.184 .428 L
.188 .42795 L
.192 .42791 L
.196 .42786 L
.2 .42782 L
Mistroke
.204 .42778 L
.208 .42773 L
.212 .42769 L
.216 .42765 L
.22 .4276 L
.224 .42756 L
.228 .42751 L
.232 .42747 L
.236 .42743 L
.24 .42738 L
.244 .42734 L
.248 .4273 L
.252 .42725 L
.256 .42721 L
.26 .42717 L
.264 .42712 L
.268 .42708 L
.272 .42704 L
.276 .42699 L
.28 .42695 L
.284 .4269 L
.288 .42686 L
.292 .42682 L
.296 .42677 L
.3 .42673 L
.304 .42669 L
.308 .42664 L
.312 .4266 L
.316 .42655 L
.32 .42651 L
.324 .42647 L
.328 .42642 L
.332 .42638 L
.336 .42634 L
.34 .4263 L
.344 .42625 L
.348 .42621 L
.352 .42617 L
.356 .42613 L
.36 .42609 L
.364 .42605 L
.368 .42602 L
.372 .42599 L
.376 .42596 L
.38 .42594 L
.384 .42593 L
.388 .42593 L
.392 .42594 L
.396 .42597 L
.4 .42603 L
Mistroke
.404 .42611 L
.408 .42623 L
.412 .4264 L
.416 .42662 L
.42 .42692 L
.424 .4273 L
.428 .42777 L
.432 .42836 L
.436 .42908 L
.44 .42996 L
.444 .431 L
.448 .43223 L
.452 .43366 L
.456 .4353 L
.46 .43716 L
.464 .43923 L
.468 .44152 L
.472 .44401 L
.476 .44669 L
.48 .44951 L
.484 .45245 L
.488 .45546 L
.492 .45849 L
.496 .46151 L
.5 .46446 L
.504 .46731 L
.508 .47003 L
.512 .47259 L
.516 .475 L
.52 .47726 L
.524 .47941 L
.528 .48148 L
.532 .48351 L
.536 .48555 L
.54 .48766 L
.544 .48985 L
.548 .49217 L
.552 .49459 L
.556 .49712 L
.56 .49972 L
.564 .50234 L
.568 .50491 L
.572 .5074 L
.576 .50973 L
.58 .5119 L
.584 .51388 L
.588 .51567 L
.592 .51729 L
.596 .51877 L
.6 .52013 L
Mistroke
.604 .5214 L
.608 .52257 L
.612 .52364 L
.616 .52456 L
.62 .52528 L
.624 .52578 L
.628 .526 L
.632 .52594 L
.636 .5256 L
.64 .52502 L
.644 .52428 L
.648 .52348 L
.652 .5227 L
.656 .52203 L
.66 .52151 L
.664 .52118 L
.668 .52103 L
.672 .52105 L
.676 .5212 L
.68 .52141 L
.684 .52164 L
.688 .52187 L
.692 .5221 L
.696 .52231 L
.7 .52249 L
.704 .5226 L
.708 .52261 L
.712 .52251 L
.716 .52232 L
.72 .52204 L
.724 .52172 L
.728 .52137 L
.732 .52107 L
.736 .52089 L
.74 .52087 L
.744 .52103 L
.748 .52129 L
.752 .52158 L
.756 .52177 L
.76 .52184 L
.764 .52176 L
.768 .52157 L
.772 .52131 L
.776 .52102 L
.78 .52077 L
.784 .52062 L
.788 .5206 L
.792 .52071 L
.796 .52089 L
.8 .52104 L
Mistroke
.804 .5211 L
.808 .52104 L
.812 .5209 L
.816 .52074 L
.82 .52061 L
.824 .52051 L
.828 .52043 L
.832 .52036 L
.836 .52032 L
.84 .52032 L
.844 .52037 L
.848 .52043 L
.852 .52046 L
.856 .52042 L
.86 .52029 L
.864 .52012 L
.868 .51997 L
.872 .51989 L
.876 .51988 L
.88 .51993 L
.884 .51997 L
.888 .51998 L
.892 .51995 L
.896 .51987 L
.9 .51977 L
.904 .51967 L
.908 .51958 L
.912 .51953 L
.916 .51949 L
.92 .5195 L
.924 .5195 L
.928 .51951 L
.932 .51948 L
.936 .51941 L
.94 .51931 L
.944 .51922 L
.948 .51912 L
.952 .51909 L
.956 .51907 L
.96 .51909 L
.964 .5191 L
.968 .51909 L
.972 .51902 L
.976 .51894 L
.98 .51878 L
.984 .51871 L
.988 .51863 L
.992 .51866 L
.996 .5187 L
1 .51877 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol500000goo000000020004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0
029oo`03001oogoo03]oo`03001oo`0000Eoo`8000=oo`03001oogoo025oo`008Woo0P00?7oo00@0
07ooOol000Aoo`8000=oo`80009oo`8000Aoo`03001oo`0000800004Ool00000Ool200000goo0000
000<Ool0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00@007ooOol000=oo`05001oogooOol00003Ool300000goo001oo`02Ool01@00Oomo
ogoo00000goo00H007ooOomoo`00Ool20003Ool3000017oo001oogoo0P000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo000037oo000ROol2000XOol00`00Oomoo`0@Ool0
0`00Oomoo`0_Ool0029oo`03001oogoo02Qoo`03001oogoo00ioo`03001oogoo031oo`008Woo0P00
:Goo00<007ooOol03Goo0P00<Woo000ROol2000ZOol00`00Oomoo`0;Ool2000cOol000]oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo02Uoo`03001oogoo00Yoo`03001oogoo03=o
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000[Ool00`00Oomoo`09
Ool00`00Oomoo`0cOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
:goo00<007ooOol00goo0`000goo00<007ooOol0<goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo02Yoo`03001oogoo009oo`07001oogooOol007oo0000=Woo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8002aoo`05001oogooOol0
0003Ool2000gOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00;Goo00<007oo
0000?Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0/Ool3000mOol000]oo`80
00Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo
0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=o
o`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eo
o`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool0
0`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^
Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0
029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04
001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo
06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
00Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool0
0`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004
Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004
Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03
001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004
Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001o
ogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uo
o`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04
001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001o
ogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03
001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo
00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`80
00Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
oed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo
00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo
00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`0dOolV000<Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0bOol3000aOol000]oo`80
00Yoo`8000Aoo`80009oo`D0009oo`03001oogoo031oo`8003Aoo`00:7oo00<007ooOol0;Goo0`00
=Woo000XOol00`00Oomoo`0/Ool2000hOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`03001oogoo02Yoo`8003Yoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`0XOol2000lOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol097oo1@00?Goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oobP0045oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2
000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo
00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05
Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo
00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool2
0004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004
Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:
Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<0
07ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003
Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eo
o`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03
001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo
00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007oo
Ool000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=o
o`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00
Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04
001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Ao
o`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00
Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo
00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002
Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool0
01aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo000;Ool0
0`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`00
1goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;
Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol0
01Moo`03001oogoo009ooc0004Eoo`005goo00<007ooOol00Woo00<007ooOol0;7oo0`00@goo000G
Ool00`00Oomoo`02Ool00`00Oomoo`0^Ool20012Ool001Ioo`8000Aoo`80035oo`03001oogoo03mo
o`005goo00<007ooOol00Woo00<007ooOol0<Goo0P00?goo000LOol00`00Oomoo`0cOol2000mOol0
01aoo`8003Eoo`<003]oo`0077oo00<007ooOol0=Woo0P00>Woo000LOol2000iOol2000hOol001ao
o`03001oogoo03Uoo`@000Eoo`8000Aoo`@00003Ool0000001L000aoo`0077oo00<007ooOol0?7oo
1P000Woo1@000Woo0`0097oo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03
001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001o
ogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo1000
0goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001o
ogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(9686\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30129 m
.008 .30018 L
.012 .30031 L
.016 .30033 L
.02 .30037 L
.024 .30051 L
.028 .3005 L
.032 .30038 L
.036 .30036 L
.04 .30042 L
.044 .30043 L
.048 .30039 L
.052 .30037 L
.056 .30038 L
.06 .30038 L
.064 .30037 L
.068 .30036 L
.072 .30036 L
.076 .30035 L
.08 .30035 L
.084 .30034 L
.088 .30033 L
.092 .30033 L
.096 .30032 L
.1 .30032 L
.104 .30031 L
.108 .3003 L
.112 .3003 L
.116 .3003 L
.12 .30029 L
.124 .30028 L
.128 .30027 L
.132 .30027 L
.136 .30027 L
.14 .30026 L
.144 .30025 L
.148 .30025 L
.152 .30024 L
.156 .30024 L
.16 .30023 L
.164 .30022 L
.168 .30022 L
.172 .30021 L
.176 .3002 L
.18 .3002 L
.184 .3002 L
.188 .30019 L
.192 .30018 L
.196 .30017 L
.2 .30017 L
Mistroke
.204 .30017 L
.208 .30016 L
.212 .30015 L
.216 .30014 L
.22 .30015 L
.224 .30014 L
.228 .30012 L
.232 .30012 L
.236 .30012 L
.24 .30012 L
.244 .3001 L
.248 .30009 L
.252 .30009 L
.256 .3001 L
.26 .30009 L
.264 .30007 L
.268 .30006 L
.272 .30007 L
.276 .30007 L
.28 .30005 L
.284 .30003 L
.288 .30004 L
.292 .30005 L
.296 .30005 L
.3 .30002 L
.304 .30002 L
.308 .30004 L
.312 .30006 L
.316 .30005 L
.32 .30004 L
.324 .30008 L
.328 .30015 L
.332 .3002 L
.336 .30025 L
.34 .30034 L
.344 .30052 L
.348 .30075 L
.352 .30101 L
.356 .30134 L
.36 .30181 L
.364 .30248 L
.368 .30331 L
.372 .30432 L
.376 .3056 L
.38 .30726 L
.384 .30936 L
.388 .31189 L
.392 .3149 L
.396 .31851 L
.4 .32286 L
Mistroke
.404 .32797 L
.408 .33379 L
.412 .34034 L
.416 .34766 L
.42 .35578 L
.424 .36453 L
.428 .37368 L
.432 .38303 L
.436 .39241 L
.44 .40158 L
.444 .41014 L
.448 .41764 L
.452 .42373 L
.456 .4282 L
.46 .43086 L
.464 .43149 L
.468 .42995 L
.472 .42636 L
.476 .42109 L
.48 .41463 L
.484 .40749 L
.488 .4002 L
.492 .39341 L
.496 .38787 L
.5 .3842 L
.504 .38272 L
.508 .38342 L
.512 .38606 L
.516 .39028 L
.52 .39553 L
.524 .40098 L
.528 .4056 L
.532 .40846 L
.536 .40898 L
.54 .40698 L
.544 .40254 L
.548 .39598 L
.552 .38784 L
.556 .37898 L
.56 .37042 L
.564 .36306 L
.568 .35733 L
.572 .35307 L
.576 .34972 L
.58 .34662 L
.584 .34305 L
.588 .3382 L
.592 .33132 L
.596 .322 L
.6 .31058 L
Mistroke
.604 .29823 L
.608 .28656 L
.612 .27706 L
.616 .27071 L
.62 .26805 L
.624 .26932 L
.628 .27434 L
.632 .28224 L
.636 .29134 L
.64 .29972 L
.644 .306 L
.648 .30987 L
.652 .31185 L
.656 .31255 L
.66 .31226 L
.664 .31104 L
.668 .3092 L
.672 .30727 L
.676 .30557 L
.68 .30365 L
.684 .30065 L
.688 .29618 L
.692 .29115 L
.696 .28749 L
.7 .28696 L
.704 .28998 L
.708 .29548 L
.712 .30181 L
.716 .30766 L
.72 .3122 L
.724 .31458 L
.728 .31366 L
.732 .30879 L
.736 .30084 L
.74 .29261 L
.744 .28749 L
.748 .28748 L
.752 .292 L
.756 .29836 L
.76 .30381 L
.764 .307 L
.768 .30813 L
.772 .30784 L
.776 .30618 L
.78 .30291 L
.784 .29844 L
.788 .29443 L
.792 .29302 L
.796 .29507 L
.8 .29936 L
Mistroke
.804 .30322 L
.808 .30456 L
.812 .30341 L
.816 .30158 L
.82 .30097 L
.824 .30183 L
.828 .30261 L
.832 .30156 L
.836 .29859 L
.84 .29557 L
.844 .29499 L
.848 .29789 L
.852 .30272 L
.856 .30656 L
.86 .30699 L
.864 .3038 L
.868 .29922 L
.872 .29581 L
.876 .29529 L
.88 .29744 L
.884 .30043 L
.888 .30292 L
.892 .30383 L
.896 .30328 L
.9 .3021 L
.904 .30035 L
.908 .29888 L
.912 .29803 L
.916 .29788 L
.92 .29927 L
.924 .30112 L
.928 .30269 L
.932 .30347 L
.936 .30224 L
.94 .30044 L
.944 .29887 L
.948 .29791 L
.952 .29886 L
.956 .3001 L
.96 .30112 L
.964 .30218 L
.968 .30183 L
.972 .30156 L
.976 .30124 L
.98 .29988 L
.984 .2992 L
.988 .29832 L
.992 .29802 L
.996 .3 L
1 .30204 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .50603 m
.008 .51174 L
.012 .51365 L
.016 .51163 L
.02 .51105 L
.024 .51171 L
.028 .51194 L
.032 .51168 L
.036 .51163 L
.04 .51169 L
.044 .51173 L
.048 .51169 L
.052 .51169 L
.056 .51169 L
.06 .51171 L
.064 .51169 L
.068 .5117 L
.072 .51169 L
.076 .5117 L
.08 .51169 L
.084 .5117 L
.088 .51169 L
.092 .5117 L
.096 .51169 L
.1 .5117 L
.104 .51169 L
.108 .5117 L
.112 .51169 L
.116 .5117 L
.12 .51169 L
.124 .5117 L
.128 .51169 L
.132 .5117 L
.136 .51169 L
.14 .5117 L
.144 .51169 L
.148 .5117 L
.152 .51169 L
.156 .5117 L
.16 .51169 L
.164 .5117 L
.168 .51169 L
.172 .51169 L
.176 .51169 L
.18 .51169 L
.184 .51169 L
.188 .51169 L
.192 .51169 L
.196 .51169 L
.2 .51169 L
Mistroke
.204 .51169 L
.208 .51169 L
.212 .51169 L
.216 .51169 L
.22 .51169 L
.224 .51169 L
.228 .51169 L
.232 .51169 L
.236 .51169 L
.24 .51169 L
.244 .51169 L
.248 .51169 L
.252 .51169 L
.256 .51169 L
.26 .51169 L
.264 .51169 L
.268 .51169 L
.272 .51169 L
.276 .51169 L
.28 .51169 L
.284 .51169 L
.288 .51169 L
.292 .51169 L
.296 .51169 L
.3 .51169 L
.304 .51169 L
.308 .51169 L
.312 .51169 L
.316 .51169 L
.32 .51168 L
.324 .51168 L
.328 .51168 L
.332 .51168 L
.336 .51167 L
.34 .51166 L
.344 .51165 L
.348 .51164 L
.352 .51162 L
.356 .5116 L
.36 .51157 L
.364 .51152 L
.368 .51147 L
.372 .51139 L
.376 .51129 L
.38 .51117 L
.384 .51101 L
.388 .51081 L
.392 .51055 L
.396 .51023 L
.4 .50983 L
Mistroke
.404 .50935 L
.408 .50877 L
.412 .50806 L
.416 .50723 L
.42 .50626 L
.424 .50513 L
.428 .50383 L
.432 .50236 L
.436 .50072 L
.44 .4989 L
.444 .49692 L
.448 .49479 L
.452 .49253 L
.456 .49017 L
.46 .48775 L
.464 .48528 L
.468 .48283 L
.472 .48041 L
.476 .47806 L
.48 .47582 L
.484 .47369 L
.488 .47168 L
.492 .46979 L
.496 .46801 L
.5 .4663 L
.504 .46464 L
.508 .46298 L
.512 .46129 L
.516 .45954 L
.52 .4577 L
.524 .45577 L
.528 .45375 L
.532 .45167 L
.536 .44956 L
.54 .44746 L
.544 .44541 L
.548 .44346 L
.552 .44164 L
.556 .43998 L
.56 .43847 L
.564 .4371 L
.568 .43587 L
.572 .43473 L
.576 .43369 L
.58 .43272 L
.584 .43184 L
.588 .43106 L
.592 .4304 L
.596 .42992 L
.6 .42964 L
Mistroke
.604 .42958 L
.608 .42975 L
.612 .43012 L
.616 .43064 L
.62 .43124 L
.624 .43187 L
.628 .43244 L
.632 .4329 L
.636 .43321 L
.64 .43336 L
.644 .43336 L
.648 .43326 L
.652 .43309 L
.656 .43287 L
.66 .43264 L
.664 .43242 L
.668 .43222 L
.672 .43207 L
.676 .43196 L
.68 .4319 L
.684 .4319 L
.688 .43198 L
.692 .43215 L
.696 .43239 L
.7 .43265 L
.704 .43288 L
.708 .43303 L
.712 .43307 L
.716 .43301 L
.72 .43285 L
.724 .43263 L
.728 .4324 L
.732 .43223 L
.736 .43217 L
.74 .43225 L
.744 .43244 L
.748 .43268 L
.752 .43288 L
.756 .433 L
.76 .43303 L
.764 .43297 L
.768 .43286 L
.772 .43274 L
.776 .43263 L
.78 .43256 L
.784 .43257 L
.788 .43265 L
.792 .43278 L
.796 .43291 L
.8 .433 L
Mistroke
.804 .43301 L
.808 .43298 L
.812 .43294 L
.816 .4329 L
.82 .43288 L
.824 .43286 L
.828 .43285 L
.832 .43286 L
.836 .43289 L
.84 .43298 L
.844 .43307 L
.848 .43315 L
.852 .43316 L
.856 .4331 L
.86 .43301 L
.864 .43295 L
.868 .43294 L
.872 .43301 L
.876 .43311 L
.88 .43319 L
.884 .43323 L
.888 .43323 L
.892 .43319 L
.896 .43315 L
.9 .43312 L
.904 .43313 L
.908 .43317 L
.912 .43321 L
.916 .43326 L
.92 .43331 L
.924 .43332 L
.928 .43332 L
.932 .43329 L
.936 .43328 L
.94 .43327 L
.944 .43329 L
.948 .43332 L
.952 .43338 L
.956 .43341 L
.96 .43345 L
.964 .43343 L
.968 .43342 L
.972 .4334 L
.976 .43339 L
.98 .43339 L
.984 .43345 L
.988 .43348 L
.992 .43357 L
.996 .43358 L
1 .43358 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43182 L
.012 .43005 L
.016 .42928 L
.02 .42964 L
.024 .42993 L
.028 .42975 L
.032 .42962 L
.036 .42957 L
.04 .42959 L
.044 .42953 L
.048 .42949 L
.052 .42942 L
.056 .4294 L
.06 .42934 L
.064 .42931 L
.068 .42925 L
.072 .42922 L
.076 .42917 L
.08 .42914 L
.084 .42908 L
.088 .42905 L
.092 .429 L
.096 .42896 L
.1 .42891 L
.104 .42887 L
.108 .42882 L
.112 .42878 L
.116 .42874 L
.12 .4287 L
.124 .42865 L
.128 .42861 L
.132 .42856 L
.136 .42852 L
.14 .42847 L
.144 .42843 L
.148 .42839 L
.152 .42835 L
.156 .4283 L
.16 .42826 L
.164 .42821 L
.168 .42817 L
.172 .42813 L
.176 .42808 L
.18 .42804 L
.184 .428 L
.188 .42795 L
.192 .42791 L
.196 .42787 L
.2 .42782 L
Mistroke
.204 .42778 L
.208 .42773 L
.212 .42769 L
.216 .42765 L
.22 .4276 L
.224 .42756 L
.228 .42752 L
.232 .42747 L
.236 .42743 L
.24 .42739 L
.244 .42734 L
.248 .4273 L
.252 .42725 L
.256 .42721 L
.26 .42717 L
.264 .42712 L
.268 .42708 L
.272 .42704 L
.276 .42699 L
.28 .42695 L
.284 .42691 L
.288 .42686 L
.292 .42682 L
.296 .42678 L
.3 .42673 L
.304 .42669 L
.308 .42665 L
.312 .4266 L
.316 .42656 L
.32 .42652 L
.324 .42648 L
.328 .42644 L
.332 .4264 L
.336 .42636 L
.34 .42632 L
.344 .42629 L
.348 .42626 L
.352 .42624 L
.356 .42623 L
.36 .42623 L
.364 .42623 L
.368 .42626 L
.372 .42631 L
.376 .42639 L
.38 .4265 L
.384 .42666 L
.388 .42687 L
.392 .42714 L
.396 .4275 L
.4 .42794 L
Mistroke
.404 .4285 L
.408 .42919 L
.412 .43002 L
.416 .43101 L
.42 .43218 L
.424 .43355 L
.428 .43512 L
.432 .43691 L
.436 .43892 L
.44 .44114 L
.444 .44356 L
.448 .44618 L
.452 .44895 L
.456 .45185 L
.46 .45483 L
.464 .45786 L
.468 .46089 L
.472 .46386 L
.476 .46675 L
.48 .46951 L
.484 .47213 L
.488 .47459 L
.492 .47691 L
.496 .4791 L
.5 .48119 L
.504 .48323 L
.508 .48526 L
.512 .48733 L
.516 .48948 L
.52 .49174 L
.524 .49411 L
.528 .49659 L
.532 .49915 L
.536 .50176 L
.54 .50435 L
.544 .50687 L
.548 .50926 L
.552 .5115 L
.556 .51354 L
.56 .5154 L
.564 .51708 L
.568 .51859 L
.572 .51997 L
.576 .52124 L
.58 .52242 L
.584 .5235 L
.588 .52445 L
.592 .52523 L
.596 .5258 L
.6 .52612 L
Mistroke
.604 .52617 L
.608 .52594 L
.612 .52546 L
.616 .52478 L
.62 .52399 L
.624 .52318 L
.628 .52245 L
.632 .52186 L
.636 .52144 L
.64 .52122 L
.644 .52118 L
.648 .52128 L
.652 .52148 L
.656 .52173 L
.66 .52198 L
.664 .52222 L
.668 .52243 L
.672 .52261 L
.676 .52273 L
.68 .52278 L
.684 .52273 L
.688 .52258 L
.692 .52235 L
.696 .52205 L
.7 .52172 L
.704 .5214 L
.708 .52116 L
.712 .52105 L
.716 .52111 L
.72 .52131 L
.724 .52158 L
.728 .52183 L
.732 .52199 L
.736 .522 L
.74 .52188 L
.744 .52166 L
.748 .52136 L
.752 .52107 L
.756 .52085 L
.76 .52076 L
.764 .52081 L
.768 .52096 L
.772 .52113 L
.776 .52124 L
.78 .52125 L
.784 .52116 L
.788 .52103 L
.792 .52088 L
.796 .52075 L
.8 .52063 L
Mistroke
.804 .52053 L
.808 .52048 L
.812 .52049 L
.816 .52054 L
.82 .52061 L
.824 .52064 L
.828 .5206 L
.832 .5205 L
.836 .52036 L
.84 .52025 L
.844 .52016 L
.848 .52011 L
.852 .52008 L
.856 .52007 L
.86 .52007 L
.864 .52009 L
.868 .52011 L
.872 .52008 L
.876 .51999 L
.88 .51985 L
.884 .51969 L
.888 .5196 L
.892 .51959 L
.896 .51966 L
.9 .51974 L
.904 .51977 L
.908 .51969 L
.912 .51953 L
.916 .51936 L
.92 .51925 L
.924 .51922 L
.928 .51929 L
.932 .51936 L
.936 .51938 L
.94 .51931 L
.944 .51917 L
.948 .51901 L
.952 .51893 L
.956 .51889 L
.96 .51896 L
.964 .519 L
.968 .51901 L
.972 .51892 L
.976 .51879 L
.98 .51863 L
.984 .51858 L
.988 .51855 L
.992 .51865 L
.996 .51867 L
1 .51867 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol60002Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo03Qoo`04001oogoo0005Ool00`00Oomoo`02Ool00`00Oomoo`0SOol0029oo`8003Uoo`04
001oogoo0004Ool30002Ool30002Ool20003Ool200000goo00000002Ool01000Oomoo`000goo0P00
3Goo000ROomS000<Ool0029oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`04001oogoo0003Ool01@00Oomoogoo00000Woo0P000goo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool00`00Oomoo`050003Ool20002Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool00`00Oomoo`0:Ool0029oo`8002Eoo`80015oo`03001oogoo
039oo`008Woo00<007ooOol09Goo00<007ooOol03Woo0P00=7oo000ROol2000VOol2000>Ool2000e
Ool0029oo`8002Moo`03001oogoo00]oo`8003Ioo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo00<007ooOol09Woo00<007ooOol02goo00<007ooOol0=Goo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8002Qoo`03001oogoo00Uoo`03001oogoo03Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000XOol00`00Oomoo`03Ool30003
Ool00`00Oomoo`0fOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0:7oo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo03Ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000YOol01@00Oomoogoo000017oo0P00>Goo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8002Yoo`04001oogoo000oOol000]oo`80
00Yoo`8000Aoo`03001oogoo009oo`03001oogoo02Uoo`<0041oo`002goo0P0017oo00<007ooOol0
0goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qo
o`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo
000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo
0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000R
Ool00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo
00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`80
00Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=o
o`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D0
07ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomo
o`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002
Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P00
2Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007oo
Ool017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007oo
Ool000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=o
o`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<0
07oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007oo
Ool000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool0
0006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool2
0004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@00
0goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol0
0`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool0
0`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool2
0004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04
001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D0
07ooOol007oo00@000=oo`03001oogoo039oobP000aoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo02moo`<003Aoo`002goo0P002Woo0P0017oo0P00
0Woo1@000Woo00<007ooOol0;Goo0`00=Woo000XOol00`00Oomoo`0[Ool3000hOol002Qoo`03001o
ogoo02Uoo`8003]oo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol09goo
0`00?7oo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo02Eo
o`<003ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0Q
Ool50010Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo9@00A7oo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03
001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomo
o`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo0080
06Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogoo
Ool5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009o
o`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;
Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001ao
o`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eo
o`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00
009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001o
ogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000L
Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Ao
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo1000
0goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`80
00Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Ao
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo0000
1Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P00
1Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Io
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=o
o`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009o
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol3
0003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol0
0Woo;@00B7oo000GOol00`00Oomoo`02Ool00`00Oomoo`0YOol30016Ool001Moo`03001oogoo009o
o`03001oogoo02aoo`03001oogoo04=oo`005Woo0P0017oo0P00;Woo0P00@goo000GOol00`00Oomo
o`02Ool00`00Oomoo`0^Ool20012Ool001aoo`03001oogoo031oo`80041oo`0077oo0P00<Woo0`00
?Woo000LOol00`00Oomoo`0cOol3000lOol001aoo`8003Ioo`8003]oo`0077oo00<007ooOol0=goo
0`001Goo0P001Goo0`000Woo6`0037oo000LOol00`00Oomoo`0iOol700000goo00000004000017oo
000000009goo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol0
00]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007oo
Ool0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0
009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(9853\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .2985 m
.008 .29958 L
.012 .30118 L
.016 .30138 L
.02 .30021 L
.024 .29994 L
.028 .30056 L
.032 .3007 L
.036 .30041 L
.04 .30033 L
.044 .30045 L
.048 .30047 L
.052 .30042 L
.056 .3004 L
.06 .30041 L
.064 .30041 L
.068 .3004 L
.072 .30039 L
.076 .30039 L
.08 .30038 L
.084 .30038 L
.088 .30037 L
.092 .30036 L
.096 .30036 L
.1 .30035 L
.104 .30035 L
.108 .30034 L
.112 .30033 L
.116 .30033 L
.12 .30032 L
.124 .30032 L
.128 .30031 L
.132 .3003 L
.136 .3003 L
.14 .30029 L
.144 .30028 L
.148 .30028 L
.152 .30028 L
.156 .30027 L
.16 .30026 L
.164 .30026 L
.168 .30025 L
.172 .30025 L
.176 .30024 L
.18 .30023 L
.184 .30023 L
.188 .30023 L
.192 .30022 L
.196 .30021 L
.2 .3002 L
Mistroke
.204 .3002 L
.208 .30019 L
.212 .30018 L
.216 .30018 L
.22 .30018 L
.224 .30017 L
.228 .30016 L
.232 .30015 L
.236 .30015 L
.24 .30015 L
.244 .30014 L
.248 .30013 L
.252 .30013 L
.256 .30013 L
.26 .30013 L
.264 .30011 L
.268 .3001 L
.272 .30011 L
.276 .30012 L
.28 .30011 L
.284 .3001 L
.288 .30012 L
.292 .30015 L
.296 .30017 L
.3 .30019 L
.304 .30023 L
.308 .30033 L
.312 .30044 L
.316 .30058 L
.32 .30075 L
.324 .30101 L
.328 .30139 L
.332 .30185 L
.336 .30243 L
.34 .30319 L
.344 .3042 L
.348 .30549 L
.352 .30707 L
.356 .30901 L
.36 .31142 L
.364 .31439 L
.368 .31794 L
.372 .32212 L
.376 .32698 L
.38 .33265 L
.384 .33914 L
.388 .34638 L
.392 .35431 L
.396 .36288 L
.4 .37202 L
Mistroke
.404 .38153 L
.408 .39108 L
.412 .40039 L
.416 .40917 L
.42 .41714 L
.424 .42391 L
.428 .42908 L
.432 .43235 L
.436 .4336 L
.44 .43283 L
.444 .43004 L
.448 .42536 L
.452 .41916 L
.456 .41203 L
.46 .40464 L
.464 .39762 L
.468 .39153 L
.472 .38696 L
.476 .38441 L
.48 .38418 L
.484 .38615 L
.488 .3899 L
.492 .3948 L
.496 .40018 L
.5 .40522 L
.504 .40902 L
.508 .41074 L
.512 .40985 L
.516 .40629 L
.52 .40039 L
.524 .39273 L
.528 .38399 L
.532 .37502 L
.536 .3667 L
.54 .35976 L
.544 .3545 L
.548 .35063 L
.552 .34745 L
.556 .34409 L
.56 .33974 L
.564 .33373 L
.568 .32562 L
.572 .31535 L
.576 .3035 L
.58 .29133 L
.584 .28045 L
.588 .27235 L
.592 .26796 L
.596 .26763 L
.6 .27116 L
Mistroke
.604 .27789 L
.608 .28667 L
.612 .29591 L
.616 .30392 L
.62 .30955 L
.624 .31256 L
.628 .31347 L
.632 .31305 L
.636 .31186 L
.64 .31015 L
.644 .30812 L
.648 .306 L
.652 .30388 L
.656 .30141 L
.66 .29812 L
.664 .29398 L
.668 .28992 L
.672 .28754 L
.676 .28818 L
.68 .29203 L
.684 .29804 L
.688 .30458 L
.692 .31021 L
.696 .31388 L
.7 .31468 L
.704 .3119 L
.708 .30569 L
.712 .29759 L
.716 .29044 L
.72 .28703 L
.724 .28847 L
.728 .29364 L
.732 .3 L
.736 .30527 L
.74 .30841 L
.744 .30935 L
.748 .30829 L
.752 .30526 L
.756 .30069 L
.76 .29597 L
.764 .29314 L
.768 .29366 L
.772 .29706 L
.776 .3012 L
.78 .30373 L
.784 .30384 L
.788 .30266 L
.792 .30193 L
.796 .30231 L
.8 .30279 L
Mistroke
.804 .30188 L
.808 .29922 L
.812 .29631 L
.816 .29535 L
.82 .29736 L
.824 .30128 L
.828 .30463 L
.832 .30553 L
.836 .30389 L
.84 .30116 L
.844 .29912 L
.848 .29827 L
.852 .29819 L
.856 .29833 L
.86 .29865 L
.864 .29998 L
.868 .30236 L
.872 .30469 L
.876 .30537 L
.88 .30301 L
.884 .29869 L
.888 .29499 L
.892 .29429 L
.896 .29772 L
.9 .30298 L
.904 .30679 L
.908 .30691 L
.912 .30283 L
.916 .29764 L
.92 .29452 L
.924 .295 L
.928 .29913 L
.932 .30362 L
.936 .30585 L
.94 .30507 L
.944 .30127 L
.948 .29756 L
.952 .29598 L
.956 .29678 L
.96 .30018 L
.964 .30339 L
.968 .30461 L
.972 .30388 L
.976 .30065 L
.98 .29752 L
.984 .2964 L
.988 .29721 L
.992 .30061 L
.996 .30401 L
1 .30511 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .50824 m
.008 .51133 L
.012 .51249 L
.016 .51159 L
.02 .51118 L
.024 .51139 L
.028 .51158 L
.032 .5115 L
.036 .51146 L
.04 .51145 L
.044 .51149 L
.048 .51147 L
.052 .51148 L
.056 .51147 L
.06 .51148 L
.064 .51147 L
.068 .51148 L
.072 .51147 L
.076 .51148 L
.08 .51147 L
.084 .51148 L
.088 .51147 L
.092 .51148 L
.096 .51147 L
.1 .51148 L
.104 .51147 L
.108 .51148 L
.112 .51147 L
.116 .51148 L
.12 .51147 L
.124 .51148 L
.128 .51147 L
.132 .51148 L
.136 .51147 L
.14 .51148 L
.144 .51147 L
.148 .51147 L
.152 .51147 L
.156 .51147 L
.16 .51147 L
.164 .51147 L
.168 .51147 L
.172 .51147 L
.176 .51147 L
.18 .51147 L
.184 .51147 L
.188 .51147 L
.192 .51147 L
.196 .51147 L
.2 .51147 L
Mistroke
.204 .51147 L
.208 .51147 L
.212 .51147 L
.216 .51147 L
.22 .51147 L
.224 .51147 L
.228 .51147 L
.232 .51147 L
.236 .51147 L
.24 .51147 L
.244 .51147 L
.248 .51147 L
.252 .51147 L
.256 .51147 L
.26 .51147 L
.264 .51147 L
.268 .51147 L
.272 .51147 L
.276 .51147 L
.28 .51147 L
.284 .51147 L
.288 .51147 L
.292 .51147 L
.296 .51146 L
.3 .51146 L
.304 .51146 L
.308 .51145 L
.312 .51145 L
.316 .51144 L
.32 .51142 L
.324 .51141 L
.328 .51138 L
.332 .51135 L
.336 .51131 L
.34 .51126 L
.344 .51119 L
.348 .5111 L
.352 .51098 L
.356 .51083 L
.36 .51064 L
.364 .51039 L
.368 .51009 L
.372 .50972 L
.376 .50926 L
.38 .5087 L
.384 .50804 L
.388 .50724 L
.392 .50631 L
.396 .50523 L
.4 .50398 L
Mistroke
.404 .50257 L
.408 .50098 L
.412 .49922 L
.416 .49729 L
.42 .49521 L
.424 .493 L
.428 .49067 L
.432 .48827 L
.436 .48582 L
.44 .48336 L
.444 .48093 L
.448 .47855 L
.452 .47627 L
.456 .4741 L
.46 .47205 L
.464 .47012 L
.468 .4683 L
.472 .46656 L
.476 .46489 L
.48 .46324 L
.484 .46157 L
.488 .45985 L
.492 .45805 L
.496 .45616 L
.5 .45419 L
.504 .45214 L
.508 .45004 L
.512 .44794 L
.516 .44587 L
.52 .44389 L
.524 .44202 L
.528 .4403 L
.532 .43873 L
.536 .43731 L
.54 .43604 L
.544 .43489 L
.548 .43383 L
.552 .43286 L
.556 .43197 L
.56 .43117 L
.564 .43049 L
.568 .42995 L
.572 .4296 L
.576 .42946 L
.58 .42953 L
.584 .42982 L
.588 .43029 L
.592 .43087 L
.596 .43149 L
.6 .4321 L
Mistroke
.604 .43261 L
.608 .43299 L
.612 .43322 L
.616 .43328 L
.62 .43321 L
.624 .43305 L
.628 .43283 L
.632 .4326 L
.636 .43237 L
.64 .43216 L
.644 .43199 L
.648 .43187 L
.652 .43179 L
.656 .43178 L
.66 .43183 L
.664 .43195 L
.668 .43215 L
.672 .43239 L
.676 .43263 L
.68 .43283 L
.684 .43293 L
.688 .43293 L
.692 .43282 L
.696 .43262 L
.7 .4324 L
.704 .43219 L
.708 .43207 L
.712 .43207 L
.716 .43219 L
.72 .4324 L
.724 .43263 L
.728 .43282 L
.732 .43291 L
.736 .4329 L
.74 .43282 L
.744 .43269 L
.748 .43256 L
.752 .43246 L
.756 .43242 L
.76 .43247 L
.764 .43258 L
.768 .43271 L
.772 .43282 L
.776 .43288 L
.78 .43288 L
.784 .43285 L
.788 .43281 L
.792 .43277 L
.796 .43274 L
.8 .43272 L
Mistroke
.804 .43271 L
.808 .43274 L
.812 .43281 L
.816 .43291 L
.82 .43299 L
.824 .43302 L
.828 .43299 L
.832 .43293 L
.836 .43287 L
.84 .43285 L
.844 .43287 L
.848 .43292 L
.852 .43298 L
.856 .43304 L
.86 .43308 L
.864 .43311 L
.868 .4331 L
.872 .43307 L
.876 .43301 L
.88 .43298 L
.884 .43299 L
.888 .43306 L
.892 .43316 L
.896 .43324 L
.9 .43326 L
.904 .43322 L
.908 .43313 L
.912 .43308 L
.916 .43309 L
.92 .43317 L
.924 .43327 L
.928 .43335 L
.932 .43335 L
.936 .43331 L
.94 .43323 L
.944 .4332 L
.948 .43323 L
.952 .4333 L
.956 .43338 L
.96 .43344 L
.964 .43342 L
.968 .43339 L
.972 .43333 L
.976 .43332 L
.98 .43335 L
.984 .43344 L
.988 .4335 L
.992 .43355 L
.996 .43351 L
1 .43348 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .426 L
.012 .42995 L
.016 .4312 L
.02 .42971 L
.024 .42929 L
.028 .42971 L
.032 .42983 L
.036 .42959 L
.04 .42952 L
.044 .42952 L
.048 .42951 L
.052 .42943 L
.056 .42939 L
.06 .42934 L
.064 .42931 L
.068 .42926 L
.072 .42922 L
.076 .42917 L
.08 .42914 L
.084 .42908 L
.088 .42905 L
.092 .429 L
.096 .42896 L
.1 .42891 L
.104 .42887 L
.108 .42882 L
.112 .42878 L
.116 .42874 L
.12 .4287 L
.124 .42865 L
.128 .42861 L
.132 .42856 L
.136 .42852 L
.14 .42848 L
.144 .42843 L
.148 .42839 L
.152 .42835 L
.156 .4283 L
.16 .42826 L
.164 .42821 L
.168 .42817 L
.172 .42813 L
.176 .42809 L
.18 .42804 L
.184 .428 L
.188 .42795 L
.192 .42791 L
.196 .42787 L
.2 .42782 L
Mistroke
.204 .42778 L
.208 .42774 L
.212 .42769 L
.216 .42765 L
.22 .4276 L
.224 .42756 L
.228 .42752 L
.232 .42747 L
.236 .42743 L
.24 .42739 L
.244 .42734 L
.248 .4273 L
.252 .42726 L
.256 .42721 L
.26 .42717 L
.264 .42713 L
.268 .42708 L
.272 .42704 L
.276 .427 L
.28 .42695 L
.284 .42691 L
.288 .42687 L
.292 .42682 L
.296 .42678 L
.3 .42674 L
.304 .4267 L
.308 .42667 L
.312 .42663 L
.316 .4266 L
.32 .42657 L
.324 .42655 L
.328 .42653 L
.332 .42652 L
.336 .42653 L
.34 .42655 L
.344 .4266 L
.348 .42667 L
.352 .42677 L
.356 .42692 L
.36 .42711 L
.364 .42737 L
.368 .4277 L
.372 .42813 L
.376 .42865 L
.38 .4293 L
.384 .43009 L
.388 .43103 L
.392 .43215 L
.396 .43346 L
.4 .43497 L
Mistroke
.404 .43669 L
.408 .43862 L
.412 .44078 L
.416 .44313 L
.42 .44569 L
.424 .4484 L
.428 .45126 L
.432 .45422 L
.436 .45723 L
.44 .46026 L
.444 .46325 L
.448 .46617 L
.452 .46898 L
.456 .47165 L
.46 .47417 L
.464 .47654 L
.468 .47877 L
.472 .4809 L
.476 .48295 L
.48 .48498 L
.484 .48702 L
.488 .48913 L
.492 .49134 L
.496 .49365 L
.5 .49608 L
.504 .49861 L
.508 .50119 L
.512 .50378 L
.516 .50632 L
.52 .50877 L
.524 .51107 L
.528 .51318 L
.532 .51511 L
.536 .51684 L
.54 .5184 L
.544 .51981 L
.548 .5211 L
.552 .52228 L
.556 .52336 L
.56 .52433 L
.564 .52516 L
.568 .5258 L
.572 .52621 L
.576 .52636 L
.58 .52624 L
.584 .52585 L
.588 .52525 L
.592 .5245 L
.596 .52369 L
.6 .52291 L
Mistroke
.604 .52224 L
.608 .52174 L
.612 .52144 L
.616 .52132 L
.62 .52138 L
.624 .52155 L
.628 .5218 L
.632 .52207 L
.636 .52233 L
.64 .52255 L
.644 .52273 L
.648 .52286 L
.652 .52294 L
.656 .52293 L
.66 .52283 L
.664 .52263 L
.668 .52237 L
.672 .52205 L
.676 .52173 L
.68 .52146 L
.684 .52128 L
.688 .52125 L
.692 .52137 L
.696 .5216 L
.7 .52186 L
.704 .52208 L
.708 .52219 L
.712 .52215 L
.716 .52198 L
.72 .52171 L
.724 .52141 L
.728 .52114 L
.732 .52097 L
.736 .52093 L
.74 .52103 L
.744 .52119 L
.748 .52134 L
.752 .52142 L
.756 .52141 L
.76 .52131 L
.764 .52116 L
.768 .52101 L
.772 .52086 L
.776 .52074 L
.78 .52066 L
.784 .52065 L
.788 .5207 L
.792 .52076 L
.796 .5208 L
.8 .52078 L
Mistroke
.804 .52071 L
.808 .52061 L
.812 .52051 L
.816 .52042 L
.82 .52033 L
.824 .52026 L
.828 .52021 L
.832 .52021 L
.836 .52025 L
.84 .5203 L
.844 .52031 L
.848 .52024 L
.852 .5201 L
.856 .51993 L
.86 .5198 L
.864 .51977 L
.868 .51982 L
.872 .51989 L
.876 .51992 L
.88 .51988 L
.884 .51976 L
.888 .51963 L
.892 .51952 L
.896 .51948 L
.9 .51946 L
.904 .51948 L
.908 .51947 L
.912 .51945 L
.916 .51939 L
.92 .51932 L
.924 .51924 L
.928 .51918 L
.932 .51912 L
.936 .51909 L
.94 .51906 L
.944 .51905 L
.948 .51902 L
.952 .51898 L
.956 .51892 L
.96 .51886 L
.964 .51877 L
.968 .51873 L
.972 .51867 L
.976 .51866 L
.98 .51864 L
.984 .51863 L
.988 .51858 L
.992 .51855 L
.996 .51843 L
1 .51837 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oo`0000Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo03Ioo`03001oo`0000Ioo`04001oogooOol2000WOol0029oo`8003Moo`04001oogoo0003
Ool40002Ool20002Ool20003Ool20002Ool2000017oo000007oo0P0000=oo`0000000Woo00<007oo
Ool037oo000ROomS000<Ool0029oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`04001oogoo0003Ool01000Oomoogoo0P000Woo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool20002Ool01000Ool000000goo00<007oo00000P000Woo0P000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000037oo000ROol2000ROol2000AOol00`00
Oomoo`0eOol0029oo`03001oogoo029oo`80011oo`03001oogoo03Eoo`008Woo0P0097oo00<007oo
Ool03Goo00<007ooOol0=Woo000ROol2000TOol00`00Oomoo`0<Ool2000hOol000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`03001oogoo02Aoo`03001oogoo00Yoo`03001oogoo03Qoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000UOol00`00Oomoo`0:Ool0
0`00Oomoo`0hOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P009Woo
00<007ooOol00goo0`000goo00<007ooOol0>7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo02Eoo`03001oogoo009oo`800005Ool007ooOol0000kOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P009goo00D007ooOomoo`0000=o
o`8003aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2000WOol00`00Oomoo`02
0011Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo02Ioo`@0049oo`002goo0P00
17oo00<007ooOol00goo0P000Woo1@000Woo0P00:7oo0P00@goo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001o
ogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo
0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol0
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007oo
Ool006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo
06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P00
17oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<0
07ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001o
ogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`80
00Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Mo
o`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009o
o`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool01000
0goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007oo
Ool007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomo
o`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0
009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo
00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007oo
Ool02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo
00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P00
0goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool2
0008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P00
17oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomo
o`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool2
0004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo031oobX000aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo02eoo`<003Ioo`00
2goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0:goo0P00>Goo000XOol00`00Oomoo`0Y
Ool2000kOol002Qoo`03001oogoo02Ioo`<003eoo`004Goo0P0017oo00<007ooOol00goo0P000goo
0`000goo00<007ooOol09Goo0P00?goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo02=oo`80045oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`0OOol40013Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo8P00Agoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0
015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001o
ogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@0
06aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`80
00Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]o
o`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001c
Ool000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002
Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eo
o`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo
0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`00
0Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<0
07ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool0
1000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo
10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Ao
o`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol0
17oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007oo
Ool017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Ao
o`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<0
07ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Io
o`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT0
00aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol0
00]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001o
ogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001c
Ool000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo
079oo`005goo00<007ooOol00Woo:P00Bgoo000GOol00`00Oomoo`02Ool00`00Oomoo`0WOol20019
Ool001Moo`03001oogoo009oo`03001oogoo02Uoo`03001oogoo04Ioo`005Woo0P0017oo0P00:goo
0P00AWoo000GOol00`00Oomoo`02Ool00`00Oomoo`0/Ool00`00Oomoo`13Ool001aoo`03001oogoo
02eoo`8004=oo`0077oo0P00;goo0`00@Goo000LOol00`00Oomoo`0`Ool3000oOol001aoo`8003=o
o`8003ioo`0077oo00<007ooOol0=7oo0`001Goo0P001Goo0`000Woo7P0037oo000LOol00`00Oomo
o`0fOol700000goo0000000400000goo00000002000YOol000Yoo`<000Aoo`03001oogoo009oo`<0
00=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo
00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;
Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001o
ogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03
001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(10020\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29933 m
.008 .30062 L
.012 .30078 L
.016 .30079 L
.02 .30051 L
.024 .30032 L
.028 .30043 L
.032 .30057 L
.036 .30052 L
.04 .30044 L
.044 .30044 L
.048 .30047 L
.052 .30047 L
.056 .30044 L
.06 .30044 L
.064 .30044 L
.068 .30044 L
.072 .30042 L
.076 .30042 L
.08 .30041 L
.084 .30041 L
.088 .3004 L
.092 .3004 L
.096 .30039 L
.1 .30039 L
.104 .30038 L
.108 .30037 L
.112 .30037 L
.116 .30036 L
.12 .30036 L
.124 .30035 L
.128 .30034 L
.132 .30034 L
.136 .30033 L
.14 .30033 L
.144 .30032 L
.148 .30031 L
.152 .30031 L
.156 .3003 L
.16 .3003 L
.164 .30029 L
.168 .30029 L
.172 .30028 L
.176 .30027 L
.18 .30027 L
.184 .30026 L
.188 .30026 L
.192 .30025 L
.196 .30024 L
.2 .30024 L
Mistroke
.204 .30024 L
.208 .30023 L
.212 .30022 L
.216 .30021 L
.22 .30021 L
.224 .30021 L
.228 .3002 L
.232 .30019 L
.236 .30019 L
.24 .30019 L
.244 .30019 L
.248 .30018 L
.252 .30018 L
.256 .30019 L
.26 .3002 L
.264 .30021 L
.268 .30022 L
.272 .30027 L
.276 .30033 L
.28 .30039 L
.284 .30048 L
.288 .30061 L
.292 .30081 L
.296 .30107 L
.3 .30139 L
.304 .30182 L
.308 .3024 L
.312 .30316 L
.316 .30411 L
.32 .3053 L
.324 .30682 L
.328 .30873 L
.332 .31107 L
.336 .31389 L
.34 .31728 L
.344 .32134 L
.348 .32612 L
.352 .33164 L
.356 .33791 L
.36 .34497 L
.364 .35283 L
.368 .36137 L
.372 .37045 L
.376 .37988 L
.38 .38952 L
.384 .39909 L
.388 .40823 L
.392 .41656 L
.396 .42375 L
.4 .42953 L
Mistroke
.404 .43359 L
.408 .43564 L
.412 .43555 L
.416 .43335 L
.42 .42928 L
.424 .42362 L
.428 .41677 L
.432 .40928 L
.436 .40187 L
.44 .39527 L
.444 .39007 L
.448 .3867 L
.452 .38545 L
.456 .38643 L
.46 .38949 L
.464 .3941 L
.468 .39949 L
.472 .40476 L
.476 .40909 L
.48 .41176 L
.484 .41211 L
.488 .40976 L
.492 .40473 L
.496 .39752 L
.5 .38891 L
.504 .37978 L
.508 .37091 L
.512 .363 L
.516 .35657 L
.52 .35174 L
.524 .34813 L
.528 .3449 L
.532 .34108 L
.536 .33582 L
.54 .32864 L
.544 .31939 L
.548 .30836 L
.552 .29638 L
.556 .28476 L
.56 .27508 L
.564 .26872 L
.568 .26649 L
.572 .26845 L
.576 .27403 L
.58 .28218 L
.584 .29156 L
.588 .30062 L
.592 .30796 L
.596 .31265 L
.6 .31461 L
Mistroke
.604 .31442 L
.608 .313 L
.612 .31104 L
.616 .30891 L
.62 .3067 L
.624 .30441 L
.628 .30197 L
.632 .29919 L
.636 .29588 L
.64 .29227 L
.644 .28924 L
.648 .28808 L
.652 .2898 L
.656 .29441 L
.66 .30083 L
.664 .30736 L
.668 .3124 L
.672 .31479 L
.676 .31386 L
.68 .30952 L
.684 .30254 L
.688 .29478 L
.692 .28886 L
.696 .28693 L
.7 .28955 L
.704 .29539 L
.708 .30199 L
.712 .30721 L
.716 .30993 L
.72 .30999 L
.724 .30768 L
.728 .3035 L
.732 .29851 L
.736 .29441 L
.74 .2929 L
.744 .29461 L
.748 .2984 L
.752 .3021 L
.756 .30399 L
.76 .30393 L
.764 .30311 L
.768 .30267 L
.772 .30261 L
.776 .30199 L
.78 .30013 L
.784 .29766 L
.788 .29619 L
.792 .29694 L
.796 .29959 L
.8 .30252 L
Mistroke
.804 .30407 L
.808 .30386 L
.812 .30269 L
.816 .30152 L
.82 .30058 L
.824 .29932 L
.828 .29765 L
.832 .29653 L
.836 .29733 L
.84 .30063 L
.844 .30486 L
.848 .30718 L
.852 .30567 L
.856 .30067 L
.86 .29539 L
.864 .29336 L
.868 .29584 L
.872 .30134 L
.876 .30599 L
.88 .30688 L
.884 .30395 L
.888 .29923 L
.892 .29614 L
.896 .2963 L
.9 .29882 L
.904 .302 L
.908 .30351 L
.912 .30291 L
.916 .3014 L
.92 .29973 L
.924 .29921 L
.928 .29966 L
.932 .30011 L
.936 .30075 L
.94 .3009 L
.944 .30076 L
.948 .30101 L
.952 .30084 L
.956 .30075 L
.96 .30076 L
.964 .30026 L
.968 .30021 L
.972 .30015 L
.976 .29996 L
.98 .30044 L
.984 .30077 L
.988 .30124 L
.992 .30178 L
.996 .30128 L
1 .30043 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51635 m
.008 .51115 L
.012 .50952 L
.016 .51132 L
.02 .51187 L
.024 .5112 L
.028 .51106 L
.032 .51126 L
.036 .51134 L
.04 .51124 L
.044 .51124 L
.048 .51125 L
.052 .51127 L
.056 .51125 L
.06 .51126 L
.064 .51125 L
.068 .51126 L
.072 .51125 L
.076 .51126 L
.08 .51125 L
.084 .51126 L
.088 .51125 L
.092 .51126 L
.096 .51125 L
.1 .51126 L
.104 .51125 L
.108 .51126 L
.112 .51125 L
.116 .51126 L
.12 .51125 L
.124 .51126 L
.128 .51125 L
.132 .51126 L
.136 .51125 L
.14 .51125 L
.144 .51125 L
.148 .51125 L
.152 .51125 L
.156 .51125 L
.16 .51125 L
.164 .51125 L
.168 .51125 L
.172 .51125 L
.176 .51125 L
.18 .51125 L
.184 .51125 L
.188 .51125 L
.192 .51125 L
.196 .51125 L
.2 .51125 L
Mistroke
.204 .51125 L
.208 .51125 L
.212 .51125 L
.216 .51125 L
.22 .51125 L
.224 .51125 L
.228 .51125 L
.232 .51125 L
.236 .51125 L
.24 .51125 L
.244 .51125 L
.248 .51125 L
.252 .51125 L
.256 .51125 L
.26 .51125 L
.264 .51125 L
.268 .51124 L
.272 .51124 L
.276 .51124 L
.28 .51123 L
.284 .51123 L
.288 .51122 L
.292 .51121 L
.296 .51119 L
.3 .51117 L
.304 .51114 L
.308 .5111 L
.312 .51105 L
.316 .51099 L
.32 .5109 L
.324 .51079 L
.328 .51065 L
.332 .51046 L
.336 .51023 L
.34 .50995 L
.344 .50959 L
.348 .50916 L
.352 .50863 L
.356 .508 L
.36 .50724 L
.364 .50635 L
.368 .50531 L
.372 .50412 L
.376 .50276 L
.38 .50122 L
.384 .49952 L
.388 .49765 L
.392 .49562 L
.396 .49345 L
.4 .49116 L
Mistroke
.404 .48878 L
.408 .48635 L
.412 .48389 L
.416 .48145 L
.42 .47905 L
.424 .47674 L
.428 .47452 L
.432 .47243 L
.436 .47046 L
.44 .4686 L
.444 .46683 L
.448 .46514 L
.452 .46349 L
.456 .46183 L
.46 .46014 L
.464 .45838 L
.468 .45654 L
.472 .4546 L
.476 .45259 L
.48 .45052 L
.484 .44842 L
.488 .44634 L
.492 .44433 L
.496 .44241 L
.5 .44064 L
.504 .43901 L
.508 .43754 L
.512 .43623 L
.516 .43504 L
.52 .43397 L
.524 .43299 L
.528 .43209 L
.532 .43128 L
.536 .43058 L
.54 .43 L
.544 .42959 L
.548 .42937 L
.552 .42936 L
.556 .42956 L
.56 .42996 L
.564 .43049 L
.568 .43111 L
.572 .43173 L
.576 .4323 L
.58 .43274 L
.584 .43304 L
.588 .43317 L
.592 .43315 L
.596 .43302 L
.6 .43281 L
Mistroke
.604 .43256 L
.608 .43232 L
.612 .4321 L
.616 .43191 L
.62 .43177 L
.624 .43169 L
.628 .43166 L
.632 .43169 L
.636 .43178 L
.64 .43194 L
.644 .43215 L
.648 .43238 L
.652 .4326 L
.656 .43275 L
.66 .43281 L
.664 .43276 L
.668 .43261 L
.672 .4324 L
.676 .43218 L
.68 .43201 L
.684 .43193 L
.688 .43198 L
.692 .43214 L
.696 .43237 L
.7 .43259 L
.704 .43274 L
.708 .4328 L
.712 .43277 L
.716 .43266 L
.72 .43251 L
.724 .43238 L
.728 .4323 L
.732 .4323 L
.736 .43238 L
.74 .4325 L
.744 .43263 L
.748 .43273 L
.752 .43277 L
.756 .43276 L
.76 .43272 L
.764 .43267 L
.768 .43263 L
.772 .4326 L
.776 .43258 L
.78 .4326 L
.784 .43265 L
.788 .43273 L
.792 .43282 L
.796 .43287 L
.8 .43287 L
Mistroke
.804 .43284 L
.808 .4328 L
.812 .43276 L
.816 .43275 L
.82 .43276 L
.824 .43279 L
.828 .43285 L
.832 .43292 L
.836 .43298 L
.84 .43301 L
.844 .43299 L
.848 .43292 L
.852 .43285 L
.856 .43284 L
.86 .43289 L
.864 .43299 L
.868 .43309 L
.872 .43313 L
.876 .4331 L
.88 .43304 L
.884 .43298 L
.888 .43298 L
.892 .43302 L
.896 .4331 L
.9 .43316 L
.904 .43319 L
.908 .43317 L
.912 .43315 L
.916 .43313 L
.92 .43314 L
.924 .43317 L
.928 .4332 L
.932 .43322 L
.936 .43325 L
.94 .43325 L
.944 .43327 L
.948 .43327 L
.952 .43329 L
.956 .43329 L
.96 .4333 L
.964 .4333 L
.968 .43333 L
.972 .43334 L
.976 .43339 L
.98 .43339 L
.984 .43342 L
.988 .4334 L
.992 .43341 L
.996 .43339 L
1 .43343 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42734 L
.012 .42968 L
.016 .43066 L
.02 .42989 L
.024 .4295 L
.028 .42962 L
.032 .42975 L
.036 .42963 L
.04 .42955 L
.044 .4295 L
.048 .4295 L
.052 .42943 L
.056 .4294 L
.06 .42934 L
.064 .42931 L
.068 .42926 L
.072 .42922 L
.076 .42917 L
.08 .42914 L
.084 .42908 L
.088 .42905 L
.092 .429 L
.096 .42896 L
.1 .42891 L
.104 .42887 L
.108 .42882 L
.112 .42879 L
.116 .42874 L
.12 .4287 L
.124 .42865 L
.128 .42861 L
.132 .42856 L
.136 .42852 L
.14 .42848 L
.144 .42844 L
.148 .42839 L
.152 .42835 L
.156 .4283 L
.16 .42826 L
.164 .42822 L
.168 .42817 L
.172 .42813 L
.176 .42809 L
.18 .42804 L
.184 .428 L
.188 .42795 L
.192 .42791 L
.196 .42787 L
.2 .42782 L
Mistroke
.204 .42778 L
.208 .42774 L
.212 .42769 L
.216 .42765 L
.22 .42761 L
.224 .42756 L
.228 .42752 L
.232 .42748 L
.236 .42743 L
.24 .42739 L
.244 .42735 L
.248 .4273 L
.252 .42726 L
.256 .42722 L
.26 .42717 L
.264 .42713 L
.268 .42709 L
.272 .42705 L
.276 .42701 L
.28 .42697 L
.284 .42693 L
.288 .4269 L
.292 .42687 L
.296 .42685 L
.3 .42683 L
.304 .42682 L
.308 .42683 L
.312 .42685 L
.316 .42688 L
.32 .42695 L
.324 .42704 L
.328 .42718 L
.332 .42736 L
.336 .4276 L
.34 .42792 L
.344 .42831 L
.348 .42881 L
.352 .42942 L
.356 .43017 L
.36 .43107 L
.364 .43213 L
.368 .43338 L
.372 .43483 L
.376 .43648 L
.38 .43835 L
.384 .44044 L
.388 .44273 L
.392 .44521 L
.396 .44788 L
.4 .45069 L
Mistroke
.404 .45361 L
.408 .4566 L
.412 .45963 L
.416 .46263 L
.42 .46558 L
.424 .46843 L
.428 .47115 L
.432 .47373 L
.436 .47615 L
.44 .47843 L
.444 .48059 L
.448 .48267 L
.452 .4847 L
.456 .48673 L
.46 .4888 L
.464 .49096 L
.468 .49322 L
.472 .4956 L
.476 .49808 L
.48 .50063 L
.484 .50321 L
.488 .50577 L
.492 .50825 L
.496 .5106 L
.5 .51279 L
.504 .51479 L
.508 .51659 L
.512 .5182 L
.516 .51965 L
.52 .52096 L
.524 .52215 L
.528 .52324 L
.532 .52422 L
.536 .52508 L
.54 .52577 L
.544 .52626 L
.548 .52651 L
.552 .52649 L
.556 .52621 L
.56 .52569 L
.564 .525 L
.568 .5242 L
.572 .52339 L
.576 .52266 L
.58 .52208 L
.584 .52169 L
.588 .5215 L
.592 .52149 L
.596 .52163 L
.6 .52186 L
Mistroke
.604 .52214 L
.608 .52242 L
.612 .52267 L
.616 .52286 L
.62 .52301 L
.624 .52309 L
.628 .52311 L
.632 .52304 L
.636 .52289 L
.64 .52266 L
.644 .52238 L
.648 .52206 L
.652 .52177 L
.656 .52155 L
.66 .52144 L
.664 .52148 L
.668 .52164 L
.672 .52188 L
.676 .52213 L
.68 .52231 L
.684 .52236 L
.688 .52227 L
.692 .52205 L
.696 .52176 L
.7 .52146 L
.704 .52123 L
.708 .52111 L
.712 .52113 L
.716 .52125 L
.72 .52142 L
.724 .52155 L
.728 .52161 L
.732 .52156 L
.736 .52144 L
.74 .52128 L
.744 .52111 L
.748 .52096 L
.752 .52086 L
.756 .52082 L
.76 .52084 L
.764 .5209 L
.768 .52095 L
.772 .52096 L
.776 .52093 L
.78 .52085 L
.784 .52075 L
.788 .52066 L
.792 .52056 L
.796 .52047 L
.8 .5204 L
Mistroke
.804 .52037 L
.808 .5204 L
.812 .52045 L
.816 .52048 L
.82 .52045 L
.824 .52035 L
.828 .5202 L
.832 .52006 L
.836 .51998 L
.84 .51998 L
.844 .52001 L
.848 .52004 L
.852 .52004 L
.856 .51999 L
.86 .51991 L
.864 .51982 L
.868 .51972 L
.872 .51964 L
.876 .51959 L
.88 .51959 L
.884 .5196 L
.888 .51962 L
.892 .5196 L
.896 .51953 L
.9 .5194 L
.904 .51928 L
.908 .5192 L
.912 .51921 L
.916 .51924 L
.92 .51928 L
.924 .51925 L
.928 .51916 L
.932 .51902 L
.936 .51892 L
.94 .51886 L
.944 .51888 L
.948 .51891 L
.952 .51892 L
.956 .51886 L
.96 .51877 L
.964 .51864 L
.968 .51858 L
.972 .51853 L
.976 .51856 L
.98 .51856 L
.984 .51856 L
.988 .51848 L
.992 .51839 L
.996 .51826 L
1 .51822 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`80009oo`8000Ioo`04001oogoo0002Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`03001oogoo00H0
00=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol0
<goo00@007ooOol000Eoo`03001oogoo009oo`03001oogoo02Qoo`008Woo0P00=7oo00@007ooOol0
00Aoo`<0009oo`<00004Ool000000003Ool01000Oomoogoo0P0000Eoo`00001oo`0001Moo`008Woo
H`0037oo000ROol01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1000Oomoo`000goo0`0000=oo`00Ool00Woo00D007ooOomoo`0000=oo`05001oogooOol00002Ool2
0002Ool3000017oo001oogoo0P000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000aoo`008Woo0P0087oo00<007ooOol047oo00<007ooOol0
=goo000ROol00`00Oomoo`0OOol2000@Ool00`00Oomoo`0hOol0029oo`80025oo`03001oogoo00eo
o`8003Yoo`008Woo0P008Woo00<007ooOol02goo0P00>goo000;Ool20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool00`00Oomoo`0QOol00`00Oomoo`0;Ool00`00Oomoo`0jOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P008goo00<007ooOol02Goo0P00?7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8002=oo`03001oogoo00=oo`<000=o
o`03001oogoo03]oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`0SOol00`00Oomoo`02Ool01P00Ool00000Ool003ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2000TOol01000Oomoogoo0P000Woo0`00?Woo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000Aoo`8002Aoo`05001oogooOol00004Ool00`00Oomoo`0mOol0
00]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo02Aoo`03001oo`0004Eoo`002goo0P00
17oo00<007ooOol00goo0P000Woo1@000Woo0P009Woo0P00AGoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001o
ogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo
0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol0
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007oo
Ool006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo
06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P00
17oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<0
07ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001o
ogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`80
00Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Mo
o`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009o
o`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool01000
0goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007oo
Ool007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomo
o`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0
009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo
00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007oo
Ool02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo
00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P00
0goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool2
0008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P00
17oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomo
o`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool2
0004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo02eoobd000aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo02Yoo`@003Qoo`00
2goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0:7oo0`00>goo000XOol00`00Oomoo`0V
Ool3000mOol002Qoo`03001oogoo02Aoo`<003moo`004Goo0P0017oo00<007ooOol00goo0P000goo
0`000goo00<007ooOol08Woo0`00@Goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo025oo`8004=oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2000MOol50015Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo7`00BWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`80
00Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo
0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol0
0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eo
o`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool0
0`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`80
00Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Ao
o`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yo
o`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00
Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=o
o`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo
00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<0
07ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol0
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomo
o`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo
00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001o
ogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@0
07ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo
00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001o
ogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol0
0goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009o
o`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`00
77oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03
001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007
Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]o
o`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`00
5goo00<007ooOol00Woo9`00CWoo000GOol00`00Oomoo`02Ool00`00Oomoo`0TOol2001<Ool001Mo
o`03001oogoo009oo`03001oogoo02Ioo`8004Yoo`005Woo0P0017oo0P00:7oo0P00BGoo000GOol0
0`00Oomoo`02Ool00`00Oomoo`0YOol00`00Oomoo`16Ool001aoo`03001oogoo02Yoo`<004Eoo`00
77oo0P00;Goo0P00A7oo000LOol00`00Oomoo`0^Ool20012Ool001aoo`80031oo`80045oo`0077oo
00<007ooOol0<Goo0`003Goo00<007ooOol00Woo800037oo000LOol00`00Oomoo`0cOolC0002Ool2
000XOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo
00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1b
Ool000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(10187\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30232 m
.008 .30148 L
.012 .2999 L
.016 .29969 L
.02 .3008 L
.024 .30101 L
.028 .30041 L
.032 .30028 L
.036 .30056 L
.04 .30061 L
.044 .30048 L
.048 .30045 L
.052 .3005 L
.056 .3005 L
.06 .30047 L
.064 .30046 L
.068 .30047 L
.072 .30046 L
.076 .30045 L
.08 .30045 L
.084 .30044 L
.088 .30044 L
.092 .30043 L
.096 .30042 L
.1 .30042 L
.104 .30041 L
.108 .30041 L
.112 .3004 L
.116 .3004 L
.12 .30039 L
.124 .30038 L
.128 .30038 L
.132 .30037 L
.136 .30037 L
.14 .30036 L
.144 .30035 L
.148 .30035 L
.152 .30034 L
.156 .30034 L
.16 .30033 L
.164 .30032 L
.168 .30032 L
.172 .30032 L
.176 .30031 L
.18 .3003 L
.184 .30029 L
.188 .30029 L
.192 .30029 L
.196 .30028 L
.2 .30027 L
Mistroke
.204 .30027 L
.208 .30027 L
.212 .30026 L
.216 .30025 L
.22 .30026 L
.224 .30026 L
.228 .30026 L
.232 .30027 L
.236 .30028 L
.24 .30031 L
.244 .30034 L
.248 .30038 L
.252 .30045 L
.256 .30055 L
.26 .30068 L
.264 .30085 L
.268 .30108 L
.272 .30141 L
.276 .30184 L
.28 .30238 L
.284 .30308 L
.288 .30399 L
.292 .30516 L
.296 .30663 L
.3 .30844 L
.304 .31067 L
.308 .3134 L
.312 .31671 L
.316 .32063 L
.32 .32523 L
.324 .33058 L
.328 .33673 L
.332 .34368 L
.336 .35137 L
.34 .35976 L
.344 .36878 L
.348 .37827 L
.352 .38799 L
.356 .39766 L
.36 .40702 L
.364 .41576 L
.368 .4235 L
.372 .42985 L
.376 .43451 L
.38 .43726 L
.384 .43797 L
.388 .43657 L
.392 .43311 L
.396 .42786 L
.4 .4213 L
Mistroke
.404 .41396 L
.408 .40644 L
.412 .39936 L
.416 .3934 L
.42 .38919 L
.424 .3871 L
.428 .38723 L
.432 .38945 L
.436 .39342 L
.44 .39857 L
.444 .4041 L
.448 .40902 L
.452 .41246 L
.456 .41376 L
.46 .41254 L
.464 .40866 L
.468 .4023 L
.472 .39402 L
.476 .3847 L
.48 .37532 L
.484 .3667 L
.488 .35936 L
.492 .3535 L
.496 .34904 L
.5 .34548 L
.504 .34197 L
.508 .33752 L
.512 .33131 L
.516 .32298 L
.52 .31274 L
.524 .30121 L
.528 .28944 L
.532 .27876 L
.536 .27064 L
.54 .26629 L
.544 .26631 L
.548 .27046 L
.552 .27783 L
.556 .28708 L
.56 .2967 L
.564 .30528 L
.568 .31165 L
.572 .31519 L
.576 .31597 L
.58 .31472 L
.584 .3124 L
.588 .30982 L
.592 .30735 L
.596 .30499 L
.6 .3026 L
Mistroke
.604 .30001 L
.608 .29712 L
.612 .29401 L
.616 .29106 L
.62 .28909 L
.624 .28912 L
.628 .29185 L
.632 .29709 L
.636 .30369 L
.64 .30988 L
.644 .31399 L
.648 .31493 L
.652 .31238 L
.656 .30679 L
.66 .29944 L
.664 .29232 L
.668 .28771 L
.672 .28723 L
.676 .29098 L
.68 .29747 L
.684 .30425 L
.688 .30916 L
.692 .31107 L
.696 .30994 L
.7 .30641 L
.704 .30151 L
.708 .29665 L
.712 .29343 L
.716 .29303 L
.72 .29549 L
.724 .29945 L
.728 .30294 L
.732 .30462 L
.736 .30451 L
.74 .30361 L
.744 .30276 L
.748 .30197 L
.752 .30072 L
.756 .2989 L
.76 .29726 L
.764 .29693 L
.768 .29832 L
.772 .30068 L
.776 .3027 L
.78 .30354 L
.784 .30337 L
.788 .30281 L
.792 .30205 L
.796 .30072 L
.8 .2986 L
Mistroke
.804 .29648 L
.808 .29604 L
.812 .29833 L
.816 .30267 L
.82 .30645 L
.824 .30697 L
.828 .30365 L
.832 .29843 L
.836 .29478 L
.84 .29495 L
.844 .29841 L
.848 .30274 L
.852 .3051 L
.856 .30453 L
.86 .3022 L
.864 .29975 L
.868 .29855 L
.872 .29855 L
.876 .29898 L
.88 .29977 L
.884 .30078 L
.888 .30208 L
.892 .30329 L
.896 .30309 L
.9 .30133 L
.904 .29878 L
.908 .2969 L
.912 .29757 L
.916 .30031 L
.92 .30338 L
.924 .30488 L
.928 .30328 L
.932 .29995 L
.936 .29722 L
.94 .29663 L
.944 .29895 L
.948 .30221 L
.952 .30407 L
.956 .30379 L
.96 .30127 L
.964 .29854 L
.968 .2975 L
.972 .29823 L
.976 .30051 L
.98 .30266 L
.984 .30327 L
.988 .30252 L
.992 .3005 L
.996 .29863 L
1 .29799 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51523 m
.008 .51113 L
.012 .50973 L
.016 .5109 L
.02 .51147 L
.024 .51109 L
.028 .51091 L
.032 .51099 L
.036 .51109 L
.04 .51104 L
.044 .51103 L
.048 .51102 L
.052 .51105 L
.056 .51103 L
.06 .51104 L
.064 .51103 L
.068 .51104 L
.072 .51103 L
.076 .51104 L
.08 .51103 L
.084 .51104 L
.088 .51103 L
.092 .51104 L
.096 .51103 L
.1 .51104 L
.104 .51103 L
.108 .51104 L
.112 .51103 L
.116 .51104 L
.12 .51103 L
.124 .51104 L
.128 .51103 L
.132 .51104 L
.136 .51103 L
.14 .51103 L
.144 .51103 L
.148 .51103 L
.152 .51103 L
.156 .51103 L
.16 .51103 L
.164 .51103 L
.168 .51103 L
.172 .51103 L
.176 .51103 L
.18 .51103 L
.184 .51103 L
.188 .51103 L
.192 .51103 L
.196 .51103 L
.2 .51103 L
Mistroke
.204 .51103 L
.208 .51103 L
.212 .51103 L
.216 .51103 L
.22 .51103 L
.224 .51103 L
.228 .51103 L
.232 .51103 L
.236 .51103 L
.24 .51103 L
.244 .51102 L
.248 .51102 L
.252 .51102 L
.256 .51101 L
.26 .511 L
.264 .51099 L
.268 .51098 L
.272 .51096 L
.276 .51093 L
.28 .51089 L
.284 .51085 L
.288 .51078 L
.292 .5107 L
.296 .5106 L
.3 .51046 L
.304 .51029 L
.308 .51007 L
.312 .5098 L
.316 .50947 L
.32 .50905 L
.324 .50855 L
.328 .50795 L
.332 .50723 L
.336 .50638 L
.34 .50539 L
.344 .50424 L
.348 .50293 L
.352 .50145 L
.356 .4998 L
.36 .49798 L
.364 .49601 L
.368 .49388 L
.372 .49163 L
.376 .48929 L
.38 .48687 L
.384 .48442 L
.388 .48197 L
.392 .47956 L
.396 .47722 L
.4 .47497 L
Mistroke
.404 .47283 L
.408 .47081 L
.412 .46891 L
.416 .46712 L
.42 .4654 L
.424 .46374 L
.428 .46209 L
.432 .46042 L
.436 .45869 L
.44 .45689 L
.444 .455 L
.448 .45303 L
.452 .45098 L
.456 .4489 L
.46 .44682 L
.464 .44478 L
.468 .44283 L
.472 .441 L
.476 .43932 L
.48 .43779 L
.484 .43643 L
.488 .43521 L
.492 .43411 L
.496 .43312 L
.5 .43221 L
.504 .43139 L
.508 .43067 L
.512 .43006 L
.516 .4296 L
.52 .42931 L
.524 .42922 L
.528 .42934 L
.532 .42966 L
.536 .43014 L
.54 .43073 L
.544 .43136 L
.548 .43196 L
.552 .43246 L
.556 .43283 L
.56 .43303 L
.564 .43307 L
.568 .43298 L
.572 .43279 L
.576 .43254 L
.58 .43228 L
.584 .43204 L
.588 .43184 L
.592 .43169 L
.596 .43158 L
.6 .43154 L
Mistroke
.604 .43155 L
.608 .43162 L
.612 .43175 L
.616 .43193 L
.62 .43215 L
.624 .43236 L
.628 .43255 L
.632 .43266 L
.636 .43266 L
.64 .43257 L
.644 .43239 L
.648 .43217 L
.652 .43197 L
.656 .43184 L
.66 .43182 L
.664 .43192 L
.668 .4321 L
.672 .43233 L
.676 .43253 L
.68 .43266 L
.684 .43268 L
.688 .43261 L
.692 .43248 L
.696 .43233 L
.7 .43221 L
.704 .43216 L
.708 .43219 L
.712 .43229 L
.716 .43243 L
.72 .43255 L
.724 .43263 L
.728 .43265 L
.732 .43263 L
.736 .43258 L
.74 .43253 L
.744 .43248 L
.748 .43246 L
.752 .43246 L
.756 .4325 L
.76 .43256 L
.764 .43264 L
.768 .43271 L
.772 .43274 L
.776 .43274 L
.78 .43271 L
.784 .43267 L
.788 .43264 L
.792 .43262 L
.796 .43263 L
.8 .43268 L
Mistroke
.804 .43275 L
.808 .43283 L
.812 .43288 L
.816 .43289 L
.82 .43284 L
.824 .43277 L
.828 .43272 L
.832 .43273 L
.836 .4328 L
.84 .4329 L
.844 .43296 L
.848 .43298 L
.852 .43296 L
.856 .43291 L
.86 .43288 L
.864 .43289 L
.868 .43292 L
.872 .43296 L
.876 .43301 L
.88 .43305 L
.884 .43306 L
.888 .43306 L
.892 .43304 L
.896 .43302 L
.9 .43301 L
.904 .43304 L
.908 .43309 L
.912 .43315 L
.916 .43318 L
.92 .43319 L
.924 .43315 L
.928 .43312 L
.932 .43311 L
.936 .43315 L
.94 .43321 L
.944 .43327 L
.948 .43328 L
.952 .43328 L
.956 .43323 L
.96 .43322 L
.964 .43323 L
.968 .43329 L
.972 .43333 L
.976 .43339 L
.98 .43337 L
.984 .43337 L
.988 .43332 L
.992 .43333 L
.996 .43334 L
1 .43342 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43339 L
.012 .42972 L
.016 .42865 L
.02 .42985 L
.024 .43018 L
.028 .42964 L
.032 .42952 L
.036 .42962 L
.04 .42963 L
.044 .42951 L
.048 .42947 L
.052 .42943 L
.056 .42941 L
.06 .42934 L
.064 .42931 L
.068 .42926 L
.072 .42923 L
.076 .42917 L
.08 .42914 L
.084 .42908 L
.088 .42905 L
.092 .429 L
.096 .42896 L
.1 .42891 L
.104 .42887 L
.108 .42882 L
.112 .42879 L
.116 .42874 L
.12 .4287 L
.124 .42865 L
.128 .42861 L
.132 .42856 L
.136 .42852 L
.14 .42848 L
.144 .42844 L
.148 .42839 L
.152 .42835 L
.156 .4283 L
.16 .42826 L
.164 .42822 L
.168 .42817 L
.172 .42813 L
.176 .42809 L
.18 .42804 L
.184 .428 L
.188 .42796 L
.192 .42791 L
.196 .42787 L
.2 .42783 L
Mistroke
.204 .42778 L
.208 .42774 L
.212 .42769 L
.216 .42765 L
.22 .42761 L
.224 .42757 L
.228 .42752 L
.232 .42748 L
.236 .42744 L
.24 .4274 L
.244 .42735 L
.248 .42731 L
.252 .42728 L
.256 .42724 L
.26 .42721 L
.264 .42718 L
.268 .42715 L
.272 .42713 L
.276 .42712 L
.28 .42712 L
.284 .42714 L
.288 .42717 L
.292 .42723 L
.296 .42732 L
.3 .42744 L
.304 .42761 L
.308 .42784 L
.312 .42813 L
.316 .42851 L
.32 .42898 L
.324 .42956 L
.328 .43027 L
.332 .43112 L
.336 .43213 L
.34 .43333 L
.344 .43471 L
.348 .4363 L
.352 .4381 L
.356 .44012 L
.36 .44234 L
.364 .44476 L
.368 .44737 L
.372 .45013 L
.376 .45301 L
.38 .45598 L
.384 .459 L
.388 .46201 L
.392 .46498 L
.396 .46786 L
.4 .47063 L
Mistroke
.404 .47326 L
.408 .47574 L
.412 .47807 L
.416 .48027 L
.42 .48238 L
.424 .48442 L
.428 .48644 L
.432 .48849 L
.436 .4906 L
.44 .49282 L
.444 .49514 L
.448 .49756 L
.452 .50008 L
.456 .50264 L
.46 .50521 L
.464 .50772 L
.468 .51012 L
.472 .51237 L
.476 .51444 L
.48 .51631 L
.484 .51798 L
.488 .51948 L
.492 .52082 L
.496 .52203 L
.5 .52313 L
.504 .52412 L
.508 .52499 L
.512 .52573 L
.516 .52628 L
.52 .52661 L
.524 .52669 L
.528 .52652 L
.532 .52609 L
.536 .52547 L
.54 .52471 L
.544 .5239 L
.548 .52312 L
.552 .52246 L
.556 .52198 L
.56 .5217 L
.564 .52162 L
.568 .52171 L
.572 .52192 L
.576 .5222 L
.58 .52249 L
.584 .52277 L
.588 .52299 L
.592 .52315 L
.596 .52325 L
.6 .52328 L
Mistroke
.604 .52324 L
.608 .52313 L
.612 .52294 L
.616 .52268 L
.62 .52239 L
.624 .52209 L
.628 .52184 L
.632 .52167 L
.636 .52163 L
.64 .52172 L
.644 .52192 L
.648 .52216 L
.652 .52239 L
.656 .52252 L
.66 .52251 L
.664 .52237 L
.668 .52211 L
.672 .52181 L
.676 .52153 L
.68 .52134 L
.684 .52127 L
.688 .52133 L
.692 .52148 L
.696 .52164 L
.7 .52176 L
.704 .52178 L
.708 .52171 L
.712 .52156 L
.716 .52138 L
.72 .52121 L
.724 .52108 L
.728 .52101 L
.732 .521 L
.736 .52104 L
.74 .52109 L
.744 .52113 L
.748 .52113 L
.752 .52107 L
.756 .52099 L
.76 .52089 L
.764 .52079 L
.768 .52069 L
.772 .52061 L
.776 .52056 L
.78 .52056 L
.784 .52059 L
.788 .52063 L
.792 .52063 L
.796 .52058 L
.8 .52047 L
Mistroke
.804 .52033 L
.808 .52022 L
.812 .52016 L
.816 .52015 L
.82 .52016 L
.824 .52019 L
.828 .52019 L
.832 .52016 L
.836 .52008 L
.84 .51998 L
.844 .51986 L
.848 .51976 L
.852 .51972 L
.856 .51975 L
.86 .5198 L
.864 .51982 L
.868 .51977 L
.872 .51965 L
.876 .5195 L
.88 .51941 L
.884 .51938 L
.888 .51941 L
.892 .51945 L
.896 .51944 L
.9 .51936 L
.904 .51925 L
.908 .51915 L
.912 .5191 L
.916 .51908 L
.92 .51909 L
.924 .51907 L
.928 .51902 L
.932 .51895 L
.936 .51888 L
.94 .51882 L
.944 .5188 L
.948 .51876 L
.952 .51874 L
.956 .51867 L
.96 .51862 L
.964 .51857 L
.968 .51854 L
.972 .51849 L
.976 .51848 L
.98 .51841 L
.984 .51837 L
.988 .51828 L
.992 .51825 L
.996 .5182 L
1 .5182 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`<0009oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
o`00Ool50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo035oo`03001oo`0000Yoo`8002aoo`008Woo0P00<Woo00@007ooOol000=oo`@0009oo`80
009oo`8000=oo`80009oo`800003Ool00000009oo`06001oogooOol007oo0P0000Aoo`00001oo`80
00aoo`008WooH`0037oo000ROol01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01000Oomoo`000Woo0P000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1000Oomoogoo0`0000Aoo`00Oomoo`<00006Ool00000001oo`000goo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol02Woo000ROol2000MOol00`00Oomo
o`0@Ool00`00Oomoo`0jOol0029oo`03001oogoo01eoo`03001oogoo00moo`03001oogoo03Yoo`00
8Woo0P007Woo00<007ooOol03Goo0P00?Goo000ROol2000OOol00`00Oomoo`0<Ool00`00Oomoo`0l
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo01moo`03001oogoo00Yo
o`03001oogoo03eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000P
Ool00`00Oomoo`0:Ool00`00Oomoo`0mOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P0087oo00<007ooOol017oo0P0017oo00<007ooOol0?Goo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo021oo`03001oogoo009oo`800005Ool0
07ooOol00010Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P008Goo
00<007ooOol00Woo00<007ooOol01000@7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`80029oo`03001oogoo008000=oo`80045oo`002goo0P002Woo0P0017oo00<007ooOol00Woo
00<007ooOol08Goo00@007ooOol004Moo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo
0P008goo0P00B7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:
Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008
Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo
001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00
Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007oo
Ool000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`00
0goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomo
o`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogoo
Ool00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo
10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001o
ogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo
0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool0
0`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=o
o`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00
Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<0
00Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00
009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001o
ogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
0Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomo
o`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo
0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@0
07ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo
001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`00
0goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`80
00Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo
0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000
Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004
Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?
Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003
Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo
00@000=oo`03001oogoo02Yooc0000aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00
Oomoo`00Ool000Ioo`03001oogoo02Qoo`<003]oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo
00<007ooOol09Woo0`00?Goo000XOol00`00Oomoo`0TOol20010Ool002Qoo`03001oogoo025oo`<0
049oo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol087oo0P00A7oo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo01ioo`8004Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000JOol60017Ool0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo7@00C7oo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
2goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009o
o`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo
000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007oo
Ool017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<0
00Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`80
00Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000
Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo
00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool0
1000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol0
0`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eo
o`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002
Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eo
o`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D0
00=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo
009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo
009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00
Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<0
07ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol0
00]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1b
Ool001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo9000DGoo000GOol0
0`00Oomoo`02Ool00`00Oomoo`0QOol2001?Ool001Moo`03001oogoo009oo`03001oogoo02=oo`80
04eoo`005Woo0P0017oo0P009Goo0P00C7oo000GOol00`00Oomoo`02Ool00`00Oomoo`0VOol2001:
Ool001aoo`03001oogoo02Moo`<004Qoo`0077oo0P00:Woo0P00Agoo000LOol00`00Oomoo`0[Ool2
0015Ool001aoo`8002eoo`<004=oo`0077oo00<007ooOol0;Woo0`004Woo0P000Woo7`0037oo000L
Ool00`00Oomoo`0`OolD000017oo00000000:Woo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2
001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001o
ogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<0
07ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1b
Ool000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(10354\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3021 m
.008 .30066 L
.012 .3002 L
.016 .30014 L
.02 .3006 L
.024 .30083 L
.028 .30059 L
.032 .30042 L
.036 .30051 L
.04 .30059 L
.044 .30056 L
.048 .30051 L
.052 .30051 L
.056 .30052 L
.06 .30052 L
.064 .3005 L
.068 .3005 L
.072 .30049 L
.076 .30049 L
.08 .30048 L
.084 .30048 L
.088 .30047 L
.092 .30046 L
.096 .30046 L
.1 .30045 L
.104 .30045 L
.108 .30044 L
.112 .30043 L
.116 .30043 L
.12 .30042 L
.124 .30042 L
.128 .30041 L
.132 .30041 L
.136 .3004 L
.14 .3004 L
.144 .30039 L
.148 .30038 L
.152 .30038 L
.156 .30037 L
.16 .30037 L
.164 .30036 L
.168 .30035 L
.172 .30035 L
.176 .30035 L
.18 .30034 L
.184 .30033 L
.188 .30033 L
.192 .30033 L
.196 .30033 L
.2 .30033 L
Mistroke
.204 .30034 L
.208 .30036 L
.212 .30038 L
.216 .3004 L
.22 .30045 L
.224 .30052 L
.228 .30061 L
.232 .30073 L
.236 .3009 L
.24 .30113 L
.244 .30144 L
.248 .30183 L
.252 .30235 L
.256 .30304 L
.26 .30392 L
.264 .30502 L
.268 .30642 L
.272 .30816 L
.276 .31032 L
.28 .31295 L
.284 .31612 L
.288 .3199 L
.292 .32438 L
.296 .3296 L
.3 .33558 L
.304 .34234 L
.308 .3499 L
.312 .35821 L
.316 .36715 L
.32 .37658 L
.324 .38633 L
.328 .39616 L
.332 .40578 L
.336 .41483 L
.34 .42297 L
.344 .42988 L
.348 .43523 L
.352 .43872 L
.356 .44014 L
.36 .43942 L
.364 .43666 L
.368 .43203 L
.372 .42586 L
.376 .41864 L
.38 .41099 L
.384 .40361 L
.388 .39714 L
.392 .39215 L
.396 .38908 L
.4 .38825 L
Mistroke
.404 .38967 L
.408 .39305 L
.412 .39781 L
.416 .40324 L
.42 .40851 L
.424 .41274 L
.428 .41509 L
.432 .41495 L
.436 .41208 L
.44 .40662 L
.444 .39902 L
.448 .38992 L
.452 .3802 L
.456 .3708 L
.46 .3625 L
.464 .35574 L
.468 .35048 L
.472 .34634 L
.476 .34266 L
.48 .33862 L
.484 .33335 L
.488 .32616 L
.492 .31685 L
.496 .30584 L
.5 .29408 L
.504 .28286 L
.508 .27351 L
.512 .26731 L
.516 .26517 L
.52 .26741 L
.524 .27356 L
.528 .28242 L
.532 .2924 L
.536 .30191 L
.54 .30967 L
.544 .31482 L
.548 .31704 L
.552 .31663 L
.556 .31437 L
.56 .3113 L
.564 .30822 L
.568 .30552 L
.572 .3031 L
.576 .3007 L
.58 .29811 L
.584 .29531 L
.588 .29256 L
.592 .29036 L
.596 .28947 L
.6 .29064 L
Mistroke
.604 .29426 L
.608 .29995 L
.612 .30644 L
.616 .31197 L
.62 .31492 L
.624 .31437 L
.628 .31036 L
.632 .30384 L
.636 .29645 L
.64 .29022 L
.644 .28705 L
.648 .28803 L
.652 .29286 L
.656 .29985 L
.66 .30655 L
.664 .31085 L
.668 .31171 L
.672 .30932 L
.676 .30476 L
.68 .29948 L
.684 .29505 L
.688 .29278 L
.692 .29337 L
.696 .29644 L
.7 .30055 L
.704 .30393 L
.708 .30543 L
.712 .30508 L
.716 .30376 L
.72 .30231 L
.724 .30098 L
.728 .29961 L
.732 .29823 L
.736 .29739 L
.74 .29772 L
.744 .29926 L
.748 .30129 L
.752 .30286 L
.756 .30351 L
.76 .30342 L
.764 .30289 L
.768 .30184 L
.772 .30005 L
.776 .29776 L
.78 .29617 L
.784 .29674 L
.788 .29979 L
.792 .30393 L
.796 .30657 L
.8 .30585 L
Mistroke
.804 .30218 L
.808 .29783 L
.812 .29551 L
.816 .29633 L
.82 .29924 L
.824 .30231 L
.828 .30395 L
.832 .30392 L
.836 .30286 L
.84 .30124 L
.844 .29945 L
.848 .29787 L
.852 .29718 L
.856 .2984 L
.86 .30127 L
.864 .3043 L
.868 .30548 L
.872 .30343 L
.876 .29937 L
.88 .29603 L
.884 .29574 L
.888 .29904 L
.892 .30339 L
.896 .30565 L
.9 .30442 L
.904 .30049 L
.908 .29704 L
.912 .29657 L
.916 .29892 L
.92 .3024 L
.924 .30417 L
.928 .30307 L
.932 .30052 L
.936 .29831 L
.94 .29818 L
.944 .30003 L
.948 .30193 L
.952 .30268 L
.956 .30177 L
.96 .29999 L
.964 .29909 L
.968 .29938 L
.972 .30061 L
.976 .30183 L
.98 .3019 L
.984 .30118 L
.988 .30008 L
.992 .29936 L
.996 .29972 L
1 .30036 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .50653 m
.008 .5109 L
.012 .51234 L
.016 .5107 L
.02 .5103 L
.024 .51086 L
.028 .51101 L
.032 .51078 L
.036 .51076 L
.04 .51082 L
.044 .51085 L
.048 .5108 L
.052 .51081 L
.056 .51081 L
.06 .51082 L
.064 .51081 L
.068 .51082 L
.072 .51081 L
.076 .51082 L
.08 .51081 L
.084 .51082 L
.088 .51081 L
.092 .51082 L
.096 .51081 L
.1 .51082 L
.104 .51081 L
.108 .51082 L
.112 .51081 L
.116 .51082 L
.12 .51081 L
.124 .51082 L
.128 .51081 L
.132 .51082 L
.136 .51081 L
.14 .51081 L
.144 .51081 L
.148 .51081 L
.152 .51081 L
.156 .51081 L
.16 .51081 L
.164 .51081 L
.168 .51081 L
.172 .51081 L
.176 .51081 L
.18 .51081 L
.184 .51081 L
.188 .51081 L
.192 .51081 L
.196 .51081 L
.2 .51081 L
Mistroke
.204 .51081 L
.208 .51081 L
.212 .51081 L
.216 .5108 L
.22 .5108 L
.224 .5108 L
.228 .51079 L
.232 .51078 L
.236 .51077 L
.24 .51076 L
.244 .51074 L
.248 .51072 L
.252 .51068 L
.256 .51064 L
.26 .51058 L
.264 .5105 L
.268 .5104 L
.272 .51027 L
.276 .51011 L
.28 .50991 L
.284 .50965 L
.288 .50933 L
.292 .50894 L
.296 .50847 L
.3 .50789 L
.304 .50721 L
.308 .5064 L
.312 .50545 L
.316 .50435 L
.32 .50309 L
.324 .50166 L
.328 .50007 L
.332 .4983 L
.336 .49638 L
.34 .4943 L
.344 .4921 L
.348 .48978 L
.352 .48739 L
.356 .48495 L
.36 .4825 L
.364 .48008 L
.368 .47771 L
.372 .47542 L
.376 .47325 L
.38 .47118 L
.384 .46924 L
.388 .46741 L
.392 .46567 L
.396 .46399 L
.4 .46234 L
Mistroke
.404 .46068 L
.408 .45899 L
.412 .45722 L
.416 .45538 L
.42 .45345 L
.424 .45144 L
.428 .44938 L
.432 .4473 L
.436 .44524 L
.44 .44326 L
.444 .44139 L
.448 .43965 L
.452 .43807 L
.456 .43665 L
.46 .43538 L
.464 .43425 L
.468 .43324 L
.472 .43232 L
.476 .4315 L
.48 .43076 L
.484 .43013 L
.488 .42962 L
.492 .42927 L
.496 .42911 L
.5 .42915 L
.504 .42939 L
.508 .42981 L
.512 .43036 L
.516 .43098 L
.52 .4316 L
.524 .43215 L
.528 .43258 L
.532 .43286 L
.536 .43297 L
.54 .43293 L
.544 .43277 L
.548 .43253 L
.552 .43226 L
.556 .432 L
.56 .43177 L
.564 .4316 L
.568 .43148 L
.572 .43142 L
.576 .43141 L
.58 .43147 L
.584 .43157 L
.588 .43173 L
.592 .43192 L
.596 .43213 L
.6 .43233 L
Mistroke
.604 .43247 L
.608 .43254 L
.612 .4325 L
.616 .43236 L
.62 .43217 L
.624 .43196 L
.628 .43179 L
.632 .4317 L
.636 .43173 L
.64 .43186 L
.644 .43207 L
.648 .43229 L
.652 .43247 L
.656 .43256 L
.66 .43255 L
.664 .43245 L
.668 .4323 L
.672 .43215 L
.676 .43206 L
.68 .43204 L
.684 .4321 L
.688 .43221 L
.692 .43235 L
.696 .43246 L
.7 .43253 L
.704 .43253 L
.708 .43249 L
.712 .43243 L
.716 .43238 L
.72 .43234 L
.724 .43233 L
.728 .43235 L
.732 .4324 L
.736 .43247 L
.74 .43254 L
.744 .4326 L
.748 .43262 L
.752 .4326 L
.756 .43257 L
.76 .43254 L
.764 .43251 L
.768 .4325 L
.772 .43252 L
.776 .43257 L
.78 .43265 L
.784 .43272 L
.788 .43276 L
.792 .43275 L
.796 .4327 L
.8 .43264 L
Mistroke
.804 .43261 L
.808 .43263 L
.812 .4327 L
.816 .43278 L
.82 .43284 L
.824 .43285 L
.828 .43284 L
.832 .4328 L
.836 .43277 L
.84 .43277 L
.844 .43278 L
.848 .43283 L
.852 .43289 L
.856 .43294 L
.86 .43296 L
.864 .43295 L
.868 .43291 L
.872 .43287 L
.876 .43288 L
.88 .43293 L
.884 .433 L
.888 .43306 L
.892 .43307 L
.896 .43304 L
.9 .433 L
.904 .43298 L
.908 .43301 L
.912 .43307 L
.916 .43312 L
.92 .43315 L
.924 .43313 L
.928 .43311 L
.932 .4331 L
.936 .43313 L
.94 .43316 L
.944 .4332 L
.948 .43321 L
.952 .43322 L
.956 .4332 L
.96 .43322 L
.964 .43323 L
.968 .43327 L
.972 .43328 L
.976 .43331 L
.98 .43329 L
.984 .43331 L
.988 .43329 L
.992 .43334 L
.996 .43335 L
1 .4334 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43316 L
.012 .43 L
.016 .42882 L
.02 .42966 L
.024 .43009 L
.028 .42974 L
.032 .42956 L
.036 .42957 L
.04 .42961 L
.044 .42953 L
.048 .42948 L
.052 .42942 L
.056 .42941 L
.06 .42934 L
.064 .42931 L
.068 .42926 L
.072 .42923 L
.076 .42917 L
.08 .42914 L
.084 .42908 L
.088 .42905 L
.092 .429 L
.096 .42896 L
.1 .42891 L
.104 .42887 L
.108 .42882 L
.112 .42879 L
.116 .42874 L
.12 .4287 L
.124 .42865 L
.128 .42861 L
.132 .42856 L
.136 .42852 L
.14 .42848 L
.144 .42844 L
.148 .42839 L
.152 .42835 L
.156 .4283 L
.16 .42826 L
.164 .42822 L
.168 .42818 L
.172 .42813 L
.176 .42809 L
.18 .42804 L
.184 .428 L
.188 .42796 L
.192 .42791 L
.196 .42787 L
.2 .42783 L
Mistroke
.204 .42779 L
.208 .42774 L
.212 .4277 L
.216 .42766 L
.22 .42762 L
.224 .42758 L
.228 .42754 L
.232 .42751 L
.236 .42748 L
.24 .42745 L
.244 .42743 L
.248 .42742 L
.252 .42742 L
.256 .42743 L
.26 .42746 L
.264 .42751 L
.268 .42759 L
.272 .42771 L
.276 .42787 L
.28 .42808 L
.284 .42835 L
.288 .42871 L
.292 .42915 L
.296 .4297 L
.3 .43037 L
.304 .43118 L
.308 .43215 L
.312 .43329 L
.316 .43462 L
.32 .43614 L
.324 .43788 L
.328 .43982 L
.332 .44198 L
.336 .44434 L
.34 .44688 L
.344 .44959 L
.348 .45243 L
.352 .45537 L
.356 .45837 L
.36 .46139 L
.364 .46437 L
.368 .46729 L
.372 .4701 L
.376 .47277 L
.38 .47531 L
.384 .47769 L
.388 .47994 L
.392 .48208 L
.396 .48413 L
.4 .48616 L
Mistroke
.404 .48819 L
.408 .49027 L
.412 .49243 L
.416 .4947 L
.42 .49708 L
.424 .49955 L
.428 .50208 L
.432 .50464 L
.436 .50717 L
.44 .50961 L
.444 .51192 L
.448 .51406 L
.452 .516 L
.456 .51774 L
.46 .51929 L
.464 .52067 L
.468 .52191 L
.472 .52302 L
.476 .52402 L
.48 .52491 L
.484 .52568 L
.488 .52628 L
.492 .52668 L
.496 .52686 L
.5 .52678 L
.504 .52646 L
.508 .52591 L
.512 .5252 L
.516 .5244 L
.52 .5236 L
.524 .52288 L
.528 .52232 L
.532 .52194 L
.536 .52178 L
.54 .5218 L
.544 .52198 L
.548 .52225 L
.552 .52255 L
.556 .52285 L
.56 .5231 L
.564 .52329 L
.568 .52341 L
.572 .52346 L
.576 .52344 L
.58 .52335 L
.584 .52319 L
.588 .52297 L
.592 .5227 L
.596 .52241 L
.6 .52214 L
Mistroke
.604 .52193 L
.608 .52183 L
.612 .52185 L
.616 .52198 L
.62 .5222 L
.624 .52244 L
.628 .52263 L
.632 .5227 L
.636 .52264 L
.64 .52244 L
.644 .52216 L
.648 .52186 L
.652 .52161 L
.656 .52146 L
.66 .52145 L
.664 .52155 L
.668 .52171 L
.672 .52187 L
.676 .52196 L
.68 .52195 L
.684 .52184 L
.688 .52167 L
.692 .52148 L
.696 .52132 L
.7 .52121 L
.704 .52116 L
.708 .52118 L
.712 .52123 L
.716 .52128 L
.72 .52131 L
.724 .52129 L
.728 .52122 L
.732 .52113 L
.736 .52102 L
.74 .52092 L
.744 .52083 L
.748 .52076 L
.752 .52073 L
.756 .52074 L
.76 .52077 L
.764 .5208 L
.768 .52078 L
.772 .52071 L
.776 .5206 L
.78 .52048 L
.784 .52038 L
.788 .52032 L
.792 .52031 L
.796 .52032 L
.8 .52035 L
Mistroke
.804 .52035 L
.808 .52032 L
.812 .52023 L
.816 .52011 L
.82 .51999 L
.824 .51991 L
.828 .5199 L
.832 .51994 L
.836 .51998 L
.84 .51997 L
.844 .51989 L
.848 .51977 L
.852 .51965 L
.856 .51958 L
.86 .51957 L
.864 .51958 L
.868 .51959 L
.872 .51956 L
.876 .51949 L
.88 .51942 L
.884 .51934 L
.888 .51929 L
.892 .51924 L
.896 .51921 L
.9 .51918 L
.904 .51916 L
.908 .51913 L
.912 .51909 L
.916 .51902 L
.92 .51895 L
.924 .51887 L
.928 .51883 L
.932 .51881 L
.936 .51881 L
.94 .51879 L
.944 .51874 L
.948 .51865 L
.952 .51857 L
.956 .5185 L
.96 .51849 L
.964 .51848 L
.968 .51848 L
.972 .51843 L
.976 .51837 L
.98 .51826 L
.984 .5182 L
.988 .51814 L
.992 .51816 L
.996 .51814 L
1 .51814 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000=oo`<000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`<000=o
o`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007oo
Ool0;Woo00@007ooOol000Yoo`03001oogoo02eoo`008Woo0P00;goo00@007ooOol000Aoo`<0009o
o`03001oo`00009oo`80009oo`8000=oo`800003Ool00000009oo`800006Ool007ooOol007oo0P00
4Woo000ROomS000<Ool0029oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo0080009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo0P000Woo
00<007oo00000P000goo10000Woo0P000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000aoo`008Woo0P006Woo0P004Woo00<007ooOol0?7oo
000ROol00`00Oomoo`0JOol00`00Oomoo`0?Ool00`00Oomoo`0mOol0029oo`8001aoo`03001oogoo
00eoo`8003moo`008Woo0P007Goo00<007ooOol02goo0P00@7oo000;Ool20004Ool00`00Oomoo`03
Ool20003Ool30003Ool00`00Oomoo`0LOol00`00Oomoo`0;Ool00`00Oomoo`0oOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P007Goo00<007ooOol02Woo0P00@Goo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8001ioo`03001oogoo00Aoo`80
00=oo`03001oogoo041oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`0MOol00`00Oomoo`03Ool00`00Ool00002Ool00`00Oomoo`11Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P007Woo00<007ooOol00Woo0P000Woo00<007oo
0000@goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8001moo`05001oogooOol0
0003Ool30013Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo01ioo`800003Ool0
07oo04Uoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P0087oo0`00BWoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@0
07ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=o
o`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol0
06ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001o
o`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo
001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo
001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]
Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00
K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1Y
Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0
JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Mo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Io
o`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo
0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`80
00Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Io
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001X
Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo
001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo0080
00]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`80
00Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009o
o`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007oo
Ool03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002
Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo
00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00
:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool0
1000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00
Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo
0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00
Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1V
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00
J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo02Qo
oc8000aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001o
ogoo02Eoo`@003eoo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol08goo0`00@7oo
000XOol00`00Oomoo`0QOol30012Ool002Qoo`03001oogoo01moo`<004Aoo`004Goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo00<007ooOol07Goo0`00AWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo01]oo`<004Qoo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0FOol6001:Ool0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo6P00Cgoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004
Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00
Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;
Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomo
o`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo
000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<0
00Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<0
00Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<0
07ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo
0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo
00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool0
1000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001o
ogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000L
Ool2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007oo
Ool037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`00
17oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo
1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<0
00Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00
Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`00
0goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079o
o`002Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo
001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
0`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001o
ogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo8@00E7oo000GOol00`00Oomoo`02Ool0
0`00Oomoo`0NOol3001AOol001Moo`03001oogoo009oo`03001oogoo021oo`80051oo`005Woo0P00
17oo0P008goo00<007ooOol0CGoo000GOol00`00Oomoo`02Ool00`00Oomoo`0SOol2001=Ool001ao
o`03001oogoo02Aoo`<004]oo`0077oo0P009goo0`00BGoo000LOol00`00Oomoo`0XOol20018Ool0
01aoo`8002]oo`8004Ioo`0077oo00<007ooOol0:goo0`004goo00@007ooOomoob4000aoo`0077oo
00<007ooOol0;Woo6000;7oo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03
001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001o
ogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo1000
0goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001o
ogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(10521\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29914 m
.008 .29971 L
.012 .30119 L
.016 .30138 L
.02 .30035 L
.024 .30016 L
.028 .30071 L
.032 .30079 L
.036 .30053 L
.04 .30048 L
.044 .30059 L
.048 .3006 L
.052 .30055 L
.056 .30053 L
.06 .30055 L
.064 .30054 L
.068 .30053 L
.072 .30052 L
.076 .30052 L
.08 .30052 L
.084 .30051 L
.088 .3005 L
.092 .3005 L
.096 .30049 L
.1 .30049 L
.104 .30048 L
.108 .30048 L
.112 .30047 L
.116 .30046 L
.12 .30046 L
.124 .30045 L
.128 .30044 L
.132 .30044 L
.136 .30043 L
.14 .30043 L
.144 .30042 L
.148 .30042 L
.152 .30041 L
.156 .30041 L
.16 .30041 L
.164 .30041 L
.168 .30041 L
.172 .30041 L
.176 .30042 L
.18 .30043 L
.184 .30045 L
.188 .30048 L
.192 .30052 L
.196 .30058 L
.2 .30066 L
Mistroke
.204 .30078 L
.208 .30095 L
.212 .30117 L
.216 .30145 L
.22 .30184 L
.224 .30234 L
.228 .30299 L
.232 .30382 L
.236 .30489 L
.24 .30623 L
.244 .30791 L
.248 .30998 L
.252 .3125 L
.256 .31556 L
.26 .31923 L
.264 .32356 L
.268 .32861 L
.272 .33443 L
.276 .34106 L
.28 .34848 L
.284 .35664 L
.288 .36548 L
.292 .37488 L
.296 .38467 L
.3 .39459 L
.304 .40438 L
.308 .41373 L
.312 .4223 L
.316 .42974 L
.32 .43568 L
.324 .43984 L
.328 .44202 L
.332 .44209 L
.336 .44002 L
.34 .43597 L
.344 .43024 L
.348 .42331 L
.352 .41571 L
.356 .40807 L
.36 .40106 L
.364 .39536 L
.368 .39148 L
.372 .38974 L
.376 .39023 L
.38 .39281 L
.384 .3971 L
.388 .40241 L
.392 .40789 L
.396 .41263 L
.4 .41582 L
Mistroke
.404 .4168 L
.408 .41513 L
.412 .41069 L
.416 .40378 L
.42 .39503 L
.424 .38529 L
.428 .37545 L
.432 .36629 L
.436 .35844 L
.44 .3522 L
.444 .34741 L
.448 .34349 L
.452 .33959 L
.456 .33485 L
.46 .3286 L
.464 .3204 L
.468 .3103 L
.472 .29887 L
.476 .28725 L
.48 .27689 L
.484 .26918 L
.488 .26516 L
.492 .26538 L
.496 .26979 L
.5 .27765 L
.504 .28759 L
.508 .29791 L
.512 .30698 L
.516 .31364 L
.52 .31735 L
.524 .31815 L
.528 .31655 L
.532 .31343 L
.536 .30976 L
.54 .30633 L
.544 .3035 L
.548 .30111 L
.552 .29882 L
.556 .29638 L
.56 .29383 L
.564 .29157 L
.568 .2902 L
.572 .29036 L
.576 .29258 L
.58 .29694 L
.584 .30283 L
.588 .30893 L
.592 .31353 L
.596 .31516 L
.6 .31316 L
Mistroke
.604 .30793 L
.608 .3008 L
.612 .29369 L
.616 .28855 L
.62 .28692 L
.624 .28935 L
.628 .29514 L
.632 .3024 L
.636 .30873 L
.64 .31214 L
.644 .31182 L
.648 .30825 L
.652 .30288 L
.656 .29749 L
.66 .29366 L
.664 .29242 L
.668 .29397 L
.672 .29759 L
.676 .30181 L
.68 .305 L
.684 .30618 L
.688 .30541 L
.692 .30355 L
.696 .30156 L
.7 .29994 L
.704 .29871 L
.708 .2979 L
.712 .29772 L
.716 .29846 L
.72 .30002 L
.724 .30182 L
.728 .30315 L
.732 .30367 L
.736 .30343 L
.74 .30261 L
.744 .30122 L
.748 .29929 L
.752 .29735 L
.756 .2965 L
.76 .29774 L
.764 .30092 L
.768 .30447 L
.772 .30622 L
.776 .30498 L
.78 .30148 L
.784 .29781 L
.788 .29604 L
.792 .29683 L
.796 .29929 L
.8 .302 L
Mistroke
.804 .30385 L
.808 .30439 L
.812 .30361 L
.816 .30157 L
.82 .29886 L
.824 .2967 L
.828 .29648 L
.832 .29893 L
.836 .30282 L
.84 .30568 L
.844 .30548 L
.848 .30201 L
.852 .29772 L
.856 .29563 L
.86 .29708 L
.864 .30101 L
.868 .30432 L
.872 .30472 L
.876 .30239 L
.88 .29924 L
.884 .29779 L
.888 .29878 L
.892 .3008 L
.896 .30223 L
.9 .30203 L
.904 .30078 L
.908 .30006 L
.912 .30029 L
.916 .3011 L
.92 .3015 L
.924 .30073 L
.928 .29967 L
.932 .29937 L
.936 .30022 L
.94 .30186 L
.944 .30268 L
.948 .30193 L
.952 .30014 L
.956 .2985 L
.96 .29855 L
.964 .30025 L
.968 .30227 L
.972 .30329 L
.976 .30224 L
.98 .30009 L
.984 .29843 L
.988 .29818 L
.992 .29993 L
.996 .30208 L
1 .30299 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .50566 m
.008 .51049 L
.012 .5122 L
.016 .51068 L
.02 .5101 L
.024 .51053 L
.028 .51077 L
.032 .51061 L
.036 .51055 L
.04 .51057 L
.044 .51062 L
.048 .51059 L
.052 .5106 L
.056 .51059 L
.06 .5106 L
.064 .51059 L
.068 .5106 L
.072 .51059 L
.076 .5106 L
.08 .51059 L
.084 .5106 L
.088 .51059 L
.092 .5106 L
.096 .51059 L
.1 .5106 L
.104 .51059 L
.108 .5106 L
.112 .51059 L
.116 .5106 L
.12 .51059 L
.124 .5106 L
.128 .51059 L
.132 .5106 L
.136 .51059 L
.14 .5106 L
.144 .51059 L
.148 .5106 L
.152 .51059 L
.156 .51059 L
.16 .51059 L
.164 .51059 L
.168 .51059 L
.172 .51059 L
.176 .51059 L
.18 .51059 L
.184 .51059 L
.188 .51059 L
.192 .51058 L
.196 .51058 L
.2 .51057 L
Mistroke
.204 .51057 L
.208 .51056 L
.212 .51055 L
.216 .51053 L
.22 .5105 L
.224 .51047 L
.228 .51043 L
.232 .51037 L
.236 .5103 L
.24 .51021 L
.244 .51009 L
.248 .50993 L
.252 .50974 L
.256 .5095 L
.26 .5092 L
.264 .50883 L
.268 .50837 L
.272 .50783 L
.276 .50717 L
.28 .5064 L
.284 .50549 L
.288 .50444 L
.292 .50323 L
.296 .50186 L
.3 .50031 L
.304 .4986 L
.308 .49673 L
.312 .49471 L
.316 .49254 L
.32 .49027 L
.324 .4879 L
.328 .48548 L
.332 .48303 L
.336 .4806 L
.34 .47821 L
.344 .47589 L
.348 .47368 L
.352 .47157 L
.356 .46959 L
.36 .46772 L
.364 .46595 L
.368 .46425 L
.372 .46259 L
.376 .46095 L
.38 .45927 L
.384 .45754 L
.388 .45574 L
.392 .45384 L
.396 .45187 L
.4 .44984 L
Mistroke
.404 .44777 L
.408 .44571 L
.412 .44371 L
.416 .44179 L
.42 .44 L
.424 .43836 L
.428 .43689 L
.432 .43557 L
.436 .4344 L
.44 .43336 L
.444 .43243 L
.448 .43159 L
.452 .43084 L
.456 .43019 L
.46 .42966 L
.464 .42926 L
.468 .42904 L
.472 .429 L
.476 .42916 L
.48 .42951 L
.484 .43 L
.488 .4306 L
.492 .43122 L
.496 .43181 L
.5 .43231 L
.504 .43266 L
.508 .43284 L
.512 .43286 L
.516 .43274 L
.52 .43252 L
.524 .43225 L
.528 .43197 L
.532 .43172 L
.536 .43152 L
.54 .43138 L
.544 .4313 L
.548 .43128 L
.552 .43132 L
.556 .4314 L
.56 .43154 L
.564 .43172 L
.568 .43191 L
.572 .43211 L
.576 .43228 L
.58 .43238 L
.584 .43239 L
.588 .43231 L
.592 .43215 L
.596 .43195 L
.6 .43175 L
Mistroke
.604 .43162 L
.608 .43158 L
.612 .43165 L
.616 .43182 L
.62 .43203 L
.624 .43225 L
.628 .43239 L
.632 .43245 L
.636 .4324 L
.64 .43227 L
.644 .43211 L
.648 .43198 L
.652 .43191 L
.656 .43192 L
.66 .43201 L
.664 .43214 L
.668 .43227 L
.672 .43237 L
.676 .43242 L
.68 .43241 L
.684 .43235 L
.688 .43229 L
.692 .43223 L
.696 .4322 L
.7 .43221 L
.704 .43224 L
.708 .4323 L
.712 .43238 L
.716 .43244 L
.72 .43248 L
.724 .43249 L
.728 .43247 L
.732 .43244 L
.736 .4324 L
.74 .43238 L
.744 .43238 L
.748 .43241 L
.752 .43247 L
.756 .43255 L
.76 .43261 L
.764 .43263 L
.768 .43261 L
.772 .43256 L
.776 .43251 L
.78 .4325 L
.784 .43253 L
.788 .43259 L
.792 .43266 L
.796 .43271 L
.8 .43273 L
Mistroke
.804 .43272 L
.808 .43268 L
.812 .43265 L
.816 .43264 L
.82 .43266 L
.824 .43272 L
.828 .43279 L
.832 .43284 L
.836 .43285 L
.84 .43282 L
.844 .43277 L
.848 .43275 L
.852 .43277 L
.856 .43283 L
.86 .43289 L
.864 .43293 L
.868 .43293 L
.872 .4329 L
.876 .43288 L
.88 .43288 L
.884 .43291 L
.888 .43296 L
.892 .43298 L
.896 .433 L
.9 .433 L
.904 .43301 L
.908 .43301 L
.912 .43303 L
.916 .43304 L
.92 .43305 L
.924 .43306 L
.928 .43309 L
.932 .43311 L
.936 .43314 L
.94 .43314 L
.944 .43314 L
.948 .43313 L
.952 .43314 L
.956 .43316 L
.96 .43321 L
.964 .43323 L
.968 .43325 L
.972 .43323 L
.976 .43322 L
.98 .43322 L
.984 .43326 L
.988 .43329 L
.992 .43334 L
.996 .43333 L
1 .43335 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42708 L
.012 .43001 L
.016 .43086 L
.02 .42967 L
.024 .4294 L
.028 .42973 L
.032 .42979 L
.036 .42958 L
.04 .42953 L
.044 .42952 L
.048 .42951 L
.052 .42943 L
.056 .4294 L
.06 .42934 L
.064 .42932 L
.068 .42926 L
.072 .42922 L
.076 .42917 L
.08 .42914 L
.084 .42908 L
.088 .42905 L
.092 .429 L
.096 .42896 L
.1 .42891 L
.104 .42887 L
.108 .42883 L
.112 .42879 L
.116 .42874 L
.12 .4287 L
.124 .42865 L
.128 .42861 L
.132 .42857 L
.136 .42853 L
.14 .42848 L
.144 .42844 L
.148 .42839 L
.152 .42835 L
.156 .42831 L
.16 .42826 L
.164 .42822 L
.168 .42818 L
.172 .42813 L
.176 .42809 L
.18 .42805 L
.184 .42801 L
.188 .42797 L
.192 .42793 L
.196 .42789 L
.2 .42785 L
Mistroke
.204 .42781 L
.208 .42778 L
.212 .42776 L
.216 .42774 L
.22 .42772 L
.224 .42772 L
.228 .42773 L
.232 .42775 L
.236 .4278 L
.24 .42787 L
.244 .42798 L
.248 .42813 L
.252 .42832 L
.256 .42858 L
.26 .42891 L
.264 .42933 L
.268 .42985 L
.272 .43049 L
.276 .43126 L
.28 .43218 L
.284 .43327 L
.288 .43454 L
.292 .436 L
.296 .43767 L
.3 .43955 L
.304 .44164 L
.308 .44393 L
.312 .44641 L
.316 .44906 L
.32 .45186 L
.324 .45477 L
.328 .45775 L
.332 .46076 L
.336 .46376 L
.34 .4667 L
.344 .46954 L
.348 .47227 L
.352 .47486 L
.356 .47729 L
.36 .47959 L
.364 .48176 L
.368 .48385 L
.372 .48587 L
.376 .48789 L
.38 .48995 L
.384 .49207 L
.388 .49429 L
.392 .49661 L
.396 .49904 L
.4 .50154 L
Mistroke
.404 .50408 L
.408 .50662 L
.412 .50909 L
.416 .51145 L
.42 .51365 L
.424 .51566 L
.428 .51747 L
.432 .51909 L
.436 .52052 L
.44 .52178 L
.444 .52292 L
.448 .52393 L
.452 .52484 L
.456 .52562 L
.46 .52626 L
.464 .52673 L
.468 .52698 L
.472 .527 L
.476 .52678 L
.48 .52632 L
.484 .52568 L
.488 .52491 L
.492 .5241 L
.496 .52334 L
.5 .52269 L
.504 .52223 L
.508 .52198 L
.512 .52192 L
.516 .52204 L
.52 .52229 L
.524 .5226 L
.528 .52291 L
.532 .5232 L
.536 .52342 L
.54 .52357 L
.544 .52364 L
.548 .52364 L
.552 .52357 L
.556 .52343 L
.56 .52324 L
.564 .52299 L
.568 .52272 L
.572 .52244 L
.576 .52221 L
.58 .52205 L
.584 .52201 L
.588 .52208 L
.592 .52226 L
.596 .52248 L
.6 .5227 L
Mistroke
.604 .52284 L
.608 .52286 L
.612 .52274 L
.616 .5225 L
.62 .52221 L
.624 .52192 L
.628 .52171 L
.632 .52161 L
.636 .52164 L
.64 .52177 L
.644 .52194 L
.648 .52208 L
.652 .52214 L
.656 .5221 L
.66 .52196 L
.664 .52177 L
.668 .52158 L
.672 .52143 L
.676 .52134 L
.68 .52133 L
.684 .52136 L
.688 .52142 L
.692 .52147 L
.696 .52148 L
.7 .52144 L
.704 .52136 L
.708 .52126 L
.712 .52115 L
.716 .52105 L
.72 .52097 L
.724 .52092 L
.728 .52091 L
.732 .52092 L
.736 .52095 L
.74 .52096 L
.744 .52092 L
.748 .52085 L
.752 .52074 L
.756 .52062 L
.76 .52053 L
.764 .52048 L
.768 .52047 L
.772 .52049 L
.776 .52052 L
.78 .52051 L
.784 .52047 L
.788 .52037 L
.792 .52024 L
.796 .52013 L
.8 .52007 L
Mistroke
.804 .52007 L
.808 .52011 L
.812 .52014 L
.816 .52011 L
.82 .52003 L
.824 .51992 L
.828 .51981 L
.832 .51975 L
.836 .51973 L
.84 .51973 L
.844 .51973 L
.848 .51971 L
.852 .51966 L
.856 .51959 L
.86 .51951 L
.864 .51943 L
.868 .51937 L
.872 .51935 L
.876 .51934 L
.88 .51934 L
.884 .51931 L
.888 .51925 L
.892 .51915 L
.896 .51907 L
.9 .51901 L
.904 .51901 L
.908 .51901 L
.912 .519 L
.916 .51894 L
.92 .51886 L
.924 .51876 L
.928 .51871 L
.932 .51869 L
.936 .51869 L
.94 .51867 L
.944 .51862 L
.948 .51854 L
.952 .51847 L
.956 .5184 L
.96 .5184 L
.964 .51837 L
.968 .51836 L
.972 .51829 L
.976 .51823 L
.98 .51815 L
.984 .51812 L
.988 .51807 L
.992 .51808 L
.996 .51802 L
1 .51799 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00H007ooOol007oo0002Ool20003Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006Ool0
1000Oomoo`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool2000017oo
000000000Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=o
o`8000Ioo`008Woo00<007ooOol0;7oo00<007oo00002goo00<007ooOol0;goo000ROol2000]Ool0
1000Oomoo`000goo10000Woo0P000Woo0`000Woo0P000Woo0P000Woo00<007ooOol00P0000Eoo`00
001oo`0000Ioo`800003Ool007oo00eoo`008WooH`0037oo000ROol01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool200000goo001oo`02Ool01@00Oomoogoo00000goo
00D007ooOomoo`00009oo`80009oo`<0009oo`03001oogoo0080009oo`80009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomo
o`0:Ool0029oo`8001Qoo`03001oogoo011oo`03001oogoo03moo`008Woo00<007ooOol067oo00<0
07ooOol03Woo0P00@Goo000ROol2000IOol00`00Oomoo`0=Ool20012Ool0029oo`8001Yoo`03001o
ogoo00aoo`03001oogoo045oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007oo
Ool06Goo00<007ooOol02goo00<007ooOol0@Woo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8001]oo`03001oogoo00Yoo`03001oogoo049oo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2000KOol00`00Oomoo`04Ool20003Ool00`00Oomoo`13
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol06Woo00<0
07ooOol00goo10000Woo00<007ooOol0@goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8001aoo`03001oogoo009oo`05001oogoo001oo`020015Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo0P0017oo0P0077oo00D007ooOomoo`0000Aoo`8004Ioo`002goo0P00
2Woo0P0017oo00<007ooOol00Woo00<007ooOol077oo00@007ooOol004aoo`002goo0P0017oo00<0
07ooOol00goo0P000Woo1@000Woo0P007Goo0`00CGoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2
001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo
0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03
001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006io
o`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`00
8Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@0
07ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
2Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03
001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Ao
o`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Ao
o`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<0
07ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Ao
o`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo
10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@0
07ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007oo
Ool017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<0
07ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool0
0`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P00
17oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
G@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool0
0`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool0
0`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo02EoocD000aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo02=oo`<0041oo`002goo0P00
2Woo0P0017oo0P000Woo1@000Woo00<007ooOol08Goo0P00@goo000XOol00`00Oomoo`0NOol40014
Ool002Qoo`03001oogoo01eoo`8004Moo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo
00<007ooOol06goo0P00BGoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo01Uoo`8004]oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Ool0000COol7001<Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo5`00DWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`80
00Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo
0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol0
0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eo
o`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool0
0`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`80
00Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Ao
o`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yo
o`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00
Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=o
o`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo
00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<0
07ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol0
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomo
o`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo
00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001o
ogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@0
07ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo
00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001o
ogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol0
0goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009o
o`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`00
77oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03
001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007
Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]o
o`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`00
5goo00<007ooOol00Woo7`00EWoo000GOol00`00Oomoo`02Ool00`00Oomoo`0KOol3001DOol001Mo
o`03001oogoo009oo`03001oogoo01eoo`8005=oo`005Woo0P0017oo0P0087oo0P00DGoo000GOol0
0`00Oomoo`02Ool00`00Oomoo`0POol2001@Ool001aoo`03001oogoo029oo`8004ioo`0077oo0P00
97oo0`00C7oo000LOol00`00Oomoo`0UOol3001:Ool001aoo`8002Qoo`8004Uoo`0077oo00<007oo
Ool0:Goo0P0067oo0P0000=oo`0000007P0037oo000LOol00`00Oomoo`0[OolH0002Ool00`00Oomo
o`0ZOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo
00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1b
Ool000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(10688\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29888 m
.008 .30042 L
.012 .30113 L
.016 .30122 L
.02 .30055 L
.024 .30028 L
.028 .30061 L
.032 .30078 L
.036 .30064 L
.04 .30054 L
.044 .30058 L
.048 .30062 L
.052 .3006 L
.056 .30057 L
.06 .30057 L
.064 .30057 L
.068 .30057 L
.072 .30056 L
.076 .30055 L
.08 .30055 L
.084 .30054 L
.088 .30054 L
.092 .30053 L
.096 .30052 L
.1 .30052 L
.104 .30051 L
.108 .30051 L
.112 .3005 L
.116 .3005 L
.12 .30049 L
.124 .30049 L
.128 .30048 L
.132 .30048 L
.136 .30048 L
.14 .30048 L
.144 .30048 L
.148 .30049 L
.152 .3005 L
.156 .30052 L
.16 .30055 L
.164 .30059 L
.168 .30064 L
.172 .30073 L
.176 .30084 L
.18 .30099 L
.184 .3012 L
.188 .30148 L
.192 .30185 L
.196 .30233 L
.2 .30294 L
Mistroke
.204 .30375 L
.208 .30477 L
.212 .30605 L
.216 .30766 L
.22 .30964 L
.224 .31208 L
.228 .31504 L
.232 .31857 L
.236 .32276 L
.24 .32766 L
.244 .33333 L
.248 .33979 L
.252 .34705 L
.256 .35508 L
.26 .36383 L
.264 .37317 L
.268 .38294 L
.272 .39293 L
.276 .40289 L
.28 .41252 L
.284 .42146 L
.288 .42936 L
.292 .43589 L
.296 .44075 L
.3 .44366 L
.304 .44445 L
.308 .44311 L
.312 .43972 L
.316 .43454 L
.32 .42792 L
.324 .42041 L
.328 .41263 L
.332 .40527 L
.336 .39894 L
.34 .39422 L
.344 .39155 L
.348 .39113 L
.352 .39293 L
.356 .39659 L
.36 .40154 L
.364 .40706 L
.368 .41225 L
.372 .41623 L
.376 .41819 L
.38 .41761 L
.384 .41428 L
.388 .40832 L
.392 .40016 L
.396 .39052 L
.4 .38033 L
Mistroke
.404 .37051 L
.408 .36178 L
.412 .35454 L
.416 .34882 L
.42 .34432 L
.424 .34038 L
.428 .3361 L
.432 .33062 L
.436 .32336 L
.44 .31417 L
.444 .30342 L
.448 .29194 L
.452 .28092 L
.456 .27182 L
.46 .26596 L
.464 .26423 L
.468 .26686 L
.472 .27334 L
.476 .2826 L
.48 .29317 L
.484 .30337 L
.488 .31167 L
.492 .31704 L
.496 .31919 L
.5 .31849 L
.504 .31574 L
.508 .3119 L
.512 .30785 L
.516 .30426 L
.52 .30139 L
.524 .29912 L
.528 .29705 L
.532 .29491 L
.536 .29276 L
.54 .29109 L
.544 .29054 L
.548 .29171 L
.552 .29486 L
.556 .29976 L
.56 .3056 L
.564 .31104 L
.568 .31449 L
.572 .31472 L
.576 .31137 L
.58 .30518 L
.584 .2978 L
.588 .29126 L
.592 .28741 L
.596 .28736 L
.6 .29118 L
Mistroke
.604 .29773 L
.608 .305 L
.612 .31066 L
.616 .31296 L
.62 .31139 L
.624 .30677 L
.628 .30085 L
.632 .2956 L
.636 .29253 L
.64 .29235 L
.644 .29484 L
.648 .29896 L
.652 .30318 L
.656 .30604 L
.66 .30674 L
.664 .30544 L
.668 .30306 L
.672 .30067 L
.676 .29894 L
.68 .29801 L
.684 .29777 L
.688 .29818 L
.692 .29923 L
.696 .30077 L
.7 .30236 L
.704 .30346 L
.708 .30376 L
.712 .30326 L
.716 .30212 L
.72 .30051 L
.724 .2987 L
.728 .29728 L
.732 .29708 L
.736 .2987 L
.74 .30173 L
.744 .3047 L
.748 .30586 L
.752 .30439 L
.756 .30108 L
.76 .29777 L
.764 .29621 L
.768 .29699 L
.772 .29939 L
.776 .3022 L
.78 .30426 L
.784 .30486 L
.788 .30375 L
.792 .30115 L
.796 .29809 L
.8 .29618 L
Mistroke
.804 .29674 L
.808 .29988 L
.812 .30378 L
.816 .30591 L
.82 .30477 L
.824 .30105 L
.828 .29739 L
.832 .29627 L
.836 .29816 L
.84 .30151 L
.844 .30379 L
.848 .30368 L
.852 .30189 L
.856 .29994 L
.86 .29918 L
.864 .2996 L
.868 .30024 L
.872 .30065 L
.876 .30086 L
.88 .30124 L
.884 .30194 L
.888 .3021 L
.892 .30125 L
.896 .29971 L
.9 .29851 L
.904 .29896 L
.908 .30093 L
.912 .30293 L
.916 .30347 L
.92 .30183 L
.924 .29925 L
.928 .29782 L
.932 .29858 L
.936 .30107 L
.94 .30328 L
.944 .30342 L
.948 .30156 L
.952 .29904 L
.956 .29793 L
.96 .29905 L
.964 .30128 L
.968 .3031 L
.972 .30299 L
.976 .30108 L
.98 .29919 L
.984 .29832 L
.988 .29926 L
.992 .30144 L
.996 .30263 L
1 .30261 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51378 m
.008 .51024 L
.012 .50918 L
.016 .51048 L
.02 .51082 L
.024 .5103 L
.028 .51023 L
.032 .51039 L
.036 .51044 L
.04 .51036 L
.044 .51036 L
.048 .51037 L
.052 .51039 L
.056 .51037 L
.06 .51038 L
.064 .51037 L
.068 .51038 L
.072 .51037 L
.076 .51038 L
.08 .51037 L
.084 .51038 L
.088 .51037 L
.092 .51038 L
.096 .51037 L
.1 .51038 L
.104 .51037 L
.108 .51038 L
.112 .51037 L
.116 .51038 L
.12 .51037 L
.124 .51038 L
.128 .51037 L
.132 .51038 L
.136 .51037 L
.14 .51038 L
.144 .51037 L
.148 .51037 L
.152 .51037 L
.156 .51037 L
.16 .51037 L
.164 .51037 L
.168 .51036 L
.172 .51036 L
.176 .51035 L
.18 .51034 L
.184 .51033 L
.188 .51031 L
.192 .51029 L
.196 .51026 L
.2 .51022 L
Mistroke
.204 .51017 L
.208 .5101 L
.212 .51001 L
.216 .5099 L
.22 .50975 L
.224 .50957 L
.228 .50934 L
.232 .50905 L
.236 .5087 L
.24 .50827 L
.244 .50775 L
.248 .50713 L
.252 .50639 L
.256 .50553 L
.26 .50452 L
.264 .50336 L
.268 .50203 L
.272 .50054 L
.276 .49889 L
.28 .49707 L
.284 .49509 L
.288 .49298 L
.292 .49074 L
.296 .4884 L
.3 .486 L
.304 .48356 L
.308 .48112 L
.312 .47872 L
.316 .47638 L
.32 .47412 L
.324 .47198 L
.328 .46995 L
.332 .46804 L
.336 .46624 L
.34 .46451 L
.344 .46285 L
.348 .4612 L
.352 .45955 L
.356 .45784 L
.36 .45608 L
.364 .45423 L
.368 .45229 L
.372 .45029 L
.376 .44824 L
.38 .44619 L
.384 .44416 L
.388 .44221 L
.392 .44037 L
.396 .43868 L
.4 .43715 L
Mistroke
.404 .43578 L
.408 .43456 L
.412 .43349 L
.416 .43253 L
.42 .43168 L
.424 .43093 L
.428 .43026 L
.432 .4297 L
.436 .42927 L
.44 .42899 L
.444 .42888 L
.448 .42896 L
.452 .42924 L
.456 .42967 L
.46 .43023 L
.464 .43085 L
.468 .43146 L
.472 .432 L
.476 .43242 L
.48 .43267 L
.484 .43276 L
.488 .4327 L
.492 .43251 L
.496 .43225 L
.5 .43196 L
.504 .43169 L
.508 .43146 L
.512 .43129 L
.516 .43119 L
.52 .43115 L
.524 .43117 L
.528 .43124 L
.532 .43136 L
.536 .43152 L
.54 .4317 L
.544 .4319 L
.548 .43207 L
.552 .4322 L
.556 .43226 L
.56 .43223 L
.564 .43211 L
.568 .43193 L
.572 .43173 L
.576 .43156 L
.58 .43147 L
.584 .43148 L
.588 .43159 L
.592 .43178 L
.596 .432 L
.6 .43219 L
Mistroke
.604 .4323 L
.608 .43232 L
.612 .43223 L
.616 .43209 L
.62 .43193 L
.624 .43182 L
.628 .43178 L
.632 .43182 L
.636 .43193 L
.64 .43206 L
.644 .43219 L
.648 .43228 L
.652 .4323 L
.656 .43227 L
.66 .43221 L
.664 .43214 L
.668 .43209 L
.672 .43207 L
.676 .43209 L
.68 .43214 L
.684 .43221 L
.688 .43228 L
.692 .43233 L
.696 .43236 L
.7 .43236 L
.704 .43234 L
.708 .4323 L
.712 .43227 L
.716 .43226 L
.72 .43227 L
.724 .43231 L
.728 .43237 L
.732 .43244 L
.736 .43249 L
.74 .4325 L
.744 .43248 L
.748 .43243 L
.752 .43239 L
.756 .43238 L
.76 .43242 L
.764 .43248 L
.768 .43255 L
.772 .4326 L
.776 .43261 L
.78 .43259 L
.784 .43256 L
.788 .43252 L
.792 .43252 L
.796 .43255 L
.8 .43261 L
Mistroke
.804 .43268 L
.808 .43272 L
.812 .43272 L
.816 .43269 L
.82 .43265 L
.824 .43263 L
.828 .43266 L
.832 .43272 L
.836 .43277 L
.84 .4328 L
.844 .4328 L
.848 .43279 L
.852 .43277 L
.856 .43277 L
.86 .43279 L
.864 .43282 L
.868 .43285 L
.872 .43288 L
.876 .43289 L
.88 .4329 L
.884 .4329 L
.888 .4329 L
.892 .4329 L
.896 .43292 L
.9 .43295 L
.904 .43299 L
.908 .43301 L
.912 .43301 L
.916 .43299 L
.92 .43299 L
.924 .433 L
.928 .43304 L
.932 .43308 L
.936 .43311 L
.94 .4331 L
.944 .4331 L
.948 .43308 L
.952 .4331 L
.956 .43313 L
.96 .43318 L
.964 .43319 L
.968 .4332 L
.972 .43318 L
.976 .43318 L
.98 .43319 L
.984 .43324 L
.988 .43326 L
.992 .4333 L
.996 .43328 L
1 .43329 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .4262 L
.012 .42973 L
.016 .43106 L
.02 .42985 L
.024 .42936 L
.028 .42964 L
.032 .4298 L
.036 .42962 L
.04 .42954 L
.044 .4295 L
.048 .4295 L
.052 .42943 L
.056 .4294 L
.06 .42934 L
.064 .42932 L
.068 .42926 L
.072 .42923 L
.076 .42917 L
.08 .42914 L
.084 .42909 L
.088 .42905 L
.092 .429 L
.096 .42896 L
.1 .42891 L
.104 .42888 L
.108 .42883 L
.112 .42879 L
.116 .42874 L
.12 .4287 L
.124 .42865 L
.128 .42861 L
.132 .42857 L
.136 .42853 L
.14 .42848 L
.144 .42844 L
.148 .4284 L
.152 .42836 L
.156 .42831 L
.16 .42827 L
.164 .42823 L
.168 .42819 L
.172 .42815 L
.176 .42812 L
.18 .42809 L
.184 .42806 L
.188 .42804 L
.192 .42802 L
.196 .42801 L
.2 .42802 L
Mistroke
.204 .42804 L
.208 .42808 L
.212 .42815 L
.216 .42825 L
.22 .42839 L
.224 .42857 L
.228 .42881 L
.232 .42912 L
.236 .42952 L
.24 .43001 L
.244 .43061 L
.248 .43134 L
.252 .43222 L
.256 .43326 L
.26 .43447 L
.264 .43588 L
.268 .43748 L
.272 .43929 L
.276 .44132 L
.28 .44354 L
.284 .44596 L
.288 .44856 L
.292 .45131 L
.296 .45418 L
.3 .45714 L
.304 .46014 L
.308 .46314 L
.312 .4661 L
.316 .46898 L
.32 .47175 L
.324 .47438 L
.328 .47687 L
.332 .47922 L
.336 .48144 L
.34 .48355 L
.344 .48559 L
.348 .48761 L
.352 .48964 L
.356 .49172 L
.36 .4939 L
.364 .49617 L
.368 .49855 L
.372 .50101 L
.376 .50353 L
.38 .50606 L
.384 .50856 L
.388 .51096 L
.392 .51321 L
.396 .5153 L
.4 .51718 L
Mistroke
.404 .51886 L
.408 .52035 L
.412 .52166 L
.416 .52282 L
.42 .52385 L
.424 .52477 L
.428 .52557 L
.432 .52624 L
.436 .52676 L
.44 .52708 L
.444 .52719 L
.448 .52705 L
.452 .52669 L
.456 .52612 L
.46 .5254 L
.464 .5246 L
.468 .52381 L
.472 .52311 L
.476 .52256 L
.48 .52221 L
.484 .52207 L
.488 .52213 L
.492 .52233 L
.496 .52263 L
.5 .52296 L
.504 .52328 L
.508 .52354 L
.512 .52372 L
.516 .52382 L
.52 .52384 L
.524 .52378 L
.528 .52367 L
.532 .52349 L
.536 .52327 L
.54 .52301 L
.544 .52274 L
.548 .5225 L
.552 .52231 L
.556 .52221 L
.56 .52222 L
.564 .52234 L
.568 .52253 L
.572 .52275 L
.576 .52294 L
.58 .52303 L
.584 .52299 L
.588 .52282 L
.592 .52256 L
.596 .52226 L
.6 .52199 L
Mistroke
.604 .52182 L
.608 .52178 L
.612 .52185 L
.616 .522 L
.62 .52217 L
.624 .52229 L
.628 .52231 L
.632 .52224 L
.636 .52207 L
.64 .52187 L
.644 .52168 L
.648 .52155 L
.652 .52149 L
.656 .5215 L
.66 .52155 L
.664 .52161 L
.668 .52165 L
.672 .52165 L
.676 .52159 L
.68 .5215 L
.684 .52138 L
.688 .52127 L
.692 .52118 L
.696 .52112 L
.7 .52109 L
.704 .52108 L
.708 .5211 L
.712 .52112 L
.716 .52111 L
.72 .52107 L
.724 .52098 L
.728 .52087 L
.732 .52076 L
.736 .52068 L
.74 .52064 L
.744 .52064 L
.748 .52066 L
.752 .52068 L
.756 .52067 L
.76 .52061 L
.764 .52051 L
.768 .52038 L
.772 .52028 L
.776 .52024 L
.78 .52024 L
.784 .52027 L
.788 .52029 L
.792 .52026 L
.796 .52018 L
.8 .52007 L
Mistroke
.804 .51997 L
.808 .51991 L
.812 .51988 L
.816 .51988 L
.82 .51988 L
.824 .51987 L
.828 .51982 L
.832 .51975 L
.836 .51965 L
.84 .51957 L
.844 .51952 L
.848 .51951 L
.852 .51952 L
.856 .51951 L
.86 .51946 L
.864 .51938 L
.868 .51929 L
.872 .51922 L
.876 .51918 L
.88 .51918 L
.884 .51917 L
.888 .51914 L
.892 .51907 L
.896 .519 L
.9 .51893 L
.904 .5189 L
.908 .51887 L
.912 .51884 L
.916 .51879 L
.92 .51874 L
.924 .51868 L
.928 .51865 L
.932 .5186 L
.936 .51857 L
.94 .51851 L
.944 .51847 L
.948 .51841 L
.952 .51838 L
.956 .51834 L
.96 .51832 L
.964 .51825 L
.968 .51821 L
.972 .51813 L
.976 .5181 L
.98 .51805 L
.984 .51805 L
.988 .518 L
.992 .51797 L
.996 .51787 L
1 .51784 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007oo000000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`<000Eoo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo02Uoo`04001oogoo000:Ool00`00Oomoo`0bOol0029oo`8002Yoo`04001oogoo0004Ool3
0002Ool00`00Ool00002Ool20002Ool20003Ool200000goo00000002Ool00`00Oomoo`020005Ool0
1P00Oomoo`00Ool0009oo`03001oogoo00aoo`008WooH`0037oo000ROol01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`06001oogooOol007oo0`000Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01000Oomoogoo1@000goo0P000Woo10000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo00Yoo`008Woo0P00
5Goo0P004Woo00<007ooOol0@Goo000ROol00`00Oomoo`0EOol00`00Oomoo`0?Ool00`00Oomoo`12
Ool0029oo`8001Moo`03001oogoo00eoo`03001oogoo04=oo`008Woo0P005goo00<007ooOol037oo
00<007ooOol0A7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0FOol0
0`00Oomoo`0<Ool00`00Oomoo`14Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P0067oo00<007ooOol02Woo00<007ooOol0AGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8001Qoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo04Eo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0HOol00`00
Oomoo`03Ool30002Ool00`00Oomoo`16Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P006Goo00<007ooOol00Woo00<007ooOol00P0000=oo`00Ool0Agoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8001Uoo`8000=oo`04001oogooOol30018Ool000]o
o`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo01Uoo`04001oogoo001?Ool000]oo`8000Ao
o`03001oogoo00=oo`80009oo`D0009oo`8001]oo`03001oo`0004moo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`000Woo0P006goo0P00D7oo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo
0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00
Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool0
00]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00
Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=o
o`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0
00=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000R
Ool00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003
Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]o
o`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool2
0004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo0003
Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool3
0004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool2
0003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007oo
Ool007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00
Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009o
o`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eo
o`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool0
02Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03
001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007oo
Ool0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol0
2Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=o
o`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol0
3goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`0SOolg000<
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0P
Ool30013Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo01ioo`<004Eoo`00:7oo
00<007ooOol077oo0`00Agoo000XOol00`00Oomoo`0JOol2001:Ool0015oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`03001oogoo01Uoo`8004]oo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`0FOol3001=Ool0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P0000=oo`00Ool03Goo2000Cgoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009ooa<005Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007oo
Ool0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo
00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol0
00Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`00
2goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004
Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004
Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001o
ogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`00
0goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03
001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo
0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo
00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Ao
o`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D0
00=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004
Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007oo
Ool02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00
M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<0
07ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomo
o`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009ooa`005Uoo`005goo00<007ooOol00Woo00<0
07ooOol067oo0`00Egoo000GOol00`00Oomoo`02Ool00`00Oomoo`0KOol00`00Oomoo`1DOol001Io
o`8000Aoo`8001eoo`8005Aoo`005goo00<007ooOol00Woo00<007ooOol07Goo0P00Dgoo000LOol0
0`00Oomoo`0OOol2001AOol001aoo`80025oo`<004moo`0077oo00<007ooOol08Woo0`00CGoo000L
Ool2000UOol2001<Ool001aoo`03001oogoo02Ioo`8001aoob8000aoo`0077oo00<007ooOol0:7oo
7000;Woo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]o
o`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0
LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009o
o`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(10855\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30185 m
.008 .30155 L
.012 .3002 L
.016 .30001 L
.02 .30091 L
.024 .30103 L
.028 .30054 L
.032 .30047 L
.036 .3007 L
.04 .30072 L
.044 .30061 L
.048 .30059 L
.052 .30063 L
.056 .30063 L
.06 .30061 L
.064 .3006 L
.068 .3006 L
.072 .3006 L
.076 .30059 L
.08 .30058 L
.084 .30058 L
.088 .30057 L
.092 .30057 L
.096 .30056 L
.1 .30056 L
.104 .30055 L
.108 .30055 L
.112 .30055 L
.116 .30056 L
.12 .30056 L
.124 .30057 L
.128 .30059 L
.132 .30062 L
.136 .30065 L
.14 .30071 L
.144 .30079 L
.148 .3009 L
.152 .30104 L
.156 .30124 L
.16 .30151 L
.164 .30186 L
.168 .30231 L
.172 .30291 L
.176 .30367 L
.18 .30465 L
.184 .30588 L
.188 .30742 L
.192 .30933 L
.196 .31168 L
.2 .31452 L
Mistroke
.204 .31793 L
.208 .32198 L
.212 .32674 L
.216 .33225 L
.22 .33855 L
.224 .34565 L
.228 .35355 L
.232 .36217 L
.236 .37143 L
.24 .38118 L
.244 .39123 L
.248 .40132 L
.252 .41117 L
.256 .42044 L
.26 .42881 L
.264 .4359 L
.268 .44139 L
.272 .445 L
.276 .44656 L
.28 .44597 L
.284 .44326 L
.288 .43863 L
.292 .43243 L
.296 .42513 L
.3 .41732 L
.304 .40964 L
.308 .40276 L
.312 .39731 L
.316 .39377 L
.32 .39242 L
.324 .39331 L
.328 .39626 L
.332 .40079 L
.336 .4062 L
.34 .41164 L
.344 .41621 L
.348 .4191 L
.352 .41965 L
.356 .41746 L
.36 .41248 L
.364 .40504 L
.368 .39578 L
.372 .38554 L
.376 .37519 L
.38 .36558 L
.384 .35733 L
.388 .3507 L
.392 .3455 L
.396 .34119 L
.4 .33701 L
Mistroke
.404 .33214 L
.408 .32583 L
.412 .31764 L
.416 .30765 L
.42 .29648 L
.424 .28523 L
.428 .27521 L
.432 .26778 L
.436 .26405 L
.44 .26465 L
.444 .26951 L
.448 .27784 L
.452 .28822 L
.456 .29901 L
.46 .30862 L
.464 .31575 L
.468 .31965 L
.472 .32024 L
.476 .31811 L
.48 .31429 L
.484 .30985 L
.488 .30562 L
.492 .30209 L
.496 .29935 L
.5 .29725 L
.504 .29546 L
.508 .29374 L
.512 .29215 L
.516 .29115 L
.52 .29141 L
.524 .29345 L
.528 .29735 L
.532 .30258 L
.536 .30814 L
.54 .31266 L
.544 .3148 L
.548 .31363 L
.552 .30911 L
.556 .30227 L
.56 .29496 L
.564 .28927 L
.568 .28685 L
.572 .28839 L
.576 .29345 L
.58 .30053 L
.584 .3075 L
.588 .31222 L
.592 .31326 L
.596 .31046 L
.6 .30496 L
Mistroke
.604 .29876 L
.608 .29388 L
.612 .29172 L
.616 .29263 L
.62 .29601 L
.624 .30052 L
.628 .3046 L
.632 .30697 L
.636 .30704 L
.64 .30516 L
.644 .30234 L
.648 .29971 L
.652 .29804 L
.656 .29749 L
.66 .29783 L
.664 .29876 L
.668 .30006 L
.672 .30154 L
.676 .30287 L
.68 .30368 L
.684 .3037 L
.688 .30292 L
.692 .30153 L
.696 .29986 L
.7 .2983 L
.704 .29741 L
.708 .29775 L
.712 .29959 L
.716 .30237 L
.72 .30482 L
.724 .30552 L
.728 .30389 L
.732 .3007 L
.736 .29763 L
.74 .29625 L
.744 .29715 L
.748 .29971 L
.752 .30267 L
.756 .30473 L
.76 .30507 L
.764 .3035 L
.768 .30056 L
.772 .29756 L
.776 .29613 L
.78 .29728 L
.784 .30062 L
.788 .30421 L
.792 .30576 L
.796 .30427 L
.8 .30071 L
Mistroke
.804 .29753 L
.808 .29674 L
.812 .2985 L
.816 .30137 L
.82 .30335 L
.824 .3035 L
.828 .30229 L
.832 .30072 L
.836 .29964 L
.84 .29922 L
.844 .2993 L
.848 .29999 L
.852 .30121 L
.856 .30249 L
.86 .30306 L
.864 .30212 L
.868 .30007 L
.872 .29835 L
.876 .29827 L
.88 .30018 L
.884 .30265 L
.888 .30368 L
.892 .30252 L
.896 .3 L
.9 .29819 L
.904 .29859 L
.908 .30067 L
.912 .30272 L
.916 .30303 L
.92 .30143 L
.924 .29949 L
.928 .2988 L
.932 .29987 L
.936 .30165 L
.94 .30244 L
.944 .30172 L
.948 .30018 L
.952 .2992 L
.956 .2998 L
.96 .30116 L
.964 .30215 L
.968 .30197 L
.972 .30051 L
.976 .29939 L
.98 .29951 L
.984 .30043 L
.988 .3019 L
.992 .30232 L
.996 .30119 L
1 .30019 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51574 m
.008 .51021 L
.012 .50836 L
.016 .51007 L
.02 .51076 L
.024 .51019 L
.028 .50998 L
.032 .51013 L
.036 .51023 L
.04 .51016 L
.044 .51015 L
.048 .51015 L
.052 .51017 L
.056 .51015 L
.06 .51016 L
.064 .51015 L
.068 .51016 L
.072 .51015 L
.076 .51016 L
.08 .51015 L
.084 .51016 L
.088 .51015 L
.092 .51016 L
.096 .51015 L
.1 .51016 L
.104 .51015 L
.108 .51016 L
.112 .51015 L
.116 .51016 L
.12 .51015 L
.124 .51016 L
.128 .51015 L
.132 .51015 L
.136 .51015 L
.14 .51015 L
.144 .51014 L
.148 .51014 L
.152 .51012 L
.156 .51011 L
.16 .5101 L
.164 .51008 L
.168 .51005 L
.172 .51001 L
.176 .50996 L
.18 .5099 L
.184 .50981 L
.188 .50971 L
.192 .50957 L
.196 .5094 L
.2 .50918 L
Mistroke
.204 .50891 L
.208 .50857 L
.212 .50817 L
.216 .50767 L
.22 .50708 L
.224 .50638 L
.228 .50555 L
.232 .50458 L
.236 .50347 L
.24 .50219 L
.244 .50076 L
.248 .49916 L
.252 .49739 L
.256 .49546 L
.26 .49339 L
.264 .4912 L
.268 .48889 L
.272 .48651 L
.276 .48409 L
.28 .48165 L
.284 .47923 L
.288 .47687 L
.292 .47458 L
.296 .4724 L
.3 .47033 L
.304 .46838 L
.308 .46654 L
.312 .46479 L
.316 .4631 L
.32 .46146 L
.324 .45981 L
.328 .45813 L
.332 .4564 L
.336 .45459 L
.34 .4527 L
.344 .45073 L
.348 .4487 L
.352 .44665 L
.356 .44462 L
.36 .44265 L
.364 .44077 L
.368 .43902 L
.372 .43743 L
.376 .436 L
.38 .43474 L
.384 .43362 L
.388 .43264 L
.392 .43177 L
.396 .431 L
.4 .43033 L
Mistroke
.404 .42975 L
.408 .42928 L
.412 .42895 L
.416 .42879 L
.42 .4288 L
.424 .429 L
.428 .42937 L
.432 .42988 L
.436 .43047 L
.44 .43109 L
.444 .43167 L
.448 .43215 L
.452 .43247 L
.456 .43264 L
.46 .43263 L
.464 .43249 L
.468 .43225 L
.472 .43196 L
.476 .43167 L
.48 .43141 L
.484 .43121 L
.488 .43108 L
.492 .43102 L
.496 .43103 L
.5 .43109 L
.504 .43119 L
.508 .43133 L
.512 .4315 L
.516 .43169 L
.52 .43187 L
.524 .43201 L
.528 .4321 L
.532 .43212 L
.536 .43204 L
.54 .4319 L
.544 .43171 L
.548 .43153 L
.552 .43139 L
.556 .43134 L
.56 .43139 L
.564 .43154 L
.568 .43175 L
.572 .43196 L
.576 .43212 L
.58 .4322 L
.584 .43217 L
.588 .43206 L
.592 .43191 L
.596 .43176 L
.6 .43167 L
Mistroke
.604 .43166 L
.608 .43172 L
.612 .43185 L
.616 .43199 L
.62 .43211 L
.624 .43218 L
.628 .43218 L
.632 .43213 L
.636 .43206 L
.64 .43199 L
.644 .43195 L
.648 .43195 L
.652 .43198 L
.656 .43204 L
.66 .43212 L
.664 .43218 L
.668 .43222 L
.672 .43224 L
.676 .43223 L
.68 .4322 L
.684 .43217 L
.688 .43214 L
.692 .43214 L
.696 .43216 L
.7 .43221 L
.704 .43227 L
.708 .43233 L
.712 .43237 L
.716 .43237 L
.72 .43234 L
.724 .4323 L
.728 .43227 L
.732 .43227 L
.736 .43231 L
.74 .43237 L
.744 .43244 L
.748 .43248 L
.752 .43249 L
.756 .43247 L
.76 .43243 L
.764 .4324 L
.768 .4324 L
.772 .43244 L
.776 .4325 L
.78 .43256 L
.784 .4326 L
.788 .43259 L
.792 .43256 L
.796 .43253 L
.8 .43252 L
Mistroke
.804 .43255 L
.808 .4326 L
.812 .43265 L
.816 .43268 L
.82 .43268 L
.824 .43267 L
.828 .43266 L
.832 .43265 L
.836 .43267 L
.84 .4327 L
.844 .43274 L
.848 .43277 L
.852 .43279 L
.856 .43279 L
.86 .43277 L
.864 .43276 L
.868 .43277 L
.872 .43281 L
.876 .43285 L
.88 .43288 L
.884 .43289 L
.888 .43288 L
.892 .43286 L
.896 .43287 L
.9 .4329 L
.904 .43294 L
.908 .43296 L
.912 .43298 L
.916 .43297 L
.92 .43297 L
.924 .43298 L
.928 .433 L
.932 .43303 L
.936 .43305 L
.94 .43305 L
.944 .43306 L
.948 .43306 L
.952 .43309 L
.956 .4331 L
.96 .43313 L
.964 .43313 L
.968 .43314 L
.972 .43314 L
.976 .43317 L
.98 .43318 L
.984 .43321 L
.988 .43321 L
.992 .43323 L
.996 .43321 L
1 .43325 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .4321 L
.012 .42967 L
.016 .42906 L
.02 .42989 L
.024 .43004 L
.028 .42963 L
.032 .42957 L
.036 .42962 L
.04 .42962 L
.044 .4295 L
.048 .42948 L
.052 .42943 L
.056 .42941 L
.06 .42934 L
.064 .42931 L
.068 .42926 L
.072 .42923 L
.076 .42917 L
.08 .42914 L
.084 .42909 L
.088 .42905 L
.092 .429 L
.096 .42896 L
.1 .42891 L
.104 .42888 L
.108 .42883 L
.112 .42879 L
.116 .42874 L
.12 .4287 L
.124 .42866 L
.128 .42862 L
.132 .42857 L
.136 .42854 L
.14 .42849 L
.144 .42846 L
.148 .42842 L
.152 .42839 L
.156 .42836 L
.16 .42834 L
.164 .42832 L
.168 .42831 L
.172 .42831 L
.176 .42833 L
.18 .42837 L
.184 .42843 L
.188 .42852 L
.192 .42865 L
.196 .42882 L
.2 .42905 L
Mistroke
.204 .42934 L
.208 .42971 L
.212 .43017 L
.216 .43075 L
.22 .43144 L
.224 .43228 L
.228 .43326 L
.232 .43443 L
.236 .43577 L
.24 .43732 L
.244 .43906 L
.248 .44102 L
.252 .44318 L
.256 .44553 L
.26 .44807 L
.264 .45077 L
.268 .4536 L
.272 .45653 L
.276 .45951 L
.28 .46251 L
.284 .46549 L
.288 .4684 L
.292 .47121 L
.296 .47389 L
.3 .47643 L
.304 .47883 L
.308 .48109 L
.312 .48324 L
.316 .4853 L
.32 .48732 L
.324 .48934 L
.328 .4914 L
.332 .49353 L
.336 .49575 L
.34 .49808 L
.344 .5005 L
.348 .50299 L
.352 .50551 L
.356 .50801 L
.36 .51045 L
.364 .51276 L
.368 .5149 L
.372 .51686 L
.376 .51861 L
.38 .52016 L
.384 .52152 L
.388 .52272 L
.392 .52377 L
.396 .5247 L
.4 .52552 L
Mistroke
.404 .52622 L
.408 .52677 L
.412 .52715 L
.416 .52733 L
.42 .52729 L
.424 .52702 L
.428 .52653 L
.432 .52587 L
.436 .5251 L
.44 .5243 L
.444 .52355 L
.448 .52293 L
.452 .52249 L
.456 .52226 L
.46 .52224 L
.464 .52239 L
.468 .52266 L
.472 .523 L
.476 .52333 L
.48 .52363 L
.484 .52385 L
.488 .52398 L
.492 .52403 L
.496 .524 L
.5 .5239 L
.504 .52374 L
.508 .52353 L
.512 .52329 L
.516 .52304 L
.52 .52279 L
.524 .52258 L
.528 .52244 L
.532 .52239 L
.536 .52245 L
.54 .5226 L
.544 .52281 L
.548 .52301 L
.552 .52316 L
.556 .52319 L
.56 .5231 L
.564 .52289 L
.568 .5226 L
.572 .52231 L
.576 .52208 L
.58 .52196 L
.584 .52197 L
.588 .52208 L
.592 .52224 L
.596 .52239 L
.6 .52248 L
Mistroke
.604 .52247 L
.608 .52236 L
.612 .52217 L
.616 .52197 L
.62 .52179 L
.624 .52168 L
.628 .52165 L
.632 .52168 L
.636 .52175 L
.64 .52181 L
.644 .52183 L
.648 .52181 L
.652 .52173 L
.656 .52163 L
.66 .52151 L
.664 .5214 L
.668 .52132 L
.672 .52127 L
.676 .52126 L
.68 .52126 L
.684 .52128 L
.688 .52129 L
.692 .52127 L
.696 .52121 L
.7 .52112 L
.704 .52101 L
.708 .52091 L
.712 .52084 L
.716 .52081 L
.72 .52081 L
.724 .52083 L
.728 .52084 L
.732 .52082 L
.736 .52075 L
.74 .52064 L
.744 .52053 L
.748 .52044 L
.752 .5204 L
.756 .52041 L
.76 .52044 L
.764 .52044 L
.768 .52041 L
.772 .52033 L
.776 .52022 L
.78 .52012 L
.784 .52006 L
.788 .52004 L
.792 .52004 L
.796 .52005 L
.8 .52003 L
Mistroke
.804 .51998 L
.808 .51989 L
.812 .5198 L
.816 .51972 L
.82 .51968 L
.824 .51967 L
.828 .51968 L
.832 .51967 L
.836 .51961 L
.84 .51953 L
.844 .51944 L
.848 .51938 L
.852 .51935 L
.856 .51934 L
.86 .51932 L
.864 .51928 L
.868 .51922 L
.872 .51916 L
.876 .5191 L
.88 .51906 L
.884 .51901 L
.888 .51898 L
.892 .51894 L
.896 .5189 L
.9 .51886 L
.904 .51882 L
.908 .51876 L
.912 .5187 L
.916 .51864 L
.92 .51861 L
.924 .51858 L
.928 .51856 L
.932 .51852 L
.936 .51846 L
.94 .51838 L
.944 .51833 L
.948 .51828 L
.952 .51828 L
.956 .51825 L
.96 .51822 L
.964 .51814 L
.968 .51808 L
.972 .518 L
.976 .51799 L
.98 .51796 L
.984 .51796 L
.988 .51789 L
.992 .51784 L
.996 .51774 L
1 .51771 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01@00
Oomoo`00Ool00P000Woo00<007ooOol00Woo0P000goo00<007ooOol017oo00@007ooOol0009oo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo
00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P000Woo10001Woo
00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`00
8Woo00<007ooOol09Woo00@007ooOol000Yoo`8003Ioo`008Woo0P009goo00@007ooOol000Aoo`@0
009oo`80009oo`<0009oo`80009oo`80009oo`800004Ool00000Ool20005Ool01000Oomoo`005Woo
000ROomS000<Ool0029oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00P00
0goo00@007ooOol000=oo`05001oogooOol00003Ool20002Ool01@00Ool007oo00000goo00<007oo
00000P0000Aoo`000000009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000037oo000ROol2000BOol2000BOol00`00
Oomoo`03Ool00`00Oomoo`0nOol0029oo`03001oogoo019oo`80011oo`8004Ioo`008Woo0P0057oo
00<007ooOol03Goo0P00Agoo000ROol2000DOol00`00Oomoo`0=Ool00`00Oomoo`16Ool000]oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo01Aoo`03001oogoo00]oo`03001oogoo
04Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000EOol00`00Oomo
o`0;Ool00`00Oomoo`17Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P005Woo00<007ooOol02Goo00<007ooOol0B7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo01Eoo`03001oogoo00Aoo`8000=oo`03001oogoo04Qoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000GOol00`00Oomoo`02Ool01000
Oomoo`000Woo00<007ooOol0B7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`80
01Moo`05001oogooOol00004Ool2001;Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001o
ogoo01Ioo`05001oogooOol0001AOol000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`80
01Qoo`04001oo`00001AOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009o
o`8001Uoo`80059oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]
Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:
Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0
029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00
0Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo
0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P00
0goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool0
1@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001o
ogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0
009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2
000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000
Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo1000
0goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000
Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
o`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=o
o`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool5
0003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qo
o`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo011o
o`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=o
o`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1@00Oomoo`00Ool010000goo00<007ooOol087oo>P0037oo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`001Woo00<007ooOol07Woo0`00AGoo000;Ool2000:Ool20004Ool2
0002Ool50002Ool00`00Oomoo`0LOol20018Ool002Qoo`03001oogoo01Yoo`8004Yoo`00:7oo00<0
07ooOol05goo0`00C7oo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0F
Ool2001>Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
57oo0`00Cgoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009ooaL0059oo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool3001VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo
1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo
001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
0`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0
3Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P00
17oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007oo
Ool000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo
011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool0
01aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002
Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomo
ogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000;Ool20004
Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000
Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Ioo`<000=oo`03001o
ogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02OolI001LOol0
01Moo`03001oogoo009oo`03001oogoo01Eoo`<005Yoo`005goo00<007ooOol00Woo00<007ooOol0
67oo0P00F7oo000FOol20004Ool2000JOol2001GOol001Moo`03001oogoo009oo`03001oogoo01]o
o`03001oogoo05Aoo`0077oo00<007ooOol077oo0P00E7oo000LOol2000NOol3001BOol001aoo`03
001oogoo021oo`80051oo`0077oo0P008Woo0P00Cgoo000LOol00`00Oomoo`0SOol2000MOolT000<
Ool001aoo`03001oogoo02Eooad0031oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo
000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;
Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo
00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;
Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(11022\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30271 m
.008 .30111 L
.012 .30014 L
.016 .30001 L
.02 .30083 L
.024 .30111 L
.028 .30068 L
.032 .30049 L
.036 .30066 L
.04 .30076 L
.044 .30068 L
.048 .30063 L
.052 .30065 L
.056 .30066 L
.06 .30065 L
.064 .30063 L
.068 .30063 L
.072 .30063 L
.076 .30063 L
.08 .30063 L
.084 .30063 L
.088 .30063 L
.092 .30064 L
.096 .30064 L
.1 .30066 L
.104 .30068 L
.108 .30072 L
.112 .30078 L
.116 .30085 L
.12 .30095 L
.124 .30109 L
.128 .30128 L
.132 .30153 L
.136 .30187 L
.14 .30231 L
.144 .30287 L
.148 .30361 L
.152 .30454 L
.156 .30572 L
.16 .3072 L
.164 .30903 L
.168 .31129 L
.172 .31402 L
.176 .31732 L
.18 .32124 L
.184 .32584 L
.188 .33119 L
.192 .33733 L
.196 .34428 L
.2 .35202 L
Mistroke
.204 .36051 L
.208 .36969 L
.212 .3794 L
.216 .38947 L
.22 .39966 L
.224 .40971 L
.228 .41929 L
.232 .42806 L
.236 .43567 L
.24 .44178 L
.244 .4461 L
.248 .4484 L
.252 .44856 L
.256 .44656 L
.26 .44256 L
.264 .43684 L
.268 .42982 L
.272 .42204 L
.276 .41417 L
.28 .40685 L
.284 .40073 L
.288 .39634 L
.292 .39406 L
.296 .39405 L
.3 .39622 L
.304 .40017 L
.308 .40531 L
.312 .41085 L
.316 .41591 L
.32 .4196 L
.324 .42117 L
.328 .42011 L
.332 .41624 L
.336 .40971 L
.34 .40099 L
.344 .39084 L
.348 .38018 L
.352 .3699 L
.356 .36072 L
.36 .35305 L
.364 .34696 L
.368 .34212 L
.372 .33787 L
.376 .33335 L
.38 .32775 L
.384 .32051 L
.388 .31146 L
.392 .30092 L
.396 .2897 L
.4 .27904 L
Mistroke
.404 .27033 L
.408 .26486 L
.412 .26348 L
.416 .26643 L
.42 .27333 L
.424 .2831 L
.428 .29418 L
.432 .30484 L
.436 .3135 L
.44 .31914 L
.444 .32136 L
.448 .3204 L
.452 .31703 L
.456 .31233 L
.46 .30744 L
.464 .30316 L
.468 .29985 L
.472 .29745 L
.476 .29565 L
.48 .29418 L
.484 .29291 L
.488 .29195 L
.492 .29172 L
.496 .29277 L
.5 .29552 L
.504 .29991 L
.508 .30524 L
.512 .31032 L
.516 .31377 L
.52 .31448 L
.524 .31193 L
.528 .30646 L
.532 .29932 L
.536 .29243 L
.54 .28782 L
.544 .28689 L
.548 .28995 L
.552 .29606 L
.556 .30341 L
.56 .30979 L
.564 .31334 L
.568 .31302 L
.572 .30906 L
.576 .30291 L
.58 .29668 L
.584 .2924 L
.588 .29126 L
.592 .29327 L
.596 .29744 L
.6 .3022 L
Mistroke
.604 .30599 L
.608 .30771 L
.612 .30707 L
.616 .3046 L
.62 .30143 L
.624 .29873 L
.628 .29727 L
.632 .29717 L
.636 .29807 L
.64 .29945 L
.644 .30094 L
.648 .3023 L
.652 .30332 L
.656 .30377 L
.66 .30347 L
.664 .30245 L
.668 .30093 L
.672 .29932 L
.676 .29808 L
.68 .29768 L
.684 .29846 L
.688 .30042 L
.692 .30293 L
.696 .30488 L
.7 .30516 L
.704 .30339 L
.708 .3003 L
.712 .29745 L
.716 .2963 L
.72 .29742 L
.724 .30017 L
.728 .3032 L
.732 .30511 L
.736 .30508 L
.74 .3031 L
.744 .3 L
.748 .29724 L
.752 .29628 L
.756 .29781 L
.76 .30116 L
.764 .30444 L
.768 .30563 L
.772 .304 L
.776 .30061 L
.78 .29766 L
.784 .2969 L
.788 .29852 L
.792 .30124 L
.796 .30331 L
.8 .30375 L
Mistroke
.804 .30275 L
.808 .30105 L
.812 .2995 L
.816 .29868 L
.82 .29884 L
.824 .30008 L
.828 .30189 L
.832 .30326 L
.836 .30326 L
.84 .30159 L
.844 .2993 L
.848 .29808 L
.852 .29885 L
.856 .30114 L
.86 .30314 L
.864 .30326 L
.868 .30157 L
.872 .29947 L
.876 .2987 L
.88 .29978 L
.884 .3015 L
.888 .30238 L
.892 .30177 L
.896 .30042 L
.9 .29976 L
.904 .3003 L
.908 .30136 L
.912 .30179 L
.916 .30104 L
.92 .29994 L
.924 .29966 L
.928 .30058 L
.932 .302 L
.936 .3024 L
.94 .3013 L
.944 .29964 L
.948 .29874 L
.952 .29973 L
.956 .30179 L
.96 .303 L
.964 .30254 L
.968 .30047 L
.972 .29844 L
.976 .29859 L
.98 .30039 L
.984 .30251 L
.988 .30357 L
.992 .30196 L
.996 .29947 L
1 .29837 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .5076 m
.008 .51006 L
.012 .51083 L
.016 .50979 L
.02 .50963 L
.024 .51 L
.028 .51007 L
.032 .5099 L
.036 .50991 L
.04 .50994 L
.044 .50996 L
.048 .50993 L
.052 .50994 L
.056 .50994 L
.06 .50995 L
.064 .50993 L
.068 .50994 L
.072 .50993 L
.076 .50994 L
.08 .50993 L
.084 .50994 L
.088 .50993 L
.092 .50994 L
.096 .50993 L
.1 .50994 L
.104 .50993 L
.108 .50993 L
.112 .50993 L
.116 .50993 L
.12 .50992 L
.124 .50991 L
.128 .5099 L
.132 .50988 L
.136 .50986 L
.14 .50984 L
.144 .5098 L
.148 .50976 L
.152 .50969 L
.156 .50962 L
.16 .50951 L
.164 .50938 L
.168 .50922 L
.172 .50902 L
.176 .50876 L
.18 .50844 L
.184 .50806 L
.188 .50759 L
.192 .50702 L
.196 .50635 L
.2 .50556 L
Mistroke
.204 .50463 L
.208 .50356 L
.212 .50234 L
.216 .50096 L
.22 .49941 L
.224 .49769 L
.228 .49582 L
.232 .4938 L
.236 .49164 L
.24 .48937 L
.244 .48702 L
.248 .48461 L
.252 .48217 L
.256 .47975 L
.26 .47737 L
.264 .47505 L
.268 .47284 L
.272 .47073 L
.276 .46873 L
.28 .46685 L
.284 .46507 L
.288 .46337 L
.292 .46171 L
.296 .46007 L
.3 .45841 L
.304 .45671 L
.308 .45493 L
.312 .45308 L
.316 .45115 L
.32 .44915 L
.324 .44712 L
.328 .44509 L
.332 .44309 L
.336 .44118 L
.34 .43938 L
.344 .43774 L
.348 .43625 L
.352 .43493 L
.356 .43377 L
.36 .43275 L
.364 .43186 L
.368 .43108 L
.372 .43039 L
.376 .42979 L
.38 .4293 L
.384 .42894 L
.388 .42872 L
.392 .42866 L
.396 .42879 L
.4 .42909 L
Mistroke
.404 .42954 L
.408 .4301 L
.412 .43072 L
.416 .43132 L
.42 .43184 L
.424 .43224 L
.428 .43248 L
.432 .43255 L
.436 .43246 L
.44 .43225 L
.444 .43197 L
.448 .43166 L
.452 .43138 L
.456 .43114 L
.46 .43098 L
.464 .4309 L
.468 .43088 L
.472 .43093 L
.476 .43102 L
.48 .43115 L
.484 .43131 L
.488 .43149 L
.492 .43166 L
.496 .43182 L
.5 .43193 L
.504 .43198 L
.508 .43195 L
.512 .43185 L
.516 .43169 L
.52 .4315 L
.524 .43134 L
.528 .43124 L
.532 .43123 L
.536 .43133 L
.54 .4315 L
.544 .43171 L
.548 .43191 L
.552 .43204 L
.556 .43207 L
.56 .43201 L
.564 .43188 L
.568 .43172 L
.572 .43159 L
.576 .43153 L
.58 .43154 L
.584 .43164 L
.588 .43178 L
.592 .43192 L
.596 .43202 L
.6 .43207 L
Mistroke
.604 .43205 L
.608 .43199 L
.612 .43191 L
.616 .43184 L
.62 .43181 L
.624 .43183 L
.628 .43188 L
.632 .43195 L
.636 .43202 L
.64 .43208 L
.644 .43211 L
.648 .43212 L
.652 .4321 L
.656 .43206 L
.66 .43203 L
.664 .43201 L
.668 .43202 L
.672 .43205 L
.676 .43211 L
.68 .43217 L
.684 .43222 L
.688 .43225 L
.692 .43224 L
.696 .43221 L
.7 .43217 L
.704 .43215 L
.708 .43216 L
.712 .4322 L
.716 .43226 L
.72 .43233 L
.724 .43236 L
.728 .43237 L
.732 .43234 L
.736 .4323 L
.74 .43228 L
.744 .43228 L
.748 .43233 L
.752 .43239 L
.756 .43245 L
.76 .43248 L
.764 .43247 L
.768 .43244 L
.772 .43241 L
.776 .4324 L
.78 .43243 L
.784 .43248 L
.788 .43253 L
.792 .43256 L
.796 .43257 L
.8 .43255 L
Mistroke
.804 .43254 L
.808 .43253 L
.812 .43255 L
.816 .43258 L
.82 .43262 L
.824 .43266 L
.828 .43267 L
.832 .43266 L
.836 .43265 L
.84 .43264 L
.844 .43266 L
.848 .4327 L
.852 .43273 L
.856 .43276 L
.86 .43276 L
.864 .43275 L
.868 .43275 L
.872 .43276 L
.876 .43279 L
.88 .43282 L
.884 .43284 L
.888 .43285 L
.892 .43285 L
.896 .43286 L
.9 .43287 L
.904 .43289 L
.908 .4329 L
.912 .43292 L
.916 .43293 L
.92 .43295 L
.924 .43296 L
.928 .43298 L
.932 .43298 L
.936 .43299 L
.94 .43299 L
.944 .43302 L
.948 .43304 L
.952 .43307 L
.956 .43307 L
.96 .43308 L
.964 .43307 L
.968 .43309 L
.972 .4331 L
.976 .43315 L
.98 .43316 L
.984 .43318 L
.988 .43316 L
.992 .43317 L
.996 .43316 L
1 .43321 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43407 L
.012 .42994 L
.016 .42849 L
.02 .42971 L
.024 .4302 L
.028 .42972 L
.032 .42952 L
.036 .42958 L
.04 .42963 L
.044 .42952 L
.048 .42947 L
.052 .42943 L
.056 .42941 L
.06 .42935 L
.064 .42931 L
.068 .42926 L
.072 .42923 L
.076 .42917 L
.08 .42914 L
.084 .42909 L
.088 .42905 L
.092 .429 L
.096 .42897 L
.1 .42892 L
.104 .42888 L
.108 .42884 L
.112 .4288 L
.116 .42876 L
.12 .42873 L
.124 .42869 L
.128 .42866 L
.132 .42864 L
.136 .42862 L
.14 .42861 L
.144 .42861 L
.148 .42862 L
.152 .42866 L
.156 .42871 L
.16 .4288 L
.164 .42891 L
.168 .42907 L
.172 .42928 L
.176 .42956 L
.18 .42991 L
.184 .43035 L
.188 .43089 L
.192 .43155 L
.196 .43234 L
.2 .43329 L
Mistroke
.204 .4344 L
.208 .43569 L
.212 .43717 L
.216 .43885 L
.22 .44074 L
.224 .44283 L
.228 .44513 L
.232 .44761 L
.236 .45025 L
.24 .45304 L
.244 .45593 L
.248 .4589 L
.252 .46189 L
.256 .46488 L
.26 .46781 L
.264 .47065 L
.268 .47338 L
.272 .47598 L
.276 .47842 L
.28 .48073 L
.284 .48292 L
.288 .48501 L
.292 .48704 L
.296 .48905 L
.3 .49108 L
.304 .49317 L
.308 .49535 L
.312 .49763 L
.316 .5 L
.32 .50246 L
.324 .50496 L
.328 .50747 L
.332 .50992 L
.336 .51228 L
.34 .51448 L
.344 .51651 L
.348 .51833 L
.352 .51995 L
.356 .52137 L
.36 .52261 L
.364 .52369 L
.368 .52464 L
.372 .52548 L
.376 .52619 L
.38 .52678 L
.384 .52721 L
.388 .52745 L
.392 .52749 L
.396 .52731 L
.4 .52691 L
Mistroke
.404 .52632 L
.408 .52559 L
.412 .5248 L
.416 .52402 L
.42 .52334 L
.424 .52282 L
.428 .52249 L
.432 .52238 L
.436 .52246 L
.44 .5227 L
.444 .52302 L
.448 .52337 L
.452 .5237 L
.456 .52396 L
.46 .52414 L
.464 .52422 L
.468 .52421 L
.472 .52413 L
.476 .52398 L
.48 .52379 L
.484 .52356 L
.488 .52332 L
.492 .52307 L
.496 .52285 L
.5 .52268 L
.504 .52259 L
.508 .5226 L
.512 .5227 L
.516 .52287 L
.52 .52308 L
.524 .52325 L
.528 .52335 L
.532 .52333 L
.536 .52319 L
.54 .52294 L
.544 .52265 L
.548 .52238 L
.552 .52219 L
.556 .52212 L
.56 .52217 L
.564 .52231 L
.568 .52247 L
.572 .52261 L
.576 .52266 L
.58 .52261 L
.584 .52247 L
.588 .52227 L
.592 .52207 L
.596 .52191 L
.6 .52182 L
Mistroke
.604 .52182 L
.608 .52187 L
.612 .52194 L
.616 .52199 L
.62 .522 L
.624 .52196 L
.628 .52187 L
.632 .52175 L
.636 .52163 L
.64 .52153 L
.644 .52147 L
.648 .52143 L
.652 .52143 L
.656 .52144 L
.66 .52145 L
.664 .52145 L
.668 .52141 L
.672 .52135 L
.676 .52125 L
.68 .52115 L
.684 .52105 L
.688 .52099 L
.692 .52097 L
.696 .52098 L
.7 .521 L
.704 .521 L
.708 .52097 L
.712 .52089 L
.716 .52078 L
.72 .52067 L
.724 .5206 L
.728 .52056 L
.732 .52057 L
.736 .5206 L
.74 .5206 L
.744 .52056 L
.748 .52047 L
.752 .52037 L
.756 .52027 L
.76 .52021 L
.764 .52019 L
.768 .5202 L
.772 .52021 L
.776 .52019 L
.78 .52013 L
.784 .52004 L
.788 .51995 L
.792 .51987 L
.796 .51984 L
.8 .51983 L
Mistroke
.804 .51984 L
.808 .51982 L
.812 .51976 L
.816 .51968 L
.82 .5196 L
.824 .51954 L
.828 .51951 L
.832 .51949 L
.836 .51947 L
.84 .51943 L
.844 .51938 L
.848 .51932 L
.852 .51926 L
.856 .51921 L
.86 .51916 L
.864 .51913 L
.868 .5191 L
.872 .51907 L
.876 .51903 L
.88 .51897 L
.884 .5189 L
.888 .51885 L
.892 .5188 L
.896 .51878 L
.9 .51875 L
.904 .51872 L
.908 .51866 L
.912 .5186 L
.916 .51853 L
.92 .51849 L
.924 .51846 L
.928 .51845 L
.932 .5184 L
.936 .51835 L
.94 .51828 L
.944 .51823 L
.948 .51818 L
.952 .51817 L
.956 .51813 L
.96 .51809 L
.964 .51802 L
.968 .51797 L
.972 .51791 L
.976 .51789 L
.98 .51785 L
.984 .51783 L
.988 .51776 L
.992 .51771 L
.996 .51763 L
1 .51762 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool00`00
Oomoo`0200001Goo001oogoo000017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@0
07ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo10000Woo0P001Woo00@0
07ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo
00<007ooOol097oo00<007oo00002goo00<007ooOol0=goo000ROol2000UOol01000Oomoo`000goo
10000Woo00<007oo00000Woo0P000Woo0P000goo0P000Woo00<007ooOol00P0000=oo`0000000Woo
00H007ooOol007oo0006Ool01000Oomoo`000Woo00<007ooOol02Woo000ROomS000<Ool0029oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo0P000Woo00D007ooOomoo`00009oo`05001oogoo
Ool00003Ool00`00Oomoo`020003Ool3000017oo001oogoo0P000goo0P000Woo00@007ooOol000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool00`00Oomoo`0:Ool0029oo`80011oo`03001oogoo011oo`8000Aoo`80049oo`008Woo00<0
07ooOol03goo0P0047oo0P00BGoo000ROol2000AOol00`00Oomoo`0>Ool00`00Oomoo`18Ool0029o
o`80019oo`03001oogoo00aoo`03001oogoo04Uoo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo00<007ooOol04Goo00<007ooOol02goo0P00Bgoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8001=oo`03001oogoo00Yoo`03001oogoo04Yoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000COol00`00Oomoo`0:Ool00`00Oomoo`1:
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol04goo00<0
07ooOol00goo0`000Woo00<007ooOol0Bgoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8001Aoo`03001oogoo009oo`03001oogoo00800003Ool007oo04aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool20004Ool2000DOol00`00Oomoo`02Ool01000Oomoogoo0P00
CWoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0DOol00`00Oomoo`02001COol0
00]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8001Eoo`800003Ool007oo05=oo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P005Woo0P00EGoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04
001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool0
1000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool0
1P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`00
8Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<0
07ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03
001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00
Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo
000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00
Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000
Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool0
1000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool5
0003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogoo
Ool00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo
00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009o
o`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool0
0`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo
0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomo
o`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00
:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomo
o`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol0
47oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<0
07ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@0
07ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Ool006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
0P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00
Oomoo`0NOoll000<Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006
Ool00`00Oomoo`0KOol40017Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo01Uo
o`<004Yoo`00:7oo00<007ooOol05goo0`00C7oo000XOol00`00Oomoo`0EOol3001>Ool0015oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo01=oo`<0051oo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0BOol2001BOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo5@00E7oo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04
001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0
KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<0
07ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Mo
o`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo
0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool2
0004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool2
0006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo
00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo
00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001o
ogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007oo
Ool0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`00
0Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P00
3Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04
001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00ao
o`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`80
00=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04
001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=o
o`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool2
0004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol0
2Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yo
o`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo
000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007oo
Ool017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol0
0`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02
Ool00`00Oomoo`1bOol001Moo`03001oogoo009ooaH005moo`005goo00<007ooOol00Woo00<007oo
Ool04Woo0`00GGoo000GOol00`00Oomoo`02Ool00`00Oomoo`0EOol2001KOol001Ioo`8000Aoo`80
01Moo`8005Yoo`005goo00<007ooOol00Woo00<007ooOol067oo0P00F7oo000LOol00`00Oomoo`0I
Ool2001GOol001aoo`8001aoo`8005Eoo`0077oo00<007ooOol07Goo0P00Dgoo000LOol2000OOol3
001AOol001aoo`03001oogoo021oo`<001eoobH000aoo`0077oo00<007ooOol08Woo7`00<Goo000:
Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo
00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool2
0009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`00
77oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(11189\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29997 m
.008 .29996 L
.012 .30112 L
.016 .30128 L
.02 .30052 L
.024 .30044 L
.028 .30084 L
.032 .30086 L
.036 .30065 L
.04 .30064 L
.044 .30073 L
.048 .30073 L
.052 .30069 L
.056 .30069 L
.06 .30071 L
.064 .30071 L
.068 .30071 L
.072 .30073 L
.076 .30076 L
.08 .30079 L
.084 .30084 L
.088 .30091 L
.092 .30101 L
.096 .30114 L
.1 .30132 L
.104 .30156 L
.108 .30188 L
.112 .3023 L
.116 .30285 L
.12 .30354 L
.124 .30444 L
.128 .30557 L
.132 .30699 L
.136 .30875 L
.14 .31091 L
.144 .31355 L
.148 .31673 L
.152 .32051 L
.156 .32497 L
.16 .33017 L
.164 .33614 L
.168 .34292 L
.172 .35051 L
.176 .35887 L
.18 .36794 L
.184 .37759 L
.188 .38766 L
.192 .39794 L
.196 .40816 L
.2 .418 L
Mistroke
.204 .42715 L
.208 .43525 L
.212 .44195 L
.216 .44694 L
.22 .44997 L
.224 .45088 L
.228 .44962 L
.232 .44628 L
.236 .44109 L
.24 .43443 L
.244 .4268 L
.248 .41882 L
.252 .41115 L
.256 .40443 L
.26 .39926 L
.264 .39609 L
.268 .39515 L
.272 .39645 L
.276 .39973 L
.28 .40449 L
.284 .40998 L
.288 .41535 L
.292 .4197 L
.296 .42223 L
.3 .4223 L
.304 .41956 L
.308 .41402 L
.312 .40602 L
.316 .39622 L
.32 .38545 L
.324 .37463 L
.328 .36459 L
.332 .35594 L
.336 .3489 L
.34 .34333 L
.344 .33871 L
.348 .3343 L
.352 .32927 L
.356 .3229 L
.36 .31478 L
.364 .30499 L
.368 .29412 L
.372 .28322 L
.376 .27357 L
.38 .26653 L
.384 .2632 L
.388 .26421 L
.392 .26946 L
.396 .27817 L
.4 .289 L
Mistroke
.404 .30029 L
.408 .31034 L
.412 .31777 L
.416 .32176 L
.42 .32221 L
.424 .31969 L
.428 .31521 L
.432 .30991 L
.436 .30482 L
.44 .30065 L
.444 .29767 L
.448 .2957 L
.452 .29436 L
.456 .29332 L
.46 .29251 L
.464 .29216 L
.468 .29269 L
.472 .29453 L
.476 .29787 L
.48 .30249 L
.484 .30761 L
.488 .31198 L
.492 .31428 L
.496 .31359 L
.5 .30977 L
.504 .30355 L
.508 .29643 L
.512 .29032 L
.516 .28701 L
.52 .28759 L
.524 .29198 L
.528 .29889 L
.532 .30622 L
.536 .31178 L
.54 .31397 L
.544 .31223 L
.548 .30724 L
.552 .30069 L
.556 .29473 L
.56 .29125 L
.564 .2912 L
.568 .29426 L
.572 .2991 L
.576 .30394 L
.58 .30727 L
.584 .30822 L
.588 .3068 L
.592 .30379 L
.596 .30038 L
.6 .29777 L
Mistroke
.604 .29665 L
.608 .29706 L
.612 .29849 L
.616 .30025 L
.62 .30185 L
.624 .30301 L
.628 .30366 L
.632 .3037 L
.636 .30309 L
.64 .30189 L
.644 .30036 L
.648 .29891 L
.652 .29801 L
.656 .29805 L
.66 .29918 L
.664 .30119 L
.668 .30341 L
.672 .30488 L
.676 .30476 L
.68 .30283 L
.684 .29988 L
.688 .2973 L
.692 .29645 L
.696 .2978 L
.7 .30069 L
.704 .3037 L
.708 .30538 L
.712 .30496 L
.716 .30265 L
.72 .2995 L
.724 .29702 L
.728 .2965 L
.732 .29832 L
.736 .30163 L
.74 .30462 L
.744 .30553 L
.748 .30383 L
.752 .30053 L
.756 .29767 L
.76 .29692 L
.764 .29849 L
.768 .30125 L
.772 .30349 L
.776 .3041 L
.78 .30304 L
.784 .30107 L
.788 .29921 L
.792 .29832 L
.796 .29876 L
.8 .30039 L
Mistroke
.804 .3024 L
.808 .30359 L
.812 .30316 L
.816 .30121 L
.82 .29905 L
.824 .29822 L
.828 .2993 L
.832 .30148 L
.836 .30307 L
.84 .30289 L
.844 .30132 L
.848 .2997 L
.852 .2993 L
.856 .30021 L
.86 .30134 L
.864 .30173 L
.868 .30127 L
.872 .30065 L
.876 .30066 L
.88 .30113 L
.884 .30136 L
.888 .30089 L
.892 .30006 L
.896 .29983 L
.9 .30068 L
.904 .30194 L
.908 .30249 L
.912 .30155 L
.916 .29984 L
.92 .29887 L
.924 .29954 L
.928 .30149 L
.932 .30302 L
.936 .30266 L
.94 .3008 L
.944 .29885 L
.948 .29851 L
.952 .30033 L
.956 .30249 L
.96 .30326 L
.964 .30212 L
.968 .29964 L
.972 .29826 L
.976 .2992 L
.98 .30121 L
.984 .30313 L
.988 .30318 L
.992 .30085 L
.996 .29889 L
1 .29848 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .50376 m
.008 .50966 L
.012 .5117 L
.016 .50976 L
.02 .50909 L
.024 .50968 L
.028 .50995 L
.032 .50973 L
.036 .50966 L
.04 .50971 L
.044 .50975 L
.048 .50972 L
.052 .50972 L
.056 .50971 L
.06 .50973 L
.064 .50972 L
.068 .50972 L
.072 .50971 L
.076 .50972 L
.08 .50971 L
.084 .50971 L
.088 .5097 L
.092 .5097 L
.096 .50969 L
.1 .50969 L
.104 .50967 L
.108 .50965 L
.112 .50962 L
.116 .50959 L
.12 .50955 L
.124 .50949 L
.128 .50941 L
.132 .50932 L
.136 .5092 L
.14 .50904 L
.144 .50885 L
.148 .50861 L
.152 .50831 L
.156 .50794 L
.16 .50749 L
.164 .50696 L
.168 .50632 L
.172 .50556 L
.176 .50467 L
.18 .50365 L
.184 .50247 L
.188 .50114 L
.192 .49964 L
.196 .49798 L
.2 .49616 L
Mistroke
.204 .49418 L
.208 .49207 L
.212 .48984 L
.216 .48752 L
.22 .48513 L
.224 .4827 L
.228 .48027 L
.232 .47787 L
.236 .47554 L
.24 .47328 L
.244 .47114 L
.248 .4691 L
.252 .46718 L
.256 .46537 L
.26 .46364 L
.264 .46197 L
.268 .46033 L
.272 .45868 L
.276 .457 L
.28 .45526 L
.284 .45345 L
.288 .45155 L
.292 .44959 L
.296 .44758 L
.3 .44555 L
.304 .44354 L
.308 .4416 L
.312 .43976 L
.316 .43806 L
.32 .43652 L
.324 .43514 L
.328 .43393 L
.332 .43288 L
.336 .43195 L
.34 .43115 L
.344 .43044 L
.348 .42983 L
.352 .42932 L
.356 .42893 L
.36 .42866 L
.364 .42855 L
.368 .42861 L
.372 .42885 L
.376 .42924 L
.38 .42975 L
.384 .43035 L
.388 .43096 L
.392 .43152 L
.396 .43198 L
.4 .43229 L
Mistroke
.404 .43243 L
.408 .4324 L
.412 .43224 L
.416 .43198 L
.42 .43167 L
.424 .43136 L
.428 .4311 L
.432 .4309 L
.436 .43078 L
.44 .43074 L
.444 .43077 L
.448 .43085 L
.452 .43097 L
.456 .43113 L
.46 .43129 L
.464 .43147 L
.468 .43163 L
.472 .43175 L
.476 .43183 L
.48 .43184 L
.484 .43178 L
.488 .43165 L
.492 .43147 L
.496 .4313 L
.5 .43117 L
.504 .43111 L
.508 .43115 L
.512 .43128 L
.516 .43147 L
.52 .43167 L
.524 .43185 L
.528 .43194 L
.532 .43194 L
.536 .43184 L
.54 .4317 L
.544 .43154 L
.548 .43143 L
.552 .4314 L
.556 .43145 L
.56 .43156 L
.564 .43171 L
.568 .43184 L
.572 .43193 L
.576 .43195 L
.58 .43191 L
.584 .43184 L
.588 .43176 L
.592 .4317 L
.596 .43168 L
.6 .43171 L
Mistroke
.604 .43178 L
.608 .43185 L
.612 .43192 L
.616 .43197 L
.62 .43199 L
.624 .43199 L
.628 .43196 L
.632 .43193 L
.636 .4319 L
.64 .43189 L
.644 .43191 L
.648 .43195 L
.652 .43201 L
.656 .43206 L
.66 .43211 L
.664 .43212 L
.668 .43211 L
.672 .43208 L
.676 .43204 L
.68 .43203 L
.684 .43204 L
.688 .43209 L
.692 .43216 L
.696 .43221 L
.7 .43224 L
.704 .43224 L
.708 .43221 L
.712 .43218 L
.716 .43216 L
.72 .43217 L
.724 .43222 L
.728 .43228 L
.732 .43233 L
.736 .43236 L
.74 .43234 L
.744 .43231 L
.748 .43229 L
.752 .43229 L
.756 .43232 L
.76 .43237 L
.764 .43242 L
.768 .43244 L
.772 .43245 L
.776 .43243 L
.78 .43241 L
.784 .43241 L
.788 .43243 L
.792 .43247 L
.796 .43251 L
.8 .43254 L
Mistroke
.804 .43255 L
.808 .43254 L
.812 .43253 L
.816 .43253 L
.82 .43254 L
.824 .43258 L
.828 .43261 L
.832 .43264 L
.836 .43264 L
.84 .43264 L
.844 .43264 L
.848 .43265 L
.852 .43267 L
.856 .43269 L
.86 .43271 L
.864 .43273 L
.868 .43274 L
.872 .43275 L
.876 .43275 L
.88 .43276 L
.884 .43277 L
.888 .43279 L
.892 .43281 L
.896 .43284 L
.9 .43285 L
.904 .43286 L
.908 .43285 L
.912 .43286 L
.916 .43288 L
.92 .43291 L
.924 .43293 L
.928 .43295 L
.932 .43294 L
.936 .43295 L
.94 .43295 L
.944 .43298 L
.948 .433 L
.952 .43303 L
.956 .43303 L
.96 .43304 L
.964 .43303 L
.968 .43305 L
.972 .43307 L
.976 .43311 L
.98 .43312 L
.984 .43314 L
.988 .43311 L
.992 .43313 L
.996 .43313 L
1 .43318 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42853 L
.012 .43005 L
.016 .43038 L
.02 .42964 L
.024 .42956 L
.028 .42975 L
.032 .42974 L
.036 .42957 L
.04 .42955 L
.044 .42953 L
.048 .4295 L
.052 .42943 L
.056 .4294 L
.06 .42935 L
.064 .42932 L
.068 .42926 L
.072 .42923 L
.076 .42918 L
.08 .42915 L
.084 .4291 L
.088 .42907 L
.092 .42903 L
.096 .429 L
.1 .42896 L
.104 .42894 L
.108 .42892 L
.112 .42891 L
.116 .4289 L
.12 .42892 L
.124 .42894 L
.128 .429 L
.132 .42907 L
.136 .42918 L
.14 .42933 L
.144 .42953 L
.148 .42978 L
.152 .43012 L
.156 .43053 L
.16 .43104 L
.164 .43166 L
.168 .43242 L
.172 .43332 L
.176 .43438 L
.18 .43561 L
.184 .43704 L
.188 .43866 L
.192 .44048 L
.196 .44251 L
.2 .44474 L
Mistroke
.204 .44716 L
.208 .44975 L
.212 .45249 L
.216 .45535 L
.22 .45829 L
.224 .46127 L
.228 .46426 L
.232 .46721 L
.236 .47009 L
.24 .47286 L
.244 .4755 L
.248 .478 L
.252 .48036 L
.256 .48258 L
.26 .48471 L
.264 .48675 L
.268 .48876 L
.272 .49078 L
.276 .49284 L
.28 .49497 L
.284 .4972 L
.288 .49953 L
.292 .50195 L
.296 .50442 L
.3 .50692 L
.304 .50939 L
.308 .51178 L
.312 .51404 L
.316 .51613 L
.32 .51803 L
.324 .51972 L
.328 .5212 L
.332 .52249 L
.336 .52361 L
.34 .52459 L
.344 .52544 L
.348 .52617 L
.352 .52678 L
.356 .52725 L
.36 .52755 L
.364 .52766 L
.368 .52756 L
.372 .52724 L
.376 .52673 L
.38 .52606 L
.384 .52529 L
.388 .5245 L
.392 .52378 L
.396 .52318 L
.4 .52277 L
Mistroke
.404 .52256 L
.408 .52257 L
.412 .52274 L
.416 .52304 L
.42 .5234 L
.424 .52375 L
.428 .52406 L
.432 .52427 L
.436 .52439 L
.44 .52442 L
.444 .52435 L
.448 .52422 L
.452 .52404 L
.456 .52383 L
.46 .52359 L
.464 .52335 L
.468 .52312 L
.472 .52294 L
.476 .52281 L
.48 .52277 L
.484 .52283 L
.488 .52296 L
.492 .52314 L
.496 .52333 L
.5 .52347 L
.504 .52352 L
.508 .52345 L
.512 .52326 L
.516 .52299 L
.52 .52271 L
.524 .52247 L
.528 .52232 L
.532 .5223 L
.536 .52238 L
.54 .52254 L
.544 .5227 L
.548 .52281 L
.552 .52283 L
.556 .52274 L
.56 .52257 L
.564 .52236 L
.568 .52217 L
.572 .52203 L
.576 .52198 L
.58 .522 L
.584 .52206 L
.588 .52214 L
.592 .52218 L
.596 .52217 L
.6 .52211 L
Mistroke
.604 .522 L
.608 .52188 L
.612 .52176 L
.616 .52167 L
.62 .52162 L
.624 .5216 L
.628 .5216 L
.632 .52162 L
.636 .52162 L
.64 .52161 L
.644 .52156 L
.648 .52148 L
.652 .52139 L
.656 .52128 L
.66 .5212 L
.664 .52115 L
.668 .52114 L
.672 .52115 L
.676 .52117 L
.68 .52116 L
.684 .52111 L
.688 .52103 L
.692 .52092 L
.696 .52082 L
.7 .52075 L
.704 .52073 L
.708 .52074 L
.712 .52076 L
.716 .52075 L
.72 .52071 L
.724 .52062 L
.728 .52052 L
.732 .52043 L
.736 .52037 L
.74 .52035 L
.744 .52036 L
.748 .52037 L
.752 .52034 L
.756 .52028 L
.76 .52019 L
.764 .5201 L
.768 .52003 L
.772 .52 L
.776 .51999 L
.78 .51999 L
.784 .51997 L
.788 .51991 L
.792 .51983 L
.796 .51975 L
.8 .5197 L
Mistroke
.804 .51966 L
.808 .51964 L
.812 .51962 L
.816 .51959 L
.82 .51954 L
.824 .51948 L
.828 .51941 L
.832 .51936 L
.836 .51931 L
.84 .51928 L
.844 .51926 L
.848 .51923 L
.852 .51918 L
.856 .51912 L
.86 .51905 L
.864 .519 L
.868 .51896 L
.872 .51894 L
.876 .51891 L
.88 .51887 L
.884 .51881 L
.888 .51875 L
.892 .51869 L
.896 .51866 L
.9 .51863 L
.904 .5186 L
.908 .51855 L
.912 .51849 L
.916 .51844 L
.92 .5184 L
.924 .51835 L
.928 .51832 L
.932 .51827 L
.936 .51823 L
.94 .51817 L
.944 .51814 L
.948 .51809 L
.952 .51806 L
.956 .518 L
.96 .51796 L
.964 .5179 L
.968 .51787 L
.972 .51782 L
.976 .5178 L
.98 .51773 L
.984 .5177 L
.988 .51762 L
.992 .5176 L
.996 .51754 L
1 .51753 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool20000
1Goo001oogoo00000Woo00<007ooOol00Woo0P000goo00<007ooOol017oo00@007ooOol0009oo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo
00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00Woo0`0017oo0P001Woo
00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`00
8Woo00<007ooOol08Goo00@007ooOol000Yoo`8003]oo`008Woo0P008Woo00@007ooOol000=oo`D0
009oo`80009oo`8000=oo`8000=oo`03001oogoo0080009oo`03001oogoo00800005Ool00000Ool0
000;Ool01000Oomoo`000Woo00<007ooOol02Woo000ROomS000<Ool0029oo`05001oogooOol00003
Ool01P00Oomoogoo001oo`<000=oo`05001oogooOol00002Ool01@00Oomoogoo00000goo00@007oo
Oomoo`800003Ool0000000=oo`<00006Ool00000001oo`000goo00@007ooOol000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00
Oomoo`0:Ool0029oo`8000eoo`03001oogoo011oo`8000Eoo`03001oogoo04=oo`008Woo00<007oo
Ool03Goo00<007ooOol03goo00<007ooOol0BWoo000ROol2000?Ool00`00Oomoo`0=Ool00`00Oomo
o`1;Ool0029oo`8000moo`03001oogoo00aoo`03001oogoo04aoo`002goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo00<007ooOol03goo00<007ooOol02goo00<007ooOol0C7oo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`03001oogoo00]oo`03001oogoo
04aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool00`00Oomo
o`0:Ool00`00Oomoo`1=Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol047oo00<007ooOol00goo0`000goo00<007ooOol0CGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`80015oo`03001oogoo00=oo`04001oo`000002Ool00`00
Oomoo`1=Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P004Woo00D007ooOomo
o`0000=oo`<0051oo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol04Goo00D007oo
Oomoo`0000Aoo`03001oogoo04moo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00
4Woo0P0000=oo`000000EWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002
Ool2000COol3001GOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol0
00Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00
KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000
Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo0080
06eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P00
2Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo
000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0
009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=o
o`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`80
00=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo
00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00
Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo
0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo
0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@0
07ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@0
00=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@0
07ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo
00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00
Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03
Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo
1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@0037oo000X
Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@
Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03
Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00D007ooOol007oo00@000=oo`03001oogoo01]oocl000aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo01Uoo`<004Yoo`002goo0P002Woo0P0017oo
0P000Woo1@000Woo00<007ooOol05goo0`00C7oo000XOol00`00Oomoo`0EOol2001?Ool002Qoo`03
001oogoo01=oo`80055oo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0
4Goo0P00Dgoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
00moo`8005Eoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02OolC001FOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=o
o`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomo
o`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo
00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`80
00Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001o
ogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003
Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomo
o`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo
000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D0
07ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`00
0Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007oo
Ool000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001o
ogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007oo
Ool000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007oo
Oomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03
001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03
001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P00
17oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@0
07ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo
079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00
Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo4`00HWoo
000GOol00`00Oomoo`02Ool00`00Oomoo`0?Ool3001POol001Moo`03001oogoo009oo`03001oogoo
019oo`8005ioo`005Woo0P0017oo0P005Goo00<007ooOol0Fgoo000GOol00`00Oomoo`02Ool00`00
Oomoo`0EOol2001KOol001aoo`03001oogoo01Ioo`<005Uoo`0077oo0P006Goo0P00F7oo000LOol0
0`00Oomoo`0JOol2001FOol001aoo`8001eoo`8005Aoo`0077oo00<007ooOol07Goo0`008Goo9@00
37oo000LOol00`00Oomoo`0POolQ000aOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=o
o`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol0
2goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomo
o`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`00
2goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(11356\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29928 m
.008 .30017 L
.012 .3014 L
.016 .30157 L
.02 .30061 L
.024 .30031 L
.028 .3008 L
.032 .301 L
.036 .30078 L
.04 .30069 L
.044 .30079 L
.048 .30086 L
.052 .30086 L
.056 .30089 L
.06 .30097 L
.064 .30107 L
.068 .3012 L
.072 .30136 L
.076 .3016 L
.08 .3019 L
.084 .3023 L
.088 .30282 L
.092 .30349 L
.096 .30434 L
.1 .30543 L
.104 .30679 L
.108 .30848 L
.112 .31056 L
.116 .31309 L
.12 .31615 L
.124 .31981 L
.128 .32413 L
.132 .32917 L
.136 .33498 L
.14 .3416 L
.144 .34903 L
.148 .35725 L
.152 .3662 L
.156 .37577 L
.16 .38582 L
.164 .39615 L
.168 .40651 L
.172 .41659 L
.176 .42608 L
.18 .43463 L
.184 .44188 L
.188 .44752 L
.192 .45127 L
.196 .45294 L
.2 .45243 L
Mistroke
.204 .44978 L
.208 .44518 L
.212 .43895 L
.216 .43155 L
.22 .42356 L
.224 .41562 L
.228 .4084 L
.232 .40252 L
.236 .39848 L
.24 .39661 L
.244 .39702 L
.248 .39955 L
.252 .40378 L
.256 .40907 L
.26 .4146 L
.264 .41948 L
.268 .42285 L
.272 .42398 L
.276 .4224 L
.28 .41795 L
.284 .41082 L
.288 .40153 L
.292 .39086 L
.296 .37971 L
.3 .36897 L
.304 .35937 L
.308 .35131 L
.312 .34487 L
.316 .33971 L
.32 .33518 L
.324 .33047 L
.328 .32478 L
.332 .31758 L
.336 .30867 L
.34 .29838 L
.344 .28751 L
.348 .27726 L
.352 .26898 L
.356 .26391 L
.36 .26292 L
.364 .26628 L
.368 .27359 L
.372 .28379 L
.376 .29529 L
.38 .30634 L
.384 .31536 L
.388 .32123 L
.392 .32343 L
.396 .32216 L
.4 .31822 L
Mistroke
.404 .3128 L
.408 .30709 L
.412 .30207 L
.416 .29824 L
.42 .2957 L
.424 .29421 L
.428 .29338 L
.432 .29287 L
.436 .2926 L
.44 .29284 L
.444 .29403 L
.448 .29652 L
.452 .30033 L
.456 .305 L
.46 .30964 L
.464 .31306 L
.468 .31413 L
.472 .31215 L
.476 .30728 L
.48 .30056 L
.484 .29373 L
.488 .28866 L
.492 .28685 L
.496 .28893 L
.5 .29444 L
.504 .3018 L
.508 .30881 L
.512 .31335 L
.516 .31409 L
.52 .31095 L
.524 .30507 L
.528 .29837 L
.532 .29298 L
.536 .29052 L
.54 .29159 L
.544 .29557 L
.548 .3009 L
.552 .30566 L
.556 .30838 L
.56 .30845 L
.564 .30622 L
.568 .30273 L
.572 .29926 L
.576 .29691 L
.58 .29625 L
.584 .29718 L
.588 .29908 L
.592 .30114 L
.596 .30275 L
.6 .30365 L
Mistroke
.604 .30386 L
.608 .30348 L
.612 .30258 L
.616 .30129 L
.62 .29984 L
.624 .29864 L
.628 .2981 L
.632 .29853 L
.636 .29991 L
.64 .30189 L
.644 .3038 L
.648 .30481 L
.652 .3043 L
.656 .30225 L
.66 .29945 L
.664 .29721 L
.668 .29669 L
.672 .29827 L
.676 .30124 L
.68 .30414 L
.684 .30554 L
.688 .30477 L
.692 .3022 L
.696 .29905 L
.7 .29686 L
.704 .29674 L
.708 .29882 L
.712 .30208 L
.716 .30481 L
.72 .30546 L
.724 .30365 L
.728 .3004 L
.732 .29762 L
.736 .29691 L
.74 .29853 L
.744 .30138 L
.748 .30375 L
.752 .3044 L
.756 .3032 L
.76 .30096 L
.764 .29893 L
.768 .2981 L
.772 .29882 L
.776 .30071 L
.78 .30275 L
.784 .30374 L
.788 .30305 L
.792 .30104 L
.796 .29902 L
.8 .29838 L
Mistroke
.804 .2995 L
.808 .30154 L
.812 .30296 L
.816 .30282 L
.82 .30145 L
.824 .30002 L
.828 .29956 L
.832 .30015 L
.836 .30101 L
.84 .30145 L
.844 .30138 L
.848 .30118 L
.852 .3012 L
.856 .30122 L
.86 .3009 L
.864 .3003 L
.868 .29995 L
.872 .3004 L
.876 .3015 L
.88 .3023 L
.884 .30203 L
.888 .30071 L
.892 .29943 L
.896 .29938 L
.9 .30064 L
.904 .3022 L
.908 .30266 L
.912 .30156 L
.916 .29994 L
.92 .29915 L
.924 .29989 L
.928 .30156 L
.932 .3025 L
.936 .30199 L
.94 .3006 L
.944 .29939 L
.948 .29965 L
.952 .30106 L
.956 .30208 L
.96 .30213 L
.964 .30103 L
.968 .29961 L
.972 .29961 L
.976 .30066 L
.98 .30171 L
.984 .30233 L
.988 .30141 L
.992 .29984 L
.996 .29958 L
1 .30004 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .50767 m
.008 .50826 L
.012 .50895 L
.016 .50961 L
.02 .50972 L
.024 .50941 L
.028 .50944 L
.032 .50953 L
.036 .50954 L
.04 .50948 L
.044 .5095 L
.048 .5095 L
.052 .50951 L
.056 .50949 L
.06 .50949 L
.064 .50948 L
.068 .50948 L
.072 .50946 L
.076 .50946 L
.08 .50943 L
.084 .50942 L
.088 .50938 L
.092 .50934 L
.096 .50928 L
.1 .50922 L
.104 .50912 L
.108 .50901 L
.112 .50886 L
.116 .50868 L
.12 .50845 L
.124 .50817 L
.128 .50782 L
.132 .5074 L
.136 .50688 L
.14 .50627 L
.144 .50555 L
.148 .5047 L
.152 .50372 L
.156 .50259 L
.16 .5013 L
.164 .49986 L
.168 .49825 L
.172 .49648 L
.176 .49455 L
.18 .49249 L
.184 .4903 L
.188 .488 L
.192 .48563 L
.196 .48322 L
.2 .48079 L
Mistroke
.204 .47839 L
.208 .47603 L
.212 .47374 L
.216 .47156 L
.22 .46949 L
.224 .46753 L
.228 .46567 L
.232 .46392 L
.236 .46223 L
.24 .46058 L
.244 .45894 L
.248 .45728 L
.252 .45558 L
.256 .4538 L
.26 .45194 L
.264 .45001 L
.268 .44803 L
.272 .44601 L
.276 .444 L
.28 .44204 L
.284 .44016 L
.288 .43841 L
.292 .43681 L
.296 .43538 L
.3 .43411 L
.304 .43301 L
.308 .43205 L
.312 .43122 L
.316 .4305 L
.32 .42987 L
.324 .42935 L
.328 .42893 L
.332 .42863 L
.336 .42847 L
.34 .42846 L
.344 .42863 L
.348 .42896 L
.352 .42942 L
.356 .42999 L
.36 .43059 L
.364 .43118 L
.368 .43168 L
.372 .43206 L
.376 .43227 L
.38 .43232 L
.384 .43221 L
.388 .43198 L
.392 .43168 L
.396 .43136 L
.4 .43107 L
Mistroke
.404 .43083 L
.408 .43068 L
.412 .43061 L
.416 .43061 L
.42 .43068 L
.424 .4308 L
.428 .43094 L
.432 .4311 L
.436 .43127 L
.44 .43143 L
.444 .43157 L
.448 .43167 L
.452 .43171 L
.456 .43168 L
.46 .43158 L
.464 .43144 L
.468 .43127 L
.472 .43111 L
.476 .43101 L
.48 .431 L
.484 .43108 L
.488 .43123 L
.492 .43143 L
.496 .43163 L
.5 .43177 L
.504 .43182 L
.508 .43178 L
.512 .43167 L
.516 .43151 L
.52 .43137 L
.524 .43128 L
.528 .43128 L
.532 .43136 L
.536 .43149 L
.54 .43164 L
.544 .43176 L
.548 .43182 L
.552 .43182 L
.556 .43177 L
.56 .43168 L
.564 .43161 L
.568 .43156 L
.572 .43156 L
.576 .43161 L
.58 .43168 L
.584 .43176 L
.588 .43183 L
.592 .43186 L
.596 .43187 L
.6 .43186 L
Mistroke
.604 .43183 L
.608 .43179 L
.612 .43177 L
.616 .43177 L
.62 .4318 L
.624 .43185 L
.628 .4319 L
.632 .43195 L
.636 .43199 L
.64 .432 L
.644 .43198 L
.648 .43195 L
.652 .43192 L
.656 .43191 L
.66 .43193 L
.664 .43198 L
.668 .43205 L
.672 .4321 L
.676 .43212 L
.68 .43211 L
.684 .43208 L
.688 .43205 L
.692 .43204 L
.696 .43206 L
.7 .43211 L
.704 .43217 L
.708 .43221 L
.712 .43223 L
.716 .43222 L
.72 .43219 L
.724 .43217 L
.728 .43217 L
.732 .4322 L
.736 .43225 L
.74 .4323 L
.744 .43233 L
.748 .43233 L
.752 .43231 L
.756 .43229 L
.76 .43229 L
.764 .43231 L
.768 .43235 L
.772 .43239 L
.776 .43242 L
.78 .43243 L
.784 .43242 L
.788 .43241 L
.792 .43241 L
.796 .43243 L
.8 .43246 L
Mistroke
.804 .4325 L
.808 .43252 L
.812 .43252 L
.816 .43252 L
.82 .43252 L
.824 .43253 L
.828 .43255 L
.832 .43257 L
.836 .43259 L
.84 .43261 L
.844 .43262 L
.848 .43263 L
.852 .43263 L
.856 .43264 L
.86 .43265 L
.864 .43268 L
.868 .4327 L
.872 .43272 L
.876 .43273 L
.88 .43273 L
.884 .43273 L
.888 .43275 L
.892 .43277 L
.896 .4328 L
.9 .43281 L
.904 .43282 L
.908 .43282 L
.912 .43283 L
.916 .43284 L
.92 .43287 L
.924 .43289 L
.928 .43291 L
.932 .43291 L
.936 .43292 L
.94 .43292 L
.944 .43294 L
.948 .43296 L
.952 .43299 L
.956 .43299 L
.96 .433 L
.964 .433 L
.968 .43302 L
.972 .43304 L
.976 .43307 L
.98 .43306 L
.984 .43309 L
.988 .43307 L
.992 .43311 L
.996 .43311 L
1 .43315 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42376 m
.008 .42496 L
.012 .42961 L
.016 .43129 L
.02 .42981 L
.024 .42928 L
.028 .42966 L
.032 .42983 L
.036 .42961 L
.04 .42953 L
.044 .42951 L
.048 .42952 L
.052 .42944 L
.056 .42941 L
.06 .42936 L
.064 .42934 L
.068 .42929 L
.072 .42927 L
.076 .42923 L
.08 .42922 L
.084 .4292 L
.088 .4292 L
.092 .42921 L
.096 .42924 L
.1 .42927 L
.104 .42935 L
.108 .42944 L
.112 .42959 L
.116 .42977 L
.12 .43002 L
.124 .43032 L
.128 .43072 L
.132 .4312 L
.136 .43179 L
.14 .43251 L
.144 .43337 L
.148 .43438 L
.152 .43556 L
.156 .43693 L
.16 .43849 L
.164 .44024 L
.168 .44221 L
.172 .44437 L
.176 .44673 L
.18 .44926 L
.184 .45195 L
.188 .45477 L
.192 .45768 L
.196 .46065 L
.2 .46364 L
Mistroke
.204 .46661 L
.208 .46951 L
.212 .47232 L
.216 .475 L
.22 .47755 L
.224 .47996 L
.228 .48223 L
.232 .48439 L
.236 .48646 L
.24 .48848 L
.244 .49048 L
.248 .49252 L
.252 .49462 L
.256 .4968 L
.26 .49908 L
.264 .50145 L
.268 .5039 L
.272 .50638 L
.276 .50885 L
.28 .51127 L
.284 .51358 L
.288 .51573 L
.292 .51769 L
.296 .51945 L
.3 .521 L
.304 .52235 L
.308 .52352 L
.312 .52453 L
.316 .5254 L
.32 .52615 L
.324 .52678 L
.328 .52728 L
.332 .52763 L
.336 .5278 L
.34 .52778 L
.344 .52754 L
.348 .52711 L
.352 .5265 L
.356 .52578 L
.36 .52499 L
.364 .52424 L
.368 .52358 L
.372 .52308 L
.376 .52278 L
.38 .5227 L
.384 .52281 L
.388 .52307 L
.392 .52341 L
.396 .52378 L
.4 .52412 L
Mistroke
.404 .52439 L
.408 .52455 L
.412 .52462 L
.416 .52458 L
.42 .52447 L
.424 .5243 L
.428 .52409 L
.432 .52386 L
.436 .52362 L
.44 .52339 L
.444 .5232 L
.448 .52305 L
.452 .52297 L
.456 .52298 L
.46 .52307 L
.464 .52322 L
.468 .52341 L
.472 .52357 L
.476 .52367 L
.48 .52366 L
.484 .52354 L
.488 .52332 L
.492 .52304 L
.496 .52277 L
.5 .52257 L
.504 .52247 L
.508 .52249 L
.512 .52261 L
.516 .52278 L
.52 .52293 L
.524 .523 L
.528 .52298 L
.532 .52286 L
.536 .52267 L
.54 .52245 L
.544 .52228 L
.548 .52217 L
.552 .52214 L
.556 .52218 L
.56 .52226 L
.564 .52233 L
.568 .52236 L
.572 .52233 L
.576 .52224 L
.58 .52213 L
.584 .522 L
.588 .52189 L
.592 .52181 L
.596 .52177 L
.6 .52177 L
Mistroke
.604 .52178 L
.608 .52179 L
.612 .52179 L
.616 .52176 L
.62 .5217 L
.624 .52162 L
.628 .52152 L
.632 .52143 L
.636 .52135 L
.64 .52132 L
.644 .52131 L
.648 .52132 L
.652 .52133 L
.656 .52131 L
.66 .52126 L
.664 .52117 L
.668 .52106 L
.672 .52097 L
.676 .52091 L
.68 .52089 L
.684 .52091 L
.688 .52092 L
.692 .52091 L
.696 .52086 L
.7 .52077 L
.704 .52066 L
.708 .52058 L
.712 .52053 L
.716 .52051 L
.72 .52052 L
.724 .52052 L
.728 .52049 L
.732 .52043 L
.736 .52034 L
.74 .52025 L
.744 .52018 L
.748 .52016 L
.752 .52015 L
.756 .52015 L
.76 .52012 L
.764 .52007 L
.768 .51999 L
.772 .51991 L
.776 .51985 L
.78 .51981 L
.784 .5198 L
.788 .51978 L
.792 .51975 L
.796 .5197 L
.8 .51963 L
Mistroke
.804 .51957 L
.808 .51951 L
.812 .51947 L
.816 .51944 L
.82 .51942 L
.824 .51939 L
.828 .51934 L
.832 .51927 L
.836 .51921 L
.84 .51916 L
.844 .51912 L
.848 .5191 L
.852 .51906 L
.856 .51902 L
.86 .51896 L
.864 .51891 L
.868 .51886 L
.872 .51882 L
.876 .51878 L
.88 .51874 L
.884 .5187 L
.888 .51865 L
.892 .5186 L
.896 .51856 L
.9 .51851 L
.904 .51847 L
.908 .51842 L
.912 .51838 L
.916 .51834 L
.92 .5183 L
.924 .51825 L
.928 .5182 L
.932 .51814 L
.936 .51811 L
.94 .51806 L
.944 .51804 L
.948 .51799 L
.952 .51795 L
.956 .51788 L
.96 .51784 L
.964 .51778 L
.968 .51777 L
.972 .51772 L
.976 .51769 L
.98 .51762 L
.984 .51757 L
.988 .5175 L
.992 .51749 L
.996 .51744 L
1 .51743 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20002Ool30002
Ool01000Oomoo`000Woo00<007ooOol00Woo0P000goo00<007ooOol017oo00@007ooOol0009oo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo
00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00H007oo001oo`00Ool20004Ool20006
Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo
000ROol00`00Oomoo`0OOol00`00Ool0000;Ool00`00Oomoo`0lOol0029oo`8001moo`05001oogoo
Ool00003Ool40002Ool30002Ool20002Ool20003Ool20002Ool2000017oo000007oo0P000Woo00@0
07ooOol0021oo`008WooH`0037oo000ROol01@00Oomoogoo00000goo00<007ooOol00P000goo00D0
07ooOomoo`0000=oo`04001oogoo0003Ool20002Ool00`00Oomoo`030002Ool00`00Ool000020002
Ool20003Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0000<Ool0029oo`8000Yoo`80019o
o`03001oogoo00=oo`8004Moo`008Woo00<007ooOol02Woo00<007ooOol03goo0P00CWoo000ROol2
000<Ool00`00Oomoo`0>Ool00`00Oomoo`1=Ool0029oo`8000eoo`03001oogoo00aoo`03001oogoo
04ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol037oo00<007ooOol0
2goo00<007ooOol0Cgoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
00eoo`03001oogoo00]oo`03001oogoo04moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool2000>Ool00`00Oomoo`0:Ool00`00Oomoo`1?Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol017oo0P0017oo00<007oo
Ool0Cgoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000moo`03001o
ogoo009oo`800005Ool007ooOol0001BOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P00
17oo0P003goo00<007ooOol00Woo00<007ooOol00`00Dgoo000;Ool2000:Ool20004Ool00`00Oomo
o`02Ool00`00Oomoo`0>Ool01000Oomoogoo0P000goo0P00Dgoo000;Ool20004Ool00`00Oomoo`03
Ool20002Ool50002Ool2000@Ool01000Oomoo`00FGoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0002Ool2000@Ool3001JOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol047oo00<007ooOol0FGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006io
o`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`00
0goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001o
o`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0
029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol0
00=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`00
2goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Io
o`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yo
o`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol0
00=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001X
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]o
o`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Ao
o`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00
Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03
001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0
3Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool0
1000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=o
o`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo
00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000
Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomo
o`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P00
0goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomo
o`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo01Uood40
00aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo
01Ioo`@004aoo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol057oo0`00Cgoo000X
Ool00`00Oomoo`0BOol3001AOol002Qoo`03001oogoo011oo`<005=oo`004Goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo00<007ooOol03Woo0`00EGoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo00aoo`<005Moo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool@001IOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0
015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001o
ogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@0
06aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`80
00Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]o
o`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001c
Ool000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002
Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eo
o`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo
0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`00
0Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<0
07ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool0
1000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo
10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Ao
o`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol0
17oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007oo
Ool017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Ao
o`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<0
07ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Io
o`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT0
00aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol0
00]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001o
ogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001c
Ool000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`00
5goo00<007ooOol00Woo4000IGoo000GOol00`00Oomoo`02Ool00`00Oomoo`0=Ool3001ROol001Mo
o`03001oogoo009oo`03001oogoo00moo`80065oo`005Woo0P0017oo0P004Woo00<007ooOol0GWoo
000GOol00`00Oomoo`02Ool00`00Oomoo`0BOol2001NOol001aoo`03001oogoo01Aoo`8005aoo`00
77oo0P005Woo0P00Fgoo000LOol00`00Oomoo`0GOol3001HOol001aoo`8001Yoo`8005Moo`0077oo
00<007ooOol06goo0P008Woo9`0037oo000LOol00`00Oomoo`0MOolR000cOol000Yoo`<000Aoo`03
001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001o
ogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007oo
Ool00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001o
ogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(11523\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30357 m
.008 .30236 L
.012 .30111 L
.016 .29962 L
.02 .29789 L
.024 .29714 L
.028 .29757 L
.032 .29862 L
.036 .29992 L
.04 .3007 L
.044 .30113 L
.048 .30152 L
.052 .3019 L
.056 .3023 L
.06 .30279 L
.064 .30343 L
.068 .30426 L
.072 .3053 L
.076 .3066 L
.08 .30822 L
.084 .31022 L
.088 .31266 L
.092 .31561 L
.096 .31914 L
.1 .32331 L
.104 .3282 L
.108 .33385 L
.112 .3403 L
.116 .34757 L
.12 .35563 L
.124 .36446 L
.128 .37394 L
.132 .38396 L
.136 .39432 L
.14 .40478 L
.144 .41507 L
.148 .42487 L
.152 .43383 L
.156 .44161 L
.16 .44787 L
.164 .45231 L
.168 .45472 L
.172 .45497 L
.176 .45304 L
.18 .44907 L
.184 .44334 L
.188 .43624 L
.192 .42833 L
.196 .42023 L
.2 .4126 L
Mistroke
.204 .40608 L
.208 .40123 L
.212 .39845 L
.216 .39794 L
.22 .39964 L
.224 .40325 L
.228 .4082 L
.232 .41374 L
.236 .419 L
.24 .42308 L
.244 .42519 L
.248 .42475 L
.252 .42144 L
.256 .41529 L
.26 .4067 L
.264 .39633 L
.268 .38505 L
.272 .37376 L
.276 .3633 L
.28 .35425 L
.284 .34685 L
.288 .34095 L
.292 .33606 L
.296 .33144 L
.3 .32628 L
.304 .31988 L
.308 .31187 L
.312 .30231 L
.316 .29177 L
.32 .28126 L
.324 .27205 L
.328 .26545 L
.332 .26257 L
.336 .26398 L
.34 .26963 L
.344 .27874 L
.348 .28998 L
.352 .30166 L
.356 .31206 L
.36 .31973 L
.364 .32379 L
.368 .3241 L
.372 .32118 L
.376 .31604 L
.38 .30994 L
.384 .30407 L
.388 .29928 L
.392 .29597 L
.396 .29404 L
.4 .29312 L
Mistroke
.404 .2928 L
.408 .2928 L
.412 .2931 L
.416 .29396 L
.42 .29573 L
.424 .29869 L
.428 .30274 L
.432 .30726 L
.436 .31126 L
.44 .31359 L
.444 .31334 L
.448 .31018 L
.452 .30453 L
.456 .29768 L
.46 .29141 L
.464 .28754 L
.468 .28729 L
.472 .29084 L
.476 .29725 L
.48 .30472 L
.484 .31105 L
.488 .31436 L
.492 .31367 L
.496 .30927 L
.5 .30269 L
.504 .29607 L
.508 .29148 L
.512 .29022 L
.516 .29244 L
.52 .29721 L
.524 .30277 L
.528 .30724 L
.532 .30924 L
.536 .30841 L
.54 .30539 L
.544 .30149 L
.548 .29808 L
.552 .29616 L
.556 .29608 L
.56 .29755 L
.564 .29983 L
.568 .30206 L
.572 .30359 L
.576 .30417 L
.58 .30392 L
.584 .3031 L
.588 .30196 L
.592 .30066 L
.596 .29941 L
.6 .29852 L
Mistroke
.604 .29834 L
.608 .29908 L
.612 .30062 L
.616 .30252 L
.62 .30409 L
.624 .30465 L
.628 .30378 L
.632 .30165 L
.636 .29906 L
.64 .29718 L
.644 .29703 L
.648 .29882 L
.652 .30179 L
.656 .30451 L
.66 .3056 L
.664 .3045 L
.668 .30174 L
.672 .29865 L
.676 .29676 L
.68 .29702 L
.684 .29932 L
.688 .30254 L
.692 .30501 L
.696 .30538 L
.7 .30343 L
.704 .30021 L
.708 .29754 L
.712 .29693 L
.716 .29864 L
.72 .30158 L
.724 .30402 L
.728 .30464 L
.732 .30327 L
.736 .30083 L
.74 .2987 L
.744 .29797 L
.748 .29892 L
.752 .30099 L
.756 .30302 L
.76 .30384 L
.764 .30299 L
.768 .30096 L
.772 .29904 L
.776 .29847 L
.78 .29956 L
.784 .30152 L
.788 .30294 L
.792 .30292 L
.796 .30168 L
.8 .30024 L
Mistroke
.804 .29959 L
.808 .29996 L
.812 .30078 L
.816 .30144 L
.82 .30168 L
.824 .3016 L
.828 .3014 L
.832 .30106 L
.836 .30054 L
.84 .30012 L
.844 .30018 L
.848 .3009 L
.852 .30184 L
.856 .3022 L
.86 .30159 L
.864 .3004 L
.868 .29963 L
.872 .29998 L
.876 .30114 L
.88 .30213 L
.884 .30207 L
.888 .30104 L
.892 .30006 L
.896 .29994 L
.9 .30071 L
.904 .30162 L
.908 .30174 L
.912 .3011 L
.916 .30044 L
.92 .30032 L
.924 .30091 L
.928 .30151 L
.932 .30134 L
.936 .30076 L
.94 .30029 L
.944 .3004 L
.948 .30128 L
.952 .3018 L
.956 .30139 L
.96 .30062 L
.964 .29986 L
.968 .30003 L
.972 .3013 L
.976 .30204 L
.98 .30184 L
.984 .301 L
.988 .29962 L
.992 .29949 L
.996 .30083 L
1 .30178 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .47197 m
.008 .47378 L
.012 .47781 L
.016 .48395 L
.02 .49024 L
.024 .49641 L
.028 .50157 L
.032 .50544 L
.036 .50775 L
.04 .50858 L
.044 .50902 L
.048 .50915 L
.052 .50922 L
.056 .50919 L
.06 .50917 L
.064 .50913 L
.068 .50909 L
.072 .50901 L
.076 .50893 L
.08 .50882 L
.084 .50869 L
.088 .5085 L
.092 .50829 L
.096 .50802 L
.1 .50769 L
.104 .50729 L
.108 .5068 L
.112 .50622 L
.116 .50553 L
.12 .50472 L
.124 .50378 L
.128 .50269 L
.132 .50146 L
.136 .50006 L
.14 .4985 L
.144 .49678 L
.148 .49491 L
.152 .49289 L
.156 .49074 L
.16 .48848 L
.164 .48614 L
.168 .48374 L
.172 .48132 L
.176 .4789 L
.18 .47653 L
.184 .47422 L
.188 .472 L
.192 .46988 L
.196 .46788 L
.2 .46599 L
Mistroke
.204 .46421 L
.208 .46249 L
.212 .46084 L
.216 .4592 L
.22 .45756 L
.224 .45588 L
.228 .45413 L
.232 .45231 L
.236 .45042 L
.24 .44846 L
.244 .44646 L
.248 .44446 L
.252 .44248 L
.256 .44058 L
.26 .43878 L
.264 .43713 L
.268 .43563 L
.272 .43431 L
.276 .43316 L
.28 .43216 L
.284 .4313 L
.288 .43055 L
.292 .42991 L
.296 .42937 L
.3 .42893 L
.304 .4286 L
.308 .4284 L
.312 .42834 L
.316 .42844 L
.32 .42871 L
.324 .42911 L
.328 .42964 L
.332 .43023 L
.336 .43082 L
.34 .43137 L
.344 .4318 L
.348 .43209 L
.352 .43221 L
.356 .43216 L
.36 .43198 L
.364 .4317 L
.368 .43137 L
.372 .43106 L
.376 .43079 L
.38 .43059 L
.384 .43049 L
.388 .43046 L
.392 .43051 L
.396 .43062 L
.4 .43076 L
Mistroke
.404 .43092 L
.408 .43108 L
.412 .43125 L
.416 .43139 L
.42 .4315 L
.424 .43156 L
.428 .43157 L
.432 .4315 L
.436 .43138 L
.44 .43123 L
.444 .43107 L
.448 .43094 L
.452 .43088 L
.456 .43091 L
.46 .43102 L
.464 .43119 L
.468 .43139 L
.472 .43157 L
.476 .43168 L
.48 .43169 L
.484 .43162 L
.488 .43148 L
.492 .43133 L
.496 .4312 L
.5 .43115 L
.504 .43118 L
.508 .43128 L
.512 .43142 L
.516 .43157 L
.52 .43167 L
.524 .43171 L
.528 .43169 L
.532 .43162 L
.536 .43153 L
.54 .43146 L
.544 .43143 L
.548 .43145 L
.552 .43151 L
.556 .43159 L
.56 .43167 L
.564 .43172 L
.568 .43175 L
.572 .43175 L
.576 .43172 L
.58 .43169 L
.584 .43166 L
.588 .43165 L
.592 .43166 L
.596 .43169 L
.6 .43174 L
Mistroke
.604 .4318 L
.608 .43184 L
.612 .43187 L
.616 .43187 L
.62 .43185 L
.624 .43182 L
.628 .4318 L
.632 .4318 L
.636 .43182 L
.64 .43188 L
.644 .43194 L
.648 .43198 L
.652 .432 L
.656 .43199 L
.66 .43196 L
.664 .43193 L
.668 .43192 L
.672 .43195 L
.676 .432 L
.68 .43205 L
.684 .4321 L
.688 .43211 L
.692 .4321 L
.696 .43207 L
.7 .43205 L
.704 .43205 L
.708 .43209 L
.712 .43214 L
.716 .43218 L
.72 .43221 L
.724 .43221 L
.728 .43219 L
.732 .43217 L
.736 .43217 L
.74 .4322 L
.744 .43223 L
.748 .43228 L
.752 .4323 L
.756 .43231 L
.76 .4323 L
.764 .43229 L
.768 .43229 L
.772 .43231 L
.776 .43234 L
.78 .43238 L
.784 .4324 L
.788 .4324 L
.792 .4324 L
.796 .4324 L
.8 .43241 L
Mistroke
.804 .43243 L
.808 .43245 L
.812 .43248 L
.816 .4325 L
.82 .4325 L
.824 .43251 L
.828 .43251 L
.832 .43252 L
.836 .43254 L
.84 .43256 L
.844 .43258 L
.848 .4326 L
.852 .43261 L
.856 .43261 L
.86 .43261 L
.864 .43263 L
.868 .43265 L
.872 .43268 L
.876 .43269 L
.88 .4327 L
.884 .4327 L
.888 .43271 L
.892 .43273 L
.896 .43275 L
.9 .43276 L
.904 .43278 L
.908 .43279 L
.912 .4328 L
.916 .43281 L
.92 .43283 L
.924 .43284 L
.928 .43286 L
.932 .43286 L
.936 .43288 L
.94 .43289 L
.944 .43291 L
.948 .43292 L
.952 .43294 L
.956 .43294 L
.96 .43296 L
.964 .43297 L
.968 .433 L
.972 .433 L
.976 .43302 L
.98 .43301 L
.984 .43304 L
.988 .43304 L
.992 .43308 L
.996 .43308 L
1 .43311 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .37888 m
.008 .38748 L
.012 .39166 L
.016 .3979 L
.02 .40594 L
.024 .4135 L
.028 .42028 L
.032 .42502 L
.036 .42753 L
.04 .42885 L
.044 .42924 L
.048 .42946 L
.052 .42949 L
.056 .42951 L
.06 .42949 L
.064 .42951 L
.068 .42952 L
.072 .42957 L
.076 .42962 L
.08 .42972 L
.084 .42984 L
.088 .43002 L
.092 .43024 L
.096 .43054 L
.1 .4309 L
.104 .43137 L
.108 .43192 L
.112 .43261 L
.116 .43342 L
.12 .43439 L
.124 .43552 L
.128 .43683 L
.132 .43833 L
.136 .44003 L
.14 .44193 L
.144 .44403 L
.148 .44632 L
.152 .4488 L
.156 .45143 L
.16 .45421 L
.164 .45709 L
.168 .46004 L
.172 .46302 L
.176 .466 L
.18 .46892 L
.184 .47176 L
.188 .47449 L
.192 .47709 L
.196 .47955 L
.2 .48187 L
Mistroke
.204 .48406 L
.208 .48616 L
.212 .48819 L
.216 .4902 L
.22 .49221 L
.224 .49428 L
.228 .49642 L
.232 .49865 L
.236 .50098 L
.24 .50338 L
.244 .50584 L
.248 .50831 L
.252 .51075 L
.256 .51309 L
.26 .5153 L
.264 .51733 L
.268 .51917 L
.272 .52079 L
.276 .5222 L
.28 .52342 L
.284 .52447 L
.288 .52537 L
.292 .52613 L
.296 .52678 L
.3 .52731 L
.304 .52769 L
.308 .52792 L
.312 .52796 L
.316 .52781 L
.32 .52746 L
.324 .52692 L
.328 .52624 L
.332 .52548 L
.336 .52471 L
.34 .524 L
.344 .52343 L
.348 .52305 L
.352 .52287 L
.356 .5229 L
.36 .5231 L
.364 .52342 L
.368 .5238 L
.372 .52417 L
.376 .52448 L
.38 .52469 L
.384 .5248 L
.388 .5248 L
.392 .52471 L
.396 .52455 L
.4 .52435 L
Mistroke
.404 .52413 L
.408 .52389 L
.412 .52366 L
.416 .52345 L
.42 .52329 L
.424 .52318 L
.428 .52315 L
.432 .5232 L
.436 .52332 L
.44 .52349 L
.444 .52366 L
.448 .52379 L
.452 .52384 L
.456 .52378 L
.46 .52362 L
.464 .52337 L
.468 .52309 L
.472 .52285 L
.476 .52269 L
.48 .52264 L
.484 .5227 L
.488 .52284 L
.492 .52301 L
.496 .52314 L
.5 .52318 L
.504 .52312 L
.508 .52296 L
.512 .52276 L
.516 .52255 L
.52 .52239 L
.524 .52231 L
.528 .52231 L
.532 .52237 L
.536 .52246 L
.54 .52252 L
.544 .52253 L
.548 .52248 L
.552 .52238 L
.556 .52225 L
.56 .52212 L
.564 .52202 L
.568 .52196 L
.572 .52194 L
.576 .52194 L
.58 .52196 L
.584 .52197 L
.588 .52195 L
.592 .52191 L
.596 .52184 L
.6 .52175 L
Mistroke
.604 .52166 L
.608 .52157 L
.612 .52151 L
.616 .52148 L
.62 .52148 L
.624 .52149 L
.628 .52149 L
.632 .52146 L
.636 .5214 L
.64 .52131 L
.644 .52121 L
.648 .52112 L
.652 .52107 L
.656 .52106 L
.66 .52107 L
.664 .52108 L
.668 .52106 L
.672 .521 L
.676 .52091 L
.68 .52081 L
.684 .52073 L
.688 .52069 L
.692 .52068 L
.696 .52068 L
.7 .52068 L
.704 .52065 L
.708 .52058 L
.712 .52049 L
.716 .5204 L
.72 .52034 L
.724 .52031 L
.728 .52031 L
.732 .5203 L
.736 .52028 L
.74 .52022 L
.744 .52014 L
.748 .52006 L
.752 .52 L
.756 .51997 L
.76 .51995 L
.764 .51993 L
.768 .5199 L
.772 .51985 L
.776 .51979 L
.78 .51972 L
.784 .51966 L
.788 .51962 L
.792 .5196 L
.796 .51957 L
.8 .51954 L
Mistroke
.804 .51949 L
.808 .51943 L
.812 .51936 L
.816 .51931 L
.82 .51928 L
.824 .51925 L
.828 .51922 L
.832 .51917 L
.836 .51912 L
.84 .51907 L
.844 .51901 L
.848 .51897 L
.852 .51893 L
.856 .51889 L
.86 .51885 L
.864 .51881 L
.868 .51876 L
.872 .51871 L
.876 .51866 L
.88 .51862 L
.884 .51857 L
.888 .51854 L
.892 .5185 L
.896 .51846 L
.9 .5184 L
.904 .51835 L
.908 .5183 L
.912 .51826 L
.916 .51823 L
.92 .5182 L
.924 .51814 L
.928 .51809 L
.932 .51803 L
.936 .51799 L
.94 .51795 L
.944 .51793 L
.948 .51788 L
.952 .51783 L
.956 .51777 L
.96 .51773 L
.964 .51767 L
.968 .51766 L
.972 .51761 L
.976 .51757 L
.98 .5175 L
.984 .51746 L
.988 .5174 L
.992 .51739 L
.996 .51733 L
1 .51732 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool30003Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`8000Aoo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo
01aoo`04001oogoo000:Ool20010Ool0029oo`@001]oo`04001oogoo0003Ool40003Ool3000017oo
000000000Woo0P000goo00<007ooOol00P000Woo00<007ooOol00P0000=oo`0000000Woo00<007oo
Ool087oo000ROomS000<Ool0029oo`05001oogooOol00003Ool300000goo001oo`02Ool01@00Oomo
ogoo00000goo00@007ooOol0009oo`8000=oo`05001oo`00Ool00003Ool20002Ool20002Ool20002
Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol0000<Ool0029oo`8000Qoo`03001oogoo011o
o`8000Aoo`8004Yoo`008Woo00<007ooOol027oo00<007ooOol03goo00<007ooOol0Cgoo000ROol2
0009Ool00`00Oomoo`0>Ool00`00Oomoo`1@Ool0029oo`8000Yoo`03001oogoo00aoo`03001oogoo
055oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol02Goo00<007ooOol0
37oo00<007ooOol0DGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
00]oo`03001oogoo00]oo`03001oogoo055oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool2000;Ool00`00Oomoo`0:Ool00`00Oomoo`1BOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol017oo0`000goo00<007oo
Ool0DWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000aoo`03001o
ogoo00=oo`03001oo`00009oo`03001oogoo05=oo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool2000<Ool00`00Oomoo`02Ool20002Ool00`00Ool0001EOol000]oo`8000Yoo`8000Ao
o`03001oogoo009oo`03001oogoo00aoo`05001oogooOol00004Ool00`00Oomoo`1DOol000]oo`80
00Aoo`03001oogoo00=oo`80009oo`D0009oo`8000eoo`04001oogoo001LOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8000ioo`03001oo`0005aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`1KOol000Yo
o`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qo
o`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001o
ogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2
001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000
Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003
Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo
06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03
Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomo
o`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
1Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4
0003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007oo
Ool017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03
001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo
0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`00
17oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo0000
0Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007oo
Oomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002
Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001o
ogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03
001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo
0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool2
0002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
0Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000
Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol0
07oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003
Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P00
17oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool0
00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04001o
ogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ao
o`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo00mo
o`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yo
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=o
o`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00
Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool0
10000goo00<007ooOol05WooA00037oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001o
ogoo001oo`001Woo00<007ooOol057oo0`00Cgoo000;Ool2000:Ool20004Ool20002Ool50002Ool0
0`00Oomoo`0BOol2001BOol002Qoo`03001oogoo00moo`@005=oo`00:7oo0P003goo0P00EWoo000A
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3000<Ool2001HOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo00002Woo0`00FGoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00/005]oo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03
001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol0
00]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001o
ogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001c
Ool000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo
0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo
0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00
Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011o
o`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool0
01aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00
Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo
0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=
Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo
0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03
001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03
001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool3
0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007oo
Ool007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`8007=oo`0077oo
0P00Lgoo000LOol3001bOol001Ioo`<000=oo`04001oo`00001aOol001Moo`03001oogoo009oo`04
001oogoo001aOol001Moo`03001oogoo009oo`80009oo`T006Qoo`005goo00<007ooOol00Woo00<0
07ooOol02Woo0`00IGoo000GOol00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`1ROol001Io
o`8000Aoo`8000moo`80069oo`005goo00<007ooOol00Woo00<007ooOol03goo0P00HGoo000LOol0
0`00Oomoo`0AOol2001OOol001aoo`8001=oo`<005eoo`0077oo00<007ooOol057oo0`00Fgoo000L
Ool2000GOol2001JOol001aoo`03001oogoo01Qoo`8002EoobL000aoo`0077oo00<007ooOol06Woo
9@00<goo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]o
o`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0
LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009o
o`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(11690\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30587 m
.008 .30406 L
.012 .30328 L
.016 .30217 L
.02 .30081 L
.024 .30039 L
.028 .30088 L
.032 .30068 L
.036 .29955 L
.04 .29797 L
.044 .29663 L
.048 .29739 L
.052 .30023 L
.056 .30404 L
.06 .30841 L
.064 .31281 L
.068 .31727 L
.072 .32194 L
.076 .32699 L
.08 .33263 L
.084 .33899 L
.088 .34611 L
.092 .35404 L
.096 .36273 L
.1 .37212 L
.104 .38207 L
.108 .39244 L
.112 .40298 L
.116 .41344 L
.12 .42351 L
.124 .43286 L
.128 .44113 L
.132 .44798 L
.136 .4531 L
.14 .45624 L
.144 .45725 L
.148 .45606 L
.152 .45276 L
.156 .44757 L
.16 .44086 L
.164 .43312 L
.168 .42495 L
.172 .417 L
.176 .40992 L
.18 .40432 L
.184 .40066 L
.188 .39922 L
.192 .40005 L
.196 .40293 L
.2 .40742 L
Mistroke
.204 .41282 L
.208 .4183 L
.212 .42296 L
.216 .42596 L
.22 .42661 L
.224 .42445 L
.228 .41939 L
.232 .41165 L
.236 .40177 L
.24 .39055 L
.244 .37891 L
.248 .36773 L
.252 .35773 L
.256 .34932 L
.26 .34254 L
.264 .33709 L
.268 .33233 L
.272 .32746 L
.276 .32172 L
.28 .31457 L
.284 .30585 L
.288 .29585 L
.292 .28537 L
.296 .27557 L
.3 .26775 L
.304 .26315 L
.308 .2626 L
.312 .26638 L
.316 .27409 L
.32 .28465 L
.324 .29652 L
.328 .30792 L
.332 .31722 L
.336 .32322 L
.34 .32536 L
.344 .3238 L
.348 .31935 L
.352 .31322 L
.356 .30673 L
.36 .30097 L
.364 .29664 L
.368 .29396 L
.372 .29271 L
.376 .29243 L
.38 .29267 L
.384 .29317 L
.388 .29399 L
.392 .29539 L
.396 .29768 L
.4 .30097 L
Mistroke
.404 .30502 L
.408 .30915 L
.412 .31234 L
.416 .31354 L
.42 .31204 L
.424 .30781 L
.428 .30164 L
.432 .29497 L
.436 .28959 L
.44 .28709 L
.444 .28834 L
.448 .29316 L
.452 .30024 L
.456 .30754 L
.46 .31291 L
.464 .31479 L
.468 .31265 L
.472 .30721 L
.476 .30023 L
.48 .29395 L
.484 .29032 L
.488 .29033 L
.492 .29371 L
.496 .29913 L
.5 .30469 L
.504 .30861 L
.508 .30976 L
.512 .30804 L
.516 .30434 L
.52 .30015 L
.524 .29692 L
.528 .29555 L
.532 .29615 L
.536 .29817 L
.54 .30075 L
.544 .30299 L
.548 .30432 L
.552 .30453 L
.556 .30383 L
.56 .30262 L
.564 .30128 L
.568 .30004 L
.572 .29907 L
.576 .29856 L
.58 .29872 L
.584 .29969 L
.588 .3013 L
.592 .30305 L
.596 .30428 L
.6 .30441 L
Mistroke
.604 .30323 L
.608 .30106 L
.612 .29872 L
.616 .29725 L
.62 .29745 L
.624 .29942 L
.628 .30233 L
.632 .3048 L
.636 .30557 L
.64 .30418 L
.644 .30128 L
.648 .2983 L
.652 .29672 L
.656 .29732 L
.66 .29983 L
.664 .30299 L
.668 .3052 L
.672 .30528 L
.676 .30316 L
.68 .29997 L
.684 .29745 L
.688 .297 L
.692 .29882 L
.696 .30182 L
.7 .30427 L
.704 .30482 L
.708 .3033 L
.712 .30069 L
.716 .2985 L
.72 .29787 L
.724 .29903 L
.728 .30125 L
.732 .30327 L
.736 .30395 L
.74 .30297 L
.744 .30091 L
.748 .29904 L
.752 .29851 L
.756 .2996 L
.76 .30153 L
.764 .30299 L
.768 .30308 L
.772 .3019 L
.776 .30038 L
.78 .29954 L
.784 .29976 L
.788 .30066 L
.792 .30155 L
.796 .30199 L
.8 .3019 L
Mistroke
.804 .30146 L
.808 .30088 L
.812 .30034 L
.816 .30012 L
.82 .30044 L
.824 .30121 L
.828 .30195 L
.832 .30206 L
.836 .30138 L
.84 .3004 L
.844 .2999 L
.848 .30032 L
.852 .30125 L
.856 .30191 L
.86 .30176 L
.864 .30102 L
.868 .30042 L
.872 .30044 L
.876 .30091 L
.88 .30131 L
.884 .30123 L
.888 .30091 L
.892 .30083 L
.896 .30105 L
.9 .30134 L
.904 .30121 L
.908 .30063 L
.912 .30029 L
.916 .30059 L
.92 .30136 L
.924 .30202 L
.928 .30166 L
.932 .30053 L
.936 .29975 L
.94 .29992 L
.944 .30114 L
.948 .30243 L
.952 .30227 L
.956 .30095 L
.96 .29963 L
.964 .29922 L
.968 .30054 L
.972 .30237 L
.976 .3027 L
.98 .30168 L
.984 .29996 L
.988 .29875 L
.992 .29984 L
.996 .30185 L
1 .30274 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42973 m
.008 .43762 L
.012 .44372 L
.016 .44795 L
.02 .4532 L
.024 .45926 L
.028 .46459 L
.032 .46917 L
.036 .47415 L
.04 .4797 L
.044 .48591 L
.048 .4924 L
.052 .49792 L
.056 .50208 L
.06 .50484 L
.064 .50632 L
.068 .50705 L
.072 .50718 L
.076 .50703 L
.08 .50665 L
.084 .50614 L
.088 .50549 L
.092 .50473 L
.096 .50382 L
.1 .50278 L
.104 .50159 L
.108 .50025 L
.112 .49874 L
.116 .49707 L
.12 .49525 L
.124 .49328 L
.128 .49117 L
.132 .48895 L
.136 .48663 L
.14 .48425 L
.144 .48184 L
.148 .47942 L
.152 .47703 L
.156 .4747 L
.16 .47245 L
.164 .4703 L
.168 .46826 L
.172 .46633 L
.176 .46451 L
.18 .46277 L
.184 .4611 L
.188 .45946 L
.192 .45782 L
.196 .45616 L
.2 .45445 L
Mistroke
.204 .45267 L
.208 .45081 L
.212 .44889 L
.216 .44691 L
.22 .44491 L
.224 .44293 L
.228 .441 L
.232 .43917 L
.236 .43746 L
.24 .43591 L
.244 .43453 L
.248 .43332 L
.252 .43228 L
.256 .43138 L
.26 .43061 L
.264 .42995 L
.268 .42939 L
.272 .42893 L
.276 .42858 L
.28 .42834 L
.284 .42823 L
.288 .42828 L
.292 .42848 L
.296 .42883 L
.3 .42931 L
.304 .42987 L
.308 .43046 L
.312 .43103 L
.316 .43152 L
.32 .43187 L
.324 .43206 L
.328 .43208 L
.332 .43196 L
.336 .43171 L
.34 .43139 L
.344 .43106 L
.348 .43076 L
.352 .43053 L
.356 .43038 L
.36 .43032 L
.364 .43035 L
.368 .43044 L
.372 .43057 L
.376 .43073 L
.38 .4309 L
.384 .43106 L
.388 .43121 L
.392 .43133 L
.396 .43141 L
.4 .43144 L
Mistroke
.404 .4314 L
.408 .43132 L
.412 .43118 L
.416 .43103 L
.42 .43088 L
.424 .43079 L
.428 .43077 L
.432 .43083 L
.436 .43097 L
.44 .43116 L
.444 .43135 L
.448 .4315 L
.452 .43157 L
.456 .43155 L
.46 .43145 L
.464 .4313 L
.468 .43115 L
.472 .43105 L
.476 .43103 L
.48 .43108 L
.484 .43121 L
.488 .43136 L
.492 .43149 L
.496 .43157 L
.5 .43159 L
.504 .43155 L
.508 .43146 L
.512 .43138 L
.516 .43132 L
.52 .4313 L
.524 .43134 L
.528 .43141 L
.532 .43149 L
.536 .43157 L
.54 .43162 L
.544 .43163 L
.548 .43162 L
.552 .43159 L
.556 .43155 L
.56 .43153 L
.564 .43153 L
.568 .43155 L
.572 .43159 L
.576 .43164 L
.58 .43169 L
.584 .43173 L
.588 .43175 L
.592 .43174 L
.596 .43172 L
.6 .43169 L
Mistroke
.604 .43167 L
.608 .43168 L
.612 .43172 L
.616 .43177 L
.62 .43183 L
.624 .43187 L
.628 .43188 L
.632 .43186 L
.636 .43183 L
.64 .4318 L
.644 .4318 L
.648 .43183 L
.652 .43189 L
.656 .43194 L
.66 .43198 L
.664 .43199 L
.668 .43197 L
.672 .43194 L
.676 .43193 L
.68 .43194 L
.684 .43197 L
.688 .43202 L
.692 .43207 L
.696 .43209 L
.7 .43209 L
.704 .43207 L
.708 .43205 L
.712 .43205 L
.716 .43208 L
.72 .43212 L
.724 .43216 L
.728 .43218 L
.732 .43219 L
.736 .43218 L
.74 .43217 L
.744 .43217 L
.748 .43219 L
.752 .43223 L
.756 .43226 L
.76 .43228 L
.764 .43229 L
.768 .43228 L
.772 .43228 L
.776 .43229 L
.78 .43231 L
.784 .43233 L
.788 .43236 L
.792 .43238 L
.796 .43239 L
.8 .43239 L
Mistroke
.804 .43239 L
.808 .4324 L
.812 .43242 L
.816 .43244 L
.82 .43247 L
.824 .43248 L
.828 .43249 L
.832 .43249 L
.836 .4325 L
.84 .43251 L
.844 .43253 L
.848 .43256 L
.852 .43257 L
.856 .43258 L
.86 .43259 L
.864 .4326 L
.868 .43261 L
.872 .43263 L
.876 .43264 L
.88 .43266 L
.884 .43267 L
.888 .43269 L
.892 .43269 L
.896 .43271 L
.9 .43272 L
.904 .43273 L
.908 .43275 L
.912 .43277 L
.916 .43278 L
.92 .43279 L
.924 .4328 L
.928 .43281 L
.932 .43282 L
.936 .43285 L
.94 .43286 L
.944 .43288 L
.948 .43288 L
.952 .43289 L
.956 .4329 L
.96 .43292 L
.964 .43293 L
.968 .43296 L
.972 .43296 L
.976 .43298 L
.98 .43297 L
.984 .433 L
.988 .43301 L
.992 .43305 L
.996 .43304 L
1 .43307 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .33401 m
.008 .34322 L
.012 .34732 L
.016 .35311 L
.02 .36064 L
.024 .3678 L
.028 .37426 L
.032 .38038 L
.036 .38633 L
.04 .39338 L
.044 .40147 L
.048 .40944 L
.052 .41665 L
.056 .42216 L
.06 .42586 L
.064 .42829 L
.068 .4297 L
.072 .43066 L
.076 .43134 L
.08 .43201 L
.084 .43269 L
.088 .43349 L
.092 .43441 L
.096 .4355 L
.1 .43675 L
.104 .4382 L
.108 .43983 L
.112 .44167 L
.116 .4437 L
.12 .44594 L
.124 .44835 L
.128 .45094 L
.132 .45366 L
.136 .45651 L
.14 .45943 L
.144 .46241 L
.148 .46538 L
.152 .46832 L
.156 .47119 L
.16 .47396 L
.164 .47661 L
.168 .47911 L
.172 .48148 L
.176 .48372 L
.18 .48585 L
.184 .4879 L
.188 .48991 L
.192 .49191 L
.196 .49395 L
.2 .49605 L
Mistroke
.204 .49824 L
.208 .50052 L
.212 .50289 L
.216 .50532 L
.22 .50778 L
.224 .51022 L
.228 .51259 L
.232 .51485 L
.236 .51695 L
.24 .51885 L
.244 .52054 L
.248 .52202 L
.252 .5233 L
.256 .5244 L
.26 .52533 L
.264 .52612 L
.268 .52679 L
.272 .52734 L
.276 .52775 L
.28 .52802 L
.284 .52813 L
.288 .52804 L
.292 .52777 L
.296 .5273 L
.3 .52668 L
.304 .52596 L
.308 .52519 L
.312 .52445 L
.316 .52382 L
.32 .52335 L
.324 .52309 L
.328 .52303 L
.332 .52316 L
.336 .52344 L
.34 .52381 L
.344 .52419 L
.348 .52454 L
.352 .52481 L
.356 .52496 L
.36 .52501 L
.364 .52495 L
.368 .52481 L
.372 .52462 L
.376 .52439 L
.38 .52416 L
.384 .52392 L
.388 .52371 L
.392 .52354 L
.396 .52341 L
.4 .52335 L
Mistroke
.404 .52336 L
.408 .52344 L
.412 .52358 L
.416 .52375 L
.42 .5239 L
.424 .52399 L
.428 .52399 L
.432 .52388 L
.436 .52368 L
.44 .52342 L
.444 .52316 L
.448 .52294 L
.452 .52283 L
.456 .52283 L
.46 .52292 L
.464 .52308 L
.468 .52324 L
.472 .52333 L
.476 .52334 L
.48 .52324 L
.484 .52306 L
.488 .52285 L
.492 .52265 L
.496 .52252 L
.5 .52247 L
.504 .5225 L
.508 .52257 L
.512 .52265 L
.516 .5227 L
.52 .52269 L
.524 .52262 L
.528 .5225 L
.532 .52237 L
.536 .52225 L
.54 .52216 L
.544 .52211 L
.548 .5221 L
.552 .52212 L
.556 .52213 L
.56 .52214 L
.564 .52211 L
.568 .52206 L
.572 .52198 L
.576 .52189 L
.58 .52179 L
.584 .52172 L
.588 .52167 L
.592 .52165 L
.596 .52165 L
.6 .52166 L
Mistroke
.604 .52165 L
.608 .52161 L
.612 .52154 L
.616 .52145 L
.62 .52135 L
.624 .52127 L
.628 .52123 L
.632 .52122 L
.636 .52124 L
.64 .52124 L
.644 .52121 L
.648 .52115 L
.652 .52106 L
.656 .52096 L
.66 .52088 L
.664 .52084 L
.668 .52084 L
.672 .52084 L
.676 .52084 L
.68 .5208 L
.684 .52073 L
.688 .52064 L
.692 .52055 L
.696 .5205 L
.7 .52047 L
.704 .52047 L
.708 .52046 L
.712 .52043 L
.716 .52037 L
.72 .52029 L
.724 .52022 L
.728 .52016 L
.732 .52012 L
.736 .52011 L
.74 .52009 L
.744 .52006 L
.748 .52001 L
.752 .51994 L
.756 .51987 L
.76 .51982 L
.764 .51978 L
.768 .51975 L
.772 .51973 L
.776 .51969 L
.78 .51964 L
.784 .51958 L
.788 .51952 L
.792 .51947 L
.796 .51943 L
.8 .5194 L
Mistroke
.804 .51937 L
.808 .51933 L
.812 .51928 L
.816 .51922 L
.82 .51917 L
.824 .51912 L
.828 .51908 L
.832 .51905 L
.836 .51901 L
.84 .51897 L
.844 .51892 L
.848 .51887 L
.852 .51881 L
.856 .51877 L
.86 .51873 L
.864 .5187 L
.868 .51866 L
.872 .51861 L
.876 .51856 L
.88 .5185 L
.884 .51846 L
.888 .51842 L
.892 .51838 L
.896 .51835 L
.9 .5183 L
.904 .51824 L
.908 .51819 L
.912 .51815 L
.916 .51811 L
.92 .51808 L
.924 .51803 L
.928 .51798 L
.932 .51793 L
.936 .51789 L
.94 .51784 L
.944 .51781 L
.948 .51776 L
.952 .51772 L
.956 .51766 L
.96 .51762 L
.964 .51757 L
.968 .51754 L
.972 .51749 L
.976 .51745 L
.98 .51739 L
.984 .51736 L
.988 .5173 L
.992 .51728 L
.996 .51721 L
1 .5172 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0004Ool40004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Eoo`04001oo`000005Ool20004Ool20006Ool01000
Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol0
0`00Oomoo`0JOol00`00Ool0000;Ool00`00Oomoo`11Ool0029oo`80009oo`8001Ioo`05001oogoo
Ool00003Ool40002Ool30002Ool20002Ool20003Ool20002Ool200000goo00000002Ool01000Oomo
o`000Woo00<007ooOol057oo00<007ooOol037oo000ROomS000<Ool0029oo`06001oogooOol007oo
0`000goo00D007ooOomoo`0000=oo`05001oogooOol00002Ool01000Oomoogoo0P0000=oo`000000
0goo0`0000=oo`00Ool00`000Woo0P000goo00D007ooOomoo`00009oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
37oo000ROol20005Ool2000BOol00`00Oomoo`03Ool2001<Ool0029oo`03001oogoo00Eoo`03001o
ogoo00moo`03001oogoo059oo`008Woo0P001goo00<007ooOol03Goo00<007ooOol0Dgoo000ROol2
0007Ool00`00Oomoo`0=Ool00`00Oomoo`1COol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`03001oogoo00Moo`03001oogoo00]oo`03001oogoo05Aoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool20008Ool00`00Oomoo`0;Ool00`00Oomoo`1DOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0027oo00<007ooOol02goo00<007oo
Ool0E7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00Qo
o`03001oogoo00Aoo`8000Aoo`03001oogoo05Aoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool20009Ool00`00Oomoo`03Ool40002Ool00`00Oomoo`1EOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo0P0017oo0P002Goo00<007ooOol00goo00H007ooOol007oo001H
Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo009oo`04001o
ogooOol2001HOol000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8000Yoo`80009oo`03
001oogoo05aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P002goo
00<007oo0000Ggoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo00Yoo`<005moo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=o
o`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2
001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomo
o`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]o
o`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`80
06eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogoo
Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0
009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomo
o`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004
Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo
00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo
00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo
00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool0
00]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=o
o`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=o
o`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogoo
Ool40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
00=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Ao
o`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo
00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007oo
Ool00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0
009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000ao
o`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007oo
Ool047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007oo
Ool00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`05001oogoo001oo`040003Ool00`00Oomoo`0DOom6000<Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0006Ool2000COol2001BOol000]oo`8000Yoo`8000Aoo`80
009oo`D0009oo`03001oo`0000moo`<005Aoo`00:7oo00@007oo000000aoo`<005Ioo`00:7oo00@0
07ooOol000Yoo`8005Uoo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00D007ooOomo
o`0000Qoo`8005Yoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool01000
Oomoogoo0P0017oo0`00G7oo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo009oo`H005ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P00
2Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3
0003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`00
00=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo
00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03
001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P00
17oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo
00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo
00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001o
ogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo
0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool0
1@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo
0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool0
1000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007oo
Oomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000
Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool0
1000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007oo
Oomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03
Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo
1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000L
Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<0
07ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Mo
o`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo
0P0027oo1@000Woo0P00Lgoo000LOol2001cOol001aoo`<0079oo`0077oo00<007oo0000LWoo000L
Ool200000goo001oo`1`Ool001aoo`05001oogooOol0001`Ool001aoo`05001oogooOol0001`Ool0
01aoo`8000=oo`03001oogoo06eoo`005Woo0`000goo00<007ooOol00Woo00<007ooOol0KGoo000G
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`1/Ool001Moo`03001oogoo009oo`8000Ao
o`@006]oo`005goo00<007ooOol00Woo00<007ooOol01goo0`00J7oo000GOol00`00Oomoo`02Ool0
0`00Oomoo`0:Ool2001VOol001Ioo`8000Aoo`8000aoo`8006Eoo`005goo00<007ooOol00Woo00<0
07ooOol03Goo00<007ooOol0HWoo000LOol00`00Oomoo`0>Ool2001ROol001aoo`80011oo`<0061o
o`0077oo00<007ooOol04Goo0`00GWoo000LOol2000DOol2001MOol001aoo`03001oogoo01Eoo`80
02IoobT000aoo`0077oo00<007ooOol05goo9P00=Goo000:Ool30004Ool00`00Oomoo`02Ool30003
Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03
001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo
00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomo
o`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(11857\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30794 m
.008 .30777 L
.012 .30876 L
.016 .30861 L
.02 .30738 L
.024 .30776 L
.028 .30979 L
.032 .31135 L
.036 .31222 L
.04 .31364 L
.044 .31633 L
.048 .32103 L
.052 .32714 L
.056 .33232 L
.06 .33643 L
.064 .34103 L
.068 .34712 L
.072 .35591 L
.076 .36725 L
.08 .38008 L
.084 .39358 L
.088 .40671 L
.092 .41897 L
.096 .42999 L
.1 .43952 L
.104 .4474 L
.108 .45341 L
.112 .4574 L
.116 .45922 L
.12 .45881 L
.124 .45622 L
.128 .45164 L
.132 .44537 L
.136 .43789 L
.14 .42973 L
.144 .42156 L
.148 .41402 L
.152 .40773 L
.156 .40323 L
.16 .40086 L
.164 .40079 L
.168 .40288 L
.172 .40679 L
.176 .41191 L
.18 .41746 L
.184 .42256 L
.188 .42633 L
.192 .42799 L
.196 .42698 L
.2 .42306 L
Mistroke
.204 .41628 L
.208 .40707 L
.212 .39613 L
.216 .38433 L
.22 .37259 L
.224 .36172 L
.228 .3523 L
.232 .34457 L
.236 .33837 L
.24 .33324 L
.244 .32843 L
.248 .32318 L
.252 .3168 L
.256 .30893 L
.26 .29963 L
.264 .28945 L
.268 .27938 L
.272 .27065 L
.276 .26455 L
.28 .26214 L
.284 .26399 L
.288 .27003 L
.292 .27952 L
.296 .29112 L
.3 .30313 L
.304 .3138 L
.308 .32164 L
.312 .32573 L
.316 .32587 L
.32 .32253 L
.324 .31678 L
.328 .30994 L
.332 .30332 L
.336 .29792 L
.34 .29426 L
.344 .29234 L
.348 .29182 L
.352 .29217 L
.356 .29295 L
.36 .29396 L
.364 .29524 L
.368 .29709 L
.372 .29974 L
.376 .3032 L
.38 .30709 L
.384 .31064 L
.388 .31286 L
.392 .31288 L
.396 .31024 L
.4 .3052 L
Mistroke
.404 .29877 L
.408 .29257 L
.412 .2883 L
.416 .2873 L
.42 .29001 L
.424 .29585 L
.428 .30325 L
.432 .31007 L
.436 .31429 L
.44 .31465 L
.444 .31111 L
.448 .30481 L
.452 .29775 L
.456 .29212 L
.46 .28962 L
.464 .29089 L
.468 .2953 L
.472 .30121 L
.476 .30659 L
.48 .30976 L
.484 .30991 L
.488 .3073 L
.492 .30307 L
.496 .2988 L
.5 .29589 L
.504 .29513 L
.508 .29643 L
.512 .29901 L
.516 .30181 L
.52 .30393 L
.524 .3049 L
.528 .30467 L
.532 .30357 L
.536 .30206 L
.54 .30059 L
.544 .29946 L
.548 .29883 L
.552 .29873 L
.556 .29925 L
.56 .30037 L
.564 .30192 L
.568 .30345 L
.572 .30434 L
.576 .3041 L
.58 .30267 L
.584 .30049 L
.588 .29843 L
.592 .29739 L
.596 .29796 L
.6 .30007 L
Mistroke
.604 .30285 L
.608 .30501 L
.612 .30544 L
.616 .3038 L
.62 .30084 L
.624 .29801 L
.628 .29673 L
.632 .29767 L
.636 .30035 L
.64 .30344 L
.644 .30537 L
.648 .30514 L
.652 .30286 L
.656 .2997 L
.66 .29736 L
.664 .29711 L
.668 .29906 L
.672 .3021 L
.676 .3045 L
.68 .30494 L
.684 .30327 L
.688 .30054 L
.692 .29832 L
.696 .2978 L
.7 .29914 L
.704 .3015 L
.708 .30351 L
.712 .30407 L
.716 .30295 L
.72 .30084 L
.724 .299 L
.728 .29853 L
.732 .29963 L
.736 .30157 L
.74 .30308 L
.744 .30324 L
.748 .30208 L
.752 .30047 L
.756 .29947 L
.76 .2996 L
.764 .30058 L
.768 .30168 L
.772 .30226 L
.776 .30213 L
.78 .3015 L
.784 .30074 L
.788 .30021 L
.792 .30017 L
.796 .30064 L
.8 .30141 L
Mistroke
.804 .302 L
.808 .30198 L
.812 .30133 L
.816 .30049 L
.82 .3001 L
.824 .30046 L
.828 .30124 L
.832 .30178 L
.836 .3017 L
.84 .30116 L
.844 .3007 L
.848 .30064 L
.852 .30088 L
.856 .30109 L
.86 .30108 L
.864 .30104 L
.868 .30117 L
.872 .30137 L
.876 .30135 L
.88 .30093 L
.884 .30038 L
.888 .30035 L
.892 .30099 L
.896 .3018 L
.9 .30207 L
.904 .30132 L
.908 .30016 L
.912 .29973 L
.916 .3004 L
.92 .30175 L
.924 .30255 L
.928 .30185 L
.932 .30038 L
.936 .29945 L
.94 .2998 L
.944 .30141 L
.948 .30268 L
.952 .30227 L
.956 .30082 L
.96 .29944 L
.964 .29933 L
.968 .301 L
.972 .30257 L
.976 .30255 L
.98 .30135 L
.984 .29958 L
.988 .29896 L
.992 .30055 L
.996 .30226 L
1 .30273 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .39208 m
.008 .40116 L
.012 .40775 L
.016 .41179 L
.02 .41669 L
.024 .42249 L
.028 .42788 L
.032 .43269 L
.036 .43769 L
.04 .443 L
.044 .44842 L
.048 .45364 L
.052 .45819 L
.056 .46218 L
.06 .46658 L
.064 .47162 L
.068 .47716 L
.072 .48277 L
.076 .48756 L
.08 .49111 L
.084 .49325 L
.088 .49404 L
.092 .49379 L
.096 .49273 L
.1 .49115 L
.104 .48919 L
.108 .48703 L
.112 .48472 L
.116 .48234 L
.12 .47993 L
.124 .47754 L
.128 .47519 L
.132 .47291 L
.136 .47072 L
.14 .46865 L
.144 .46668 L
.148 .46482 L
.152 .46305 L
.156 .46136 L
.16 .45972 L
.164 .45809 L
.168 .45644 L
.172 .45476 L
.176 .45301 L
.18 .45119 L
.184 .44929 L
.188 .44735 L
.192 .44536 L
.196 .44338 L
.2 .44144 L
Mistroke
.204 .43957 L
.208 .43782 L
.212 .43621 L
.216 .43477 L
.22 .43351 L
.224 .43241 L
.228 .43147 L
.232 .43067 L
.236 .42999 L
.24 .42941 L
.244 .42893 L
.248 .42856 L
.252 .42829 L
.256 .42815 L
.26 .42814 L
.264 .42828 L
.268 .42857 L
.272 .429 L
.276 .42953 L
.28 .43011 L
.284 .43069 L
.288 .43121 L
.292 .43162 L
.296 .43188 L
.3 .43198 L
.304 .43191 L
.308 .43171 L
.312 .43141 L
.316 .43108 L
.32 .43075 L
.324 .43048 L
.328 .43029 L
.332 .43019 L
.336 .43019 L
.34 .43026 L
.344 .43038 L
.348 .43054 L
.352 .43071 L
.356 .43088 L
.36 .43103 L
.364 .43116 L
.368 .43125 L
.372 .4313 L
.376 .43129 L
.38 .43123 L
.384 .43112 L
.388 .43098 L
.392 .43083 L
.396 .43071 L
.4 .43065 L
Mistroke
.404 .43067 L
.408 .43077 L
.412 .43093 L
.416 .43112 L
.42 .43129 L
.424 .43141 L
.428 .43144 L
.432 .43139 L
.436 .43127 L
.44 .43111 L
.444 .43098 L
.448 .43091 L
.452 .43092 L
.456 .431 L
.46 .43114 L
.464 .43129 L
.468 .43141 L
.472 .43147 L
.476 .43146 L
.48 .4314 L
.484 .43131 L
.488 .43123 L
.492 .43118 L
.496 .43118 L
.5 .43124 L
.504 .43132 L
.508 .4314 L
.512 .43147 L
.516 .43151 L
.52 .43151 L
.524 .43149 L
.528 .43145 L
.532 .43142 L
.536 .4314 L
.54 .43141 L
.544 .43144 L
.548 .43148 L
.552 .43154 L
.556 .43158 L
.56 .43162 L
.564 .43162 L
.568 .43161 L
.572 .43159 L
.576 .43156 L
.58 .43155 L
.584 .43157 L
.588 .43161 L
.592 .43166 L
.596 .43172 L
.6 .43175 L
Mistroke
.604 .43175 L
.608 .43173 L
.612 .4317 L
.616 .43168 L
.62 .43169 L
.624 .43172 L
.628 .43178 L
.632 .43183 L
.636 .43186 L
.64 .43187 L
.644 .43185 L
.648 .43182 L
.652 .43181 L
.656 .43182 L
.66 .43186 L
.664 .43191 L
.668 .43195 L
.672 .43197 L
.676 .43197 L
.68 .43195 L
.684 .43193 L
.688 .43194 L
.692 .43196 L
.696 .432 L
.7 .43204 L
.704 .43207 L
.708 .43207 L
.712 .43206 L
.716 .43205 L
.72 .43205 L
.724 .43208 L
.728 .43211 L
.732 .43214 L
.736 .43216 L
.74 .43217 L
.744 .43217 L
.748 .43216 L
.752 .43217 L
.756 .43219 L
.76 .43222 L
.764 .43224 L
.768 .43226 L
.772 .43227 L
.776 .43227 L
.78 .43227 L
.784 .43228 L
.788 .4323 L
.792 .43233 L
.796 .43235 L
.8 .43236 L
Mistroke
.804 .43237 L
.808 .43237 L
.812 .43238 L
.816 .4324 L
.82 .43242 L
.824 .43244 L
.828 .43245 L
.832 .43246 L
.836 .43247 L
.84 .43248 L
.844 .43249 L
.848 .43251 L
.852 .43252 L
.856 .43254 L
.86 .43256 L
.864 .43257 L
.868 .43258 L
.872 .43259 L
.876 .4326 L
.88 .43262 L
.884 .43263 L
.888 .43265 L
.892 .43266 L
.896 .43267 L
.9 .43268 L
.904 .43269 L
.908 .43271 L
.912 .43273 L
.916 .43274 L
.92 .43276 L
.924 .43276 L
.928 .43277 L
.932 .43278 L
.936 .43281 L
.94 .43282 L
.944 .43284 L
.948 .43284 L
.952 .43285 L
.956 .43286 L
.96 .43289 L
.964 .4329 L
.968 .43292 L
.972 .43292 L
.976 .43294 L
.98 .43293 L
.984 .43297 L
.988 .43297 L
.992 .43301 L
.996 .433 L
1 .43303 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .28913 m
.008 .29423 L
.012 .30271 L
.016 .30993 L
.02 .316 L
.024 .32273 L
.028 .32987 L
.032 .33659 L
.036 .34301 L
.04 .35014 L
.044 .35783 L
.048 .36511 L
.052 .3717 L
.056 .3782 L
.06 .38507 L
.064 .39313 L
.068 .40228 L
.072 .4116 L
.076 .42044 L
.08 .42807 L
.084 .43429 L
.088 .43931 L
.092 .44333 L
.096 .44679 L
.1 .44989 L
.104 .45288 L
.108 .45582 L
.112 .45879 L
.116 .46177 L
.12 .46476 L
.124 .46772 L
.128 .47062 L
.132 .47342 L
.136 .47611 L
.14 .47866 L
.144 .48108 L
.148 .48336 L
.152 .48553 L
.156 .4876 L
.16 .48962 L
.164 .49162 L
.168 .49364 L
.172 .4957 L
.176 .49785 L
.18 .50009 L
.184 .50241 L
.188 .50481 L
.192 .50725 L
.196 .50969 L
.2 .51209 L
Mistroke
.204 .51438 L
.208 .51653 L
.212 .51851 L
.216 .52027 L
.22 .52183 L
.224 .52317 L
.228 .52431 L
.232 .52529 L
.236 .52611 L
.24 .5268 L
.244 .52736 L
.248 .52781 L
.252 .52811 L
.256 .52827 L
.26 .52825 L
.264 .52804 L
.268 .52765 L
.272 .5271 L
.276 .52642 L
.28 .52567 L
.284 .52491 L
.288 .52424 L
.292 .5237 L
.296 .52334 L
.3 .52319 L
.304 .52325 L
.308 .52347 L
.312 .52381 L
.316 .5242 L
.32 .52458 L
.324 .52489 L
.328 .52511 L
.332 .5252 L
.336 .52518 L
.34 .52507 L
.344 .52489 L
.348 .52466 L
.352 .52442 L
.356 .52419 L
.36 .52397 L
.364 .52378 L
.368 .52364 L
.372 .52355 L
.376 .52353 L
.38 .52358 L
.384 .52369 L
.388 .52384 L
.392 .524 L
.396 .52412 L
.4 .52416 L
Mistroke
.404 .52412 L
.408 .52397 L
.412 .52374 L
.416 .52348 L
.42 .52323 L
.424 .52306 L
.428 .52299 L
.432 .52303 L
.436 .52315 L
.44 .52331 L
.444 .52345 L
.448 .52352 L
.452 .52348 L
.456 .52335 L
.46 .52315 L
.464 .52294 L
.468 .52276 L
.472 .52266 L
.476 .52264 L
.48 .52269 L
.484 .52277 L
.488 .52284 L
.492 .52288 L
.496 .52284 L
.5 .52275 L
.504 .52263 L
.508 .52249 L
.512 .52238 L
.516 .5223 L
.52 .52227 L
.524 .52227 L
.528 .52229 L
.532 .52231 L
.536 .5223 L
.54 .52227 L
.544 .5222 L
.548 .52211 L
.552 .52202 L
.556 .52193 L
.56 .52187 L
.564 .52183 L
.568 .52182 L
.572 .52182 L
.576 .52182 L
.58 .52181 L
.584 .52176 L
.588 .52168 L
.592 .52159 L
.596 .5215 L
.6 .52143 L
Mistroke
.604 .52139 L
.608 .52139 L
.612 .5214 L
.616 .5214 L
.62 .52136 L
.624 .52129 L
.628 .5212 L
.632 .52111 L
.636 .52104 L
.64 .521 L
.644 .521 L
.648 .521 L
.652 .52099 L
.656 .52095 L
.66 .52087 L
.664 .52079 L
.668 .52071 L
.672 .52065 L
.676 .52063 L
.68 .52062 L
.684 .52062 L
.688 .52058 L
.692 .52052 L
.696 .52045 L
.7 .52037 L
.704 .52031 L
.708 .52028 L
.712 .52026 L
.716 .52025 L
.72 .52021 L
.724 .52016 L
.728 .52009 L
.732 .52003 L
.736 .51997 L
.74 .51993 L
.744 .51991 L
.748 .51988 L
.752 .51985 L
.756 .5198 L
.76 .51974 L
.764 .51967 L
.768 .51962 L
.772 .51959 L
.776 .51956 L
.78 .51953 L
.784 .51948 L
.788 .51943 L
.792 .51938 L
.796 .51932 L
.8 .51928 L
Mistroke
.804 .51924 L
.808 .5192 L
.812 .51917 L
.816 .51912 L
.82 .51907 L
.824 .51902 L
.828 .51897 L
.832 .51893 L
.836 .51889 L
.84 .51885 L
.844 .51881 L
.848 .51877 L
.852 .51871 L
.856 .51866 L
.86 .51861 L
.864 .51858 L
.868 .51854 L
.872 .5185 L
.876 .51845 L
.88 .5184 L
.884 .51835 L
.888 .51831 L
.892 .51827 L
.896 .51823 L
.9 .51818 L
.904 .51814 L
.908 .51809 L
.912 .51805 L
.916 .518 L
.92 .51796 L
.924 .51791 L
.928 .51787 L
.932 .51782 L
.936 .51778 L
.94 .51773 L
.944 .51769 L
.948 .51764 L
.952 .5176 L
.956 .51755 L
.96 .51752 L
.964 .51746 L
.968 .51743 L
.972 .51737 L
.976 .51734 L
.98 .51728 L
.984 .51725 L
.988 .51719 L
.992 .51717 L
.996 .5171 L
1 .51708 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0002Ool20002Ool20004
Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Io
o`04001oogoo0005Ool0029oo`8000aoo`D000=oo`8000=oo`8000=oo`03001oogoo00=oo`8000Ao
o`8000Ioo`04001oogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool2
0006Ool0029oo`03001oogoo01Moo`04001oogoo000:Ool20015Ool0029oo`8001Qoo`04001oogoo
0003Ool40003Ool20002Ool30002Ool20003Ool00`00Oomoo`020002Ool200000goo00000002Ool0
1000Oomoo`009goo000ROomS000<Ool0029oo`03001oogoo008000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo0P0000Aoo`00Oomoo`<0009oo`03001oogoo0080009oo`8000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0000<Ool0029oo`8000=oo`03
001oogoo011oo`03001oogoo00=oo`8004moo`008Woo00<007ooOol00goo00<007ooOol03Woo0P00
EWoo000ROol20004Ool2000?Ool00`00Oomoo`1EOol0029oo`8000Eoo`03001oogoo00aoo`03001o
ogoo05Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol01Goo00<007oo
Ool02goo00<007ooOol0EWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8000Ioo`03001oogoo00]oo`03001oogoo05Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool20006Ool00`00Oomoo`0:Ool00`00Oomoo`1GOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Woo00<007ooOol0Egoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
00Moo`03001oogoo00=oo`03001oo`00009oo`03001oogoo05Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool20004Ool20007Ool00`00Oomoo`02Ool200001Goo000007oo0000FWoo000;Ool2
000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`07Ool01@00Oomoogoo00000goo0`00FWoo000;
Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool20008Ool01000Oomoo`00HGoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool20008Ool01000Oomoo`00HGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00Qoo`80069oo`002Woo
00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007oo
Ool0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`80
06eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=o
o`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0
K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo
00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05
Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomo
o`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool3
0003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004
Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002
Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomo
ogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009o
o`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007oo
Ool0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<0
07ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol0
00Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80
009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00
Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=o
o`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004
Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`00
0goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007oo
Ool000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo
00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo
00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo
0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol00`00IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`03001VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo
00@000=oo`04001oogoo000@Oom9000<Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0006Ool00`00Oomoo`02000=Ool3001DOol000]oo`8000Yoo`8000Aoo`80009oo`D0
009oo`05001oogooOol0000;Ool3001FOol002Qoo`03001oogoo009oo`03001oogoo00Ioo`8005Uo
o`00:7oo00<007ooOol00goo00<007ooOol00goo0P00Fgoo000AOol20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool00`00Oomoo`04Ool00`00Oomoo`02001MOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol017oo1000GWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001o
ogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03
Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000
Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eo
o`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001o
ogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool4
0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`80
00Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P00
17oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P00
1Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo
0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eo
o`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04
001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000
Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool0
0`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003
Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000
Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2
000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P00
17oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yo
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo0P00Lgoo000:Ool01000Oomo
o`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool0
1000Oomoo`001goo10000goo00<007oo0000LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo
0P0000=oo`00Ool0L7oo000;Ool20008Ool50002Ool00`00Oomoo`02001`Ool001aoo`05001oogoo
Ool0001`Ool001aoo`80009oo`03001oogoo06ioo`0077oo00<007ooOol00Woo00<007ooOol0KGoo
000LOol20004Ool00`00Oomoo`1/Ool001aoo`03001oogoo00=oo`03001oogoo06aoo`0077oo00<0
07ooOol017oo00<007ooOol0Jgoo000LOol20005Ool00`00Oomoo`1[Ool001Ioo`<000=oo`03001o
ogoo00Eoo`03001oogoo06Yoo`005goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0JWoo
000GOol00`00Oomoo`02Ool20006Ool2001[Ool001Moo`03001oogoo009oo`03001oogoo00Ioo`80
06Yoo`005goo00<007ooOol00Woo00<007ooOol01goo0P00JGoo000FOol20004Ool20009Ool2001X
Ool001Moo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo06Eoo`0077oo00<007ooOol02goo
0P00IGoo000LOol2000>Ool2001SOol001aoo`03001oogoo00moo`80065oo`0077oo0P004Goo0P00
H7oo000LOol00`00Oomoo`0BOol3000VOol[000<Ool001aoo`03001oogoo01AoobP003Ioo`002Woo
0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;
Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P00
2Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001ao
o`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(12024\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32143 m
.008 .32342 L
.012 .32573 L
.016 .32794 L
.02 .32996 L
.024 .33356 L
.028 .33899 L
.032 .34493 L
.036 .35091 L
.04 .35753 L
.044 .36538 L
.048 .37497 L
.052 .38544 L
.056 .39458 L
.06 .4024 L
.064 .41105 L
.068 .42098 L
.072 .43109 L
.076 .43975 L
.08 .44481 L
.084 .44603 L
.088 .44477 L
.092 .44217 L
.096 .43945 L
.1 .43682 L
.104 .43387 L
.108 .43028 L
.112 .42569 L
.116 .42031 L
.12 .4146 L
.124 .40923 L
.128 .40491 L
.132 .40222 L
.136 .40154 L
.14 .40296 L
.144 .40628 L
.148 .41104 L
.152 .41653 L
.156 .42192 L
.16 .42633 L
.164 .42892 L
.168 .42903 L
.172 .42626 L
.176 .42055 L
.18 .41217 L
.184 .40169 L
.188 .38992 L
.192 .3778 L
.196 .36619 L
.2 .35581 L
Mistroke
.204 .34707 L
.208 .34 L
.212 .33429 L
.216 .32933 L
.22 .32434 L
.224 .31859 L
.228 .31153 L
.232 .30302 L
.236 .29336 L
.24 .28331 L
.244 .27399 L
.248 .26669 L
.252 .26258 L
.256 .2625 L
.26 .2667 L
.264 .2748 L
.268 .28571 L
.272 .29789 L
.276 .30956 L
.28 .31906 L
.284 .32513 L
.288 .32718 L
.292 .32532 L
.296 .32037 L
.3 .31357 L
.304 .30634 L
.308 .29989 L
.312 .29508 L
.316 .29222 L
.32 .29116 L
.324 .2914 L
.328 .29237 L
.332 .29365 L
.336 .29509 L
.34 .29678 L
.344 .29898 L
.348 .30184 L
.352 .30528 L
.356 .30882 L
.36 .31164 L
.364 .31283 L
.368 .31169 L
.372 .30804 L
.376 .30244 L
.38 .29608 L
.384 .29061 L
.388 .28762 L
.392 .28812 L
.396 .29218 L
.4 .29881 L
Mistroke
.404 .30619 L
.408 .3122 L
.412 .31508 L
.416 .31394 L
.42 .30915 L
.424 .30222 L
.428 .29534 L
.432 .29062 L
.436 .28942 L
.44 .29195 L
.444 .29721 L
.448 .30334 L
.452 .30833 L
.456 .31062 L
.46 .30972 L
.464 .30624 L
.468 .3016 L
.472 .29745 L
.476 .29506 L
.48 .295 L
.484 .29695 L
.488 .29998 L
.492 .30292 L
.496 .30483 L
.5 .30535 L
.504 .30461 L
.508 .3031 L
.512 .3014 L
.516 .29994 L
.52 .29901 L
.524 .2987 L
.528 .29901 L
.532 .29986 L
.536 .3011 L
.54 .30251 L
.544 .30372 L
.548 .30424 L
.552 .3037 L
.556 .30212 L
.56 .3 L
.564 .29822 L
.568 .29759 L
.572 .29852 L
.576 .30074 L
.58 .30334 L
.584 .30514 L
.588 .3052 L
.592 .30336 L
.596 .30041 L
.6 .29778 L
Mistroke
.604 .29681 L
.608 .29805 L
.612 .30088 L
.616 .30387 L
.62 .30552 L
.624 .30497 L
.628 .30252 L
.632 .29942 L
.636 .29729 L
.64 .29727 L
.644 .29936 L
.648 .3024 L
.652 .30471 L
.656 .30501 L
.66 .30321 L
.664 .30039 L
.668 .29817 L
.672 .29776 L
.676 .29927 L
.68 .30174 L
.684 .30374 L
.688 .3042 L
.692 .30294 L
.696 .30076 L
.7 .29895 L
.704 .29853 L
.708 .29969 L
.712 .30165 L
.716 .30319 L
.72 .30339 L
.724 .30222 L
.728 .30053 L
.732 .29941 L
.736 .29948 L
.74 .30054 L
.744 .3018 L
.748 .3025 L
.752 .30233 L
.756 .30154 L
.76 .30064 L
.764 .30012 L
.768 .30019 L
.772 .30079 L
.776 .30156 L
.78 .30206 L
.784 .30197 L
.788 .30133 L
.792 .30057 L
.796 .30022 L
.8 .30053 L
Mistroke
.804 .30121 L
.808 .30174 L
.812 .30175 L
.816 .30133 L
.82 .30088 L
.824 .3007 L
.828 .30081 L
.832 .301 L
.836 .30111 L
.84 .30122 L
.844 .30138 L
.848 .30146 L
.852 .30128 L
.856 .30081 L
.86 .3004 L
.864 .30054 L
.868 .30121 L
.872 .30189 L
.876 .30196 L
.88 .30117 L
.884 .3002 L
.888 .29997 L
.892 .30071 L
.896 .30184 L
.9 .30233 L
.904 .30159 L
.908 .30038 L
.912 .29978 L
.916 .3003 L
.92 .3016 L
.924 .30236 L
.928 .30181 L
.932 .30065 L
.936 .29982 L
.94 .3001 L
.944 .30141 L
.948 .30224 L
.952 .30185 L
.956 .30084 L
.96 .29986 L
.964 .30001 L
.968 .30133 L
.972 .30213 L
.976 .30189 L
.98 .30098 L
.984 .2998 L
.988 .29988 L
.992 .30127 L
.996 .30208 L
1 .30205 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .36055 m
.008 .36389 L
.012 .36853 L
.016 .37441 L
.02 .37969 L
.024 .38446 L
.028 .38932 L
.032 .39409 L
.036 .39871 L
.04 .40327 L
.044 .40784 L
.048 .41222 L
.052 .41612 L
.056 .41966 L
.06 .42348 L
.064 .4276 L
.068 .43149 L
.072 .43479 L
.076 .43743 L
.08 .4397 L
.084 .44239 L
.088 .44576 L
.092 .44975 L
.096 .45399 L
.1 .45784 L
.104 .46089 L
.108 .4629 L
.112 .46386 L
.116 .46396 L
.12 .46339 L
.124 .46241 L
.128 .46114 L
.132 .45974 L
.136 .45823 L
.14 .45666 L
.144 .45502 L
.148 .45332 L
.152 .45154 L
.156 .44969 L
.16 .44777 L
.164 .44581 L
.168 .44383 L
.172 .44188 L
.176 .43998 L
.18 .43819 L
.184 .43654 L
.188 .43504 L
.192 .43371 L
.196 .43256 L
.2 .43157 L
Mistroke
.204 .43073 L
.208 .43002 L
.212 .42943 L
.216 .42894 L
.22 .42854 L
.224 .42825 L
.228 .42807 L
.232 .42802 L
.236 .42811 L
.24 .42834 L
.244 .42871 L
.248 .4292 L
.252 .42976 L
.256 .43034 L
.26 .43089 L
.264 .43135 L
.268 .43167 L
.272 .43184 L
.276 .43184 L
.28 .43169 L
.284 .43143 L
.288 .4311 L
.292 .43076 L
.296 .43046 L
.3 .43022 L
.304 .43008 L
.308 .43004 L
.312 .43008 L
.316 .43019 L
.32 .43034 L
.324 .43052 L
.328 .43069 L
.332 .43085 L
.336 .43099 L
.34 .43109 L
.344 .43115 L
.348 .43117 L
.352 .43113 L
.356 .43104 L
.36 .43092 L
.364 .43078 L
.368 .43065 L
.372 .43056 L
.376 .43054 L
.38 .43059 L
.384 .43072 L
.388 .43089 L
.392 .43107 L
.396 .43122 L
.4 .43131 L
Mistroke
.404 .4313 L
.408 .43122 L
.412 .43108 L
.416 .43094 L
.42 .43082 L
.424 .43078 L
.428 .43082 L
.432 .43093 L
.436 .43107 L
.44 .43121 L
.444 .43132 L
.448 .43135 L
.452 .43132 L
.456 .43125 L
.46 .43116 L
.464 .43108 L
.468 .43105 L
.472 .43107 L
.476 .43114 L
.48 .43122 L
.484 .43131 L
.488 .43137 L
.492 .43139 L
.496 .43138 L
.5 .43135 L
.504 .43131 L
.508 .43128 L
.512 .43128 L
.516 .43129 L
.52 .43133 L
.524 .43138 L
.528 .43143 L
.532 .43147 L
.536 .4315 L
.54 .4315 L
.544 .43148 L
.548 .43146 L
.552 .43144 L
.556 .43144 L
.56 .43146 L
.564 .4315 L
.568 .43156 L
.572 .4316 L
.576 .43163 L
.58 .43163 L
.584 .43161 L
.588 .43158 L
.592 .43156 L
.596 .43158 L
.6 .43161 L
Mistroke
.604 .43167 L
.608 .43171 L
.612 .43174 L
.616 .43174 L
.62 .43172 L
.624 .4317 L
.628 .43169 L
.632 .43171 L
.636 .43175 L
.64 .43179 L
.644 .43183 L
.648 .43185 L
.652 .43185 L
.656 .43183 L
.66 .43181 L
.664 .43182 L
.668 .43185 L
.672 .43189 L
.676 .43193 L
.68 .43195 L
.684 .43195 L
.688 .43194 L
.692 .43193 L
.696 .43194 L
.7 .43196 L
.704 .43199 L
.708 .43202 L
.712 .43204 L
.716 .43205 L
.72 .43205 L
.724 .43205 L
.728 .43205 L
.732 .43207 L
.736 .4321 L
.74 .43213 L
.744 .43214 L
.748 .43215 L
.752 .43215 L
.756 .43216 L
.76 .43217 L
.764 .43218 L
.768 .43221 L
.772 .43223 L
.776 .43225 L
.78 .43225 L
.784 .43226 L
.788 .43226 L
.792 .43228 L
.796 .4323 L
.8 .43232 L
Mistroke
.804 .43233 L
.808 .43235 L
.812 .43235 L
.816 .43236 L
.82 .43237 L
.824 .43239 L
.828 .43241 L
.832 .43242 L
.836 .43244 L
.84 .43245 L
.844 .43246 L
.848 .43247 L
.852 .43248 L
.856 .4325 L
.86 .43251 L
.864 .43253 L
.868 .43254 L
.872 .43255 L
.876 .43256 L
.88 .43257 L
.884 .43259 L
.888 .43261 L
.892 .43262 L
.896 .43264 L
.9 .43264 L
.904 .43265 L
.908 .43267 L
.912 .43269 L
.916 .4327 L
.92 .43272 L
.924 .43272 L
.928 .43274 L
.932 .43275 L
.936 .43277 L
.94 .43278 L
.944 .4328 L
.948 .4328 L
.952 .43282 L
.956 .43282 L
.96 .43285 L
.964 .43285 L
.968 .43288 L
.972 .43288 L
.976 .4329 L
.98 .4329 L
.984 .43293 L
.988 .43293 L
.992 .43296 L
.996 .43295 L
1 .43299 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .24426 m
.008 .24851 L
.012 .25837 L
.016 .26649 L
.02 .27273 L
.024 .27968 L
.028 .28738 L
.032 .29488 L
.036 .3021 L
.04 .30985 L
.044 .31809 L
.048 .3262 L
.052 .33401 L
.056 .34207 L
.06 .35068 L
.064 .35997 L
.068 .36958 L
.072 .37869 L
.076 .38719 L
.08 .39572 L
.084 .40478 L
.088 .41489 L
.092 .4259 L
.096 .43709 L
.1 .44779 L
.104 .45729 L
.108 .46528 L
.112 .47174 L
.116 .47681 L
.12 .48082 L
.124 .48401 L
.128 .48669 L
.132 .48903 L
.136 .49119 L
.14 .49327 L
.144 .49535 L
.148 .49747 L
.152 .49967 L
.156 .50195 L
.16 .50431 L
.164 .50673 L
.168 .50916 L
.172 .51157 L
.176 .5139 L
.18 .5161 L
.184 .51814 L
.188 .51998 L
.192 .5216 L
.196 .52301 L
.2 .52422 L
Mistroke
.204 .52523 L
.208 .52609 L
.212 .5268 L
.216 .52739 L
.22 .52786 L
.224 .5282 L
.228 .52839 L
.232 .52843 L
.236 .52829 L
.24 .52798 L
.244 .52749 L
.248 .52686 L
.252 .52614 L
.256 .52538 L
.26 .52467 L
.264 .52407 L
.268 .52363 L
.272 .5234 L
.276 .52337 L
.28 .52353 L
.284 .52382 L
.288 .52421 L
.292 .5246 L
.296 .52496 L
.3 .52522 L
.304 .52537 L
.308 .5254 L
.312 .52532 L
.316 .52515 L
.32 .52494 L
.324 .5247 L
.328 .52445 L
.332 .52422 L
.336 .52403 L
.34 .52387 L
.344 .52376 L
.348 .52372 L
.352 .52374 L
.356 .52382 L
.36 .52394 L
.364 .52409 L
.368 .52423 L
.372 .52431 L
.376 .52432 L
.38 .52422 L
.384 .52404 L
.388 .52379 L
.392 .52354 L
.396 .52332 L
.4 .52319 L
Mistroke
.404 .52317 L
.408 .52325 L
.412 .52339 L
.416 .52354 L
.42 .52366 L
.424 .52368 L
.428 .52361 L
.432 .52345 L
.436 .52324 L
.44 .52303 L
.444 .52288 L
.448 .5228 L
.452 .52281 L
.456 .52288 L
.46 .52297 L
.464 .52303 L
.468 .52304 L
.472 .52299 L
.476 .52288 L
.48 .52275 L
.484 .52261 L
.488 .52251 L
.492 .52245 L
.496 .52244 L
.5 .52245 L
.504 .52247 L
.508 .52248 L
.512 .52246 L
.516 .52241 L
.52 .52234 L
.524 .52225 L
.528 .52216 L
.532 .52208 L
.536 .52202 L
.54 .52199 L
.544 .52199 L
.548 .52199 L
.552 .52198 L
.556 .52196 L
.56 .5219 L
.564 .52182 L
.568 .52173 L
.572 .52164 L
.576 .52158 L
.58 .52156 L
.584 .52156 L
.588 .52156 L
.592 .52155 L
.596 .52151 L
.6 .52144 L
Mistroke
.604 .52134 L
.608 .52126 L
.612 .52119 L
.616 .52116 L
.62 .52116 L
.624 .52116 L
.628 .52115 L
.632 .5211 L
.636 .52102 L
.64 .52093 L
.644 .52086 L
.648 .52081 L
.652 .52079 L
.656 .52078 L
.66 .52077 L
.664 .52074 L
.668 .52068 L
.672 .5206 L
.676 .52052 L
.68 .52047 L
.684 .52043 L
.688 .52042 L
.692 .5204 L
.696 .52037 L
.7 .52031 L
.704 .52025 L
.708 .52018 L
.712 .52013 L
.716 .52009 L
.72 .52006 L
.724 .52004 L
.728 .52 L
.732 .51995 L
.736 .51989 L
.74 .51983 L
.744 .51978 L
.748 .51974 L
.752 .51971 L
.756 .51968 L
.76 .51964 L
.764 .51959 L
.768 .51953 L
.772 .51948 L
.776 .51943 L
.78 .51939 L
.784 .51936 L
.788 .51932 L
.792 .51928 L
.796 .51923 L
.8 .51918 L
Mistroke
.804 .51912 L
.808 .51908 L
.812 .51904 L
.816 .51901 L
.82 .51897 L
.824 .51892 L
.828 .51887 L
.832 .51882 L
.836 .51877 L
.84 .51873 L
.844 .51869 L
.848 .51865 L
.852 .51861 L
.856 .51856 L
.86 .51851 L
.864 .51846 L
.868 .51842 L
.872 .51838 L
.876 .51834 L
.88 .51829 L
.884 .51825 L
.888 .5182 L
.892 .51815 L
.896 .51811 L
.9 .51807 L
.904 .51803 L
.908 .51798 L
.912 .51794 L
.916 .51789 L
.92 .51784 L
.924 .51779 L
.928 .51776 L
.932 .51771 L
.936 .51768 L
.94 .51762 L
.944 .51758 L
.948 .51752 L
.952 .51749 L
.956 .51744 L
.96 .51741 L
.964 .51735 L
.968 .51732 L
.972 .51725 L
.976 .51723 L
.98 .51717 L
.984 .51715 L
.988 .51708 L
.992 .51706 L
.996 .51698 L
1 .51696 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`03001oogoo008000Eoo`8000Aoo`04
001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@0
07ooOol000Eoo`008Woo0P0037oo1@000goo0`0000=oo`00Ool017oo00<007ooOol00goo0P0017oo
0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`80
00Ioo`008Woo00<007ooOol05Goo00<007oo00002goo00<007ooOol0AWoo000ROol2000EOol01@00
Oomoogoo00000goo0`000goo0`000Woo0P000Woo0P000goo00@007ooOomoo`80009oo`04001oogoo
0002Ool20002Ool00`00Oomoo`0WOol0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool02@00Oomoogoo001oo`00Ool00002Ool01@00Ool007oo00000goo0P000Woo0`00
00Ioo`00Ool007oo0003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`0:
Ool0029oo`<0019oo`8000Eoo`80055oo`008Woo00@007oo0000015oo`03001oogoo05Moo`008Woo
0P0000=oo`00Ool03goo00<007ooOol0F7oo000ROol20002Ool00`00Oomoo`0=Ool00`00Oomoo`1H
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`05001oogooOol0000>Ool00`00Oomo
o`1IOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P000goo00<007oo
Ool02goo00<007ooOol0FGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8000=oo`03001oogoo00Yoo`03001oogoo05Yoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`1JOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0017oo00<007ooOol00goo10000Woo00<0
07ooOol0FWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8000Eoo`04001oogoo
Ool20002Ool01000Ool00000G7oo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool01@00Oomoogoo000017oo0P00GGoo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2
0006Ool3001TOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8000Io
o`8006Eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/
Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007oo
Ool000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029o
o`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool2
0003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003
Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03
001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00
Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D0
07ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001o
ogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo
00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo
0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001o
ogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`00
0goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomo
ogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eo
o`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04
001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool2
0004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`00
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool0
00030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`00
1Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Io
o`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Ao
o`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool2
0006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qoo`03001o
ogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001o
ogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo0P00Igoo000XOol3001VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=o
o`04001oo`00001UOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003
Ool01000Oomoo`000Woo00<007ooOol0Hgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04
001oogoo0005Ool01000Oomoo`000goo00<007ooOol0HWoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`020002Ool2001SOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00=oo`03001oogoo00Uood/000ao
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00Ao
o`8000Ioo`<005Moo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol01Goo0P000goo
0`00FGoo000XOol00`00Oomoo`06Ool5001KOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015o
o`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogoo
Ool00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05
Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006ao
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yo
o`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`80
00Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol0
00Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool0
0`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<0
00=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P00
3Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000
Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo1000
0goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06
001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo
00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol0
17oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07
001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007oo
Ool00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0
009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000ao
o`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol2001cOol0
01aoo`<0079oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007oo0000LWoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`04001oogoo001aOol000Yoo`04001oogoo000;Ool00`00
Oomoo`020002Ool00`00Oomoo`1^Ool000Yoo`04001oogoo000;Ool01000Oomoo`000goo00<007oo
Ool0KWoo000:Ool01000Oomoo`001goo10000goo00@007ooOomoo`8006moo`002Woo00@007ooOol0
00Moo`03001oogoo00Aoo`8000=oo`03001oogoo06eoo`002goo0P0027oo1@000Woo00<007ooOol0
0goo00<007ooOol0K7oo000LOol00`00Oomoo`03Ool00`00Oomoo`1/Ool001aoo`8000Aoo`03001o
ogoo06aoo`0077oo00<007ooOol017oo00<007ooOol0Jgoo000LOol20005Ool00`00Oomoo`1[Ool0
01aoo`03001oogoo00Eoo`03001oogoo06Yoo`0077oo00<007ooOol01Goo00<007ooOol0JWoo000L
Ool20006Ool2001[Ool001Ioo`<000=oo`03001oogoo00Ioo`03001oogoo06Uoo`005goo00<007oo
Ool00Woo00<007ooOol01Woo00<007ooOol0JGoo000GOol00`00Oomoo`02Ool20008Ool00`00Oomo
o`1XOol001Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo06Qoo`005goo00<007ooOol0
0Woo00<007ooOol027oo00<007ooOol0Igoo000FOol20004Ool20009Ool00`00Oomoo`1WOol001Mo
o`03001oogoo009oo`03001oogoo00Qoo`8006Qoo`0077oo00<007ooOol02Goo0P00Igoo000LOol2
000;Ool2001VOol001aoo`03001oogoo00aoo`8006Aoo`0077oo0P003goo0P00HWoo000LOol00`00
Oomoo`0?Ool3000YOol[000<Ool001aoo`03001oogoo015oob/003Ioo`002Woo0`0017oo00<007oo
Ool00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02
001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol0
17oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(12191\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .36805 m
.008 .37173 L
.012 .3758 L
.016 .38161 L
.02 .38897 L
.024 .39678 L
.028 .40508 L
.032 .4141 L
.036 .42313 L
.04 .43134 L
.044 .43888 L
.048 .44647 L
.052 .45319 L
.056 .45681 L
.06 .45731 L
.064 .45688 L
.068 .45593 L
.072 .453 L
.076 .44701 L
.08 .43772 L
.084 .42669 L
.088 .41687 L
.092 .40938 L
.096 .40351 L
.1 .39829 L
.104 .39267 L
.108 .38708 L
.112 .3831 L
.116 .38199 L
.12 .38468 L
.124 .39081 L
.128 .39914 L
.132 .40803 L
.136 .41567 L
.14 .42074 L
.144 .42234 L
.148 .42015 L
.152 .41439 L
.156 .40563 L
.16 .39477 L
.164 .38284 L
.168 .37087 L
.172 .35973 L
.176 .35003 L
.18 .34202 L
.184 .33559 L
.188 .33025 L
.192 .32531 L
.196 .32 L
.2 .31368 L
Mistroke
.204 .30598 L
.208 .29697 L
.212 .2872 L
.216 .27761 L
.22 .2694 L
.224 .26383 L
.228 .26192 L
.232 .26422 L
.236 .27067 L
.24 .28051 L
.244 .29242 L
.248 .30469 L
.252 .31555 L
.256 .3235 L
.26 .32757 L
.264 .32749 L
.268 .32376 L
.272 .31743 L
.276 .30989 L
.28 .30257 L
.284 .29658 L
.288 .29257 L
.292 .29065 L
.296 .29047 L
.3 .29145 L
.304 .29301 L
.308 .29474 L
.312 .29653 L
.316 .29852 L
.32 .30094 L
.324 .30388 L
.328 .30713 L
.332 .31014 L
.336 .31212 L
.34 .31225 L
.344 .31004 L
.348 .30558 L
.352 .29966 L
.356 .29366 L
.36 .28919 L
.364 .28759 L
.368 .28955 L
.372 .29474 L
.376 .30185 L
.38 .30892 L
.384 .31388 L
.388 .31526 L
.392 .31264 L
.396 .30682 L
.4 .29958 L
Mistroke
.404 .29317 L
.408 .28953 L
.412 .2897 L
.416 .29344 L
.42 .29937 L
.424 .30548 L
.428 .30981 L
.432 .3111 L
.436 .30917 L
.44 .30494 L
.444 .30004 L
.448 .29614 L
.452 .29442 L
.456 .29515 L
.46 .29775 L
.464 .3011 L
.468 .30401 L
.472 .30561 L
.476 .30563 L
.48 .30437 L
.484 .30249 L
.488 .30065 L
.492 .29933 L
.496 .2987 L
.5 .29876 L
.504 .29942 L
.508 .3005 L
.512 .3018 L
.516 .30305 L
.52 .3039 L
.524 .30402 L
.528 .30321 L
.532 .30157 L
.536 .29961 L
.54 .29814 L
.544 .29787 L
.548 .2991 L
.552 .3014 L
.556 .30381 L
.56 .30522 L
.564 .30489 L
.568 .30287 L
.572 .29999 L
.576 .29763 L
.58 .29699 L
.584 .29847 L
.588 .30138 L
.592 .30426 L
.596 .30563 L
.6 .30478 L
Mistroke
.604 .30215 L
.608 .29911 L
.612 .29723 L
.616 .29747 L
.62 .2997 L
.624 .30273 L
.628 .3049 L
.632 .30504 L
.636 .30311 L
.64 .30023 L
.644 .29805 L
.648 .29775 L
.652 .29941 L
.656 .30198 L
.66 .30398 L
.664 .30433 L
.668 .30293 L
.672 .30067 L
.676 .29887 L
.68 .29853 L
.684 .29976 L
.688 .30177 L
.692 .30333 L
.696 .30352 L
.7 .30233 L
.704 .30056 L
.708 .29936 L
.712 .29939 L
.716 .30051 L
.72 .3019 L
.724 .30271 L
.728 .30252 L
.732 .3016 L
.736 .30058 L
.74 .30003 L
.744 .3002 L
.748 .3009 L
.752 .3017 L
.756 .30215 L
.76 .302 L
.764 .30135 L
.768 .30062 L
.772 .3003 L
.776 .30057 L
.78 .30121 L
.784 .30175 L
.788 .30183 L
.792 .30147 L
.796 .30099 L
.8 .30072 L
Mistroke
.804 .30076 L
.808 .30097 L
.812 .3012 L
.816 .30138 L
.82 .3015 L
.824 .30147 L
.828 .30122 L
.832 .30081 L
.836 .30052 L
.84 .3007 L
.844 .3013 L
.848 .30186 L
.852 .30186 L
.856 .30118 L
.86 .30039 L
.864 .30021 L
.868 .30081 L
.872 .30174 L
.876 .30212 L
.88 .30156 L
.884 .30063 L
.888 .30014 L
.892 .30052 L
.896 .30145 L
.9 .30199 L
.904 .30164 L
.908 .30087 L
.912 .30033 L
.916 .30053 L
.92 .3013 L
.924 .30172 L
.928 .30148 L
.932 .30094 L
.936 .3005 L
.94 .30071 L
.944 .30136 L
.948 .30153 L
.952 .30125 L
.956 .30085 L
.96 .30051 L
.964 .30089 L
.968 .30154 L
.972 .30149 L
.976 .30112 L
.98 .30068 L
.984 .30033 L
.988 .30095 L
.992 .30174 L
.996 .3016 L
1 .3012 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .322 m
.008 .3231 L
.012 .32674 L
.016 .33287 L
.02 .338 L
.024 .34202 L
.028 .34608 L
.032 .35017 L
.036 .35401 L
.04 .3576 L
.044 .36114 L
.048 .36456 L
.052 .36764 L
.056 .37047 L
.06 .37353 L
.064 .37682 L
.068 .37994 L
.072 .38271 L
.076 .38537 L
.08 .38822 L
.084 .39165 L
.088 .39555 L
.092 .39934 L
.096 .40269 L
.1 .40564 L
.104 .40848 L
.108 .41179 L
.112 .41582 L
.116 .42049 L
.12 .42546 L
.124 .43014 L
.128 .4341 L
.132 .43701 L
.136 .43879 L
.14 .43953 L
.144 .43942 L
.148 .43872 L
.152 .43763 L
.156 .43637 L
.16 .43506 L
.164 .43381 L
.168 .43266 L
.172 .43166 L
.176 .43079 L
.18 .43006 L
.184 .42944 L
.188 .42894 L
.192 .42852 L
.196 .42821 L
.2 .428 L
Mistroke
.204 .42791 L
.208 .42795 L
.212 .42814 L
.216 .42845 L
.22 .42889 L
.224 .42941 L
.228 .42999 L
.232 .43055 L
.236 .43105 L
.24 .43143 L
.244 .43167 L
.248 .43174 L
.252 .43166 L
.256 .43144 L
.26 .43113 L
.264 .43078 L
.268 .43045 L
.272 .43018 L
.276 .42999 L
.28 .42991 L
.284 .42992 L
.288 .43 L
.292 .43015 L
.296 .43032 L
.3 .4305 L
.304 .43067 L
.308 .43081 L
.312 .43093 L
.316 .431 L
.32 .43104 L
.324 .43102 L
.328 .43096 L
.332 .43085 L
.336 .43072 L
.34 .43059 L
.344 .43048 L
.348 .43042 L
.352 .43044 L
.356 .43052 L
.36 .43067 L
.364 .43085 L
.368 .43102 L
.372 .43114 L
.376 .43119 L
.38 .43115 L
.384 .43104 L
.388 .4309 L
.392 .43076 L
.396 .43068 L
.4 .43066 L
Mistroke
.404 .43073 L
.408 .43086 L
.412 .43101 L
.416 .43114 L
.42 .43122 L
.424 .43123 L
.428 .43118 L
.432 .43109 L
.436 .431 L
.44 .43094 L
.444 .43093 L
.448 .43097 L
.452 .43104 L
.456 .43113 L
.46 .43121 L
.464 .43126 L
.468 .43127 L
.472 .43125 L
.476 .43122 L
.48 .43118 L
.484 .43115 L
.488 .43115 L
.492 .43118 L
.496 .43123 L
.5 .43128 L
.504 .43133 L
.508 .43136 L
.512 .43138 L
.516 .43137 L
.52 .43135 L
.524 .43133 L
.528 .43132 L
.532 .43132 L
.536 .43135 L
.54 .4314 L
.544 .43145 L
.548 .43149 L
.552 .43151 L
.556 .4315 L
.56 .43148 L
.564 .43146 L
.568 .43145 L
.572 .43146 L
.576 .4315 L
.58 .43155 L
.584 .4316 L
.588 .43162 L
.592 .43162 L
.596 .4316 L
.6 .43158 L
Mistroke
.604 .43157 L
.608 .43159 L
.612 .43163 L
.616 .43168 L
.62 .43172 L
.624 .43173 L
.628 .43172 L
.632 .43171 L
.636 .4317 L
.64 .4317 L
.644 .43173 L
.648 .43177 L
.652 .43181 L
.656 .43183 L
.66 .43183 L
.664 .43182 L
.668 .43181 L
.672 .43182 L
.676 .43184 L
.68 .43187 L
.684 .43191 L
.688 .43193 L
.692 .43193 L
.696 .43193 L
.7 .43193 L
.704 .43194 L
.708 .43195 L
.712 .43198 L
.716 .43201 L
.72 .43203 L
.724 .43203 L
.728 .43204 L
.732 .43204 L
.736 .43205 L
.74 .43207 L
.744 .43209 L
.748 .43211 L
.752 .43213 L
.756 .43213 L
.76 .43214 L
.764 .43215 L
.768 .43216 L
.772 .43218 L
.776 .4322 L
.78 .43222 L
.784 .43223 L
.788 .43224 L
.792 .43224 L
.796 .43225 L
.8 .43227 L
Mistroke
.804 .43229 L
.808 .43231 L
.812 .43232 L
.816 .43233 L
.82 .43234 L
.824 .43235 L
.828 .43236 L
.832 .43238 L
.836 .4324 L
.84 .43241 L
.844 .43242 L
.848 .43243 L
.852 .43244 L
.856 .43246 L
.86 .43247 L
.864 .43249 L
.868 .4325 L
.872 .43252 L
.876 .43252 L
.88 .43254 L
.884 .43255 L
.888 .43257 L
.892 .43258 L
.896 .4326 L
.9 .43261 L
.904 .43262 L
.908 .43263 L
.912 .43265 L
.916 .43266 L
.92 .43268 L
.924 .43268 L
.928 .4327 L
.932 .43271 L
.936 .43273 L
.94 .43274 L
.944 .43276 L
.948 .43276 L
.952 .43278 L
.956 .43279 L
.96 .43281 L
.964 .43281 L
.968 .43284 L
.972 .43284 L
.976 .43287 L
.98 .43287 L
.984 .43289 L
.988 .43289 L
.992 .43292 L
.996 .43291 L
1 .43295 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .19938 m
.008 .20877 L
.012 .21574 L
.016 .22375 L
.02 .2326 L
.024 .24121 L
.028 .24971 L
.032 .25843 L
.036 .26725 L
.04 .27635 L
.044 .28576 L
.048 .29516 L
.052 .30442 L
.056 .31381 L
.06 .3235 L
.064 .33347 L
.068 .34341 L
.072 .35284 L
.076 .36181 L
.08 .37102 L
.084 .38067 L
.088 .39052 L
.092 .40009 L
.096 .40883 L
.1 .41676 L
.104 .42452 L
.108 .43266 L
.112 .44171 L
.116 .45164 L
.12 .46198 L
.124 .47217 L
.128 .48161 L
.132 .48991 L
.136 .49694 L
.14 .50272 L
.144 .50745 L
.148 .5113 L
.152 .51447 L
.156 .51711 L
.16 .51932 L
.164 .52118 L
.168 .52275 L
.172 .52406 L
.176 .52516 L
.18 .52606 L
.184 .52681 L
.188 .52742 L
.192 .52791 L
.196 .52827 L
.2 .52851 L
Mistroke
.204 .52859 L
.208 .52852 L
.212 .52826 L
.216 .52784 L
.22 .52727 L
.224 .52659 L
.228 .52585 L
.232 .52512 L
.236 .52447 L
.24 .52397 L
.244 .52364 L
.248 .52353 L
.252 .52361 L
.256 .52385 L
.26 .52421 L
.264 .52461 L
.268 .52499 L
.272 .52531 L
.276 .52551 L
.28 .52559 L
.284 .52556 L
.288 .52542 L
.292 .52522 L
.296 .52497 L
.3 .52472 L
.304 .52448 L
.308 .52427 L
.312 .5241 L
.316 .52398 L
.32 .52392 L
.324 .52391 L
.328 .52396 L
.332 .52406 L
.336 .5242 L
.34 .52434 L
.344 .52444 L
.348 .52449 L
.352 .52444 L
.356 .52431 L
.36 .5241 L
.364 .52385 L
.368 .52361 L
.372 .52343 L
.376 .52335 L
.38 .52337 L
.384 .52347 L
.388 .52362 L
.392 .52376 L
.396 .52385 L
.4 .52383 L
Mistroke
.404 .52372 L
.408 .52354 L
.412 .52333 L
.416 .52314 L
.42 .52301 L
.424 .52297 L
.428 .523 L
.432 .52308 L
.436 .52316 L
.44 .52321 L
.444 .5232 L
.448 .52313 L
.452 .52301 L
.456 .52287 L
.46 .52274 L
.464 .52265 L
.468 .52261 L
.472 .5226 L
.476 .52262 L
.48 .52265 L
.484 .52265 L
.488 .52262 L
.492 .52256 L
.496 .52248 L
.5 .52238 L
.504 .52229 L
.508 .52222 L
.512 .52218 L
.516 .52216 L
.52 .52216 L
.524 .52216 L
.528 .52214 L
.532 .52211 L
.536 .52204 L
.54 .52196 L
.544 .52187 L
.548 .52179 L
.552 .52174 L
.556 .52172 L
.56 .52172 L
.564 .52172 L
.568 .52171 L
.572 .52166 L
.576 .52158 L
.58 .52149 L
.584 .52141 L
.588 .52135 L
.592 .52132 L
.596 .52132 L
.6 .52132 L
Mistroke
.604 .5213 L
.608 .52125 L
.612 .52117 L
.616 .52108 L
.62 .52101 L
.624 .52097 L
.628 .52095 L
.632 .52094 L
.636 .52093 L
.64 .52089 L
.644 .52083 L
.648 .52075 L
.652 .52068 L
.656 .52062 L
.66 .52059 L
.664 .52057 L
.668 .52056 L
.672 .52052 L
.676 .52047 L
.68 .5204 L
.684 .52033 L
.688 .52028 L
.692 .52024 L
.696 .52022 L
.7 .52019 L
.704 .52016 L
.708 .52011 L
.712 .52004 L
.716 .51998 L
.72 .51993 L
.724 .5199 L
.728 .51987 L
.732 .51984 L
.736 .51979 L
.74 .51974 L
.744 .51969 L
.748 .51963 L
.752 .51959 L
.756 .51955 L
.76 .51951 L
.764 .51948 L
.768 .51943 L
.772 .51938 L
.776 .51933 L
.78 .51928 L
.784 .51924 L
.788 .5192 L
.792 .51916 L
.796 .51912 L
.8 .51907 L
Mistroke
.804 .51902 L
.808 .51897 L
.812 .51893 L
.816 .51889 L
.82 .51885 L
.824 .51881 L
.828 .51876 L
.832 .51871 L
.836 .51866 L
.84 .51862 L
.844 .51858 L
.848 .51854 L
.852 .51849 L
.856 .51845 L
.86 .5184 L
.864 .51836 L
.868 .51831 L
.872 .51827 L
.876 .51822 L
.88 .51818 L
.884 .51814 L
.888 .51809 L
.892 .51804 L
.896 .518 L
.9 .51795 L
.904 .51791 L
.908 .51787 L
.912 .51783 L
.916 .51778 L
.92 .51773 L
.924 .51768 L
.928 .51765 L
.932 .5176 L
.936 .51756 L
.94 .51751 L
.944 .51747 L
.948 .51741 L
.952 .51738 L
.956 .51733 L
.96 .5173 L
.964 .51724 L
.968 .51721 L
.972 .51714 L
.976 .51712 L
.98 .51706 L
.984 .51704 L
.988 .51697 L
.992 .51695 L
.996 .51687 L
1 .51685 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`@000Ioo`8000Aoo`04001oogoo0002
Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eo
o`008Woo0P0037oo1@000Woo0`0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D0
00=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol0
4Woo00@007ooOol000]oo`03001oogoo04Qoo`008Woo0P004Woo00D007ooOomoo`0000=oo`@000=o
o`8000=oo`80009oo`80009oo`8000=oo`03001oogoo0080009oo`04001oogoo0002Ool00`00Oomo
o`0ZOol0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo0P0000=oo`00Ool00Woo1@000Woo0P000Woo0P000goo00D007ooOomoo`0000=oo`05
001oogooOol00002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000aoo`008Woo0P004Goo00<007ooOol00goo0P00
E7oo000ROol00`00Oomoo`0?Ool00`00Oomoo`1JOol0029oo`8000moo`8005aoo`008Woo0P003goo
00<007ooOol0Fgoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2000?Ool00`00Oomo
o`1KOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P003goo00<007oo
Ool0Fgoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`<000Qoo`8000=o
o`03001oogoo05aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Ool00007Ool01000Oomoo`000Woo00<007ooOol0G7oo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`800003Ool007oo00Aoo`80009oo`03001oo`0005moo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool20004Ool200000goo001oo`04Ool01000Oomoogoo0`00Ggoo000;
Ool2000:Ool20004Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol00goo00<007oo
Ool0GWoo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool20002Ool01@00Oomoogoo0000
IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool01000Oomo
o`00IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo009o
o`<006Moo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008
Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eo
o`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool0
00Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007oo
Ool000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]
Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yo
o`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`00
8Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool2
0003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool2
0004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007oo
Ool0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003
Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05
001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007oo
Ool00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007oo
Ool03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`80
00Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001o
ogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001o
ogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003
Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03
001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001o
ogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06
001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo
00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo
0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D0
00=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo
0P0047oo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007oo
Ool02Woo000XOol3001VOol002Qoo`04001oo`00001UOol002Qoo`04001oogoo001UOol002Qoo`04
001oogooOol2001SOol002Qoo`03001oogoo009oo`80069oo`002goo0P0017oo00<007ooOol00goo
0P0017oo0P000goo0`000goo00<007ooOol00goo0P00HGoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`000goo00@007ooOol000Moo`03001oogoo05ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol000Qoo`8005ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P0027oo0P00GGoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`08Ool0
1000OomoogooCP0037oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`00
1Woo00<007ooOol02Goo1000FGoo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001W
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P00
17oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool0
0`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04
001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007oo
Ool00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@0
07ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007oo
Ool00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007oo
Ool000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079o
o`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo
0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomo
ogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomo
o`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00
Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`00
27oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomo
o`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00
Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004
Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo
0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00
Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`8007=oo`0077oo0P00Lgoo000LOol2001cOol001aoo`03001oo`00079oo`00
77oo00<007oo0000LWoo000LOol200000goo001oo`1`Ool001aoo`05001oogooOol0001`Ool001ao
o`80009oo`03001oogoo06ioo`002goo0P0017oo00<007ooOol00Woo0`000goo00D007ooOomoo`00
071oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`1]
Ool000Yoo`04001oogoo000;Ool00`00Oomoo`020003Ool00`00Oomoo`1]Ool000Yoo`04001oogoo
000;Ool01000Oomoo`001Goo00<007ooOol0K7oo000:Ool01000Oomoo`001goo10000goo00<007oo
Ool00goo00<007ooOol0K7oo000:Ool01000Oomoo`001goo00<007ooOol017oo0P0017oo00<007oo
Ool0K7oo000;Ool20008Ool50002Ool00`00Oomoo`04Ool00`00Oomoo`1[Ool001aoo`03001oogoo
00Aoo`03001oogoo06]oo`0077oo0P001Woo00<007ooOol0JWoo000LOol00`00Oomoo`05Ool00`00
Oomoo`1ZOol001aoo`8000Ioo`03001oogoo06Yoo`0077oo00<007ooOol01Woo00<007ooOol0JGoo
000LOol00`00Oomoo`06Ool00`00Oomoo`1YOol001aoo`8000Qoo`03001oogoo06Qoo`005Woo0`00
0goo00<007ooOol01goo00<007ooOol0J7oo000GOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00
Oomoo`1WOol001Moo`03001oogoo009oo`8000Uoo`03001oogoo06Moo`005goo00<007ooOol00Woo
00<007ooOol02Goo00<007ooOol0IWoo000GOol00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomo
o`1VOol001Ioo`8000Aoo`8000]oo`03001oogoo06Eoo`005goo00<007ooOol00Woo00<007ooOol0
2Woo00<007ooOol0IGoo000LOol00`00Oomoo`0:Ool00`00Oomoo`1UOol001aoo`8000aoo`03001o
ogoo06Aoo`0077oo00<007ooOol02goo00<007ooOol0I7oo000LOol2000=Ool2001TOol001aoo`03
001oogoo00eoo`8002]oob`000aoo`0077oo00<007ooOol03goo:`00>7oo000:Ool30004Ool00`00
Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo
008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomo
o`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(12358\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .46016 m
.008 .46492 L
.012 .46909 L
.016 .47354 L
.02 .47816 L
.024 .48119 L
.028 .48243 L
.032 .48254 L
.036 .48122 L
.04 .47741 L
.044 .47139 L
.048 .46455 L
.052 .45687 L
.056 .447 L
.06 .43553 L
.064 .4251 L
.068 .41679 L
.072 .40968 L
.076 .40317 L
.08 .39764 L
.084 .39455 L
.088 .39565 L
.092 .40021 L
.096 .40535 L
.1 .40909 L
.104 .41104 L
.108 .41192 L
.112 .41295 L
.116 .41371 L
.12 .41231 L
.124 .40695 L
.128 .3965 L
.132 .38163 L
.136 .36449 L
.14 .34755 L
.144 .33317 L
.148 .32259 L
.152 .31601 L
.156 .3128 L
.16 .31171 L
.164 .31139 L
.168 .31054 L
.172 .30819 L
.176 .3038 L
.18 .29731 L
.184 .28919 L
.188 .28034 L
.192 .27199 L
.196 .26549 L
.2 .26206 L
Mistroke
.204 .26254 L
.208 .26722 L
.212 .2757 L
.216 .28694 L
.22 .29938 L
.224 .31125 L
.228 .32087 L
.232 .32695 L
.236 .32886 L
.24 .3267 L
.244 .32126 L
.248 .31384 L
.252 .3059 L
.256 .29881 L
.26 .29354 L
.264 .29049 L
.268 .28959 L
.272 .29031 L
.276 .292 L
.28 .29406 L
.284 .29614 L
.288 .2982 L
.292 .30039 L
.296 .30289 L
.3 .30574 L
.304 .30865 L
.308 .31101 L
.312 .31207 L
.316 .31115 L
.32 .308 L
.324 .30296 L
.328 .29703 L
.332 .29165 L
.336 .28834 L
.34 .2882 L
.344 .29152 L
.348 .2976 L
.352 .30487 L
.356 .31129 L
.36 .31499 L
.364 .31484 L
.368 .31085 L
.372 .30421 L
.376 .29697 L
.38 .29132 L
.384 .28895 L
.388 .29048 L
.392 .29528 L
.396 .30167 L
.4 .30753 L
Mistroke
.404 .31102 L
.408 .31118 L
.412 .30824 L
.416 .30341 L
.42 .29845 L
.424 .295 L
.428 .29403 L
.432 .29556 L
.436 .29876 L
.44 .30234 L
.444 .30507 L
.448 .30622 L
.452 .30569 L
.456 .30396 L
.46 .30178 L
.464 .29989 L
.468 .29877 L
.472 .29851 L
.476 .299 L
.48 .29996 L
.484 .30119 L
.488 .30244 L
.492 .30346 L
.496 .30397 L
.5 .30372 L
.504 .30266 L
.508 .30101 L
.512 .29929 L
.516 .29819 L
.52 .29827 L
.524 .2997 L
.528 .30199 L
.532 .30418 L
.536 .30523 L
.54 .30454 L
.544 .30234 L
.548 .29957 L
.552 .29754 L
.556 .29726 L
.56 .29896 L
.564 .30188 L
.568 .30459 L
.572 .30567 L
.576 .30456 L
.58 .30179 L
.584 .29881 L
.588 .29717 L
.592 .2977 L
.596 .3001 L
.6 .30308 L
Mistroke
.604 .30507 L
.608 .305 L
.612 .30295 L
.616 .30006 L
.62 .29795 L
.624 .29777 L
.628 .29956 L
.632 .30222 L
.636 .30421 L
.64 .30445 L
.644 .3029 L
.648 .30056 L
.652 .29878 L
.656 .29852 L
.66 .29985 L
.664 .30191 L
.668 .30347 L
.672 .30364 L
.676 .30241 L
.68 .30058 L
.684 .29931 L
.688 .29933 L
.692 .3005 L
.696 .302 L
.7 .30289 L
.704 .3027 L
.708 .30168 L
.712 .30054 L
.716 .29995 L
.72 .30018 L
.724 .30098 L
.728 .30184 L
.732 .30227 L
.736 .30206 L
.74 .30137 L
.744 .30065 L
.748 .30033 L
.752 .3006 L
.756 .30124 L
.76 .3018 L
.764 .30192 L
.768 .30158 L
.772 .30107 L
.776 .30073 L
.78 .30073 L
.784 .30098 L
.788 .30129 L
.792 .30151 L
.796 .30158 L
.8 .30147 L
Mistroke
.804 .30119 L
.808 .30084 L
.812 .30065 L
.816 .30084 L
.82 .30134 L
.824 .3018 L
.828 .30181 L
.832 .30127 L
.836 .3006 L
.84 .30039 L
.844 .30083 L
.848 .30159 L
.852 .30198 L
.856 .30164 L
.86 .3009 L
.864 .30042 L
.868 .30059 L
.872 .30126 L
.876 .30174 L
.88 .30165 L
.884 .30117 L
.888 .30072 L
.892 .3007 L
.896 .30109 L
.9 .30137 L
.904 .30138 L
.908 .30122 L
.912 .301 L
.916 .30102 L
.92 .30116 L
.924 .30108 L
.928 .30102 L
.932 .30106 L
.936 .30113 L
.94 .30137 L
.944 .30137 L
.948 .30094 L
.952 .30072 L
.956 .30081 L
.96 .3011 L
.964 .30164 L
.968 .30164 L
.972 .30095 L
.976 .30054 L
.98 .30051 L
.984 .30091 L
.988 .30179 L
.992 .3019 L
.996 .30109 L
1 .30053 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .2702 m
.008 .27423 L
.012 .27824 L
.016 .28224 L
.02 .28646 L
.024 .29075 L
.028 .29461 L
.032 .29816 L
.036 .30164 L
.04 .30504 L
.044 .30843 L
.048 .31182 L
.052 .31509 L
.056 .31829 L
.06 .32174 L
.064 .32545 L
.068 .32913 L
.072 .33262 L
.076 .33611 L
.08 .33978 L
.084 .34378 L
.088 .34786 L
.092 .35157 L
.096 .35482 L
.1 .35798 L
.104 .36137 L
.108 .36517 L
.112 .36918 L
.116 .37292 L
.12 .37614 L
.124 .37895 L
.128 .38169 L
.132 .38493 L
.136 .38899 L
.14 .3939 L
.144 .39941 L
.148 .40507 L
.152 .41041 L
.156 .41507 L
.16 .41885 L
.164 .42174 L
.168 .42381 L
.172 .42524 L
.176 .4262 L
.18 .42689 L
.184 .42743 L
.188 .42794 L
.192 .42846 L
.196 .42902 L
.2 .4296 L
Mistroke
.204 .43019 L
.208 .43073 L
.212 .43116 L
.216 .43147 L
.22 .43161 L
.224 .43159 L
.228 .43142 L
.232 .43115 L
.236 .43081 L
.24 .43046 L
.244 .43016 L
.248 .42993 L
.252 .42979 L
.256 .42976 L
.26 .42982 L
.264 .42995 L
.268 .43012 L
.272 .4303 L
.276 .43048 L
.28 .43064 L
.284 .43077 L
.288 .43085 L
.292 .4309 L
.296 .4309 L
.3 .43086 L
.304 .43077 L
.308 .43066 L
.312 .43053 L
.316 .43041 L
.32 .43033 L
.324 .43031 L
.328 .43035 L
.332 .43047 L
.336 .43063 L
.34 .4308 L
.344 .43095 L
.348 .43104 L
.352 .43105 L
.356 .43098 L
.36 .43086 L
.364 .43072 L
.368 .4306 L
.372 .43054 L
.376 .43056 L
.38 .43065 L
.384 .43079 L
.388 .43094 L
.392 .43105 L
.396 .43111 L
.4 .4311 L
Mistroke
.404 .43103 L
.408 .43094 L
.412 .43085 L
.416 .43081 L
.42 .43081 L
.424 .43087 L
.428 .43095 L
.432 .43104 L
.436 .43111 L
.44 .43115 L
.444 .43115 L
.448 .43112 L
.452 .43108 L
.456 .43104 L
.46 .43103 L
.464 .43104 L
.468 .43107 L
.472 .43112 L
.476 .43118 L
.48 .43122 L
.484 .43125 L
.488 .43125 L
.492 .43124 L
.496 .43122 L
.5 .4312 L
.504 .4312 L
.508 .43121 L
.512 .43124 L
.516 .43129 L
.52 .43134 L
.524 .43137 L
.528 .43138 L
.532 .43137 L
.536 .43135 L
.54 .43133 L
.544 .43133 L
.548 .43135 L
.552 .43139 L
.556 .43144 L
.56 .43148 L
.564 .4315 L
.568 .4315 L
.572 .43148 L
.576 .43146 L
.58 .43146 L
.584 .43148 L
.588 .43152 L
.592 .43157 L
.596 .4316 L
.6 .43161 L
Mistroke
.604 .4316 L
.608 .43159 L
.612 .43158 L
.616 .43159 L
.62 .43162 L
.624 .43166 L
.628 .43169 L
.632 .43171 L
.636 .43171 L
.64 .4317 L
.644 .4317 L
.648 .4317 L
.652 .43173 L
.656 .43176 L
.66 .43179 L
.664 .43181 L
.668 .43181 L
.672 .43181 L
.676 .43181 L
.68 .43182 L
.684 .43184 L
.688 .43186 L
.692 .43189 L
.696 .43191 L
.7 .43192 L
.704 .43192 L
.708 .43192 L
.712 .43193 L
.716 .43195 L
.72 .43197 L
.724 .43199 L
.728 .43201 L
.732 .43202 L
.736 .43202 L
.74 .43203 L
.744 .43204 L
.748 .43206 L
.752 .43208 L
.756 .4321 L
.76 .43211 L
.764 .43212 L
.768 .43213 L
.772 .43214 L
.776 .43215 L
.78 .43217 L
.784 .43219 L
.788 .4322 L
.792 .43221 L
.796 .43222 L
.8 .43223 L
Mistroke
.804 .43224 L
.808 .43226 L
.812 .43228 L
.816 .4323 L
.82 .43231 L
.824 .43232 L
.828 .43233 L
.832 .43234 L
.836 .43235 L
.84 .43237 L
.844 .43239 L
.848 .4324 L
.852 .43241 L
.856 .43242 L
.86 .43243 L
.864 .43245 L
.868 .43246 L
.872 .43248 L
.876 .43249 L
.88 .4325 L
.884 .43251 L
.888 .43253 L
.892 .43254 L
.896 .43256 L
.9 .43257 L
.904 .43258 L
.908 .43259 L
.912 .43261 L
.916 .43262 L
.92 .43264 L
.924 .43265 L
.928 .43267 L
.932 .43267 L
.936 .43269 L
.94 .4327 L
.944 .43272 L
.948 .43272 L
.952 .43275 L
.956 .43275 L
.96 .43277 L
.964 .43277 L
.968 .4328 L
.972 .4328 L
.976 .43283 L
.98 .43283 L
.984 .43286 L
.988 .43285 L
.992 .43288 L
.996 .43287 L
1 .43291 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16888 L
.012 .17587 L
.016 .18508 L
.02 .19652 L
.024 .2074 L
.028 .2176 L
.032 .22785 L
.036 .23817 L
.04 .24845 L
.044 .25865 L
.048 .26866 L
.052 .27836 L
.056 .28789 L
.06 .29735 L
.064 .30682 L
.068 .31609 L
.072 .3249 L
.076 .33338 L
.08 .34209 L
.084 .35115 L
.088 .36023 L
.092 .369 L
.096 .37739 L
.1 .38571 L
.104 .39456 L
.108 .40407 L
.112 .41387 L
.116 .42341 L
.12 .43221 L
.124 .44027 L
.128 .44807 L
.132 .45607 L
.136 .46471 L
.14 .47399 L
.144 .48355 L
.148 .4929 L
.152 .50147 L
.156 .50887 L
.16 .51489 L
.164 .51952 L
.168 .52291 L
.172 .52524 L
.176 .52673 L
.18 .52755 L
.184 .52788 L
.188 .52782 L
.192 .52748 L
.196 .52694 L
.2 .52627 L
Mistroke
.204 .52556 L
.208 .52489 L
.212 .52432 L
.216 .52392 L
.22 .52372 L
.224 .52372 L
.228 .5239 L
.232 .52421 L
.236 .52461 L
.24 .52501 L
.244 .52537 L
.248 .52563 L
.252 .52577 L
.256 .52578 L
.26 .52568 L
.264 .52549 L
.268 .52526 L
.272 .525 L
.276 .52475 L
.28 .52452 L
.284 .52434 L
.288 .5242 L
.292 .52412 L
.296 .52409 L
.3 .52412 L
.304 .52419 L
.308 .52431 L
.312 .52444 L
.316 .52456 L
.32 .52464 L
.324 .52464 L
.328 .52455 L
.332 .52438 L
.336 .52416 L
.34 .52391 L
.344 .5237 L
.348 .52356 L
.352 .52352 L
.356 .52358 L
.36 .5237 L
.364 .52385 L
.368 .52397 L
.372 .52402 L
.376 .52397 L
.38 .52383 L
.384 .52363 L
.388 .52342 L
.392 .52325 L
.396 .52315 L
.4 .52314 L
Mistroke
.404 .52319 L
.408 .52328 L
.412 .52336 L
.416 .52339 L
.42 .52336 L
.424 .52326 L
.428 .52313 L
.432 .52298 L
.436 .52287 L
.44 .52279 L
.444 .52277 L
.448 .52278 L
.452 .5228 L
.456 .52282 L
.46 .52281 L
.464 .52277 L
.468 .5227 L
.472 .52261 L
.476 .52252 L
.48 .52243 L
.484 .52237 L
.488 .52234 L
.492 .52233 L
.496 .52232 L
.5 .52232 L
.504 .5223 L
.508 .52225 L
.512 .52219 L
.516 .5221 L
.52 .52201 L
.524 .52194 L
.528 .5219 L
.532 .52189 L
.536 .52189 L
.54 .52188 L
.544 .52186 L
.548 .5218 L
.552 .52172 L
.556 .52163 L
.56 .52156 L
.564 .52151 L
.568 .52148 L
.572 .52148 L
.576 .52148 L
.58 .52145 L
.584 .5214 L
.588 .52132 L
.592 .52123 L
.596 .52116 L
.6 .52112 L
Mistroke
.604 .5211 L
.608 .5211 L
.612 .52108 L
.616 .52104 L
.62 .52098 L
.624 .5209 L
.628 .52083 L
.632 .52078 L
.636 .52075 L
.64 .52073 L
.644 .52071 L
.648 .52068 L
.652 .52062 L
.656 .52055 L
.66 .52049 L
.664 .52043 L
.668 .5204 L
.672 .52037 L
.676 .52035 L
.68 .52031 L
.684 .52026 L
.688 .5202 L
.692 .52014 L
.696 .52009 L
.7 .52005 L
.704 .52002 L
.708 .51999 L
.712 .51995 L
.716 .5199 L
.72 .51984 L
.724 .51979 L
.728 .51974 L
.732 .5197 L
.736 .51967 L
.74 .51963 L
.744 .51959 L
.748 .51954 L
.752 .51949 L
.756 .51943 L
.76 .51939 L
.764 .51935 L
.768 .51932 L
.772 .51928 L
.776 .51923 L
.78 .51918 L
.784 .51913 L
.788 .51908 L
.792 .51904 L
.796 .519 L
.8 .51896 L
Mistroke
.804 .51892 L
.808 .51887 L
.812 .51882 L
.816 .51877 L
.82 .51873 L
.824 .51869 L
.828 .51865 L
.832 .51861 L
.836 .51856 L
.84 .51851 L
.844 .51846 L
.848 .51842 L
.852 .51838 L
.856 .51834 L
.86 .51829 L
.864 .51825 L
.868 .5182 L
.872 .51815 L
.876 .51811 L
.88 .51807 L
.884 .51803 L
.888 .51798 L
.892 .51793 L
.896 .51789 L
.9 .51784 L
.904 .5178 L
.908 .51776 L
.912 .51772 L
.916 .51767 L
.92 .51762 L
.924 .51757 L
.928 .51754 L
.932 .51749 L
.936 .51745 L
.94 .5174 L
.944 .51736 L
.948 .5173 L
.952 .51727 L
.956 .51722 L
.96 .51719 L
.964 .51713 L
.968 .5171 L
.972 .51704 L
.976 .51701 L
.98 .51695 L
.984 .51692 L
.988 .51686 L
.992 .51683 L
.996 .51676 L
1 .51675 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo009oo`<0009oo`03001oogoo00Aoo`8000Ao
o`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo
00@007ooOol000Eoo`008Woo0P0037oo1P0000Aoo`00000000Qoo`03001oogoo00=oo`8000Aoo`80
00Ioo`04001oogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006
Ool0029oo`03001oogoo00moo`04001oogoo000;Ool00`00Oomoo`1;Ool0029oo`80011oo`04001o
ogoo0003Ool40003Ool00`00Ool00002Ool20002Ool30002Ool01000Oomoogoo0P000Woo00<007oo
Ool00P000Woo00@007ooOol002ioo`008WooH`0037oo000ROol01@00Oomoogoo00000goo00D007oo
Oomoo`00009oo`<0009oo`05001oo`00Ool00002Ool00`00Oomoo`020003Ool20002Ool20002Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`04001oogoo0003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol02Woo
000ROol2000=Ool00`00Oomoo`04Ool3001FOol0029oo`03001oogoo00]oo`03001oogoo05ioo`00
8Woo0P0037oo00<007ooOol0GWoo000ROol2000<Ool00`00Oomoo`1NOol000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`03001oogoo00Yoo`03001oogoo05moo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2000;Ool00`00Oomoo`1OOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P002goo00<007ooOol0Ggoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00Eoo`8000=oo`03001oogoo05moo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20005Ool2000017oo001oo`00
HWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8000Eoo`04001oogooOol2001R
Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo06Ioo`002goo
0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P0017oo00<007ooOol0IWoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P000goo00<007ooOol0Igoo000:Ool01000
Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol20002Ool2001YOol000Yoo`04001oogoo0008
Ool01P00Oomoo`00Ool000=oo`03001oogoo00D006Yoo`002Woo00@007ooOol000Qoo`06001oogoo
001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00
Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007oo
Ool000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`00
0goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomo
o`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogoo
Ool00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo
10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001o
ogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo
0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool0
0`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=o
o`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00
Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<0
00Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00
009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001o
ogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
0Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomo
o`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo
0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@0
07ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo
001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`00
0goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`80
00Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo
0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000
Oomoo`001Goo000XOol2000:Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000
Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol0
0`00Ool0001VOol002Qoo`04001oogoo001UOol002Qooed000aoo`00:7oo00<007ooOol00Woo0P00
2goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol0
2Woo000XOol00`00Oomoo`03Ool2001QOol002Qoo`03001oogoo00Aoo`80061oo`00:7oo00<007oo
Ool01Goo0P00Ggoo000XOol00`00Oomoo`06Ool2001NOol002Qoo`03001oogoo00Moo`8005eoo`00
2goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol02Goo0P00Fgoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol000aoo`03
001oogoo05Uoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Ool000eoo`03001oogoo05Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol00P0037oo0P00FGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001o
ogoo001oo`040003Ool00`00Oomoo`0<Oom>000<Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000A
Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomo
ogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
1Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:
Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool2
0004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo
000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo
00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool3
0003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`80
00eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009o
o`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001o
ogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@0
07ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@0
00=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool0
1P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Ao
o`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo
00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool0
1`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001o
ogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool3
0002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<
Ool001aoo`80009oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol2001cOol001ao
o`<0079oo`0077oo00<007oo0000LWoo000LOol01000Oomoo`00LGoo000LOol200000goo001oo`1`
Ool001aoo`05001oogooOol0001`Ool001aoo`05001oogooOol0001`Ool001aoo`80009oo`03001o
ogoo06ioo`0077oo00<007ooOol00Woo00<007ooOol0KGoo000LOol20003Ool00`00Oomoo`1]Ool0
00]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo00=oo`03001oogoo06aoo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`03Ool00`00Oomoo`1/Ool000Yoo`04001o
ogoo000;Ool00`00Oomoo`020004Ool00`00Oomoo`1/Ool000Yoo`04001oogoo000;Ool01000Oomo
o`001Woo00<007ooOol0Jgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol017oo00<007oo
Ool0Jgoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P001Woo00<007ooOol0JWoo000;Ool2
0008Ool50002Ool00`00Oomoo`05Ool00`00Oomoo`1ZOol001aoo`03001oogoo00Eoo`03001oogoo
06Yoo`0077oo0P001goo00<007ooOol0JGoo000LOol00`00Oomoo`06Ool00`00Oomoo`1YOol001ao
o`8000Qoo`03001oogoo06Qoo`0077oo00<007ooOol01goo0P00JGoo000LOol00`00Oomoo`08Ool0
0`00Oomoo`1WOol001aoo`8000Uoo`03001oogoo06Moo`005Woo0`000goo00<007ooOol02Goo00<0
07ooOol0IWoo000GOol00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`1VOol001Moo`03001o
ogoo009oo`8000]oo`03001oogoo06Eoo`005goo00<007ooOol00Woo00<007ooOol02Woo00<007oo
Ool0IGoo000GOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`1UOol001Ioo`8000Aoo`80
00aoo`03001oogoo06Aoo`005goo00<007ooOol00Woo00<007ooOol02goo00<007ooOol0I7oo000L
Ool00`00Oomoo`0<Ool00`00Oomoo`1SOol001aoo`8000eoo`03001oogoo06=oo`0077oo00<007oo
Ool03Goo00<007ooOol0HWoo000LOol2000>Ool00`00Oomoo`1ROol001aoo`03001oogoo00ioo`03
001oogoo02Qoobd000aoo`0077oo00<007ooOol03goo:`00>7oo000:Ool30004Ool00`00Oomoo`02
Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=o
o`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool0
0`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(12525\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .5413 m
.008 .54166 L
.012 .53875 L
.016 .53363 L
.02 .52669 L
.024 .51624 L
.028 .50289 L
.032 .48828 L
.036 .4735 L
.04 .45908 L
.044 .44596 L
.048 .43553 L
.052 .42817 L
.056 .42256 L
.06 .41869 L
.064 .41787 L
.068 .42013 L
.072 .42358 L
.076 .42636 L
.08 .42764 L
.084 .42774 L
.088 .42733 L
.092 .42521 L
.096 .41887 L
.1 .40788 L
.104 .39422 L
.108 .38033 L
.112 .36787 L
.116 .35657 L
.12 .34479 L
.124 .33222 L
.128 .32008 L
.132 .31015 L
.136 .30377 L
.14 .3003 L
.144 .29742 L
.148 .29261 L
.152 .28403 L
.156 .27165 L
.16 .25713 L
.164 .24298 L
.168 .23198 L
.172 .22614 L
.176 .22656 L
.18 .23324 L
.184 .24521 L
.188 .26089 L
.192 .27824 L
.196 .29516 L
.2 .30967 L
Mistroke
.204 .32029 L
.208 .32612 L
.212 .32705 L
.216 .32371 L
.22 .31732 L
.224 .30942 L
.228 .3016 L
.232 .29514 L
.236 .29085 L
.24 .28894 L
.244 .28909 L
.248 .29068 L
.252 .29299 L
.256 .29546 L
.26 .2978 L
.264 .30001 L
.268 .30228 L
.272 .30474 L
.276 .30736 L
.28 .30978 L
.284 .31139 L
.288 .3115 L
.292 .30961 L
.296 .30569 L
.3 .30032 L
.304 .29465 L
.308 .29014 L
.312 .28812 L
.316 .28941 L
.32 .29392 L
.324 .30061 L
.328 .30771 L
.332 .31322 L
.336 .31549 L
.34 .31381 L
.344 .30863 L
.348 .30148 L
.352 .29453 L
.356 .28987 L
.36 .28889 L
.364 .29176 L
.368 .29744 L
.372 .30402 L
.376 .30937 L
.38 .31185 L
.384 .31086 L
.388 .30698 L
.392 .30171 L
.396 .2969 L
.4 .29407 L
Mistroke
.404 .29395 L
.408 .29627 L
.412 .29996 L
.416 .30362 L
.42 .30606 L
.424 .30665 L
.428 .30553 L
.432 .30334 L
.436 .30098 L
.44 .29917 L
.444 .29833 L
.448 .29848 L
.452 .29936 L
.456 .30061 L
.46 .30191 L
.464 .30302 L
.468 .30373 L
.472 .30388 L
.476 .30333 L
.48 .30211 L
.484 .3005 L
.488 .29904 L
.492 .29832 L
.496 .29876 L
.5 .30035 L
.504 .30255 L
.508 .30445 L
.512 .30514 L
.516 .30416 L
.52 .30184 L
.524 .29919 L
.528 .29748 L
.532 .29758 L
.536 .29951 L
.54 .30241 L
.544 .30486 L
.548 .30563 L
.552 .30428 L
.556 .30144 L
.56 .29856 L
.564 .29715 L
.568 .29795 L
.572 .3005 L
.576 .30346 L
.58 .30524 L
.584 .30493 L
.588 .30274 L
.592 .29987 L
.596 .29788 L
.6 .29785 L
Mistroke
.604 .29975 L
.608 .30245 L
.612 .30442 L
.616 .30455 L
.62 .30288 L
.624 .30044 L
.628 .29867 L
.632 .29851 L
.636 .29996 L
.64 .30208 L
.644 .30363 L
.648 .30375 L
.652 .30245 L
.656 .30058 L
.66 .29928 L
.664 .29928 L
.668 .3005 L
.672 .30209 L
.676 .30306 L
.68 .30287 L
.684 .30177 L
.688 .30052 L
.692 .29987 L
.696 .30014 L
.7 .30105 L
.704 .30198 L
.708 .30241 L
.712 .30214 L
.716 .3014 L
.72 .30066 L
.724 .30035 L
.728 .30063 L
.732 .30128 L
.736 .30186 L
.74 .30202 L
.744 .30169 L
.748 .30114 L
.752 .30074 L
.756 .30071 L
.76 .301 L
.764 .30138 L
.768 .30163 L
.772 .30166 L
.776 .30148 L
.78 .30118 L
.784 .30088 L
.788 .30076 L
.792 .30095 L
.796 .30137 L
.8 .30176 L
Mistroke
.804 .30178 L
.808 .30135 L
.812 .30078 L
.816 .30054 L
.82 .30084 L
.824 .30148 L
.828 .3019 L
.832 .30173 L
.836 .30115 L
.84 .30064 L
.844 .30063 L
.848 .3011 L
.852 .30159 L
.856 .3017 L
.86 .30142 L
.864 .30099 L
.868 .3008 L
.872 .30094 L
.876 .30118 L
.88 .30138 L
.884 .30144 L
.888 .30132 L
.892 .30117 L
.896 .30102 L
.9 .30087 L
.904 .30098 L
.908 .30127 L
.912 .30149 L
.916 .30155 L
.92 .30122 L
.924 .30071 L
.928 .30064 L
.932 .30101 L
.936 .30152 L
.94 .30185 L
.944 .30144 L
.948 .30065 L
.952 .30041 L
.956 .30076 L
.96 .30147 L
.964 .30206 L
.968 .30163 L
.972 .30066 L
.976 .30027 L
.98 .30051 L
.984 .30136 L
.988 .30222 L
.992 .30182 L
.996 .30073 L
1 .30021 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .24449 m
.008 .24596 L
.012 .24647 L
.016 .24611 L
.02 .24509 L
.024 .24361 L
.028 .24318 L
.032 .24404 L
.036 .2464 L
.04 .25012 L
.044 .25434 L
.048 .25885 L
.052 .26328 L
.056 .26759 L
.06 .27192 L
.064 .27627 L
.068 .28042 L
.072 .28426 L
.076 .28793 L
.08 .29161 L
.084 .29539 L
.088 .29914 L
.092 .30261 L
.096 .30586 L
.1 .30932 L
.104 .3132 L
.108 .31742 L
.112 .32172 L
.116 .3258 L
.12 .32971 L
.124 .33385 L
.128 .33851 L
.132 .34373 L
.136 .34925 L
.14 .35459 L
.144 .35949 L
.148 .36401 L
.152 .36844 L
.156 .37326 L
.16 .37879 L
.164 .38513 L
.168 .39209 L
.172 .39926 L
.176 .4062 L
.18 .41248 L
.184 .41782 L
.188 .42208 L
.192 .42526 L
.196 .42747 L
.2 .42886 L
Mistroke
.204 .42961 L
.208 .42993 L
.212 .42997 L
.216 .42987 L
.22 .42973 L
.224 .42962 L
.228 .42958 L
.232 .42963 L
.236 .42974 L
.24 .42991 L
.244 .4301 L
.248 .43029 L
.252 .43046 L
.256 .4306 L
.26 .4307 L
.264 .43076 L
.268 .43078 L
.272 .43075 L
.276 .43068 L
.28 .43058 L
.284 .43046 L
.288 .43034 L
.292 .43025 L
.296 .43019 L
.3 .43021 L
.304 .43028 L
.308 .43042 L
.312 .43059 L
.316 .43075 L
.32 .43087 L
.324 .43093 L
.328 .4309 L
.332 .43081 L
.336 .43068 L
.34 .43054 L
.344 .43045 L
.348 .43042 L
.352 .43047 L
.356 .43058 L
.36 .43073 L
.364 .43086 L
.368 .43096 L
.372 .43099 L
.376 .43096 L
.38 .43088 L
.384 .43078 L
.388 .43071 L
.392 .43068 L
.396 .4307 L
.4 .43077 L
Mistroke
.404 .43086 L
.408 .43095 L
.412 .43101 L
.416 .43104 L
.42 .43102 L
.424 .43099 L
.428 .43094 L
.432 .43091 L
.436 .4309 L
.44 .43092 L
.444 .43097 L
.448 .43102 L
.452 .43107 L
.456 .43111 L
.46 .43113 L
.464 .43113 L
.468 .43111 L
.472 .43109 L
.476 .43108 L
.48 .43108 L
.484 .4311 L
.488 .43114 L
.492 .43118 L
.496 .43123 L
.5 .43125 L
.504 .43126 L
.508 .43125 L
.512 .43123 L
.516 .43121 L
.52 .43121 L
.524 .43124 L
.528 .43128 L
.532 .43133 L
.536 .43137 L
.54 .43138 L
.544 .43137 L
.548 .43135 L
.552 .43134 L
.556 .43134 L
.56 .43137 L
.564 .43141 L
.568 .43145 L
.572 .43148 L
.576 .43149 L
.58 .43148 L
.584 .43147 L
.588 .43146 L
.592 .43147 L
.596 .4315 L
.6 .43154 L
Mistroke
.604 .43157 L
.608 .43159 L
.612 .43159 L
.616 .43158 L
.62 .43158 L
.624 .43159 L
.628 .43161 L
.632 .43164 L
.636 .43167 L
.64 .43169 L
.644 .4317 L
.648 .43169 L
.652 .43169 L
.656 .4317 L
.66 .43172 L
.664 .43175 L
.668 .43177 L
.672 .43179 L
.676 .4318 L
.68 .4318 L
.684 .4318 L
.688 .43181 L
.692 .43183 L
.696 .43185 L
.7 .43188 L
.704 .43189 L
.708 .4319 L
.712 .4319 L
.716 .43191 L
.72 .43192 L
.724 .43194 L
.728 .43196 L
.732 .43198 L
.736 .43199 L
.74 .432 L
.744 .43201 L
.748 .43202 L
.752 .43203 L
.756 .43205 L
.76 .43207 L
.764 .43209 L
.768 .4321 L
.772 .43211 L
.776 .43211 L
.78 .43213 L
.784 .43214 L
.788 .43216 L
.792 .43218 L
.796 .43219 L
.8 .4322 L
Mistroke
.804 .43221 L
.808 .43222 L
.812 .43224 L
.816 .43225 L
.82 .43227 L
.824 .43228 L
.828 .43229 L
.832 .4323 L
.836 .43232 L
.84 .43233 L
.844 .43235 L
.848 .43236 L
.852 .43237 L
.856 .43239 L
.86 .4324 L
.864 .43241 L
.868 .43242 L
.872 .43244 L
.876 .43245 L
.88 .43247 L
.884 .43248 L
.888 .43249 L
.892 .4325 L
.896 .43252 L
.9 .43253 L
.904 .43255 L
.908 .43256 L
.912 .43257 L
.916 .43258 L
.92 .4326 L
.924 .43261 L
.928 .43263 L
.932 .43263 L
.936 .43265 L
.94 .43266 L
.944 .43268 L
.948 .43268 L
.952 .43271 L
.956 .43271 L
.96 .43273 L
.964 .43274 L
.968 .43276 L
.972 .43276 L
.976 .43279 L
.98 .43279 L
.984 .43282 L
.988 .43281 L
.992 .43284 L
.996 .43284 L
1 .43287 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16536 L
.012 .17331 L
.016 .17938 L
.02 .18361 L
.024 .1879 L
.028 .19252 L
.032 .19889 L
.036 .20709 L
.04 .21627 L
.044 .22616 L
.048 .236 L
.052 .24566 L
.056 .25516 L
.06 .26459 L
.064 .27407 L
.068 .28351 L
.072 .2927 L
.076 .30175 L
.08 .31104 L
.084 .3206 L
.088 .33008 L
.092 .3392 L
.096 .34799 L
.1 .35669 L
.104 .36564 L
.108 .37468 L
.112 .38332 L
.116 .39126 L
.12 .39861 L
.124 .40578 L
.128 .41328 L
.132 .42118 L
.136 .42914 L
.14 .43667 L
.144 .4434 L
.148 .44937 L
.152 .45499 L
.156 .46076 L
.16 .46712 L
.164 .47416 L
.168 .48169 L
.172 .48931 L
.176 .49654 L
.18 .50299 L
.184 .50844 L
.188 .51283 L
.192 .51625 L
.196 .51884 L
.2 .52081 L
Mistroke
.204 .52231 L
.208 .52347 L
.212 .52437 L
.216 .52505 L
.22 .52552 L
.224 .52581 L
.228 .52593 L
.232 .5259 L
.236 .52576 L
.24 .52554 L
.244 .52528 L
.248 .52502 L
.252 .52478 L
.256 .52458 L
.26 .52442 L
.264 .52432 L
.268 .52427 L
.272 .52428 L
.276 .52434 L
.28 .52444 L
.284 .52456 L
.288 .52468 L
.292 .52477 L
.296 .52481 L
.3 .52477 L
.304 .52464 L
.308 .52445 L
.312 .52422 L
.316 .52399 L
.32 .5238 L
.324 .52371 L
.328 .52371 L
.332 .5238 L
.336 .52394 L
.34 .52408 L
.344 .52417 L
.348 .52418 L
.352 .52409 L
.356 .52392 L
.36 .52371 L
.364 .52351 L
.368 .52337 L
.372 .5233 L
.376 .52332 L
.38 .52339 L
.384 .52348 L
.388 .52355 L
.392 .52356 L
.396 .5235 L
.4 .52339 L
Mistroke
.404 .52324 L
.408 .52311 L
.412 .523 L
.416 .52294 L
.42 .52293 L
.424 .52295 L
.428 .52298 L
.432 .52299 L
.436 .52297 L
.44 .52292 L
.444 .52284 L
.448 .52274 L
.452 .52265 L
.456 .52258 L
.46 .52253 L
.464 .5225 L
.468 .52249 L
.472 .52249 L
.476 .52248 L
.48 .52245 L
.484 .5224 L
.488 .52232 L
.492 .52224 L
.496 .52216 L
.5 .5221 L
.504 .52206 L
.508 .52205 L
.512 .52205 L
.516 .52204 L
.52 .52201 L
.524 .52195 L
.528 .52187 L
.532 .52178 L
.536 .52171 L
.54 .52166 L
.544 .52165 L
.548 .52164 L
.552 .52163 L
.556 .5216 L
.56 .52154 L
.564 .52146 L
.568 .52138 L
.572 .52132 L
.576 .52128 L
.58 .52126 L
.584 .52125 L
.588 .52123 L
.592 .52119 L
.596 .52113 L
.6 .52105 L
Mistroke
.604 .52098 L
.608 .52093 L
.612 .5209 L
.616 .52089 L
.62 .52087 L
.624 .52083 L
.628 .52077 L
.632 .5207 L
.636 .52064 L
.64 .52059 L
.644 .52055 L
.648 .52053 L
.652 .5205 L
.656 .52046 L
.66 .52041 L
.664 .52035 L
.668 .52029 L
.672 .52024 L
.676 .52021 L
.68 .52018 L
.684 .52014 L
.688 .5201 L
.692 .52005 L
.696 .52 L
.7 .51994 L
.704 .51989 L
.708 .51986 L
.712 .51982 L
.716 .51979 L
.72 .51974 L
.724 .51969 L
.728 .51964 L
.732 .51959 L
.736 .51955 L
.74 .51951 L
.744 .51947 L
.748 .51943 L
.752 .51938 L
.756 .51933 L
.76 .51928 L
.764 .51924 L
.768 .5192 L
.772 .51916 L
.776 .51912 L
.78 .51907 L
.784 .51902 L
.788 .51898 L
.792 .51893 L
.796 .51889 L
.8 .51885 L
Mistroke
.804 .5188 L
.808 .51876 L
.812 .51871 L
.816 .51867 L
.82 .51862 L
.824 .51858 L
.828 .51853 L
.832 .51849 L
.836 .51845 L
.84 .5184 L
.844 .51835 L
.848 .51831 L
.852 .51826 L
.856 .51822 L
.86 .51818 L
.864 .51814 L
.868 .51809 L
.872 .51804 L
.876 .518 L
.88 .51796 L
.884 .51791 L
.888 .51787 L
.892 .51782 L
.896 .51778 L
.9 .51773 L
.904 .51769 L
.908 .51764 L
.912 .5176 L
.916 .51755 L
.92 .51751 L
.924 .51746 L
.928 .51743 L
.932 .51738 L
.936 .51734 L
.94 .51729 L
.944 .51725 L
.948 .5172 L
.952 .51716 L
.956 .51711 L
.96 .51707 L
.964 .51701 L
.968 .51698 L
.972 .51693 L
.976 .5169 L
.98 .51684 L
.984 .51681 L
.988 .51674 L
.992 .51672 L
.996 .51665 L
1 .51664 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`03001oogoo0080009oo`04001oogoo
0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool0
1000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007oo
Ool00Woo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8000moo`80009oo`04001oogoo0007Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P003Woo00<007oo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`05001o
ogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol017oo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;
Ool50002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
1000Oomoogoo10000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@0
07ooOol000=oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo
00<007ooOol00Woo0P0037oo00D007oo001oo`00009oo`04001oogoo0006Ool20004Ool01000Oomo
o`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo
0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogoo
Ool50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001o
ogoo00aoo`05001oogooOol0000;Ool00`00Oomoo`1=Ool0029oo`8000aoo`8000=oo`04001oogoo
Ool30004Ool20002Ool30002Ool20002Ool20003Ool01@00Oomoogoo00000Woo00<007ooOol00P00
00=oo`000000<7oo000ROomS000<Ool0029oo`05001oogooOol00003Ool01000Oomoogoo0P000Woo
00T007ooOomoo`00Ool007oo00000Woo0`0000Moo`00000007oo001oo`030003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`04001oogoo0003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol02Woo000ROol2000;
Ool00`00Oomoo`04Ool2001IOol0029oo`03001oogoo00Uoo`03001oogoo061oo`008Woo0P002Woo
00<007ooOol0H7oo000ROol20009Ool00`00Oomoo`1QOol000]oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`03001oogoo00Qoo`03001oogoo065oo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool20009Ool00`00Oomoo`1QOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P002Goo00<007ooOol0HGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo00Moo`03001oogoo069oo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool20008Ool00`00Oomoo`1ROol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo0P0017oo0P0017oo0P000Woo00<007ooOol0HWoo000;Ool2000:Ool20004
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool5001UOol000]oo`8000Aoo`03001oogoo00=oo`80009o
o`D0009oo`8000=oo`03001oogoo06Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`000Woo0P000Woo00<007ooOol0J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`05001oogooOol0001ZOol000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@0
07ooOomoo`80009oo`03001oogoo06Qoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00<007ooOol00P000Woo00<007ooOol0J7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool01000Oomoo`000Woo00<007ooOol0JGoo000;Ool2000:Ool20003Ool30003Ool200000goo001o
o`1ZOol0029oo`04001oogoo001[Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<0
06aoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00`00K7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007oo
Ool00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;
Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2
001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomo
ogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool5
0002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007oo
Ool00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P00
17oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P00
1Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomo
o`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Io
o`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@0
07ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo
000;Ool2000:Ool20004Ool20002Ool50002Ool4000<Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol01@00Oomoogoo00001goo10000goo
00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomo
o`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
0goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00@007ooOomoo`8000Ioo`03001oogoo
00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001o
ogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
0goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol00goo00<007ooOol00goo1@00
0goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Ao
o`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol017oo00<007ooOol0Ggoo
000XOol00`00Oomoo`05Ool00`00Oomoo`1NOol002Qooed000aoo`00:7oo00<007ooOol01goo00<0
07ooOol01Goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<0
07ooOol02Woo000XOol00`00Oomoo`08Ool00`00Oomoo`1KOol002Qoo`03001oogoo00Uoo`03001o
ogoo05Yoo`00:7oo00<007ooOol02Woo00<007ooOol0FGoo000XOol00`00Oomoo`0:Ool2001JOol0
02Qoo`03001oogoo00]oo`8005Uoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`00
0goo00<007ooOol037oo00<007ooOol0Egoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06
001oogoo001oo`000goo00@007ooOol000ioo`8005Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOol000moo`03001oogoo05Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P003goo00<007ooOol0EGoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`0?Oom;000<
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1V
Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo
06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002
Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Ao
o`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool3
0004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool2
0005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`00
2Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@0
07ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eo
o`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo
00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03
001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005
Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`80009oo`05001oogooOol00004Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
17oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol0
0Woo00<007ooOol02Woo000LOol3001bOol001aoo`@0075oo`0077oo00<007ooOol00P00L7oo000L
Ool01@00Oomoogoo0000L7oo000LOol20002Ool00`00Oomoo`1^Ool001aoo`03001oogoo009oo`03
001oogoo06eoo`0077oo00<007ooOol00Woo00<007ooOol0KGoo000LOol20004Ool00`00Oomoo`1/
Ool001aoo`03001oogoo00=oo`03001oogoo06aoo`0077oo0P0017oo00<007ooOol0K7oo000;Ool2
0004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`04Ool00`00Oomoo`1[Ool000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol017oo00<007ooOol0Jgoo000:Ool01000Oomoo`00
2goo00<007ooOol00P001Woo00<007ooOol0JWoo000:Ool01000Oomoo`002goo00@007ooOol000Mo
o`03001oogoo06Yoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo00Eoo`03001oogoo06Yo
o`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8000Moo`03001oogoo06Uoo`002goo0P0027oo
1@000Woo00<007ooOol01Woo00<007ooOol0JGoo000LOol00`00Oomoo`07Ool00`00Oomoo`1XOol0
01aoo`8000Qoo`8006Uoo`0077oo00<007ooOol027oo00<007ooOol0Igoo000LOol20009Ool00`00
Oomoo`1WOol001aoo`03001oogoo00Uoo`03001oogoo06Ioo`0077oo00<007ooOol02Goo00<007oo
Ool0IWoo000LOol2000;Ool00`00Oomoo`1UOol001Ioo`<000=oo`03001oogoo00Yoo`03001oogoo
06Eoo`005goo00<007ooOol00Woo00<007ooOol02goo00<007ooOol0I7oo000GOol00`00Oomoo`02
Ool2000<Ool00`00Oomoo`1TOol001Moo`03001oogoo009oo`03001oogoo00aoo`03001oogoo06=o
o`005goo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol0HWoo000FOol20004Ool2000>Ool0
0`00Oomoo`1ROol001Moo`03001oogoo009oo`03001oogoo00ioo`03001oogoo065oo`0077oo00<0
07ooOol03Woo0P00HWoo000LOol2000@Ool00`00Oomoo`1POol001aoo`03001oogoo00moo`03001o
ogoo061oo`0077oo0P004Goo00<007ooOol0Ggoo000LOol00`00Oomoo`0AOol2000UOol^000<Ool0
01aoo`03001oogoo019oobH003Yoo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;
Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool0
1000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Mo
o`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool0
0`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(12692\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51635 m
.008 .51078 L
.012 .50361 L
.016 .49755 L
.02 .49279 L
.024 .48776 L
.028 .48272 L
.032 .48035 L
.036 .48089 L
.04 .48274 L
.044 .48496 L
.048 .486 L
.052 .48528 L
.056 .48179 L
.06 .47525 L
.064 .46693 L
.068 .45726 L
.072 .4454 L
.076 .43079 L
.08 .41381 L
.084 .39634 L
.088 .38045 L
.092 .36632 L
.096 .35253 L
.1 .33917 L
.104 .328 L
.108 .3201 L
.112 .3147 L
.116 .30939 L
.12 .3016 L
.124 .29112 L
.128 .27999 L
.132 .2701 L
.136 .26208 L
.14 .25525 L
.144 .24855 L
.148 .24247 L
.152 .23912 L
.156 .24079 L
.16 .24876 L
.164 .26203 L
.168 .27752 L
.172 .29147 L
.176 .30057 L
.18 .30319 L
.184 .29957 L
.188 .29136 L
.192 .28105 L
.196 .27105 L
.2 .26331 L
Mistroke
.204 .25899 L
.208 .25837 L
.212 .26113 L
.216 .26637 L
.22 .27301 L
.224 .27997 L
.228 .28641 L
.232 .29186 L
.236 .29625 L
.24 .29979 L
.244 .30284 L
.248 .30566 L
.252 .30823 L
.256 .31025 L
.26 .31115 L
.264 .31039 L
.268 .30767 L
.272 .30321 L
.276 .29778 L
.28 .29264 L
.284 .28917 L
.288 .28853 L
.292 .29118 L
.296 .29666 L
.3 .30364 L
.304 .31026 L
.308 .31461 L
.312 .31537 L
.316 .31224 L
.32 .30608 L
.324 .29872 L
.328 .29237 L
.332 .28892 L
.336 .28937 L
.34 .29348 L
.344 .29983 L
.348 .30633 L
.352 .31093 L
.356 .31227 L
.36 .31012 L
.364 .30544 L
.368 .29992 L
.372 .29545 L
.376 .2934 L
.38 .29419 L
.384 .29725 L
.388 .30131 L
.392 .30489 L
.396 .30689 L
.4 .30687 L
Mistroke
.404 .30516 L
.408 .30258 L
.412 .30011 L
.416 .2985 L
.42 .29804 L
.424 .29862 L
.428 .29986 L
.432 .30131 L
.436 .30261 L
.44 .30352 L
.444 .30389 L
.448 .30367 L
.452 .30286 L
.456 .30156 L
.46 .30008 L
.464 .29891 L
.468 .29855 L
.472 .29929 L
.476 .301 L
.48 .30307 L
.484 .30464 L
.488 .30494 L
.492 .3037 L
.496 .30135 L
.5 .29889 L
.504 .29751 L
.508 .29794 L
.512 .30007 L
.516 .30292 L
.52 .30511 L
.524 .30553 L
.528 .30393 L
.532 .30106 L
.536 .29835 L
.54 .29721 L
.544 .29823 L
.548 .30091 L
.552 .30381 L
.556 .3054 L
.56 .30485 L
.564 .3025 L
.568 .29964 L
.572 .29781 L
.576 .29798 L
.58 .29999 L
.584 .3027 L
.588 .30459 L
.592 .30462 L
.596 .30284 L
.6 .30034 L
Mistroke
.604 .29857 L
.608 .2985 L
.612 .30007 L
.616 .30227 L
.62 .30381 L
.624 .30385 L
.628 .30247 L
.632 .30055 L
.636 .29924 L
.64 .29927 L
.644 .30052 L
.648 .30218 L
.652 .30321 L
.656 .30303 L
.66 .30186 L
.664 .30051 L
.668 .2998 L
.672 .3001 L
.676 .30109 L
.68 .30212 L
.684 .30256 L
.688 .30223 L
.692 .30143 L
.696 .30065 L
.7 .30035 L
.704 .30066 L
.708 .30134 L
.712 .30194 L
.716 .30211 L
.72 .30178 L
.724 .30119 L
.728 .30075 L
.732 .3007 L
.736 .30102 L
.74 .30146 L
.744 .30174 L
.748 .30175 L
.752 .30151 L
.756 .30118 L
.76 .30091 L
.764 .30085 L
.768 .30105 L
.772 .30142 L
.776 .30175 L
.78 .30177 L
.784 .30142 L
.788 .30093 L
.792 .30067 L
.796 .30087 L
.8 .3014 L
Mistroke
.804 .30184 L
.808 .30181 L
.812 .30134 L
.816 .30082 L
.82 .30067 L
.824 .301 L
.828 .30149 L
.832 .30175 L
.836 .30161 L
.84 .30121 L
.844 .30089 L
.848 .30086 L
.852 .30108 L
.856 .30139 L
.86 .30158 L
.864 .30151 L
.868 .30128 L
.872 .30098 L
.876 .30081 L
.88 .30098 L
.884 .30137 L
.888 .30166 L
.892 .30164 L
.896 .30119 L
.9 .30069 L
.904 .30067 L
.908 .30112 L
.912 .30168 L
.916 .30189 L
.92 .30138 L
.924 .30065 L
.928 .30048 L
.932 .30091 L
.936 .30165 L
.94 .30205 L
.944 .3015 L
.948 .30064 L
.952 .30036 L
.956 .30076 L
.96 .30163 L
.964 .30216 L
.968 .30155 L
.972 .30061 L
.976 .30029 L
.98 .30064 L
.984 .30162 L
.988 .30227 L
.992 .30159 L
.996 .30059 L
1 .30022 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .21741 m
.008 .21511 L
.012 .21468 L
.016 .21618 L
.02 .21691 L
.024 .21696 L
.028 .21769 L
.032 .21915 L
.036 .22017 L
.04 .22049 L
.044 .22 L
.048 .21898 L
.052 .21861 L
.056 .21924 L
.06 .22114 L
.064 .22424 L
.068 .22794 L
.072 .232 L
.076 .23624 L
.08 .24071 L
.084 .24544 L
.088 .25027 L
.092 .25499 L
.096 .25966 L
.1 .26453 L
.104 .26972 L
.108 .27505 L
.112 .28026 L
.116 .28525 L
.12 .29021 L
.124 .2955 L
.128 .30122 L
.132 .30715 L
.136 .31297 L
.14 .3185 L
.144 .32385 L
.148 .32938 L
.152 .33531 L
.156 .34162 L
.16 .34799 L
.164 .35398 L
.168 .35931 L
.172 .36397 L
.176 .36824 L
.18 .37258 L
.184 .37737 L
.188 .38281 L
.192 .38886 L
.196 .39528 L
.2 .40171 L
Mistroke
.204 .40778 L
.208 .41321 L
.212 .41781 L
.216 .42153 L
.22 .42441 L
.224 .42654 L
.228 .42805 L
.232 .42908 L
.236 .42974 L
.24 .43014 L
.244 .43035 L
.248 .43042 L
.252 .43041 L
.256 .43034 L
.26 .43025 L
.264 .43016 L
.268 .43009 L
.272 .43007 L
.276 .43012 L
.28 .43023 L
.284 .43037 L
.288 .43054 L
.292 .43068 L
.296 .43078 L
.3 .4308 L
.304 .43074 L
.308 .43063 L
.312 .4305 L
.316 .43038 L
.32 .43031 L
.324 .43031 L
.328 .43038 L
.332 .43051 L
.336 .43066 L
.34 .43078 L
.344 .43086 L
.348 .43086 L
.352 .43081 L
.356 .43072 L
.36 .43063 L
.364 .43057 L
.368 .43056 L
.372 .4306 L
.376 .43068 L
.38 .43077 L
.384 .43086 L
.388 .43091 L
.392 .43092 L
.396 .43089 L
.4 .43085 L
Mistroke
.404 .43081 L
.408 .43078 L
.412 .43078 L
.416 .43081 L
.42 .43086 L
.424 .43092 L
.428 .43097 L
.432 .431 L
.436 .43101 L
.44 .431 L
.444 .43098 L
.448 .43096 L
.452 .43095 L
.456 .43096 L
.46 .43099 L
.464 .43103 L
.468 .43108 L
.472 .43111 L
.476 .43113 L
.48 .43114 L
.484 .43112 L
.488 .4311 L
.492 .43109 L
.496 .4311 L
.5 .43113 L
.504 .43118 L
.508 .43122 L
.512 .43125 L
.516 .43126 L
.52 .43125 L
.524 .43123 L
.528 .43122 L
.532 .43123 L
.536 .43125 L
.54 .4313 L
.544 .43134 L
.548 .43136 L
.552 .43137 L
.556 .43136 L
.56 .43135 L
.564 .43134 L
.568 .43136 L
.572 .43139 L
.576 .43143 L
.58 .43146 L
.584 .43147 L
.588 .43147 L
.592 .43147 L
.596 .43146 L
.6 .43147 L
Mistroke
.604 .43149 L
.608 .43152 L
.612 .43155 L
.616 .43157 L
.62 .43158 L
.624 .43158 L
.628 .43158 L
.632 .43158 L
.636 .4316 L
.64 .43163 L
.644 .43166 L
.648 .43167 L
.652 .43168 L
.656 .43168 L
.66 .43169 L
.664 .4317 L
.668 .43171 L
.672 .43174 L
.676 .43176 L
.68 .43177 L
.684 .43178 L
.688 .43179 L
.692 .43179 L
.696 .43181 L
.7 .43182 L
.704 .43185 L
.708 .43186 L
.712 .43188 L
.716 .43188 L
.72 .43189 L
.724 .4319 L
.728 .43192 L
.732 .43193 L
.736 .43195 L
.74 .43197 L
.744 .43198 L
.748 .43199 L
.752 .432 L
.756 .43201 L
.76 .43203 L
.764 .43204 L
.768 .43206 L
.772 .43207 L
.776 .43208 L
.78 .43209 L
.784 .4321 L
.788 .43212 L
.792 .43214 L
.796 .43215 L
.8 .43216 L
Mistroke
.804 .43217 L
.808 .43219 L
.812 .4322 L
.816 .43221 L
.82 .43223 L
.824 .43224 L
.828 .43225 L
.832 .43227 L
.836 .43228 L
.84 .43229 L
.844 .4323 L
.848 .43232 L
.852 .43233 L
.856 .43235 L
.86 .43236 L
.864 .43237 L
.868 .43238 L
.872 .4324 L
.876 .43241 L
.88 .43243 L
.884 .43244 L
.888 .43245 L
.892 .43246 L
.896 .43248 L
.9 .43249 L
.904 .43251 L
.908 .43252 L
.912 .43253 L
.916 .43254 L
.92 .43256 L
.924 .43257 L
.928 .43259 L
.932 .4326 L
.936 .43261 L
.94 .43262 L
.944 .43264 L
.948 .43265 L
.952 .43267 L
.956 .43267 L
.96 .43269 L
.964 .4327 L
.968 .43272 L
.972 .43272 L
.976 .43275 L
.98 .43275 L
.984 .43278 L
.988 .43277 L
.992 .43281 L
.996 .4328 L
1 .43283 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16538 L
.012 .17171 L
.016 .17727 L
.02 .18205 L
.024 .18681 L
.028 .19186 L
.032 .19733 L
.036 .20302 L
.04 .20758 L
.044 .21104 L
.048 .21451 L
.052 .21853 L
.056 .22411 L
.06 .23137 L
.064 .23993 L
.068 .24938 L
.072 .25895 L
.076 .26845 L
.08 .27791 L
.084 .28731 L
.088 .29633 L
.092 .3048 L
.096 .31283 L
.1 .32068 L
.104 .32859 L
.108 .33644 L
.112 .34385 L
.116 .35073 L
.12 .35738 L
.124 .36413 L
.128 .37113 L
.132 .37812 L
.136 .38465 L
.14 .39052 L
.144 .39599 L
.148 .4015 L
.152 .40752 L
.156 .41414 L
.16 .42104 L
.164 .42782 L
.168 .43415 L
.172 .44003 L
.176 .44581 L
.18 .45192 L
.184 .45873 L
.188 .46637 L
.192 .47466 L
.196 .4832 L
.2 .4915 L
Mistroke
.204 .49909 L
.208 .50565 L
.212 .511 L
.216 .51516 L
.22 .51823 L
.224 .5204 L
.228 .52186 L
.232 .52282 L
.236 .52343 L
.24 .52383 L
.244 .52409 L
.248 .52429 L
.252 .52446 L
.256 .52462 L
.26 .52477 L
.264 .52489 L
.268 .52496 L
.272 .52496 L
.276 .52488 L
.28 .52472 L
.284 .52451 L
.288 .52428 L
.292 .52407 L
.296 .52393 L
.3 .52387 L
.304 .52391 L
.308 .52402 L
.312 .52417 L
.316 .52429 L
.32 .52435 L
.324 .52432 L
.328 .5242 L
.332 .52401 L
.336 .5238 L
.34 .52362 L
.344 .5235 L
.348 .52347 L
.352 .52351 L
.356 .52359 L
.36 .52368 L
.364 .52373 L
.368 .52371 L
.372 .52363 L
.376 .52351 L
.38 .52336 L
.384 .52323 L
.388 .52314 L
.392 .5231 L
.396 .5231 L
.4 .52313 L
Mistroke
.404 .52315 L
.408 .52316 L
.412 .52313 L
.416 .52306 L
.42 .52297 L
.424 .52288 L
.428 .52279 L
.432 .52272 L
.436 .52268 L
.44 .52266 L
.444 .52266 L
.448 .52266 L
.452 .52264 L
.456 .5226 L
.46 .52254 L
.464 .52246 L
.468 .52238 L
.472 .52231 L
.476 .52225 L
.48 .52222 L
.484 .52221 L
.488 .52221 L
.492 .5222 L
.496 .52216 L
.5 .52209 L
.504 .52201 L
.508 .52193 L
.512 .52186 L
.516 .52182 L
.52 .52181 L
.524 .5218 L
.528 .52179 L
.532 .52175 L
.536 .52169 L
.54 .52161 L
.544 .52153 L
.548 .52147 L
.552 .52144 L
.556 .52142 L
.56 .52141 L
.564 .52139 L
.568 .52134 L
.572 .52128 L
.576 .5212 L
.58 .52113 L
.584 .52109 L
.588 .52106 L
.592 .52104 L
.596 .52102 L
.6 .52098 L
Mistroke
.604 .52092 L
.608 .52086 L
.612 .52079 L
.616 .52074 L
.62 .52071 L
.624 .52068 L
.628 .52066 L
.632 .52062 L
.636 .52057 L
.64 .52051 L
.644 .52045 L
.648 .5204 L
.652 .52036 L
.656 .52033 L
.66 .5203 L
.664 .52026 L
.668 .52021 L
.672 .52015 L
.676 .5201 L
.68 .52005 L
.684 .52001 L
.688 .51998 L
.692 .51994 L
.696 .5199 L
.7 .51985 L
.704 .51979 L
.708 .51974 L
.712 .5197 L
.716 .51966 L
.72 .51962 L
.724 .51958 L
.728 .51954 L
.732 .51949 L
.736 .51944 L
.74 .51939 L
.744 .51935 L
.748 .51931 L
.752 .51927 L
.756 .51923 L
.76 .51918 L
.764 .51913 L
.768 .51908 L
.772 .51904 L
.776 .519 L
.78 .51896 L
.784 .51892 L
.788 .51887 L
.792 .51882 L
.796 .51877 L
.8 .51873 L
Mistroke
.804 .51869 L
.808 .51865 L
.812 .5186 L
.816 .51856 L
.82 .51851 L
.824 .51846 L
.828 .51842 L
.832 .51838 L
.836 .51834 L
.84 .51829 L
.844 .51825 L
.848 .5182 L
.852 .51815 L
.856 .51811 L
.86 .51807 L
.864 .51803 L
.868 .51798 L
.872 .51794 L
.876 .51789 L
.88 .51785 L
.884 .5178 L
.888 .51776 L
.892 .51771 L
.896 .51767 L
.9 .51762 L
.904 .51758 L
.908 .51753 L
.912 .51749 L
.916 .51744 L
.92 .5174 L
.924 .51736 L
.928 .51732 L
.932 .51726 L
.936 .51723 L
.94 .51717 L
.944 .51714 L
.948 .51709 L
.952 .51705 L
.956 .517 L
.96 .51696 L
.964 .5169 L
.968 .51687 L
.972 .51682 L
.976 .51679 L
.98 .51673 L
.984 .5167 L
.988 .51663 L
.992 .51661 L
.996 .51654 L
1 .51653 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8000eoo`04001oogoo0002Ool01000Oomoo`001goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
0goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000
Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03
001oogoo00]oo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogooOol40003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:
Ool20004Ool00`00Oomoo`02Ool2000;Ool200000goo001oo`02Ool20002Ool00`00Oomoo`04Ool2
0004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`00
00Ioo`04001oogoo0005Ool0029oo`8000]oo`L0009oo`8000Qoo`03001oogoo00=oo`8000Aoo`80
00Ioo`04001oogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006
Ool0029oo`03001oogoo00Yoo`07001oogooOol007oo00000Woo00<007ooOol0EWoo000ROol2000:
Ool00`00Oomoo`02Ool20004Ool01000Oomoogoo0`000Woo0P000Woo0`000Woo00<007ooOol00Woo
00<007ooOol00P0000=oo`0000000Woo00@007ooOol003=oo`008WooH`0037oo000ROol01@00Oomo
ogoo00000goo00<007ooOol00P000goo00D007ooOomoo`0000=oo`@0009oo`80009oo`8000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
000037oo000ROol20008Ool2001SOol0029oo`03001oogoo00Moo`03001oogoo069oo`008Woo0P00
27oo00<007ooOol0HWoo000ROol20008Ool00`00Oomoo`1ROol000]oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`03001oogoo00Ioo`03001oogoo06=oo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool20007Ool00`00Oomoo`1SOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P001goo00<007ooOol0Hgoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo06Aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20006Ool00`00Oomoo`1TOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo0P0017oo0P001Woo00<007ooOol0I7oo000;Ool2000:Ool20004Ool0
0`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`1TOol000]oo`8000Aoo`03001oogoo00=oo`80
009oo`D0009oo`8000Ioo`03001oogoo06Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`000Woo0P001Goo00<007ooOol0IGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo06Eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0004Ool01000Oomoogoo0P0017oo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00H007oo
Ool007oo0003Ool00`00Oomoo`0200001Goo000007oo0000J7oo000:Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool01`00Oomoo`00Ool007oo008006Uoo`002goo0P002Woo0P000goo0`000goo
0`00K7oo000ROol2001]Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo
0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000R
Ool00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo
00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`80
00Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=o
o`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo1`001Goo00D007ooOomo
o`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05
001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`03Ool2
0008Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002
Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P00
2Woo0P0017oo0P000Woo1@000Woo00<007ooOol017oo0P001goo00@007ooOol0009oo`03001oogoo
00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo
00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol01Goo00@007oo
Oomoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=o
o`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Ioo`80
0003Ool007oo00Eoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`80
00=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol01goo00<007oo
000010000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=o
o`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol027oo00<007oo
Ool0Fgoo000XOol00`00Oomoo`08Ool2001LOol002Qooed000aoo`00:7oo00<007ooOol02Woo00<0
07ooOol00Woo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<0
07ooOol02Woo000XOol00`00Oomoo`0;Ool00`00Oomoo`1HOol002Qoo`03001oogoo00]oo`03001o
ogoo05Qoo`00:7oo00<007ooOol037oo00<007ooOol0Egoo000XOol00`00Oomoo`0<Ool2001HOol0
02Qoo`03001oogoo00eoo`8005Moo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`00
0goo00<007ooOol03Woo0P00EWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`000goo00@007ooOol0015oo`03001oogoo05Aoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOol0015oo`8005Eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol00P004Goo0P00E7oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`0AOom9000<Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yo
o`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P00
17oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<0
07ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`00
2goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007oo
Ool000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=o
o`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool3
0004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool3
0004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03
001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001o
o`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009o
o`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00
77oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001o
ogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol0
00Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eo
o`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool3
0004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo000LOomY000<Ool001aoo`80009oo`05001oogooOol00004Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol0
2Woo000LOol00`00Ool0001bOol001aoo`800003Ool007oo071oo`0077oo00D007ooOomoo`00071o
o`0077oo00@007ooOomoo`8006moo`0077oo0P000goo0P00KWoo000LOol00`00Oomoo`03Ool00`00
Oomoo`1/Ool001aoo`03001oogoo00=oo`8006eoo`0077oo0P001Goo00<007ooOol0Jgoo000LOol0
0`00Oomoo`05Ool00`00Oomoo`1ZOol001aoo`8000Ioo`03001oogoo06Yoo`002goo0P0017oo00<0
07ooOol00Woo0`000goo00<007ooOol01Goo00<007ooOol0JWoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo00Ioo`03001oogoo06Uoo`002Woo00@007ooOol000]oo`03001o
ogoo008000Moo`03001oogoo06Uoo`002Woo00@007ooOol000]oo`04001oogoo0009Ool00`00Oomo
o`1XOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`07Ool00`00Oomoo`1XOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool20009Ool00`00Oomoo`1WOol000]oo`8000Qoo`D0009oo`03
001oogoo00Qoo`03001oogoo06Moo`0077oo00<007ooOol02Goo00<007ooOol0IWoo000LOol2000:
Ool00`00Oomoo`1VOol001aoo`03001oogoo00Yoo`03001oogoo06Eoo`0077oo0P002goo00<007oo
Ool0IGoo000LOol00`00Oomoo`0;Ool00`00Oomoo`1TOol001aoo`03001oogoo00aoo`03001oogoo
06=oo`0077oo0P003Goo0P00I7oo000FOol30003Ool00`00Oomoo`0=Ool00`00Oomoo`1ROol001Mo
o`03001oogoo009oo`03001oogoo00ioo`03001oogoo065oo`005goo00<007ooOol00Woo0P003goo
0P00HWoo000GOol00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`1POol001Moo`03001oogoo
009oo`03001oogoo00moo`80065oo`005Woo0P0017oo0P004Goo00<007ooOol0Ggoo000GOol00`00
Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`1NOol001aoo`03001oogoo015oo`03001oogoo05io
o`0077oo0P004Woo0P00Ggoo000LOol00`00Oomoo`0BOol00`00Oomoo`1MOol001aoo`8001Aoo`03
001oogoo05aoo`0077oo00<007ooOol057oo00<007ooOol07goo<00037oo000LOol00`00Oomoo`0E
OolR000kOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo
00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`00
2goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomo
o`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@00
0Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(12859\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .46706 m
.008 .46751 L
.012 .47034 L
.016 .47667 L
.02 .48565 L
.024 .49367 L
.028 .49931 L
.032 .50418 L
.036 .5075 L
.04 .5072 L
.044 .50212 L
.048 .49249 L
.052 .47946 L
.056 .4654 L
.06 .4512 L
.064 .43718 L
.068 .4238 L
.072 .40992 L
.076 .39516 L
.08 .37995 L
.084 .3655 L
.088 .35317 L
.092 .34204 L
.096 .32979 L
.1 .31585 L
.104 .30183 L
.108 .28932 L
.112 .27855 L
.116 .269 L
.12 .26054 L
.124 .255 L
.128 .25513 L
.132 .26157 L
.136 .2722 L
.14 .28367 L
.144 .29317 L
.148 .3 L
.152 .30502 L
.156 .30852 L
.16 .30953 L
.164 .30644 L
.168 .29823 L
.172 .28598 L
.176 .27274 L
.18 .262 L
.184 .25637 L
.188 .25623 L
.192 .25986 L
.196 .26455 L
.2 .26772 L
Mistroke
.204 .26803 L
.208 .26566 L
.212 .26193 L
.216 .2587 L
.22 .25752 L
.224 .25916 L
.228 .26342 L
.232 .26931 L
.236 .2754 L
.24 .28034 L
.244 .28329 L
.248 .28414 L
.252 .28359 L
.256 .28286 L
.26 .28333 L
.264 .286 L
.268 .29117 L
.272 .29823 L
.276 .30575 L
.28 .31193 L
.284 .31514 L
.288 .31448 L
.292 .31011 L
.296 .30329 L
.3 .29606 L
.304 .29058 L
.308 .2885 L
.312 .29039 L
.316 .29557 L
.32 .30232 L
.324 .30848 L
.328 .31213 L
.332 .31224 L
.336 .309 L
.34 .30366 L
.344 .29812 L
.348 .2942 L
.352 .29303 L
.356 .29474 L
.36 .29847 L
.364 .30275 L
.368 .3061 L
.372 .30754 L
.376 .30684 L
.38 .30457 L
.384 .3017 L
.388 .29925 L
.392 .29792 L
.396 .29791 L
.4 .29894 L
Mistroke
.404 .3005 L
.408 .30207 L
.412 .30326 L
.416 .30389 L
.42 .30392 L
.424 .30336 L
.428 .30233 L
.432 .30102 L
.436 .29974 L
.44 .2989 L
.444 .29889 L
.448 .29987 L
.452 .30162 L
.456 .30351 L
.46 .30475 L
.464 .30468 L
.468 .30321 L
.472 .30086 L
.476 .29865 L
.48 .29763 L
.484 .29837 L
.488 .30063 L
.492 .30339 L
.496 .3053 L
.5 .30539 L
.504 .30355 L
.508 .30066 L
.512 .29816 L
.516 .29732 L
.52 .29859 L
.524 .30133 L
.528 .30413 L
.532 .30551 L
.536 .30474 L
.54 .30225 L
.544 .29941 L
.548 .29774 L
.552 .29812 L
.556 .30027 L
.56 .30298 L
.564 .30475 L
.568 .30464 L
.572 .30277 L
.576 .30024 L
.58 .2985 L
.584 .29851 L
.588 .30017 L
.592 .30246 L
.596 .304 L
.6 .30397 L
Mistroke
.604 .30248 L
.608 .30049 L
.612 .29919 L
.616 .29927 L
.62 .30058 L
.624 .30228 L
.628 .30334 L
.632 .30317 L
.636 .30195 L
.64 .30051 L
.644 .29974 L
.648 .30004 L
.652 .30113 L
.656 .30224 L
.66 .30272 L
.664 .30235 L
.668 .30146 L
.672 .30063 L
.676 .30033 L
.68 .30068 L
.684 .3014 L
.688 .30203 L
.692 .3022 L
.696 .30186 L
.7 .30125 L
.704 .30077 L
.708 .3007 L
.712 .30104 L
.716 .30153 L
.72 .30185 L
.724 .30184 L
.728 .30155 L
.732 .30119 L
.736 .30094 L
.74 .30092 L
.744 .30114 L
.748 .30149 L
.752 .30176 L
.756 .30177 L
.76 .30148 L
.764 .30105 L
.768 .30079 L
.772 .30092 L
.776 .30136 L
.78 .30179 L
.784 .30186 L
.788 .3015 L
.792 .30099 L
.796 .30074 L
.8 .30095 L
Mistroke
.804 .30141 L
.808 .30176 L
.812 .30175 L
.816 .30138 L
.82 .30099 L
.824 .30085 L
.828 .30102 L
.832 .30138 L
.836 .30166 L
.84 .30165 L
.844 .30139 L
.848 .30102 L
.852 .30082 L
.856 .30099 L
.86 .3014 L
.864 .30173 L
.868 .30171 L
.872 .30127 L
.876 .30078 L
.88 .30072 L
.884 .30113 L
.888 .30169 L
.892 .3019 L
.896 .30146 L
.9 .3008 L
.904 .30058 L
.908 .30094 L
.912 .30163 L
.916 .30198 L
.92 .30153 L
.924 .30082 L
.928 .30053 L
.932 .30086 L
.936 .30161 L
.94 .302 L
.944 .30151 L
.948 .30079 L
.952 .30052 L
.956 .30084 L
.96 .30164 L
.964 .30202 L
.968 .30144 L
.972 .30072 L
.976 .3005 L
.98 .30085 L
.984 .30171 L
.988 .30206 L
.992 .30135 L
.996 .30062 L
1 .30046 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .19278 m
.008 .19108 L
.012 .19051 L
.016 .19109 L
.02 .19128 L
.024 .19101 L
.028 .19103 L
.032 .19151 L
.036 .1919 L
.04 .1921 L
.044 .19224 L
.048 .19266 L
.052 .19378 L
.056 .19549 L
.06 .1969 L
.064 .19776 L
.068 .19803 L
.072 .19802 L
.076 .1986 L
.08 .20025 L
.084 .20322 L
.088 .20736 L
.092 .21219 L
.096 .21755 L
.1 .22338 L
.104 .22962 L
.108 .236 L
.112 .24229 L
.116 .24842 L
.12 .25455 L
.124 .26087 L
.128 .2673 L
.132 .27353 L
.136 .27932 L
.14 .2847 L
.144 .28993 L
.148 .29528 L
.152 .30079 L
.156 .30622 L
.16 .31134 L
.164 .31607 L
.168 .32065 L
.172 .32547 L
.176 .3308 L
.18 .33665 L
.184 .34274 L
.188 .34867 L
.192 .35415 L
.196 .35911 L
.2 .36375 L
Mistroke
.204 .36842 L
.208 .37346 L
.212 .37907 L
.216 .38524 L
.22 .39177 L
.224 .39833 L
.228 .40459 L
.232 .41025 L
.236 .41512 L
.24 .41913 L
.244 .42231 L
.248 .42475 L
.252 .42659 L
.256 .42795 L
.26 .42894 L
.264 .42963 L
.268 .4301 L
.272 .43037 L
.276 .43049 L
.28 .43049 L
.284 .4304 L
.288 .4303 L
.292 .43021 L
.296 .43017 L
.3 .43021 L
.304 .43031 L
.308 .43045 L
.312 .43059 L
.316 .4307 L
.32 .43074 L
.324 .43073 L
.328 .43066 L
.332 .43056 L
.336 .43048 L
.34 .43043 L
.344 .43044 L
.348 .4305 L
.352 .43059 L
.356 .43068 L
.36 .43076 L
.364 .43079 L
.368 .43079 L
.372 .43076 L
.376 .43071 L
.38 .43067 L
.384 .43066 L
.388 .43067 L
.392 .43071 L
.396 .43076 L
.4 .43082 L
Mistroke
.404 .43086 L
.408 .43088 L
.412 .43089 L
.416 .43087 L
.42 .43085 L
.424 .43084 L
.428 .43083 L
.432 .43085 L
.436 .43088 L
.44 .43092 L
.444 .43097 L
.448 .431 L
.452 .43101 L
.456 .43101 L
.46 .43099 L
.464 .43098 L
.468 .43097 L
.472 .43099 L
.476 .43102 L
.48 .43107 L
.484 .43111 L
.488 .43113 L
.492 .43114 L
.496 .43113 L
.5 .43111 L
.504 .4311 L
.508 .43111 L
.512 .43114 L
.516 .43118 L
.52 .43122 L
.524 .43124 L
.528 .43125 L
.532 .43124 L
.536 .43123 L
.54 .43123 L
.544 .43124 L
.548 .43127 L
.552 .43131 L
.556 .43134 L
.56 .43135 L
.564 .43135 L
.568 .43135 L
.572 .43134 L
.576 .43135 L
.58 .43138 L
.584 .43141 L
.588 .43144 L
.592 .43145 L
.596 .43146 L
.6 .43146 L
Mistroke
.604 .43146 L
.608 .43147 L
.612 .43149 L
.616 .43151 L
.62 .43154 L
.624 .43155 L
.628 .43156 L
.632 .43156 L
.636 .43157 L
.64 .43158 L
.644 .4316 L
.648 .43162 L
.652 .43164 L
.656 .43166 L
.66 .43167 L
.664 .43167 L
.668 .43168 L
.672 .43169 L
.676 .43171 L
.68 .43173 L
.684 .43175 L
.688 .43176 L
.692 .43177 L
.696 .43177 L
.7 .43178 L
.704 .4318 L
.708 .43182 L
.712 .43183 L
.716 .43185 L
.72 .43186 L
.724 .43187 L
.728 .43188 L
.732 .43189 L
.736 .43191 L
.74 .43193 L
.744 .43194 L
.748 .43195 L
.752 .43196 L
.756 .43197 L
.76 .43199 L
.764 .432 L
.768 .43202 L
.772 .43203 L
.776 .43205 L
.78 .43206 L
.784 .43207 L
.788 .43208 L
.792 .43209 L
.796 .43211 L
.8 .43212 L
Mistroke
.804 .43214 L
.808 .43215 L
.812 .43216 L
.816 .43217 L
.82 .43219 L
.824 .4322 L
.828 .43222 L
.832 .43223 L
.836 .43224 L
.84 .43225 L
.844 .43227 L
.848 .43228 L
.852 .43229 L
.856 .43231 L
.86 .43232 L
.864 .43234 L
.868 .43235 L
.872 .43236 L
.876 .43237 L
.88 .43239 L
.884 .4324 L
.888 .43242 L
.892 .43243 L
.896 .43244 L
.9 .43245 L
.904 .43247 L
.908 .43248 L
.912 .43249 L
.916 .4325 L
.92 .43252 L
.924 .43253 L
.928 .43255 L
.932 .43256 L
.936 .43257 L
.94 .43258 L
.944 .4326 L
.948 .43261 L
.952 .43263 L
.956 .43263 L
.96 .43266 L
.964 .43266 L
.968 .43268 L
.972 .43269 L
.976 .43271 L
.98 .43271 L
.984 .43274 L
.988 .43273 L
.992 .43277 L
.996 .43276 L
1 .4328 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16697 L
.012 .16937 L
.016 .1731 L
.02 .17815 L
.024 .18285 L
.028 .18735 L
.032 .19246 L
.036 .19806 L
.04 .2031 L
.044 .20766 L
.048 .21262 L
.052 .21817 L
.056 .22371 L
.06 .22879 L
.064 .2326 L
.068 .23516 L
.072 .2372 L
.076 .23938 L
.08 .24272 L
.084 .24746 L
.088 .25329 L
.092 .25985 L
.096 .26679 L
.1 .27405 L
.104 .2815 L
.108 .28889 L
.112 .29585 L
.116 .30235 L
.12 .30873 L
.124 .31525 L
.128 .32196 L
.132 .32863 L
.136 .33503 L
.14 .34127 L
.144 .34774 L
.148 .35472 L
.152 .36219 L
.156 .36979 L
.16 .37705 L
.164 .38377 L
.168 .39015 L
.172 .39657 L
.176 .40337 L
.18 .41057 L
.184 .41785 L
.188 .4248 L
.192 .43111 L
.196 .43679 L
.2 .44213 L
Mistroke
.204 .4476 L
.208 .45364 L
.212 .4605 L
.216 .46817 L
.22 .47638 L
.224 .48472 L
.228 .49275 L
.232 .50005 L
.236 .50637 L
.24 .51155 L
.244 .51559 L
.248 .51858 L
.252 .52066 L
.256 .52202 L
.26 .52284 L
.264 .5233 L
.268 .52355 L
.272 .52371 L
.276 .52385 L
.28 .52402 L
.284 .52419 L
.288 .52436 L
.292 .52447 L
.296 .52451 L
.3 .52444 L
.304 .5243 L
.308 .5241 L
.312 .5239 L
.316 .52373 L
.32 .52365 L
.324 .52364 L
.328 .5237 L
.332 .52379 L
.336 .52387 L
.34 .5239 L
.344 .52386 L
.348 .52376 L
.352 .52362 L
.356 .52348 L
.36 .52336 L
.364 .52328 L
.368 .52326 L
.372 .52328 L
.376 .52331 L
.38 .52333 L
.384 .52332 L
.388 .52328 L
.392 .5232 L
.396 .52311 L
.4 .52301 L
Mistroke
.404 .52293 L
.408 .52287 L
.412 .52284 L
.416 .52283 L
.42 .52283 L
.424 .52282 L
.428 .5228 L
.432 .52275 L
.436 .52268 L
.44 .5226 L
.444 .52252 L
.448 .52245 L
.452 .52241 L
.456 .52239 L
.46 .52238 L
.464 .52237 L
.468 .52235 L
.472 .5223 L
.476 .52224 L
.48 .52215 L
.484 .52207 L
.488 .52202 L
.492 .52198 L
.496 .52197 L
.5 .52196 L
.504 .52194 L
.508 .5219 L
.512 .52184 L
.516 .52176 L
.52 .52168 L
.524 .52163 L
.528 .52159 L
.532 .52158 L
.536 .52157 L
.54 .52154 L
.544 .52149 L
.548 .52143 L
.552 .52135 L
.556 .52129 L
.56 .52124 L
.564 .52122 L
.568 .5212 L
.572 .52117 L
.576 .52113 L
.58 .52108 L
.584 .52101 L
.588 .52095 L
.592 .5209 L
.596 .52086 L
.6 .52084 L
Mistroke
.604 .52081 L
.608 .52077 L
.612 .52072 L
.616 .52066 L
.62 .5206 L
.624 .52055 L
.628 .52051 L
.632 .52048 L
.636 .52045 L
.64 .52041 L
.644 .52036 L
.648 .5203 L
.652 .52025 L
.656 .5202 L
.66 .52017 L
.664 .52013 L
.668 .52009 L
.672 .52005 L
.676 .52 L
.68 .51995 L
.684 .5199 L
.688 .51985 L
.692 .51982 L
.696 .51978 L
.7 .51974 L
.704 .51969 L
.708 .51964 L
.712 .51959 L
.716 .51955 L
.72 .5195 L
.724 .51947 L
.728 .51943 L
.732 .51938 L
.736 .51934 L
.74 .51929 L
.744 .51924 L
.748 .51919 L
.752 .51915 L
.756 .51911 L
.76 .51907 L
.764 .51902 L
.768 .51898 L
.772 .51893 L
.776 .51889 L
.78 .51884 L
.784 .5188 L
.788 .51876 L
.792 .51871 L
.796 .51867 L
.8 .51862 L
Mistroke
.804 .51858 L
.808 .51853 L
.812 .51849 L
.816 .51845 L
.82 .5184 L
.824 .51836 L
.828 .51831 L
.832 .51827 L
.836 .51822 L
.84 .51818 L
.844 .51814 L
.848 .51809 L
.852 .51804 L
.856 .518 L
.86 .51796 L
.864 .51791 L
.868 .51787 L
.872 .51783 L
.876 .51778 L
.88 .51774 L
.884 .51769 L
.888 .51765 L
.892 .5176 L
.896 .51756 L
.9 .51751 L
.904 .51747 L
.908 .51742 L
.912 .51738 L
.916 .51733 L
.92 .51729 L
.924 .51724 L
.928 .51721 L
.932 .51715 L
.936 .51712 L
.94 .51706 L
.944 .51703 L
.948 .51698 L
.952 .51694 L
.956 .51688 L
.96 .51685 L
.964 .51679 L
.968 .51676 L
.972 .51671 L
.976 .51668 L
.98 .51661 L
.984 .51659 L
.988 .51652 L
.992 .5165 L
.996 .51643 L
1 .51642 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02Goo1`000Woo0P0000=oo`00Ool01Woo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool01000Oomoogoo10000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomo
o`000Woo00@007ooOol000=oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P00
2Woo0P0017oo00<007ooOol00Woo0P002Woo0`000goo1@0000=oo`00Ool01Goo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000ROol20009Ool00`00Ool0000500000goo001oo`020008Ool00`00Oomoo`03Ool20004
Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo
0P001Woo000ROol00`00Oomoo`08Ool01000Oomoo`000Woo00<007ooOol017oo0`000goo00<007oo
Ool0CWoo000ROol20009Ool01000Oomoo`000Woo00<007ooOol01Woo0P0000Aoo`000000009oo`80
009oo`8000Moo`03001oogoo0080009oo`04001oogoo000eOol0029oof<000aoo`008Woo00D007oo
Oomoo`0000=oo`05001oo`00Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00`0000=oo`00
00000Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007oo
Ool000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool00`00Oomoo`0:Ool0029oo`8000Qoo`03001oogoo069oo`008Woo00<007ooOol0
1goo00<007ooOol0HWoo000ROol20007Ool00`00Oomoo`1SOol0029oo`8000Moo`03001oogoo06=o
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol01Goo00<007ooOol0I7oo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Ioo`03001oogoo06Ao
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20006Ool00`00Oomoo`1T
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol01Goo00<0
07ooOol0I7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Eoo`03
001oogoo06Eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool20005Ool00`00Oomo
o`1UOol000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo06Eoo`00
2goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P0017oo00<007ooOol0IWoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0IWoo
000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol20004Ool00`00Oomoo`1VOol0
00Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo00<0009oo`03001oogoo06Mo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00H007ooOol007oo0002Ool00`00Oomo
o`1WOol000]oo`8000Yoo`8000=oo`<000=oo`800003Ool0000006Yoo`008Woo00<007ooOol00P00
JWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008
Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo
0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eo
o`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`80
06eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo0000
0goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool0
0`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=o
o`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04
Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007oo
Ool0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003
Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003
Ool00`00Oomoo`05001TOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogoo0004Ool4001POol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo008000Ioo`03001oogoo009oo`<000Aoo`8000Moo`<000Aoo`8000Ao
o`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Io
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0
1Woo00@007ooOol000=oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0006Ool00`00Oomoo`07Ool00`00Oomoo`03Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol01goo
00<007ooOol00goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03
001oogoo00=oo`00:7oo00<007ooOol027oo1@000goo00@007ooOol000Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol0
00Eoo`00:7oo00<007ooOol027oo0P001Woo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool0
1000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00
Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo
0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`0:Ool0
0`00Oomoo`1IOol002Qoo`03001oogoo00]oo`03001oogoo05Qoo`00:7ooG@0037oo000XOol00`00
Oomoo`0<Ool01000Oomoo`004Woo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<0
07ooOol02Woo000XOol00`00Oomoo`0=Ool00`00Oomoo`1FOol002Qoo`03001oogoo00ioo`03001o
ogoo05Eoo`00:7oo00<007ooOol03Woo0P00EWoo000XOol00`00Oomoo`0?Ool00`00Oomoo`1DOol0
02Qoo`03001oogoo011oo`03001oogoo05=oo`002goo0P0017oo00<007ooOol00goo0P0017oo0P00
0goo0`000goo00<007ooOol047oo0P00E7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06
001oogoo001oo`000goo00@007ooOol001=oo`8005=oo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOol001Aoo`03001oogoo055oo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P0057oo00<007ooOol0D7oo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`0DOom6000<
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1V
Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo
06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002
Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Ao
o`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool3
0004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool2
0005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`00
2Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@0
07ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eo
o`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo
00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03
001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005
Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`80009oo`05001oogooOol00004Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
17oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol0
0Woo00<007ooOol02Woo000LOol00`00Ool0001bOol001aoo`800003Ool007oo071oo`0077oo00D0
07ooOomoo`00071oo`0077oo00@007ooOomoo`8006moo`0077oo0P000goo0P00KWoo000LOol00`00
Oomoo`03Ool00`00Oomoo`1/Ool001aoo`03001oogoo00Aoo`8006aoo`0077oo0P001Woo0P00Jgoo
000LOol00`00Oomoo`06Ool2001ZOol001aoo`8000Qoo`03001oogoo06Qoo`002goo0P0017oo00<0
07ooOol00Woo0`000goo00<007ooOol027oo00<007ooOol0Igoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo00Qoo`03001oogoo06Moo`002Woo00@007ooOol000]oo`03001o
ogoo008000Yoo`03001oogoo06Ioo`002Woo00@007ooOol000]oo`04001oogoo000;Ool00`00Oomo
o`1VOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0:Ool00`00Oomoo`1UOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool2000;Ool00`00Oomoo`1UOol000]oo`8000Qoo`D0009oo`03
001oogoo00]oo`03001oogoo06Aoo`0077oo00<007ooOol037oo00<007ooOol0Hgoo000LOol2000=
Ool2001TOol001aoo`03001oogoo00eoo`03001oogoo069oo`0077oo0P003Woo00<007ooOol0HWoo
000LOol00`00Oomoo`0>Ool00`00Oomoo`1QOol001aoo`03001oogoo00moo`03001oogoo061oo`00
77oo0P0047oo00<007ooOol0H7oo000FOol30003Ool00`00Oomoo`0@Ool00`00Oomoo`1OOol001Mo
o`03001oogoo009oo`03001oogoo011oo`03001oogoo05moo`005goo00<007ooOol00Woo0P004Woo
00<007ooOol0GWoo000GOol00`00Oomoo`02Ool00`00Oomoo`0AOol2001OOol001Moo`03001oogoo
009oo`03001oogoo019oo`8005ioo`005Woo0P0017oo0P0057oo00<007ooOol0G7oo000GOol00`00
Oomoo`02Ool00`00Oomoo`0DOol00`00Oomoo`1KOol001aoo`03001oogoo01Aoo`03001oogoo05]o
o`0077oo0P005Goo00<007ooOol0Fgoo000LOol00`00Oomoo`0EOol00`00Oomoo`1JOol001aoo`80
01Moo`03001oogoo05Uoo`0077oo00<007ooOol05Woo0P007Woo<00037oo000LOol00`00Oomoo`0H
OolN000lOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo
00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`00
2goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomo
o`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@00
0Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(13026\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .5056 m
.008 .50397 L
.012 .49947 L
.016 .492 L
.02 .48252 L
.024 .47004 L
.028 .45565 L
.032 .44127 L
.036 .42863 L
.04 .41759 L
.044 .40803 L
.048 .39989 L
.052 .39376 L
.056 .39075 L
.06 .38942 L
.064 .38694 L
.068 .38203 L
.072 .37478 L
.076 .36551 L
.08 .3559 L
.084 .34733 L
.088 .34055 L
.092 .33522 L
.096 .32955 L
.1 .32406 L
.104 .32111 L
.108 .3222 L
.112 .32663 L
.116 .33196 L
.12 .33586 L
.124 .33778 L
.128 .33828 L
.132 .33679 L
.136 .33143 L
.14 .32124 L
.144 .30754 L
.148 .29366 L
.152 .28307 L
.156 .27686 L
.16 .27356 L
.164 .27119 L
.168 .26887 L
.172 .26739 L
.176 .26829 L
.18 .27188 L
.184 .27677 L
.188 .28068 L
.192 .28172 L
.196 .27977 L
.2 .27637 L
Mistroke
.204 .27356 L
.208 .2727 L
.212 .27358 L
.216 .27461 L
.22 .27382 L
.224 .26987 L
.228 .2629 L
.232 .25447 L
.236 .24698 L
.24 .24275 L
.244 .24309 L
.248 .24794 L
.252 .25588 L
.256 .26468 L
.26 .27217 L
.264 .27684 L
.268 .27844 L
.272 .27785 L
.276 .27682 L
.28 .27719 L
.284 .28026 L
.288 .28625 L
.292 .29426 L
.296 .3025 L
.3 .30895 L
.304 .31205 L
.308 .31126 L
.312 .30723 L
.316 .30157 L
.32 .2963 L
.324 .29314 L
.328 .29298 L
.332 .29561 L
.336 .29988 L
.34 .30422 L
.344 .30719 L
.348 .30796 L
.352 .30657 L
.356 .30379 L
.36 .30073 L
.364 .29843 L
.368 .29749 L
.372 .29796 L
.376 .29941 L
.38 .30123 L
.384 .30283 L
.388 .30384 L
.392 .30414 L
.396 .30379 L
.4 .30295 L
Mistroke
.404 .30178 L
.408 .30053 L
.412 .29949 L
.416 .299 L
.42 .29932 L
.424 .30049 L
.428 .30221 L
.432 .30386 L
.436 .30474 L
.44 .30435 L
.444 .30271 L
.448 .30041 L
.452 .29847 L
.456 .29782 L
.46 .29886 L
.464 .30121 L
.468 .30381 L
.472 .30542 L
.476 .30519 L
.48 .30315 L
.484 .30028 L
.488 .29799 L
.492 .29747 L
.496 .29898 L
.5 .30179 L
.504 .30444 L
.508 .30556 L
.512 .30457 L
.516 .30199 L
.52 .2992 L
.524 .2977 L
.528 .29827 L
.532 .30056 L
.536 .30328 L
.54 .30493 L
.544 .30464 L
.548 .30264 L
.552 .3001 L
.556 .29844 L
.56 .29856 L
.564 .30031 L
.568 .30263 L
.572 .30417 L
.576 .30407 L
.58 .30249 L
.584 .30043 L
.588 .29912 L
.592 .29926 L
.596 .30066 L
.6 .30242 L
Mistroke
.604 .30348 L
.608 .30327 L
.612 .30201 L
.616 .30052 L
.62 .29971 L
.624 .30001 L
.628 .30115 L
.632 .30235 L
.636 .30288 L
.64 .30248 L
.644 .3015 L
.648 .3006 L
.652 .3003 L
.656 .3007 L
.66 .30148 L
.664 .30214 L
.668 .3023 L
.672 .30193 L
.676 .30129 L
.68 .30079 L
.684 .30071 L
.688 .30106 L
.692 .30159 L
.696 .30194 L
.7 .30193 L
.704 .30161 L
.708 .3012 L
.712 .30095 L
.716 .30097 L
.72 .30122 L
.724 .30156 L
.728 .3018 L
.732 .30179 L
.736 .30152 L
.74 .30114 L
.744 .30089 L
.748 .30098 L
.752 .30136 L
.756 .30177 L
.76 .30189 L
.764 .30161 L
.768 .30114 L
.772 .30083 L
.776 .30094 L
.78 .30136 L
.784 .30176 L
.788 .30184 L
.792 .30154 L
.796 .30111 L
.8 .30088 L
Mistroke
.804 .30099 L
.808 .30136 L
.812 .3017 L
.816 .30176 L
.82 .3015 L
.824 .3011 L
.828 .30086 L
.832 .30099 L
.836 .30139 L
.84 .30175 L
.844 .30178 L
.848 .30139 L
.852 .30091 L
.856 .30077 L
.86 .3011 L
.864 .30164 L
.868 .3019 L
.872 .30158 L
.876 .301 L
.88 .3007 L
.884 .30093 L
.888 .30153 L
.892 .30191 L
.896 .30164 L
.9 .30107 L
.904 .30071 L
.908 .30088 L
.912 .30148 L
.916 .30186 L
.92 .30159 L
.924 .30106 L
.928 .30074 L
.932 .30091 L
.936 .3015 L
.94 .3018 L
.944 .30147 L
.948 .30101 L
.952 .30078 L
.956 .30099 L
.96 .30158 L
.964 .30176 L
.968 .30131 L
.972 .30091 L
.976 .30079 L
.98 .30108 L
.984 .30169 L
.988 .30175 L
.992 .30115 L
.996 .30078 L
1 .30078 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16546 m
.008 .1677 L
.012 .16835 L
.016 .16756 L
.02 .16726 L
.024 .16748 L
.028 .16767 L
.032 .16798 L
.036 .16849 L
.04 .16914 L
.044 .16989 L
.048 .17093 L
.052 .17251 L
.056 .17449 L
.06 .17626 L
.064 .17781 L
.068 .17959 L
.072 .1819 L
.076 .18486 L
.08 .18825 L
.084 .19135 L
.088 .19381 L
.092 .19548 L
.096 .19672 L
.1 .19831 L
.104 .20066 L
.108 .2039 L
.112 .20788 L
.116 .21242 L
.12 .21747 L
.124 .22296 L
.128 .2287 L
.132 .23436 L
.136 .2398 L
.14 .24516 L
.144 .25069 L
.148 .25651 L
.152 .26247 L
.156 .2683 L
.16 .27384 L
.164 .27923 L
.168 .28471 L
.172 .29048 L
.176 .29645 L
.18 .30231 L
.184 .3078 L
.188 .31285 L
.192 .31766 L
.196 .32259 L
.2 .32789 L
Mistroke
.204 .33358 L
.208 .33945 L
.212 .34516 L
.216 .35047 L
.22 .35531 L
.224 .35984 L
.228 .36441 L
.232 .36933 L
.236 .37481 L
.24 .3809 L
.244 .38742 L
.248 .3941 L
.252 .4006 L
.256 .40661 L
.26 .41191 L
.264 .41642 L
.268 .4201 L
.272 .42303 L
.276 .4253 L
.28 .42703 L
.284 .4283 L
.288 .42919 L
.292 .42979 L
.296 .43013 L
.3 .43029 L
.304 .43034 L
.308 .43031 L
.312 .43028 L
.316 .43028 L
.32 .43032 L
.324 .4304 L
.328 .4305 L
.332 .43059 L
.336 .43065 L
.34 .43068 L
.344 .43066 L
.348 .43062 L
.352 .43057 L
.356 .43054 L
.36 .43053 L
.364 .43056 L
.368 .4306 L
.372 .43066 L
.376 .43071 L
.38 .43075 L
.384 .43077 L
.388 .43076 L
.392 .43074 L
.396 .43072 L
.4 .43071 L
Mistroke
.404 .43072 L
.408 .43074 L
.412 .43077 L
.416 .43082 L
.42 .43086 L
.424 .43088 L
.428 .43089 L
.432 .43088 L
.436 .43087 L
.44 .43086 L
.444 .43086 L
.448 .43088 L
.452 .43091 L
.456 .43095 L
.46 .43099 L
.464 .43101 L
.468 .43101 L
.472 .431 L
.476 .43099 L
.48 .43098 L
.484 .431 L
.488 .43103 L
.492 .43107 L
.496 .43111 L
.5 .43113 L
.504 .43113 L
.508 .43112 L
.512 .43111 L
.516 .43111 L
.52 .43113 L
.524 .43116 L
.528 .4312 L
.532 .43122 L
.536 .43124 L
.54 .43123 L
.544 .43123 L
.548 .43123 L
.552 .43124 L
.556 .43126 L
.56 .43129 L
.564 .43132 L
.568 .43134 L
.572 .43134 L
.576 .43134 L
.58 .43134 L
.584 .43135 L
.588 .43137 L
.592 .4314 L
.596 .43142 L
.6 .43144 L
Mistroke
.604 .43145 L
.608 .43145 L
.612 .43145 L
.616 .43146 L
.62 .43148 L
.624 .4315 L
.628 .43152 L
.632 .43154 L
.636 .43155 L
.64 .43155 L
.644 .43156 L
.648 .43157 L
.652 .43159 L
.656 .43161 L
.66 .43163 L
.664 .43164 L
.668 .43165 L
.672 .43166 L
.676 .43167 L
.68 .43168 L
.684 .4317 L
.688 .43172 L
.692 .43173 L
.696 .43174 L
.7 .43175 L
.704 .43176 L
.708 .43178 L
.712 .43179 L
.716 .43181 L
.72 .43182 L
.724 .43184 L
.728 .43185 L
.732 .43186 L
.736 .43187 L
.74 .43188 L
.744 .4319 L
.748 .43192 L
.752 .43193 L
.756 .43194 L
.76 .43195 L
.764 .43196 L
.768 .43198 L
.772 .43199 L
.776 .43201 L
.78 .43202 L
.784 .43203 L
.788 .43204 L
.792 .43206 L
.796 .43207 L
.8 .43209 L
Mistroke
.804 .4321 L
.808 .43211 L
.812 .43212 L
.816 .43214 L
.82 .43215 L
.824 .43216 L
.828 .43218 L
.832 .43219 L
.836 .4322 L
.84 .43222 L
.844 .43223 L
.848 .43224 L
.852 .43226 L
.856 .43227 L
.86 .43228 L
.864 .4323 L
.868 .43231 L
.872 .43232 L
.876 .43234 L
.88 .43235 L
.884 .43236 L
.888 .43238 L
.892 .43239 L
.896 .4324 L
.9 .43241 L
.904 .43243 L
.908 .43244 L
.912 .43246 L
.916 .43247 L
.92 .43248 L
.924 .43249 L
.928 .43251 L
.932 .43252 L
.936 .43254 L
.94 .43254 L
.944 .43257 L
.948 .43257 L
.952 .43259 L
.956 .43259 L
.96 .43262 L
.964 .43262 L
.968 .43265 L
.972 .43265 L
.976 .43267 L
.98 .43267 L
.984 .4327 L
.988 .4327 L
.992 .43273 L
.996 .43272 L
1 .43276 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16734 L
.012 .17076 L
.016 .17481 L
.02 .17964 L
.024 .18394 L
.028 .18765 L
.032 .19136 L
.036 .19512 L
.04 .19838 L
.044 .20117 L
.048 .2042 L
.052 .20764 L
.056 .211 L
.06 .21402 L
.064 .2166 L
.068 .21906 L
.072 .22202 L
.076 .22558 L
.08 .22922 L
.084 .23242 L
.088 .23445 L
.092 .23529 L
.096 .23562 L
.1 .23624 L
.104 .23801 L
.108 .24115 L
.112 .2455 L
.116 .25094 L
.12 .25741 L
.124 .26479 L
.128 .27268 L
.132 .28063 L
.136 .28831 L
.14 .29574 L
.144 .3032 L
.148 .31075 L
.152 .3182 L
.156 .32525 L
.16 .33177 L
.164 .33799 L
.168 .34432 L
.172 .35104 L
.176 .35808 L
.18 .36512 L
.184 .37181 L
.188 .37805 L
.192 .38412 L
.196 .39041 L
.2 .39722 L
Mistroke
.204 .40457 L
.208 .41214 L
.212 .41948 L
.216 .42624 L
.22 .43229 L
.224 .43783 L
.228 .44326 L
.232 .44903 L
.236 .45547 L
.24 .46269 L
.244 .47057 L
.248 .4788 L
.252 .48698 L
.256 .49469 L
.26 .5016 L
.264 .50748 L
.268 .51224 L
.272 .51589 L
.276 .51855 L
.28 .52038 L
.284 .52159 L
.288 .52235 L
.292 .52285 L
.296 .5232 L
.3 .52347 L
.304 .5237 L
.308 .52388 L
.312 .52399 L
.316 .52403 L
.32 .52398 L
.324 .52387 L
.328 .52373 L
.332 .52359 L
.336 .52349 L
.34 .52343 L
.344 .52343 L
.348 .52345 L
.352 .52348 L
.356 .5235 L
.36 .52348 L
.364 .52342 L
.368 .52334 L
.372 .52324 L
.376 .52315 L
.38 .52307 L
.384 .52302 L
.388 .523 L
.392 .523 L
.396 .52299 L
.4 .52298 L
Mistroke
.404 .52295 L
.408 .5229 L
.412 .52282 L
.416 .52274 L
.42 .52267 L
.424 .52261 L
.428 .52257 L
.432 .52255 L
.436 .52254 L
.44 .52253 L
.444 .5225 L
.448 .52245 L
.452 .52238 L
.456 .5223 L
.46 .52222 L
.464 .52217 L
.468 .52214 L
.472 .52213 L
.476 .52212 L
.48 .5221 L
.484 .52205 L
.488 .52198 L
.492 .52191 L
.496 .52183 L
.5 .52178 L
.504 .52175 L
.508 .52174 L
.512 .52172 L
.516 .52169 L
.52 .52164 L
.524 .52157 L
.528 .5215 L
.532 .52144 L
.536 .5214 L
.54 .52137 L
.544 .52135 L
.548 .52133 L
.552 .52129 L
.556 .52123 L
.56 .52116 L
.564 .5211 L
.568 .52105 L
.572 .52102 L
.576 .52099 L
.58 .52096 L
.584 .52092 L
.588 .52087 L
.592 .52081 L
.596 .52075 L
.6 .52071 L
Mistroke
.604 .52067 L
.608 .52064 L
.612 .5206 L
.616 .52056 L
.62 .52051 L
.624 .52046 L
.628 .5204 L
.632 .52036 L
.636 .52032 L
.64 .52028 L
.644 .52025 L
.648 .52021 L
.652 .52016 L
.656 .5201 L
.66 .52005 L
.664 .52001 L
.668 .51997 L
.672 .51993 L
.676 .51989 L
.68 .51985 L
.684 .5198 L
.688 .51975 L
.692 .5197 L
.696 .51966 L
.7 .51962 L
.704 .51958 L
.708 .51954 L
.712 .51949 L
.716 .51944 L
.72 .51939 L
.724 .51935 L
.728 .51931 L
.732 .51927 L
.736 .51923 L
.74 .51918 L
.744 .51913 L
.748 .51908 L
.752 .51904 L
.756 .519 L
.76 .51896 L
.764 .51891 L
.768 .51887 L
.772 .51882 L
.776 .51878 L
.78 .51873 L
.784 .51869 L
.788 .51865 L
.792 .5186 L
.796 .51856 L
.8 .51851 L
Mistroke
.804 .51847 L
.808 .51842 L
.812 .51838 L
.816 .51834 L
.82 .51829 L
.824 .51825 L
.828 .5182 L
.832 .51816 L
.836 .51811 L
.84 .51807 L
.844 .51802 L
.848 .51798 L
.852 .51794 L
.856 .51789 L
.86 .51785 L
.864 .5178 L
.868 .51776 L
.872 .51771 L
.876 .51767 L
.88 .51763 L
.884 .51758 L
.888 .51754 L
.892 .51749 L
.896 .51745 L
.9 .5174 L
.904 .51736 L
.908 .51731 L
.912 .51727 L
.916 .51722 L
.92 .51718 L
.924 .51713 L
.928 .5171 L
.932 .51704 L
.936 .51701 L
.94 .51695 L
.944 .51692 L
.948 .51687 L
.952 .51683 L
.956 .51677 L
.96 .51674 L
.964 .51668 L
.968 .51665 L
.972 .5166 L
.976 .51657 L
.98 .5165 L
.984 .51648 L
.988 .51641 L
.992 .51639 L
.996 .51632 L
1 .5163 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`05001oogoo001oo`020007Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0002
Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0
2goo10000goo00<007oo00000P001Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool01000Oomoogoo10000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000=oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Woo0P00
17oo00<007ooOol00Woo0P0037oo00@007ooOol000=oo`800003Ool0000000Eoo`8000Aoo`04001o
ogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007oo
Ool000Eoo`008Woo0P0037oo1@0000=oo`0000000P0000Aoo`00000000Aoo`03001oogoo00=oo`80
00Aoo`8000Ioo`04001oogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003
Ool20006Ool0029oo`03001oogoo00aoo`03001oogoo008000Ioo`03001oo`00059oo`008Woo0P00
3Goo00<007ooOol02goo00@007oo000000=oo`03001oogoo00Eoo`80009oo`03001oogoo00800003
Ool0000003Moo`008WooH`0037oo000ROol01@00Oomoogoo00000goo00T007ooOomoo`00Ool007oo
00000goo00D007ooOomoo`00009oo`03001oogoo008000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`04001oogoo0003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol02Woo000ROol2
0008Ool20002Ool00`00Oomoo`1NOol0029oo`03001oogoo00Ioo`03001oo`000080065oo`008Woo
0P001Woo0P00IGoo000ROol20006Ool00`00Oomoo`1TOol000]oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`03001oogoo00Eoo`03001oogoo06Aoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool20005Ool00`00Oomoo`1UOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P0017oo0P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo06Moo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool20002Ool00`00Oomoo`1XOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo0P0017oo0P000Woo00<007ooOol0J7oo000;Ool2000:Ool20004Ool00`00Oomoo`02
Ool01@00Oomoogoo0000JWoo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool200000goo
001oo`1ZOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`800003Ool0
07oo06Yoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`00
Jgoo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol3001/Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo00<006aoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00H007ooOol007oo001/Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eo
o`008Woo0P00KGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`80
00=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=o
o`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<0
07ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00
Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007oo
Oomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool0
0`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P00
17oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo1@00I7oo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool3
0003Ool00`00Oomoo`02Ool3001QOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007oo
Ool007oo0003Ool01000Oomoo`001Woo0P00H7oo0003Ool50002Ool01000Oomoo`0027oo00@007oo
Ool0009oo`04001oogoo0005Ool01000Oomoo`001goo0`00GWoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`020008Ool2000017oo0000000017oo0P001goo
0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo
0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003
Ool00`00Oomoo`08Ool20003Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001o
ogoo001oo`001Woo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00
Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0:Ool01000
Oomoo`000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomo
o`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo
00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007oo
Ool02Goo00<007oo000017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`00
0Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool5
0003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`00
17oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`0<Ool2001HOol002Qo
o`03001oogoo00eoo`8005Moo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool0
0`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo
00moo`8005Eoo`00:7oo00<007ooOol047oo00<007ooOol0Dgoo000XOol00`00Oomoo`0AOol00`00
Oomoo`1BOol002Qoo`03001oogoo019oo`03001oogoo055oo`00:7oo00<007ooOol04Woo0P00DWoo
000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0COol00`00Oomo
o`1@Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomo
o`005Woo00<007ooOol0Cgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005
Ool01000Oomoo`005goo00<007ooOol0CWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04
001oogoo0005Ool00`00Oomoo`02000FOol2001?Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00D007ooOol007oo00@000=oo`03001oogoo01Iood@000aoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P00
0Woo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo
0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomo
o`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo
0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007oo
Oomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool0
00]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomo
o`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo1000
0goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008
Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Ao
o`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Io
o`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000
Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol0
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`00
0Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool4
0003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000
Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<0
07ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo
00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P00
2Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Ao
o`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
01aoofT000aoo`0077oo0P000Woo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03
001oo`00079oo`0077oo0P0000=oo`000000L7oo000LOol01000Oomoogoo0P00Kgoo000LOol00`00
Oomoo`02Ool2001^Ool001aoo`8000Aoo`8006eoo`0077oo00<007ooOol01Goo00<007ooOol0JWoo
000LOol00`00Oomoo`06Ool3001YOol001aoo`8000Uoo`8006Qoo`0077oo00<007ooOol02Goo0P00
Igoo000LOol2000;Ool00`00Oomoo`1UOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001o
ogoo00Yoo`03001oogoo06Eoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`0;Ool00`00Oomoo`1TOol000Yoo`04001oogoo000;Ool00`00Oomoo`02000=Ool00`00Oomoo`1S
Ool000Yoo`04001oogoo000;Ool01000Oomoo`003Woo00<007ooOol0Hgoo000:Ool01000Oomoo`00
1goo10000goo00<007ooOol03Goo00<007ooOol0HWoo000:Ool01000Oomoo`001goo00<007ooOol0
17oo0P003Woo00<007ooOol0HWoo000;Ool20008Ool50002Ool00`00Oomoo`0>Ool00`00Oomoo`1Q
Ool001aoo`03001oogoo00ioo`80069oo`0077oo0P0047oo00<007ooOol0H7oo000LOol00`00Oomo
o`0?Ool2001QOol001aoo`80015oo`03001oogoo05moo`0077oo00<007ooOol04Goo00<007ooOol0
GWoo000LOol00`00Oomoo`0AOol00`00Oomoo`1NOol001aoo`8001=oo`03001oogoo05eoo`005Woo
0`000goo00<007ooOol04goo00<007ooOol0G7oo000GOol00`00Oomoo`02Ool00`00Oomoo`0COol0
0`00Oomoo`1LOol001Moo`03001oogoo009oo`8001Eoo`03001oogoo05]oo`005goo00<007ooOol0
0Woo00<007ooOol057oo0P00G7oo000GOol00`00Oomoo`02Ool00`00Oomoo`0EOol00`00Oomoo`1J
Ool001Ioo`8000Aoo`8001Moo`03001oogoo05Uoo`005goo00<007ooOol00Woo00<007ooOol05Woo
00<007ooOol0FGoo000LOol00`00Oomoo`0GOol00`00Oomoo`1HOol001aoo`8001Qoo`03001oogoo
05Qoo`0077oo00<007ooOol067oo00<007ooOol0Egoo000LOol2000JOol00`00Oomoo`1FOol001ao
o`03001oogoo01Uoo`8001Uooc8000aoo`0077oo00<007ooOol06goo6P00?Goo000:Ool30004Ool0
0`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001o
ogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00
Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(13193\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .44429 m
.008 .43566 L
.012 .42687 L
.016 .4181 L
.02 .40927 L
.024 .40147 L
.028 .39419 L
.032 .38697 L
.036 .37988 L
.04 .37261 L
.044 .36456 L
.048 .3546 L
.052 .34405 L
.056 .33509 L
.06 .32839 L
.064 .32264 L
.068 .31884 L
.072 .31942 L
.076 .32541 L
.08 .33659 L
.084 .3513 L
.088 .36682 L
.092 .38049 L
.096 .39033 L
.1 .39585 L
.104 .39884 L
.108 .39986 L
.112 .39755 L
.116 .39036 L
.12 .3778 L
.124 .36235 L
.128 .34765 L
.132 .33547 L
.136 .32535 L
.14 .3165 L
.144 .30937 L
.148 .30507 L
.152 .30394 L
.156 .30436 L
.16 .30361 L
.164 .30056 L
.168 .29639 L
.172 .2934 L
.176 .29291 L
.18 .29384 L
.184 .29336 L
.188 .2893 L
.192 .28169 L
.196 .27274 L
.2 .2655 L
Mistroke
.204 .26185 L
.208 .26174 L
.212 .2637 L
.216 .266 L
.22 .26775 L
.224 .26912 L
.228 .27061 L
.232 .27241 L
.236 .27388 L
.24 .27382 L
.244 .27117 L
.248 .26571 L
.252 .25836 L
.256 .25089 L
.26 .24524 L
.264 .24278 L
.268 .24372 L
.272 .24724 L
.276 .25184 L
.28 .25604 L
.284 .25902 L
.288 .26087 L
.292 .26249 L
.296 .2651 L
.3 .26965 L
.304 .27637 L
.308 .28458 L
.312 .29295 L
.316 .29992 L
.32 .30431 L
.324 .3057 L
.328 .30454 L
.332 .30192 L
.336 .29917 L
.34 .29736 L
.344 .29703 L
.348 .29809 L
.352 .29999 L
.356 .30201 L
.36 .30355 L
.364 .3043 L
.368 .30424 L
.372 .30354 L
.376 .30244 L
.38 .30122 L
.384 .3001 L
.388 .29936 L
.392 .29921 L
.396 .29982 L
.4 .30112 L
Mistroke
.404 .30275 L
.408 .30413 L
.412 .30464 L
.416 .30395 L
.42 .30219 L
.424 .30002 L
.428 .29838 L
.432 .29808 L
.436 .29939 L
.44 .30179 L
.444 .3042 L
.448 .30547 L
.452 .30491 L
.456 .30273 L
.46 .29993 L
.464 .29789 L
.468 .29766 L
.472 .2994 L
.476 .30224 L
.48 .30473 L
.484 .30559 L
.488 .30436 L
.492 .30169 L
.496 .299 L
.5 .2977 L
.504 .29847 L
.508 .30086 L
.512 .30356 L
.516 .30508 L
.52 .30463 L
.524 .30251 L
.528 .29994 L
.532 .29838 L
.536 .29863 L
.54 .30048 L
.544 .30283 L
.548 .30432 L
.552 .30415 L
.556 .30249 L
.56 .30038 L
.564 .29905 L
.568 .29925 L
.572 .30074 L
.576 .30257 L
.58 .30364 L
.584 .30338 L
.588 .30205 L
.592 .30051 L
.596 .29968 L
.6 .29999 L
Mistroke
.604 .30118 L
.608 .30245 L
.612 .30303 L
.616 .30262 L
.62 .30157 L
.624 .30058 L
.628 .30024 L
.632 .30069 L
.636 .30155 L
.64 .30226 L
.644 .30242 L
.648 .302 L
.652 .30132 L
.656 .3008 L
.66 .30072 L
.664 .30109 L
.668 .30165 L
.672 .30203 L
.676 .30203 L
.68 .30168 L
.684 .30123 L
.688 .30095 L
.692 .301 L
.696 .30129 L
.7 .30165 L
.704 .30186 L
.708 .30181 L
.712 .30155 L
.716 .3012 L
.72 .30099 L
.724 .30105 L
.728 .30138 L
.732 .30176 L
.736 .30191 L
.74 .3017 L
.744 .30127 L
.748 .30093 L
.752 .30096 L
.756 .30132 L
.76 .30175 L
.764 .3019 L
.768 .30167 L
.772 .30124 L
.776 .30094 L
.78 .30099 L
.784 .30134 L
.788 .30172 L
.792 .30184 L
.796 .30162 L
.8 .30121 L
Mistroke
.804 .30093 L
.808 .301 L
.812 .30137 L
.816 .30175 L
.82 .30184 L
.824 .30152 L
.828 .30105 L
.832 .30084 L
.836 .30107 L
.84 .30157 L
.844 .30189 L
.848 .30171 L
.852 .30121 L
.856 .30083 L
.86 .30091 L
.864 .30141 L
.868 .30183 L
.872 .30176 L
.876 .30131 L
.88 .30089 L
.884 .30088 L
.888 .30134 L
.892 .30174 L
.896 .30169 L
.9 .30133 L
.904 .30096 L
.908 .30095 L
.912 .30134 L
.916 .30164 L
.92 .30156 L
.924 .30128 L
.928 .30101 L
.932 .30106 L
.936 .30141 L
.94 .30156 L
.944 .30139 L
.948 .30119 L
.952 .30105 L
.956 .30117 L
.96 .3015 L
.964 .3015 L
.968 .30121 L
.972 .30109 L
.976 .30108 L
.98 .30129 L
.984 .30161 L
.988 .30145 L
.992 .30104 L
.996 .30098 L
1 .3011 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14254 m
.008 .1449 L
.012 .14614 L
.016 .14637 L
.02 .14715 L
.024 .14865 L
.028 .15017 L
.032 .15176 L
.036 .15339 L
.04 .1551 L
.044 .15672 L
.048 .15839 L
.052 .16031 L
.056 .16244 L
.06 .16437 L
.064 .16614 L
.068 .16817 L
.072 .17063 L
.076 .17329 L
.08 .17589 L
.084 .17805 L
.088 .17984 L
.092 .18167 L
.096 .18386 L
.1 .18656 L
.104 .18952 L
.108 .19206 L
.112 .19381 L
.116 .19479 L
.12 .19544 L
.124 .19643 L
.128 .19808 L
.132 .20053 L
.136 .20379 L
.14 .20793 L
.144 .21294 L
.148 .21859 L
.152 .22453 L
.156 .2304 L
.16 .2361 L
.164 .24177 L
.168 .2476 L
.172 .25356 L
.176 .25945 L
.18 .26503 L
.184 .27028 L
.188 .27542 L
.192 .28074 L
.196 .28641 L
.2 .29233 L
Mistroke
.204 .2982 L
.208 .30375 L
.212 .30893 L
.216 .31388 L
.22 .31892 L
.224 .32427 L
.228 .32996 L
.232 .33583 L
.236 .34156 L
.24 .34692 L
.244 .35183 L
.248 .35641 L
.252 .36092 L
.256 .36568 L
.26 .37093 L
.264 .37675 L
.268 .38306 L
.272 .38964 L
.276 .39622 L
.28 .40249 L
.284 .40823 L
.288 .41327 L
.292 .41755 L
.296 .42106 L
.3 .42383 L
.304 .42595 L
.308 .42751 L
.312 .42859 L
.316 .42931 L
.32 .42975 L
.324 .43001 L
.328 .43015 L
.332 .43025 L
.336 .43032 L
.34 .43039 L
.344 .43047 L
.348 .43054 L
.352 .4306 L
.356 .43063 L
.36 .43064 L
.364 .43063 L
.368 .43062 L
.372 .4306 L
.376 .43059 L
.38 .4306 L
.384 .43063 L
.388 .43067 L
.392 .43071 L
.396 .43074 L
.4 .43077 L
Mistroke
.404 .43077 L
.408 .43076 L
.412 .43074 L
.416 .43074 L
.42 .43074 L
.424 .43077 L
.428 .4308 L
.432 .43084 L
.436 .43088 L
.44 .43089 L
.444 .43089 L
.448 .43088 L
.452 .43087 L
.456 .43087 L
.46 .43089 L
.464 .43092 L
.468 .43096 L
.472 .43099 L
.476 .43101 L
.48 .43101 L
.484 .431 L
.488 .43099 L
.492 .43099 L
.496 .43101 L
.5 .43105 L
.504 .43108 L
.508 .43111 L
.512 .43112 L
.516 .43111 L
.52 .43111 L
.524 .43111 L
.528 .43112 L
.532 .43115 L
.536 .43118 L
.54 .4312 L
.544 .43122 L
.548 .43122 L
.552 .43122 L
.556 .43122 L
.56 .43123 L
.564 .43125 L
.568 .43128 L
.572 .4313 L
.576 .43132 L
.58 .43133 L
.584 .43133 L
.588 .43133 L
.592 .43135 L
.596 .43136 L
.6 .43139 L
Mistroke
.604 .43141 L
.608 .43142 L
.612 .43143 L
.616 .43144 L
.62 .43144 L
.624 .43146 L
.628 .43147 L
.632 .43149 L
.636 .43151 L
.64 .43152 L
.644 .43153 L
.648 .43154 L
.652 .43155 L
.656 .43156 L
.66 .43158 L
.664 .4316 L
.668 .43162 L
.672 .43163 L
.676 .43164 L
.68 .43165 L
.684 .43166 L
.688 .43167 L
.692 .43169 L
.696 .43171 L
.7 .43172 L
.704 .43173 L
.708 .43174 L
.712 .43175 L
.716 .43177 L
.72 .43178 L
.724 .4318 L
.728 .43181 L
.732 .43182 L
.736 .43183 L
.74 .43185 L
.744 .43186 L
.748 .43187 L
.752 .43189 L
.756 .4319 L
.76 .43192 L
.764 .43193 L
.768 .43194 L
.772 .43195 L
.776 .43197 L
.78 .43198 L
.784 .432 L
.788 .43201 L
.792 .43202 L
.796 .43203 L
.8 .43205 L
Mistroke
.804 .43206 L
.808 .43207 L
.812 .43209 L
.816 .4321 L
.82 .43211 L
.824 .43213 L
.828 .43214 L
.832 .43215 L
.836 .43217 L
.84 .43218 L
.844 .43219 L
.848 .43221 L
.852 .43222 L
.856 .43223 L
.86 .43224 L
.864 .43226 L
.868 .43227 L
.872 .43229 L
.876 .4323 L
.88 .43231 L
.884 .43232 L
.888 .43234 L
.892 .43235 L
.896 .43237 L
.9 .43238 L
.904 .43239 L
.908 .4324 L
.912 .43242 L
.916 .43243 L
.92 .43245 L
.924 .43246 L
.928 .43247 L
.932 .43248 L
.936 .4325 L
.94 .43251 L
.944 .43253 L
.948 .43253 L
.952 .43255 L
.956 .43256 L
.96 .43258 L
.964 .43258 L
.968 .43261 L
.972 .43261 L
.976 .43263 L
.98 .43263 L
.984 .43266 L
.988 .43266 L
.992 .43269 L
.996 .43268 L
1 .43272 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16299 L
.012 .1678 L
.016 .17142 L
.02 .1741 L
.024 .17695 L
.028 .18003 L
.032 .18289 L
.036 .18568 L
.04 .18809 L
.044 .19018 L
.048 .1922 L
.052 .19432 L
.056 .1962 L
.06 .1977 L
.064 .1989 L
.068 .20013 L
.072 .20186 L
.076 .20406 L
.08 .20622 L
.084 .20819 L
.088 .2101 L
.092 .21235 L
.096 .21547 L
.1 .21956 L
.104 .22402 L
.108 .22816 L
.112 .23119 L
.116 .23305 L
.12 .23434 L
.124 .2357 L
.128 .23766 L
.132 .2404 L
.136 .24403 L
.14 .24867 L
.144 .25441 L
.148 .26106 L
.152 .26814 L
.156 .27527 L
.16 .28231 L
.164 .28942 L
.168 .29682 L
.172 .30446 L
.176 .31205 L
.18 .31928 L
.184 .32607 L
.188 .33265 L
.192 .33938 L
.196 .34641 L
.2 .35361 L
Mistroke
.204 .36064 L
.208 .3672 L
.212 .37328 L
.216 .37916 L
.22 .38527 L
.224 .39194 L
.228 .3992 L
.232 .40677 L
.236 .41423 L
.24 .42116 L
.244 .42739 L
.248 .43303 L
.252 .43844 L
.256 .44404 L
.26 .45021 L
.264 .45716 L
.268 .46485 L
.272 .47304 L
.276 .48136 L
.28 .48938 L
.284 .49673 L
.288 .50314 L
.292 .50847 L
.296 .5127 L
.3 .51592 L
.304 .51829 L
.308 .51999 L
.312 .52119 L
.316 .52204 L
.32 .52263 L
.324 .52304 L
.328 .52331 L
.332 .52346 L
.336 .52352 L
.34 .5235 L
.344 .52344 L
.348 .52335 L
.352 .52327 L
.356 .52321 L
.36 .52318 L
.364 .52317 L
.368 .52316 L
.372 .52316 L
.376 .52314 L
.38 .5231 L
.384 .52304 L
.388 .52296 L
.392 .52288 L
.396 .52281 L
.4 .52276 L
Mistroke
.404 .52273 L
.408 .52271 L
.412 .5227 L
.416 .52269 L
.42 .52265 L
.424 .5226 L
.428 .52252 L
.432 .52244 L
.436 .52237 L
.44 .52233 L
.444 .5223 L
.448 .52229 L
.452 .52228 L
.456 .52225 L
.46 .5222 L
.464 .52213 L
.468 .52205 L
.472 .52199 L
.476 .52194 L
.48 .52191 L
.484 .52189 L
.488 .52188 L
.492 .52184 L
.496 .52179 L
.5 .52172 L
.504 .52165 L
.508 .52159 L
.512 .52155 L
.516 .52153 L
.52 .52151 L
.524 .52148 L
.528 .52144 L
.532 .52138 L
.536 .52131 L
.54 .52125 L
.544 .52121 L
.548 .52117 L
.552 .52115 L
.556 .52112 L
.56 .52108 L
.564 .52102 L
.568 .52097 L
.572 .52091 L
.576 .52086 L
.58 .52082 L
.584 .52079 L
.588 .52076 L
.592 .52072 L
.596 .52067 L
.6 .52061 L
Mistroke
.604 .52056 L
.608 .52051 L
.612 .52047 L
.616 .52044 L
.62 .5204 L
.624 .52036 L
.628 .52031 L
.632 .52026 L
.636 .52021 L
.64 .52016 L
.644 .52012 L
.648 .52009 L
.652 .52005 L
.656 .52 L
.66 .51995 L
.664 .5199 L
.668 .51985 L
.672 .51981 L
.676 .51977 L
.68 .51973 L
.684 .51969 L
.688 .51964 L
.692 .5196 L
.696 .51955 L
.7 .5195 L
.704 .51946 L
.708 .51942 L
.712 .51938 L
.716 .51933 L
.72 .51929 L
.724 .51924 L
.728 .51919 L
.732 .51915 L
.736 .51911 L
.74 .51907 L
.744 .51902 L
.748 .51898 L
.752 .51893 L
.756 .51889 L
.76 .51884 L
.764 .5188 L
.768 .51876 L
.772 .51871 L
.776 .51867 L
.78 .51862 L
.784 .51858 L
.788 .51853 L
.792 .51849 L
.796 .51845 L
.8 .5184 L
Mistroke
.804 .51836 L
.808 .51831 L
.812 .51827 L
.816 .51822 L
.82 .51818 L
.824 .51814 L
.828 .51809 L
.832 .51805 L
.836 .518 L
.84 .51796 L
.844 .51791 L
.848 .51787 L
.852 .51782 L
.856 .51778 L
.86 .51774 L
.864 .51769 L
.868 .51765 L
.872 .5176 L
.876 .51756 L
.88 .51752 L
.884 .51747 L
.888 .51743 L
.892 .51738 L
.896 .51734 L
.9 .51729 L
.904 .51725 L
.908 .5172 L
.912 .51716 L
.916 .51711 L
.92 .51707 L
.924 .51702 L
.928 .51698 L
.932 .51693 L
.936 .5169 L
.94 .51684 L
.944 .51681 L
.948 .51675 L
.952 .51672 L
.956 .51666 L
.96 .51663 L
.964 .51657 L
.968 .51654 L
.972 .51648 L
.976 .51645 L
.98 .51639 L
.984 .51637 L
.988 .5163 L
.992 .51628 L
.996 .51621 L
1 .51619 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool40004Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0002
Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0
2goo10000goo00<007ooOol00P0000=oo`00Ool00goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol0009oo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000=oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo
0P002Woo0P0017oo00<007ooOol00Woo0P0037oo00<007ooOol00goo0`0000=oo`0000000Woo0P00
00=oo`00000017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000
Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00L007ooOomo
o`00Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool60002Ool30004Ool200000goo001oo`04
Ool20004Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo
1@000goo0P001Woo000ROol00`00Oomoo`0@Ool00`00Oomoo`08Ool00`00Oomoo`1>Ool0029oo`80
00moo`8000aoo`04001oo`000007Ool00`00Oomoo`020002Ool01000Oomoo`00>Woo000ROomS000<
Ool0029oo`05001oogooOol00002Ool20003Ool01@00Ool007oo00000goo00D007ooOomoo`00009o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`03001oogoo00Yoo`008Woo0P0017oo0`0017oo00<007ooOol0
Ggoo000ROol00`00Oomoo`03Ool00`00Ool00004Ool00`00Oomoo`1OOol0029oo`8000=oo`04001o
ogoo0004Ool00`00Oomoo`1OOol0029oo`8000=oo`04001oogoo0004Ool00`00Oomoo`1OOol000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`05001oogooOol00004Ool01000Oomoo`00HWoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80009oo`03001oogoo009o
o`04001oogoo001ROol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
00=oo`00Ool01Goo0P00Hgoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`04001oogoo0006Ool2001SOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`<006aoo`002goo0P00
2Woo0P0017oo00<007ooOol00Woo0P00KGoo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo
0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo
06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]
Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2
001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06ao
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`00
00=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo
00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003
Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0
17oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004
Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001o
ogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo0`00IWoo000XOol00`00Oomoo`03001S
Ool002Qoo`03001oogoo009oo`<0065oo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo
0`000goo00<007ooOol017oo0P00H7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001o
ogoo001oo`000goo00@007ooOol000Qoo`8005ioo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00@007ooOol000Uoo`@005]oo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P00
17oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P00
1Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomo
o`09Ool01@00Ool007oo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Io
o`03001oogoo00]oo`<0009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0
009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2
000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0<Ool20002Ool01000Oomoo`001goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool50002Ool01000Oomoo`00
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool0
00030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool01000Oomoogoo0P0000Eoo`00Oomo
o`0000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool0
0006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool60002Ool20008Ool00`00Oomoo`03Ool2
0004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@00
0goo0P001Woo000XOol00`00Oomoo`0?Ool00`00Oomoo`1DOol002Qoo`03001oogoo00moo`8005Eo
o`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool01000Ool000003goo00<007ooOol03goo00<007oo
Ool03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`0BOol00`00Oomoo`1AOol0
02Qoo`03001oogoo019oo`80059oo`00:7oo00<007ooOol04goo0P00DGoo000XOol00`00Oomoo`0D
Ool2001@Ool002Qoo`03001oogoo01Eoo`03001oogoo04ioo`002goo0P0017oo00<007ooOol00goo
0P0017oo0P000goo0`000goo00<007ooOol05Woo00<007ooOol0CGoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol001Qoo`03001oogoo04eoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol001Uoo`03001oogoo
04aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00
67oo0P00CGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool0
0`00Oomoo`0IOom1000<Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007oo
Ool006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02
001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomo
ogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02
Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`00
2goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000L
Ool00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005
Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol0
0002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00
Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`00
77oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo
00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@0
00=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool2
0004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`00
00Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`80
00Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006
Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`<00003Ool0
07oo009oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`04001oo`00001aOol001aoo`80
009oo`8006moo`0077oo00<007ooOol00goo0`00K7oo000LOol00`00Oomoo`05Ool2001[Ool001ao
o`8000Qoo`8006Uoo`0077oo00<007ooOol027oo00<007ooOol0Igoo000LOol00`00Oomoo`09Ool3
001VOol001aoo`8000aoo`8006Eoo`0077oo00<007ooOol037oo00<007ooOol0Hgoo000LOol2000>
Ool00`00Oomoo`1ROol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo00eoo`03001o
ogoo069oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0>Ool00`00Oomo
o`1QOol000Yoo`04001oogoo000;Ool00`00Oomoo`02000?Ool2001ROol000Yoo`04001oogoo000;
Ool01000Oomoo`004Goo00<007ooOol0H7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0
3goo00<007ooOol0H7oo000:Ool01000Oomoo`001goo00<007ooOol017oo0P004Goo00<007ooOol0
Ggoo000;Ool20008Ool50002Ool00`00Oomoo`0AOol00`00Oomoo`1NOol001aoo`03001oogoo015o
o`03001oogoo05ioo`0077oo0P004goo00<007ooOol0GGoo000LOol00`00Oomoo`0BOol00`00Oomo
o`1MOol001aoo`8001Aoo`03001oogoo05aoo`0077oo00<007ooOol057oo00<007ooOol0Fgoo000L
Ool00`00Oomoo`0DOol00`00Oomoo`1KOol001aoo`8001Ioo`03001oogoo05Yoo`005Woo0`000goo
00<007ooOol05Goo0P00Fgoo000GOol00`00Oomoo`02Ool00`00Oomoo`0FOol00`00Oomoo`1IOol0
01Moo`03001oogoo009oo`8001Moo`8005Yoo`005goo00<007ooOol00Woo00<007ooOol05goo0P00
FGoo000GOol00`00Oomoo`02Ool00`00Oomoo`0HOol00`00Oomoo`1GOol001Ioo`8000Aoo`8001Yo
o`03001oogoo05Ioo`005goo00<007ooOol00Woo00<007ooOol06Goo00<007ooOol0EWoo000LOol0
0`00Oomoo`0JOol00`00Oomoo`1EOol001aoo`8001]oo`03001oogoo05Eoo`0077oo00<007ooOol0
6goo00<007ooOol0E7oo000LOol2000LOol00`00Oomoo`1DOol001aoo`03001oogoo01aoo`8001Io
oc8000aoo`0077oo00<007ooOol07Woo5P00?Woo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2
001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001o
ogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<0
07ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1b
Ool000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(13360\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .34652 m
.008 .34413 L
.012 .34243 L
.016 .34054 L
.02 .33824 L
.024 .33568 L
.028 .3328 L
.032 .32963 L
.036 .32673 L
.04 .3259 L
.044 .32722 L
.048 .33032 L
.052 .33566 L
.056 .34475 L
.06 .35646 L
.064 .36727 L
.068 .37567 L
.072 .38203 L
.076 .38629 L
.08 .38721 L
.084 .38411 L
.088 .37687 L
.092 .36722 L
.096 .35785 L
.1 .35102 L
.104 .34842 L
.108 .3498 L
.112 .35268 L
.116 .35487 L
.12 .35616 L
.124 .35807 L
.128 .36276 L
.132 .36958 L
.136 .37541 L
.14 .37792 L
.144 .37681 L
.148 .37342 L
.152 .36865 L
.156 .36175 L
.16 .35139 L
.164 .33788 L
.168 .32361 L
.172 .3112 L
.176 .30176 L
.18 .29457 L
.184 .28841 L
.188 .28348 L
.192 .28141 L
.196 .28349 L
.2 .2889 L
Mistroke
.204 .29445 L
.208 .29606 L
.212 .29147 L
.216 .28152 L
.22 .26968 L
.224 .26021 L
.228 .25582 L
.232 .25668 L
.236 .26087 L
.24 .26559 L
.244 .26872 L
.248 .26941 L
.252 .26803 L
.256 .26559 L
.26 .26301 L
.264 .26081 L
.268 .25906 L
.272 .25758 L
.276 .25612 L
.28 .25445 L
.284 .25242 L
.288 .24995 L
.292 .2471 L
.296 .24417 L
.3 .24172 L
.304 .24056 L
.308 .24148 L
.312 .245 L
.316 .25116 L
.32 .2594 L
.324 .26871 L
.328 .27789 L
.332 .28588 L
.336 .29201 L
.34 .29609 L
.344 .29837 L
.348 .2993 L
.352 .2994 L
.356 .29911 L
.36 .2988 L
.364 .29875 L
.368 .29919 L
.372 .30018 L
.376 .30162 L
.38 .30315 L
.384 .30426 L
.388 .30444 L
.392 .3035 L
.396 .30168 L
.4 .29968 L
Mistroke
.404 .29838 L
.408 .29843 L
.412 .29994 L
.416 .30233 L
.42 .30453 L
.424 .30546 L
.428 .3046 L
.432 .30228 L
.436 .29959 L
.44 .29784 L
.444 .29793 L
.448 .29985 L
.452 .30268 L
.456 .30499 L
.46 .30557 L
.464 .30412 L
.468 .30139 L
.472 .2988 L
.476 .29773 L
.48 .29871 L
.484 .3012 L
.488 .30384 L
.492 .3052 L
.496 .30458 L
.5 .30236 L
.504 .29979 L
.508 .29832 L
.512 .29871 L
.516 .30068 L
.52 .30305 L
.524 .30447 L
.528 .3042 L
.532 .30246 L
.536 .30031 L
.54 .29901 L
.544 .29926 L
.548 .30082 L
.552 .30271 L
.556 .3038 L
.56 .30349 L
.564 .30208 L
.568 .30047 L
.572 .29963 L
.576 .29999 L
.58 .30123 L
.584 .30255 L
.588 .30315 L
.592 .30274 L
.596 .30164 L
.6 .30058 L
Mistroke
.604 .3002 L
.608 .30067 L
.612 .3016 L
.616 .30239 L
.62 .30256 L
.624 .30209 L
.628 .30134 L
.632 .30079 L
.636 .30073 L
.64 .30113 L
.644 .30172 L
.648 .30211 L
.652 .30211 L
.656 .30174 L
.66 .30126 L
.664 .30097 L
.668 .30102 L
.672 .30135 L
.676 .30173 L
.68 .30193 L
.684 .30186 L
.688 .30157 L
.692 .30124 L
.696 .30106 L
.7 .30113 L
.704 .30142 L
.708 .30177 L
.712 .30192 L
.716 .30176 L
.72 .30138 L
.724 .30104 L
.728 .301 L
.732 .30131 L
.736 .30173 L
.74 .30194 L
.744 .30178 L
.748 .30137 L
.752 .30102 L
.756 .301 L
.76 .30131 L
.764 .30171 L
.768 .3019 L
.772 .30172 L
.776 .30133 L
.78 .30101 L
.784 .30102 L
.788 .30134 L
.792 .30174 L
.796 .30189 L
.8 .30164 L
Mistroke
.804 .3012 L
.808 .30093 L
.812 .30105 L
.816 .30149 L
.82 .30187 L
.824 .30182 L
.828 .30141 L
.832 .30098 L
.836 .30092 L
.84 .3013 L
.844 .30175 L
.848 .30185 L
.852 .30153 L
.856 .30108 L
.86 .30092 L
.864 .30122 L
.868 .30162 L
.872 .30176 L
.876 .30155 L
.88 .30116 L
.884 .301 L
.888 .30122 L
.892 .30152 L
.896 .30163 L
.9 .30149 L
.904 .30122 L
.908 .30112 L
.912 .30128 L
.916 .30143 L
.92 .30147 L
.924 .30141 L
.928 .30126 L
.932 .30124 L
.936 .30136 L
.94 .30136 L
.944 .30131 L
.948 .30132 L
.952 .30129 L
.956 .30135 L
.96 .30144 L
.964 .30129 L
.968 .30116 L
.972 .30125 L
.976 .30132 L
.98 .30145 L
.984 .30152 L
.988 .30122 L
.992 .301 L
.996 .30118 L
1 .30136 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13658 m
.008 .13491 L
.012 .13464 L
.016 .13586 L
.02 .13679 L
.024 .13759 L
.028 .13882 L
.032 .14054 L
.036 .14243 L
.04 .14453 L
.044 .14669 L
.048 .14896 L
.052 .15133 L
.056 .15376 L
.06 .15583 L
.064 .15754 L
.068 .15916 L
.072 .16084 L
.076 .16241 L
.08 .16373 L
.084 .16477 L
.088 .16578 L
.092 .16717 L
.096 .16906 L
.1 .17122 L
.104 .17337 L
.108 .17524 L
.112 .17691 L
.116 .17884 L
.12 .18139 L
.124 .18458 L
.128 .18802 L
.132 .19099 L
.136 .19315 L
.14 .19454 L
.144 .1955 L
.148 .19646 L
.152 .19766 L
.156 .19936 L
.16 .20181 L
.164 .20524 L
.168 .20969 L
.172 .21488 L
.176 .22045 L
.18 .2261 L
.184 .23179 L
.188 .23763 L
.192 .24369 L
.196 .24982 L
.2 .25578 L
Mistroke
.204 .26134 L
.208 .26656 L
.212 .27169 L
.216 .27703 L
.22 .28272 L
.224 .28864 L
.228 .29451 L
.232 .30006 L
.236 .30522 L
.24 .31016 L
.244 .31514 L
.248 .32042 L
.252 .32607 L
.256 .33194 L
.26 .33777 L
.264 .3433 L
.268 .34839 L
.272 .35309 L
.276 .35761 L
.28 .36222 L
.284 .3672 L
.288 .37269 L
.292 .37871 L
.296 .38513 L
.3 .39173 L
.304 .39822 L
.308 .40435 L
.312 .4099 L
.316 .41472 L
.32 .41875 L
.324 .422 L
.328 .42452 L
.332 .42639 L
.336 .42774 L
.34 .42867 L
.344 .42931 L
.348 .42973 L
.352 .43001 L
.356 .43021 L
.36 .43036 L
.364 .43047 L
.368 .43055 L
.372 .4306 L
.376 .43063 L
.38 .43064 L
.384 .43063 L
.388 .43062 L
.392 .43061 L
.396 .43063 L
.4 .43065 L
Mistroke
.404 .43069 L
.408 .43073 L
.412 .43076 L
.416 .43077 L
.42 .43077 L
.424 .43076 L
.428 .43075 L
.432 .43075 L
.436 .43077 L
.44 .43081 L
.444 .43084 L
.448 .43087 L
.452 .43089 L
.456 .43089 L
.46 .43088 L
.464 .43087 L
.468 .43088 L
.472 .4309 L
.476 .43093 L
.48 .43097 L
.484 .43099 L
.488 .431 L
.492 .431 L
.496 .43099 L
.5 .43099 L
.504 .43101 L
.508 .43103 L
.512 .43106 L
.516 .43109 L
.52 .4311 L
.524 .43111 L
.528 .4311 L
.532 .43111 L
.536 .43112 L
.54 .43114 L
.544 .43116 L
.548 .43119 L
.552 .4312 L
.556 .43121 L
.56 .43121 L
.564 .43122 L
.568 .43123 L
.572 .43125 L
.576 .43127 L
.58 .43129 L
.584 .4313 L
.588 .43131 L
.592 .43132 L
.596 .43133 L
.6 .43134 L
Mistroke
.604 .43136 L
.608 .43138 L
.612 .43139 L
.616 .43141 L
.62 .43142 L
.624 .43142 L
.628 .43143 L
.632 .43145 L
.636 .43146 L
.64 .43148 L
.644 .4315 L
.648 .43151 L
.652 .43152 L
.656 .43153 L
.66 .43154 L
.664 .43156 L
.668 .43157 L
.672 .43159 L
.676 .4316 L
.68 .43161 L
.684 .43162 L
.688 .43164 L
.692 .43165 L
.696 .43167 L
.7 .43168 L
.704 .43169 L
.708 .43171 L
.712 .43172 L
.716 .43173 L
.72 .43174 L
.724 .43176 L
.728 .43177 L
.732 .43179 L
.736 .4318 L
.74 .43181 L
.744 .43182 L
.748 .43184 L
.752 .43185 L
.756 .43186 L
.76 .43188 L
.764 .43189 L
.768 .4319 L
.772 .43192 L
.776 .43193 L
.78 .43194 L
.784 .43196 L
.788 .43197 L
.792 .43198 L
.796 .432 L
.8 .43201 L
Mistroke
.804 .43202 L
.808 .43204 L
.812 .43205 L
.816 .43206 L
.82 .43207 L
.824 .43209 L
.828 .4321 L
.832 .43212 L
.836 .43213 L
.84 .43214 L
.844 .43215 L
.848 .43217 L
.852 .43218 L
.856 .4322 L
.86 .43221 L
.864 .43222 L
.868 .43223 L
.872 .43225 L
.876 .43226 L
.88 .43227 L
.884 .43228 L
.888 .4323 L
.892 .43231 L
.896 .43233 L
.9 .43234 L
.904 .43235 L
.908 .43236 L
.912 .43238 L
.916 .43239 L
.92 .43241 L
.924 .43242 L
.928 .43243 L
.932 .43244 L
.936 .43246 L
.94 .43247 L
.944 .43249 L
.948 .43249 L
.952 .43251 L
.956 .43252 L
.96 .43254 L
.964 .43254 L
.968 .43257 L
.972 .43257 L
.976 .4326 L
.98 .43259 L
.984 .43262 L
.988 .43262 L
.992 .43265 L
.996 .43265 L
1 .43268 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .1603 L
.012 .16274 L
.016 .1642 L
.02 .16469 L
.024 .16544 L
.028 .16664 L
.032 .16791 L
.036 .16932 L
.04 .17068 L
.044 .17211 L
.048 .17372 L
.052 .17568 L
.056 .17774 L
.06 .17983 L
.064 .18188 L
.068 .18412 L
.072 .18672 L
.076 .18954 L
.08 .19208 L
.084 .19424 L
.088 .19633 L
.092 .19861 L
.096 .20121 L
.1 .20397 L
.104 .20639 L
.108 .20831 L
.112 .20993 L
.116 .21179 L
.12 .21451 L
.124 .21818 L
.128 .22218 L
.132 .22581 L
.136 .22852 L
.14 .23035 L
.144 .23176 L
.148 .23319 L
.152 .23498 L
.156 .23736 L
.16 .24064 L
.164 .24506 L
.168 .25063 L
.172 .25702 L
.176 .26375 L
.18 .27048 L
.184 .27723 L
.188 .2842 L
.192 .29153 L
.196 .2991 L
.2 .3066 L
Mistroke
.204 .31376 L
.208 .32056 L
.212 .32725 L
.216 .33412 L
.22 .34127 L
.224 .34854 L
.228 .35559 L
.232 .36218 L
.236 .36828 L
.24 .37419 L
.244 .3803 L
.248 .38694 L
.252 .39415 L
.256 .40168 L
.26 .40914 L
.264 .41613 L
.268 .42244 L
.272 .42813 L
.276 .43352 L
.28 .43902 L
.284 .44502 L
.288 .45176 L
.292 .45926 L
.296 .46734 L
.3 .47566 L
.304 .48384 L
.308 .49149 L
.312 .49835 L
.316 .50423 L
.32 .50909 L
.324 .51297 L
.328 .51596 L
.332 .51822 L
.336 .51987 L
.34 .52105 L
.344 .52186 L
.348 .5224 L
.352 .52273 L
.356 .52291 L
.36 .52298 L
.364 .52299 L
.368 .52296 L
.372 .52292 L
.376 .52289 L
.38 .52288 L
.384 .52287 L
.388 .52286 L
.392 .52284 L
.396 .5228 L
.4 .52274 L
Mistroke
.404 .52266 L
.408 .52259 L
.412 .52253 L
.416 .52248 L
.42 .52246 L
.424 .52245 L
.428 .52243 L
.432 .5224 L
.436 .52235 L
.44 .52228 L
.444 .5222 L
.448 .52214 L
.452 .52209 L
.456 .52207 L
.46 .52205 L
.464 .52203 L
.468 .522 L
.472 .52194 L
.476 .52187 L
.48 .5218 L
.484 .52175 L
.488 .52171 L
.492 .52168 L
.496 .52166 L
.5 .52163 L
.504 .52159 L
.508 .52153 L
.512 .52147 L
.516 .52141 L
.52 .52136 L
.524 .52133 L
.528 .5213 L
.532 .52127 L
.536 .52123 L
.54 .52118 L
.544 .52112 L
.548 .52106 L
.552 .52101 L
.556 .52098 L
.56 .52094 L
.564 .52091 L
.568 .52087 L
.572 .52082 L
.576 .52077 L
.58 .52071 L
.584 .52067 L
.588 .52063 L
.592 .52059 L
.596 .52056 L
.6 .52051 L
Mistroke
.604 .52046 L
.608 .52041 L
.612 .52036 L
.616 .52032 L
.62 .52028 L
.624 .52024 L
.628 .5202 L
.632 .52016 L
.636 .52011 L
.64 .52006 L
.644 .52001 L
.648 .51997 L
.652 .51993 L
.656 .51989 L
.66 .51985 L
.664 .5198 L
.668 .51975 L
.672 .5197 L
.676 .51966 L
.68 .51962 L
.684 .51958 L
.688 .51953 L
.692 .51949 L
.696 .51944 L
.7 .51939 L
.704 .51935 L
.708 .51931 L
.712 .51927 L
.716 .51922 L
.72 .51918 L
.724 .51913 L
.728 .51909 L
.732 .51904 L
.736 .519 L
.74 .51896 L
.744 .51891 L
.748 .51887 L
.752 .51882 L
.756 .51878 L
.76 .51873 L
.764 .51869 L
.768 .51865 L
.772 .5186 L
.776 .51856 L
.78 .51851 L
.784 .51847 L
.788 .51842 L
.792 .51838 L
.796 .51833 L
.8 .51829 L
Mistroke
.804 .51825 L
.808 .5182 L
.812 .51816 L
.816 .51811 L
.82 .51807 L
.824 .51802 L
.828 .51798 L
.832 .51794 L
.836 .51789 L
.84 .51785 L
.844 .5178 L
.848 .51776 L
.852 .51771 L
.856 .51767 L
.86 .51762 L
.864 .51758 L
.868 .51754 L
.872 .51749 L
.876 .51745 L
.88 .5174 L
.884 .51736 L
.888 .51732 L
.892 .51727 L
.896 .51723 L
.9 .51718 L
.904 .51714 L
.908 .51709 L
.912 .51705 L
.916 .517 L
.92 .51696 L
.924 .51691 L
.928 .51687 L
.932 .51682 L
.936 .51679 L
.94 .51673 L
.944 .5167 L
.948 .51664 L
.952 .51661 L
.956 .51655 L
.96 .51652 L
.964 .51647 L
.968 .51643 L
.972 .51637 L
.976 .51634 L
.98 .51628 L
.984 .51626 L
.988 .5162 L
.992 .51617 L
.996 .5161 L
1 .51608 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`02Ool40004Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0002
Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0
2goo10000goo10000Woo0P000Woo0P0017oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomo
ogoo10000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0
00=oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007oo
Ool00Woo0P0037oo00<007ooOol017oo1P0017oo0P0017oo00@007ooOol0009oo`04001oogoo0004
Ool20003Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002
Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool5
0003Ool40006Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`00
17oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`0?Ool200000goo001o
o`09Ool00`00Oomoo`1<Ool0029oo`80011oo`04001oo`00000;Ool200000goo001oo`02Ool01000
Oomoo`000goo00@007ooOol003aoo`008WooH`0037oo000ROol01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`80009oo`05001oogooOol00002Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomo
o`0:Ool0029oo`80009oo`03001oogoo00Yoo`03001oogoo05]oo`008Woo00H007oo000007oo000:
Ool00`00Oomoo`1LOol0029oo`<000=oo`04001oogooOol20004Ool00`00Oomoo`1LOol0029oo`80
00Aoo`04001oogooOol30003Ool00`00Oomoo`1LOol000]oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`03001oogoo00=oo`04001oogoo0003Ool00`00Ool0001OOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P001Goo00<007oo00000goo0`00Ggoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Eoo`8006Ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool2
0004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomo
o`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003
Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]
Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo
00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00
KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo
000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool0
1000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomo
o`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo
0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`00
27oo00@007ooOol0009oo`8000Aoo`<006Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<0
07ooOol00P00I7oo000XOol00`00Oomoo`02Ool2001ROol002Qoo`03001oogoo00Aoo`<005moo`00
2goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol01goo0P00GGoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol000Yoo`<0
05]oo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Ool000aoo`<005Uoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol00P002goo10000goo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo
1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007oo
Ool000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=o
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`800005Ool007ooOol0
0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001o
ogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00
Oomoo`0=Ool40002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool0
02Qoo`03001oogoo00Uoo`@0009oo`80009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00
:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool0
1000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00
Oomoo`09Ool50002Ool30008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo
0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`0AOol2
001COol002Qoo`03001oogoo019oo`03001oogoo055oo`00:7ooG@0037oo000XOol00`00Oomoo`0?
Ool01000Oomoogoo0P003Goo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007oo
Ool02Woo000XOol00`00Oomoo`0DOol2001@Ool002Qoo`03001oogoo01Eoo`03001oogoo04ioo`00
:7oo00<007ooOol05Woo00<007ooOol0CGoo000XOol00`00Oomoo`0FOol2001>Ool002Qoo`03001o
ogoo01Moo`8004eoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007oo
Ool067oo00<007ooOol0Bgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`000goo00@007ooOol001]oo`03001oogoo04Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOol001]oo`8004]oo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol00P006goo0P00BWoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`0KOolo000<Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`80
00Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007oo
Ool0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo
00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol0
00Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`00
2goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004
Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004
Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001o
ogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`00
0goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03
001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo
0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo
00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Ao
o`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D0
00=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004
Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000LOomY000<Ool001aoo`03001oo`0000<0009oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomo
o`0:Ool001aoo`03001oogoo009oo`<006eoo`0077oo0P001Goo0P00K7oo000LOol00`00Oomoo`06
Ool2001ZOol001aoo`03001oogoo00Qoo`8006Qoo`0077oo0P002Woo0P00Igoo000LOol00`00Oomo
o`0:Ool3001UOol001aoo`03001oogoo00aoo`<006=oo`0077oo0P003goo00<007ooOol0HGoo000L
Ool00`00Oomoo`0?Ool00`00Oomoo`1POol001aoo`80011oo`03001oogoo061oo`002goo0P0017oo
00<007ooOol00Woo0`000goo00<007ooOol047oo00<007ooOol0Ggoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo015oo`03001oogoo05ioo`002Woo00@007ooOol000]oo`03
001oogoo0080019oo`03001oogoo05ioo`002Woo00@007ooOol000]oo`04001oogoo000COol2001O
Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0BOol00`00Oomoo`1MOol000Yoo`04001o
ogoo0007Ool00`00Oomoo`04Ool2000DOol00`00Oomoo`1LOol000]oo`8000Qoo`D0009oo`03001o
ogoo01Aoo`03001oogoo05]oo`0077oo00<007ooOol057oo00<007ooOol0Fgoo000LOol2000EOol2
001LOol001aoo`03001oogoo01Eoo`03001oogoo05Yoo`0077oo0P005goo00<007ooOol0FGoo000L
Ool00`00Oomoo`0FOol00`00Oomoo`1IOol001aoo`03001oogoo01Moo`03001oogoo05Qoo`0077oo
0P006Goo00<007ooOol0Egoo000FOol30003Ool00`00Oomoo`0HOol00`00Oomoo`1GOol001Moo`03
001oogoo009oo`03001oogoo01Uoo`03001oogoo05Ioo`005goo00<007ooOol00Woo0P006Woo0P00
Egoo000GOol00`00Oomoo`02Ool00`00Oomoo`0JOol00`00Oomoo`1EOol001Moo`03001oogoo009o
o`03001oogoo01]oo`03001oogoo05Aoo`005Woo0P0017oo0P0077oo00<007ooOol0E7oo000GOol0
0`00Oomoo`02Ool00`00Oomoo`0LOol00`00Oomoo`1COol001aoo`03001oogoo01aoo`03001oogoo
05=oo`0077oo0P007Woo00<007ooOol0DWoo000LOol00`00Oomoo`0MOol00`00Oomoo`1BOol001ao
o`8001moo`03001oogoo055oo`0077oo00<007ooOol07goo0P004Woo<`0037oo000LOol00`00Oomo
o`0QOolB000oOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol0
1goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Ao
o`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00
Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo
1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(13527\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .28843 m
.008 .28425 L
.012 .28074 L
.016 .28015 L
.02 .28292 L
.024 .28921 L
.028 .29911 L
.032 .31189 L
.036 .32688 L
.04 .34293 L
.044 .35831 L
.048 .3701 L
.052 .37734 L
.056 .3812 L
.06 .38157 L
.064 .37747 L
.068 .36967 L
.072 .36151 L
.076 .35512 L
.08 .35093 L
.084 .34834 L
.088 .34672 L
.092 .34647 L
.096 .34826 L
.1 .35168 L
.104 .3553 L
.108 .35809 L
.112 .3591 L
.116 .35874 L
.12 .3589 L
.124 .36137 L
.128 .36637 L
.132 .37149 L
.136 .37281 L
.14 .36892 L
.144 .36219 L
.148 .35636 L
.152 .35422 L
.156 .35559 L
.16 .35865 L
.164 .36239 L
.168 .36678 L
.172 .37128 L
.176 .37358 L
.18 .37067 L
.184 .36091 L
.188 .34567 L
.192 .32869 L
.196 .31343 L
.2 .30141 L
Mistroke
.204 .29237 L
.208 .28568 L
.212 .28169 L
.216 .28134 L
.22 .28463 L
.224 .28949 L
.228 .29236 L
.232 .29001 L
.236 .28174 L
.24 .27 L
.244 .25917 L
.248 .2533 L
.252 .25395 L
.256 .25955 L
.26 .26647 L
.264 .27087 L
.268 .27054 L
.272 .26571 L
.276 .25858 L
.28 .25215 L
.284 .24877 L
.288 .24925 L
.292 .25269 L
.296 .25706 L
.3 .26006 L
.304 .26004 L
.308 .25649 L
.312 .25014 L
.316 .24256 L
.32 .23564 L
.324 .23098 L
.328 .22957 L
.332 .23165 L
.336 .23684 L
.34 .24439 L
.344 .25341 L
.348 .26303 L
.352 .2724 L
.356 .28074 L
.36 .28739 L
.364 .29197 L
.368 .29446 L
.372 .29536 L
.376 .29552 L
.38 .29591 L
.384 .29721 L
.388 .29951 L
.392 .30223 L
.396 .30441 L
.4 .30515 L
Mistroke
.404 .30411 L
.408 .30177 L
.412 .29926 L
.416 .29782 L
.42 .29822 L
.424 .30033 L
.428 .30312 L
.432 .3052 L
.436 .3055 L
.44 .30384 L
.444 .30108 L
.448 .29863 L
.452 .29779 L
.456 .29898 L
.46 .30156 L
.464 .30412 L
.468 .3053 L
.472 .30449 L
.476 .30218 L
.48 .29964 L
.484 .29829 L
.488 .29882 L
.492 .30088 L
.496 .30327 L
.5 .30463 L
.504 .30424 L
.508 .3024 L
.512 .30023 L
.516 .29897 L
.52 .29929 L
.524 .30092 L
.528 .30285 L
.532 .30393 L
.536 .30359 L
.54 .30212 L
.544 .30045 L
.548 .29958 L
.552 .29998 L
.556 .3013 L
.56 .30267 L
.564 .30329 L
.568 .30284 L
.572 .30169 L
.576 .30058 L
.58 .30018 L
.584 .30065 L
.588 .30164 L
.592 .30249 L
.596 .30269 L
.6 .30219 L
Mistroke
.604 .30137 L
.608 .30076 L
.612 .30071 L
.616 .30117 L
.62 .3018 L
.624 .30221 L
.628 .30219 L
.632 .3018 L
.636 .3013 L
.64 .30099 L
.644 .30104 L
.648 .30139 L
.652 .3018 L
.656 .30201 L
.66 .30193 L
.664 .30161 L
.668 .30127 L
.672 .3011 L
.676 .3012 L
.68 .30149 L
.684 .3018 L
.688 .30194 L
.692 .30181 L
.696 .30147 L
.7 .30114 L
.704 .30107 L
.708 .30131 L
.712 .30171 L
.716 .30196 L
.72 .30187 L
.724 .30149 L
.728 .30112 L
.732 .30103 L
.736 .3013 L
.74 .3017 L
.744 .30194 L
.748 .30182 L
.752 .30145 L
.756 .3011 L
.76 .30104 L
.764 .30132 L
.768 .30172 L
.772 .30193 L
.776 .30176 L
.78 .30135 L
.784 .30103 L
.788 .30106 L
.792 .30143 L
.796 .30183 L
.8 .3019 L
Mistroke
.804 .30159 L
.808 .30114 L
.812 .30097 L
.816 .30122 L
.82 .30166 L
.824 .30189 L
.828 .30171 L
.832 .30128 L
.836 .301 L
.84 .30114 L
.844 .30151 L
.848 .30179 L
.852 .30172 L
.856 .30137 L
.86 .3011 L
.864 .30115 L
.868 .30141 L
.872 .30165 L
.876 .30165 L
.88 .30142 L
.884 .30122 L
.888 .30122 L
.892 .30135 L
.896 .3015 L
.9 .30155 L
.904 .30143 L
.908 .30133 L
.912 .3013 L
.916 .30129 L
.92 .30137 L
.924 .30146 L
.928 .30145 L
.932 .30142 L
.936 .30136 L
.94 .30123 L
.944 .30125 L
.948 .3014 L
.952 .30146 L
.956 .3015 L
.96 .30141 L
.964 .30117 L
.968 .30114 L
.972 .30136 L
.976 .30149 L
.98 .30156 L
.984 .30144 L
.988 .30109 L
.992 .30104 L
.996 .30134 L
1 .30153 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13782 m
.008 .13547 L
.012 .13485 L
.016 .13605 L
.02 .13683 L
.024 .13718 L
.028 .13761 L
.032 .13822 L
.036 .13878 L
.04 .13929 L
.044 .1397 L
.048 .14016 L
.052 .14081 L
.056 .14174 L
.06 .14272 L
.064 .14383 L
.068 .14524 L
.072 .14709 L
.076 .14911 L
.08 .15115 L
.084 .15307 L
.088 .155 L
.092 .15708 L
.096 .15927 L
.1 .16126 L
.104 .16289 L
.108 .16423 L
.112 .16553 L
.116 .16713 L
.12 .16909 L
.124 .17115 L
.128 .17298 L
.132 .1744 L
.136 .17563 L
.14 .17726 L
.144 .17966 L
.148 .18277 L
.152 .18614 L
.156 .1892 L
.16 .19165 L
.164 .19347 L
.168 .19481 L
.172 .19587 L
.176 .19686 L
.18 .19814 L
.184 .20011 L
.188 .20309 L
.192 .20708 L
.196 .21183 L
.2 .21698 L
Mistroke
.204 .22232 L
.208 .22787 L
.212 .23369 L
.216 .23976 L
.22 .2459 L
.224 .25182 L
.228 .25736 L
.232 .26261 L
.236 .26783 L
.24 .27328 L
.244 .27907 L
.248 .28505 L
.252 .29092 L
.256 .29645 L
.26 .30157 L
.264 .30644 L
.268 .31134 L
.272 .31654 L
.276 .32215 L
.28 .32805 L
.284 .33399 L
.288 .33969 L
.292 .34496 L
.296 .34977 L
.3 .35428 L
.304 .35876 L
.308 .36349 L
.312 .3687 L
.316 .37446 L
.32 .38072 L
.324 .38729 L
.328 .39392 L
.332 .40032 L
.336 .40626 L
.34 .41154 L
.344 .41605 L
.348 .41977 L
.352 .42272 L
.356 .42498 L
.36 .42667 L
.364 .4279 L
.368 .42878 L
.372 .4294 L
.376 .42984 L
.38 .43014 L
.384 .43035 L
.388 .43048 L
.392 .43056 L
.396 .43059 L
.4 .4306 L
Mistroke
.404 .43061 L
.408 .43063 L
.412 .43066 L
.416 .43069 L
.42 .43073 L
.424 .43076 L
.428 .43077 L
.432 .43076 L
.436 .43076 L
.44 .43075 L
.444 .43076 L
.448 .43079 L
.452 .43082 L
.456 .43085 L
.46 .43087 L
.464 .43088 L
.468 .43088 L
.472 .43087 L
.476 .43088 L
.48 .43089 L
.484 .43092 L
.488 .43095 L
.492 .43097 L
.496 .43098 L
.5 .43099 L
.504 .43099 L
.508 .43099 L
.512 .431 L
.516 .43102 L
.52 .43105 L
.524 .43107 L
.528 .43108 L
.532 .43109 L
.536 .4311 L
.54 .4311 L
.544 .43111 L
.548 .43113 L
.552 .43115 L
.556 .43117 L
.56 .43119 L
.564 .4312 L
.568 .4312 L
.572 .43121 L
.576 .43122 L
.58 .43124 L
.584 .43126 L
.588 .43128 L
.592 .43129 L
.596 .4313 L
.6 .43131 L
Mistroke
.604 .43132 L
.608 .43133 L
.612 .43135 L
.616 .43137 L
.62 .43138 L
.624 .43139 L
.628 .4314 L
.632 .43141 L
.636 .43142 L
.64 .43144 L
.644 .43146 L
.648 .43147 L
.652 .43149 L
.656 .4315 L
.66 .43151 L
.664 .43152 L
.668 .43153 L
.672 .43155 L
.676 .43156 L
.68 .43158 L
.684 .43159 L
.688 .4316 L
.692 .43161 L
.696 .43163 L
.7 .43164 L
.704 .43166 L
.708 .43167 L
.712 .43168 L
.716 .43169 L
.72 .43171 L
.724 .43172 L
.728 .43173 L
.732 .43175 L
.736 .43176 L
.74 .43177 L
.744 .43179 L
.748 .4318 L
.752 .43181 L
.756 .43183 L
.76 .43184 L
.764 .43185 L
.768 .43187 L
.772 .43188 L
.776 .43189 L
.78 .43191 L
.784 .43192 L
.788 .43193 L
.792 .43195 L
.796 .43196 L
.8 .43197 L
Mistroke
.804 .43198 L
.808 .432 L
.812 .43201 L
.816 .43202 L
.82 .43204 L
.824 .43205 L
.828 .43206 L
.832 .43208 L
.836 .43209 L
.84 .4321 L
.844 .43212 L
.848 .43213 L
.852 .43214 L
.856 .43216 L
.86 .43217 L
.864 .43218 L
.868 .43219 L
.872 .43221 L
.876 .43222 L
.88 .43224 L
.884 .43225 L
.888 .43226 L
.892 .43227 L
.896 .43229 L
.9 .4323 L
.904 .43232 L
.908 .43233 L
.912 .43234 L
.916 .43235 L
.92 .43237 L
.924 .43238 L
.928 .4324 L
.932 .4324 L
.936 .43242 L
.94 .43243 L
.944 .43245 L
.948 .43246 L
.952 .43248 L
.956 .43248 L
.96 .4325 L
.964 .43251 L
.968 .43253 L
.972 .43253 L
.976 .43256 L
.98 .43256 L
.984 .43259 L
.988 .43258 L
.992 .43261 L
.996 .43261 L
1 .43264 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .1615 L
.012 .15954 L
.016 .15848 L
.02 .1584 L
.024 .15801 L
.028 .15758 L
.032 .15757 L
.036 .15806 L
.04 .15875 L
.044 .15968 L
.048 .16098 L
.052 .16272 L
.056 .16471 L
.06 .16683 L
.064 .1689 L
.068 .17108 L
.072 .17345 L
.076 .17594 L
.08 .17812 L
.084 .18002 L
.088 .18191 L
.092 .18404 L
.096 .18632 L
.1 .18854 L
.104 .19043 L
.108 .19205 L
.112 .19379 L
.116 .19596 L
.12 .19863 L
.124 .2015 L
.128 .20404 L
.132 .20602 L
.136 .20777 L
.14 .20987 L
.144 .21283 L
.148 .21659 L
.152 .22052 L
.156 .22403 L
.16 .22676 L
.164 .22877 L
.168 .23031 L
.172 .23163 L
.176 .23303 L
.18 .23489 L
.184 .23767 L
.188 .24166 L
.192 .2468 L
.196 .25272 L
.2 .25898 L
Mistroke
.204 .26536 L
.208 .27195 L
.212 .27892 L
.216 .28632 L
.22 .29394 L
.224 .30143 L
.228 .30856 L
.232 .31533 L
.236 .32201 L
.24 .32887 L
.244 .33601 L
.248 .34328 L
.252 .35037 L
.256 .35703 L
.26 .36325 L
.264 .36926 L
.268 .37541 L
.272 .382 L
.276 .38911 L
.28 .39655 L
.284 .40397 L
.288 .411 L
.292 .41743 L
.296 .42326 L
.3 .42873 L
.304 .43421 L
.308 .44006 L
.312 .44655 L
.316 .45377 L
.32 .4616 L
.324 .4698 L
.328 .47803 L
.332 .48593 L
.336 .49321 L
.34 .49966 L
.344 .50517 L
.348 .50971 L
.352 .51334 L
.356 .51615 L
.36 .51826 L
.364 .51979 L
.368 .52085 L
.372 .52156 L
.376 .522 L
.38 .52226 L
.384 .5224 L
.388 .52248 L
.392 .52252 L
.396 .52255 L
.4 .52257 L
Mistroke
.404 .52257 L
.408 .52254 L
.412 .52249 L
.416 .52242 L
.42 .52235 L
.424 .52229 L
.428 .52225 L
.432 .52223 L
.436 .52221 L
.44 .52219 L
.444 .52215 L
.448 .52209 L
.452 .52202 L
.456 .52196 L
.46 .5219 L
.464 .52186 L
.468 .52184 L
.472 .52182 L
.476 .52178 L
.48 .52174 L
.484 .52168 L
.488 .52162 L
.492 .52156 L
.496 .52151 L
.5 .52148 L
.504 .52145 L
.508 .52142 L
.512 .52138 L
.516 .52133 L
.52 .52127 L
.524 .52122 L
.528 .52117 L
.532 .52113 L
.536 .5211 L
.54 .52106 L
.544 .52102 L
.548 .52097 L
.552 .52092 L
.556 .52087 L
.56 .52082 L
.564 .52078 L
.568 .52075 L
.572 .52071 L
.576 .52067 L
.58 .52062 L
.584 .52057 L
.588 .52052 L
.592 .52047 L
.596 .52043 L
.6 .52039 L
Mistroke
.604 .52035 L
.608 .52031 L
.612 .52026 L
.616 .52021 L
.62 .52016 L
.624 .52012 L
.628 .52008 L
.632 .52004 L
.636 .52 L
.64 .51995 L
.644 .51991 L
.648 .51986 L
.652 .51981 L
.656 .51977 L
.66 .51973 L
.664 .51969 L
.668 .51964 L
.672 .5196 L
.676 .51955 L
.68 .5195 L
.684 .51946 L
.688 .51942 L
.692 .51938 L
.696 .51933 L
.7 .51929 L
.704 .51924 L
.708 .5192 L
.712 .51915 L
.716 .51911 L
.72 .51907 L
.724 .51902 L
.728 .51898 L
.732 .51893 L
.736 .51889 L
.74 .51884 L
.744 .5188 L
.748 .51876 L
.752 .51871 L
.756 .51867 L
.76 .51862 L
.764 .51858 L
.768 .51853 L
.772 .51849 L
.776 .51845 L
.78 .5184 L
.784 .51836 L
.788 .51831 L
.792 .51827 L
.796 .51822 L
.8 .51818 L
Mistroke
.804 .51813 L
.808 .51809 L
.812 .51805 L
.816 .518 L
.82 .51796 L
.824 .51791 L
.828 .51787 L
.832 .51783 L
.836 .51778 L
.84 .51774 L
.844 .51769 L
.848 .51765 L
.852 .5176 L
.856 .51756 L
.86 .51751 L
.864 .51747 L
.868 .51743 L
.872 .51738 L
.876 .51734 L
.88 .51729 L
.884 .51725 L
.888 .51721 L
.892 .51716 L
.896 .51712 L
.9 .51707 L
.904 .51703 L
.908 .51698 L
.912 .51694 L
.916 .51689 L
.92 .51685 L
.924 .5168 L
.928 .51676 L
.932 .51671 L
.936 .51668 L
.94 .51662 L
.944 .51659 L
.948 .51653 L
.952 .5165 L
.956 .51644 L
.96 .51641 L
.964 .51636 L
.968 .51632 L
.972 .51626 L
.976 .51623 L
.98 .51617 L
.984 .51615 L
.988 .51609 L
.992 .51606 L
.996 .51599 L
1 .51597 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
17oo0`000goo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`04Ool30003Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol02goo1000
0goo00<007ooOol00P0000=oo`000000100000Eoo`00Oomoo`00009oo`04001oogoo0002Ool00`00
Oomoo`03Ool01000Oomoogoo10000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomo
o`000Woo00@007ooOol000=oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P00
2Woo0P0017oo00<007ooOol00Woo0P0037oo00<007ooOol017oo00<007ooOol00P0000=oo`00Ool0
100000Eoo`00Oomoo`00009oo`04001oogoo0002Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00L0
07ooOomoo`00Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool50003Ool300000goo001oo`04
Ool00`00Ool00003Ool20004Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo
0P001Goo0`000Woo1@000goo0P001Woo000ROol3000AOol4000;Ool00`00Oomoo`19Ool0029oo`<0
015oo`04001oo`00000<Ool30002Ool01000Oomoo`000Woo00<007ooOol0?Goo000ROomS000<Ool0
029oo`03001oogoo008000=oo`05001oogooOol00003Ool00`00Oomoo`020003Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`00009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo000037oo000ROol20002Ool00`00Oomoo`0<Ool00`00Oomoo`1I
Ool0029oo`05001oogooOol0000>Ool00`00Oomoo`1IOol0029oo`80009oo`04001oogooOol30007
Ool00`00Oomoo`1JOol0029oo`80009oo`06001oogooOol007oo0`000Woo0P0000=oo`00Ool0Fgoo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`02Ool00`00Ool00004Ool3
000017oo00000000G7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
00=oo`8000Ioo`04001oogooOol2001LOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P0017oo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2
000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80
009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06ao
o`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo
00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`80
00=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=o
o`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<0
07ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00
Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007oo
Oomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool0
0`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P00
17oo1000IGoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`05001QOol002Qoo`03
001oogoo00Aoo`<005moo`00:7oo00<007ooOol01Woo0`00GGoo000;Ool20004Ool00`00Oomoo`03
Ool20004Ool20003Ool30003Ool00`00Oomoo`09Ool2001KOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`003Goo0P00FGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`003Woo0`00Egoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30002Ool0
1000Ool000001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo
0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001o
ogoo001oo`040003Ool00`00Oomoo`09Ool01P00Oomoogoo001oo`80009oo`03001oogoo00Eoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo
00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo
0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomo
o`0=Ool00`00Oomoo`0200000goo001oo`06Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03
Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oo`000007Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qo
o`03001oogoo00Uoo`03001oogoo00Aoo`04001oo`000006Ool20004Ool01000Oomoo`000Woo00@0
07ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007oo
Ool02Goo1@000goo0`001goo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`80
00=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol057oo00<0
07ooOol0Cgoo000XOol00`00Oomoo`0EOol00`00Oomoo`1>Ool002Qooed000aoo`00:7oo00<007oo
Ool03goo00<007ooOol017oo00<007ooOol02Goo00<007ooOol03goo00<007ooOol03goo00<007oo
Ool047oo00<007ooOol02Woo000XOol00`00Oomoo`0GOol00`00Oomoo`1<Ool002Qoo`03001oogoo
01Moo`8004eoo`00:7oo00<007ooOol067oo0P00C7oo000XOol00`00Oomoo`0IOol00`00Oomoo`1:
Ool002Qoo`03001oogoo01Yoo`03001oogoo04Uoo`002goo0P0017oo00<007ooOol00goo0P0017oo
0P000goo0`000goo00<007ooOol06Woo0P00BWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`000goo00@007ooOol001eoo`03001oogoo04Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol001ioo`03001oogoo04Moo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P007Woo00<007ooOol0
AWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomo
o`0NOoll000<Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool0
0`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Io
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00
Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo
0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@0
07ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00
Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003
Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool0
1000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<0
07ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eo
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04
001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04
001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04
001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001ao
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`06001oogooOol007oo
0`0017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo
Ool00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03
001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol01Goo0P00Jgoo000LOol20008Ool2001Y
Ool001aoo`03001oogoo00Uoo`8006Moo`0077oo00<007ooOol02Woo0`00IGoo000LOol2000=Ool2
001TOol001aoo`03001oogoo00eoo`<0069oo`0077oo00<007ooOol03goo0P00HGoo000LOol2000B
Ool00`00Oomoo`1NOol001aoo`03001oogoo015oo`8005moo`0077oo0P004goo00<007ooOol0GGoo
000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`0COol00`00Oomoo`1LOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol057oo00<007ooOol0Fgoo000:Ool01000
Oomoo`002goo00<007ooOol00P005Goo00<007ooOol0Fgoo000:Ool01000Oomoo`002goo00@007oo
Ool001Ioo`03001oogoo05]oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo01Eoo`03001o
ogoo05Yoo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8001Moo`03001oogoo05Uoo`002goo
0P0027oo1@000Woo00<007ooOol05Woo00<007ooOol0FGoo000LOol00`00Oomoo`0GOol00`00Oomo
o`1HOol001aoo`8001Qoo`03001oogoo05Qoo`0077oo00<007ooOol067oo00<007ooOol0Egoo000L
Ool2000JOol00`00Oomoo`1FOol001aoo`03001oogoo01Uoo`03001oogoo05Ioo`0077oo00<007oo
Ool06Woo00<007ooOol0EGoo000LOol2000KOol2001FOol001Ioo`<000=oo`03001oogoo01]oo`03
001oogoo05Aoo`005goo00<007ooOol00Woo00<007ooOol06goo0P00EGoo000GOol00`00Oomoo`02
Ool2000MOol2001DOol001Moo`03001oogoo009oo`03001oogoo01eoo`03001oogoo059oo`005goo
00<007ooOol00Woo00<007ooOol07Goo00<007ooOol0DWoo000FOol20004Ool2000OOol00`00Oomo
o`1AOol001Moo`03001oogoo009oo`03001oogoo01moo`03001oogoo051oo`0077oo00<007ooOol0
7goo00<007ooOol0D7oo000LOol2000QOol00`00Oomoo`1?Ool001aoo`03001oogoo021oo`03001o
ogoo04moo`0077oo0P008Woo00<007ooOol0CWoo000LOol00`00Oomoo`0ROol2000=Oole000<Ool0
01aoo`03001oogoo02Aoo`h0041oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;
Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool0
1000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Mo
o`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool0
0`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(13694\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29168 m
.008 .29904 L
.012 .30954 L
.016 .32049 L
.02 .33067 L
.024 .33824 L
.028 .34181 L
.032 .34106 L
.036 .33619 L
.04 .32951 L
.044 .32213 L
.048 .31475 L
.052 .30891 L
.056 .30707 L
.06 .30983 L
.064 .31517 L
.068 .32194 L
.072 .33021 L
.076 .33981 L
.08 .34938 L
.084 .35714 L
.088 .36233 L
.092 .3657 L
.096 .36889 L
.1 .37165 L
.104 .37255 L
.108 .37068 L
.112 .36615 L
.116 .35997 L
.12 .35383 L
.124 .34909 L
.128 .34597 L
.132 .34404 L
.136 .34267 L
.14 .34296 L
.144 .34734 L
.148 .35648 L
.152 .36768 L
.156 .37591 L
.16 .37691 L
.164 .37074 L
.168 .36148 L
.172 .35364 L
.176 .34983 L
.18 .35027 L
.184 .35419 L
.188 .361 L
.192 .36956 L
.196 .3771 L
.2 .37951 L
Mistroke
.204 .37375 L
.208 .35999 L
.212 .34185 L
.216 .32437 L
.22 .31102 L
.224 .30229 L
.228 .29662 L
.232 .29224 L
.236 .28863 L
.24 .28631 L
.244 .28544 L
.248 .28498 L
.252 .28296 L
.256 .27787 L
.26 .26997 L
.264 .26151 L
.268 .25556 L
.272 .25426 L
.276 .25753 L
.28 .26304 L
.284 .26746 L
.288 .26808 L
.292 .26413 L
.296 .25699 L
.3 .24937 L
.304 .24403 L
.308 .24263 L
.312 .24517 L
.316 .25019 L
.32 .25547 L
.324 .25885 L
.328 .25891 L
.332 .25525 L
.336 .24846 L
.34 .23988 L
.344 .23131 L
.348 .22459 L
.352 .22128 L
.356 .2223 L
.36 .2277 L
.364 .23659 L
.368 .24736 L
.372 .2581 L
.376 .26724 L
.38 .27403 L
.384 .2787 L
.388 .28222 L
.392 .28576 L
.396 .29005 L
.4 .29496 L
Mistroke
.404 .29961 L
.408 .30279 L
.412 .30372 L
.416 .30249 L
.42 .30012 L
.424 .2981 L
.428 .29766 L
.432 .29915 L
.436 .30184 L
.44 .30435 L
.444 .30536 L
.448 .30437 L
.452 .30197 L
.456 .29948 L
.46 .29827 L
.464 .29896 L
.468 .30111 L
.472 .30349 L
.476 .30476 L
.48 .30426 L
.484 .30234 L
.488 .30014 L
.492 .29892 L
.496 .29933 L
.5 .30105 L
.504 .30301 L
.508 .30407 L
.512 .30367 L
.516 .30213 L
.52 .30042 L
.524 .29955 L
.528 .29998 L
.532 .30136 L
.536 .3028 L
.54 .30343 L
.544 .30294 L
.548 .30172 L
.552 .30056 L
.556 .30015 L
.56 .30066 L
.564 .3017 L
.568 .30259 L
.572 .30282 L
.576 .3023 L
.58 .30142 L
.584 .30075 L
.588 .30068 L
.592 .30119 L
.596 .30188 L
.6 .30233 L
Mistroke
.604 .30229 L
.608 .30185 L
.612 .30132 L
.616 .30101 L
.62 .30107 L
.624 .30144 L
.628 .30186 L
.632 .30209 L
.636 .30199 L
.64 .30166 L
.644 .3013 L
.648 .30113 L
.652 .30125 L
.656 .30155 L
.66 .30186 L
.664 .30197 L
.668 .30184 L
.672 .30153 L
.676 .30123 L
.68 .30114 L
.684 .30134 L
.688 .30171 L
.692 .30197 L
.696 .30194 L
.7 .30161 L
.704 .30122 L
.708 .30108 L
.712 .30129 L
.716 .30169 L
.72 .30197 L
.724 .30191 L
.728 .30157 L
.732 .30119 L
.736 .30108 L
.74 .30131 L
.744 .3017 L
.748 .30195 L
.752 .30185 L
.756 .30149 L
.76 .30114 L
.764 .30108 L
.768 .30139 L
.772 .30179 L
.776 .30195 L
.78 .30174 L
.784 .30131 L
.788 .30104 L
.792 .30118 L
.796 .30158 L
.8 .3019 L
Mistroke
.804 .30185 L
.808 .30147 L
.812 .30112 L
.816 .30111 L
.82 .30142 L
.824 .30176 L
.828 .30183 L
.832 .30157 L
.836 .30123 L
.84 .30114 L
.844 .30133 L
.848 .30162 L
.852 .30175 L
.856 .30159 L
.86 .30135 L
.864 .30122 L
.868 .30129 L
.872 .30149 L
.876 .30164 L
.88 .30158 L
.884 .30144 L
.888 .3013 L
.892 .30126 L
.896 .30139 L
.9 .30154 L
.904 .30157 L
.908 .30151 L
.912 .30137 L
.916 .30124 L
.92 .3013 L
.924 .30147 L
.928 .30156 L
.932 .30156 L
.936 .3014 L
.94 .30119 L
.944 .30123 L
.948 .30143 L
.952 .30157 L
.956 .3016 L
.96 .30141 L
.964 .30113 L
.968 .30117 L
.972 .30143 L
.976 .30159 L
.98 .30162 L
.984 .30139 L
.988 .30105 L
.992 .30112 L
.996 .30146 L
1 .30163 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14002 m
.008 .14124 L
.012 .14125 L
.016 .14015 L
.02 .1393 L
.024 .13873 L
.028 .13795 L
.032 .13716 L
.036 .1366 L
.04 .13632 L
.044 .13613 L
.048 .1361 L
.052 .13631 L
.056 .1368 L
.06 .13732 L
.064 .13785 L
.068 .13852 L
.072 .13942 L
.076 .14046 L
.08 .14154 L
.084 .14261 L
.088 .14384 L
.092 .14537 L
.096 .14715 L
.1 .1489 L
.104 .15053 L
.108 .15214 L
.112 .15391 L
.116 .15591 L
.12 .15802 L
.124 .15995 L
.128 .16156 L
.132 .16295 L
.136 .16442 L
.14 .16626 L
.144 .16843 L
.148 .17055 L
.152 .17224 L
.156 .17345 L
.16 .17454 L
.164 .17609 L
.168 .1784 L
.172 .18136 L
.176 .18459 L
.18 .18766 L
.184 .19032 L
.188 .19245 L
.192 .19401 L
.196 .19507 L
.2 .19587 L
Mistroke
.204 .19686 L
.208 .19853 L
.212 .20117 L
.216 .20478 L
.22 .2091 L
.224 .21383 L
.228 .21884 L
.232 .22416 L
.236 .22985 L
.24 .23584 L
.244 .24192 L
.248 .2478 L
.252 .25337 L
.256 .25869 L
.26 .26401 L
.264 .26956 L
.268 .27541 L
.272 .2814 L
.276 .28726 L
.28 .29277 L
.284 .29787 L
.288 .30271 L
.292 .30758 L
.296 .31275 L
.3 .31832 L
.304 .32423 L
.308 .33024 L
.312 .33605 L
.316 .34144 L
.32 .34635 L
.324 .3509 L
.328 .35531 L
.332 .35987 L
.336 .36485 L
.34 .37037 L
.344 .37643 L
.348 .38291 L
.352 .38958 L
.356 .39615 L
.36 .40238 L
.364 .40803 L
.368 .41298 L
.372 .41716 L
.376 .42057 L
.38 .42329 L
.384 .42539 L
.388 .42698 L
.392 .42816 L
.396 .429 L
.4 .42959 L
Mistroke
.404 .42997 L
.408 .43022 L
.412 .43038 L
.416 .43048 L
.42 .43055 L
.424 .43062 L
.428 .43067 L
.432 .43072 L
.436 .43074 L
.44 .43075 L
.444 .43075 L
.448 .43075 L
.452 .43076 L
.456 .43078 L
.46 .4308 L
.464 .43083 L
.468 .43085 L
.472 .43086 L
.476 .43087 L
.48 .43087 L
.484 .43087 L
.488 .43089 L
.492 .43091 L
.496 .43093 L
.5 .43095 L
.504 .43097 L
.508 .43098 L
.512 .43098 L
.516 .43099 L
.52 .431 L
.524 .43101 L
.528 .43103 L
.532 .43105 L
.536 .43107 L
.54 .43108 L
.544 .43109 L
.548 .43109 L
.552 .43111 L
.556 .43112 L
.56 .43114 L
.564 .43116 L
.568 .43117 L
.572 .43118 L
.576 .43119 L
.58 .4312 L
.584 .43121 L
.588 .43123 L
.592 .43125 L
.596 .43126 L
.6 .43128 L
Mistroke
.604 .43129 L
.608 .4313 L
.612 .43131 L
.616 .43132 L
.62 .43134 L
.624 .43136 L
.628 .43137 L
.632 .43138 L
.636 .43139 L
.64 .4314 L
.644 .43142 L
.648 .43143 L
.652 .43145 L
.656 .43146 L
.66 .43147 L
.664 .43148 L
.668 .4315 L
.672 .43151 L
.676 .43152 L
.68 .43154 L
.684 .43155 L
.688 .43157 L
.692 .43158 L
.696 .43159 L
.7 .4316 L
.704 .43162 L
.708 .43163 L
.712 .43164 L
.716 .43166 L
.72 .43167 L
.724 .43168 L
.728 .4317 L
.732 .43171 L
.736 .43172 L
.74 .43174 L
.744 .43175 L
.748 .43176 L
.752 .43177 L
.756 .43179 L
.76 .4318 L
.764 .43181 L
.768 .43183 L
.772 .43184 L
.776 .43185 L
.78 .43187 L
.784 .43188 L
.788 .43189 L
.792 .43191 L
.796 .43192 L
.8 .43193 L
Mistroke
.804 .43195 L
.808 .43196 L
.812 .43197 L
.816 .43199 L
.82 .432 L
.824 .43201 L
.828 .43203 L
.832 .43204 L
.836 .43205 L
.84 .43207 L
.844 .43208 L
.848 .43209 L
.852 .4321 L
.856 .43212 L
.86 .43213 L
.864 .43214 L
.868 .43216 L
.872 .43217 L
.876 .43218 L
.88 .4322 L
.884 .43221 L
.888 .43222 L
.892 .43223 L
.896 .43225 L
.9 .43226 L
.904 .43228 L
.908 .43229 L
.912 .4323 L
.916 .43231 L
.92 .43233 L
.924 .43234 L
.928 .43236 L
.932 .43237 L
.936 .43238 L
.94 .43239 L
.944 .43241 L
.948 .43242 L
.952 .43244 L
.956 .43244 L
.96 .43247 L
.964 .43247 L
.968 .43249 L
.972 .43249 L
.976 .43252 L
.98 .43252 L
.984 .43255 L
.988 .43254 L
.992 .43257 L
.996 .43257 L
1 .4326 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16247 L
.012 .16012 L
.016 .15902 L
.02 .15931 L
.024 .15936 L
.028 .1591 L
.032 .15902 L
.036 .15921 L
.04 .15932 L
.044 .15935 L
.048 .15932 L
.052 .15938 L
.056 .15949 L
.06 .15965 L
.064 .15982 L
.068 .16018 L
.072 .16093 L
.076 .16207 L
.08 .16333 L
.084 .16471 L
.088 .16641 L
.092 .16858 L
.096 .17102 L
.1 .1735 L
.104 .1758 L
.108 .178 L
.112 .18033 L
.116 .18287 L
.12 .18539 L
.124 .18763 L
.128 .18937 L
.132 .19078 L
.136 .19234 L
.14 .19444 L
.144 .19706 L
.148 .19981 L
.152 .20213 L
.156 .20392 L
.16 .2056 L
.164 .20776 L
.168 .21073 L
.172 .21438 L
.176 .21819 L
.18 .22173 L
.184 .22474 L
.188 .22715 L
.192 .22899 L
.196 .23035 L
.2 .23153 L
Mistroke
.204 .23301 L
.208 .23532 L
.212 .23877 L
.216 .24329 L
.22 .24858 L
.224 .25428 L
.228 .2603 L
.232 .26673 L
.236 .27372 L
.24 .28118 L
.244 .28884 L
.248 .2963 L
.252 .30336 L
.256 .31008 L
.26 .31671 L
.264 .32355 L
.268 .3307 L
.272 .33802 L
.276 .3452 L
.28 .35199 L
.284 .35833 L
.288 .36439 L
.292 .37052 L
.296 .377 L
.3 .38396 L
.304 .39129 L
.308 .3987 L
.312 .40583 L
.316 .41244 L
.32 .41847 L
.324 .42407 L
.328 .42954 L
.332 .43524 L
.336 .44145 L
.34 .44834 L
.344 .45587 L
.348 .46388 L
.352 .47208 L
.356 .48016 L
.36 .48782 L
.364 .49479 L
.368 .50092 L
.372 .50612 L
.376 .51038 L
.38 .51374 L
.384 .51631 L
.388 .5182 L
.392 .51955 L
.396 .52049 L
.4 .52113 L
Mistroke
.404 .52157 L
.408 .52186 L
.412 .52204 L
.416 .52214 L
.42 .52218 L
.424 .52217 L
.428 .52213 L
.432 .52209 L
.436 .52204 L
.44 .52201 L
.444 .52199 L
.448 .52197 L
.452 .52194 L
.456 .52189 L
.46 .52183 L
.464 .52177 L
.468 .52171 L
.472 .52167 L
.476 .52164 L
.48 .52161 L
.484 .52158 L
.488 .52153 L
.492 .52148 L
.496 .52142 L
.5 .52137 L
.504 .52132 L
.508 .52128 L
.512 .52125 L
.516 .52122 L
.52 .52118 L
.524 .52113 L
.528 .52107 L
.532 .52102 L
.536 .52097 L
.54 .52093 L
.544 .5209 L
.548 .52086 L
.552 .52082 L
.556 .52077 L
.56 .52072 L
.564 .52067 L
.568 .52062 L
.572 .52058 L
.576 .52055 L
.58 .52051 L
.584 .52046 L
.588 .52042 L
.592 .52037 L
.596 .52032 L
.6 .52027 L
Mistroke
.604 .52023 L
.608 .5202 L
.612 .52015 L
.616 .52011 L
.62 .52006 L
.624 .52001 L
.628 .51997 L
.632 .51992 L
.636 .51988 L
.64 .51984 L
.644 .5198 L
.648 .51975 L
.652 .5197 L
.656 .51966 L
.66 .51962 L
.664 .51957 L
.668 .51953 L
.672 .51949 L
.676 .51944 L
.68 .5194 L
.684 .51935 L
.688 .51931 L
.692 .51926 L
.696 .51922 L
.7 .51918 L
.704 .51913 L
.708 .51909 L
.712 .51904 L
.716 .519 L
.72 .51896 L
.724 .51891 L
.728 .51887 L
.732 .51882 L
.736 .51878 L
.74 .51873 L
.744 .51869 L
.748 .51865 L
.752 .5186 L
.756 .51856 L
.76 .51851 L
.764 .51847 L
.768 .51842 L
.772 .51838 L
.776 .51834 L
.78 .51829 L
.784 .51825 L
.788 .5182 L
.792 .51816 L
.796 .51811 L
.8 .51807 L
Mistroke
.804 .51802 L
.808 .51798 L
.812 .51794 L
.816 .51789 L
.82 .51785 L
.824 .5178 L
.828 .51776 L
.832 .51771 L
.836 .51767 L
.84 .51763 L
.844 .51758 L
.848 .51754 L
.852 .51749 L
.856 .51745 L
.86 .5174 L
.864 .51736 L
.868 .51732 L
.872 .51727 L
.876 .51723 L
.88 .51718 L
.884 .51714 L
.888 .51709 L
.892 .51705 L
.896 .51701 L
.9 .51696 L
.904 .51692 L
.908 .51687 L
.912 .51683 L
.916 .51678 L
.92 .51674 L
.924 .51669 L
.928 .51665 L
.932 .5166 L
.936 .51656 L
.94 .51651 L
.944 .51648 L
.948 .51642 L
.952 .51639 L
.956 .51633 L
.96 .5163 L
.964 .51625 L
.968 .51621 L
.972 .51615 L
.976 .51612 L
.98 .51606 L
.984 .51604 L
.988 .51597 L
.992 .51595 L
.996 .51588 L
1 .51586 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00H007oo000007oo0002Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`00
00=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool0
0`00Oomoo`02Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001o
ogoo00Eoo`03001oo`0000<0009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`03Ool40002Ool2
0002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00=oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol017oo
00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004
Ool00`00Oomoo`0;Ool40003Ool01@00Oomoo`00Ool00P0000=oo`00Ool00`000Woo0P000Woo00@0
07ooOol0009oo`03001oogoo00=oo`04001oogooOol40003Ool01000Oomoo`000Woo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000Oomo
o`001Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01@00Oomo
o`00Ool0100000=oo`0000000goo0P000Woo00@007ooOol0009oo`03001oogoo009oo`8000=oo`03
001oogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0029oo`8000aoo`D000=oo`800005
Ool007ooOol00003Ool00`00Oomoo`02Ool30004Ool20006Ool01000Oomoogoo1@000goo0P0017oo
0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`0EOol2000<Ool0
0`00Oomoo`16Ool0029oo`8001Aoo`8000moo`04001oo`000002Ool00`00Oomoo`0oOol0029oof<0
00aoo`008Woo0P000Woo0`0000=oo`00Ool00Woo00D007ooOomoo`0000=oo`05001oo`00Ool00002
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00@007ooOol000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool00`00Oomoo`0:Ool0029oo`<00005Ool007ooOol0000=Ool0
0`00Oomoo`1GOol0029oo`05001oo`00Ool00002Ool2000<Ool00`00Oomoo`1GOol0029oo`800003
Ool007oo00=oo`04001oogooOol30002Ool01@00Oomoogoo0000FGoo000ROol20006Ool00`00Oomo
o`020002Ool01P00Ool00000Ool005Yoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo
00<007ooOol01Woo0`000goo00<007oo00000`00FWoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8000Qoo`8000=oo`80009oo`8005Yoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]o
o`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo
0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000R
Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P00
0goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol0
0`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05
001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000
Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=o
o`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool2
0004Ool00`00Oomoo`04001ROol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`<000Aoo`<005mo
o`00:7oo00<007ooOol01goo0P00GGoo000XOol00`00Oomoo`09Ool3001JOol000]oo`8000Aoo`03
001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo00]oo`<005Qoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000?Ool2001GOol000=oo`D0
009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000AOol2001E
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]o
o`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Ao
o`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00
Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oo`000007Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03
001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0
3Goo00@007ooOol0009oo`8000Ioo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomo
o`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo
00<007ooOol02Goo10000goo00<007ooOol00`001Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00
Oomoo`09Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000Aoo`8000Aoo`04001oogoo0002Ool01000
Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomo
o`09Ool50003Ool20003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomo
ogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00
Oomoo`0FOol00`00Oomoo`1=Ool002Qoo`03001oogoo01Moo`03001oogoo04aoo`00:7ooG@0037oo
000XOol00`00Oomoo`0?Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0?Ool00`00Oomo
o`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo01Uoo`03001oogoo04Yoo`00
:7oo00<007ooOol06Woo00<007ooOol0BGoo000XOol00`00Oomoo`0JOol2001:Ool002Qoo`03001o
ogoo01]oo`8004Uoo`00:7oo00<007ooOol077oo0P00B7oo000;Ool20004Ool00`00Oomoo`03Ool2
0004Ool20003Ool30003Ool00`00Oomoo`0MOol00`00Oomoo`16Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`0087oo00<007ooOol0AGoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`0087oo00<007ooOol0
AGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000P
Ool00`00Oomoo`14Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@0
00=oo`03001oogoo021oocX000aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo
0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`80
00Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo
00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool0
1000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001o
ogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04
001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001o
ogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1b
Ool001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Ao
o`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007oo
Oomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol0
0goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol0
07oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol0
00Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol0
07oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P00
17oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=o
o`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D0
07ooOomoo`0000=oo`<0009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo00Qoo`8006Qoo`00
77oo0P002Woo0`00IWoo000LOol00`00Oomoo`0<Ool2001TOol001aoo`03001oogoo00eoo`<0069o
o`0077oo0P0047oo00<007ooOol0H7oo000LOol00`00Oomoo`0@Ool2001POol001aoo`03001oogoo
019oo`8005ioo`0077oo0P005Goo00<007ooOol0Fgoo000LOol00`00Oomoo`0DOol00`00Oomoo`1K
Ool001aoo`8001Ioo`03001oogoo05Yoo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007oo
Ool05Woo00<007ooOol0FGoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo
01Ioo`03001oogoo05Uoo`002Woo00@007ooOol000]oo`03001oogoo008001Qoo`03001oogoo05Qo
o`002Woo00@007ooOol000]oo`04001oogoo000IOol00`00Oomoo`1HOol000Yoo`04001oogoo0007
Ool40003Ool00`00Oomoo`0HOol00`00Oomoo`1GOol000Yoo`04001oogoo0007Ool00`00Oomoo`04
Ool2000JOol00`00Oomoo`1FOol000]oo`8000Qoo`D0009oo`03001oogoo01Uoo`03001oogoo05Io
o`0077oo00<007ooOol06Goo0P00Egoo000LOol2000KOol00`00Oomoo`1EOol001aoo`03001oogoo
01]oo`03001oogoo05Aoo`0077oo0P0077oo00<007ooOol0E7oo000LOol00`00Oomoo`0LOol00`00
Oomoo`1COol001aoo`03001oogoo01eoo`03001oogoo059oo`0077oo0P007Woo00<007ooOol0DWoo
000FOol30003Ool00`00Oomoo`0MOol2001COol001Moo`03001oogoo009oo`03001oogoo01ioo`80
059oo`005goo00<007ooOol00Woo0P0087oo00<007ooOol0D7oo000GOol00`00Oomoo`02Ool00`00
Oomoo`0POol00`00Oomoo`1?Ool001Moo`03001oogoo009oo`03001oogoo021oo`03001oogoo04mo
o`005Woo0P0017oo0P008Woo00<007ooOol0CWoo000GOol00`00Oomoo`02Ool00`00Oomoo`0QOol2
001?Ool001aoo`03001oogoo029oo`03001oogoo04eoo`0077oo0P008goo00<007ooOol0CGoo000L
Ool00`00Oomoo`0SOol00`00Oomoo`1<Ool001aoo`8002Eoo`03001oogoo04]oo`0077oo00<007oo
Ool097oo100027oo=P0037oo000LOol00`00Oomoo`0WOol:0011Ool000Yoo`<000Aoo`03001oogoo
009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079o
o`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00
Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Ao
o`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(13861\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .36248 m
.008 .35758 L
.012 .34802 L
.016 .33476 L
.02 .3199 L
.024 .30662 L
.028 .29718 L
.032 .29081 L
.036 .28859 L
.04 .29061 L
.044 .29617 L
.048 .30262 L
.052 .30861 L
.056 .31465 L
.06 .32024 L
.064 .32435 L
.068 .32639 L
.072 .32753 L
.076 .32883 L
.08 .33028 L
.084 .33096 L
.088 .33005 L
.092 .32867 L
.096 .32867 L
.1 .33053 L
.104 .33339 L
.108 .33717 L
.112 .34279 L
.116 .3507 L
.12 .36036 L
.124 .36963 L
.128 .37574 L
.132 .3766 L
.136 .37194 L
.14 .36363 L
.144 .35509 L
.148 .34873 L
.152 .3446 L
.156 .3418 L
.16 .34017 L
.164 .34146 L
.168 .34773 L
.172 .35795 L
.176 .36765 L
.18 .37195 L
.184 .36885 L
.188 .36076 L
.192 .35248 L
.196 .34766 L
.2 .34746 L
Mistroke
.204 .35124 L
.208 .35801 L
.212 .36666 L
.216 .37516 L
.22 .38021 L
.224 .37845 L
.228 .36883 L
.232 .35372 L
.236 .33771 L
.24 .32497 L
.244 .3168 L
.248 .31145 L
.252 .30605 L
.256 .29893 L
.26 .29069 L
.264 .28342 L
.268 .27875 L
.272 .27654 L
.276 .275 L
.28 .27202 L
.284 .26681 L
.288 .26046 L
.292 .25533 L
.296 .25348 L
.3 .2554 L
.304 .25954 L
.308 .26315 L
.312 .26359 L
.316 .25974 L
.32 .25247 L
.324 .24429 L
.328 .23824 L
.332 .23655 L
.336 .2397 L
.34 .24627 L
.344 .25347 L
.348 .25822 L
.352 .25832 L
.356 .25324 L
.36 .24424 L
.364 .23383 L
.368 .22481 L
.372 .21929 L
.376 .21804 L
.38 .22052 L
.384 .22536 L
.388 .23124 L
.392 .23741 L
.396 .24396 L
.4 .25144 L
Mistroke
.404 .26025 L
.408 .27007 L
.412 .27982 L
.416 .28799 L
.42 .2934 L
.424 .29576 L
.428 .29591 L
.432 .29539 L
.436 .29567 L
.44 .29744 L
.444 .3003 L
.448 .30305 L
.452 .30448 L
.456 .30401 L
.46 .3021 L
.464 .29996 L
.468 .29884 L
.472 .29936 L
.476 .30117 L
.48 .30317 L
.484 .3042 L
.488 .30374 L
.492 .30213 L
.496 .30038 L
.5 .29952 L
.504 .29999 L
.508 .30142 L
.512 .30291 L
.516 .30356 L
.52 .30305 L
.524 .30177 L
.528 .30055 L
.532 .30011 L
.536 .30066 L
.54 .30176 L
.544 .3027 L
.548 .30294 L
.552 .30239 L
.556 .30146 L
.56 .30075 L
.564 .30066 L
.568 .30119 L
.572 .30195 L
.576 .30244 L
.58 .3024 L
.584 .30192 L
.588 .30133 L
.592 .301 L
.596 .3011 L
.6 .3015 L
Mistroke
.604 .30194 L
.608 .30216 L
.612 .30205 L
.616 .30171 L
.62 .30134 L
.624 .30117 L
.628 .30129 L
.632 .30161 L
.636 .30192 L
.64 .30203 L
.644 .30188 L
.648 .30157 L
.652 .30129 L
.656 .30122 L
.66 .3014 L
.664 .30172 L
.668 .30198 L
.672 .30198 L
.676 .3017 L
.68 .30133 L
.684 .30115 L
.688 .30129 L
.692 .30167 L
.696 .30198 L
.7 .30199 L
.704 .30169 L
.708 .3013 L
.712 .30113 L
.716 .30131 L
.72 .30169 L
.724 .30197 L
.728 .30194 L
.732 .30161 L
.736 .30125 L
.74 .30113 L
.744 .30136 L
.748 .30175 L
.752 .30198 L
.756 .30186 L
.76 .30147 L
.764 .30115 L
.768 .30116 L
.772 .30151 L
.776 .30187 L
.78 .30194 L
.784 .30165 L
.788 .30126 L
.792 .30112 L
.796 .30134 L
.8 .30171 L
Mistroke
.804 .3019 L
.808 .30174 L
.812 .30139 L
.816 .30118 L
.82 .30127 L
.824 .30157 L
.828 .30179 L
.832 .30174 L
.836 .3015 L
.84 .30127 L
.844 .30126 L
.848 .30146 L
.852 .30167 L
.856 .3017 L
.86 .30156 L
.864 .30136 L
.868 .30127 L
.872 .30138 L
.876 .30156 L
.88 .30166 L
.884 .30161 L
.888 .30143 L
.892 .30127 L
.896 .30132 L
.9 .30149 L
.904 .30163 L
.908 .30164 L
.912 .30146 L
.916 .30126 L
.92 .30127 L
.924 .30145 L
.928 .30162 L
.932 .30166 L
.936 .30145 L
.94 .30121 L
.944 .30124 L
.948 .30145 L
.952 .30163 L
.956 .30166 L
.96 .30142 L
.964 .30115 L
.968 .30122 L
.972 .30148 L
.976 .30165 L
.98 .30165 L
.984 .30137 L
.988 .30108 L
.992 .30121 L
.996 .30154 L
1 .30167 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13679 m
.008 .13957 L
.012 .14053 L
.016 .13985 L
.02 .13965 L
.024 .14009 L
.028 .14024 L
.032 .14011 L
.036 .13994 L
.04 .13978 L
.044 .13947 L
.048 .13904 L
.052 .13863 L
.056 .13831 L
.06 .13797 L
.064 .13762 L
.068 .13733 L
.072 .13723 L
.076 .13724 L
.08 .13731 L
.084 .13738 L
.088 .1376 L
.092 .13811 L
.096 .13889 L
.1 .13975 L
.104 .14066 L
.108 .14174 L
.112 .14313 L
.116 .14478 L
.12 .14655 L
.124 .14819 L
.128 .14971 L
.132 .15127 L
.136 .15305 L
.14 .15509 L
.144 .15721 L
.148 .15907 L
.152 .16058 L
.156 .16192 L
.16 .16345 L
.164 .16541 L
.168 .16763 L
.172 .16967 L
.176 .17121 L
.18 .17234 L
.184 .17344 L
.188 .175 L
.192 .17723 L
.196 .18003 L
.2 .18312 L
Mistroke
.204 .1862 L
.208 .18904 L
.212 .19139 L
.216 .1931 L
.22 .19418 L
.224 .19491 L
.228 .19576 L
.232 .19723 L
.236 .19958 L
.24 .20279 L
.244 .20663 L
.248 .21088 L
.252 .2155 L
.256 .22054 L
.26 .22606 L
.264 .23197 L
.268 .23799 L
.272 .24387 L
.276 .24946 L
.28 .25484 L
.284 .26022 L
.288 .26581 L
.292 .27166 L
.296 .27764 L
.3 .28351 L
.304 .28904 L
.308 .29417 L
.312 .29903 L
.316 .3039 L
.32 .30903 L
.324 .31455 L
.328 .32043 L
.332 .32645 L
.336 .33233 L
.34 .33784 L
.344 .34286 L
.348 .34747 L
.352 .35188 L
.356 .35635 L
.36 .36115 L
.364 .36645 L
.368 .3723 L
.372 .37861 L
.376 .3852 L
.38 .39183 L
.384 .39823 L
.388 .4042 L
.392 .40957 L
.396 .41424 L
.4 .41818 L
Mistroke
.404 .42139 L
.408 .42393 L
.412 .42588 L
.416 .42732 L
.42 .42837 L
.424 .42912 L
.428 .42965 L
.432 .43002 L
.436 .43028 L
.44 .43046 L
.444 .43058 L
.448 .43065 L
.452 .4307 L
.456 .43072 L
.46 .43074 L
.464 .43076 L
.468 .43079 L
.472 .43081 L
.476 .43083 L
.48 .43085 L
.484 .43086 L
.488 .43086 L
.492 .43087 L
.496 .43088 L
.5 .4309 L
.504 .43092 L
.508 .43094 L
.512 .43095 L
.516 .43096 L
.52 .43097 L
.524 .43098 L
.528 .43099 L
.532 .43101 L
.536 .43102 L
.54 .43104 L
.544 .43106 L
.548 .43107 L
.552 .43108 L
.556 .43108 L
.56 .4311 L
.564 .43111 L
.568 .43113 L
.572 .43115 L
.576 .43116 L
.58 .43117 L
.584 .43118 L
.588 .43119 L
.592 .43121 L
.596 .43122 L
.6 .43124 L
Mistroke
.604 .43125 L
.608 .43126 L
.612 .43127 L
.616 .43129 L
.62 .4313 L
.624 .43131 L
.628 .43133 L
.632 .43134 L
.636 .43136 L
.64 .43137 L
.644 .43138 L
.648 .43139 L
.652 .43141 L
.656 .43142 L
.66 .43144 L
.664 .43145 L
.668 .43146 L
.672 .43147 L
.676 .43149 L
.68 .4315 L
.684 .43151 L
.688 .43153 L
.692 .43154 L
.696 .43155 L
.7 .43157 L
.704 .43158 L
.708 .43159 L
.712 .43161 L
.716 .43162 L
.72 .43163 L
.724 .43164 L
.728 .43166 L
.732 .43167 L
.736 .43169 L
.74 .4317 L
.744 .43171 L
.748 .43172 L
.752 .43174 L
.756 .43175 L
.76 .43176 L
.764 .43178 L
.768 .43179 L
.772 .4318 L
.776 .43182 L
.78 .43183 L
.784 .43184 L
.788 .43186 L
.792 .43187 L
.796 .43188 L
.8 .4319 L
Mistroke
.804 .43191 L
.808 .43192 L
.812 .43194 L
.816 .43195 L
.82 .43196 L
.824 .43197 L
.828 .43199 L
.832 .432 L
.836 .43201 L
.84 .43203 L
.844 .43204 L
.848 .43205 L
.852 .43207 L
.856 .43208 L
.86 .43209 L
.864 .43211 L
.868 .43212 L
.872 .43213 L
.876 .43214 L
.88 .43216 L
.884 .43217 L
.888 .43219 L
.892 .4322 L
.896 .43221 L
.9 .43222 L
.904 .43224 L
.908 .43225 L
.912 .43227 L
.916 .43228 L
.92 .43229 L
.924 .4323 L
.928 .43232 L
.932 .43233 L
.936 .43235 L
.94 .43235 L
.944 .43237 L
.948 .43238 L
.952 .4324 L
.956 .4324 L
.96 .43243 L
.964 .43243 L
.968 .43245 L
.972 .43245 L
.976 .43248 L
.98 .43248 L
.984 .43251 L
.988 .43251 L
.992 .43254 L
.996 .43253 L
1 .43256 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16125 L
.012 .16296 L
.016 .16368 L
.02 .16368 L
.024 .1636 L
.028 .16347 L
.032 .16293 L
.036 .1622 L
.04 .16142 L
.044 .16064 L
.048 .15987 L
.052 .15923 L
.056 .1588 L
.06 .15855 L
.064 .15833 L
.068 .15822 L
.072 .15835 L
.076 .15869 L
.08 .15898 L
.084 .15922 L
.088 .15957 L
.092 .16019 L
.096 .161 L
.1 .16186 L
.104 .16273 L
.108 .16378 L
.112 .16527 L
.116 .16723 L
.12 .16941 L
.124 .17162 L
.128 .17377 L
.132 .17601 L
.136 .17851 L
.14 .18125 L
.144 .18391 L
.148 .18613 L
.152 .18777 L
.156 .18914 L
.16 .19078 L
.164 .19304 L
.168 .19575 L
.172 .19841 L
.176 .20055 L
.18 .20219 L
.184 .20378 L
.188 .20584 L
.192 .20861 L
.196 .21196 L
.2 .2156 L
Mistroke
.204 .21924 L
.208 .22261 L
.212 .22548 L
.216 .22765 L
.22 .22911 L
.224 .23017 L
.228 .23136 L
.232 .23326 L
.236 .23618 L
.24 .24009 L
.244 .24474 L
.248 .24991 L
.252 .25557 L
.256 .26182 L
.26 .26872 L
.264 .27613 L
.268 .28371 L
.272 .29108 L
.276 .29807 L
.28 .30473 L
.284 .31136 L
.288 .31823 L
.292 .32544 L
.296 .33282 L
.3 .3401 L
.304 .34699 L
.308 .35341 L
.312 .3595 L
.316 .36557 L
.32 .37194 L
.324 .37876 L
.328 .386 L
.332 .3934 L
.336 .40065 L
.34 .40747 L
.344 .41372 L
.348 .41947 L
.352 .42497 L
.356 .43052 L
.36 .43645 L
.364 .44298 L
.368 .45017 L
.372 .45794 L
.376 .46609 L
.38 .47431 L
.384 .48228 L
.388 .48971 L
.392 .49637 L
.396 .50213 L
.4 .50695 L
Mistroke
.404 .51085 L
.408 .51392 L
.412 .51628 L
.416 .51804 L
.42 .51933 L
.424 .52023 L
.428 .52085 L
.432 .52124 L
.436 .52148 L
.44 .52161 L
.444 .52167 L
.448 .52171 L
.452 .52172 L
.456 .52172 L
.46 .52171 L
.464 .52167 L
.468 .52163 L
.472 .52157 L
.476 .52152 L
.48 .52147 L
.484 .52144 L
.488 .5214 L
.492 .52137 L
.496 .52133 L
.5 .52128 L
.504 .52123 L
.508 .52117 L
.512 .52113 L
.516 .52109 L
.52 .52105 L
.524 .52101 L
.528 .52097 L
.532 .52093 L
.536 .52087 L
.54 .52082 L
.544 .52078 L
.548 .52074 L
.552 .5207 L
.556 .52066 L
.56 .52062 L
.564 .52057 L
.568 .52052 L
.572 .52047 L
.576 .52043 L
.58 .52039 L
.584 .52035 L
.588 .52031 L
.592 .52026 L
.596 .52021 L
.6 .52017 L
Mistroke
.604 .52012 L
.608 .52008 L
.612 .52004 L
.616 .52 L
.62 .51995 L
.624 .51991 L
.628 .51986 L
.632 .51981 L
.636 .51977 L
.64 .51973 L
.644 .51969 L
.648 .51964 L
.652 .5196 L
.656 .51955 L
.66 .5195 L
.664 .51946 L
.668 .51942 L
.672 .51938 L
.676 .51933 L
.68 .51929 L
.684 .51924 L
.688 .5192 L
.692 .51915 L
.696 .51911 L
.7 .51907 L
.704 .51902 L
.708 .51898 L
.712 .51893 L
.716 .51889 L
.72 .51884 L
.724 .5188 L
.728 .51876 L
.732 .51871 L
.736 .51867 L
.74 .51862 L
.744 .51858 L
.748 .51853 L
.752 .51849 L
.756 .51845 L
.76 .5184 L
.764 .51836 L
.768 .51831 L
.772 .51827 L
.776 .51823 L
.78 .51818 L
.784 .51814 L
.788 .51809 L
.792 .51805 L
.796 .518 L
.8 .51796 L
Mistroke
.804 .51791 L
.808 .51787 L
.812 .51782 L
.816 .51778 L
.82 .51774 L
.824 .51769 L
.828 .51765 L
.832 .5176 L
.836 .51756 L
.84 .51752 L
.844 .51747 L
.848 .51743 L
.852 .51738 L
.856 .51734 L
.86 .51729 L
.864 .51725 L
.868 .5172 L
.872 .51716 L
.876 .51712 L
.88 .51707 L
.884 .51702 L
.888 .51698 L
.892 .51694 L
.896 .5169 L
.9 .51685 L
.904 .51681 L
.908 .51676 L
.912 .51672 L
.916 .51667 L
.92 .51663 L
.924 .51658 L
.928 .51654 L
.932 .51649 L
.936 .51645 L
.94 .5164 L
.944 .51637 L
.948 .51631 L
.952 .51628 L
.956 .51622 L
.96 .51619 L
.964 .51614 L
.968 .5161 L
.972 .51604 L
.976 .51601 L
.98 .51595 L
.984 .51593 L
.988 .51586 L
.992 .51584 L
.996 .51577 L
1 .51575 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00@007ooOomoo`<00005Ool007ooOol00002Ool00`00Oomoo`03Ool01@00Oomoogoo0000
0goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03
001oogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007oo
Ool01Goo00@007ooOomoo`<00005Ool007ooOol00002Ool00`00Oomoo`03Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool200000goo
001oo`040002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=o
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00
Oomoo`0;Ool40003Ool01000Oomoo`0017oo00D007oo000007oo00800003Ool007oo0080009oo`04
001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol0009oo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000=oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo
0P002Woo0P0017oo00<007ooOol00Woo0P0037oo00<007ooOol017oo00@007ooOol000=oo`03001o
o`0000800005Ool007ooOol00002Ool01000Oomoo`000Woo00<007ooOol00Woo0P000goo00<007oo
Ool017oo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=o
o`07001oogooOol007oo00001Woo00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P000goo00<0
07ooOol00Woo00<007ooOol00goo0`000goo0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Ao
o`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol05goo00<007ooOol02goo
0P00AGoo000ROol200000goo0000000DOol00`00Oomoo`0=Ool30013Ool0029oof<000aoo`008Woo
00T007oo001oo`00Ool007oo00000goo00D007ooOomoo`0000=oo`05001oogooOol00002Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00@007ooOol000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool00`00Oomoo`0:Ool0029oo`<000=oo`D000eoo`03001oogoo05Aoo`00
8Woo00<007oo00001Goo10002goo00<007ooOol0EGoo000ROol20009Ool01000Oomoogoo0`0000=o
o`0000000Woo00<007ooOol0EGoo000ROol20009Ool200001Woo001oogoo001oo`80009oo`03001o
ogoo05Eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P002Woo00<007oo00000Woo
0P000Woo0P00F7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000]o
o`03001oogoo009oo`03001oogoo008005Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Ao
o`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000
Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`00
0goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qo
o`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol0
00Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00
KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003
Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
1Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03
001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo
00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Ao
o`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo
00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomo
o`02Ool4001POol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`H000=oo`<005eoo`00:7oo00<0
07ooOol02Goo0`00FWoo000XOol00`00Oomoo`0;Ool3001HOol000]oo`8000Aoo`03001oogoo00=o
o`8000Aoo`8000=oo`<000=oo`03001oogoo00ioo`8005Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000AOol3001DOol000=oo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000COol3001BOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`@0
00Eoo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0
009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool0
10000goo00<007ooOol02Goo00D007ooOomoo`00009oo`03001oogoo00<000Eoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo0000
0goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Ool00005Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00
Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000
Oomoo`000Woo00@007ooOol000Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomo
o`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo
00<007ooOol02Goo10000goo00@007ooOol0009oo`8000=oo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo
00<007ooOol02Goo00<007ooOol017oo00@007ooOol000=oo`03001oogoo008000Aoo`04001oogoo
0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000X
Ool00`00Oomoo`09Ool50003Ool20005Ool01000Oomoo`001Goo0P0017oo0P0017oo00@007ooOomo
o`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007oo
Ool06Goo00<007ooOol0BWoo000XOol00`00Oomoo`0IOol2001;Ool002Qooed000aoo`00:7oo00<0
07ooOol03goo00<007ooOol02Goo00<007ooOol017oo00<007ooOol03goo00<007ooOol03goo00<0
07ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`0KOol20019Ool002Qoo`03001oogoo01ao
o`8004Qoo`00:7oo00<007ooOol07Goo0P00Agoo000XOol00`00Oomoo`0NOol00`00Oomoo`15Ool0
02Qoo`03001oogoo01moo`03001oogoo04Aoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P00
0goo0`000goo00<007ooOol07goo00<007ooOol0A7oo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`06001oogoo001oo`000goo00@007ooOol0029oo`03001oogoo04=oo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol002=oo`03001oogoo049oo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P008Woo0P00@goo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`0R
Oolh000<Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00
Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003
Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007oo
Ool007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomo
o`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool2
0004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000
Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo0000
0goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007oo
Ool047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=o
o`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0
009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001o
ogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`03001oo`00008000=oo`03
001oogoo00<000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Ao
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomo
o`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo00Yoo`<006Eoo`0077oo0P003Goo0`00Hgoo000L
Ool00`00Oomoo`0>Ool2001ROol001aoo`03001oogoo011oo`80061oo`0077oo0P004Woo0P00Ggoo
000LOol00`00Oomoo`0COol2001MOol001aoo`03001oogoo01Eoo`8005]oo`0077oo0P005goo0P00
FWoo000LOol00`00Oomoo`0GOol00`00Oomoo`1HOol001aoo`8001Uoo`03001oogoo05Moo`002goo
0P0017oo00<007ooOol00Woo0`000goo00<007ooOol06Goo00<007ooOol0EWoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo01Uoo`03001oogoo05Ioo`002Woo00@007ooOol0
00]oo`03001oogoo008001Yoo`8005Moo`002Woo00@007ooOol000]oo`04001oogoo000LOol00`00
Oomoo`1EOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0KOol00`00Oomoo`1DOol000Yo
o`04001oogoo0007Ool00`00Oomoo`04Ool2000LOol00`00Oomoo`1DOol000]oo`8000Qoo`D0009o
o`03001oogoo01aoo`03001oogoo05=oo`0077oo00<007ooOol077oo0P00E7oo000LOol2000NOol0
0`00Oomoo`1BOol001aoo`03001oogoo01eoo`8005=oo`0077oo0P007goo00<007ooOol0DGoo000L
Ool00`00Oomoo`0OOol00`00Oomoo`1@Ool001aoo`03001oogoo01moo`80055oo`0077oo0P008Goo
00<007ooOol0Cgoo000FOol30003Ool00`00Oomoo`0POol2001@Ool001Moo`03001oogoo009oo`03
001oogoo025oo`03001oogoo04ioo`005goo00<007ooOol00Woo0P008goo00<007ooOol0CGoo000G
Ool00`00Oomoo`02Ool00`00Oomoo`0ROol2001>Ool001Moo`03001oogoo009oo`03001oogoo02=o
o`03001oogoo04aoo`005Woo0P0017oo0P009Goo00<007ooOol0Bgoo000GOol00`00Oomoo`02Ool0
0`00Oomoo`0TOol00`00Oomoo`1;Ool001aoo`03001oogoo02Aoo`8004aoo`0077oo0P009Woo00<0
07ooOol0BWoo000LOol00`00Oomoo`0VOol00`00Oomoo`19Ool001aoo`8002Moo`8004Yoo`0077oo
00<007ooOol09goo100017oo=`0037oo000LOol00`00Oomoo`0ZOol60012Ool000Yoo`<000Aoo`03
001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001o
ogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007oo
Ool00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001o
ogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(14028\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29124 m
.008 .29316 L
.012 .29939 L
.016 .30797 L
.02 .31694 L
.024 .32627 L
.028 .33385 L
.032 .3385 L
.036 .33918 L
.04 .33761 L
.044 .33439 L
.048 .32933 L
.052 .32319 L
.056 .31701 L
.06 .31195 L
.064 .30723 L
.068 .30281 L
.072 .29925 L
.076 .29787 L
.08 .2995 L
.084 .30342 L
.088 .30865 L
.092 .31501 L
.096 .32296 L
.1 .33088 L
.104 .33593 L
.108 .33674 L
.112 .33425 L
.116 .33053 L
.12 .32739 L
.124 .32596 L
.128 .32682 L
.132 .33069 L
.136 .3381 L
.14 .3485 L
.144 .36018 L
.148 .37006 L
.152 .37463 L
.156 .37217 L
.16 .36429 L
.164 .35523 L
.168 .34923 L
.172 .34745 L
.176 .34763 L
.18 .3474 L
.184 .34663 L
.188 .34729 L
.192 .351 L
.196 .35652 L
.2 .36041 L
Mistroke
.204 .36023 L
.208 .35643 L
.212 .35182 L
.216 .3492 L
.22 .34937 L
.224 .35153 L
.228 .35487 L
.232 .35947 L
.236 .36543 L
.24 .37154 L
.244 .37514 L
.248 .37349 L
.252 .36591 L
.256 .35447 L
.26 .34261 L
.264 .3329 L
.268 .32546 L
.272 .31845 L
.276 .3099 L
.28 .29947 L
.284 .28881 L
.288 .28027 L
.292 .27518 L
.296 .27289 L
.3 .27132 L
.304 .26842 L
.308 .26359 L
.312 .25801 L
.316 .25376 L
.32 .25239 L
.324 .25387 L
.328 .25654 L
.332 .25804 L
.336 .25665 L
.34 .25216 L
.344 .24597 L
.348 .24029 L
.352 .23704 L
.356 .237 L
.36 .23962 L
.364 .24343 L
.368 .24681 L
.372 .24861 L
.376 .2484 L
.38 .24623 L
.384 .24237 L
.388 .23701 L
.392 .23041 L
.396 .22318 L
.4 .21647 L
Mistroke
.404 .21191 L
.408 .21113 L
.412 .21509 L
.416 .22355 L
.42 .23501 L
.424 .24726 L
.428 .25823 L
.432 .26676 L
.436 .27294 L
.44 .27777 L
.444 .28245 L
.448 .2876 L
.452 .29294 L
.456 .29754 L
.46 .3004 L
.464 .30119 L
.468 .30042 L
.472 .29925 L
.476 .29881 L
.48 .29959 L
.484 .30126 L
.488 .30288 L
.492 .3036 L
.496 .30309 L
.5 .30178 L
.504 .30052 L
.508 .30007 L
.512 .30065 L
.516 .30181 L
.52 .30282 L
.524 .30307 L
.528 .30248 L
.532 .30149 L
.536 .30074 L
.54 .30065 L
.544 .30121 L
.548 .30201 L
.552 .30254 L
.556 .30251 L
.56 .30199 L
.564 .30135 L
.568 .30099 L
.572 .3011 L
.576 .30155 L
.58 .30203 L
.584 .30225 L
.588 .30212 L
.592 .30175 L
.596 .30137 L
.6 .30121 L
Mistroke
.604 .30133 L
.608 .30166 L
.612 .30197 L
.616 .30209 L
.62 .30194 L
.624 .30162 L
.628 .30134 L
.632 .30127 L
.636 .30145 L
.64 .30176 L
.644 .302 L
.648 .30201 L
.652 .30177 L
.656 .30143 L
.66 .30123 L
.664 .30133 L
.668 .30166 L
.672 .30198 L
.676 .30205 L
.68 .3018 L
.684 .30141 L
.688 .30119 L
.692 .30131 L
.696 .30167 L
.7 .30199 L
.704 .30202 L
.708 .30173 L
.712 .30136 L
.716 .30119 L
.72 .30135 L
.724 .30172 L
.728 .30199 L
.732 .30195 L
.736 .30162 L
.74 .30127 L
.744 .30119 L
.748 .30145 L
.752 .30183 L
.756 .302 L
.76 .30181 L
.764 .30142 L
.768 .30118 L
.772 .30129 L
.776 .30165 L
.78 .30193 L
.784 .30188 L
.788 .30156 L
.792 .30127 L
.796 .30124 L
.8 .30151 L
Mistroke
.804 .30179 L
.808 .30185 L
.812 .30165 L
.816 .30137 L
.82 .30127 L
.824 .30142 L
.828 .30166 L
.832 .30178 L
.836 .30169 L
.84 .30147 L
.844 .30131 L
.848 .30136 L
.852 .30156 L
.856 .30171 L
.86 .30171 L
.864 .30153 L
.868 .30134 L
.872 .30133 L
.876 .30148 L
.88 .30166 L
.884 .30171 L
.888 .30155 L
.892 .30135 L
.896 .30131 L
.9 .30144 L
.904 .30164 L
.908 .30172 L
.912 .30155 L
.916 .30132 L
.92 .30129 L
.924 .30144 L
.928 .30164 L
.932 .30171 L
.936 .30151 L
.94 .30127 L
.944 .30128 L
.948 .30146 L
.952 .30165 L
.956 .30169 L
.96 .30145 L
.964 .30121 L
.968 .30129 L
.972 .30151 L
.976 .30167 L
.98 .30165 L
.984 .30137 L
.988 .30115 L
.992 .30131 L
.996 .30159 L
1 .30168 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13973 m
.008 .13893 L
.012 .13878 L
.016 .13932 L
.02 .13958 L
.024 .13974 L
.028 .14001 L
.032 .1404 L
.036 .14067 L
.04 .14095 L
.044 .14107 L
.048 .1411 L
.052 .14098 L
.056 .1408 L
.06 .1405 L
.064 .14009 L
.068 .13963 L
.072 .13923 L
.076 .13892 L
.08 .13865 L
.084 .13833 L
.088 .13806 L
.092 .13793 L
.096 .13792 L
.1 .13784 L
.104 .13771 L
.108 .13765 L
.112 .13783 L
.116 .13825 L
.12 .13883 L
.124 .13946 L
.128 .1402 L
.132 .14122 L
.136 .14257 L
.14 .14414 L
.144 .14576 L
.148 .14724 L
.152 .14865 L
.156 .15021 L
.16 .15212 L
.164 .15431 L
.168 .15647 L
.172 .15828 L
.176 .15968 L
.18 .16099 L
.184 .16258 L
.188 .16458 L
.192 .16675 L
.196 .16869 L
.2 .17017 L
Mistroke
.204 .17132 L
.208 .1725 L
.212 .17404 L
.216 .17612 L
.22 .17868 L
.224 .18159 L
.228 .18467 L
.232 .18765 L
.236 .19021 L
.24 .19211 L
.244 .19331 L
.248 .19408 L
.252 .19489 L
.256 .19621 L
.26 .19826 L
.264 .20103 L
.268 .20435 L
.272 .20811 L
.276 .21232 L
.28 .21708 L
.284 .22242 L
.288 .22821 L
.292 .23417 L
.296 .24002 L
.3 .24562 L
.304 .25102 L
.308 .25641 L
.312 .262 L
.316 .26784 L
.32 .27381 L
.324 .2797 L
.328 .28528 L
.332 .29048 L
.336 .29541 L
.34 .3003 L
.344 .30539 L
.348 .31083 L
.352 .31662 L
.356 .32259 L
.36 .32851 L
.364 .33412 L
.368 .3393 L
.372 .34406 L
.376 .34854 L
.38 .35298 L
.384 .35762 L
.388 .36267 L
.392 .36824 L
.396 .37431 L
.4 .38075 L
Mistroke
.404 .38738 L
.408 .39394 L
.412 .40021 L
.416 .40598 L
.42 .41109 L
.424 .41549 L
.428 .41915 L
.432 .4221 L
.436 .42444 L
.44 .42623 L
.444 .42759 L
.448 .42858 L
.452 .4293 L
.456 .42979 L
.46 .43013 L
.464 .43036 L
.468 .43051 L
.472 .43061 L
.476 .43069 L
.48 .43075 L
.484 .43079 L
.488 .43082 L
.492 .43084 L
.496 .43085 L
.5 .43086 L
.504 .43087 L
.508 .43089 L
.512 .43091 L
.516 .43092 L
.52 .43094 L
.524 .43095 L
.528 .43096 L
.532 .43097 L
.536 .43098 L
.54 .431 L
.544 .43101 L
.548 .43103 L
.552 .43104 L
.556 .43105 L
.56 .43106 L
.564 .43107 L
.568 .43109 L
.572 .4311 L
.576 .43112 L
.58 .43114 L
.584 .43115 L
.588 .43116 L
.592 .43117 L
.596 .43118 L
.6 .4312 L
Mistroke
.604 .43121 L
.608 .43123 L
.612 .43124 L
.616 .43125 L
.62 .43126 L
.624 .43128 L
.628 .43129 L
.632 .4313 L
.636 .43132 L
.64 .43133 L
.644 .43134 L
.648 .43136 L
.652 .43137 L
.656 .43138 L
.66 .4314 L
.664 .43141 L
.668 .43142 L
.672 .43144 L
.676 .43145 L
.68 .43146 L
.684 .43148 L
.688 .43149 L
.692 .4315 L
.696 .43152 L
.7 .43153 L
.704 .43154 L
.708 .43155 L
.712 .43157 L
.716 .43158 L
.72 .43159 L
.724 .43161 L
.728 .43162 L
.732 .43163 L
.736 .43165 L
.74 .43166 L
.744 .43167 L
.748 .43169 L
.752 .4317 L
.756 .43171 L
.76 .43173 L
.764 .43174 L
.768 .43175 L
.772 .43176 L
.776 .43178 L
.78 .43179 L
.784 .43181 L
.788 .43182 L
.792 .43183 L
.796 .43184 L
.8 .43186 L
Mistroke
.804 .43187 L
.808 .43189 L
.812 .4319 L
.816 .43191 L
.82 .43192 L
.824 .43194 L
.828 .43195 L
.832 .43196 L
.836 .43198 L
.84 .43199 L
.844 .432 L
.848 .43202 L
.852 .43203 L
.856 .43204 L
.86 .43206 L
.864 .43207 L
.868 .43208 L
.872 .4321 L
.876 .43211 L
.88 .43212 L
.884 .43213 L
.888 .43215 L
.892 .43216 L
.896 .43217 L
.9 .43218 L
.904 .4322 L
.908 .43221 L
.912 .43223 L
.916 .43224 L
.92 .43225 L
.924 .43226 L
.928 .43228 L
.932 .43229 L
.936 .43231 L
.94 .43232 L
.944 .43233 L
.948 .43234 L
.952 .43236 L
.956 .43237 L
.96 .43239 L
.964 .43239 L
.968 .43242 L
.972 .43242 L
.976 .43244 L
.98 .43244 L
.984 .43247 L
.988 .43247 L
.992 .4325 L
.996 .43249 L
1 .43253 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15871 L
.012 .16029 L
.016 .16071 L
.02 .16004 L
.024 .15992 L
.028 .16051 L
.032 .16104 L
.036 .16157 L
.04 .16207 L
.044 .1626 L
.048 .16289 L
.052 .16299 L
.056 .16292 L
.06 .16269 L
.064 .16219 L
.068 .16151 L
.072 .16083 L
.076 .16022 L
.08 .15958 L
.084 .15893 L
.088 .15842 L
.092 .15822 L
.096 .15825 L
.1 .15837 L
.104 .15849 L
.108 .1587 L
.112 .15916 L
.116 .15984 L
.12 .16052 L
.124 .16114 L
.128 .16181 L
.132 .16279 L
.136 .16423 L
.14 .16609 L
.144 .16811 L
.148 .17011 L
.152 .17211 L
.156 .1743 L
.16 .17685 L
.164 .17966 L
.168 .1823 L
.172 .18439 L
.176 .18594 L
.18 .18737 L
.184 .18923 L
.188 .1917 L
.192 .19448 L
.196 .19703 L
.2 .19903 L
Mistroke
.204 .20058 L
.208 .2021 L
.212 .20399 L
.216 .20647 L
.22 .20953 L
.224 .21305 L
.228 .21681 L
.232 .22051 L
.236 .22375 L
.24 .22619 L
.244 .22776 L
.248 .22877 L
.252 .22979 L
.256 .2314 L
.26 .23389 L
.264 .23725 L
.268 .24132 L
.272 .24596 L
.276 .2512 L
.28 .25716 L
.284 .26386 L
.288 .27111 L
.292 .27855 L
.296 .28582 L
.3 .29274 L
.304 .29939 L
.308 .30604 L
.312 .31295 L
.316 .3202 L
.32 .32766 L
.324 .33502 L
.328 .34199 L
.332 .34846 L
.336 .35456 L
.34 .36057 L
.344 .36683 L
.348 .37354 L
.352 .38071 L
.356 .38815 L
.36 .39552 L
.364 .40252 L
.368 .40896 L
.372 .41484 L
.376 .42034 L
.38 .42579 L
.384 .4315 L
.388 .43774 L
.392 .44466 L
.396 .4522 L
.4 .46022 L
Mistroke
.404 .46844 L
.408 .47655 L
.412 .48428 L
.416 .49138 L
.42 .49768 L
.424 .50311 L
.428 .50763 L
.432 .51128 L
.436 .51415 L
.44 .51633 L
.444 .51793 L
.448 .51909 L
.452 .5199 L
.456 .52046 L
.46 .52083 L
.464 .52107 L
.468 .52122 L
.472 .52129 L
.476 .52132 L
.48 .52131 L
.484 .52129 L
.488 .52126 L
.492 .52123 L
.496 .5212 L
.5 .52116 L
.504 .52112 L
.508 .52108 L
.512 .52103 L
.516 .52098 L
.52 .52093 L
.524 .52089 L
.528 .52085 L
.532 .52081 L
.536 .52077 L
.54 .52072 L
.544 .52067 L
.548 .52063 L
.552 .52058 L
.556 .52054 L
.56 .5205 L
.564 .52046 L
.568 .52042 L
.572 .52037 L
.576 .52032 L
.58 .52027 L
.584 .52023 L
.588 .52019 L
.592 .52015 L
.596 .52011 L
.6 .52006 L
Mistroke
.604 .52001 L
.608 .51997 L
.612 .51992 L
.616 .51988 L
.62 .51984 L
.624 .5198 L
.628 .51975 L
.632 .5197 L
.636 .51966 L
.64 .51962 L
.644 .51957 L
.648 .51953 L
.652 .51949 L
.656 .51944 L
.66 .5194 L
.664 .51935 L
.668 .51931 L
.672 .51926 L
.676 .51922 L
.68 .51918 L
.684 .51913 L
.688 .51909 L
.692 .51904 L
.696 .519 L
.7 .51896 L
.704 .51891 L
.708 .51887 L
.712 .51882 L
.716 .51878 L
.72 .51873 L
.724 .51869 L
.728 .51865 L
.732 .5186 L
.736 .51856 L
.74 .51851 L
.744 .51847 L
.748 .51842 L
.752 .51838 L
.756 .51834 L
.76 .51829 L
.764 .51825 L
.768 .5182 L
.772 .51816 L
.776 .51812 L
.78 .51807 L
.784 .51803 L
.788 .51798 L
.792 .51794 L
.796 .51789 L
.8 .51785 L
Mistroke
.804 .5178 L
.808 .51776 L
.812 .51771 L
.816 .51767 L
.82 .51763 L
.824 .51758 L
.828 .51754 L
.832 .51749 L
.836 .51745 L
.84 .5174 L
.844 .51736 L
.848 .51732 L
.852 .51727 L
.856 .51723 L
.86 .51718 L
.864 .51714 L
.868 .51709 L
.872 .51705 L
.876 .51701 L
.88 .51696 L
.884 .51691 L
.888 .51687 L
.892 .51683 L
.896 .51679 L
.9 .51674 L
.904 .5167 L
.908 .51665 L
.912 .51661 L
.916 .51656 L
.92 .51652 L
.924 .51647 L
.928 .51643 L
.932 .51638 L
.936 .51634 L
.94 .51629 L
.944 .51626 L
.948 .5162 L
.952 .51617 L
.956 .51611 L
.96 .51608 L
.964 .51602 L
.968 .51599 L
.972 .51593 L
.976 .5159 L
.98 .51584 L
.984 .51582 L
.988 .51575 L
.992 .51573 L
.996 .51566 L
1 .51564 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0`000goo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00<007oo00000P0000Eoo`00Oomoo`0000Eoo`05001oogooOol00003
Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<0
07ooOol00Woo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomo
o`05Ool01@00Ool00000Ool00P0000Eoo`00001oo`00009oo`03001oogoo00=oo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001o
o`0000@00005Ool00000Ool00002Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol00goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomo
o`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`03001oogoo00]oo`@000=oo`04001oogoo0006Ool30002Ool20002Ool200001Goo001o
ogoo00001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`80
00Yoo`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0005Ool30004Ool0
1@00Oomoo`00Ool00P000Woo00<007ooOol00Woo0P000goo00<007ooOol017oo00@007ooOol0009o
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo0000
1Woo00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P001Goo0P0000=oo`00Ool017oo0P000goo
0`001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`80
00Ioo`008Woo00<007ooOol06Goo00<007ooOol037oo0P00@Woo000ROol20006Ool00`00Oomoo`0A
Ool00`00Oomoo`0=Ool20011Ool0029oof<000aoo`008Woo00P007oo001oo`00Ool007oo0P000Woo
00D007ooOomoo`0000=oo`05001oogooOol00002Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomo
o`0:Ool0029oo`<0009oo`03001oogoo009oo`04001oo`00000<Ool00`00Oomoo`1BOol0029oo`03
001oogoo008000Eoo`800003Ool007oo00]oo`03001oogoo059oo`008Woo0P0037oo00<007ooOol0
0P000Woo0P000Woo00<007ooOol0Dgoo000ROol2000<Ool00`00Ool00002Ool500000goo001oo`1D
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo00aoo`8000=oo`06001o
ogoo001oo`00EGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000eo
o`03001oogoo00Ioo`03001oogoo05Aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03
001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomo
o`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eo
o`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qo
o`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo
000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool0
0`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo
00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001o
ogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<0
07ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03
001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`05
Ool4001MOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`P000=oo`@005Yoo`00:7oo00<007oo
Ool02goo0`00F7oo000XOol00`00Oomoo`0>Ool3001EOol000]oo`8000Aoo`03001oogoo00=oo`80
00Aoo`8000=oo`<000=oo`03001oogoo011oo`<005=oo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000DOol2001BOol000=oo`D0009oo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000EOol3001@Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000=o
o`04001oogooOol30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool2
0003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007oo
Ool007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`000goo00D007oo
Oomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo
00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool01000Oomoogoo
0P000Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<0
07ooOol03Goo00@007ooOol0009oo`03001oogoo009oo`800003Ool007oo00=oo`04001oogoo0002
Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03
001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Eoo`03001oo`0000Aoo`04
001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol0
00Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo
0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000X
Ool00`00Oomoo`09Ool50003Ool20007Ool20005Ool20004Ool20004Ool01000Oomoogoo1@000goo
0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`0KOol0
0`00Oomoo`18Ool002Qoo`03001oogoo01aoo`03001oogoo04Moo`00:7ooG@0037oo000XOol00`00
Oomoo`0?Ool00`00Oomoo`0;Ool20003Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@
Ool00`00Oomoo`0:Ool002Qoo`03001oogoo01ioo`03001oogoo04Eoo`00:7oo00<007ooOol07goo
00<007ooOol0A7oo000XOol00`00Oomoo`0OOol20015Ool002Qoo`03001oogoo021oo`8004Aoo`00
:7oo00<007ooOol08Goo00<007ooOol0@Woo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003
Ool30003Ool00`00Oomoo`0ROol00`00Oomoo`11Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00H007ooOol007oo0003Ool01000Oomoo`0097oo0P00@Woo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool01000Oomoo`009Goo0P00@Goo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000UOol20010Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo02EoocD000aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo
0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003
Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001o
ogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool0
1000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo
0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`80
00Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0
009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`00
0Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomo
o`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomo
o`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009o
o`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol0
0goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo
00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000
Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo
0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`80
00Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`D0
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo
00Yoo`0077oo00<007ooOol03Goo0`00HWoo000LOol2000@Ool3001POol001aoo`03001oogoo015o
o`<005ioo`0077oo00<007ooOol04goo0P00GGoo000LOol2000EOol2001LOol001aoo`03001oogoo
01Ioo`8005Yoo`0077oo00<007ooOol067oo0P00F7oo000LOol2000JOol00`00Oomoo`1FOol001ao
o`03001oogoo01Yoo`03001oogoo05Eoo`0077oo0P0077oo00<007ooOol0E7oo000;Ool20004Ool0
0`00Oomoo`02Ool30003Ool00`00Oomoo`0KOol00`00Oomoo`1DOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol077oo00<007ooOol0Dgoo000:Ool01000Oomoo`002goo00<0
07ooOol00P007Goo00<007ooOol0Dgoo000:Ool01000Oomoo`002goo00@007ooOol001moo`03001o
ogoo059oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo01eoo`03001oogoo059oo`002Woo
00@007ooOol000Moo`03001oogoo00Aoo`8001moo`03001oogoo055oo`002goo0P0027oo1@000Woo
00<007ooOol07goo00<007ooOol0D7oo000LOol00`00Oomoo`0OOol00`00Oomoo`1@Ool001aoo`80
025oo`03001oogoo04moo`0077oo00<007ooOol087oo00<007ooOol0Cgoo000LOol2000ROol00`00
Oomoo`1>Ool001aoo`03001oogoo029oo`03001oogoo04eoo`0077oo00<007ooOol08Woo00<007oo
Ool0CGoo000LOol2000TOol00`00Oomoo`1<Ool001Ioo`<000=oo`03001oogoo02=oo`8004eoo`00
5goo00<007ooOol00Woo00<007ooOol097oo00<007ooOol0Bgoo000GOol00`00Oomoo`02Ool2000U
Ool2001<Ool001Moo`03001oogoo009oo`03001oogoo02Eoo`03001oogoo04Yoo`005goo00<007oo
Ool00Woo00<007ooOol09Woo00<007ooOol0BGoo000FOol20004Ool2000XOol00`00Oomoo`18Ool0
01Moo`03001oogoo009oo`03001oogoo02Moo`03001oogoo04Qoo`0077oo00<007ooOol09goo00<0
07ooOol0B7oo000LOol2000YOol00`00Oomoo`17Ool001aoo`03001oogoo02Uoo`03001oogoo04Io
o`0077oo0P00:Woo0P00Agoo000LOol00`00Oomoo`0ZOoll000<Ool001aoo`03001oogoo079oo`00
2Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo
00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomo
o`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo
0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(14195\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32728 m
.008 .32825 L
.012 .32668 L
.016 .32407 L
.02 .32139 L
.024 .31859 L
.028 .31685 L
.032 .31573 L
.036 .31542 L
.04 .31575 L
.044 .31669 L
.048 .318 L
.052 .31907 L
.056 .32091 L
.06 .32353 L
.064 .32686 L
.068 .32961 L
.072 .33085 L
.076 .33044 L
.08 .32813 L
.084 .32341 L
.088 .31555 L
.092 .3065 L
.096 .29938 L
.1 .29606 L
.104 .29635 L
.108 .2998 L
.112 .30653 L
.116 .31573 L
.12 .32529 L
.124 .33212 L
.128 .33406 L
.132 .33144 L
.136 .32665 L
.14 .32242 L
.144 .32071 L
.148 .32231 L
.152 .32683 L
.156 .33358 L
.16 .34213 L
.164 .35172 L
.168 .36069 L
.172 .36619 L
.176 .36575 L
.18 .35983 L
.184 .35249 L
.188 .34844 L
.192 .34965 L
.196 .35374 L
.2 .35616 L
Mistroke
.204 .35453 L
.208 .35029 L
.212 .34686 L
.216 .34655 L
.22 .34876 L
.224 .35118 L
.228 .35231 L
.232 .35234 L
.236 .35222 L
.24 .35226 L
.244 .35198 L
.248 .35124 L
.252 .35119 L
.256 .35376 L
.26 .35964 L
.264 .36707 L
.268 .3724 L
.272 .3724 L
.276 .36643 L
.28 .35682 L
.284 .34703 L
.288 .3392 L
.292 .33281 L
.296 .32545 L
.3 .31502 L
.304 .30151 L
.308 .28734 L
.312 .27593 L
.316 .26957 L
.32 .2681 L
.324 .26909 L
.328 .26924 L
.332 .26632 L
.336 .26018 L
.34 .25271 L
.344 .24668 L
.348 .24417 L
.352 .24556 L
.356 .24936 L
.36 .2529 L
.364 .25365 L
.368 .25032 L
.372 .24354 L
.376 .23555 L
.38 .22936 L
.384 .22739 L
.388 .23046 L
.392 .23731 L
.396 .24508 L
.4 .25042 L
Mistroke
.404 .2508 L
.408 .24553 L
.412 .23594 L
.416 .22476 L
.42 .21498 L
.424 .20873 L
.428 .20672 L
.432 .20837 L
.436 .21253 L
.44 .21823 L
.444 .22508 L
.448 .23324 L
.452 .24287 L
.456 .25364 L
.46 .26458 L
.464 .2744 L
.468 .282 L
.472 .28707 L
.476 .29014 L
.48 .29224 L
.484 .29431 L
.488 .29675 L
.492 .29927 L
.496 .30122 L
.5 .30209 L
.504 .30188 L
.508 .3011 L
.512 .30046 L
.516 .30047 L
.52 .30113 L
.524 .30203 L
.528 .30262 L
.532 .3026 L
.536 .30206 L
.54 .30138 L
.544 .30099 L
.548 .3011 L
.552 .30158 L
.556 .30211 L
.56 .30235 L
.564 .3022 L
.568 .30179 L
.572 .30139 L
.576 .30123 L
.58 .30138 L
.584 .30172 L
.588 .30203 L
.592 .30214 L
.596 .30199 L
.6 .30167 L
Mistroke
.604 .30139 L
.608 .30132 L
.612 .3015 L
.616 .30181 L
.62 .30205 L
.624 .30205 L
.628 .30183 L
.632 .30151 L
.636 .30131 L
.64 .30138 L
.644 .30167 L
.648 .30198 L
.652 .30209 L
.656 .30189 L
.66 .30153 L
.664 .30127 L
.668 .30132 L
.672 .30164 L
.676 .30199 L
.68 .30208 L
.684 .30185 L
.688 .30147 L
.692 .30125 L
.696 .30135 L
.7 .30169 L
.704 .302 L
.708 .30203 L
.712 .30175 L
.716 .30139 L
.72 .30124 L
.724 .30142 L
.728 .30179 L
.732 .30203 L
.736 .30193 L
.74 .30158 L
.744 .30128 L
.748 .30128 L
.752 .30158 L
.756 .30191 L
.76 .30198 L
.764 .30173 L
.768 .30139 L
.772 .30126 L
.776 .30145 L
.78 .30176 L
.784 .30192 L
.788 .3018 L
.792 .3015 L
.796 .30131 L
.8 .30138 L
Mistroke
.804 .30163 L
.808 .30183 L
.812 .30181 L
.816 .30159 L
.82 .30138 L
.824 .30136 L
.828 .30153 L
.832 .30174 L
.836 .30179 L
.84 .30164 L
.844 .30143 L
.848 .30136 L
.852 .30147 L
.856 .30167 L
.86 .30177 L
.864 .30166 L
.868 .30146 L
.872 .30135 L
.876 .30143 L
.88 .30163 L
.884 .30176 L
.888 .30165 L
.892 .30145 L
.896 .30135 L
.9 .30142 L
.904 .30162 L
.908 .30174 L
.912 .30162 L
.916 .30141 L
.92 .30134 L
.924 .30144 L
.928 .30164 L
.932 .30172 L
.936 .30156 L
.94 .30136 L
.944 .30134 L
.948 .30148 L
.952 .30165 L
.956 .30169 L
.96 .30148 L
.964 .3013 L
.968 .30137 L
.972 .30154 L
.976 .30167 L
.98 .30164 L
.984 .30139 L
.988 .30124 L
.992 .30141 L
.996 .30161 L
1 .30166 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14384 m
.008 .14097 L
.012 .13985 L
.016 .14058 L
.02 .14062 L
.024 .14003 L
.028 .1396 L
.032 .13943 L
.036 .13928 L
.04 .13922 L
.044 .13928 L
.048 .13951 L
.052 .13984 L
.056 .14031 L
.06 .14077 L
.064 .1412 L
.068 .14146 L
.072 .14162 L
.076 .14165 L
.08 .14152 L
.084 .14117 L
.088 .14071 L
.092 .14029 L
.096 .13994 L
.1 .13958 L
.104 .13917 L
.108 .13881 L
.112 .13859 L
.116 .13847 L
.12 .13834 L
.124 .13812 L
.128 .13791 L
.132 .13788 L
.136 .1381 L
.14 .13848 L
.144 .13892 L
.148 .13938 L
.152 .13998 L
.156 .14088 L
.16 .14212 L
.164 .14355 L
.168 .14496 L
.172 .14625 L
.176 .14757 L
.18 .14921 L
.184 .15127 L
.188 .15357 L
.192 .15572 L
.196 .15741 L
.2 .15873 L
Mistroke
.204 .16005 L
.208 .1617 L
.212 .16372 L
.216 .16584 L
.22 .16773 L
.224 .16924 L
.228 .17048 L
.232 .1717 L
.236 .17315 L
.24 .17498 L
.244 .17727 L
.248 .18001 L
.252 .18309 L
.256 .1862 L
.26 .18897 L
.264 .19107 L
.268 .19244 L
.272 .19332 L
.276 .19416 L
.28 .19536 L
.284 .19713 L
.288 .19947 L
.292 .20229 L
.296 .20556 L
.3 .20936 L
.304 .21382 L
.308 .21896 L
.312 .22461 L
.316 .23047 L
.32 .23626 L
.324 .24182 L
.328 .24718 L
.332 .25255 L
.336 .25811 L
.34 .26394 L
.344 .26994 L
.348 .2759 L
.352 .28158 L
.356 .28688 L
.36 .29186 L
.364 .29672 L
.368 .30172 L
.372 .30704 L
.376 .31273 L
.38 .31868 L
.384 .32466 L
.388 .33042 L
.392 .33578 L
.396 .34069 L
.4 .34523 L
Mistroke
.404 .34963 L
.408 .35412 L
.412 .35895 L
.416 .36427 L
.42 .37012 L
.424 .37641 L
.428 .38298 L
.432 .3896 L
.436 .39605 L
.44 .4021 L
.444 .4076 L
.448 .41245 L
.452 .41659 L
.456 .42002 L
.46 .42279 L
.464 .42496 L
.468 .42662 L
.472 .42786 L
.476 .42877 L
.48 .42942 L
.484 .42989 L
.488 .43021 L
.492 .43044 L
.496 .43059 L
.5 .43069 L
.504 .43075 L
.508 .4308 L
.512 .43083 L
.516 .43086 L
.52 .43089 L
.524 .43091 L
.528 .43092 L
.532 .43094 L
.536 .43095 L
.54 .43096 L
.544 .43097 L
.548 .43099 L
.552 .431 L
.556 .43102 L
.56 .43103 L
.564 .43104 L
.568 .43105 L
.572 .43107 L
.576 .43108 L
.58 .4311 L
.584 .43111 L
.588 .43112 L
.592 .43114 L
.596 .43115 L
.6 .43116 L
Mistroke
.604 .43117 L
.608 .43119 L
.612 .4312 L
.616 .43122 L
.62 .43123 L
.624 .43124 L
.628 .43125 L
.632 .43127 L
.636 .43128 L
.64 .43129 L
.644 .43131 L
.648 .43132 L
.652 .43133 L
.656 .43135 L
.66 .43136 L
.664 .43137 L
.668 .43139 L
.672 .4314 L
.676 .43141 L
.68 .43142 L
.684 .43144 L
.688 .43145 L
.692 .43147 L
.696 .43148 L
.7 .43149 L
.704 .4315 L
.708 .43152 L
.712 .43153 L
.716 .43154 L
.72 .43156 L
.724 .43157 L
.728 .43158 L
.732 .4316 L
.736 .43161 L
.74 .43162 L
.744 .43164 L
.748 .43165 L
.752 .43166 L
.756 .43167 L
.76 .43169 L
.764 .4317 L
.768 .43172 L
.772 .43173 L
.776 .43174 L
.78 .43175 L
.784 .43177 L
.788 .43178 L
.792 .4318 L
.796 .43181 L
.8 .43182 L
Mistroke
.804 .43183 L
.808 .43185 L
.812 .43186 L
.816 .43187 L
.82 .43189 L
.824 .4319 L
.828 .43191 L
.832 .43193 L
.836 .43194 L
.84 .43195 L
.844 .43197 L
.848 .43198 L
.852 .43199 L
.856 .432 L
.86 .43202 L
.864 .43203 L
.868 .43204 L
.872 .43206 L
.876 .43207 L
.88 .43208 L
.884 .4321 L
.888 .43211 L
.892 .43212 L
.896 .43214 L
.9 .43215 L
.904 .43216 L
.908 .43217 L
.912 .43219 L
.916 .4322 L
.92 .43222 L
.924 .43222 L
.928 .43224 L
.932 .43225 L
.936 .43227 L
.94 .43228 L
.944 .4323 L
.948 .4323 L
.952 .43232 L
.956 .43233 L
.96 .43235 L
.964 .43235 L
.968 .43238 L
.972 .43238 L
.976 .4324 L
.98 .4324 L
.984 .43243 L
.988 .43243 L
.992 .43246 L
.996 .43245 L
1 .43249 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .1617 L
.012 .1613 L
.016 .1612 L
.02 .1614 L
.024 .16127 L
.028 .16102 L
.032 .16082 L
.036 .16068 L
.04 .16055 L
.044 .16053 L
.048 .16057 L
.052 .16074 L
.056 .16102 L
.06 .16145 L
.064 .16182 L
.068 .16217 L
.072 .16248 L
.076 .16279 L
.08 .16288 L
.084 .16272 L
.088 .16234 L
.092 .16189 L
.096 .16136 L
.1 .1607 L
.104 .15993 L
.108 .15921 L
.112 .15874 L
.116 .15855 L
.12 .15845 L
.124 .15837 L
.128 .15836 L
.132 .15855 L
.136 .15896 L
.14 .15947 L
.144 .15992 L
.148 .16031 L
.152 .16086 L
.156 .16182 L
.16 .16327 L
.164 .16508 L
.168 .16694 L
.172 .1687 L
.176 .1705 L
.18 .17264 L
.184 .17523 L
.188 .17805 L
.192 .1806 L
.196 .18259 L
.2 .18414 L
Mistroke
.204 .18573 L
.208 .1878 L
.212 .19038 L
.216 .19311 L
.22 .19555 L
.224 .19747 L
.228 .19901 L
.232 .20049 L
.236 .20222 L
.24 .20443 L
.244 .20722 L
.248 .21062 L
.252 .21446 L
.256 .21838 L
.26 .22188 L
.264 .22454 L
.268 .22625 L
.272 .22733 L
.276 .22832 L
.28 .22975 L
.284 .2319 L
.288 .23478 L
.292 .2383 L
.296 .2424 L
.3 .24718 L
.304 .25277 L
.308 .25916 L
.312 .26616 L
.316 .27341 L
.32 .28056 L
.324 .28743 L
.328 .2941 L
.332 .30079 L
.336 .30774 L
.34 .31502 L
.344 .32248 L
.348 .32986 L
.352 .33688 L
.356 .34342 L
.36 .34956 L
.364 .35559 L
.368 .36181 L
.372 .36845 L
.376 .37553 L
.38 .38292 L
.384 .39032 L
.388 .39743 L
.392 .40404 L
.396 .4101 L
.4 .41572 L
Mistroke
.404 .42118 L
.408 .42676 L
.412 .43275 L
.416 .43933 L
.42 .44656 L
.424 .45433 L
.428 .46245 L
.432 .47065 L
.436 .47864 L
.44 .48615 L
.444 .49296 L
.448 .49895 L
.452 .50404 L
.456 .50824 L
.46 .51161 L
.464 .51425 L
.468 .51627 L
.472 .51777 L
.476 .51885 L
.48 .51961 L
.484 .52013 L
.488 .52046 L
.492 .52067 L
.496 .52079 L
.5 .52086 L
.504 .52089 L
.508 .5209 L
.512 .52088 L
.516 .52085 L
.52 .52081 L
.524 .52077 L
.528 .52073 L
.532 .52069 L
.536 .52065 L
.54 .52061 L
.544 .52057 L
.548 .52052 L
.552 .52047 L
.556 .52043 L
.56 .52038 L
.564 .52034 L
.568 .5203 L
.572 .52026 L
.576 .52021 L
.58 .52017 L
.584 .52012 L
.588 .52008 L
.592 .52003 L
.596 .51999 L
.6 .51995 L
Mistroke
.604 .51991 L
.608 .51986 L
.612 .51981 L
.616 .51977 L
.62 .51973 L
.624 .51968 L
.628 .51964 L
.632 .5196 L
.636 .51955 L
.64 .51951 L
.644 .51946 L
.648 .51942 L
.652 .51937 L
.656 .51933 L
.66 .51929 L
.664 .51924 L
.668 .5192 L
.672 .51915 L
.676 .51911 L
.68 .51907 L
.684 .51902 L
.688 .51898 L
.692 .51893 L
.696 .51889 L
.7 .51884 L
.704 .5188 L
.708 .51876 L
.712 .51871 L
.716 .51867 L
.72 .51862 L
.724 .51858 L
.728 .51854 L
.732 .51849 L
.736 .51845 L
.74 .5184 L
.744 .51836 L
.748 .51831 L
.752 .51827 L
.756 .51823 L
.76 .51818 L
.764 .51814 L
.768 .51809 L
.772 .51805 L
.776 .51801 L
.78 .51796 L
.784 .51792 L
.788 .51787 L
.792 .51783 L
.796 .51778 L
.8 .51774 L
Mistroke
.804 .5177 L
.808 .51765 L
.812 .5176 L
.816 .51756 L
.82 .51752 L
.824 .51747 L
.828 .51743 L
.832 .51739 L
.836 .51734 L
.84 .51729 L
.844 .51725 L
.848 .51721 L
.852 .51716 L
.856 .51712 L
.86 .51707 L
.864 .51703 L
.868 .51698 L
.872 .51694 L
.876 .5169 L
.88 .51685 L
.884 .51681 L
.888 .51676 L
.892 .51672 L
.896 .51668 L
.9 .51663 L
.904 .51659 L
.908 .51654 L
.912 .5165 L
.916 .51645 L
.92 .51641 L
.924 .51636 L
.928 .51632 L
.932 .51627 L
.936 .51623 L
.94 .51618 L
.944 .51615 L
.948 .51609 L
.952 .51606 L
.956 .516 L
.96 .51597 L
.964 .51591 L
.968 .51588 L
.972 .51582 L
.976 .51579 L
.98 .51573 L
.984 .51571 L
.988 .51564 L
.992 .51562 L
.996 .51555 L
1 .51553 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0000=oo`0000000`001Goo0`000goo0`0017oo
0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool0
1000Oomoo`001goo00<007ooOol00Woo00<007ooOol00P0000Eoo`00Oomoo`0000Eoo`05001oogoo
Ool00003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
0Woo00<007ooOol00Woo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool2000017oo001oogoo0P0000=oo`00Ool017oo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00@0
07oo001oo`D0009oo`800003Ool007oo00Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
00<007ooOol02goo10000goo00@007ooOol000Moo`800005Ool00000001oo`020002Ool01000Ool0
00001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool30003Ool01000
Oomoo`000Woo00@007oo000000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Moo`8000Eoo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo
01]oo`03001oogoo00eoo`03001oogoo03ioo`008Woo0P0027oo00<007ooOol04Goo00<007ooOol0
3Woo0P00?Woo000ROomS000<Ool0029oo`03001oo`0000<0009oo`800003Ool0000000=oo`05001o
ogooOol00003Ool02000Oomoo`00Ool007oo0003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo00Yoo`008Woo0`000goo
00<007oo00000goo10003Goo00<007ooOol0Cgoo000ROol00`00Oomoo`04Ool20003Ool200000goo
001oo`0;Ool2001AOol0029oo`8000ioo`05001oo`00001oo`020005Ool00`00Oomoo`1@Ool0029o
o`8000ioo`03001oo`0000800003Ool0000000800003Ool007oo059oo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo00<007ooOol03Woo00<007ooOol01Woo0P00Dgoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8001Qoo`8005=oo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool0
00]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol0
0goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qo
o`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo
000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo
0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000R
Ool00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo
00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool00`00Oomoo`08Ool3001KOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`/0009o
o`D005Moo`00:7oo00<007ooOol03Woo0`00EGoo000XOol00`00Oomoo`0@Ool3001COol000]oo`80
00Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo019oo`<0055oo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000FOol3001?Ool0
00=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000H
Ool3001=Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo
008000]oo`<000Aoo`8000Eoo`D000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=o
o`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0005
Ool30004Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03
001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol017oo
0P0017oo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D0
07ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomo
o`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo
00<007ooOol02Goo10000goo00@007ooOol000Moo`8000=oo`04001oogoo0002Ool01000Oomoo`00
0goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo
00<007ooOol017oo00@007ooOol000Ioo`<000=oo`04001oogoo0002Ool01000Oomoo`000Woo0P00
0goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool2
0008Ool00`00Ool00003Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P00
17oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`0MOol20017Ool002Qoo`03001o
ogoo01ioo`8004Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Ool0
000AOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo021oo`80
04Aoo`00:7oo00<007ooOol08Goo0P00@goo000XOol00`00Oomoo`0ROol00`00Oomoo`11Ool002Qo
o`03001oogoo02=oo`03001oogoo041oo`00:7oo00<007ooOol097oo00<007ooOol0?goo000;Ool2
0004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0TOol20010Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`009goo00<007oo
Ool0?Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00
9goo0P00?goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`02000WOol2000nOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@0
00=oo`03001oogoo02Qooc8000aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo
0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`80
00Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo
00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool0
1000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001o
ogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04
001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001o
ogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1b
Ool001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Ao
o`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007oo
Oomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol0
0goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol0
07oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol0
00Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol0
07oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P00
17oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=o
o`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D0
07ooOomoo`0000=oo`03001oogoo009oo`04001oogooOol300000goo001oo`02Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo011oo`80061o
o`0077oo0P004goo0P00GWoo000LOol00`00Oomoo`0DOol2001LOol001aoo`03001oogoo01Ioo`80
05Yoo`0077oo0P0067oo0P00FGoo000LOol00`00Oomoo`0HOol3001GOol001aoo`03001oogoo01]o
o`03001oogoo05Aoo`0077oo0P007Goo00<007ooOol0Dgoo000LOol00`00Oomoo`0MOol00`00Oomo
o`1BOol001aoo`8001ioo`03001oogoo059oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<0
07ooOol07Woo00<007ooOol0DGoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo01ioo`80059oo`002Woo00@007ooOol000]oo`03001oogoo0080021oo`03001oogoo051oo`00
2Woo00@007ooOol000]oo`04001oogoo000ROol00`00Oomoo`1?Ool000Yoo`04001oogoo0007Ool4
0003Ool00`00Oomoo`0POol00`00Oomoo`1?Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2
000ROol00`00Oomoo`1>Ool000]oo`8000Qoo`D0009oo`03001oogoo025oo`8004moo`0077oo00<0
07ooOol08Woo00<007ooOol0CGoo000LOol2000SOol2001>Ool001aoo`03001oogoo02=oo`03001o
ogoo04aoo`0077oo0P009Goo00<007ooOol0Bgoo000LOol00`00Oomoo`0TOol00`00Oomoo`1;Ool0
01aoo`03001oogoo02Eoo`03001oogoo04Yoo`0077oo0P009Woo0P00Bgoo000FOol30003Ool00`00
Oomoo`0VOol00`00Oomoo`19Ool001Moo`03001oogoo009oo`03001oogoo02Moo`03001oogoo04Qo
o`005goo00<007ooOol00Woo0P00:7oo0P00BGoo000GOol00`00Oomoo`02Ool00`00Oomoo`0XOol0
0`00Oomoo`17Ool001Moo`03001oogoo009oo`03001oogoo02Uoo`03001oogoo04Ioo`005Woo0P00
17oo0P00:Woo00<007ooOol0AWoo000GOol00`00Oomoo`02Ool00`00Oomoo`0ZOol00`00Oomoo`15
Ool001aoo`03001oogoo02Yoo`03001oogoo04Eoo`0077oo0P00;7oo00<007ooOol0A7oo000LOol0
0`00Oomoo`0[Ool20015Ool001aoo`8002eoo`8004Aoo`0077oo00<007ooOol0;Goo>@0037oo000L
Ool00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007oo
Ool01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol0
07Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool0
0`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol0
1goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(14362\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32565 m
.008 .32355 L
.012 .32116 L
.016 .31874 L
.02 .31658 L
.024 .3144 L
.028 .31254 L
.032 .31208 L
.036 .31303 L
.04 .31531 L
.044 .31858 L
.048 .32172 L
.052 .3239 L
.056 .32405 L
.06 .32266 L
.064 .32013 L
.068 .3171 L
.072 .31449 L
.076 .31375 L
.08 .31655 L
.084 .32192 L
.088 .32777 L
.092 .33233 L
.096 .33512 L
.1 .33506 L
.104 .3305 L
.108 .32172 L
.112 .31114 L
.116 .30235 L
.12 .29757 L
.124 .29717 L
.128 .30023 L
.132 .30597 L
.136 .31358 L
.14 .32116 L
.144 .32632 L
.148 .32744 L
.152 .32474 L
.156 .32029 L
.16 .31705 L
.164 .31718 L
.168 .3209 L
.172 .32662 L
.176 .3322 L
.18 .33693 L
.184 .34185 L
.188 .34779 L
.192 .35372 L
.196 .35701 L
.2 .3559 L
Mistroke
.204 .35187 L
.208 .34901 L
.212 .35028 L
.216 .3549 L
.22 .35894 L
.224 .3587 L
.228 .35397 L
.232 .34784 L
.236 .34384 L
.24 .34327 L
.244 .34496 L
.248 .34705 L
.252 .34877 L
.256 .35042 L
.26 .35214 L
.264 .35311 L
.268 .35231 L
.272 .34993 L
.276 .34789 L
.28 .34868 L
.284 .35331 L
.288 .36032 L
.292 .36655 L
.296 .36921 L
.3 .3675 L
.304 .36262 L
.308 .35624 L
.312 .34898 L
.316 .33999 L
.32 .32809 L
.324 .31335 L
.328 .29782 L
.332 .28472 L
.336 .2766 L
.34 .27368 L
.344 .27361 L
.348 .2728 L
.352 .26852 L
.356 .26043 L
.36 .2508 L
.364 .2431 L
.368 .24002 L
.372 .24201 L
.376 .24703 L
.38 .25168 L
.384 .25293 L
.388 .24957 L
.392 .2426 L
.396 .23457 L
.4 .22828 L
Mistroke
.404 .22552 L
.408 .22656 L
.412 .23033 L
.416 .23512 L
.42 .23935 L
.424 .24192 L
.428 .24225 L
.432 .24006 L
.436 .23525 L
.44 .22807 L
.444 .21927 L
.448 .21028 L
.452 .20301 L
.456 .19927 L
.46 .20015 L
.464 .20561 L
.468 .21454 L
.472 .22525 L
.476 .23618 L
.48 .24639 L
.484 .25568 L
.488 .26425 L
.492 .27234 L
.496 .27983 L
.5 .28629 L
.504 .29127 L
.508 .29457 L
.512 .29646 L
.516 .29753 L
.52 .29839 L
.524 .29939 L
.528 .30051 L
.532 .30147 L
.536 .302 L
.54 .30201 L
.544 .30167 L
.548 .30131 L
.552 .30119 L
.556 .30138 L
.56 .30176 L
.564 .30209 L
.568 .3022 L
.572 .30203 L
.576 .30171 L
.58 .30144 L
.584 .30137 L
.588 .30154 L
.592 .30185 L
.596 .30209 L
.6 .3021 L
Mistroke
.604 .30189 L
.608 .30157 L
.612 .30138 L
.616 .30143 L
.62 .30169 L
.624 .30199 L
.628 .30212 L
.632 .30196 L
.636 .30164 L
.64 .30137 L
.644 .30136 L
.648 .30163 L
.652 .30198 L
.656 .30213 L
.66 .30196 L
.664 .30159 L
.668 .30132 L
.672 .30136 L
.676 .30167 L
.68 .302 L
.684 .30209 L
.688 .30187 L
.692 .30151 L
.696 .3013 L
.7 .30141 L
.704 .30175 L
.708 .30203 L
.712 .30202 L
.716 .30173 L
.72 .3014 L
.724 .3013 L
.728 .30153 L
.732 .30188 L
.736 .30204 L
.74 .30188 L
.744 .30154 L
.748 .30131 L
.752 .30141 L
.756 .30171 L
.76 .30196 L
.764 .30193 L
.768 .30165 L
.772 .30139 L
.776 .30137 L
.78 .30159 L
.784 .30184 L
.788 .3019 L
.792 .30173 L
.796 .30148 L
.8 .30138 L
Mistroke
.804 .30151 L
.808 .30173 L
.812 .30186 L
.816 .30176 L
.82 .30155 L
.824 .30141 L
.828 .30146 L
.832 .30165 L
.836 .30181 L
.84 .30177 L
.844 .30158 L
.848 .30142 L
.852 .30143 L
.856 .30161 L
.86 .30178 L
.864 .30175 L
.868 .30158 L
.872 .30142 L
.876 .30142 L
.88 .3016 L
.884 .30175 L
.888 .30172 L
.892 .30155 L
.896 .30141 L
.9 .30143 L
.904 .30161 L
.908 .30174 L
.912 .30166 L
.916 .3015 L
.92 .30141 L
.924 .30146 L
.928 .30163 L
.932 .30172 L
.936 .30159 L
.94 .30144 L
.944 .30142 L
.948 .30151 L
.952 .30165 L
.956 .30168 L
.96 .30151 L
.964 .30139 L
.968 .30144 L
.972 .30156 L
.976 .30166 L
.98 .30163 L
.984 .30143 L
.988 .30134 L
.992 .30149 L
.996 .30163 L
1 .30165 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13989 m
.008 .14026 L
.012 .14039 L
.016 .14037 L
.02 .14054 L
.024 .14088 L
.028 .14103 L
.032 .14115 L
.036 .14119 L
.04 .14119 L
.044 .14103 L
.048 .14076 L
.052 .14042 L
.056 .14009 L
.06 .13981 L
.064 .13964 L
.068 .13958 L
.072 .13969 L
.076 .14 L
.08 .14045 L
.084 .14087 L
.088 .14126 L
.092 .14161 L
.096 .14191 L
.1 .14201 L
.104 .14189 L
.108 .14163 L
.112 .14136 L
.116 .14108 L
.12 .14074 L
.124 .1403 L
.128 .13982 L
.132 .13945 L
.136 .1392 L
.14 .13897 L
.144 .13868 L
.148 .13837 L
.152 .13818 L
.156 .13821 L
.16 .13846 L
.164 .13878 L
.168 .13907 L
.172 .13935 L
.176 .13981 L
.18 .14061 L
.184 .14175 L
.188 .14302 L
.192 .14422 L
.196 .14535 L
.2 .14663 L
Mistroke
.204 .14834 L
.208 .15051 L
.212 .15281 L
.216 .15485 L
.22 .15643 L
.224 .15773 L
.228 .15911 L
.232 .16082 L
.236 .16285 L
.24 .16494 L
.244 .16683 L
.248 .16841 L
.252 .16974 L
.256 .17097 L
.26 .17227 L
.264 .17384 L
.268 .17587 L
.272 .17845 L
.276 .1815 L
.28 .18472 L
.284 .18766 L
.288 .18997 L
.292 .19155 L
.296 .1926 L
.3 .1935 L
.304 .19461 L
.308 .19612 L
.312 .19807 L
.316 .20044 L
.32 .20328 L
.324 .20671 L
.328 .21086 L
.332 .21574 L
.336 .22117 L
.34 .22686 L
.344 .23251 L
.348 .23799 L
.352 .24332 L
.356 .24868 L
.36 .25425 L
.364 .2601 L
.368 .26612 L
.372 .27212 L
.376 .27785 L
.38 .28321 L
.384 .28823 L
.388 .29309 L
.392 .29805 L
.396 .3033 L
.4 .30892 L
Mistroke
.404 .31483 L
.408 .32083 L
.412 .32667 L
.416 .33216 L
.42 .33721 L
.424 .34187 L
.428 .3463 L
.432 .35073 L
.436 .3554 L
.44 .36048 L
.444 .36606 L
.448 .37212 L
.452 .37855 L
.456 .38516 L
.46 .39173 L
.464 .39804 L
.468 .4039 L
.472 .40916 L
.476 .41375 L
.48 .41763 L
.484 .42082 L
.488 .42339 L
.492 .42541 L
.496 .42695 L
.5 .42811 L
.504 .42896 L
.508 .42957 L
.512 .43 L
.516 .43029 L
.52 .4305 L
.524 .43065 L
.528 .43075 L
.532 .43082 L
.536 .43086 L
.54 .4309 L
.544 .43092 L
.548 .43094 L
.552 .43096 L
.556 .43098 L
.56 .43099 L
.564 .43101 L
.568 .43102 L
.572 .43103 L
.576 .43104 L
.58 .43106 L
.584 .43107 L
.588 .43109 L
.592 .4311 L
.596 .43111 L
.6 .43112 L
Mistroke
.604 .43114 L
.608 .43115 L
.612 .43116 L
.616 .43118 L
.62 .43119 L
.624 .4312 L
.628 .43122 L
.632 .43123 L
.636 .43124 L
.64 .43126 L
.644 .43127 L
.648 .43128 L
.652 .43129 L
.656 .43131 L
.66 .43132 L
.664 .43134 L
.668 .43135 L
.672 .43136 L
.676 .43137 L
.68 .43139 L
.684 .4314 L
.688 .43141 L
.692 .43143 L
.696 .43144 L
.7 .43145 L
.704 .43147 L
.708 .43148 L
.712 .43149 L
.716 .43151 L
.72 .43152 L
.724 .43153 L
.728 .43154 L
.732 .43156 L
.736 .43157 L
.74 .43159 L
.744 .4316 L
.748 .43161 L
.752 .43162 L
.756 .43164 L
.76 .43165 L
.764 .43167 L
.768 .43168 L
.772 .43169 L
.776 .4317 L
.78 .43172 L
.784 .43173 L
.788 .43174 L
.792 .43176 L
.796 .43177 L
.8 .43178 L
Mistroke
.804 .43179 L
.808 .43181 L
.812 .43182 L
.816 .43184 L
.82 .43185 L
.824 .43186 L
.828 .43187 L
.832 .43189 L
.836 .4319 L
.84 .43192 L
.844 .43193 L
.848 .43194 L
.852 .43195 L
.856 .43197 L
.86 .43198 L
.864 .43199 L
.868 .43201 L
.872 .43202 L
.876 .43203 L
.88 .43205 L
.884 .43206 L
.888 .43207 L
.892 .43208 L
.896 .4321 L
.9 .43211 L
.904 .43212 L
.908 .43214 L
.912 .43215 L
.916 .43216 L
.92 .43218 L
.924 .43219 L
.928 .4322 L
.932 .43221 L
.936 .43223 L
.94 .43224 L
.944 .43226 L
.948 .43226 L
.952 .43228 L
.956 .43229 L
.96 .43231 L
.964 .43232 L
.968 .43234 L
.972 .43234 L
.976 .43237 L
.98 .43237 L
.984 .4324 L
.988 .43239 L
.992 .43242 L
.996 .43241 L
1 .43245 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16339 L
.012 .16147 L
.016 .16081 L
.02 .16158 L
.024 .16181 L
.028 .16161 L
.032 .16144 L
.036 .16144 L
.04 .16134 L
.044 .16123 L
.048 .16106 L
.052 .1609 L
.056 .16076 L
.06 .16067 L
.064 .16057 L
.068 .16048 L
.072 .16049 L
.076 .16067 L
.08 .16091 L
.084 .16122 L
.088 .16156 L
.092 .16201 L
.096 .16248 L
.1 .16284 L
.104 .16293 L
.108 .1628 L
.112 .16256 L
.116 .16221 L
.12 .16165 L
.124 .1609 L
.128 .16012 L
.132 .15952 L
.136 .15915 L
.14 .15893 L
.144 .1587 L
.148 .15847 L
.152 .15837 L
.156 .1585 L
.16 .15879 L
.164 .15912 L
.168 .15936 L
.172 .15959 L
.176 .16008 L
.18 .16106 L
.184 .16251 L
.188 .16419 L
.192 .16577 L
.196 .16724 L
.2 .16888 L
Mistroke
.204 .171 L
.208 .17364 L
.212 .17645 L
.216 .17891 L
.22 .18084 L
.224 .18245 L
.228 .1842 L
.232 .18639 L
.236 .18897 L
.24 .19161 L
.244 .19397 L
.248 .19591 L
.252 .19751 L
.256 .19898 L
.26 .20056 L
.264 .20251 L
.268 .20504 L
.272 .20829 L
.276 .21214 L
.28 .21617 L
.284 .21984 L
.288 .22268 L
.292 .22459 L
.296 .22584 L
.3 .22693 L
.304 .22831 L
.308 .23022 L
.312 .23268 L
.316 .23565 L
.32 .23919 L
.324 .24343 L
.328 .24856 L
.332 .25459 L
.336 .26132 L
.34 .26839 L
.344 .27544 L
.348 .28228 L
.352 .28892 L
.356 .29559 L
.36 .30249 L
.364 .30973 L
.368 .31719 L
.372 .32462 L
.376 .33175 L
.38 .33841 L
.384 .34466 L
.388 .3507 L
.392 .35685 L
.396 .36335 L
.4 .3703 L
Mistroke
.404 .37761 L
.408 .38504 L
.412 .39229 L
.416 .39911 L
.42 .40538 L
.424 .41115 L
.428 .41662 L
.432 .42208 L
.436 .42784 L
.44 .43412 L
.444 .44103 L
.448 .44855 L
.452 .45653 L
.456 .46472 L
.46 .47285 L
.464 .48065 L
.468 .48788 L
.472 .49438 L
.476 .50004 L
.48 .50483 L
.484 .50876 L
.488 .51191 L
.492 .51435 L
.496 .51621 L
.5 .51759 L
.504 .51858 L
.508 .51928 L
.512 .51976 L
.516 .52008 L
.52 .52028 L
.524 .5204 L
.528 .52045 L
.532 .52047 L
.536 .52047 L
.54 .52046 L
.544 .52043 L
.548 .5204 L
.552 .52036 L
.556 .52032 L
.56 .52027 L
.564 .52023 L
.568 .52019 L
.572 .52015 L
.576 .5201 L
.58 .52006 L
.584 .52001 L
.588 .51997 L
.592 .51992 L
.596 .51988 L
.6 .51984 L
Mistroke
.604 .51979 L
.608 .51975 L
.612 .5197 L
.616 .51966 L
.62 .51962 L
.624 .51957 L
.628 .51953 L
.632 .51948 L
.636 .51944 L
.64 .5194 L
.644 .51935 L
.648 .51931 L
.652 .51926 L
.656 .51922 L
.66 .51918 L
.664 .51913 L
.668 .51909 L
.672 .51904 L
.676 .519 L
.68 .51896 L
.684 .51891 L
.688 .51887 L
.692 .51882 L
.696 .51878 L
.7 .51873 L
.704 .51869 L
.708 .51865 L
.712 .5186 L
.716 .51856 L
.72 .51851 L
.724 .51847 L
.728 .51843 L
.732 .51838 L
.736 .51834 L
.74 .51829 L
.744 .51825 L
.748 .5182 L
.752 .51816 L
.756 .51812 L
.76 .51807 L
.764 .51803 L
.768 .51798 L
.772 .51794 L
.776 .51789 L
.78 .51785 L
.784 .51781 L
.788 .51776 L
.792 .51771 L
.796 .51767 L
.8 .51763 L
Mistroke
.804 .51759 L
.808 .51754 L
.812 .51749 L
.816 .51745 L
.82 .5174 L
.824 .51736 L
.828 .51732 L
.832 .51728 L
.836 .51723 L
.84 .51718 L
.844 .51714 L
.848 .5171 L
.852 .51705 L
.856 .51701 L
.86 .51696 L
.864 .51692 L
.868 .51687 L
.872 .51683 L
.876 .51679 L
.88 .51674 L
.884 .5167 L
.888 .51665 L
.892 .51661 L
.896 .51657 L
.9 .51652 L
.904 .51648 L
.908 .51643 L
.912 .51639 L
.916 .51634 L
.92 .5163 L
.924 .51625 L
.928 .51621 L
.932 .51616 L
.936 .51612 L
.94 .51607 L
.944 .51604 L
.948 .51598 L
.952 .51595 L
.956 .51589 L
.96 .51586 L
.964 .5158 L
.968 .51577 L
.972 .51571 L
.976 .51569 L
.98 .51562 L
.984 .5156 L
.988 .51553 L
.992 .51551 L
.996 .51544 L
1 .51542 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2000ZOol20011Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0`0017oo0`000goo0`0017oo
0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool0
1000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009o
o`03001oogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol00Woo00<007oo00000P0000Aoo`00Oomoo`8000Aoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`04001o
ogooOol300000goo000000020002Ool20004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool00goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Ao
o`03001oogoo00]oo`@000=oo`04001oogoo0007Ool01@00Oomoo`00Ool00P0000Eoo`00Oomoo`00
009oo`8000Aoo`04001oogooOol40003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2
000:Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P000Woo
00<007oo00000Woo00@007ooOol0009oo`03001oo`00009oo`8000=oo`03001oogoo00Aoo`04001o
ogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo
001oo`0000Ioo`04001oogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`<000=oo`8000Aoo`80
009oo`05001oogooOol00003Ool50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003
Ool20006Ool0029oo`03001oogoo01eoo`03001oogoo00eoo`8003eoo`008Woo0P002Woo00<007oo
Ool04Goo00<007ooOol03Woo0`00>goo000ROomS000<Ool0029oo`03001oo`000080009oo`80009o
o`<0009oo`05001oogooOol00003Ool01000Oomoo`000goo0P000Woo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`0:Ool0
029oo`8000=oo`800005Ool00000Ool00002Ool200000goo001oo`0<Ool00`00Oomoo`1=Ool0029o
o`03001oogoo00Ioo`8000Ioo`8000aoo`03001oogoo04eoo`008Woo0P0047oo00<007oo00000Woo
0`0000=oo`00Ool00Woo00<007ooOol0CGoo000ROol2000AOol40002Ool2000017oo001oo`00D7oo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0JOol2001@Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`00
2goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03
Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0
029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool2
0003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029o
o`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04
001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P00
0goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`03001oogoo00]oo`8005Uoo`004Goo0P002Woo0P0017oo00<007ooOol00Woo3P0000=o
o`0000000`00EGoo000XOol00`00Oomoo`0@Ool3001COol002Qoo`03001oogoo019oo`@0051oo`00
2goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol05Goo0P00Cgoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol001Uoo`80
04eoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Ool001]oo`8004]oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo
1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007oo
Ool000Moo`8000=oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001o
ogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo0000
0Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomo
o`05Ool30002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002
Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=
Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo00000Woo00@007ooOol0009oo`04001oogoo
0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo
000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00H007ooOol007oo0002Ool01000Oomo
o`000Woo00D007ooOomoo`0000=oo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<0
07ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`80009oo`<0009oo`04001oogoo0002Ool0
0`00Oomoo`020003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo
00Uoo`D000=oo`8000Qoo`06001oogooOol007oo0P0017oo0P0017oo00@007ooOomoo`D000=oo`80
00=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol087oo00<0
07ooOol0@goo000XOol00`00Oomoo`0QOol00`00Oomoo`12Ool002Qooed000aoo`00:7oo00<007oo
Ool03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007oo
Ool02Woo000XOol00`00Oomoo`0SOol00`00Oomoo`10Ool002Qoo`03001oogoo02Aoo`03001oogoo
03moo`00:7oo00<007ooOol097oo0P00@7oo000XOol00`00Oomoo`0UOol2000oOol002Qoo`03001o
ogoo02Ioo`03001oogoo03eoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo
00<007ooOol09goo00<007ooOol0?7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001o
ogoo001oo`000goo00@007ooOol002Uoo`8003eoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOol002Yoo`03001oogoo03]oo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00:Woo00<007ooOol0>Woo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`0ZOol`000<Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol0
00]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Io
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool0
1000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`00
2Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo
00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004
Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005
Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007oo
Ool0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06
001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<0
07ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001o
ogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool0
01aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo
00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0
01aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003
Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000Woo0P000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo
00<007ooOol02Woo000LOol00`00Oomoo`0COol2001MOol001aoo`8001Ioo`8005]oo`0077oo00<0
07ooOol05Woo0`00FGoo000LOol00`00Oomoo`0IOol00`00Oomoo`1FOol001aoo`8001]oo`8005Io
o`0077oo00<007ooOol06goo0`00E7oo000LOol00`00Oomoo`0MOol2001COol001aoo`80021oo`03
001oogoo051oo`0077oo00<007ooOol087oo00<007ooOol0Cgoo000LOol2000QOol00`00Oomoo`1?
Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo025oo`03001oogoo04ioo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0QOol2001?Ool000Yoo`04001oogoo
000;Ool00`00Oomoo`02000SOol00`00Oomoo`1=Ool000Yoo`04001oogoo000;Ool01000Oomoo`00
97oo00<007ooOol0CGoo000:Ool01000Oomoo`001goo10000goo00<007ooOol08goo00<007ooOol0
C7oo000:Ool01000Oomoo`001goo00<007ooOol017oo0P009Goo00<007ooOol0Bgoo000;Ool20008
Ool50002Ool00`00Oomoo`0TOol00`00Oomoo`1;Ool001aoo`03001oogoo02Aoo`8004aoo`0077oo
0P009Woo0P00Bgoo000LOol00`00Oomoo`0VOol00`00Oomoo`19Ool001aoo`8002Qoo`03001oogoo
04Qoo`0077oo00<007ooOol09goo00<007ooOol0B7oo000LOol00`00Oomoo`0XOol00`00Oomoo`17
Ool001aoo`8002Uoo`03001oogoo04Moo`005Woo0`000goo00<007ooOol0:Goo00<007ooOol0AWoo
000GOol00`00Oomoo`02Ool00`00Oomoo`0YOol20017Ool001Moo`03001oogoo009oo`8002]oo`80
04Ioo`005goo00<007ooOol00Woo00<007ooOol0:goo00<007ooOol0A7oo000GOol00`00Oomoo`02
Ool00`00Oomoo`0/Ool00`00Oomoo`13Ool001Ioo`8000Aoo`8002eoo`03001oogoo04=oo`005goo
00<007ooOol00Woo00<007ooOol0;7oo0P00A7oo000LOol00`00Oomoo`0]Ool00`00Oomoo`12Ool0
01aoo`8002moo`03001oogoo045oo`0077oo00<007ooOol0;Woo00<007ooOol0@Goo000LOol2000`
Ool00`00Oomoo`10Ool001aoo`03001oogoo031oocH000aoo`0077oo00<007ooOol0LWoo000:Ool3
0004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]o
o`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009
Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(14529\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3064 m
.008 .30791 L
.012 .31242 L
.016 .31842 L
.02 .32437 L
.024 .32964 L
.028 .33265 L
.032 .33247 L
.036 .32916 L
.04 .32362 L
.044 .31745 L
.048 .3124 L
.052 .30959 L
.056 .30966 L
.06 .31247 L
.064 .31736 L
.068 .32234 L
.072 .32502 L
.076 .32478 L
.08 .32221 L
.084 .3183 L
.088 .31352 L
.092 .3098 L
.096 .30975 L
.1 .31411 L
.104 .32137 L
.108 .32875 L
.112 .33458 L
.116 .3377 L
.12 .33734 L
.124 .33271 L
.128 .32414 L
.132 .31427 L
.136 .30648 L
.14 .30276 L
.144 .30274 L
.148 .30507 L
.152 .30847 L
.156 .31221 L
.16 .31586 L
.164 .31866 L
.168 .31981 L
.172 .319 L
.176 .31693 L
.18 .31538 L
.184 .31632 L
.188 .32022 L
.192 .32536 L
.196 .32928 L
.2 .33101 L
Mistroke
.204 .33224 L
.208 .33576 L
.212 .34222 L
.216 .34896 L
.22 .3523 L
.224 .35101 L
.228 .34778 L
.232 .347 L
.236 .35063 L
.24 .35658 L
.244 .36052 L
.248 .35947 L
.252 .3539 L
.256 .34689 L
.26 .34146 L
.264 .339 L
.268 .33944 L
.272 .34231 L
.276 .34709 L
.28 .35264 L
.284 .35664 L
.288 .35655 L
.292 .35151 L
.296 .34376 L
.3 .3379 L
.304 .33821 L
.308 .3458 L
.312 .35769 L
.316 .36854 L
.32 .37374 L
.324 .37182 L
.328 .36467 L
.332 .35568 L
.336 .3473 L
.34 .33976 L
.344 .33149 L
.348 .32084 L
.352 .30759 L
.356 .29338 L
.36 .28084 L
.364 .27201 L
.368 .26724 L
.372 .26506 L
.376 .26308 L
.38 .25936 L
.384 .2534 L
.388 .24636 L
.392 .24036 L
.396 .23736 L
.4 .23802 L
Mistroke
.404 .24136 L
.408 .24505 L
.412 .24649 L
.416 .24399 L
.42 .23762 L
.424 .22929 L
.428 .22191 L
.432 .21821 L
.436 .21953 L
.44 .22521 L
.444 .23292 L
.448 .23958 L
.452 .24261 L
.456 .2408 L
.46 .23458 L
.464 .22556 L
.468 .21578 L
.472 .20703 L
.476 .20048 L
.48 .1967 L
.484 .19595 L
.488 .19836 L
.492 .2039 L
.496 .21232 L
.5 .22295 L
.504 .23474 L
.508 .24651 L
.512 .25729 L
.516 .26653 L
.52 .27417 L
.524 .28046 L
.528 .28573 L
.532 .29018 L
.536 .29383 L
.54 .29659 L
.544 .29845 L
.548 .29951 L
.552 .30004 L
.556 .30037 L
.56 .30071 L
.564 .30115 L
.568 .30162 L
.572 .30196 L
.576 .30205 L
.58 .30188 L
.584 .30161 L
.588 .30142 L
.592 .30146 L
.596 .30172 L
.6 .30202 L
Mistroke
.604 .30215 L
.608 .30202 L
.612 .30172 L
.616 .30145 L
.62 .30141 L
.624 .30164 L
.628 .30197 L
.632 .30215 L
.636 .30204 L
.64 .30171 L
.644 .30141 L
.648 .30138 L
.652 .30165 L
.656 .30199 L
.66 .30215 L
.664 .30198 L
.668 .30163 L
.672 .30138 L
.676 .30142 L
.68 .30172 L
.684 .30203 L
.688 .30209 L
.692 .30186 L
.696 .30152 L
.7 .30136 L
.704 .3015 L
.708 .30183 L
.712 .30206 L
.716 .302 L
.72 .30169 L
.724 .30141 L
.728 .30139 L
.732 .30166 L
.736 .30195 L
.74 .30202 L
.744 .3018 L
.748 .3015 L
.752 .30139 L
.756 .30155 L
.76 .30182 L
.764 .30197 L
.768 .30186 L
.772 .3016 L
.776 .30143 L
.78 .30149 L
.784 .30171 L
.788 .30189 L
.792 .30187 L
.796 .30167 L
.8 .30148 L
Mistroke
.804 .30146 L
.808 .30163 L
.812 .30182 L
.816 .30185 L
.82 .30171 L
.824 .30151 L
.828 .30145 L
.832 .30159 L
.836 .30177 L
.84 .30183 L
.844 .30171 L
.848 .30152 L
.852 .30145 L
.856 .30157 L
.86 .30175 L
.864 .30179 L
.868 .30168 L
.872 .30151 L
.876 .30146 L
.88 .30158 L
.884 .30173 L
.888 .30175 L
.892 .30164 L
.896 .3015 L
.9 .30147 L
.904 .30161 L
.908 .30172 L
.912 .30169 L
.916 .30158 L
.92 .30149 L
.924 .3015 L
.928 .30163 L
.932 .30171 L
.936 .30163 L
.94 .30152 L
.944 .30149 L
.948 .30154 L
.952 .30165 L
.956 .30168 L
.96 .30155 L
.964 .30147 L
.968 .30152 L
.972 .30159 L
.976 .30166 L
.98 .30162 L
.984 .30147 L
.988 .30144 L
.992 .30156 L
.996 .30164 L
1 .30163 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13828 m
.008 .14118 L
.012 .14208 L
.016 .14104 L
.02 .14059 L
.024 .14082 L
.028 .14081 L
.032 .14066 L
.036 .1406 L
.04 .14073 L
.044 .14088 L
.048 .14107 L
.052 .14125 L
.056 .14145 L
.06 .14156 L
.064 .14159 L
.068 .14145 L
.072 .1412 L
.076 .14091 L
.08 .14062 L
.084 .14032 L
.088 .14008 L
.092 .14 L
.096 .14013 L
.1 .14036 L
.104 .14065 L
.108 .14096 L
.112 .14135 L
.116 .14175 L
.12 .14206 L
.124 .14218 L
.128 .14217 L
.132 .14212 L
.136 .14204 L
.14 .14183 L
.144 .14146 L
.148 .14097 L
.152 .14049 L
.156 .14011 L
.16 .1398 L
.164 .13946 L
.168 .13908 L
.172 .13874 L
.176 .13859 L
.18 .13867 L
.184 .13889 L
.188 .13909 L
.192 .13919 L
.196 .13931 L
.2 .13967 L
Mistroke
.204 .14043 L
.208 .14149 L
.212 .1426 L
.216 .14358 L
.22 .14456 L
.224 .14582 L
.228 .14758 L
.232 .14976 L
.236 .15198 L
.24 .15389 L
.244 .15541 L
.248 .15673 L
.252 .15819 L
.256 .15995 L
.26 .16197 L
.264 .16404 L
.268 .16597 L
.272 .16765 L
.276 .16905 L
.28 .17025 L
.284 .17139 L
.288 .17272 L
.292 .17452 L
.296 .17696 L
.3 .17998 L
.304 .18326 L
.308 .18633 L
.312 .1888 L
.316 .19056 L
.32 .19178 L
.324 .19278 L
.328 .19389 L
.332 .19525 L
.336 .19692 L
.34 .19892 L
.344 .20135 L
.348 .20437 L
.352 .20813 L
.356 .21267 L
.36 .21782 L
.364 .22331 L
.368 .22884 L
.372 .23425 L
.376 .23955 L
.38 .24489 L
.384 .25042 L
.388 .25623 L
.392 .26224 L
.396 .26826 L
.4 .27407 L
Mistroke
.404 .27953 L
.408 .28463 L
.412 .28953 L
.416 .29445 L
.42 .29961 L
.424 .30511 L
.428 .31094 L
.432 .31693 L
.436 .32285 L
.44 .32849 L
.444 .33372 L
.448 .33852 L
.452 .34302 L
.456 .3474 L
.46 .35192 L
.464 .35678 L
.468 .36211 L
.472 .36794 L
.476 .3742 L
.48 .38074 L
.484 .38735 L
.488 .39382 L
.492 .39995 L
.496 .40558 L
.5 .4106 L
.504 .41494 L
.508 .41859 L
.512 .42158 L
.516 .42397 L
.52 .42584 L
.524 .42727 L
.528 .42834 L
.532 .42913 L
.536 .4297 L
.54 .4301 L
.544 .43038 L
.548 .43058 L
.552 .43071 L
.556 .4308 L
.56 .43087 L
.564 .43092 L
.568 .43095 L
.572 .43098 L
.576 .431 L
.58 .43101 L
.584 .43103 L
.588 .43105 L
.592 .43106 L
.596 .43107 L
.6 .43109 L
Mistroke
.604 .4311 L
.608 .43111 L
.612 .43113 L
.616 .43114 L
.62 .43115 L
.624 .43117 L
.628 .43118 L
.632 .43119 L
.636 .43121 L
.64 .43122 L
.644 .43123 L
.648 .43125 L
.652 .43126 L
.656 .43127 L
.66 .43128 L
.664 .4313 L
.668 .43131 L
.672 .43132 L
.676 .43134 L
.68 .43135 L
.684 .43136 L
.688 .43138 L
.692 .43139 L
.696 .4314 L
.7 .43142 L
.704 .43143 L
.708 .43144 L
.712 .43146 L
.716 .43147 L
.72 .43148 L
.724 .4315 L
.728 .43151 L
.732 .43152 L
.736 .43153 L
.74 .43155 L
.744 .43156 L
.748 .43158 L
.752 .43159 L
.756 .4316 L
.76 .43161 L
.764 .43163 L
.768 .43164 L
.772 .43165 L
.776 .43167 L
.78 .43168 L
.784 .43169 L
.788 .43171 L
.792 .43172 L
.796 .43173 L
.8 .43175 L
Mistroke
.804 .43176 L
.808 .43177 L
.812 .43178 L
.816 .4318 L
.82 .43181 L
.824 .43182 L
.828 .43184 L
.832 .43185 L
.836 .43186 L
.84 .43188 L
.844 .43189 L
.848 .4319 L
.852 .43191 L
.856 .43193 L
.86 .43194 L
.864 .43196 L
.868 .43197 L
.872 .43198 L
.876 .43199 L
.88 .43201 L
.884 .43202 L
.888 .43204 L
.892 .43205 L
.896 .43206 L
.9 .43207 L
.904 .43209 L
.908 .4321 L
.912 .43212 L
.916 .43212 L
.92 .43214 L
.924 .43215 L
.928 .43217 L
.932 .43218 L
.936 .4322 L
.94 .4322 L
.944 .43222 L
.948 .43223 L
.952 .43225 L
.956 .43225 L
.96 .43228 L
.964 .43228 L
.968 .4323 L
.972 .4323 L
.976 .43233 L
.98 .43233 L
.984 .43236 L
.988 .43235 L
.992 .43238 L
.996 .43238 L
1 .43241 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16095 L
.012 .16093 L
.016 .16075 L
.02 .16064 L
.024 .16073 L
.028 .16097 L
.032 .16111 L
.036 .16128 L
.04 .16143 L
.044 .1616 L
.048 .16163 L
.052 .16163 L
.056 .16158 L
.06 .16156 L
.064 .16148 L
.068 .16137 L
.072 .16122 L
.076 .16111 L
.08 .16096 L
.084 .16075 L
.088 .16051 L
.092 .16035 L
.096 .16033 L
.1 .16045 L
.104 .16061 L
.108 .1609 L
.112 .16136 L
.116 .16197 L
.12 .16248 L
.124 .1628 L
.128 .16291 L
.132 .1629 L
.136 .16276 L
.14 .16242 L
.144 .16183 L
.148 .1611 L
.152 .16045 L
.156 .15997 L
.16 .15963 L
.164 .1593 L
.168 .15892 L
.172 .15856 L
.176 .15839 L
.18 .15846 L
.184 .15868 L
.188 .15886 L
.192 .15893 L
.196 .15904 L
.2 .1595 L
Mistroke
.204 .16049 L
.208 .16187 L
.212 .16331 L
.216 .16457 L
.22 .16578 L
.224 .16731 L
.228 .16946 L
.232 .17212 L
.236 .17486 L
.24 .17724 L
.244 .17915 L
.248 .18085 L
.252 .18271 L
.256 .18492 L
.26 .18743 L
.264 .18998 L
.268 .19233 L
.272 .19438 L
.276 .19611 L
.28 .1976 L
.284 .19905 L
.288 .20074 L
.292 .203 L
.296 .20604 L
.3 .20978 L
.304 .21383 L
.308 .21761 L
.312 .22066 L
.316 .22285 L
.32 .22438 L
.324 .22566 L
.328 .22704 L
.332 .22873 L
.336 .23079 L
.34 .23324 L
.344 .23623 L
.348 .23998 L
.352 .24466 L
.356 .25032 L
.36 .25675 L
.364 .26358 L
.368 .27045 L
.372 .27716 L
.376 .28373 L
.38 .29035 L
.384 .29722 L
.388 .30444 L
.392 .31193 L
.396 .31941 L
.4 .32663 L
Mistroke
.404 .33339 L
.408 .33971 L
.412 .34577 L
.416 .35187 L
.42 .35827 L
.424 .36511 L
.428 .37234 L
.432 .37978 L
.436 .38712 L
.44 .3941 L
.444 .40056 L
.448 .4065 L
.452 .41206 L
.456 .41749 L
.46 .42309 L
.464 .4291 L
.468 .4357 L
.472 .44291 L
.476 .45065 L
.48 .45874 L
.484 .46694 L
.488 .47496 L
.492 .48255 L
.496 .48951 L
.5 .4957 L
.504 .50104 L
.508 .50553 L
.512 .5092 L
.516 .51212 L
.52 .5144 L
.524 .51612 L
.528 .5174 L
.532 .51831 L
.536 .51896 L
.54 .5194 L
.544 .51969 L
.548 .51988 L
.552 .51999 L
.556 .52004 L
.56 .52006 L
.564 .52006 L
.568 .52004 L
.572 .52001 L
.576 .51998 L
.58 .51994 L
.584 .5199 L
.588 .51986 L
.592 .51981 L
.596 .51977 L
.6 .51973 L
Mistroke
.604 .51968 L
.608 .51964 L
.612 .51959 L
.616 .51955 L
.62 .51951 L
.624 .51946 L
.628 .51942 L
.632 .51937 L
.636 .51933 L
.64 .51928 L
.644 .51924 L
.648 .5192 L
.652 .51915 L
.656 .51911 L
.66 .51907 L
.664 .51902 L
.668 .51898 L
.672 .51893 L
.676 .51889 L
.68 .51885 L
.684 .5188 L
.688 .51876 L
.692 .51871 L
.696 .51867 L
.7 .51862 L
.704 .51858 L
.708 .51854 L
.712 .51849 L
.716 .51845 L
.72 .5184 L
.724 .51836 L
.728 .51831 L
.732 .51827 L
.736 .51823 L
.74 .51818 L
.744 .51814 L
.748 .51809 L
.752 .51805 L
.756 .51801 L
.76 .51796 L
.764 .51792 L
.768 .51787 L
.772 .51783 L
.776 .51778 L
.78 .51774 L
.784 .5177 L
.788 .51765 L
.792 .51761 L
.796 .51756 L
.8 .51752 L
Mistroke
.804 .51747 L
.808 .51743 L
.812 .51739 L
.816 .51734 L
.82 .51729 L
.824 .51725 L
.828 .51721 L
.832 .51717 L
.836 .51712 L
.84 .51707 L
.844 .51703 L
.848 .51699 L
.852 .51694 L
.856 .5169 L
.86 .51685 L
.864 .51681 L
.868 .51676 L
.872 .51672 L
.876 .51668 L
.88 .51663 L
.884 .51659 L
.888 .51654 L
.892 .5165 L
.896 .51646 L
.9 .51641 L
.904 .51637 L
.908 .51632 L
.912 .51628 L
.916 .51623 L
.92 .51619 L
.924 .51614 L
.928 .5161 L
.932 .51605 L
.936 .51602 L
.94 .51596 L
.944 .51593 L
.948 .51587 L
.952 .51584 L
.956 .51578 L
.96 .51575 L
.964 .51569 L
.968 .51566 L
.972 .5156 L
.976 .51558 L
.98 .51551 L
.984 .51549 L
.988 .51542 L
.992 .5154 L
.996 .51533 L
1 .51532 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0;7oo00<007ooOol0?Goo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool2000]Ool2000nOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0`0000Ao
o`00Oomoo`<000=oo`<000Aoo`8000=oo`D000=oo`8000Aoo`8000Aoo`D0009oo`<000Aoo`8000Io
o`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0;
Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`05001oogoo001oo`020000
0goo00000002Ool01000Oomoo`000goo00D007ooOomoo`00009oo`04001oogoo0003Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoo`00Ool000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
47oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00800003Ool007oo
0080009oo`04001oogoo0007Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool500000goo000000020003Ool00`00Ool00007Ool01000
Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000Aoo`03001oogoo00]oo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool2
00001Goo001oogoo00000Woo00L007ooOomoo`00Ool00003Ool40003Ool01000Oomoo`000Woo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003Ool0
1000Oomoo`001Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool0
1000Oomoo`001Woo0P000goo0P000Woo00@007ooOol0009oo`04001oogooOol30003Ool00`00Oomo
o`04Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo
00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool50003Ool20008Ool01P00
Oomoogoo001oo`8000Aoo`8000Eoo`8000=oo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0
009oo`D000=oo`8000Ioo`008Woo00<007ooOol087oo00<007ooOol03Goo0P00>Woo000ROol2000Q
Ool00`00Oomoo`0>Ool2000iOol0029oof<000aoo`008Woo0`0000Eoo`00000007oo00<00004Ool0
0000Ool400000goo001oo`02Ool01000Oomoo`000goo00<007ooOol00P000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0000<Ool0029o
o`<00004Ool007ooOol200001Goo000007oo00000goo0`003Woo00<007ooOol0BWoo000ROol01000
Ool000001goo0P001goo00<007ooOol00goo00<007ooOol00P000Woo0P00C7oo000ROol2000COol3
00001Goo001oo`00Ool00P000Woo00<007ooOol0Bgoo000ROol2000DOol400001Goo00000000Ool0
0P00CWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0EOol00`00Oomo
o`04Ool2001>Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P007Goo
0P00CWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0
K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo
00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol0
0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2
000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00
Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
1000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<0
07ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@00
0Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:
Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
06Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo
00<007ooOol00Woo5P00Dgoo000XOol00`00Oomoo`0BOol4001@Ool002Qoo`03001oogoo01Eoo`<0
04ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol05goo0`00
C7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol0
01]oo`<004Yoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOol001eoo`<004Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol00P002goo0`0017oo0P001goo1@000Woo0P0017oo0P000goo0`000goo0`0017oo
0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo
00@007ooOol000Moo`06001oogoo001oo`000Woo00@007ooOol0009oo`05001oogooOol00003Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002
Ool00`00Oomoo`05Ool01000Oomoogoo0P000Woo00@007ooOol0009oo`05001oogooOol00007Ool0
1000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo
00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`04001oogooOol20002Ool01000Oomo
o`000Woo00D007ooOomoo`0000Moo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool200001Goo
001oogoo00000Woo00D007ooOomoo`0000=oo`@000=oo`06001oogoo001oo`000goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00
:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`800005Ool007ooOol0
0002Ool00`00Oomoo`020003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03
001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003
Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo029o
o`80049oo`00:7oo00<007ooOol08goo0P00@Goo000XOomM000<Ool002Qoo`03001oogoo00moo`03
001oogoo011oo`04001oogoo000>Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool0
02Qoo`03001oogoo02Eoo`8003moo`00:7oo00<007ooOol09Woo00<007ooOol0?Goo000XOol00`00
Oomoo`0WOol2000mOol002Qoo`03001oogoo02Qoo`03001oogoo03]oo`00:7oo00<007ooOol0:Goo
00<007ooOol0>Woo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomo
o`0YOol00`00Oomoo`0jOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0003Ool01000Oomoo`00;7oo00<007ooOol0>Goo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0005Ool01000Oomoo`00;7oo0P00>Woo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`02000/Ool2000iOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo02aoobh000aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P00
17oo0P000Woo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool0
0`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomo
o`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool0
0`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`00
1goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;
Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Ao
o`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Ao
o`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007oo
Ool00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003
Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<0
07ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000
Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo
0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2
000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol0
37oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo
0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@00
0goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Ao
o`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol0
0003Ool00`00Ool000020003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo
00Yoo`0077oo00<007ooOol05Woo0P00FWoo000LOol2000IOol2001HOol001aoo`03001oogoo01Uo
o`<005Ioo`0077oo00<007ooOol06goo0P00EGoo000LOol2000NOol00`00Oomoo`1BOol001aoo`03
001oogoo01ioo`<0055oo`0077oo00<007ooOol087oo0P00D7oo000LOol2000SOol00`00Oomoo`1=
Ool001aoo`03001oogoo029oo`03001oogoo04eoo`0077oo0P0097oo00<007ooOol0C7oo000;Ool2
0004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`0SOol2001=Ool000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol097oo00<007ooOol0Bgoo000:Ool01000Oomoo`002goo00<0
07ooOol00P009Goo0P00C7oo000:Ool01000Oomoo`002goo00@007ooOol002Moo`03001oogoo04Yo
o`002Woo00@007ooOol000Moo`@000=oo`03001oogoo02Ioo`03001oogoo04Uoo`002Woo00@007oo
Ool000Moo`03001oogoo00Aoo`8002Moo`8004Yoo`002goo0P0027oo1@000Woo00<007ooOol09goo
00<007ooOol0B7oo000LOol00`00Oomoo`0WOol20019Ool001aoo`8002Uoo`03001oogoo04Moo`00
77oo00<007ooOol0:Goo00<007ooOol0AWoo000LOol2000ZOol00`00Oomoo`16Ool001aoo`03001o
ogoo02Yoo`03001oogoo04Eoo`0077oo00<007ooOol0:Woo0P00AWoo000LOol2000/Ool00`00Oomo
o`14Ool001Ioo`<000=oo`03001oogoo02aoo`03001oogoo04=oo`005goo00<007ooOol00Woo00<0
07ooOol0;7oo0P00A7oo000GOol00`00Oomoo`02Ool2000^Ool00`00Oomoo`12Ool001Moo`03001o
ogoo009oo`03001oogoo02ioo`03001oogoo045oo`005goo00<007ooOol00Woo00<007ooOol0;Woo
00<007ooOol0@Goo000FOol20004Ool2000`Ool00`00Oomoo`10Ool001Moo`03001oogoo009oo`03
001oogoo02moo`03001oogoo041oo`0077oo00<007ooOol0<7oo00<007ooOol0?goo000LOol2000a
Ool00`00Oomoo`0oOol001aoo`03001oogoo035oo`03001oogoo03ioo`0077oo0P00<goo00<007oo
Ool0?Goo000LOol00`00Oomoo`0cOolc000<Ool001aoo`03001oogoo079oo`002Woo0`0017oo00<0
07ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomo
o`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007oo
Ool017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(14696\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .33495 m
.008 .33325 L
.012 .32774 L
.016 .31942 L
.02 .3109 L
.024 .30463 L
.028 .30287 L
.032 .30524 L
.036 .31108 L
.04 .31879 L
.044 .32606 L
.048 .33112 L
.052 .33242 L
.056 .32964 L
.06 .32408 L
.064 .31815 L
.068 .31376 L
.072 .31175 L
.076 .31263 L
.08 .31658 L
.084 .3219 L
.088 .32577 L
.092 .32634 L
.096 .32385 L
.1 .3195 L
.104 .31416 L
.108 .3092 L
.112 .30642 L
.116 .30771 L
.12 .31328 L
.124 .32103 L
.128 .32812 L
.132 .33287 L
.136 .33531 L
.14 .33524 L
.144 .33228 L
.148 .32669 L
.152 .32002 L
.156 .31439 L
.16 .31113 L
.164 .31008 L
.168 .31001 L
.172 .31002 L
.176 .31007 L
.18 .31075 L
.184 .31257 L
.188 .31499 L
.192 .31661 L
.196 .31635 L
.2 .31486 L
Mistroke
.204 .31432 L
.208 .31674 L
.212 .32172 L
.216 .32648 L
.22 .32856 L
.224 .32824 L
.228 .32839 L
.232 .33172 L
.236 .33783 L
.24 .34351 L
.244 .34598 L
.248 .34562 L
.252 .34554 L
.256 .34856 L
.26 .35419 L
.264 .35897 L
.268 .35942 L
.272 .35487 L
.276 .34789 L
.28 .34203 L
.284 .33941 L
.288 .33994 L
.292 .34233 L
.296 .34546 L
.3 .34867 L
.304 .3512 L
.308 .35182 L
.312 .34949 L
.316 .34463 L
.32 .33956 L
.324 .33745 L
.328 .34029 L
.332 .34741 L
.336 .35583 L
.34 .36216 L
.344 .36463 L
.348 .36387 L
.352 .36182 L
.356 .35978 L
.36 .35711 L
.364 .35158 L
.368 .3411 L
.372 .32556 L
.376 .30746 L
.38 .29081 L
.384 .27902 L
.388 .27306 L
.392 .27108 L
.396 .26961 L
.4 .26555 L
Mistroke
.404 .2579 L
.408 .2481 L
.412 .23912 L
.416 .23375 L
.42 .23312 L
.424 .23627 L
.428 .24068 L
.432 .24357 L
.436 .24308 L
.44 .23892 L
.444 .23221 L
.448 .22492 L
.452 .21904 L
.456 .21603 L
.46 .21645 L
.464 .22 L
.468 .22555 L
.472 .23146 L
.476 .23585 L
.48 .23712 L
.484 .23433 L
.488 .22756 L
.492 .21796 L
.496 .20738 L
.5 .19795 L
.504 .19139 L
.508 .18871 L
.512 .19012 L
.516 .19514 L
.52 .20296 L
.524 .21272 L
.528 .22363 L
.532 .23505 L
.536 .2464 L
.54 .25715 L
.544 .26682 L
.548 .27506 L
.552 .28169 L
.556 .28681 L
.56 .29068 L
.564 .29365 L
.568 .29603 L
.572 .29798 L
.576 .29949 L
.58 .30049 L
.584 .30098 L
.588 .30108 L
.592 .30107 L
.596 .30118 L
.6 .30149 L
Mistroke
.604 .30187 L
.608 .30211 L
.612 .30207 L
.616 .3018 L
.62 .3015 L
.624 .30142 L
.628 .30163 L
.632 .30197 L
.636 .30218 L
.64 .30208 L
.644 .30175 L
.648 .30146 L
.652 .30144 L
.656 .3017 L
.66 .30203 L
.664 .30215 L
.668 .30198 L
.672 .30164 L
.676 .30143 L
.68 .3015 L
.684 .3018 L
.688 .30207 L
.692 .30209 L
.696 .30183 L
.7 .30152 L
.704 .30142 L
.708 .30161 L
.712 .30192 L
.716 .30208 L
.72 .30195 L
.724 .30164 L
.728 .30144 L
.732 .30151 L
.736 .30179 L
.74 .302 L
.744 .30197 L
.748 .30174 L
.752 .30151 L
.756 .30149 L
.76 .30168 L
.764 .3019 L
.768 .30195 L
.772 .3018 L
.776 .30158 L
.78 .30149 L
.784 .30161 L
.788 .30181 L
.792 .30191 L
.796 .30182 L
.8 .30162 L
Mistroke
.804 .3015 L
.808 .30157 L
.812 .30176 L
.816 .30187 L
.82 .30182 L
.824 .30164 L
.828 .30151 L
.832 .30156 L
.836 .30172 L
.84 .30184 L
.844 .3018 L
.848 .30163 L
.852 .30152 L
.856 .30157 L
.86 .30171 L
.864 .3018 L
.868 .30175 L
.872 .30161 L
.876 .30152 L
.88 .30159 L
.884 .30171 L
.888 .30176 L
.892 .3017 L
.896 .30158 L
.9 .30153 L
.904 .30162 L
.908 .30171 L
.912 .30171 L
.916 .30165 L
.92 .30156 L
.924 .30156 L
.928 .30164 L
.932 .3017 L
.936 .30165 L
.94 .30159 L
.944 .30156 L
.948 .30159 L
.952 .30166 L
.956 .30167 L
.96 .30158 L
.964 .30155 L
.968 .30158 L
.972 .30162 L
.976 .30166 L
.98 .30163 L
.984 .30152 L
.988 .30153 L
.992 .30162 L
.996 .30165 L
1 .30163 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14091 m
.008 .14118 L
.012 .14131 L
.016 .14142 L
.02 .1414 L
.024 .14145 L
.028 .14152 L
.032 .14156 L
.036 .14149 L
.04 .14141 L
.044 .14129 L
.048 .14119 L
.052 .14107 L
.056 .141 L
.06 .14101 L
.064 .14112 L
.068 .14125 L
.072 .14143 L
.076 .14163 L
.08 .14183 L
.084 .14192 L
.088 .14189 L
.092 .14177 L
.096 .14161 L
.1 .14139 L
.104 .1411 L
.108 .14081 L
.112 .14062 L
.116 .14056 L
.12 .14059 L
.124 .14066 L
.128 .1408 L
.132 .14108 L
.136 .14147 L
.14 .14186 L
.144 .14216 L
.148 .14236 L
.152 .14252 L
.156 .14264 L
.16 .14266 L
.164 .14246 L
.168 .14207 L
.172 .14159 L
.176 .14114 L
.18 .14077 L
.184 .14042 L
.188 .14001 L
.192 .13956 L
.196 .13921 L
.2 .13909 L
Mistroke
.204 .13919 L
.208 .13935 L
.212 .13938 L
.216 .13929 L
.22 .13929 L
.224 .13963 L
.228 .14037 L
.232 .14134 L
.236 .14226 L
.24 .14305 L
.244 .1439 L
.248 .14513 L
.252 .14687 L
.256 .14896 L
.26 .15106 L
.264 .15288 L
.268 .1544 L
.272 .15581 L
.276 .15734 L
.28 .15912 L
.284 .16109 L
.288 .16313 L
.292 .16509 L
.296 .16685 L
.3 .16833 L
.304 .16952 L
.308 .17056 L
.312 .17171 L
.316 .17332 L
.32 .17561 L
.324 .17853 L
.328 .18176 L
.332 .18487 L
.336 .18747 L
.34 .18944 L
.344 .19089 L
.348 .19209 L
.352 .19326 L
.356 .19453 L
.36 .19596 L
.364 .19761 L
.368 .19963 L
.372 .20224 L
.376 .20562 L
.38 .20982 L
.384 .21468 L
.388 .21994 L
.392 .22531 L
.396 .23061 L
.4 .23582 L
Mistroke
.404 .24109 L
.408 .24657 L
.412 .25235 L
.416 .25835 L
.42 .26441 L
.424 .27029 L
.428 .27584 L
.432 .28102 L
.436 .28594 L
.44 .29084 L
.444 .29592 L
.448 .30133 L
.452 .30708 L
.456 .31304 L
.46 .31901 L
.464 .32477 L
.468 .33015 L
.472 .33511 L
.476 .33971 L
.48 .34411 L
.484 .34855 L
.488 .35322 L
.492 .35831 L
.496 .36388 L
.5 .36992 L
.504 .37632 L
.508 .38291 L
.512 .38949 L
.516 .39584 L
.52 .40178 L
.524 .40718 L
.528 .41195 L
.532 .41604 L
.536 .41947 L
.54 .42227 L
.544 .4245 L
.548 .42624 L
.552 .42757 L
.556 .42856 L
.56 .42929 L
.564 .42982 L
.568 .4302 L
.572 .43047 L
.576 .43065 L
.58 .43078 L
.584 .43087 L
.588 .43093 L
.592 .43097 L
.596 .43101 L
.6 .43103 L
Mistroke
.604 .43105 L
.608 .43107 L
.612 .43109 L
.616 .4311 L
.62 .43112 L
.624 .43113 L
.628 .43114 L
.632 .43115 L
.636 .43117 L
.64 .43118 L
.644 .4312 L
.648 .43121 L
.652 .43122 L
.656 .43123 L
.66 .43125 L
.664 .43126 L
.668 .43127 L
.672 .43129 L
.676 .4313 L
.68 .43131 L
.684 .43132 L
.688 .43134 L
.692 .43135 L
.696 .43137 L
.7 .43138 L
.704 .43139 L
.708 .4314 L
.712 .43142 L
.716 .43143 L
.72 .43145 L
.724 .43146 L
.728 .43147 L
.732 .43148 L
.736 .4315 L
.74 .43151 L
.744 .43152 L
.748 .43154 L
.752 .43155 L
.756 .43156 L
.76 .43157 L
.764 .43159 L
.768 .4316 L
.772 .43162 L
.776 .43163 L
.78 .43164 L
.784 .43165 L
.788 .43167 L
.792 .43168 L
.796 .4317 L
.8 .43171 L
Mistroke
.804 .43172 L
.808 .43173 L
.812 .43175 L
.816 .43176 L
.82 .43177 L
.824 .43179 L
.828 .4318 L
.832 .43181 L
.836 .43182 L
.84 .43184 L
.844 .43185 L
.848 .43187 L
.852 .43188 L
.856 .43189 L
.86 .4319 L
.864 .43192 L
.868 .43193 L
.872 .43195 L
.876 .43196 L
.88 .43197 L
.884 .43198 L
.888 .432 L
.892 .43201 L
.896 .43202 L
.9 .43203 L
.904 .43205 L
.908 .43206 L
.912 .43208 L
.916 .43209 L
.92 .4321 L
.924 .43211 L
.928 .43213 L
.932 .43214 L
.936 .43216 L
.94 .43216 L
.944 .43218 L
.948 .43219 L
.952 .43221 L
.956 .43221 L
.96 .43224 L
.964 .43224 L
.968 .43226 L
.972 .43226 L
.976 .43229 L
.98 .43229 L
.984 .43232 L
.988 .43231 L
.992 .43234 L
.996 .43234 L
1 .43237 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15934 L
.012 .16166 L
.016 .1624 L
.02 .16171 L
.024 .16132 L
.028 .16139 L
.032 .16123 L
.036 .16095 L
.04 .16078 L
.044 .16079 L
.048 .16083 L
.052 .16091 L
.056 .16102 L
.06 .16119 L
.064 .1613 L
.068 .16139 L
.072 .16142 L
.076 .16149 L
.08 .16156 L
.084 .16161 L
.088 .1616 L
.092 .16156 L
.096 .16151 L
.1 .1614 L
.104 .16114 L
.108 .16079 L
.112 .16049 L
.116 .16032 L
.12 .16023 L
.124 .16022 L
.128 .16035 L
.132 .16072 L
.136 .16127 L
.14 .16186 L
.144 .16231 L
.148 .16261 L
.152 .16281 L
.156 .16293 L
.16 .16288 L
.164 .16257 L
.168 .16203 L
.172 .16141 L
.176 .16087 L
.18 .16047 L
.184 .16008 L
.188 .15962 L
.192 .15908 L
.196 .15863 L
.2 .15844 L
Mistroke
.204 .15852 L
.208 .15867 L
.212 .1587 L
.216 .1586 L
.22 .15863 L
.224 .15909 L
.228 .16006 L
.232 .16128 L
.236 .16241 L
.24 .16336 L
.244 .16438 L
.248 .16588 L
.252 .16804 L
.256 .17067 L
.26 .17331 L
.264 .17561 L
.268 .17752 L
.272 .17927 L
.276 .18116 L
.28 .18334 L
.284 .18577 L
.288 .18829 L
.292 .19074 L
.296 .19296 L
.3 .19482 L
.304 .19632 L
.308 .1976 L
.312 .19902 L
.316 .201 L
.32 .20382 L
.324 .20744 L
.328 .21148 L
.332 .21535 L
.336 .2186 L
.34 .22105 L
.344 .22285 L
.348 .22432 L
.352 .22576 L
.356 .22732 L
.36 .22909 L
.364 .23114 L
.368 .23366 L
.372 .23691 L
.376 .24112 L
.38 .24632 L
.384 .25236 L
.388 .25889 L
.392 .26556 L
.396 .27214 L
.4 .27864 L
Mistroke
.404 .28519 L
.408 .29201 L
.412 .29918 L
.416 .30663 L
.42 .31414 L
.424 .32144 L
.428 .32832 L
.432 .33475 L
.436 .34088 L
.44 .34695 L
.444 .35325 L
.448 .35995 L
.452 .36707 L
.456 .37446 L
.46 .38187 L
.464 .38901 L
.468 .39569 L
.472 .40183 L
.476 .40751 L
.48 .41296 L
.484 .41843 L
.488 .42421 L
.492 .43051 L
.496 .43741 L
.5 .44489 L
.504 .45282 L
.508 .46098 L
.512 .46912 L
.516 .47698 L
.52 .48434 L
.524 .49101 L
.528 .4969 L
.532 .50194 L
.536 .50615 L
.54 .50957 L
.544 .51229 L
.548 .5144 L
.552 .516 L
.556 .51718 L
.56 .51803 L
.564 .51863 L
.568 .51904 L
.572 .51931 L
.576 .51948 L
.58 .51958 L
.584 .51963 L
.588 .51965 L
.592 .51964 L
.596 .51962 L
.6 .51959 L
Mistroke
.604 .51956 L
.608 .51952 L
.612 .51948 L
.616 .51944 L
.62 .51939 L
.624 .51935 L
.628 .51931 L
.632 .51926 L
.636 .51922 L
.64 .51917 L
.644 .51913 L
.648 .51909 L
.652 .51904 L
.656 .519 L
.66 .51896 L
.664 .51891 L
.668 .51886 L
.672 .51882 L
.676 .51878 L
.68 .51873 L
.684 .51869 L
.688 .51865 L
.692 .5186 L
.696 .51856 L
.7 .51851 L
.704 .51847 L
.708 .51843 L
.712 .51838 L
.716 .51834 L
.72 .51829 L
.724 .51825 L
.728 .5182 L
.732 .51816 L
.736 .51812 L
.74 .51807 L
.744 .51803 L
.748 .51798 L
.752 .51794 L
.756 .5179 L
.76 .51785 L
.764 .51781 L
.768 .51776 L
.772 .51772 L
.776 .51767 L
.78 .51763 L
.784 .51759 L
.788 .51754 L
.792 .5175 L
.796 .51745 L
.8 .51741 L
Mistroke
.804 .51736 L
.808 .51732 L
.812 .51728 L
.816 .51723 L
.82 .51718 L
.824 .51714 L
.828 .5171 L
.832 .51706 L
.836 .51701 L
.84 .51697 L
.844 .51692 L
.848 .51688 L
.852 .51683 L
.856 .51679 L
.86 .51674 L
.864 .5167 L
.868 .51665 L
.872 .51661 L
.876 .51657 L
.88 .51652 L
.884 .51648 L
.888 .51644 L
.892 .51639 L
.896 .51635 L
.9 .5163 L
.904 .51626 L
.908 .51621 L
.912 .51617 L
.916 .51612 L
.92 .51608 L
.924 .51603 L
.928 .51599 L
.932 .51594 L
.936 .51591 L
.94 .51585 L
.944 .51582 L
.948 .51576 L
.952 .51573 L
.956 .51567 L
.96 .51564 L
.964 .51558 L
.968 .51555 L
.972 .51549 L
.976 .51547 L
.98 .51541 L
.984 .51538 L
.988 .51531 L
.992 .51529 L
.996 .51522 L
1 .51521 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0;Woo0P00?7oo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool2000_Ool00`00Ool0000kOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P000Woo
00<007ooOol00`000goo0`0017oo0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P00
1Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
00]oo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`@0
0003Ool007oo009oo`05001oogooOol00003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo00H007ooOol007oo0003Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`02000017oo
001oogoo0`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol00Woo00D007ooOol007oo0080009oo`03001oogoo00=o
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol02goo10000goo00@007ooOol0
00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo0P000Woo10000goo00@007oo
Ool0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogooOol0
07oo10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo0P0037oo00<0
07ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oo`000002Ool01000Oomoo`0017oo0`000Woo
00<007ooOol017oo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P00
27oo00<007ooOol00goo0P0017oo0P001Woo00@007oo001oo`D000=oo`8000Aoo`<000Aoo`8000Ao
o`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol08goo00<007ooOol03Goo00<007oo
Ool0=Woo000ROol2000SOol00`00Oomoo`0?Ool2000fOol0029oof<000aoo`008Woo00H007oo001o
o`00Ool3000017oo000000000Woo1P000goo00@007ooOol000=oo`09001oogooOol007oo001oo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomo
o`0:Ool0029oo`<00005Ool007oo001oo`0300001Goo000007oo00001Goo0P003Goo00<007ooOol0
B7oo000ROol20003Ool20006Ool20008Ool00`00Oomoo`02Ool00`00Oomoo`020003Ool00`00Oomo
o`18Ool0029oo`8001Ioo`800005Ool00000001oo`020003Ool00`00Oomoo`18Ool0029oo`8001Mo
o`<0009oo`05001oogoo001oo`02001:Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`03001oogoo01ioo`8004aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomo
o`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004
Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomo
o`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]o
o`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=o
o`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol0
0`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool5
0002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`80
00Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Io
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004
Ool00`00Oomoo`02OolI001@Ool002Qoo`03001oogoo01Eoo`<004ioo`00:7oo00<007ooOol05goo
0`00C7oo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0JOol2
001:Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomo
o`007Goo0`00B7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005
Ool01000Oomoo`007goo0`00AWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30002Ool40004Ool20003Ool30003Ool30004
Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002
Ool01000Oomoo`001goo00<007ooOol00Woo0P0000Eoo`00Oomoo`00009oo`05001oogooOol00003
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo
0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool40002Ool01000Oomoo`000goo00<007ooOol01Goo
00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009o
o`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Ool00000
0Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool0
0`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo
0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool00`00Oomo
o`0200001Goo001oogoo00000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo
000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool2000017oo001oogoo0P0017oo
00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00
:7oo00<007ooOol09Goo00<007ooOol0?Woo000XOol00`00Oomoo`0VOol00`00Oomoo`0mOol002Qo
oed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol00Woo00<007ooOol02Woo
00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`0XOol00`00Oomo
o`0kOol002Qoo`03001oogoo02Uoo`03001oogoo03Yoo`00:7oo00<007ooOol0:Goo0P00>goo000X
Ool00`00Oomoo`0ZOol00`00Oomoo`0iOol002Qoo`03001oogoo02]oo`03001oogoo03Qoo`002goo
0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0;7oo00<007ooOol0=goo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol002io
o`03001oogoo03Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOol002moo`03001oogoo03Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol00P00;Woo0P00=goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05
001oogoo001oo`040003Ool00`00Oomoo`0_Ool[000<Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0
009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo
000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00
Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4
001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2
000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;
Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00
Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@00
0Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005
Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001ao
o`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001o
ogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0
009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03
001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo
00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomo
o`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004
Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo
00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001o
ogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004
Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03
001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006
Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY
000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00@007oo
Oomoo`<00003Ool007oo009oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00
Oomoo`0HOol3001GOol001aoo`8001]oo`8005Ioo`0077oo00<007ooOol077oo0`00Dgoo000LOol0
0`00Oomoo`0NOol2001BOol001aoo`80025oo`03001oogoo04moo`0077oo00<007ooOol08Goo0P00
Cgoo000LOol00`00Oomoo`0SOol2001=Ool001aoo`8002Eoo`03001oogoo04]oo`0077oo00<007oo
Ool09Goo00<007ooOol0BWoo000LOol2000WOol00`00Oomoo`19Ool000]oo`8000Aoo`03001oogoo
009oo`<000=oo`03001oogoo02Ioo`8004Yoo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`0WOol00`00Oomoo`18Ool000Yoo`04001oogoo000;Ool00`00Oomoo`02000XOol0
0`00Oomoo`18Ool000Yoo`04001oogoo000;Ool01000Oomoo`00:Woo00<007ooOol0Agoo000:Ool0
1000Oomoo`001goo10000goo00<007ooOol0:Goo00<007ooOol0AWoo000:Ool01000Oomoo`001goo
00<007ooOol017oo0P00:Woo00<007ooOol0AWoo000;Ool20008Ool50002Ool00`00Oomoo`0YOol2
0017Ool001aoo`03001oogoo02Yoo`8004Ioo`0077oo0P00;7oo00<007ooOol0A7oo000LOol00`00
Oomoo`0/Ool00`00Oomoo`13Ool001aoo`8002eoo`03001oogoo04=oo`0077oo00<007ooOol0;Goo
00<007ooOol0@Woo000LOol00`00Oomoo`0]Ool00`00Oomoo`12Ool001aoo`8002moo`03001oogoo
045oo`005Woo0`000goo00<007ooOol0;Woo0P00@Woo000GOol00`00Oomoo`02Ool00`00Oomoo`0_
Ool20011Ool001Moo`03001oogoo009oo`80035oo`03001oogoo03moo`005goo00<007ooOol00Woo
00<007ooOol0<7oo00<007ooOol0?goo000GOol00`00Oomoo`02Ool00`00Oomoo`0aOol00`00Oomo
o`0nOol001Ioo`8000Aoo`8003=oo`03001oogoo03eoo`005goo00<007ooOol00Woo00<007ooOol0
<Woo00<007ooOol0?Goo000LOol00`00Oomoo`0cOol00`00Oomoo`0lOol001aoo`8003Aoo`03001o
ogoo03aoo`0077oo00<007ooOol0=7oo00<007ooOol0>goo000LOol2000fOol00`00Oomoo`0jOol0
01aoo`03001oogoo03Eooc4000aoo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02
Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=o
o`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool0
0`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(14863\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30172 m
.008 .30549 L
.012 .31284 L
.016 .32212 L
.02 .33033 L
.024 .33536 L
.028 .33518 L
.032 .33097 L
.036 .32364 L
.04 .31537 L
.044 .30893 L
.048 .30615 L
.052 .30785 L
.056 .31246 L
.06 .31841 L
.064 .32404 L
.068 .32748 L
.072 .32738 L
.076 .32405 L
.08 .31965 L
.084 .31615 L
.088 .3144 L
.092 .31476 L
.096 .31747 L
.1 .32183 L
.104 .32601 L
.108 .32777 L
.112 .32628 L
.116 .32247 L
.12 .31795 L
.124 .31363 L
.128 .30981 L
.132 .30767 L
.136 .30857 L
.14 .31256 L
.144 .31792 L
.148 .32278 L
.152 .32648 L
.156 .32923 L
.16 .33128 L
.164 .33189 L
.168 .33026 L
.172 .3265 L
.176 .32192 L
.18 .318 L
.184 .31555 L
.188 .31431 L
.192 .31329 L
.196 .31192 L
.2 .31057 L
Mistroke
.204 .31019 L
.208 .31124 L
.212 .31282 L
.216 .31342 L
.22 .31274 L
.224 .31258 L
.228 .31518 L
.232 .32073 L
.236 .32633 L
.24 .32814 L
.244 .32517 L
.248 .32071 L
.252 .31984 L
.256 .32518 L
.26 .33467 L
.264 .34333 L
.268 .34746 L
.272 .34717 L
.276 .34551 L
.28 .34547 L
.284 .34769 L
.288 .35067 L
.292 .35265 L
.296 .35293 L
.3 .35172 L
.304 .34926 L
.308 .34547 L
.312 .3408 L
.316 .33694 L
.32 .3363 L
.324 .34018 L
.328 .34716 L
.332 .35335 L
.336 .35466 L
.34 .34966 L
.344 .34086 L
.348 .33333 L
.352 .33164 L
.356 .33712 L
.36 .34732 L
.364 .35773 L
.368 .36456 L
.372 .3665 L
.376 .36476 L
.38 .36136 L
.384 .35736 L
.388 .3521 L
.392 .34392 L
.396 .33167 L
.4 .31595 L
Mistroke
.404 .29922 L
.408 .28464 L
.412 .27444 L
.416 .26881 L
.42 .26589 L
.424 .26285 L
.428 .25749 L
.432 .24937 L
.436 .24008 L
.44 .23231 L
.444 .22841 L
.448 .22915 L
.452 .23327 L
.456 .23801 L
.46 .24039 L
.464 .23851 L
.468 .23236 L
.472 .22375 L
.476 .21548 L
.48 .21019 L
.484 .20936 L
.488 .2129 L
.492 .21931 L
.496 .22634 L
.5 .23174 L
.504 .23384 L
.508 .23194 L
.512 .22625 L
.516 .21773 L
.52 .20778 L
.524 .19799 L
.528 .18987 L
.532 .18466 L
.536 .18316 L
.54 .18565 L
.544 .19189 L
.548 .20112 L
.552 .21231 L
.556 .22437 L
.56 .23636 L
.564 .24765 L
.568 .25795 L
.572 .26715 L
.576 .2752 L
.58 .28198 L
.584 .28739 L
.588 .29141 L
.592 .29423 L
.596 .29622 L
.6 .29778 L
Mistroke
.604 .29913 L
.608 .30028 L
.612 .30109 L
.616 .30144 L
.62 .30142 L
.624 .30128 L
.628 .30129 L
.632 .30157 L
.636 .30194 L
.64 .30216 L
.644 .30206 L
.648 .30175 L
.652 .3015 L
.656 .3015 L
.66 .30177 L
.664 .30206 L
.668 .30215 L
.672 .30196 L
.676 .30165 L
.68 .30148 L
.684 .30159 L
.688 .30188 L
.692 .30211 L
.696 .30206 L
.7 .30179 L
.704 .30153 L
.708 .30151 L
.712 .30174 L
.716 .302 L
.72 .30207 L
.724 .30188 L
.728 .30161 L
.732 .30151 L
.736 .30165 L
.74 .30189 L
.744 .30202 L
.748 .30192 L
.752 .30169 L
.756 .30154 L
.76 .3016 L
.764 .3018 L
.768 .30195 L
.772 .30192 L
.776 .30174 L
.78 .30158 L
.784 .30158 L
.788 .30173 L
.792 .30189 L
.796 .30191 L
.8 .30176 L
Mistroke
.804 .3016 L
.808 .30157 L
.812 .3017 L
.816 .30185 L
.82 .30188 L
.824 .30175 L
.828 .3016 L
.832 .30158 L
.836 .30169 L
.84 .30182 L
.844 .30184 L
.848 .30172 L
.852 .3016 L
.856 .30159 L
.86 .30169 L
.864 .3018 L
.868 .3018 L
.872 .30169 L
.876 .3016 L
.88 .30162 L
.884 .3017 L
.888 .30177 L
.892 .30175 L
.896 .30165 L
.9 .3016 L
.904 .30164 L
.908 .30171 L
.912 .30173 L
.916 .3017 L
.92 .30163 L
.924 .30161 L
.928 .30166 L
.932 .3017 L
.936 .30168 L
.94 .30165 L
.944 .30162 L
.948 .30163 L
.952 .30168 L
.956 .30167 L
.96 .30162 L
.964 .30162 L
.968 .30164 L
.972 .30165 L
.976 .30167 L
.98 .30163 L
.984 .30157 L
.988 .3016 L
.992 .30166 L
.996 .30166 L
1 .30164 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14469 m
.008 .14184 L
.012 .14082 L
.016 .14173 L
.02 .14194 L
.024 .14158 L
.028 .14143 L
.032 .1416 L
.036 .14168 L
.04 .14176 L
.044 .14183 L
.048 .14195 L
.052 .14197 L
.056 .14194 L
.06 .14186 L
.064 .14177 L
.068 .14162 L
.072 .14148 L
.076 .14139 L
.08 .14139 L
.084 .14143 L
.088 .14151 L
.092 .14163 L
.096 .14182 L
.1 .142 L
.104 .14213 L
.108 .14217 L
.112 .14217 L
.116 .14215 L
.12 .14206 L
.124 .14187 L
.128 .14161 L
.132 .14138 L
.136 .14122 L
.14 .14109 L
.144 .14097 L
.148 .14091 L
.152 .141 L
.156 .14126 L
.16 .14162 L
.164 .14197 L
.168 .14228 L
.172 .14258 L
.176 .14288 L
.18 .14311 L
.184 .14316 L
.188 .14297 L
.192 .1426 L
.196 .14217 L
.2 .14179 L
Mistroke
.204 .14146 L
.208 .14108 L
.212 .1406 L
.216 .1401 L
.22 .13975 L
.224 .13966 L
.228 .13974 L
.232 .13977 L
.236 .13963 L
.24 .1394 L
.244 .13937 L
.248 .13974 L
.252 .14047 L
.256 .1413 L
.26 .142 L
.264 .14258 L
.268 .14332 L
.272 .14448 L
.276 .14616 L
.28 .14815 L
.284 .15015 L
.288 .15193 L
.292 .15349 L
.296 .15496 L
.3 .1565 L
.304 .15822 L
.308 .16012 L
.312 .16214 L
.316 .16417 L
.32 .16607 L
.324 .16765 L
.328 .16887 L
.332 .16982 L
.336 .1708 L
.34 .17221 L
.344 .17431 L
.348 .17708 L
.352 .18023 L
.356 .18336 L
.36 .18608 L
.364 .18826 L
.368 .18996 L
.372 .19135 L
.376 .19262 L
.38 .19386 L
.384 .19512 L
.388 .19649 L
.392 .19817 L
.396 .2004 L
.4 .20339 L
Mistroke
.404 .20721 L
.408 .21174 L
.412 .21672 L
.416 .22188 L
.42 .22705 L
.424 .23217 L
.428 .23737 L
.432 .24279 L
.436 .2485 L
.44 .25447 L
.444 .26053 L
.448 .26647 L
.452 .27211 L
.456 .27738 L
.46 .28237 L
.464 .28727 L
.468 .29228 L
.472 .29758 L
.476 .30322 L
.48 .30913 L
.484 .31513 L
.488 .32099 L
.492 .32653 L
.496 .33166 L
.5 .33639 L
.504 .34084 L
.508 .34523 L
.512 .34976 L
.516 .35463 L
.52 .35995 L
.524 .36575 L
.528 .37197 L
.532 .37847 L
.536 .38507 L
.54 .39157 L
.544 .39777 L
.548 .40352 L
.552 .40869 L
.556 .41321 L
.56 .41708 L
.564 .42029 L
.568 .42291 L
.572 .42499 L
.576 .42661 L
.58 .42784 L
.584 .42877 L
.588 .42945 L
.592 .42994 L
.596 .4303 L
.6 .43055 L
Mistroke
.604 .43072 L
.608 .43084 L
.612 .43093 L
.616 .43099 L
.62 .43103 L
.624 .43106 L
.628 .43109 L
.632 .43111 L
.636 .43112 L
.64 .43114 L
.644 .43116 L
.648 .43117 L
.652 .43118 L
.656 .4312 L
.66 .43121 L
.664 .43122 L
.668 .43124 L
.672 .43125 L
.676 .43126 L
.68 .43128 L
.684 .43129 L
.688 .4313 L
.692 .43131 L
.696 .43133 L
.7 .43134 L
.704 .43136 L
.708 .43137 L
.712 .43138 L
.716 .43139 L
.72 .43141 L
.724 .43142 L
.728 .43144 L
.732 .43145 L
.736 .43146 L
.74 .43147 L
.744 .43149 L
.748 .4315 L
.752 .43151 L
.756 .43153 L
.76 .43154 L
.764 .43155 L
.768 .43156 L
.772 .43158 L
.776 .43159 L
.78 .4316 L
.784 .43162 L
.788 .43163 L
.792 .43164 L
.796 .43166 L
.8 .43167 L
Mistroke
.804 .43168 L
.808 .4317 L
.812 .43171 L
.816 .43172 L
.82 .43174 L
.824 .43175 L
.828 .43176 L
.832 .43177 L
.836 .43179 L
.84 .4318 L
.844 .43181 L
.848 .43183 L
.852 .43184 L
.856 .43185 L
.86 .43186 L
.864 .43188 L
.868 .43189 L
.872 .43191 L
.876 .43192 L
.88 .43193 L
.884 .43194 L
.888 .43196 L
.892 .43197 L
.896 .43199 L
.9 .432 L
.904 .43201 L
.908 .43202 L
.912 .43204 L
.916 .43205 L
.92 .43207 L
.924 .43207 L
.928 .43209 L
.932 .4321 L
.936 .43212 L
.94 .43213 L
.944 .43214 L
.948 .43215 L
.952 .43217 L
.956 .43218 L
.96 .4322 L
.964 .4322 L
.968 .43223 L
.972 .43223 L
.976 .43225 L
.98 .43225 L
.984 .43228 L
.988 .43228 L
.992 .43231 L
.996 .4323 L
1 .43234 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16064 L
.012 .16074 L
.016 .16083 L
.02 .16087 L
.024 .1609 L
.028 .16112 L
.032 .16134 L
.036 .16154 L
.04 .16159 L
.044 .1616 L
.048 .16151 L
.052 .16138 L
.056 .1612 L
.06 .16109 L
.064 .161 L
.068 .16096 L
.072 .16094 L
.076 .16097 L
.08 .16102 L
.084 .16108 L
.088 .1611 L
.092 .16114 L
.096 .16124 L
.1 .16141 L
.104 .16153 L
.108 .16162 L
.112 .1617 L
.116 .16178 L
.12 .16174 L
.124 .16153 L
.128 .1612 L
.132 .16086 L
.136 .16059 L
.14 .16036 L
.144 .16017 L
.148 .16009 L
.152 .16023 L
.156 .16062 L
.16 .16112 L
.164 .1616 L
.168 .162 L
.172 .16235 L
.176 .16268 L
.18 .16292 L
.184 .16295 L
.188 .1627 L
.192 .16225 L
.196 .16175 L
.2 .16133 L
Mistroke
.204 .16095 L
.208 .16048 L
.212 .15987 L
.216 .15921 L
.22 .15874 L
.224 .1586 L
.228 .15869 L
.232 .15876 L
.236 .15861 L
.24 .15836 L
.244 .15833 L
.248 .15879 L
.252 .15967 L
.256 .16068 L
.26 .16153 L
.264 .16226 L
.268 .16318 L
.272 .16466 L
.276 .16677 L
.28 .16926 L
.284 .17174 L
.288 .17395 L
.292 .17586 L
.296 .17768 L
.3 .1796 L
.304 .18175 L
.308 .18412 L
.312 .18665 L
.316 .18919 L
.32 .19154 L
.324 .1935 L
.328 .195 L
.332 .19616 L
.336 .19739 L
.34 .19915 L
.344 .20176 L
.348 .20521 L
.352 .20914 L
.356 .21302 L
.36 .2164 L
.364 .21909 L
.368 .22119 L
.372 .22292 L
.376 .2245 L
.38 .22604 L
.384 .2276 L
.388 .22931 L
.392 .23138 L
.396 .23414 L
.4 .23785 L
Mistroke
.404 .24259 L
.408 .24823 L
.412 .25443 L
.416 .26086 L
.42 .26727 L
.424 .27364 L
.428 .28009 L
.432 .28681 L
.436 .29391 L
.44 .30133 L
.444 .30887 L
.448 .31625 L
.452 .32325 L
.456 .32978 L
.46 .33597 L
.464 .34203 L
.468 .34825 L
.472 .35483 L
.476 .36184 L
.48 .36917 L
.484 .3766 L
.488 .38386 L
.492 .39072 L
.496 .39707 L
.5 .40293 L
.504 .40844 L
.508 .41387 L
.512 .41947 L
.516 .42549 L
.52 .43207 L
.524 .43925 L
.528 .44696 L
.532 .45502 L
.536 .46319 L
.54 .47124 L
.544 .47891 L
.548 .48601 L
.552 .4924 L
.556 .49799 L
.56 .50274 L
.564 .50669 L
.568 .50989 L
.572 .51242 L
.576 .51438 L
.58 .51586 L
.584 .51695 L
.588 .51774 L
.592 .51829 L
.596 .51867 L
.6 .51892 L
Mistroke
.604 .51908 L
.608 .51917 L
.612 .51922 L
.616 .51923 L
.62 .51922 L
.624 .5192 L
.628 .51917 L
.632 .51914 L
.636 .5191 L
.64 .51906 L
.644 .51902 L
.648 .51897 L
.652 .51893 L
.656 .51889 L
.66 .51885 L
.664 .5188 L
.668 .51876 L
.672 .51871 L
.676 .51867 L
.68 .51862 L
.684 .51858 L
.688 .51854 L
.692 .51849 L
.696 .51845 L
.7 .5184 L
.704 .51836 L
.708 .51832 L
.712 .51827 L
.716 .51823 L
.72 .51818 L
.724 .51814 L
.728 .51809 L
.732 .51805 L
.736 .51801 L
.74 .51796 L
.744 .51792 L
.748 .51787 L
.752 .51783 L
.756 .51778 L
.76 .51774 L
.764 .5177 L
.768 .51765 L
.772 .51761 L
.776 .51756 L
.78 .51752 L
.784 .51748 L
.788 .51743 L
.792 .51739 L
.796 .51734 L
.8 .5173 L
Mistroke
.804 .51725 L
.808 .51721 L
.812 .51717 L
.816 .51712 L
.82 .51708 L
.824 .51703 L
.828 .51699 L
.832 .51695 L
.836 .5169 L
.84 .51686 L
.844 .51681 L
.848 .51677 L
.852 .51672 L
.856 .51668 L
.86 .51663 L
.864 .51659 L
.868 .51654 L
.872 .5165 L
.876 .51646 L
.88 .51641 L
.884 .51637 L
.888 .51633 L
.892 .51628 L
.896 .51624 L
.9 .51619 L
.904 .51615 L
.908 .5161 L
.912 .51606 L
.916 .51601 L
.92 .51597 L
.924 .51592 L
.928 .51588 L
.932 .51583 L
.936 .5158 L
.94 .51574 L
.944 .51571 L
.948 .51565 L
.952 .51562 L
.956 .51557 L
.96 .51553 L
.964 .51547 L
.968 .51544 L
.972 .51538 L
.976 .51536 L
.98 .5153 L
.984 .51527 L
.988 .5152 L
.992 .51518 L
.996 .51511 L
1 .5151 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
0080039oo`8003Uoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0<Goo0P00>Goo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool2000aOol01000Oomoo`00>7oo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8000eoo`<000Aoo`8000Moo`<000Aoo`8000Ao
o`800003Ool00000009oo`@0009oo`<000Aoo`8000=oo`D000=oo`8000Aoo`8000Aoo`D0009oo`<0
00Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`0;Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo
0002Ool03P00Oomoo`00Ool007oo001oo`00Ool007oo0003Ool01000Oomoo`000Woo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo00H007ooOol007oo0003
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomo
o`000Woo0P0000Aoo`00Oomoo`800005Ool007ooOol00004Ool01000Oomoo`000Woo00<007ooOol0
0Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07oo000000Eoo`04001oogoo0004Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`00
009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007oo
Ool00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00]oo`@000=o
o`04001oogoo0007Ool00`00Oomoo`02Ool01@00Oomoo`00Ool00P000Woo00<007ooOol00goo00<0
07ooOol01@000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000=oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<0
07ooOol00Woo0P0037oo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`03001oogoo00800005
Ool007ooOol00004Ool20002Ool20006Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000ROol2
000<Ool50003Ool20008Ool00`00Oomoo`03Ool40002Ool20006Ool01000Oomoogoo1@000goo0P00
17oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`0UOol00`00
Oomoo`0>Ool00`00Oomoo`0cOol0029oo`8002Ioo`03001oogoo00ioo`<003=oo`008WooH`0037oo
000ROol20002Ool01000Ool007oo0`0000Moo`00000007oo001oo`0500001Goo001oogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo000037oo000ROol300000goo001oo`0300000goo00000003Ool00`00
Ool00005Ool3000=Ool00`00Oomoo`15Ool0029oo`04001oo`00000<Ool20007Ool00`00Oomoo`03
Ool00`00Oomoo`020003Ool00`00Oomoo`15Ool0029oo`8001Qoo`<00003Ool0000000@0009oo`03
001oogoo04Ioo`008Woo0P006Woo0P000Woo0P000Woo00<007oo0000B7oo000;Ool20004Ool00`00
Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0QOol20019Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo
00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2
001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001o
ogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06ao
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
1Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]
Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003
Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=o
o`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05
Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<0
07ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool0
0`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo
00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo
06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo6`00CWoo000XOol00`00Oomoo`0GOol3001<
Ool002Qoo`03001oogoo01Yoo`<004Uoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo
0`000goo00<007ooOol077oo0P00B7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001o
ogoo001oo`000goo00@007ooOol0021oo`8004Ioo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00@007ooOol0029oo`<004=oo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P00
17oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P00
1Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomo
o`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Io
o`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`02
00001Goo001oogoo00000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`040002Ool01@00Oomoogoo00001goo00@007ooOol0
009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@0
07ooOol000Moo`03001oogoo009oo`05001oogoo001oo`020002Ool01@00Oomoogoo00000goo1000
0goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000
Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
o`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=o
o`8000=oo`<000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool5
0003Ool20006Ool002Qoo`03001oogoo02Moo`8003eoo`00:7oo00<007ooOol0:7oo00<007ooOol0
>goo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00Aoo`8000Uo
o`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0:Woo00<007oo
Ool0>Goo000XOol00`00Oomoo`0[Ool2000iOol002Qoo`03001oogoo02aoo`03001oogoo03Moo`00
:7oo00<007ooOol0;Goo00<007ooOol0=Woo000XOol00`00Oomoo`0]Ool2000gOol000]oo`8000Ao
o`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo02ioo`03001oogoo03Eoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000`Ool2000f
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000aOol2
000eOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo0080
035oo`8003Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo
00<007ooOol0<Goo:@0037oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003
Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo
00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00
Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001o
ogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0
0P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007oo
Oomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol0
0Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol0
00]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`00
77oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P00
1Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo
00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D0
07ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool0
01aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Ao
o`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool4
0003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo
0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool0
0006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool2
0006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P00
1Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomo
ogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00002Ool30002Ool0
1@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol06goo0`00E7oo000LOol2
000NOol2001COol001aoo`03001oogoo01moo`<0051oo`0077oo00<007ooOol08Goo0P00Cgoo000L
Ool2000SOol2001>Ool001aoo`03001oogoo02Aoo`8004aoo`0077oo00<007ooOol09Woo0P00BWoo
000LOol2000XOol00`00Oomoo`18Ool001aoo`03001oogoo02Qoo`03001oogoo04Moo`0077oo0P00
:Goo0P00B7oo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`0YOol00`00Oomoo`16
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0:Goo0P00Agoo000:Ool0
1000Oomoo`002goo00<007ooOol00P00:goo00<007ooOol0AGoo000:Ool01000Oomoo`002goo00@0
07ooOol002eoo`03001oogoo04Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo02]oo`80
04Eoo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8002eoo`03001oogoo04=oo`002goo0P00
27oo1@000Woo00<007ooOol0;7oo0P00A7oo000LOol00`00Oomoo`0]Ool00`00Oomoo`12Ool001ao
o`8002moo`03001oogoo045oo`0077oo00<007ooOol0;Woo00<007ooOol0@Goo000LOol2000`Ool0
0`00Oomoo`10Ool001aoo`03001oogoo02moo`80045oo`0077oo00<007ooOol0<7oo00<007ooOol0
?goo000LOol2000aOol20010Ool001Ioo`<000=oo`03001oogoo035oo`8003moo`005goo00<007oo
Ool00Woo00<007ooOol0<Woo00<007ooOol0?Goo000GOol00`00Oomoo`02Ool2000dOol00`00Oomo
o`0lOol001Moo`03001oogoo009oo`03001oogoo03=oo`03001oogoo03aoo`005goo00<007ooOol0
0Woo00<007ooOol0=7oo00<007ooOol0>goo000FOol20004Ool2000eOol2000lOol001Moo`03001o
ogoo009oo`03001oogoo03Eoo`03001oogoo03Yoo`0077oo00<007ooOol0=Goo00<007ooOol0>Woo
000LOol2000gOol00`00Oomoo`0iOol001aoo`03001oogoo03Moo`03001oogoo03Qoo`0077oo0P00
>7oo0P00>Goo000LOol00`00Oomoo`0hOol^000<Ool001aoo`03001oogoo079oo`002Woo0`0017oo
00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00
Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<0
07ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001o
ogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(15030\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .33451 m
.008 .32968 L
.012 .32133 L
.016 .3134 L
.02 .30813 L
.024 .30564 L
.028 .30733 L
.032 .3123 L
.036 .31944 L
.04 .32563 L
.044 .32897 L
.048 .32939 L
.052 .32667 L
.056 .32211 L
.06 .3171 L
.064 .31387 L
.068 .31337 L
.072 .31483 L
.076 .31741 L
.08 .32015 L
.084 .32226 L
.088 .32267 L
.092 .32104 L
.096 .31843 L
.1 .31634 L
.104 .31571 L
.108 .31637 L
.112 .31782 L
.116 .32009 L
.12 .32312 L
.124 .32575 L
.128 .32649 L
.132 .3251 L
.136 .32275 L
.14 .32027 L
.144 .31747 L
.148 .31415 L
.152 .31102 L
.156 .30963 L
.16 .31078 L
.164 .31391 L
.168 .3176 L
.172 .32099 L
.176 .32409 L
.18 .32683 L
.184 .32878 L
.188 .3292 L
.192 .32792 L
.196 .32564 L
.2 .32362 L
Mistroke
.204 .32261 L
.208 .32211 L
.212 .32059 L
.216 .31675 L
.22 .31122 L
.224 .30658 L
.228 .30547 L
.232 .3083 L
.236 .31272 L
.24 .31571 L
.244 .31631 L
.248 .31621 L
.252 .31743 L
.256 .31991 L
.26 .32149 L
.264 .32043 L
.268 .31792 L
.272 .31758 L
.276 .32206 L
.28 .33036 L
.284 .33824 L
.288 .34163 L
.292 .34008 L
.296 .33699 L
.3 .33661 L
.304 .34076 L
.308 .3477 L
.312 .35383 L
.316 .35641 L
.32 .35491 L
.324 .35057 L
.328 .34507 L
.332 .33983 L
.336 .3361 L
.34 .33515 L
.344 .33779 L
.348 .34338 L
.352 .3494 L
.356 .35251 L
.36 .35053 L
.364 .34404 L
.368 .33631 L
.372 .33141 L
.376 .33184 L
.38 .33722 L
.384 .34488 L
.388 .35179 L
.392 .35638 L
.396 .35899 L
.4 .36088 L
Mistroke
.404 .36259 L
.408 .36304 L
.412 .35997 L
.416 .35141 L
.42 .3372 L
.424 .31946 L
.428 .30174 L
.432 .28735 L
.436 .27782 L
.44 .27235 L
.444 .26853 L
.448 .2637 L
.452 .25635 L
.456 .24683 L
.46 .23701 L
.464 .22932 L
.468 .22554 L
.472 .22597 L
.476 .22938 L
.48 .23347 L
.484 .23577 L
.488 .23464 L
.492 .22975 L
.496 .2222 L
.5 .21406 L
.504 .20767 L
.508 .20482 L
.512 .20624 L
.516 .21134 L
.52 .21847 L
.524 .22536 L
.528 .22982 L
.532 .23031 L
.536 .22633 L
.54 .21847 L
.544 .20822 L
.548 .19746 L
.552 .18803 L
.556 .18129 L
.56 .17806 L
.564 .17856 L
.568 .18268 L
.572 .19005 L
.576 .20008 L
.58 .21195 L
.584 .22469 L
.588 .23729 L
.592 .24895 L
.596 .25923 L
.6 .2681 L
Mistroke
.604 .2757 L
.608 .28218 L
.612 .28755 L
.616 .29172 L
.62 .29467 L
.624 .29662 L
.628 .29795 L
.632 .29905 L
.636 .30008 L
.64 .30096 L
.644 .30149 L
.648 .30161 L
.652 .30148 L
.656 .30137 L
.66 .30148 L
.664 .30179 L
.668 .30207 L
.672 .30212 L
.676 .30191 L
.68 .30163 L
.684 .30153 L
.688 .3017 L
.692 .30198 L
.696 .30212 L
.7 .30201 L
.704 .30174 L
.708 .30156 L
.712 .30162 L
.716 .30186 L
.72 .30205 L
.724 .30203 L
.728 .30182 L
.732 .30162 L
.736 .3016 L
.74 .30177 L
.744 .30197 L
.748 .30201 L
.752 .30186 L
.756 .30167 L
.76 .3016 L
.764 .30172 L
.768 .30189 L
.772 .30197 L
.776 .30188 L
.78 .3017 L
.784 .30161 L
.788 .30168 L
.792 .30185 L
.796 .30194 L
.8 .30187 L
Mistroke
.804 .30171 L
.808 .30162 L
.812 .30167 L
.816 .30182 L
.82 .3019 L
.824 .30184 L
.828 .3017 L
.832 .30163 L
.836 .30168 L
.84 .3018 L
.844 .30187 L
.848 .3018 L
.852 .30169 L
.856 .30164 L
.86 .3017 L
.864 .30179 L
.868 .30182 L
.872 .30175 L
.876 .30167 L
.88 .30166 L
.884 .30171 L
.888 .30177 L
.892 .30178 L
.896 .30172 L
.9 .30167 L
.904 .30168 L
.908 .30171 L
.912 .30174 L
.916 .30174 L
.92 .30169 L
.924 .30167 L
.928 .30169 L
.932 .3017 L
.936 .3017 L
.94 .3017 L
.944 .30168 L
.948 .30168 L
.952 .3017 L
.956 .30168 L
.96 .30166 L
.964 .30167 L
.968 .30169 L
.972 .30168 L
.976 .30168 L
.98 .30165 L
.984 .30162 L
.988 .30166 L
.992 .3017 L
.996 .30168 L
1 .30165 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14271 m
.008 .14203 L
.012 .14178 L
.016 .14208 L
.02 .14227 L
.024 .14233 L
.028 .14227 L
.032 .14222 L
.036 .14214 L
.04 .14203 L
.044 .14191 L
.048 .14187 L
.052 .14187 L
.056 .14194 L
.06 .14204 L
.064 .1422 L
.068 .1423 L
.072 .14237 L
.076 .14236 L
.08 .14233 L
.084 .14223 L
.088 .1421 L
.092 .14195 L
.096 .14186 L
.1 .14181 L
.104 .14181 L
.108 .14182 L
.112 .14188 L
.116 .14201 L
.12 .14216 L
.124 .14228 L
.128 .14235 L
.132 .14243 L
.136 .14253 L
.14 .14257 L
.144 .1425 L
.148 .14234 L
.152 .14216 L
.156 .14198 L
.16 .14178 L
.164 .14154 L
.168 .14131 L
.172 .14119 L
.176 .14126 L
.18 .14149 L
.184 .14179 L
.188 .1421 L
.192 .14243 L
.196 .14281 L
.2 .14319 L
Mistroke
.204 .14347 L
.208 .14354 L
.212 .14337 L
.216 .14306 L
.22 .14275 L
.224 .14249 L
.228 .14221 L
.232 .14178 L
.236 .14121 L
.24 .14065 L
.244 .14031 L
.248 .14024 L
.252 .14027 L
.256 .14018 L
.26 .13991 L
.264 .13962 L
.268 .1396 L
.272 .13998 L
.276 .14062 L
.28 .14127 L
.284 .14175 L
.288 .14218 L
.292 .14284 L
.296 .14394 L
.3 .14553 L
.304 .1474 L
.308 .14929 L
.312 .15103 L
.316 .1526 L
.32 .1541 L
.324 .15562 L
.328 .15728 L
.332 .15913 L
.336 .16116 L
.34 .16328 L
.344 .16529 L
.348 .16697 L
.352 .16821 L
.356 .16909 L
.36 .16996 L
.364 .1712 L
.368 .17311 L
.372 .17571 L
.376 .17875 L
.38 .18183 L
.384 .18462 L
.388 .18697 L
.392 .1889 L
.396 .19053 L
.4 .19195 L
Mistroke
.404 .19323 L
.408 .1944 L
.412 .19556 L
.416 .19694 L
.42 .19881 L
.424 .2014 L
.428 .20483 L
.432 .209 L
.436 .21369 L
.44 .21863 L
.444 .22362 L
.448 .22862 L
.452 .23371 L
.456 .23903 L
.46 .24466 L
.464 .25058 L
.468 .25665 L
.472 .26264 L
.476 .26837 L
.48 .27373 L
.484 .27879 L
.488 .28369 L
.492 .28866 L
.496 .29386 L
.5 .2994 L
.504 .30524 L
.508 .31123 L
.512 .31716 L
.516 .32284 L
.52 .32814 L
.524 .33302 L
.528 .33758 L
.532 .34196 L
.536 .3464 L
.54 .35108 L
.544 .35615 L
.548 .3617 L
.552 .36771 L
.556 .37407 L
.56 .38063 L
.564 .38721 L
.568 .3936 L
.572 .39963 L
.576 .40517 L
.58 .4101 L
.584 .4144 L
.588 .41804 L
.592 .42106 L
.596 .42351 L
.6 .42545 L
Mistroke
.604 .42695 L
.608 .4281 L
.612 .42896 L
.616 .4296 L
.62 .43006 L
.624 .43039 L
.628 .43063 L
.632 .43079 L
.636 .4309 L
.64 .43098 L
.644 .43104 L
.648 .43109 L
.652 .43112 L
.656 .43114 L
.66 .43116 L
.664 .43118 L
.668 .43119 L
.672 .43121 L
.676 .43123 L
.68 .43124 L
.684 .43125 L
.688 .43126 L
.692 .43128 L
.696 .43129 L
.7 .43131 L
.704 .43132 L
.708 .43133 L
.712 .43134 L
.716 .43136 L
.72 .43137 L
.724 .43138 L
.728 .4314 L
.732 .43141 L
.736 .43142 L
.74 .43143 L
.744 .43145 L
.748 .43146 L
.752 .43148 L
.756 .43149 L
.76 .4315 L
.764 .43151 L
.768 .43153 L
.772 .43154 L
.776 .43156 L
.78 .43157 L
.784 .43158 L
.788 .43159 L
.792 .43161 L
.796 .43162 L
.8 .43163 L
Mistroke
.804 .43165 L
.808 .43166 L
.812 .43167 L
.816 .43168 L
.82 .4317 L
.824 .43171 L
.828 .43172 L
.832 .43174 L
.836 .43175 L
.84 .43176 L
.844 .43178 L
.848 .43179 L
.852 .4318 L
.856 .43182 L
.86 .43183 L
.864 .43184 L
.868 .43185 L
.872 .43187 L
.876 .43188 L
.88 .43189 L
.884 .43191 L
.888 .43192 L
.892 .43193 L
.896 .43195 L
.9 .43196 L
.904 .43197 L
.908 .43198 L
.912 .432 L
.916 .43201 L
.92 .43203 L
.924 .43204 L
.928 .43205 L
.932 .43206 L
.936 .43208 L
.94 .43209 L
.944 .43211 L
.948 .43211 L
.952 .43213 L
.956 .43214 L
.96 .43216 L
.964 .43216 L
.968 .43219 L
.972 .43219 L
.976 .43221 L
.98 .43221 L
.984 .43224 L
.988 .43224 L
.992 .43227 L
.996 .43226 L
1 .4323 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16336 L
.012 .1615 L
.016 .16085 L
.02 .16154 L
.024 .16162 L
.028 .16125 L
.032 .161 L
.036 .16096 L
.04 .16091 L
.044 .16092 L
.048 .16098 L
.052 .16113 L
.056 .16125 L
.06 .16137 L
.064 .16144 L
.068 .16148 L
.072 .16143 L
.076 .16138 L
.08 .16131 L
.084 .16126 L
.088 .16117 L
.092 .16108 L
.096 .16102 L
.1 .16101 L
.104 .16097 L
.108 .16092 L
.112 .16092 L
.116 .16103 L
.12 .16118 L
.124 .16134 L
.128 .16147 L
.132 .16163 L
.136 .1618 L
.14 .16189 L
.144 .1618 L
.148 .16157 L
.152 .16129 L
.156 .16103 L
.16 .16075 L
.164 .16045 L
.168 .16019 L
.172 .16009 L
.176 .16021 L
.18 .16052 L
.184 .16089 L
.188 .16125 L
.192 .16163 L
.196 .16206 L
.2 .16253 L
Mistroke
.204 .16289 L
.208 .163 L
.212 .16282 L
.216 .16245 L
.22 .16208 L
.224 .16174 L
.228 .16136 L
.232 .1608 L
.236 .16007 L
.24 .15938 L
.244 .15898 L
.248 .15891 L
.252 .15897 L
.256 .15887 L
.26 .15852 L
.264 .15814 L
.268 .1581 L
.272 .15856 L
.276 .15936 L
.28 .16017 L
.284 .16079 L
.288 .16134 L
.292 .16216 L
.296 .16354 L
.3 .1655 L
.304 .16782 L
.308 .17016 L
.312 .17233 L
.316 .1743 L
.32 .17616 L
.324 .17807 L
.328 .18014 L
.332 .18243 L
.336 .18496 L
.34 .18759 L
.344 .19008 L
.348 .19217 L
.352 .19371 L
.356 .19482 L
.36 .19589 L
.364 .19744 L
.368 .19981 L
.372 .20303 L
.376 .2068 L
.38 .21063 L
.384 .21411 L
.388 .21704 L
.392 .21944 L
.396 .22146 L
.4 .22322 L
Mistroke
.404 .22479 L
.408 .22622 L
.412 .22767 L
.416 .22938 L
.42 .2317 L
.424 .23493 L
.428 .23918 L
.432 .24436 L
.436 .25019 L
.44 .25633 L
.444 .26253 L
.448 .26875 L
.452 .27508 L
.456 .28169 L
.46 .28868 L
.464 .29603 L
.468 .30357 L
.472 .31101 L
.476 .31812 L
.48 .32479 L
.484 .33106 L
.488 .33714 L
.492 .34329 L
.496 .34975 L
.5 .35662 L
.504 .36386 L
.508 .37129 L
.512 .37865 L
.516 .38569 L
.52 .39225 L
.524 .39829 L
.528 .40393 L
.532 .40935 L
.536 .41484 L
.54 .42063 L
.544 .42691 L
.548 .43378 L
.552 .44121 L
.556 .44909 L
.56 .45722 L
.564 .46536 L
.568 .47328 L
.572 .48074 L
.576 .48758 L
.58 .49368 L
.584 .49897 L
.588 .50346 L
.592 .50716 L
.596 .51014 L
.6 .5125 L
Mistroke
.604 .51432 L
.608 .5157 L
.612 .51671 L
.616 .51744 L
.62 .51795 L
.624 .5183 L
.628 .51853 L
.632 .51868 L
.636 .51877 L
.64 .51881 L
.644 .51882 L
.648 .51881 L
.652 .51878 L
.656 .51875 L
.66 .51872 L
.664 .51868 L
.668 .51864 L
.672 .5186 L
.676 .51855 L
.68 .51851 L
.684 .51847 L
.688 .51843 L
.692 .51838 L
.696 .51834 L
.7 .51829 L
.704 .51825 L
.708 .5182 L
.712 .51816 L
.716 .51812 L
.72 .51807 L
.724 .51803 L
.728 .51798 L
.732 .51794 L
.736 .5179 L
.74 .51785 L
.744 .51781 L
.748 .51776 L
.752 .51772 L
.756 .51767 L
.76 .51763 L
.764 .51759 L
.768 .51754 L
.772 .5175 L
.776 .51745 L
.78 .51741 L
.784 .51737 L
.788 .51732 L
.792 .51728 L
.796 .51723 L
.8 .51719 L
Mistroke
.804 .51714 L
.808 .5171 L
.812 .51706 L
.816 .51701 L
.82 .51697 L
.824 .51692 L
.828 .51688 L
.832 .51683 L
.836 .51679 L
.84 .51675 L
.844 .5167 L
.848 .51666 L
.852 .51661 L
.856 .51657 L
.86 .51652 L
.864 .51648 L
.868 .51643 L
.872 .51639 L
.876 .51635 L
.88 .5163 L
.884 .51626 L
.888 .51622 L
.892 .51617 L
.896 .51613 L
.9 .51608 L
.904 .51604 L
.908 .51599 L
.912 .51595 L
.916 .5159 L
.92 .51586 L
.924 .51581 L
.928 .51577 L
.932 .51572 L
.936 .51569 L
.94 .51563 L
.944 .5156 L
.948 .51554 L
.952 .51551 L
.956 .51546 L
.96 .51542 L
.964 .51536 L
.968 .51533 L
.972 .51528 L
.976 .51525 L
.98 .51519 L
.984 .51516 L
.988 .51509 L
.992 .51507 L
.996 .515 L
1 .51499 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008003Aoo`8003Moo`002goo0P002Woo0P000goo0`000goo00<007ooOol0<goo00<007oo0000=Woo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2000`Ool01`00Oomoogoo001oo`0003Io
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000=Ool30004Ool20007
Ool30004Ool20004Ool20003Ool50003Ool30004Ool20003Ool50003Ool20004Ool20004Ool50002
Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol02goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00H007ooOol007oo0002Ool30002Ool20002Ool01000Oomoo`000Woo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo00H007ooOol007oo0003
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00<007oo00000`000goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0004Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
47oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Ool0
00001Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol02goo10000goo00@0
07ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool200000goo001oo`04Ool01000Oomoogoo
10000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=o
o`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol0
0Woo0P0037oo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool200000goo
001oo`03Ool20003Ool00`00Ool00004Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000ROol2
000<Ool50003Ool20008Ool00`00Oomoo`03Ool20003Ool30006Ool01000Oomoogoo1@000goo0P00
17oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`0WOol00`00
Oomoo`0>Ool2000bOol0029oo`8002Qoo`03001oogoo00moo`80035oo`008WooH`0037oo000ROol0
0`00Ool0000200001Goo00000000Ool00`0000=oo`0000000P000Woo20000goo00D007ooOomoo`00
00=oo`03001oogoo008000=oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol0000<Ool0029oo`80009oo`<00004Ool00000Ool40002Ool50003Ool3000=Ool00`00Oomo
o`13Ool0029oo`8001Uoo`<0009oo`<00003Ool0000000=oo`03001oogoo04=oo`008Woo0P006Woo
0`0000Qoo`00Ool007oo001oo`000Woo00<007ooOol0@goo000ROol2000MOol20002Ool00`00Oomo
o`040015Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo02Aoo`8004Io
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03
001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=o
o`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2
001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomo
o`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]o
o`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`80
06eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogoo
Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0
009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02OolM001<
Ool002Qoo`03001oogoo01Yoo`8004Yoo`00:7oo00<007ooOol077oo0`00Agoo000;Ool20004Ool0
0`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0OOol20015Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`008Woo0`00@goo0003Ool5
0002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`0097oo0`00
@Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;
Ool30004Ool20007Ool30004Ool2000017oo000007oo0P000goo0`000goo0`0017oo0P000Woo1@00
0goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol0
00Moo`03001oogoo009oo`05001oogoo001oo`020002Ool01@00Oomoogoo00000goo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<0
07ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool2
00000goo001oo`02Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oo`000003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`00
1Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0
009oo`04001oo`000002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qo
o`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`<000=oo`04001oogooOol5
0003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo
02Yoo`03001oogoo03Uoo`00:7oo00<007ooOol0:Woo0P00>Woo000XOomM000<Ool002Qoo`03001o
ogoo00moo`03001oogoo011oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00moo`03001o
ogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0;Goo00<007ooOol0=Woo000XOol00`00Oomo
o`0]Ool2000gOol002Qoo`03001oogoo02ioo`8003Ioo`00:7oo00<007ooOol0;goo0P00=Goo000X
Ool00`00Oomoo`0`Ool00`00Oomoo`0cOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=o
o`<000=oo`03001oogoo031oo`8003Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00
Oomoo`00Ool000=oo`04001oogoo000cOol00`00Oomoo`0bOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000dOol00`00Oomoo`0aOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008003Aoo`03001oogoo031oo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0=7oo
9P0037oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007oo
Ool0IWoo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo
1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo
001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
0`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0
3Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P00
17oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007oo
Ool000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo
011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool0
01aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002
Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomo
ogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Ool000020003Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`0NOol3001AOol001aoo`80025oo`80
051oo`0077oo00<007ooOol08Woo0P00CWoo000LOol00`00Oomoo`0TOol00`00Oomoo`1;Ool001ao
o`8002Ioo`8004]oo`0077oo00<007ooOol09Woo0`00BGoo000LOol00`00Oomoo`0YOol00`00Oomo
o`16Ool001aoo`8002]oo`03001oogoo04Eoo`0077oo00<007ooOol0:goo00<007ooOol0A7oo000L
Ool2000/Ool20015Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo02aoo`03001o
ogoo04=oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0/Ool20014Ool0
00Yoo`04001oogoo000;Ool00`00Oomoo`02000^Ool00`00Oomoo`12Ool000Yoo`04001oogoo000;
Ool01000Oomoo`00<7oo00<007ooOol0@Goo000:Ool01000Oomoo`001goo10000goo00<007ooOol0
;Woo00<007ooOol0@Goo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00<7oo00<007ooOol0
@7oo000;Ool20008Ool50002Ool00`00Oomoo`0_Ool20011Ool001aoo`03001oogoo031oo`03001o
ogoo03moo`0077oo0P00<Goo0P00@7oo000LOol00`00Oomoo`0aOol00`00Oomoo`0nOol001aoo`80
03=oo`03001oogoo03eoo`0077oo00<007ooOol0<Woo0P00?Woo000LOol00`00Oomoo`0cOol00`00
Oomoo`0lOol001aoo`8003Aoo`8003eoo`005Woo0`000goo00<007ooOol0=7oo0P00?7oo000GOol0
0`00Oomoo`02Ool00`00Oomoo`0eOol00`00Oomoo`0jOol001Moo`03001oogoo009oo`8003Ioo`80
03]oo`005goo00<007ooOol00Woo00<007ooOol0=Woo00<007ooOol0>Goo000GOol00`00Oomoo`02
Ool00`00Oomoo`0gOol00`00Oomoo`0hOol001Ioo`8000Aoo`8003Qoo`03001oogoo03Qoo`005goo
00<007ooOol00Woo00<007ooOol0>7oo00<007ooOol0=goo000LOol00`00Oomoo`0hOol00`00Oomo
o`0gOol001aoo`8003Yoo`03001oogoo03Ioo`0077oo00<007ooOol0>Goo0P00=goo000LOol2000k
Ool2000fOol001aoo`03001oogoo03]oob/000aoo`0077oo00<007ooOol0LWoo000:Ool30004Ool0
0`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001o
ogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00
Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(15197\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31172 m
.008 .31531 L
.012 .3209 L
.016 .32506 L
.02 .32733 L
.024 .32714 L
.028 .32422 L
.032 .32062 L
.036 .31687 L
.04 .31453 L
.044 .31384 L
.048 .31481 L
.052 .31726 L
.056 .31941 L
.06 .32089 L
.064 .32136 L
.068 .32111 L
.072 .32039 L
.076 .3193 L
.08 .31884 L
.084 .31918 L
.088 .32008 L
.092 .32076 L
.096 .32078 L
.1 .32051 L
.104 .32011 L
.108 .31936 L
.112 .31795 L
.116 .31653 L
.12 .31609 L
.124 .31656 L
.128 .31716 L
.132 .31773 L
.136 .31907 L
.14 .32154 L
.144 .3242 L
.148 .32565 L
.152 .32538 L
.156 .32397 L
.16 .32213 L
.164 .31985 L
.168 .31695 L
.172 .31414 L
.176 .3127 L
.18 .31325 L
.184 .31497 L
.188 .31649 L
.192 .31699 L
.196 .317 L
.2 .31785 L
Mistroke
.204 .32044 L
.208 .32446 L
.212 .32848 L
.216 .33095 L
.22 .33115 L
.224 .32952 L
.228 .32669 L
.232 .32278 L
.236 .31763 L
.24 .31194 L
.244 .30789 L
.248 .30776 L
.252 .3116 L
.256 .31634 L
.26 .318 L
.264 .31512 L
.268 .31044 L
.272 .30866 L
.276 .31221 L
.28 .31897 L
.284 .32417 L
.288 .32456 L
.292 .32115 L
.296 .31808 L
.3 .31894 L
.304 .32396 L
.308 .3304 L
.312 .33524 L
.316 .33749 L
.32 .33832 L
.324 .3394 L
.328 .34144 L
.332 .34403 L
.336 .34661 L
.34 .34898 L
.344 .35092 L
.348 .35156 L
.352 .34953 L
.356 .34428 L
.36 .33733 L
.364 .33207 L
.368 .33185 L
.372 .33742 L
.376 .346 L
.38 .3526 L
.384 .3531 L
.388 .34686 L
.392 .33716 L
.396 .32916 L
.4 .3268 L
Mistroke
.404 .33077 L
.408 .33865 L
.412 .34682 L
.416 .35282 L
.42 .35637 L
.424 .35874 L
.428 .36106 L
.432 .3629 L
.436 .36218 L
.44 .35642 L
.444 .34446 L
.448 .32752 L
.452 .30886 L
.456 .29229 L
.46 .28036 L
.464 .27327 L
.468 .26898 L
.472 .26453 L
.476 .25762 L
.48 .24785 L
.484 .23678 L
.488 .22714 L
.492 .2214 L
.496 .22062 L
.5 .2239 L
.504 .22882 L
.508 .23243 L
.512 .23245 L
.516 .22814 L
.52 .22046 L
.524 .21162 L
.528 .2042 L
.532 .20023 L
.536 .20057 L
.54 .20481 L
.544 .21147 L
.548 .21857 L
.552 .22411 L
.556 .22649 L
.56 .2248 L
.564 .21897 L
.568 .20977 L
.572 .19874 L
.576 .1878 L
.58 .17885 L
.584 .17328 L
.588 .17175 L
.592 .17423 L
.596 .18021 L
.6 .18899 L
Mistroke
.604 .19989 L
.608 .21224 L
.612 .22527 L
.616 .23813 L
.62 .25001 L
.624 .2604 L
.628 .26916 L
.632 .27648 L
.636 .28263 L
.64 .28778 L
.644 .29188 L
.648 .29489 L
.652 .29689 L
.656 .29819 L
.66 .29916 L
.664 .30005 L
.668 .30086 L
.672 .30144 L
.676 .30166 L
.68 .30159 L
.684 .30146 L
.688 .30151 L
.692 .30175 L
.696 .30202 L
.7 .30209 L
.704 .30193 L
.708 .30171 L
.712 .30162 L
.716 .30174 L
.72 .30196 L
.724 .30207 L
.728 .30198 L
.732 .30177 L
.736 .30165 L
.74 .30171 L
.744 .30189 L
.748 .30201 L
.752 .30198 L
.756 .30181 L
.76 .30168 L
.764 .30169 L
.768 .30183 L
.772 .30197 L
.776 .30196 L
.78 .30183 L
.784 .30169 L
.788 .30168 L
.792 .3018 L
.796 .30193 L
.8 .30193 L
Mistroke
.804 .30181 L
.808 .30169 L
.812 .30169 L
.816 .3018 L
.82 .3019 L
.824 .30189 L
.828 .30179 L
.832 .3017 L
.836 .3017 L
.84 .30179 L
.844 .30187 L
.848 .30185 L
.852 .30176 L
.856 .3017 L
.86 .30172 L
.864 .30179 L
.868 .30184 L
.872 .3018 L
.876 .30174 L
.88 .30171 L
.884 .30173 L
.888 .30178 L
.892 .3018 L
.896 .30177 L
.9 .30173 L
.904 .30172 L
.908 .30173 L
.912 .30175 L
.916 .30177 L
.92 .30174 L
.924 .30172 L
.928 .30172 L
.932 .30172 L
.936 .30172 L
.94 .30174 L
.944 .30173 L
.948 .30172 L
.952 .30172 L
.956 .3017 L
.96 .30169 L
.964 .30172 L
.968 .30173 L
.972 .30172 L
.976 .3017 L
.98 .30168 L
.984 .30167 L
.988 .30172 L
.992 .30174 L
.996 .3017 L
1 .30167 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13997 m
.008 .14267 L
.012 .14346 L
.016 .14243 L
.02 .14201 L
.024 .14229 L
.028 .14236 L
.032 .14234 L
.036 .1424 L
.04 .14258 L
.044 .14267 L
.048 .14272 L
.052 .14268 L
.056 .1426 L
.06 .14246 L
.064 .14235 L
.068 .14225 L
.072 .14221 L
.076 .14223 L
.08 .14233 L
.084 .14246 L
.088 .14259 L
.092 .14267 L
.096 .14273 L
.1 .14273 L
.104 .14269 L
.108 .14258 L
.112 .14246 L
.116 .14237 L
.12 .14232 L
.124 .14226 L
.128 .14221 L
.132 .1422 L
.136 .14227 L
.14 .14235 L
.144 .14243 L
.148 .14249 L
.152 .1426 L
.156 .14276 L
.16 .14291 L
.164 .14296 L
.168 .14292 L
.172 .14283 L
.176 .14271 L
.18 .14253 L
.184 .14227 L
.188 .14196 L
.192 .14169 L
.196 .14157 L
.2 .14163 L
Mistroke
.204 .14179 L
.208 .142 L
.212 .14224 L
.216 .14256 L
.22 .14298 L
.224 .14342 L
.228 .14375 L
.232 .14385 L
.236 .14374 L
.24 .14354 L
.244 .14338 L
.248 .14321 L
.252 .14291 L
.256 .1424 L
.26 .14175 L
.264 .1412 L
.268 .14093 L
.272 .14089 L
.276 .14085 L
.28 .14063 L
.284 .14024 L
.288 .13992 L
.292 .13991 L
.296 .14026 L
.3 .14079 L
.304 .14127 L
.308 .1416 L
.312 .14193 L
.316 .1425 L
.32 .14351 L
.324 .14495 L
.328 .14666 L
.332 .14844 L
.336 .15016 L
.34 .15176 L
.344 .15326 L
.348 .15476 L
.352 .15634 L
.356 .15813 L
.36 .16017 L
.364 .16236 L
.368 .16448 L
.372 .16626 L
.376 .16754 L
.38 .16842 L
.384 .1692 L
.388 .17031 L
.392 .17202 L
.396 .17441 L
.4 .17727 L
Mistroke
.404 .18027 L
.408 .18311 L
.412 .18561 L
.416 .18777 L
.42 .18963 L
.424 .19123 L
.428 .19259 L
.432 .19373 L
.436 .19476 L
.44 .1959 L
.444 .19745 L
.448 .19967 L
.452 .2027 L
.456 .20649 L
.46 .21086 L
.464 .21554 L
.468 .22034 L
.472 .22519 L
.476 .23015 L
.48 .23534 L
.484 .24087 L
.488 .24671 L
.492 .25275 L
.496 .25878 L
.5 .26459 L
.504 .27006 L
.508 .2752 L
.512 .28013 L
.516 .28506 L
.52 .29018 L
.524 .29561 L
.528 .30136 L
.532 .30731 L
.536 .31329 L
.54 .31909 L
.544 .32455 L
.548 .3296 L
.552 .33428 L
.556 .33872 L
.56 .3431 L
.564 .34763 L
.568 .35249 L
.572 .35779 L
.576 .36356 L
.58 .36973 L
.584 .37619 L
.588 .38278 L
.592 .38929 L
.596 .39556 L
.6 .40141 L
Mistroke
.604 .40673 L
.608 .41144 L
.612 .41551 L
.616 .41894 L
.62 .42177 L
.624 .42406 L
.628 .42587 L
.632 .42728 L
.636 .42835 L
.64 .42915 L
.644 .42974 L
.648 .43018 L
.652 .43049 L
.656 .43071 L
.66 .43086 L
.664 .43097 L
.668 .43104 L
.672 .4311 L
.676 .43114 L
.68 .43117 L
.684 .4312 L
.688 .43122 L
.692 .43123 L
.696 .43125 L
.7 .43127 L
.704 .43128 L
.708 .43129 L
.712 .43131 L
.716 .43132 L
.72 .43133 L
.724 .43135 L
.728 .43136 L
.732 .43137 L
.736 .43139 L
.74 .4314 L
.744 .43141 L
.748 .43142 L
.752 .43144 L
.756 .43145 L
.76 .43146 L
.764 .43148 L
.768 .43149 L
.772 .4315 L
.776 .43152 L
.78 .43153 L
.784 .43154 L
.788 .43155 L
.792 .43157 L
.796 .43158 L
.8 .4316 L
Mistroke
.804 .43161 L
.808 .43162 L
.812 .43163 L
.816 .43165 L
.82 .43166 L
.824 .43167 L
.828 .43169 L
.832 .4317 L
.836 .43171 L
.84 .43173 L
.844 .43174 L
.848 .43175 L
.852 .43177 L
.856 .43178 L
.86 .43179 L
.864 .4318 L
.868 .43182 L
.872 .43183 L
.876 .43184 L
.88 .43186 L
.884 .43187 L
.888 .43188 L
.892 .43189 L
.896 .43191 L
.9 .43192 L
.904 .43194 L
.908 .43195 L
.912 .43196 L
.916 .43197 L
.92 .43199 L
.924 .432 L
.928 .43202 L
.932 .43202 L
.936 .43204 L
.94 .43205 L
.944 .43207 L
.948 .43207 L
.952 .4321 L
.956 .4321 L
.96 .43212 L
.964 .43213 L
.968 .43215 L
.972 .43215 L
.976 .43218 L
.98 .43218 L
.984 .4322 L
.988 .4322 L
.992 .43223 L
.996 .43222 L
1 .43226 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16181 L
.012 .16114 L
.016 .16079 L
.02 .16097 L
.024 .16113 L
.028 .16122 L
.032 .16124 L
.036 .16136 L
.04 .1614 L
.044 .16143 L
.048 .16136 L
.052 .1613 L
.056 .1612 L
.06 .16111 L
.064 .16104 L
.068 .16102 L
.072 .16101 L
.076 .16105 L
.08 .16112 L
.084 .16124 L
.088 .16131 L
.092 .16137 L
.096 .16141 L
.1 .16146 L
.104 .16144 L
.108 .16137 L
.112 .16126 L
.116 .16118 L
.12 .1611 L
.124 .161 L
.128 .16088 L
.132 .16083 L
.136 .16088 L
.14 .161 L
.144 .16112 L
.148 .16125 L
.152 .16142 L
.156 .16164 L
.16 .16181 L
.164 .16185 L
.168 .16177 L
.172 .16162 L
.176 .16145 L
.18 .16125 L
.184 .16096 L
.188 .1606 L
.192 .16029 L
.196 .16014 L
.2 .16019 L
Mistroke
.204 .16037 L
.208 .1606 L
.212 .1609 L
.216 .1613 L
.22 .16184 L
.224 .16241 L
.228 .16283 L
.232 .16296 L
.236 .16281 L
.24 .16256 L
.244 .16233 L
.248 .16212 L
.252 .16175 L
.256 .16111 L
.26 .16032 L
.264 .15965 L
.268 .15931 L
.272 .15925 L
.276 .15921 L
.28 .15892 L
.284 .15843 L
.288 .15803 L
.292 .15802 L
.296 .15846 L
.3 .15914 L
.304 .15974 L
.308 .16014 L
.312 .16054 L
.316 .16125 L
.32 .1625 L
.324 .16429 L
.328 .16643 L
.332 .16866 L
.336 .1708 L
.34 .17279 L
.344 .17467 L
.348 .17651 L
.352 .17848 L
.356 .18071 L
.36 .18325 L
.364 .18598 L
.368 .18862 L
.372 .19084 L
.376 .19243 L
.38 .19351 L
.384 .19447 L
.388 .19584 L
.392 .19798 L
.396 .20096 L
.4 .20452 L
Mistroke
.404 .20825 L
.408 .21177 L
.412 .21487 L
.416 .21755 L
.42 .21986 L
.424 .22185 L
.428 .22354 L
.432 .22495 L
.436 .22622 L
.44 .22762 L
.444 .22954 L
.448 .23229 L
.452 .23606 L
.456 .24078 L
.46 .24621 L
.464 .25203 L
.468 .25799 L
.472 .26401 L
.476 .27017 L
.48 .27663 L
.484 .2835 L
.488 .29077 L
.492 .29827 L
.496 .30575 L
.5 .31297 L
.504 .31976 L
.508 .32613 L
.512 .33226 L
.516 .33837 L
.52 .34471 L
.524 .35145 L
.528 .35858 L
.532 .36596 L
.536 .37338 L
.54 .38057 L
.544 .38733 L
.548 .39359 L
.552 .39938 L
.556 .40487 L
.56 .41029 L
.564 .4159 L
.568 .42191 L
.572 .42846 L
.576 .4356 L
.58 .44325 L
.584 .45126 L
.588 .45942 L
.592 .46748 L
.596 .47523 L
.6 .48247 L
Mistroke
.604 .48904 L
.608 .49485 L
.612 .49987 L
.616 .50409 L
.62 .50756 L
.624 .51035 L
.628 .51254 L
.632 .51424 L
.636 .51551 L
.64 .51646 L
.644 .51713 L
.648 .51761 L
.652 .51793 L
.656 .51814 L
.66 .51828 L
.664 .51836 L
.668 .51839 L
.672 .5184 L
.676 .51839 L
.68 .51837 L
.684 .51834 L
.688 .5183 L
.692 .51827 L
.696 .51822 L
.7 .51818 L
.704 .51813 L
.708 .51809 L
.712 .51805 L
.716 .51801 L
.72 .51796 L
.724 .51792 L
.728 .51787 L
.732 .51783 L
.736 .51779 L
.74 .51774 L
.744 .5177 L
.748 .51765 L
.752 .51761 L
.756 .51756 L
.76 .51752 L
.764 .51748 L
.768 .51743 L
.772 .51739 L
.776 .51734 L
.78 .5173 L
.784 .51726 L
.788 .51721 L
.792 .51717 L
.796 .51712 L
.8 .51708 L
Mistroke
.804 .51703 L
.808 .51699 L
.812 .51695 L
.816 .5169 L
.82 .51686 L
.824 .51681 L
.828 .51677 L
.832 .51672 L
.836 .51668 L
.84 .51664 L
.844 .51659 L
.848 .51655 L
.852 .5165 L
.856 .51646 L
.86 .51641 L
.864 .51637 L
.868 .51633 L
.872 .51628 L
.876 .51624 L
.88 .51619 L
.884 .51615 L
.888 .51611 L
.892 .51606 L
.896 .51602 L
.9 .51597 L
.904 .51593 L
.908 .51588 L
.912 .51584 L
.916 .51579 L
.92 .51575 L
.924 .5157 L
.928 .51567 L
.932 .51561 L
.936 .51558 L
.94 .51552 L
.944 .51549 L
.948 .51543 L
.952 .5154 L
.956 .51535 L
.96 .51531 L
.964 .51526 L
.968 .51523 L
.972 .51517 L
.976 .51514 L
.98 .51508 L
.984 .51505 L
.988 .51498 L
.992 .51496 L
.996 .5149 L
1 .51488 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02000gOol2000dOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008003Moo`8003Aoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0=Goo00@007oo
Ool003=oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00<Woo0P000Woo00@007oo
Ool003=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000=Ool30004
Ool20007Ool30004Ool20004Ool20005Ool300000goo001oo`030004Ool20003Ool50003Ool20004
Ool20004Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol02goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00D007ooOol007oo00800004Ool00000Ool30003Ool01000Oomo
o`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo
00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00<007ooOol01@0000=oo`00Ool01Woo00@007ooOol0009oo`03
001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0
009oo`03001oogoo008000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0002
Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0
2goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool00`00Oomoo`020004
Ool01000Oomoogoo100000Aoo`00Ool0009oo`04001oogoo0003Ool01000Oomoo`000Woo00@007oo
Ool0009oo`05001oogooOol00003Ool00`00Ool000030003Ool01000Oomoo`001Goo000;Ool2000:
Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@0
07ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`02Ool00`00Ool00002Ool01000Oomo
o`000goo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000goo00<007oo00001Woo
00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0`001Goo
00@007ooOomoo`L00003Ool0000000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Io
o`008Woo00<007ooOol0:Woo00<007ooOol03Woo00<007ooOol0;Woo000ROol2000[Ool00`00Oomo
o`0?Ool2000^Ool0029oof<000aoo`008Woo0P000Woo0P000Woo00<007ooOol00`000Woo1@000Woo
1@0000Aoo`00Ool000=oo`05001oogooOol00003Ool20002Ool01@00Oomoogoo00000goo00D007oo
Oomoo`00009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo000037oo000ROol40002Ool2000017oo000000000Woo0`00
0goo100017oo0`0027oo00<007ooOol00Woo00<007ooOol0@7oo000ROol00`00Oomoo`0BOol20007
Ool30002Ool2000017oo001oo`000goo00<007ooOol0@7oo000ROol2000NOol400001Goo000007oo
00000Woo00<007ooOol0@Goo000ROol2000POol00`00Oomoo`020002Ool00`00Ool00013Ool000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo02Moo`8004=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2
000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80
009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06ao
o`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo
00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`80
00=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=o
o`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<0
07ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00
Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007oo
Oomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool0
0`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P00
17oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02OolO001:Ool002Qoo`03001o
ogoo01aoo`<004Moo`00:7oo00<007ooOol07Woo1000A7oo000;Ool20004Ool00`00Oomoo`03Ool2
0004Ool20003Ool30003Ool00`00Oomoo`0QOol20013Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00H007ooOol007oo0003Ool01000Oomoo`0097oo0`00@Goo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`009goo0P00?goo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007
Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002
Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@0
00=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oo`000003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001o
ogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogoo
Ool00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo
0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007ooOol00P000Woo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`00
0Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<0
07ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool00`00Oomo
o`020002Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomo
o`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`05001oogoo001o
o`030003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D0
00=oo`8000Qoo`03001oogoo00=oo`8000Aoo`80009oo`<000=oo`D000=oo`8000=oo`<000Aoo`80
00Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0;7oo0P00>7oo000XOol00`00
Oomoo`0]Ool00`00Oomoo`0fOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo
00<007ooOol02Goo00<007ooOol00goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo
000XOol00`00Oomoo`0_Ool2000eOol002Qoo`03001oogoo031oo`03001oogoo03=oo`00:7oo00<0
07ooOol0<Goo00<007ooOol0<Woo000XOol00`00Oomoo`0aOol2000cOol002Qoo`03001oogoo039o
o`80039oo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0<goo
00<007ooOol0<7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo
00@007ooOol003Ioo`03001oogoo02moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`001Goo00@007ooOol003Ioo`80031oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol00P00=Woo0P00;goo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`05001oogoo001oo`040003Ool00`00Oomoo`0fOolT000<Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80
009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007oo
Ool0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001o
ogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo
000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007oo
Ool00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@0
00=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P00
27oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004
Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006
Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=o
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@0
07ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo
00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0
009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo
10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03
001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=o
o`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`80
00Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004
Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`04001oogooOol300000goo001oo`03Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000L
Ool00`00Oomoo`0QOol2001?Ool001aoo`8002=oo`<004eoo`0077oo00<007ooOol097oo0`00Bgoo
000LOol00`00Oomoo`0WOol00`00Oomoo`18Ool001aoo`8002Uoo`8004Qoo`0077oo00<007ooOol0
:Goo0`00AWoo000LOol00`00Oomoo`0/Ool00`00Oomoo`13Ool001aoo`8002ioo`03001oogoo049o
o`0077oo00<007ooOol0;Goo0P00@goo000LOol2000_Ool00`00Oomoo`11Ool000]oo`8000Aoo`03
001oogoo009oo`<000=oo`03001oogoo02ioo`80049oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`0_Ool00`00Oomoo`10Ool000Yoo`04001oogoo000;Ool00`00Oomoo`02
000aOol00`00Oomoo`0oOol000Yoo`04001oogoo000;Ool01000Oomoo`00<Woo00<007ooOol0?goo
000:Ool01000Oomoo`001goo10000goo00<007ooOol0<Goo00<007ooOol0?Woo000:Ool01000Oomo
o`001goo00<007ooOol017oo0P00<Woo0P00?goo000;Ool20008Ool50002Ool00`00Oomoo`0bOol0
0`00Oomoo`0mOol001aoo`03001oogoo03=oo`03001oogoo03aoo`0077oo0P00=7oo00<007ooOol0
?7oo000LOol00`00Oomoo`0dOol00`00Oomoo`0kOol001aoo`8003Ioo`03001oogoo03Yoo`0077oo
00<007ooOol0=Goo00<007ooOol0>Woo000LOol00`00Oomoo`0eOol2000kOol001aoo`8003Moo`80
03Yoo`005Woo0`000goo00<007ooOol0=goo00<007ooOol0>7oo000GOol00`00Oomoo`02Ool00`00
Oomoo`0hOol00`00Oomoo`0gOol001Moo`03001oogoo009oo`8003Uoo`03001oogoo03Moo`005goo
00<007ooOol00Woo00<007ooOol0>Goo00<007ooOol0=Woo000GOol00`00Oomoo`02Ool00`00Oomo
o`0jOol00`00Oomoo`0eOol001Ioo`8000Aoo`8003]oo`03001oogoo03Eoo`005goo00<007ooOol0
0Woo00<007ooOol0>Woo00<007ooOol0=Goo000LOol00`00Oomoo`0kOol00`00Oomoo`0dOol001ao
o`8003eoo`03001oogoo03=oo`0077oo00<007ooOol0?7oo00<007ooOol0<goo000LOol2000nOol2
000cOol001aoo`03001oogoo03ioobP000aoo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00
Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo
008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomo
o`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(15364\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3181 m
.008 .31592 L
.012 .3148 L
.016 .31543 L
.02 .31642 L
.024 .3185 L
.028 .32073 L
.032 .32143 L
.036 .32127 L
.04 .31992 L
.044 .31858 L
.048 .3178 L
.052 .31785 L
.056 .31899 L
.06 .32012 L
.064 .32122 L
.068 .32166 L
.072 .32109 L
.076 .31969 L
.08 .31776 L
.084 .3165 L
.088 .31619 L
.092 .31672 L
.096 .31773 L
.1 .31906 L
.104 .32085 L
.108 .32229 L
.112 .32274 L
.116 .32232 L
.12 .32179 L
.124 .32129 L
.128 .32002 L
.132 .3179 L
.136 .31584 L
.14 .31491 L
.144 .31523 L
.148 .31623 L
.152 .31762 L
.156 .3196 L
.16 .32209 L
.164 .32396 L
.168 .32401 L
.172 .32239 L
.176 .32064 L
.18 .3201 L
.184 .3208 L
.188 .32167 L
.192 .32168 L
.196 .32051 L
.2 .31842 L
Mistroke
.204 .31578 L
.208 .31291 L
.212 .31058 L
.216 .30994 L
.22 .31213 L
.224 .31733 L
.228 .32406 L
.232 .32962 L
.236 .33164 L
.24 .32984 L
.244 .32633 L
.248 .32396 L
.252 .32376 L
.256 .32414 L
.26 .32266 L
.264 .31865 L
.268 .31403 L
.272 .31144 L
.276 .31157 L
.28 .31253 L
.284 .31219 L
.288 .31062 L
.292 .31023 L
.296 .31314 L
.3 .31848 L
.304 .32268 L
.308 .32257 L
.312 .31845 L
.316 .31416 L
.32 .31394 L
.324 .31897 L
.328 .32655 L
.332 .33255 L
.336 .3346 L
.34 .33357 L
.344 .33229 L
.348 .33314 L
.352 .33654 L
.356 .34133 L
.36 .34603 L
.364 .34967 L
.368 .35161 L
.372 .35112 L
.376 .34759 L
.38 .34144 L
.384 .33475 L
.388 .33067 L
.392 .33163 L
.396 .33753 L
.4 .34537 L
Mistroke
.404 .35079 L
.408 .35066 L
.412 .34489 L
.416 .33644 L
.42 .32944 L
.424 .32681 L
.428 .32896 L
.432 .33414 L
.436 .33999 L
.44 .34517 L
.444 .34979 L
.448 .35468 L
.452 .36002 L
.456 .3645 L
.46 .36562 L
.464 .361 L
.468 .34976 L
.472 .33333 L
.476 .31493 L
.48 .29817 L
.484 .28545 L
.488 .27708 L
.492 .27135 L
.496 .2657 L
.5 .25808 L
.504 .24797 L
.508 .23659 L
.512 .22625 L
.516 .21927 L
.52 .21691 L
.524 .21884 L
.528 .22323 L
.532 .22743 L
.536 .22895 L
.54 .22634 L
.544 .21973 L
.548 .21075 L
.552 .20199 L
.556 .19601 L
.56 .19445 L
.564 .19752 L
.568 .204 L
.572 .21176 L
.576 .21851 L
.58 .22238 L
.584 .22233 L
.588 .21816 L
.592 .2104 L
.596 .20014 L
.6 .1889 L
Mistroke
.604 .17844 L
.608 .17045 L
.612 .16621 L
.616 .16628 L
.62 .1705 L
.624 .17812 L
.628 .18827 L
.632 .20013 L
.636 .213 L
.64 .22624 L
.644 .23915 L
.648 .25106 L
.652 .26144 L
.656 .27013 L
.66 .27729 L
.664 .28322 L
.668 .28814 L
.672 .29209 L
.676 .29504 L
.68 .29704 L
.684 .29834 L
.688 .29928 L
.692 .30011 L
.696 .30087 L
.7 .3014 L
.704 .30163 L
.708 .3016 L
.712 .30153 L
.716 .3016 L
.72 .3018 L
.724 .30199 L
.728 .30203 L
.732 .30191 L
.736 .30175 L
.74 .30171 L
.744 .30182 L
.748 .30197 L
.752 .30203 L
.756 .30194 L
.76 .30178 L
.764 .30172 L
.768 .30179 L
.772 .30193 L
.776 .302 L
.78 .30192 L
.784 .30179 L
.788 .30172 L
.792 .30179 L
.796 .30191 L
.8 .30196 L
Mistroke
.804 .3019 L
.808 .30178 L
.812 .30173 L
.816 .30179 L
.82 .30189 L
.824 .30192 L
.828 .30186 L
.832 .30177 L
.836 .30174 L
.84 .3018 L
.844 .30187 L
.848 .30188 L
.852 .30183 L
.856 .30177 L
.86 .30175 L
.864 .3018 L
.868 .30185 L
.872 .30184 L
.876 .3018 L
.88 .30176 L
.884 .30176 L
.888 .30179 L
.892 .30182 L
.896 .30181 L
.9 .30179 L
.904 .30176 L
.908 .30176 L
.912 .30177 L
.916 .3018 L
.92 .30179 L
.924 .30177 L
.928 .30176 L
.932 .30175 L
.936 .30175 L
.94 .30178 L
.944 .30177 L
.948 .30176 L
.952 .30175 L
.956 .30173 L
.96 .30173 L
.964 .30177 L
.968 .30177 L
.972 .30175 L
.976 .30173 L
.98 .30171 L
.984 .30171 L
.988 .30176 L
.992 .30177 L
.996 .30173 L
1 .3017 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14135 m
.008 .14264 L
.012 .14314 L
.016 .14295 L
.02 .14284 L
.024 .14301 L
.028 .14306 L
.032 .143 L
.036 .14286 L
.04 .14276 L
.044 .14267 L
.048 .14264 L
.052 .14265 L
.056 .14274 L
.06 .14284 L
.064 .14298 L
.068 .14305 L
.072 .14309 L
.076 .14303 L
.08 .14295 L
.084 .14284 L
.088 .14273 L
.092 .14263 L
.096 .1426 L
.1 .14263 L
.104 .14273 L
.108 .14282 L
.112 .14291 L
.116 .14299 L
.12 .14307 L
.124 .14308 L
.128 .14303 L
.132 .14296 L
.136 .14291 L
.14 .14286 L
.144 .14278 L
.148 .14268 L
.152 .14261 L
.156 .14259 L
.16 .14262 L
.164 .14264 L
.168 .14267 L
.172 .14276 L
.176 .14293 L
.18 .14312 L
.184 .14326 L
.188 .14331 L
.192 .14331 L
.196 .14327 L
.2 .1432 L
Mistroke
.204 .14303 L
.208 .14275 L
.212 .14243 L
.216 .14218 L
.22 .14205 L
.224 .14204 L
.228 .14209 L
.232 .14218 L
.236 .14236 L
.24 .14269 L
.244 .14316 L
.248 .14366 L
.252 .144 L
.256 .14411 L
.26 .14406 L
.264 .144 L
.268 .14397 L
.272 .14387 L
.276 .14355 L
.28 .14297 L
.284 .14232 L
.288 .14183 L
.292 .14162 L
.296 .14156 L
.3 .14143 L
.304 .14108 L
.308 .14061 L
.312 .14028 L
.316 .14028 L
.32 .14059 L
.324 .14102 L
.328 .14135 L
.332 .14156 L
.336 .14179 L
.34 .14226 L
.344 .14313 L
.348 .14441 L
.352 .14597 L
.356 .14767 L
.36 .14937 L
.364 .15097 L
.368 .15246 L
.372 .15389 L
.376 .15539 L
.38 .15712 L
.384 .15916 L
.388 .16142 L
.392 .16364 L
.396 .16552 L
.4 .16688 L
Mistroke
.404 .16777 L
.408 .1685 L
.412 .16949 L
.416 .17103 L
.42 .17321 L
.424 .17588 L
.428 .17875 L
.432 .18157 L
.436 .18418 L
.44 .18653 L
.444 .18862 L
.448 .19044 L
.452 .19193 L
.456 .19311 L
.46 .19407 L
.464 .19502 L
.468 .19629 L
.472 .19816 L
.476 .20081 L
.48 .20423 L
.484 .20825 L
.488 .21264 L
.492 .21721 L
.496 .22188 L
.5 .22669 L
.504 .23174 L
.508 .23713 L
.512 .24288 L
.516 .24887 L
.52 .25491 L
.524 .26079 L
.528 .26637 L
.532 .2716 L
.536 .27658 L
.54 .28149 L
.544 .28654 L
.548 .29186 L
.552 .2975 L
.556 .3034 L
.56 .30939 L
.564 .31528 L
.568 .32089 L
.572 .32612 L
.576 .33095 L
.58 .33548 L
.584 .33985 L
.588 .34428 L
.592 .34896 L
.596 .35402 L
.6 .35953 L
Mistroke
.604 .36549 L
.608 .3718 L
.612 .37833 L
.616 .3849 L
.62 .39133 L
.624 .39745 L
.628 .4031 L
.632 .40821 L
.636 .41269 L
.64 .41654 L
.644 .41978 L
.648 .42244 L
.652 .42458 L
.656 .42627 L
.66 .42758 L
.664 .42858 L
.668 .42933 L
.672 .42988 L
.676 .43028 L
.68 .43058 L
.684 .43078 L
.688 .43093 L
.692 .43103 L
.696 .4311 L
.7 .43116 L
.704 .4312 L
.708 .43123 L
.712 .43125 L
.716 .43127 L
.72 .43129 L
.724 .4313 L
.728 .43132 L
.732 .43134 L
.736 .43135 L
.74 .43136 L
.744 .43137 L
.748 .43139 L
.752 .4314 L
.756 .43141 L
.76 .43143 L
.764 .43144 L
.768 .43145 L
.772 .43146 L
.776 .43148 L
.78 .43149 L
.784 .43151 L
.788 .43152 L
.792 .43153 L
.796 .43154 L
.8 .43156 L
Mistroke
.804 .43157 L
.808 .43158 L
.812 .4316 L
.816 .43161 L
.82 .43162 L
.824 .43164 L
.828 .43165 L
.832 .43166 L
.836 .43167 L
.84 .43169 L
.844 .4317 L
.848 .43172 L
.852 .43173 L
.856 .43174 L
.86 .43175 L
.864 .43177 L
.868 .43178 L
.872 .43179 L
.876 .43181 L
.88 .43182 L
.884 .43183 L
.888 .43185 L
.892 .43186 L
.896 .43187 L
.9 .43188 L
.904 .4319 L
.908 .43191 L
.912 .43192 L
.916 .43193 L
.92 .43195 L
.924 .43196 L
.928 .43198 L
.932 .43199 L
.936 .432 L
.94 .43201 L
.944 .43203 L
.948 .43204 L
.952 .43206 L
.956 .43206 L
.96 .43208 L
.964 .43209 L
.968 .43211 L
.972 .43211 L
.976 .43214 L
.98 .43214 L
.984 .43217 L
.988 .43216 L
.992 .43219 L
.996 .43219 L
1 .43222 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15934 L
.012 .16132 L
.016 .1619 L
.02 .16128 L
.024 .16105 L
.028 .16128 L
.032 .16129 L
.036 .16118 L
.04 .1611 L
.044 .1611 L
.048 .16108 L
.052 .16111 L
.056 .16114 L
.06 .16123 L
.064 .16129 L
.068 .16138 L
.072 .16139 L
.076 .16138 L
.08 .16131 L
.084 .16125 L
.088 .16114 L
.092 .16103 L
.096 .16097 L
.1 .16098 L
.104 .16104 L
.108 .16112 L
.112 .16121 L
.116 .16134 L
.12 .16146 L
.124 .16152 L
.128 .16149 L
.132 .16142 L
.136 .16133 L
.14 .16124 L
.144 .16111 L
.148 .16096 L
.152 .16086 L
.156 .16087 L
.16 .16093 L
.164 .16098 L
.168 .16104 L
.172 .16115 L
.176 .16134 L
.18 .16156 L
.184 .16171 L
.188 .16176 L
.192 .16176 L
.196 .16174 L
.2 .16167 L
Mistroke
.204 .16147 L
.208 .16113 L
.212 .16072 L
.216 .16038 L
.22 .16021 L
.224 .16019 L
.228 .16026 L
.232 .16038 L
.236 .16062 L
.24 .16103 L
.244 .16163 L
.248 .16223 L
.252 .16265 L
.256 .16279 L
.26 .16272 L
.264 .16265 L
.268 .16261 L
.272 .16249 L
.276 .1621 L
.28 .16138 L
.284 .16057 L
.288 .15995 L
.292 .15968 L
.296 .15961 L
.3 .15944 L
.304 .15901 L
.308 .15843 L
.312 .15803 L
.316 .15803 L
.32 .15842 L
.324 .15894 L
.328 .15935 L
.332 .1596 L
.336 .15989 L
.34 .16049 L
.344 .16158 L
.348 .16317 L
.352 .16512 L
.356 .16722 L
.36 .16933 L
.364 .17133 L
.368 .17319 L
.372 .17497 L
.376 .17685 L
.38 .179 L
.384 .18154 L
.388 .18434 L
.392 .1871 L
.396 .18944 L
.4 .19113 L
Mistroke
.404 .19224 L
.408 .19315 L
.412 .19437 L
.416 .19628 L
.42 .19899 L
.424 .2023 L
.428 .20587 L
.432 .20938 L
.436 .21263 L
.44 .21555 L
.444 .21815 L
.448 .22039 L
.452 .22225 L
.456 .2237 L
.46 .22489 L
.464 .22607 L
.468 .22764 L
.472 .22996 L
.476 .23325 L
.48 .23749 L
.484 .24249 L
.488 .24795 L
.492 .25364 L
.496 .25944 L
.5 .26541 L
.504 .27169 L
.508 .27839 L
.512 .28553 L
.516 .29298 L
.52 .30048 L
.524 .30778 L
.528 .3147 L
.532 .32119 L
.536 .32737 L
.54 .33347 L
.544 .33972 L
.548 .34632 L
.552 .35332 L
.556 .36064 L
.56 .36807 L
.564 .37538 L
.568 .38234 L
.572 .38881 L
.576 .39479 L
.58 .40038 L
.584 .4058 L
.588 .41128 L
.592 .41707 L
.596 .42333 L
.6 .43015 L
Mistroke
.604 .43752 L
.608 .44535 L
.612 .45344 L
.616 .46158 L
.62 .46954 L
.624 .4771 L
.628 .48409 L
.632 .49039 L
.636 .49593 L
.64 .50067 L
.644 .50465 L
.648 .5079 L
.652 .51051 L
.656 .51255 L
.66 .51413 L
.664 .51531 L
.668 .51619 L
.672 .51682 L
.676 .51726 L
.68 .51756 L
.684 .51775 L
.688 .51788 L
.692 .51795 L
.696 .51798 L
.7 .51799 L
.704 .51797 L
.708 .51795 L
.712 .51792 L
.716 .51788 L
.72 .51785 L
.724 .5178 L
.728 .51776 L
.732 .51772 L
.736 .51767 L
.74 .51763 L
.744 .51759 L
.748 .51754 L
.752 .5175 L
.756 .51745 L
.76 .51741 L
.764 .51737 L
.768 .51732 L
.772 .51728 L
.776 .51723 L
.78 .51719 L
.784 .51714 L
.788 .5171 L
.792 .51706 L
.796 .51701 L
.8 .51697 L
Mistroke
.804 .51692 L
.808 .51688 L
.812 .51684 L
.816 .51679 L
.82 .51675 L
.824 .5167 L
.828 .51666 L
.832 .51661 L
.836 .51657 L
.84 .51653 L
.844 .51648 L
.848 .51644 L
.852 .51639 L
.856 .51635 L
.86 .5163 L
.864 .51626 L
.868 .51622 L
.872 .51617 L
.876 .51613 L
.88 .51608 L
.884 .51604 L
.888 .516 L
.892 .51595 L
.896 .51591 L
.9 .51586 L
.904 .51582 L
.908 .51577 L
.912 .51573 L
.916 .51568 L
.92 .51564 L
.924 .51559 L
.928 .51556 L
.932 .51551 L
.936 .51547 L
.94 .51542 L
.944 .51538 L
.948 .51533 L
.952 .51529 L
.956 .51524 L
.96 .5152 L
.964 .51515 L
.968 .51512 L
.972 .51506 L
.976 .51503 L
.98 .51497 L
.984 .51494 L
.988 .51488 L
.992 .51485 L
.996 .51479 L
1 .51477 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02000iOol3000aOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008003Uoo`03001oo`00035oo`002goo0P002Woo0P000goo0`000goo00<007ooOol0<goo
0P000goo00<007oo0000<Goo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2000dOol2
0002Ool01@00Oomoogoo0000<7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8000eoo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000Eoo`@00003Ool000000080009oo`04
001oo`000003Ool50003Ool20004Ool20004Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol02goo00D007ooOomoo`00
009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`@0009o
o`80009oo`04001oo`000002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002
Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001goo
00@007oo0000009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00007Ool01000Oomoo`000Woo00<0
07ooOol00goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`03001oogoo00]oo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0003Ool40003Ool01000Oomoo`000Woo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000;Ool2000:Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo
0P0017oo00@007ooOol0009oo`05001oogoo001oo`0200000goo00000003Ool00`00Oomoo`04Ool2
00001Goo001oogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000goo
00<007oo00001Woo00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo
0P0017oo0P000Woo00D007ooOomoo`0000=oo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0
009oo`D000=oo`8000Ioo`008Woo00<007ooOol0;7oo00<007ooOol03goo00<007ooOol0:goo000R
Ool2000]Ool00`00Oomoo`0@Ool2000[Ool0029oof<000aoo`008Woo0`0000Eoo`00000007oo00<0
0003Ool0000000<000=oo`<00003Ool007oo00@00003Ool00000009oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`04001oogoo0003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol02Woo
000ROol2000017oo000007oo0`0000=oo`0000000P0000=oo`0000000`000Woo00@007oo000000Ao
o`03001oo`0000Qoo`8000Aoo`03001oogoo03eoo`008Woo00<007ooOol057oo0P001goo0`000goo
0P0000=oo`0000000goo00<007ooOol0?Woo000ROol2000QOol300000goo00000002Ool01000Oomo
o`00@7oo000ROol2000ROol01@00Oomoogoo00000goo00<007oo0000@7oo000;Ool20004Ool00`00
Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0ZOol00`00Oomoo`0oOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo
0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool5
0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qo
o`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001o
ogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2
001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000
Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003
Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo
06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03
Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomo
o`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
1Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4
0003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007oo
Ool017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03
001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo8P00Agoo000XOol00`00Oomoo`0N
Ool30015Ool002Qoo`03001oogoo025oo`<0049oo`002goo0P0017oo00<007ooOol00goo0P0017oo
0P000goo0`000goo00<007ooOol097oo0P00@7oo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`000goo00@007ooOol002Moo`<003ioo`000goo1@000Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol002Uoo`<003aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`00
17oo0P0017oo100000Aoo`00000000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009o
o`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool01000
0goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00<007ooOol00P000Woo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo
00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00
Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00P007ooOol007oo001oo`001goo00@007ooOol0009oo`05001oogooOol0
0004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0009oo`8000Moo`04
001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo
00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@0
00=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=o
o`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
0goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo
00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol0
17oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomo
o`03Ool20004Ool20004Ool20002Ool50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool5
0003Ool20006Ool002Qoo`03001oogoo02ioo`8003Ioo`00:7oo00<007ooOol0;goo0P00=Goo000X
OomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00aoo`04001oogoo000A
Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo035oo`8003=oo`00:7oo00<007oo
Ool0<Woo0P00<Woo000XOol00`00Oomoo`0cOol2000aOol002Qoo`03001oogoo03Aoo`03001oogoo
02moo`00:7oo00<007ooOol0=Goo00<007ooOol0;Woo000;Ool20004Ool00`00Oomoo`03Ool20004
Ool20003Ool30003Ool00`00Oomoo`0eOol00`00Oomoo`0^Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00>7oo00<007ooOol0;Goo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00>Goo00<007ooOol0;7oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000hOol2
000]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001o
ogoo03Uoob4000aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Io
o`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001o
ogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0
IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00
J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Mo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5
001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<0
00=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool0
1000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03
001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D0
00=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009o
o`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogoo
Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol0
0`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
1Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000
Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo
00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Ao
o`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo
00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo
00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`00
77oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomoo`00
00=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`8000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo02=oo`<004aoo`0077oo0P009Woo
0`00BWoo000LOol00`00Oomoo`0WOol30018Ool001aoo`03001oogoo02Uoo`8004Moo`0077oo0P00
:goo0`00AGoo000LOol00`00Oomoo`0/Ool30013Ool001aoo`03001oogoo02ioo`80049oo`0077oo
0P00<7oo0P00@Goo000LOol00`00Oomoo`0`Ool00`00Oomoo`0oOol001aoo`80039oo`03001oogoo
03ioo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0<Goo0P00?goo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo039oo`03001oogoo03eoo`002Woo00@007oo
Ool000]oo`03001oogoo008003Aoo`03001oogoo03aoo`002Woo00@007ooOol000]oo`04001oogoo
000eOol00`00Oomoo`0lOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0dOol00`00Oomo
o`0kOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2000eOol2000lOol000]oo`8000Qoo`D0
009oo`03001oogoo03Eoo`03001oogoo03Yoo`0077oo00<007ooOol0=Goo0P00>goo000LOol2000g
Ool00`00Oomoo`0iOol001aoo`03001oogoo03Moo`03001oogoo03Qoo`0077oo0P00>7oo0P00>Goo
000LOol00`00Oomoo`0hOol00`00Oomoo`0gOol001aoo`03001oogoo03Qoo`8003Qoo`0077oo0P00
>Woo00<007ooOol0=Woo000FOol30003Ool00`00Oomoo`0jOol00`00Oomoo`0eOol001Moo`03001o
ogoo009oo`03001oogoo03Yoo`8003Ioo`005goo00<007ooOol00Woo0P00?7oo00<007ooOol0=7oo
000GOol00`00Oomoo`02Ool00`00Oomoo`0lOol00`00Oomoo`0cOol001Moo`03001oogoo009oo`03
001oogoo03aoo`03001oogoo03=oo`005Woo0P0017oo0P00?Woo00<007ooOol0<Woo000GOol00`00
Oomoo`02Ool00`00Oomoo`0mOol00`00Oomoo`0bOol001aoo`03001oogoo03ioo`03001oogoo035o
o`0077oo0P00?goo0P00<Woo000LOol00`00Oomoo`0oOol00`00Oomoo`0`Ool001aoo`80045oo`80
031oo`0077oo00<007ooOol0@Goo9@0037oo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001o
ogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo
079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol0
0P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo
00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(15531\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32429 m
.008 .32561 L
.012 .32404 L
.016 .32035 L
.02 .31686 L
.024 .31419 L
.028 .31384 L
.032 .31579 L
.036 .31872 L
.04 .32199 L
.044 .32371 L
.048 .32375 L
.052 .3221 L
.056 .31921 L
.06 .31654 L
.064 .31462 L
.068 .31458 L
.072 .31617 L
.076 .31858 L
.08 .32115 L
.084 .32299 L
.088 .32405 L
.092 .32372 L
.096 .32191 L
.1 .31938 L
.104 .317 L
.108 .31539 L
.112 .31434 L
.116 .31428 L
.12 .31589 L
.124 .31898 L
.128 .32233 L
.132 .32452 L
.136 .32521 L
.14 .32455 L
.144 .32262 L
.148 .31955 L
.152 .31613 L
.156 .31409 L
.16 .31457 L
.164 .31699 L
.168 .31949 L
.172 .32073 L
.176 .32068 L
.18 .31991 L
.184 .31884 L
.188 .31784 L
.192 .31764 L
.196 .31913 L
.2 .32235 L
Mistroke
.204 .32587 L
.208 .32754 L
.212 .32604 L
.216 .3219 L
.22 .31707 L
.224 .31364 L
.228 .3125 L
.232 .31304 L
.236 .31408 L
.24 .31494 L
.244 .31596 L
.248 .31778 L
.252 .32032 L
.256 .32269 L
.26 .32423 L
.264 .32544 L
.268 .32738 L
.272 .33003 L
.276 .33139 L
.28 .32892 L
.284 .32228 L
.288 .31453 L
.292 .31012 L
.296 .31111 L
.3 .31523 L
.304 .31782 L
.308 .31603 L
.312 .31139 L
.316 .30829 L
.32 .30994 L
.324 .31551 L
.328 .32093 L
.332 .32252 L
.336 .31998 L
.34 .31629 L
.344 .31501 L
.348 .3175 L
.352 .32241 L
.356 .32728 L
.36 .33049 L
.364 .33201 L
.368 .33268 L
.372 .33331 L
.376 .3344 L
.38 .33647 L
.384 .34004 L
.388 .34504 L
.392 .35003 L
.396 .35241 L
.4 .34997 L
Mistroke
.404 .34275 L
.408 .33374 L
.412 .32756 L
.416 .32773 L
.42 .3343 L
.424 .34365 L
.428 .35057 L
.432 .35126 L
.436 .3455 L
.44 .33645 L
.444 .32855 L
.448 .32496 L
.452 .32614 L
.456 .33031 L
.46 .33516 L
.464 .33951 L
.468 .34379 L
.472 .34915 L
.476 .356 L
.48 .36293 L
.484 .36704 L
.488 .36527 L
.492 .35609 L
.496 .34052 L
.5 .32179 L
.504 .30395 L
.508 .29 L
.512 .28068 L
.516 .27444 L
.52 .26852 L
.524 .2605 L
.528 .24959 L
.532 .23698 L
.536 .22519 L
.54 .21681 L
.544 .21331 L
.548 .21448 L
.552 .21854 L
.556 .22289 L
.56 .22508 L
.564 .22355 L
.568 .21808 L
.572 .20977 L
.576 .20071 L
.58 .19333 L
.584 .18965 L
.588 .19066 L
.592 .19594 L
.596 .20378 L
.6 .21178 L
Mistroke
.604 .21758 L
.608 .21955 L
.612 .21712 L
.616 .21064 L
.62 .20115 L
.624 .19006 L
.628 .17891 L
.632 .16929 L
.636 .16264 L
.64 .15999 L
.644 .16171 L
.648 .16751 L
.652 .17657 L
.656 .18791 L
.66 .20063 L
.664 .21401 L
.668 .22746 L
.672 .24039 L
.676 .2522 L
.68 .26246 L
.684 .27102 L
.688 .27805 L
.692 .28383 L
.696 .28859 L
.7 .29237 L
.704 .29519 L
.708 .29713 L
.712 .29844 L
.716 .29941 L
.72 .30023 L
.724 .30091 L
.728 .30138 L
.732 .30158 L
.736 .30159 L
.74 .30159 L
.744 .30168 L
.748 .30185 L
.752 .30199 L
.756 .30199 L
.76 .30188 L
.764 .30177 L
.768 .30179 L
.772 .3019 L
.776 .302 L
.78 .30199 L
.784 .30188 L
.788 .30179 L
.792 .3018 L
.796 .30189 L
.8 .30197 L
Mistroke
.804 .30195 L
.808 .30186 L
.812 .30179 L
.816 .30181 L
.82 .30188 L
.824 .30194 L
.828 .30192 L
.832 .30184 L
.836 .30179 L
.84 .30181 L
.844 .30187 L
.848 .3019 L
.852 .30188 L
.856 .30183 L
.86 .3018 L
.864 .30182 L
.868 .30186 L
.872 .30187 L
.876 .30185 L
.88 .30182 L
.884 .3018 L
.888 .30181 L
.892 .30184 L
.896 .30185 L
.9 .30183 L
.904 .30181 L
.908 .30179 L
.912 .3018 L
.916 .30182 L
.92 .30183 L
.924 .30182 L
.928 .3018 L
.932 .30178 L
.936 .30178 L
.94 .30181 L
.944 .30181 L
.948 .3018 L
.952 .30178 L
.956 .30176 L
.96 .30177 L
.964 .3018 L
.968 .30181 L
.972 .30178 L
.976 .30176 L
.98 .30174 L
.984 .30175 L
.988 .3018 L
.992 .3018 L
.996 .30176 L
1 .30173 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14578 m
.008 .14332 L
.012 .14243 L
.016 .14324 L
.02 .14341 L
.024 .14307 L
.028 .14296 L
.032 .14313 L
.036 .14321 L
.04 .14327 L
.044 .14332 L
.048 .14339 L
.052 .14337 L
.056 .14332 L
.06 .14322 L
.064 .14314 L
.068 .14307 L
.072 .14304 L
.076 .14305 L
.08 .14312 L
.084 .14321 L
.088 .14332 L
.092 .14338 L
.096 .1434 L
.1 .14339 L
.104 .14334 L
.108 .14325 L
.112 .14314 L
.116 .14306 L
.12 .14304 L
.124 .14304 L
.128 .14306 L
.132 .14311 L
.136 .14321 L
.14 .14331 L
.144 .14339 L
.148 .14341 L
.152 .14341 L
.156 .1434 L
.16 .14338 L
.164 .1433 L
.168 .14317 L
.172 .14306 L
.176 .14301 L
.18 .14299 L
.184 .14297 L
.188 .14295 L
.192 .14298 L
.196 .1431 L
.2 .14327 L
Mistroke
.204 .14343 L
.208 .14353 L
.212 .14361 L
.216 .14367 L
.22 .14372 L
.224 .14369 L
.228 .14353 L
.232 .14325 L
.236 .14294 L
.24 .14269 L
.244 .14254 L
.248 .14246 L
.252 .1424 L
.256 .14239 L
.26 .14252 L
.264 .14287 L
.268 .14337 L
.272 .14386 L
.276 .14417 L
.28 .1443 L
.284 .14434 L
.288 .14443 L
.292 .14453 L
.296 .14448 L
.3 .14413 L
.304 .14353 L
.308 .14291 L
.312 .1425 L
.316 .14232 L
.32 .14222 L
.324 .14198 L
.328 .14154 L
.332 .14104 L
.336 .14072 L
.34 .14072 L
.344 .14097 L
.348 .14127 L
.352 .14148 L
.356 .14159 L
.36 .14174 L
.364 .14212 L
.368 .14285 L
.372 .14394 L
.376 .14535 L
.38 .14695 L
.384 .14862 L
.388 .15022 L
.392 .15168 L
.396 .15304 L
.4 .15446 L
Mistroke
.404 .15613 L
.408 .15816 L
.412 .16046 L
.416 .16276 L
.42 .16474 L
.424 .16619 L
.428 .16714 L
.432 .16787 L
.436 .16877 L
.44 .17014 L
.444 .1721 L
.448 .17454 L
.452 .17726 L
.456 .18002 L
.46 .1827 L
.464 .18521 L
.468 .18751 L
.472 .18954 L
.476 .19121 L
.48 .19248 L
.484 .19343 L
.488 .19428 L
.492 .19532 L
.496 .19688 L
.5 .19916 L
.504 .20219 L
.508 .20586 L
.512 .20995 L
.516 .21427 L
.52 .21873 L
.524 .22336 L
.528 .22824 L
.532 .23348 L
.536 .2391 L
.54 .24501 L
.544 .25104 L
.548 .25697 L
.552 .26264 L
.556 .26797 L
.56 .27302 L
.564 .27794 L
.568 .28292 L
.572 .28814 L
.576 .29367 L
.58 .29949 L
.584 .30547 L
.588 .31142 L
.592 .31717 L
.596 .32256 L
.6 .32756 L
Mistroke
.604 .33221 L
.608 .33663 L
.612 .34101 L
.616 .34553 L
.62 .35038 L
.624 .35564 L
.628 .36136 L
.632 .36749 L
.636 .37391 L
.64 .38047 L
.644 .387 L
.648 .39331 L
.652 .39926 L
.656 .40472 L
.66 .4096 L
.664 .41387 L
.668 .41751 L
.672 .42056 L
.676 .42306 L
.68 .42506 L
.684 .42664 L
.688 .42787 L
.692 .4288 L
.696 .42949 L
.7 .43001 L
.704 .43039 L
.708 .43066 L
.712 .43086 L
.716 .431 L
.72 .43109 L
.724 .43116 L
.728 .43122 L
.732 .43126 L
.736 .43129 L
.74 .43131 L
.744 .43133 L
.748 .43134 L
.752 .43136 L
.756 .43137 L
.76 .43139 L
.764 .4314 L
.768 .43141 L
.772 .43143 L
.776 .43144 L
.78 .43146 L
.784 .43147 L
.788 .43148 L
.792 .43149 L
.796 .43151 L
.8 .43152 L
Mistroke
.804 .43153 L
.808 .43155 L
.812 .43156 L
.816 .43157 L
.82 .43158 L
.824 .4316 L
.828 .43161 L
.832 .43163 L
.836 .43164 L
.84 .43165 L
.844 .43166 L
.848 .43168 L
.852 .43169 L
.856 .4317 L
.86 .43172 L
.864 .43173 L
.868 .43174 L
.872 .43176 L
.876 .43177 L
.88 .43178 L
.884 .43179 L
.888 .43181 L
.892 .43182 L
.896 .43183 L
.9 .43185 L
.904 .43186 L
.908 .43187 L
.912 .43189 L
.916 .4319 L
.92 .43191 L
.924 .43192 L
.928 .43194 L
.932 .43195 L
.936 .43197 L
.94 .43197 L
.944 .43199 L
.948 .432 L
.952 .43202 L
.956 .43202 L
.96 .43205 L
.964 .43205 L
.968 .43207 L
.972 .43207 L
.976 .4321 L
.98 .4321 L
.984 .43213 L
.988 .43212 L
.992 .43216 L
.996 .43215 L
1 .43218 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16016 L
.012 .16118 L
.016 .16156 L
.02 .16128 L
.024 .16107 L
.028 .16113 L
.032 .16115 L
.036 .16118 L
.04 .16117 L
.044 .16125 L
.048 .1613 L
.052 .16135 L
.056 .16133 L
.06 .16128 L
.064 .16119 L
.068 .16112 L
.072 .16105 L
.076 .16102 L
.08 .16104 L
.084 .16115 L
.088 .16126 L
.092 .16137 L
.096 .16143 L
.1 .16146 L
.104 .16142 L
.108 .16131 L
.112 .16115 L
.116 .16103 L
.12 .16096 L
.124 .16095 L
.128 .16097 L
.132 .16106 L
.136 .1612 L
.14 .16136 L
.144 .16147 L
.148 .16149 L
.152 .16146 L
.156 .16144 L
.16 .16139 L
.164 .16128 L
.168 .16114 L
.172 .16102 L
.176 .16096 L
.18 .16095 L
.184 .16092 L
.188 .16089 L
.192 .16092 L
.196 .16105 L
.2 .16126 L
Mistroke
.204 .16146 L
.208 .16161 L
.212 .1617 L
.216 .16179 L
.22 .16185 L
.224 .16181 L
.228 .16161 L
.232 .16125 L
.236 .16086 L
.24 .16054 L
.244 .16036 L
.248 .16027 L
.252 .1602 L
.256 .16019 L
.26 .16036 L
.264 .16079 L
.268 .16141 L
.272 .16201 L
.276 .1624 L
.28 .16255 L
.284 .16262 L
.288 .16273 L
.292 .16286 L
.296 .16279 L
.3 .16235 L
.304 .1616 L
.308 .16082 L
.312 .16031 L
.316 .1601 L
.32 .15998 L
.324 .15968 L
.328 .15913 L
.332 .1585 L
.336 .1581 L
.34 .15809 L
.344 .1584 L
.348 .15879 L
.352 .15906 L
.356 .1592 L
.36 .15938 L
.364 .15985 L
.368 .16074 L
.372 .16211 L
.376 .16387 L
.38 .16587 L
.384 .16795 L
.388 .16994 L
.392 .17175 L
.396 .17344 L
.4 .17521 L
Mistroke
.404 .17729 L
.408 .17982 L
.412 .18268 L
.416 .18555 L
.42 .18801 L
.424 .1898 L
.428 .19098 L
.432 .19188 L
.436 .193 L
.44 .19471 L
.444 .19714 L
.448 .20018 L
.452 .20356 L
.456 .20699 L
.46 .21032 L
.464 .21344 L
.468 .2163 L
.472 .21882 L
.476 .22089 L
.48 .22246 L
.484 .22364 L
.488 .22468 L
.492 .22597 L
.496 .2279 L
.5 .23073 L
.504 .2345 L
.508 .23905 L
.512 .24414 L
.516 .24951 L
.52 .25506 L
.524 .2608 L
.528 .26686 L
.532 .27338 L
.536 .28036 L
.54 .28771 L
.544 .29521 L
.548 .30258 L
.552 .30961 L
.556 .31622 L
.56 .32248 L
.564 .32859 L
.568 .33478 L
.572 .34125 L
.576 .34811 L
.58 .35532 L
.584 .36274 L
.588 .37013 L
.592 .37725 L
.596 .38394 L
.6 .39013 L
Mistroke
.604 .39587 L
.608 .40134 L
.612 .40675 L
.616 .41236 L
.62 .41835 L
.624 .42487 L
.628 .43195 L
.632 .43953 L
.636 .44749 L
.64 .45562 L
.644 .4637 L
.648 .47152 L
.652 .47888 L
.656 .48562 L
.66 .49165 L
.664 .49691 L
.668 .5014 L
.672 .50514 L
.676 .50819 L
.68 .51062 L
.684 .51253 L
.688 .514 L
.692 .5151 L
.696 .51591 L
.7 .5165 L
.704 .5169 L
.708 .51718 L
.712 .51736 L
.716 .51748 L
.72 .51754 L
.724 .51757 L
.728 .51757 L
.732 .51755 L
.736 .51753 L
.74 .5175 L
.744 .51747 L
.748 .51743 L
.752 .51739 L
.756 .51734 L
.76 .5173 L
.764 .51726 L
.768 .51721 L
.772 .51717 L
.776 .51712 L
.78 .51708 L
.784 .51703 L
.788 .51699 L
.792 .51695 L
.796 .5169 L
.8 .51686 L
Mistroke
.804 .51681 L
.808 .51677 L
.812 .51673 L
.816 .51668 L
.82 .51664 L
.824 .51659 L
.828 .51655 L
.832 .51651 L
.836 .51646 L
.84 .51642 L
.844 .51637 L
.848 .51633 L
.852 .51628 L
.856 .51624 L
.86 .5162 L
.864 .51615 L
.868 .51611 L
.872 .51606 L
.876 .51602 L
.88 .51598 L
.884 .51593 L
.888 .51589 L
.892 .51584 L
.896 .5158 L
.9 .51575 L
.904 .51571 L
.908 .51566 L
.912 .51562 L
.916 .51557 L
.92 .51553 L
.924 .51548 L
.928 .51545 L
.932 .5154 L
.936 .51536 L
.94 .51531 L
.944 .51527 L
.948 .51522 L
.952 .51518 L
.956 .51513 L
.96 .5151 L
.964 .51504 L
.968 .51501 L
.972 .51495 L
.976 .51492 L
.98 .51486 L
.984 .51483 L
.988 .51477 L
.992 .51475 L
.996 .51468 L
1 .51466 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000?Goo0P00;goo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`02000lOol2000_Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0
00=oo`03001oogoo008003]oo`04001oogoo000^Ool000]oo`8000Yoo`8000=oo`<000=oo`03001o
ogoo03Ioo`80009oo`04001oogoo000^Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`8003Ioo`03001oo`00009oo`04001oogoo000^Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo100000=oo`00
00000`000goo0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogoo
Ool00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool5
0002Ool20002Ool01000Ool000000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
17oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`05001oogoo001o
o`020004Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol017oo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;Ool4
0003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000
Oomoogoo10000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000=oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<0
07ooOol00Woo0P0037oo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool0
1000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001oogooOol00002Ool0
1000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`00
8Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo0`000goo1@000goo0P00
00Aoo`00Oomoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol0
;goo00<007ooOol03goo00<007ooOol0:7oo000ROol2000`Ool00`00Oomoo`0?Ool3000XOol0029o
of<000aoo`008Woo00<007oo00000P0000Eoo`00000007oo00<0009oo`800005Ool00000001oo`03
0002Ool90003Ool01@00Oomoogoo00000goo00D007oo001oo`0000=oo`05001oogooOol00002Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000aoo`008Woo0`0000=oo`0000000Woo0`000Woo0`0000Aoo`00001oo`80
00=oo`@000=oo`@000Aoo`800003Ool0000000Aoo`03001oogoo03]oo`008Woo00<007ooOol067oo
00<007ooOol01Goo0`000Woo0P0000Aoo`00Ool000=oo`03001oogoo03]oo`008Woo0P0097oo1000
00Moo`00Oomoo`00Ool0000nOol0029oo`8002Eoo`04001oogoo0004Ool2000nOol000]oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo02aoo`8003ioo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2
001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool2
0004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0
009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007oo
Ool0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`80
06eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=o
o`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0
K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo
00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05
Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomo
o`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02OolT0015Ool002Qoo`03001oogoo025o
o`8004=oo`00:7oo00<007ooOol08goo0`00@7oo000;Ool20004Ool00`00Oomoo`03Ool20004Ool2
0003Ool30003Ool00`00Oomoo`0VOol2000nOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0003Ool01000Oomoo`00:Goo0`00?7oo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00:goo0`00>Woo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004
Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004
Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03
001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`000goo0P001Woo00@007ooOol0009oo`05001oogooOol00004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool0
00]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`8000Ioo`04001oogoo0002
Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001o
ogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001o
ogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oo`00Ool40003
Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03
001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001o
ogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`80009oo`8000Ioo`06001oogoo
001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo
00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo
0P0017oo00<007ooOol01P000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P00
1Woo000XOol00`00Oomoo`0aOol00`00Oomoo`0bOol002Qoo`03001oogoo039oo`03001oogoo035o
o`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0>Ool2000AOol0
0`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo03Aoo`03001oogoo02moo`00:7oo00<0
07ooOol0=Goo00<007ooOol0;Woo000XOol00`00Oomoo`0fOol00`00Oomoo`0]Ool002Qoo`03001o
ogoo03Moo`03001oogoo02aoo`00:7oo00<007ooOol0=goo00<007ooOol0;7oo000;Ool20004Ool0
0`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0hOol00`00Oomoo`0[Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00>Woo0P00;7oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00>goo00<0
07ooOol0:Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`02000kOol2000ZOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@0
00=oo`03001oogoo03]ooal000aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo
0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`80
00Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo
00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool0
1000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001o
ogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04
001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001o
ogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1b
Ool001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Ao
o`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007oo
Oomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol0
0goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol0
07oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol0
00Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol0
07oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P00
17oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=o
o`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D0
07ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`03001oo`0000<000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol09Woo0`00
BGoo000LOol2000YOol30017Ool001aoo`03001oogoo02Yoo`<004Eoo`0077oo00<007ooOol0;7oo
0P00A7oo000LOol2000^Ool20013Ool001aoo`03001oogoo02moo`<0041oo`0077oo00<007ooOol0
<Goo0P00?goo000LOol2000cOol2000nOol001aoo`03001oogoo03=oo`03001oogoo03aoo`0077oo
0P00=7oo0P00?Goo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`0dOol00`00Oomo
o`0kOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0=Goo00<007ooOol0
>Woo000:Ool01000Oomoo`002goo00<007ooOol00P00=Woo00<007ooOol0>Woo000:Ool01000Oomo
o`002goo00@007ooOol003Qoo`03001oogoo03Uoo`002Woo00@007ooOol000Moo`@000=oo`03001o
ogoo03Ioo`8003Yoo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8003Qoo`03001oogoo03Qo
o`002goo0P0027oo1@000Woo00<007ooOol0>7oo00<007ooOol0=goo000LOol00`00Oomoo`0hOol0
0`00Oomoo`0gOol001aoo`8003Yoo`03001oogoo03Ioo`0077oo00<007ooOol0>Woo00<007ooOol0
=Goo000LOol2000kOol00`00Oomoo`0eOol001aoo`03001oogoo03Yoo`8003Ioo`0077oo00<007oo
Ool0>goo00<007ooOol0=7oo000LOol2000mOol00`00Oomoo`0cOol001Ioo`<000=oo`03001oogoo
03aoo`8003Aoo`005goo00<007ooOol00Woo00<007ooOol0?Goo00<007ooOol0<Woo000GOol00`00
Oomoo`02Ool2000oOol00`00Oomoo`0aOol001Moo`03001oogoo009oo`03001oogoo03moo`03001o
ogoo031oo`005goo00<007ooOol00Woo00<007ooOol0?goo00<007ooOol0<7oo000FOol20004Ool2
0010Ool00`00Oomoo`0`Ool001Moo`03001oogoo009oo`03001oogoo041oo`03001oogoo02moo`00
77oo00<007ooOol0@Goo00<007ooOol0;Woo000LOol20012Ool00`00Oomoo`0^Ool001aoo`03001o
ogoo049oo`03001oogoo02eoo`0077oo0P00A7oo00<007ooOol0;7oo000LOol00`00Oomoo`14OolR
000<Ool001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;
Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool0
1000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Mo
o`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool0
0`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(15698\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .313 m
.008 .3133 L
.012 .31558 L
.016 .31954 L
.02 .32332 L
.024 .32536 L
.028 .32449 L
.032 .32207 L
.036 .31896 L
.04 .31575 L
.044 .31399 L
.048 .31381 L
.052 .31559 L
.056 .31857 L
.06 .32153 L
.064 .32387 L
.068 .32457 L
.072 .32382 L
.076 .32157 L
.08 .31823 L
.084 .31516 L
.088 .31328 L
.092 .31341 L
.096 .31518 L
.1 .31826 L
.104 .3222 L
.108 .32551 L
.112 .32676 L
.116 .32518 L
.12 .32168 L
.124 .31771 L
.128 .3143 L
.132 .31242 L
.136 .31277 L
.14 .31563 L
.144 .31985 L
.148 .32331 L
.152 .32446 L
.156 .3234 L
.16 .3215 L
.164 .31977 L
.168 .31855 L
.172 .31812 L
.176 .3188 L
.18 .32031 L
.184 .32133 L
.188 .32056 L
.192 .31805 L
.196 .31537 L
.2 .31442 L
Mistroke
.204 .31573 L
.208 .31838 L
.212 .32097 L
.216 .3227 L
.22 .32347 L
.224 .3235 L
.228 .32294 L
.232 .32197 L
.236 .32095 L
.24 .32041 L
.244 .32049 L
.248 .32059 L
.252 .31952 L
.256 .31648 L
.26 .3123 L
.264 .30938 L
.268 .3101 L
.272 .31474 L
.276 .32083 L
.28 .32509 L
.284 .3261 L
.288 .32544 L
.292 .32567 L
.296 .32758 L
.3 .32923 L
.304 .32797 L
.308 .32345 L
.312 .31822 L
.316 .31542 L
.32 .31573 L
.324 .3168 L
.328 .31573 L
.332 .31219 L
.336 .30888 L
.34 .30904 L
.344 .31327 L
.348 .31878 L
.352 .32172 L
.356 .3204 L
.36 .31656 L
.364 .31371 L
.368 .31429 L
.372 .31805 L
.376 .32282 L
.38 .32648 L
.384 .32835 L
.388 .32907 L
.392 .32953 L
.396 .33018 L
.4 .3313 L
Mistroke
.404 .33344 L
.408 .33732 L
.412 .3429 L
.416 .34856 L
.42 .35148 L
.424 .34932 L
.428 .34216 L
.432 .33305 L
.436 .3266 L
.44 .32629 L
.444 .33227 L
.448 .34121 L
.452 .34824 L
.456 .34976 L
.46 .34529 L
.464 .33739 L
.468 .32981 L
.472 .32533 L
.476 .32459 L
.48 .32647 L
.484 .32944 L
.488 .33285 L
.492 .33727 L
.496 .3436 L
.5 .35193 L
.504 .36066 L
.508 .36686 L
.512 .36743 L
.516 .36063 L
.52 .347 L
.524 .32928 L
.528 .31122 L
.532 .29604 L
.536 .28513 L
.54 .27765 L
.544 .2712 L
.548 .2632 L
.552 .25229 L
.556 .23905 L
.56 .22576 L
.564 .2153 L
.568 .20982 L
.572 .20969 L
.576 .21343 L
.58 .21831 L
.584 .22149 L
.588 .22101 L
.592 .21637 L
.596 .2085 L
.6 .19931 L
Mistroke
.604 .19107 L
.608 .18585 L
.612 .18493 L
.616 .1885 L
.62 .19552 L
.624 .20394 L
.628 .21135 L
.632 .2156 L
.636 .21545 L
.64 .21073 L
.644 .20227 L
.648 .19144 L
.652 .17985 L
.656 .16907 L
.66 .16054 L
.664 .15543 L
.668 .1545 L
.672 .15792 L
.676 .16525 L
.68 .17559 L
.684 .18792 L
.688 .20136 L
.692 .21521 L
.696 .22886 L
.7 .24177 L
.704 .25342 L
.708 .26348 L
.712 .27188 L
.716 .27879 L
.72 .28446 L
.724 .28906 L
.728 .29267 L
.732 .29535 L
.736 .29722 L
.74 .29854 L
.744 .29953 L
.748 .30034 L
.752 .30097 L
.756 .30137 L
.76 .30153 L
.764 .30158 L
.768 .30164 L
.772 .30177 L
.776 .30192 L
.78 .30198 L
.784 .30193 L
.788 .30184 L
.792 .30182 L
.796 .30188 L
.8 .30197 L
Mistroke
.804 .30199 L
.808 .30193 L
.812 .30185 L
.816 .30184 L
.82 .30189 L
.824 .30195 L
.828 .30195 L
.832 .3019 L
.836 .30185 L
.84 .30185 L
.844 .30188 L
.848 .30192 L
.852 .30192 L
.856 .30188 L
.86 .30184 L
.864 .30185 L
.868 .30188 L
.872 .3019 L
.876 .3019 L
.88 .30187 L
.884 .30184 L
.888 .30184 L
.892 .30186 L
.896 .30188 L
.9 .30188 L
.904 .30185 L
.908 .30183 L
.912 .30183 L
.916 .30185 L
.92 .30186 L
.924 .30186 L
.928 .30184 L
.932 .30181 L
.936 .30182 L
.94 .30184 L
.944 .30185 L
.948 .30184 L
.952 .30182 L
.956 .30179 L
.96 .3018 L
.964 .30184 L
.968 .30184 L
.972 .30182 L
.976 .30179 L
.98 .30178 L
.984 .30179 L
.988 .30184 L
.992 .30183 L
.996 .30179 L
1 .30177 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14524 m
.008 .14359 L
.012 .14299 L
.016 .14355 L
.02 .14379 L
.024 .14371 L
.028 .14361 L
.032 .14365 L
.036 .14364 L
.04 .14359 L
.044 .14352 L
.048 .1435 L
.052 .14349 L
.056 .14352 L
.06 .14355 L
.064 .14361 L
.068 .14366 L
.072 .14371 L
.076 .1437 L
.08 .14368 L
.084 .14363 L
.088 .14357 L
.092 .1435 L
.096 .14345 L
.1 .14344 L
.104 .14348 L
.108 .14353 L
.112 .14361 L
.116 .14368 L
.12 .14376 L
.124 .14379 L
.128 .14376 L
.132 .14367 L
.136 .14358 L
.14 .1435 L
.144 .14343 L
.148 .14338 L
.152 .14337 L
.156 .14344 L
.16 .14355 L
.164 .14365 L
.168 .14372 L
.172 .14376 L
.176 .14381 L
.18 .14382 L
.184 .14378 L
.188 .14367 L
.192 .14357 L
.196 .14349 L
.2 .14345 L
Mistroke
.204 .1434 L
.208 .14333 L
.212 .14329 L
.216 .14332 L
.22 .14343 L
.224 .14357 L
.228 .1437 L
.232 .1438 L
.236 .14391 L
.24 .14404 L
.244 .14415 L
.248 .14415 L
.252 .14399 L
.256 .14373 L
.26 .14344 L
.264 .14323 L
.268 .14306 L
.272 .1429 L
.276 .14272 L
.28 .14263 L
.284 .14275 L
.288 .1431 L
.292 .14359 L
.296 .14402 L
.3 .14428 L
.304 .14443 L
.308 .14461 L
.312 .14486 L
.316 .14506 L
.32 .14502 L
.324 .14465 L
.328 .14406 L
.332 .14351 L
.336 .14318 L
.34 .14303 L
.344 .14288 L
.348 .14255 L
.352 .14204 L
.356 .14152 L
.36 .14121 L
.364 .14118 L
.368 .14135 L
.372 .14156 L
.376 .14169 L
.38 .14174 L
.384 .14181 L
.388 .14207 L
.392 .14262 L
.396 .14354 L
.4 .1448 L
Mistroke
.404 .14632 L
.408 .14795 L
.412 .14952 L
.416 .15093 L
.42 .15221 L
.424 .15355 L
.428 .15515 L
.432 .15716 L
.436 .15948 L
.44 .16184 L
.444 .16391 L
.448 .16546 L
.452 .1665 L
.456 .16726 L
.46 .16811 L
.464 .16934 L
.468 .17109 L
.472 .1733 L
.476 .17583 L
.48 .17849 L
.484 .18118 L
.488 .18381 L
.492 .1863 L
.496 .18854 L
.5 .19041 L
.504 .19182 L
.508 .19283 L
.512 .19362 L
.516 .1945 L
.52 .19579 L
.524 .19773 L
.528 .20039 L
.532 .2037 L
.536 .20747 L
.54 .21152 L
.544 .21575 L
.548 .22017 L
.552 .22486 L
.556 .22992 L
.56 .23538 L
.564 .24119 L
.568 .24718 L
.572 .25314 L
.576 .25889 L
.58 .26432 L
.584 .26945 L
.588 .27439 L
.592 .27934 L
.596 .28446 L
.6 .28988 L
Mistroke
.604 .2956 L
.608 .30154 L
.612 .30753 L
.616 .31338 L
.62 .31893 L
.624 .32411 L
.628 .3289 L
.632 .3334 L
.636 .33778 L
.64 .3422 L
.644 .34686 L
.648 .35189 L
.652 .35736 L
.656 .36327 L
.66 .36953 L
.664 .37603 L
.668 .38259 L
.672 .38904 L
.676 .39523 L
.68 .401 L
.684 .40625 L
.688 .41092 L
.692 .41498 L
.696 .41842 L
.7 .42129 L
.704 .42364 L
.708 .42551 L
.712 .42699 L
.716 .42813 L
.72 .429 L
.724 .42966 L
.728 .43014 L
.732 .43049 L
.736 .43075 L
.74 .43093 L
.744 .43106 L
.748 .43115 L
.752 .43122 L
.756 .43127 L
.76 .43131 L
.764 .43134 L
.768 .43136 L
.772 .43138 L
.776 .4314 L
.78 .43141 L
.784 .43143 L
.788 .43144 L
.792 .43146 L
.796 .43147 L
.8 .43148 L
Mistroke
.804 .4315 L
.808 .43151 L
.812 .43152 L
.816 .43153 L
.82 .43155 L
.824 .43156 L
.828 .43157 L
.832 .43159 L
.836 .4316 L
.84 .43161 L
.844 .43163 L
.848 .43164 L
.852 .43165 L
.856 .43167 L
.86 .43168 L
.864 .43169 L
.868 .4317 L
.872 .43172 L
.876 .43173 L
.88 .43174 L
.884 .43176 L
.888 .43177 L
.892 .43178 L
.896 .4318 L
.9 .43181 L
.904 .43182 L
.908 .43183 L
.912 .43185 L
.916 .43186 L
.92 .43188 L
.924 .43188 L
.928 .4319 L
.932 .43191 L
.936 .43193 L
.94 .43194 L
.944 .43196 L
.948 .43196 L
.952 .43198 L
.956 .43199 L
.96 .43201 L
.964 .43201 L
.968 .43204 L
.972 .43204 L
.976 .43206 L
.98 .43206 L
.984 .43209 L
.988 .43209 L
.992 .43212 L
.996 .43211 L
1 .43215 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16282 L
.012 .16109 L
.016 .16053 L
.02 .1612 L
.024 .16139 L
.028 .16126 L
.032 .16123 L
.036 .16133 L
.04 .1613 L
.044 .16122 L
.048 .16113 L
.052 .1611 L
.056 .16106 L
.06 .1611 L
.064 .16115 L
.068 .16127 L
.072 .16135 L
.076 .1614 L
.08 .16138 L
.084 .16132 L
.088 .16122 L
.092 .1611 L
.096 .161 L
.1 .16098 L
.104 .16103 L
.108 .16113 L
.112 .16124 L
.116 .16136 L
.12 .16145 L
.124 .16149 L
.128 .16142 L
.132 .1613 L
.136 .16117 L
.14 .16108 L
.144 .161 L
.148 .16095 L
.152 .16095 L
.156 .16105 L
.16 .16118 L
.164 .1613 L
.168 .16137 L
.172 .16142 L
.176 .16147 L
.18 .1615 L
.184 .16145 L
.188 .16132 L
.192 .16119 L
.196 .1611 L
.2 .16104 L
Mistroke
.204 .16097 L
.208 .16088 L
.212 .16083 L
.216 .16087 L
.22 .16101 L
.224 .16119 L
.228 .16135 L
.232 .16148 L
.236 .16162 L
.24 .16178 L
.244 .16191 L
.248 .1619 L
.252 .1617 L
.256 .16137 L
.26 .16103 L
.264 .16076 L
.268 .16057 L
.272 .16036 L
.276 .16014 L
.28 .16001 L
.284 .16015 L
.288 .16059 L
.292 .16121 L
.296 .16175 L
.3 .16209 L
.304 .16227 L
.308 .16248 L
.312 .16278 L
.316 .16303 L
.32 .16299 L
.324 .16253 L
.328 .16181 L
.332 .16113 L
.336 .16071 L
.34 .16051 L
.344 .16032 L
.348 .1599 L
.352 .15927 L
.356 .15864 L
.36 .15825 L
.364 .15821 L
.368 .15843 L
.372 .15868 L
.376 .15884 L
.38 .15889 L
.384 .15899 L
.388 .15932 L
.392 .16001 L
.396 .16115 L
.4 .16272 L
Mistroke
.404 .16461 L
.408 .16664 L
.412 .16859 L
.416 .17035 L
.42 .17195 L
.424 .17361 L
.428 .17561 L
.432 .1781 L
.436 .18099 L
.44 .18393 L
.444 .18651 L
.448 .18844 L
.452 .18972 L
.456 .19067 L
.46 .19172 L
.464 .19325 L
.468 .19542 L
.472 .19817 L
.476 .20131 L
.48 .20463 L
.484 .20797 L
.488 .21123 L
.492 .21433 L
.496 .21711 L
.5 .21943 L
.504 .22118 L
.508 .22242 L
.512 .2234 L
.516 .22449 L
.52 .22608 L
.524 .22849 L
.528 .23179 L
.532 .2359 L
.536 .24059 L
.54 .24563 L
.544 .25089 L
.548 .25638 L
.552 .2622 L
.556 .26848 L
.56 .27527 L
.564 .28249 L
.568 .28994 L
.572 .29735 L
.576 .30449 L
.58 .31122 L
.584 .31758 L
.588 .32372 L
.592 .32986 L
.596 .33622 L
.6 .34294 L
Mistroke
.604 .35004 L
.608 .3574 L
.612 .36483 L
.616 .37208 L
.62 .37897 L
.624 .38538 L
.628 .39131 L
.632 .39688 L
.636 .40229 L
.64 .40776 L
.644 .41353 L
.648 .41976 L
.652 .42653 L
.656 .43384 L
.66 .4416 L
.664 .44965 L
.668 .45778 L
.672 .46577 L
.676 .47342 L
.68 .48056 L
.684 .48705 L
.688 .49281 L
.692 .49781 L
.696 .50205 L
.7 .50556 L
.704 .50842 L
.708 .5107 L
.712 .51248 L
.716 .51384 L
.72 .51487 L
.724 .51563 L
.728 .51617 L
.732 .51654 L
.736 .5168 L
.74 .51697 L
.744 .51707 L
.748 .51713 L
.752 .51715 L
.756 .51715 L
.76 .51714 L
.764 .51711 L
.768 .51708 L
.772 .51705 L
.776 .51701 L
.78 .51697 L
.784 .51692 L
.788 .51688 L
.792 .51684 L
.796 .51679 L
.8 .51675 L
Mistroke
.804 .5167 L
.808 .51666 L
.812 .51662 L
.816 .51657 L
.82 .51653 L
.824 .51649 L
.828 .51644 L
.832 .5164 L
.836 .51635 L
.84 .51631 L
.844 .51626 L
.848 .51622 L
.852 .51617 L
.856 .51613 L
.86 .51609 L
.864 .51604 L
.868 .516 L
.872 .51596 L
.876 .51591 L
.88 .51587 L
.884 .51582 L
.888 .51578 L
.892 .51573 L
.896 .51569 L
.9 .51564 L
.904 .5156 L
.908 .51555 L
.912 .51551 L
.916 .51546 L
.92 .51543 L
.924 .51537 L
.928 .51534 L
.932 .51529 L
.936 .51525 L
.94 .5152 L
.944 .51516 L
.948 .51511 L
.952 .51507 L
.956 .51502 L
.96 .51499 L
.964 .51493 L
.968 .5149 L
.972 .51484 L
.976 .51481 L
.98 .51475 L
.984 .51472 L
.988 .51466 L
.992 .51464 L
.996 .51457 L
1 .51455 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8003moo`03001oogoo02]oo`002Woo00@0
07ooOol000Qoo`04001oogoo0004Ool01@00Oomoogoo0000?goo0`00;7oo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool00`00Oomoo`02000nOol00`00Ool0000/Ool000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008003Yoo`07001oogooOol007oo0000;7oo000;
Ool2000:Ool20003Ool30003Ool00`00Oomoo`0hOol300000goo001oo`02Ool00`00Oomoo`0YOol0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8003Uoo`05001oo`00Ool00003Ool00`00
Oomoo`0YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo0`00
17oo0P001goo0`0017oo0P0017oo0P001Goo0`0000=oo`0000000`0000Aoo`00001oo`80009oo`H0
00=oo`8000Aoo`8000Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo00000Woo00@007ooOol0
00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00`000Woo00@0
07ooOol0009oo`05001oo`00Ool00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo
009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`0017oo00@007ooOol0
009oo`03001oo`00009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Ool00005Ool01000Oomoo`000Woo00<007oo00000goo
00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001o
ogoo00]oo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`04001oo`00Ool40003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002
Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:Ool2
0004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool2000017oo001oo`001Woo00@007ooOol0009oo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol0
00Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo0P000Woo1@00
0goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`0a
Ool00`00Oomoo`0?Ool00`00Oomoo`0VOol0029oo`80039oo`03001oogoo011oo`8002Ioo`008Woo
H`0037oo000ROol20002Ool300001Goo00000000Ool00`0000Aoo`00001oo`8000=oo`@000=oo`H0
009oo`05001oogooOol00003Ool01000Oomoogoo0P000Woo00D007ooOomoo`00009oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo000037oo000ROol40002Ool300001Goo00000000Ool00`0000Aoo`00Oomoo`D00003Ool0
0000008000=oo`800003Ool0000000Aoo`03001oogoo008000=oo`03001oogoo03Uoo`008Woo00<0
07ooOol097oo0P0000Aoo`00001oo`800005Ool007ooOol0000kOol0029oo`8002Ioo`<00003Ool0
0000009oo`04001oogoo000kOol0029oo`8002Moo`03001oogoo00Eoo`03001oo`0003]oo`002goo
0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0;Woo0P00?7oo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`80
00Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P00
0Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2
001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo
000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001o
ogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol0
0`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P00
0goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo
0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00
Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001o
ogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomo
ogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03
001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
4Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004
Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oobH004=oo`00:7oo00<007oo
Ool08goo0`00@7oo000XOol00`00Oomoo`0UOol4000mOol000]oo`8000Aoo`03001oogoo00=oo`80
00Aoo`8000=oo`<000=oo`03001oogoo02Qoo`8003aoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000/Ool3000iOol000=oo`D0009oo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000^Ool3000gOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Mo
o`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009o
o`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool01000
0goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000=oo`03001oo`00008000=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@0
07ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000=oo`04001oogoo0004Ool01000Oomoo`000Woo00D007ooOomo
o`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0
009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007oo
Oomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03
001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomo
o`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo
00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009o
o`8000=oo`<000Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P00
27oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Ao
o`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0=7oo00<007ooOol0;goo000XOol0
0`00Oomoo`0dOol2000`Ool002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<0
07ooOol03goo00<007oo00003goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`0g
Ool00`00Oomoo`0/Ool002Qoo`03001oogoo03Moo`8002eoo`00:7oo00<007ooOol0>7oo00<007oo
Ool0:goo000XOol00`00Oomoo`0iOol00`00Oomoo`0ZOol002Qoo`03001oogoo03Uoo`8002]oo`00
2goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0>Woo0P00:Woo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol003eoo`03
001oogoo02Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Ool003eoo`8002Uoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol00P00?Goo0P00:7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001o
o`040003Ool00`00Oomoo`0mOolM000<Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:
Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo0000
0goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool0
0`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<0
07ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004
Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool0
0`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool0
1000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007oo
Ool0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool3
0004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05
001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001o
ogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol0
00Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomo
ogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001o
ogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomo
ogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=o
o`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool5
0003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001ao
o`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool00`00Oomoo`02Ool300000goo001oo`02Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo02Uo
o`8004Moo`0077oo0P00;7oo0`00A7oo000LOol00`00Oomoo`0]Ool20013Ool001aoo`03001oogoo
02moo`80045oo`0077oo0P00<Goo0P00@7oo000LOol00`00Oomoo`0bOol2000nOol001aoo`03001o
ogoo03Aoo`8003aoo`0077oo0P00=Woo00<007ooOol0>Woo000LOol00`00Oomoo`0eOol2000kOol0
01aoo`8003Moo`8003Yoo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0=goo00<0
07ooOol0>7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo03Qoo`03001o
ogoo03Moo`002Woo00@007ooOol000]oo`03001oogoo008003Uoo`03001oogoo03Moo`002Woo00@0
07ooOol000]oo`04001oogoo000kOol00`00Oomoo`0fOol000Yoo`04001oogoo0007Ool40003Ool0
0`00Oomoo`0iOol2000gOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2000kOol00`00Oomo
o`0eOol000]oo`8000Qoo`D0009oo`03001oogoo03Yoo`8003Ioo`0077oo00<007ooOol0>goo00<0
07ooOol0=7oo000LOol2000mOol00`00Oomoo`0cOol001aoo`03001oogoo03aoo`03001oogoo03=o
o`0077oo0P00?Woo00<007ooOol0<Woo000LOol00`00Oomoo`0mOol2000cOol001aoo`03001oogoo
03ioo`03001oogoo035oo`0077oo0P00@7oo00<007ooOol0<7oo000FOol30003Ool00`00Oomoo`0o
Ool2000aOol001Moo`03001oogoo009oo`03001oogoo041oo`03001oogoo02moo`005goo00<007oo
Ool00Woo0P00@Woo00<007ooOol0;Woo000GOol00`00Oomoo`02Ool00`00Oomoo`11Ool00`00Oomo
o`0^Ool001Moo`03001oogoo009oo`03001oogoo049oo`03001oogoo02eoo`005Woo0P0017oo0P00
@goo00<007ooOol0;Goo000GOol00`00Oomoo`02Ool00`00Oomoo`13Ool00`00Oomoo`0/Ool001ao
o`03001oogoo04=oo`03001oogoo02aoo`0077oo0P00AGoo00<007ooOol0:goo000LOol00`00Oomo
o`14Ool2000/Ool001aoo`8004Moo`03001oogoo02Uoo`0077oo00<007ooOol0Agoo7`0037oo000L
Ool00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007oo
Ool01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol0
07Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool0
0`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol0
1goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(15865\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32433 m
.008 .32261 L
.012 .32018 L
.016 .31772 L
.02 .31593 L
.024 .31489 L
.028 .31518 L
.032 .31643 L
.036 .31872 L
.04 .32125 L
.044 .32304 L
.048 .32382 L
.052 .32291 L
.056 .32083 L
.06 .318 L
.064 .31514 L
.068 .31362 L
.072 .31396 L
.076 .31638 L
.08 .31982 L
.084 .32307 L
.088 .32534 L
.092 .32543 L
.096 .32315 L
.1 .3192 L
.104 .31538 L
.108 .31334 L
.112 .31336 L
.116 .31532 L
.12 .3185 L
.124 .32189 L
.128 .32411 L
.132 .3241 L
.136 .32229 L
.14 .32002 L
.144 .31859 L
.148 .31813 L
.152 .31805 L
.156 .31811 L
.16 .31829 L
.164 .31834 L
.168 .31781 L
.172 .31703 L
.176 .31723 L
.18 .31915 L
.184 .32216 L
.188 .32443 L
.192 .32462 L
.196 .32286 L
.2 .32027 L
Mistroke
.204 .31787 L
.208 .31616 L
.212 .3155 L
.216 .3162 L
.22 .31807 L
.224 .3201 L
.228 .32094 L
.232 .31998 L
.236 .31808 L
.24 .31698 L
.244 .31804 L
.248 .32107 L
.252 .32441 L
.256 .32608 L
.26 .32528 L
.264 .32289 L
.268 .32044 L
.272 .31872 L
.276 .31728 L
.28 .31535 L
.284 .31325 L
.288 .31236 L
.292 .31369 L
.296 .31653 L
.3 .31892 L
.304 .31971 L
.308 .31998 L
.312 .32202 L
.316 .32659 L
.32 .33142 L
.324 .33277 L
.328 .3289 L
.332 .322 L
.336 .31663 L
.34 .31578 L
.344 .31829 L
.348 .32014 L
.352 .31816 L
.356 .31301 L
.36 .30851 L
.364 .30825 L
.368 .31249 L
.372 .31813 L
.376 .32133 L
.38 .32055 L
.384 .31726 L
.388 .3144 L
.392 .31408 L
.396 .31641 L
.4 .32015 L
Mistroke
.404 .32391 L
.408 .32688 L
.412 .32871 L
.416 .32922 L
.42 .32856 L
.424 .32775 L
.428 .32858 L
.432 .33263 L
.436 .33977 L
.44 .34747 L
.444 .35183 L
.448 .34995 L
.452 .34205 L
.456 .33183 L
.46 .32452 L
.464 .32389 L
.468 .33002 L
.472 .33931 L
.476 .34674 L
.48 .34871 L
.484 .34481 L
.488 .33755 L
.492 .33044 L
.496 .32591 L
.5 .32431 L
.504 .3245 L
.508 .32531 L
.512 .32674 L
.516 .33001 L
.52 .33646 L
.524 .34614 L
.528 .35712 L
.532 .36594 L
.536 .36905 L
.54 .36443 L
.544 .3525 L
.548 .33588 L
.552 .31825 L
.556 .30276 L
.56 .29092 L
.564 .28225 L
.568 .27481 L
.572 .26628 L
.576 .25519 L
.58 .24166 L
.584 .22747 L
.588 .2153 L
.592 .2076 L
.596 .20546 L
.6 .20808 L
Mistroke
.604 .21305 L
.608 .2173 L
.612 .21829 L
.616 .2149 L
.62 .20762 L
.624 .19824 L
.628 .18912 L
.632 .18249 L
.636 .17986 L
.64 .18175 L
.644 .18757 L
.648 .19575 L
.652 .20408 L
.656 .21026 L
.66 .21252 L
.664 .21007 L
.668 .20323 L
.672 .19314 L
.676 .18141 L
.68 .16971 L
.684 .15958 L
.688 .15231 L
.692 .14887 L
.696 .14975 L
.7 .15487 L
.704 .16363 L
.708 .1751 L
.712 .1883 L
.716 .20236 L
.72 .21658 L
.724 .23038 L
.728 .24323 L
.732 .25469 L
.736 .26453 L
.74 .27275 L
.744 .27953 L
.748 .28507 L
.752 .28953 L
.756 .29297 L
.76 .29551 L
.764 .29731 L
.768 .29863 L
.772 .29966 L
.776 .30046 L
.78 .30102 L
.784 .30134 L
.788 .30149 L
.792 .30159 L
.796 .30172 L
.8 .30185 L
Mistroke
.804 .30194 L
.808 .30194 L
.812 .30189 L
.816 .30187 L
.82 .3019 L
.824 .30195 L
.828 .30198 L
.832 .30195 L
.836 .3019 L
.84 .30188 L
.844 .3019 L
.848 .30194 L
.852 .30195 L
.856 .30193 L
.86 .30189 L
.864 .30188 L
.868 .3019 L
.872 .30192 L
.876 .30193 L
.88 .30191 L
.884 .30188 L
.888 .30187 L
.892 .30189 L
.896 .30191 L
.9 .30192 L
.904 .30189 L
.908 .30186 L
.912 .30186 L
.916 .30188 L
.92 .30189 L
.924 .3019 L
.928 .30187 L
.932 .30185 L
.936 .30185 L
.94 .30187 L
.944 .30188 L
.948 .30188 L
.952 .30185 L
.956 .30183 L
.96 .30184 L
.964 .30187 L
.968 .30187 L
.972 .30185 L
.976 .30183 L
.98 .30181 L
.984 .30183 L
.988 .30187 L
.992 .30186 L
.996 .30182 L
1 .3018 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14184 m
.008 .14404 L
.012 .1447 L
.016 .14394 L
.02 .14369 L
.024 .14398 L
.028 .14402 L
.032 .14393 L
.036 .14389 L
.04 .14395 L
.044 .14396 L
.048 .14398 L
.052 .14399 L
.056 .14402 L
.06 .14401 L
.064 .144 L
.068 .14396 L
.072 .14393 L
.076 .14388 L
.08 .14387 L
.084 .14388 L
.088 .14393 L
.092 .14398 L
.096 .14404 L
.1 .14408 L
.104 .1441 L
.108 .14407 L
.112 .14399 L
.116 .1439 L
.12 .14383 L
.124 .1438 L
.128 .1438 L
.132 .14384 L
.136 .14393 L
.14 .14404 L
.144 .14414 L
.148 .14416 L
.152 .14414 L
.156 .14408 L
.16 .14401 L
.164 .14391 L
.168 .14381 L
.172 .14374 L
.176 .14375 L
.18 .14381 L
.184 .14389 L
.188 .14396 L
.192 .14403 L
.196 .14412 L
.2 .14419 L
Mistroke
.204 .1442 L
.208 .14415 L
.212 .14407 L
.216 .144 L
.22 .14395 L
.224 .14389 L
.228 .14379 L
.232 .14369 L
.236 .14365 L
.24 .14368 L
.244 .14377 L
.248 .14387 L
.252 .14396 L
.256 .14406 L
.26 .14422 L
.264 .14441 L
.268 .14455 L
.272 .14455 L
.276 .14441 L
.28 .14418 L
.284 .14397 L
.288 .1438 L
.292 .14362 L
.296 .14336 L
.3 .14307 L
.304 .14292 L
.308 .14302 L
.312 .14337 L
.316 .1438 L
.32 .14415 L
.324 .14437 L
.328 .14457 L
.332 .14487 L
.336 .14524 L
.34 .14551 L
.344 .14548 L
.348 .14512 L
.352 .1446 L
.356 .14414 L
.36 .14387 L
.364 .14372 L
.368 .14351 L
.372 .14312 L
.376 .14258 L
.38 .14206 L
.384 .14174 L
.388 .14167 L
.392 .14176 L
.396 .14189 L
.4 .14196 L
Mistroke
.404 .14196 L
.408 .14197 L
.412 .1421 L
.416 .14248 L
.42 .14322 L
.424 .14433 L
.428 .14576 L
.432 .14734 L
.436 .14887 L
.44 .15022 L
.444 .15142 L
.448 .15267 L
.452 .1542 L
.456 .15616 L
.46 .15847 L
.464 .16088 L
.468 .16304 L
.472 .1647 L
.476 .16585 L
.48 .16668 L
.484 .16751 L
.488 .16863 L
.492 .17018 L
.496 .17216 L
.5 .17448 L
.504 .17701 L
.508 .17966 L
.512 .18235 L
.516 .18499 L
.52 .18743 L
.524 .18951 L
.528 .19111 L
.532 .19223 L
.536 .19303 L
.54 .1938 L
.544 .19487 L
.548 .1965 L
.552 .19881 L
.556 .20177 L
.56 .20521 L
.564 .20898 L
.568 .21296 L
.572 .21715 L
.576 .22162 L
.58 .22647 L
.584 .23175 L
.588 .23743 L
.592 .24335 L
.596 .24931 L
.6 .25512 L
Mistroke
.604 .26065 L
.608 .26586 L
.612 .27085 L
.616 .27578 L
.62 .28083 L
.624 .28614 L
.628 .29175 L
.632 .29762 L
.636 .30361 L
.64 .30954 L
.644 .31523 L
.648 .32058 L
.652 .32554 L
.656 .33016 L
.66 .33457 L
.664 .33894 L
.668 .34346 L
.672 .34828 L
.676 .3535 L
.68 .35917 L
.684 .36524 L
.688 .37161 L
.692 .37815 L
.696 .38468 L
.7 .39104 L
.704 .39707 L
.708 .40266 L
.712 .40771 L
.716 .41217 L
.72 .41602 L
.724 .41927 L
.728 .42198 L
.732 .42418 L
.736 .42594 L
.74 .42732 L
.744 .42839 L
.748 .4292 L
.752 .42981 L
.756 .43026 L
.76 .43059 L
.764 .43083 L
.768 .43101 L
.772 .43113 L
.776 .43122 L
.78 .43128 L
.784 .43133 L
.788 .43137 L
.792 .43139 L
.796 .43142 L
.8 .43143 L
Mistroke
.804 .43145 L
.808 .43147 L
.812 .43148 L
.816 .4315 L
.82 .43151 L
.824 .43152 L
.828 .43154 L
.832 .43155 L
.836 .43156 L
.84 .43158 L
.844 .43159 L
.848 .4316 L
.852 .43161 L
.856 .43163 L
.86 .43164 L
.864 .43165 L
.868 .43167 L
.872 .43168 L
.876 .43169 L
.88 .43171 L
.884 .43172 L
.888 .43173 L
.892 .43174 L
.896 .43176 L
.9 .43177 L
.904 .43179 L
.908 .4318 L
.912 .43181 L
.916 .43182 L
.92 .43184 L
.924 .43185 L
.928 .43186 L
.932 .43187 L
.936 .43189 L
.94 .4319 L
.944 .43192 L
.948 .43192 L
.952 .43194 L
.956 .43195 L
.96 .43197 L
.964 .43197 L
.968 .432 L
.972 .432 L
.976 .43203 L
.98 .43202 L
.984 .43205 L
.988 .43205 L
.992 .43208 L
.996 .43207 L
1 .43211 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .1626 L
.012 .16139 L
.016 .16086 L
.02 .16124 L
.024 .16135 L
.028 .1612 L
.032 .16106 L
.036 .1611 L
.04 .16113 L
.044 .16119 L
.048 .16123 L
.052 .16132 L
.056 .16133 L
.06 .16133 L
.064 .16126 L
.068 .1612 L
.072 .16112 L
.076 .16107 L
.08 .16105 L
.084 .16111 L
.088 .16118 L
.092 .16128 L
.096 .16134 L
.1 .16139 L
.104 .16138 L
.108 .16133 L
.112 .16122 L
.116 .16111 L
.12 .16104 L
.124 .16102 L
.128 .16103 L
.132 .16109 L
.136 .16119 L
.14 .16132 L
.144 .16142 L
.148 .16145 L
.152 .16142 L
.156 .16136 L
.16 .16127 L
.164 .16116 L
.168 .16103 L
.172 .16094 L
.176 .16095 L
.18 .16103 L
.184 .16112 L
.188 .16121 L
.192 .16129 L
.196 .1614 L
.2 .16149 L
Mistroke
.204 .16152 L
.208 .16145 L
.212 .16135 L
.216 .16126 L
.22 .1612 L
.224 .16111 L
.228 .16099 L
.232 .16087 L
.236 .16082 L
.24 .16086 L
.244 .16098 L
.248 .16111 L
.252 .16121 L
.256 .16133 L
.26 .16152 L
.264 .16176 L
.268 .16194 L
.272 .16195 L
.276 .16178 L
.28 .1615 L
.284 .16123 L
.288 .16101 L
.292 .16077 L
.296 .16045 L
.3 .1601 L
.304 .15992 L
.308 .16005 L
.312 .16048 L
.316 .16101 L
.32 .16144 L
.324 .16171 L
.328 .16196 L
.332 .16234 L
.336 .16281 L
.34 .16315 L
.344 .16311 L
.348 .16265 L
.352 .16199 L
.356 .16142 L
.36 .1611 L
.364 .16092 L
.368 .16066 L
.372 .16016 L
.376 .15948 L
.38 .15884 L
.384 .15844 L
.388 .15835 L
.392 .15847 L
.396 .15863 L
.4 .15871 L
Mistroke
.404 .15871 L
.408 .15872 L
.412 .15888 L
.416 .15936 L
.42 .16028 L
.424 .16167 L
.428 .16345 L
.432 .16542 L
.436 .16732 L
.44 .169 L
.444 .1705 L
.448 .17205 L
.452 .17395 L
.456 .17639 L
.46 .17928 L
.464 .18228 L
.468 .18496 L
.472 .18703 L
.476 .18845 L
.48 .18948 L
.484 .19051 L
.488 .19189 L
.492 .19383 L
.496 .19629 L
.5 .19917 L
.504 .20231 L
.508 .20561 L
.512 .20896 L
.516 .21224 L
.52 .21527 L
.524 .21785 L
.528 .21983 L
.532 .22121 L
.536 .22219 L
.54 .22315 L
.544 .22447 L
.548 .2265 L
.552 .22937 L
.556 .23304 L
.56 .23731 L
.564 .24199 L
.568 .24694 L
.572 .25215 L
.576 .25771 L
.58 .26373 L
.584 .2703 L
.588 .27734 L
.592 .2847 L
.596 .29212 L
.6 .29934 L
Mistroke
.604 .3062 L
.608 .31267 L
.612 .31886 L
.616 .32497 L
.62 .33124 L
.624 .33783 L
.628 .34479 L
.632 .35207 L
.636 .3595 L
.64 .36685 L
.644 .37391 L
.648 .38054 L
.652 .38668 L
.656 .3924 L
.66 .39785 L
.664 .40326 L
.668 .40885 L
.672 .41482 L
.676 .42129 L
.68 .4283 L
.684 .43582 L
.688 .44371 L
.692 .45181 L
.696 .4599 L
.7 .46777 L
.704 .47524 L
.708 .48215 L
.712 .48838 L
.716 .49388 L
.72 .49862 L
.724 .50262 L
.728 .50593 L
.732 .50861 L
.736 .51074 L
.74 .5124 L
.744 .51367 L
.748 .51463 L
.752 .51533 L
.756 .51583 L
.76 .51618 L
.764 .51642 L
.768 .51658 L
.772 .51667 L
.776 .51672 L
.78 .51674 L
.784 .51674 L
.788 .51672 L
.792 .5167 L
.796 .51667 L
.8 .51663 L
Mistroke
.804 .51659 L
.808 .51655 L
.812 .5165 L
.816 .51646 L
.82 .51642 L
.824 .51638 L
.828 .51633 L
.832 .51629 L
.836 .51624 L
.84 .5162 L
.844 .51615 L
.848 .51611 L
.852 .51607 L
.856 .51602 L
.86 .51598 L
.864 .51593 L
.868 .51589 L
.872 .51585 L
.876 .5158 L
.88 .51576 L
.884 .51571 L
.888 .51567 L
.892 .51562 L
.896 .51558 L
.9 .51553 L
.904 .51549 L
.908 .51544 L
.912 .51541 L
.916 .51536 L
.92 .51532 L
.924 .51527 L
.928 .51523 L
.932 .51518 L
.936 .51514 L
.94 .51509 L
.944 .51505 L
.948 .515 L
.952 .51496 L
.956 .51491 L
.96 .51488 L
.964 .51482 L
.968 .51479 L
.972 .51473 L
.976 .5147 L
.98 .51464 L
.984 .51461 L
.988 .51455 L
.992 .51453 L
.996 .51446 L
1 .51444 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80045oo`8002Yoo`002Woo00@007ooOol0
00Qoo`04001oogoo0004Ool01@00Oomoogoo0000@Woo00<007oo0000:Goo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool00`00Oomoo`020010Ool01000Oomoo`00:Goo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02000lOol01@00Oomoogoo00000Woo00<007oo
Ool09goo000;Ool2000:Ool20003Ool30003Ool00`00Oomoo`0jOol00`00Ool00002Ool01@00Oomo
ogoo0000:7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2000hOol01000Oomoo`00
0Woo0P0017oo00<007ooOol09Woo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8000eoo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000Eoo`<000=oo`D0009oo`8000=oo`D0
00=oo`8000Aoo`8000Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo00000Woo00@007ooOol0
00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`800003Ool0
0000009oo`04001oogoo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0004Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0004Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0004Ool20003
Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol02goo10000goo
00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomo
o`@000=oo`04001oogoo0002Ool01@00Ool007oo00000Woo00@007ooOol0009oo`04001oogoo0003
Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo
009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`020002Ool01000Oomo
o`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`008Woo0P00
37oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00<007ooOol01P000goo0P0017oo
0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`0dOol00`00Oomo
o`0?Ool00`00Oomoo`0SOol0029oo`8003Eoo`03001oogoo00moo`<002=oo`008WooH`0037oo000R
Ool00`00Ool0000200001Goo00000000Ool00`0000=oo`0000000`0000=oo`0000000`000Woo0`00
00=oo`00Ool0100000=oo`0000000goo00D007ooOomoo`0000=oo`03001oogoo008000=oo`04001o
ogoo0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00<007ooOol02Woo000ROol20002Ool300001Goo00000000Ool00`000goo0`00
00=oo`0000000`000goo0`0000Ioo`00Oomoo`00Ool40002Ool00`00Oomoo`030003Ool00`00Oomo
o`0fOol0029oo`03001oogoo01aoo`8000Uoo`800006Ool00000Ool007oo0P000Woo00<007ooOol0
=Woo000ROol2000YOol20002Ool01@00Oomoogoo00000Woo00<007ooOol0=Woo000ROol2000YOol0
0`00Oomoo`06Ool2000iOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo
035oo`8003Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]o
o`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomo
ogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool0
00Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`80
00=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003
Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo0080
06eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo
001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/
Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Ao
o`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001o
ogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomo
o`02OolY0010Ool002Qoo`03001oogoo02Eoo`<003ioo`00:7oo00<007ooOol0:7oo0`00>goo000;
Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0ZOol3000iOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00;Woo0`00
=goo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomo
o`00<7oo0`00=Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool300000goo000000030004Ool2
0002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool0
1000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo
0P000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05
001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0
009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo
Ool00Woo0P0000Eoo`00Oomoo`00009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Ao
o`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00=oo`03001oo`00009oo`04001oogoo
0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04
001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<0
00=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool2
0004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo0080009oo`06001oogoo
001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo
00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo
0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`80
00Ioo`00:7oo00<007ooOol0=Woo00<007ooOol0;Goo000XOol00`00Oomoo`0gOol00`00Oomoo`0/
Ool002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00D007oo
Oomoo`0000eoo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0>Goo00<007ooOol0
:Woo000XOol00`00Oomoo`0jOol00`00Oomoo`0YOol002Qoo`03001oogoo03]oo`03001oogoo02Qo
o`00:7oo00<007ooOol0>goo0P00:Goo000XOol00`00Oomoo`0lOol00`00Oomoo`0WOol000]oo`80
00Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo03eoo`03001oogoo02Ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000oOol0
0`00Oomoo`0VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001o
ogoo0010Ool00`00Oomoo`0UOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo0080041oo`8002Eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00
Oomoo`00Ool010000goo00<007ooOol0@7oo6P0037oo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool20002Ool50002
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`00
4Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007oo
Oomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000
K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P00
2Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo
0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=o
o`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009o
o`03001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo
0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2
000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo
00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04
001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol4
0003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04
Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomo
o`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00
Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo
0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@00
37oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007oo00000`000Woo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00
Oomoo`0/Ool20014Ool001aoo`8002moo`<0045oo`0077oo00<007ooOol0<7oo0P00@7oo000LOol0
0`00Oomoo`0aOol2000oOol001aoo`8003Aoo`8003eoo`0077oo00<007ooOol0=Goo0P00>goo000L
Ool00`00Oomoo`0gOol00`00Oomoo`0hOol001aoo`8003Uoo`03001oogoo03Moo`0077oo00<007oo
Ool0>7oo0P00>7oo000LOol2000jOol00`00Oomoo`0fOol000]oo`8000Aoo`03001oogoo009oo`<0
00=oo`03001oogoo03Yoo`03001oogoo03Eoo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`0jOol00`00Oomoo`0eOol000Yoo`04001oogoo000;Ool00`00Oomoo`02000lOol0
0`00Oomoo`0dOol000Yoo`04001oogoo000;Ool01000Oomoo`00?Goo0P00=Goo000:Ool01000Oomo
o`001goo10000goo00<007ooOol0?7oo00<007ooOol0<goo000:Ool01000Oomoo`001goo00<007oo
Ool017oo0P00?Goo0P00=7oo000;Ool20008Ool50002Ool00`00Oomoo`0mOol00`00Oomoo`0bOol0
01aoo`03001oogoo03ioo`03001oogoo035oo`0077oo0P00@7oo00<007ooOol0<7oo000LOol00`00
Oomoo`0oOol00`00Oomoo`0`Ool001aoo`80041oo`80035oo`0077oo00<007ooOol0@7oo00<007oo
Ool0;goo000LOol00`00Oomoo`11Ool00`00Oomoo`0^Ool001aoo`80049oo`8002moo`005Woo0`00
0goo00<007ooOol0@Woo0P00;Woo000GOol00`00Oomoo`02Ool00`00Oomoo`13Ool00`00Oomoo`0/
Ool001Moo`03001oogoo009oo`8004Aoo`03001oogoo02aoo`005goo00<007ooOol00Woo00<007oo
Ool0A7oo00<007ooOol0:goo000GOol00`00Oomoo`02Ool00`00Oomoo`15Ool00`00Oomoo`0ZOol0
01Ioo`8000Aoo`8004Ioo`03001oogoo02Yoo`005goo00<007ooOol00Woo00<007ooOol0AWoo00<0
07ooOol0:Goo000LOol00`00Oomoo`16Ool00`00Oomoo`0YOol001aoo`8004Qoo`03001oogoo02Qo
o`0077oo00<007ooOol0Agoo0P00:Goo000LOol20019Ool2000XOol001aoo`03001oogoo04Yooa`0
00aoo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]o
o`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04
001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo
10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03
001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(16032\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .316 m
.008 .31713 L
.012 .31904 L
.016 .32022 L
.02 .3207 L
.024 .32121 L
.028 .32138 L
.032 .32076 L
.036 .31919 L
.04 .31763 L
.044 .31647 L
.048 .31593 L
.052 .31658 L
.056 .31817 L
.06 .32036 L
.064 .32206 L
.068 .32257 L
.072 .32201 L
.076 .32033 L
.08 .31823 L
.084 .31646 L
.088 .31588 L
.092 .31679 L
.096 .31825 L
.1 .31967 L
.104 .32062 L
.108 .321 L
.112 .32085 L
.116 .32017 L
.12 .31971 L
.124 .31977 L
.128 .32007 L
.132 .3198 L
.136 .31848 L
.14 .31686 L
.144 .31586 L
.148 .31606 L
.152 .31741 L
.156 .31975 L
.16 .32282 L
.164 .32532 L
.168 .32561 L
.172 .32302 L
.176 .31873 L
.18 .31495 L
.184 .3132 L
.188 .31371 L
.192 .31586 L
.196 .31893 L
.2 .32204 L
Mistroke
.204 .32397 L
.208 .32377 L
.212 .32173 L
.216 .31943 L
.22 .31849 L
.224 .31922 L
.228 .32051 L
.232 .32092 L
.236 .31996 L
.24 .3183 L
.244 .31697 L
.248 .31653 L
.252 .31688 L
.256 .31761 L
.26 .31855 L
.264 .31981 L
.268 .32132 L
.272 .32255 L
.276 .32286 L
.28 .32222 L
.284 .32154 L
.288 .32188 L
.292 .32311 L
.296 .32354 L
.3 .32136 L
.304 .31665 L
.308 .31194 L
.312 .31029 L
.316 .31255 L
.32 .31649 L
.324 .31899 L
.328 .31903 L
.332 .31865 L
.336 .32067 L
.34 .32552 L
.344 .33035 L
.348 .33154 L
.352 .32811 L
.356 .32271 L
.36 .31923 L
.364 .31929 L
.368 .32095 L
.372 .32079 L
.376 .31724 L
.38 .3121 L
.384 .30892 L
.388 .30992 L
.392 .31417 L
.396 .31857 L
.4 .32036 L
Mistroke
.404 .31909 L
.408 .31642 L
.412 .31454 L
.416 .31455 L
.42 .31631 L
.424 .31904 L
.428 .32215 L
.432 .32517 L
.436 .32741 L
.44 .32807 L
.444 .32694 L
.448 .32518 L
.452 .32512 L
.456 .32886 L
.46 .33645 L
.464 .34517 L
.468 .35073 L
.472 .34979 L
.476 .34229 L
.48 .33181 L
.484 .32368 L
.488 .32196 L
.492 .32718 L
.496 .3362 L
.5 .34418 L
.504 .34733 L
.508 .34478 L
.512 .3385 L
.516 .33169 L
.52 .32672 L
.524 .32411 L
.528 .32291 L
.532 .32211 L
.536 .32186 L
.54 .32363 L
.544 .3292 L
.548 .33909 L
.552 .35157 L
.556 .363 L
.56 .36923 L
.564 .36753 L
.568 .35774 L
.572 .3423 L
.576 .325 L
.58 .30929 L
.584 .29695 L
.588 .28766 L
.592 .27959 L
.596 .27051 L
.6 .25894 L
Mistroke
.604 .24487 L
.608 .2298 L
.612 .21619 L
.616 .20654 L
.62 .2023 L
.624 .20329 L
.628 .20765 L
.632 .21248 L
.636 .2149 L
.64 .21309 L
.644 .2069 L
.648 .19771 L
.652 .18785 L
.656 .17978 L
.66 .17536 L
.664 .17548 L
.668 .17994 L
.672 .1875 L
.676 .19621 L
.68 .20382 L
.684 .20827 L
.688 .20826 L
.692 .20353 L
.696 .19479 L
.7 .18345 L
.704 .17121 L
.708 .15975 L
.712 .15054 L
.716 .14472 L
.72 .14304 L
.724 .14572 L
.728 .15247 L
.732 .16258 L
.736 .17507 L
.74 .18902 L
.744 .20359 L
.748 .21811 L
.752 .232 L
.756 .24473 L
.76 .25597 L
.764 .26559 L
.768 .27363 L
.772 .28028 L
.776 .2857 L
.78 .28998 L
.784 .29324 L
.788 .29565 L
.792 .29743 L
.796 .29877 L
.8 .2998 L
Mistroke
.804 .30054 L
.808 .30102 L
.812 .30131 L
.816 .30149 L
.82 .30165 L
.824 .30179 L
.828 .30189 L
.832 .30192 L
.836 .30191 L
.84 .3019 L
.844 .30192 L
.848 .30195 L
.852 .30198 L
.856 .30197 L
.86 .30194 L
.864 .30192 L
.868 .30192 L
.872 .30195 L
.876 .30197 L
.88 .30195 L
.884 .30192 L
.888 .30191 L
.892 .30192 L
.896 .30194 L
.9 .30195 L
.904 .30193 L
.908 .3019 L
.912 .3019 L
.916 .30191 L
.92 .30193 L
.924 .30193 L
.928 .30191 L
.932 .30188 L
.936 .30189 L
.94 .30191 L
.944 .30192 L
.948 .30191 L
.952 .30189 L
.956 .30187 L
.96 .30188 L
.964 .3019 L
.968 .30191 L
.972 .30189 L
.976 .30186 L
.98 .30185 L
.984 .30187 L
.988 .3019 L
.992 .30189 L
.996 .30186 L
1 .30184 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14222 m
.008 .14432 L
.012 .145 L
.016 .14438 L
.02 .14408 L
.024 .14428 L
.028 .14437 L
.032 .14435 L
.036 .14432 L
.04 .14438 L
.044 .14438 L
.048 .14437 L
.052 .14432 L
.056 .1443 L
.06 .14427 L
.064 .14427 L
.068 .14428 L
.072 .14434 L
.076 .14437 L
.08 .14441 L
.084 .14442 L
.088 .14441 L
.092 .14436 L
.096 .14429 L
.1 .14424 L
.104 .14422 L
.108 .14423 L
.112 .14427 L
.116 .14433 L
.12 .14441 L
.124 .14447 L
.128 .14448 L
.132 .14444 L
.136 .14438 L
.14 .1443 L
.144 .14423 L
.148 .14417 L
.152 .14415 L
.156 .14419 L
.16 .14429 L
.164 .14439 L
.168 .14446 L
.172 .14451 L
.176 .14452 L
.18 .1445 L
.184 .14443 L
.188 .14431 L
.192 .1442 L
.196 .14414 L
.2 .14414 L
Mistroke
.204 .14417 L
.208 .14421 L
.212 .14427 L
.216 .14436 L
.22 .14447 L
.224 .14454 L
.228 .14455 L
.232 .14452 L
.236 .14448 L
.24 .14445 L
.244 .14439 L
.248 .1443 L
.252 .14417 L
.256 .14407 L
.26 .14403 L
.264 .14407 L
.268 .14412 L
.272 .14417 L
.276 .14422 L
.28 .14432 L
.284 .14452 L
.288 .14475 L
.292 .14491 L
.296 .14492 L
.3 .1448 L
.304 .14465 L
.308 .14452 L
.312 .14438 L
.316 .14415 L
.32 .1438 L
.324 .14345 L
.328 .14328 L
.332 .14337 L
.336 .14368 L
.34 .14401 L
.344 .14425 L
.348 .14444 L
.352 .1447 L
.356 .14512 L
.36 .14559 L
.364 .1459 L
.368 .14588 L
.372 .14555 L
.376 .14511 L
.38 .14475 L
.384 .14455 L
.388 .1444 L
.392 .14414 L
.396 .14371 L
.4 .14315 L
Mistroke
.404 .14264 L
.408 .1423 L
.412 .14218 L
.416 .1422 L
.42 .14227 L
.424 .1423 L
.428 .14226 L
.432 .1422 L
.436 .14221 L
.44 .14242 L
.444 .14298 L
.448 .14395 L
.452 .14529 L
.456 .1468 L
.46 .14827 L
.464 .14956 L
.468 .15068 L
.472 .15183 L
.476 .15328 L
.48 .15517 L
.484 .15746 L
.488 .15989 L
.492 .16212 L
.496 .1639 L
.5 .16517 L
.504 .1661 L
.508 .16695 L
.512 .16799 L
.516 .16937 L
.52 .17113 L
.524 .17322 L
.528 .17558 L
.532 .17815 L
.536 .18086 L
.54 .18361 L
.544 .18622 L
.548 .18851 L
.552 .19031 L
.556 .19158 L
.56 .19245 L
.564 .19318 L
.568 .19409 L
.572 .19546 L
.576 .19745 L
.58 .20006 L
.584 .20317 L
.588 .20665 L
.592 .21036 L
.596 .21431 L
.6 .21854 L
Mistroke
.604 .22315 L
.608 .22823 L
.612 .23373 L
.616 .23955 L
.62 .24549 L
.624 .25134 L
.628 .25695 L
.632 .26226 L
.636 .26731 L
.64 .27224 L
.644 .27723 L
.648 .28244 L
.652 .28793 L
.656 .29371 L
.66 .29967 L
.664 .30565 L
.668 .31146 L
.672 .31697 L
.676 .3221 L
.68 .32687 L
.684 .33136 L
.688 .33573 L
.692 .34015 L
.696 .34479 L
.7 .34978 L
.704 .3552 L
.708 .36105 L
.712 .36726 L
.716 .37371 L
.72 .38026 L
.724 .38673 L
.728 .39298 L
.732 .39885 L
.736 .40425 L
.74 .40909 L
.744 .41334 L
.748 .417 L
.752 .42007 L
.756 .42262 L
.76 .42469 L
.764 .42633 L
.768 .42763 L
.772 .42862 L
.776 .42938 L
.78 .42995 L
.784 .43038 L
.788 .43069 L
.792 .43091 L
.796 .43108 L
.8 .43119 L
Mistroke
.804 .43128 L
.808 .43134 L
.812 .43139 L
.816 .43142 L
.82 .43145 L
.824 .43147 L
.828 .43149 L
.832 .43151 L
.836 .43152 L
.84 .43154 L
.844 .43155 L
.848 .43156 L
.852 .43158 L
.856 .43159 L
.86 .4316 L
.864 .43162 L
.868 .43163 L
.872 .43164 L
.876 .43165 L
.88 .43167 L
.884 .43168 L
.888 .4317 L
.892 .43171 L
.896 .43172 L
.9 .43173 L
.904 .43175 L
.908 .43176 L
.912 .43177 L
.916 .43178 L
.92 .4318 L
.924 .43181 L
.928 .43183 L
.932 .43183 L
.936 .43185 L
.94 .43186 L
.944 .43188 L
.948 .43189 L
.952 .43191 L
.956 .43191 L
.96 .43193 L
.964 .43194 L
.968 .43196 L
.972 .43196 L
.976 .43199 L
.98 .43199 L
.984 .43201 L
.988 .43201 L
.992 .43204 L
.996 .43204 L
1 .43207 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15973 L
.012 .16123 L
.016 .16163 L
.02 .16113 L
.024 .16101 L
.028 .16127 L
.032 .16132 L
.036 .16128 L
.04 .16124 L
.044 .16125 L
.048 .1612 L
.052 .16117 L
.056 .16113 L
.06 .16114 L
.064 .16115 L
.068 .1612 L
.072 .16123 L
.076 .16128 L
.08 .16129 L
.084 .1613 L
.088 .16127 L
.092 .16123 L
.096 .16116 L
.1 .16111 L
.104 .16108 L
.108 .1611 L
.112 .16114 L
.116 .16121 L
.12 .16129 L
.124 .16137 L
.128 .16139 L
.132 .16135 L
.136 .16127 L
.14 .16118 L
.144 .16109 L
.148 .16102 L
.152 .16099 L
.156 .16104 L
.16 .16115 L
.164 .16128 L
.168 .16137 L
.172 .16142 L
.176 .16144 L
.18 .16142 L
.184 .16134 L
.188 .16119 L
.192 .16105 L
.196 .16098 L
.2 .16097 L
Mistroke
.204 .161 L
.208 .16104 L
.212 .16112 L
.216 .16125 L
.22 .16139 L
.224 .16149 L
.228 .16149 L
.232 .16144 L
.236 .16138 L
.24 .16134 L
.244 .16128 L
.248 .16117 L
.252 .16103 L
.256 .1609 L
.26 .16084 L
.264 .16087 L
.268 .16094 L
.272 .16099 L
.276 .16106 L
.28 .16121 L
.284 .16145 L
.288 .16174 L
.292 .16193 L
.296 .16193 L
.3 .16178 L
.304 .1616 L
.308 .16144 L
.312 .16128 L
.316 .16099 L
.32 .16055 L
.324 .16011 L
.328 .15988 L
.332 .16001 L
.336 .16039 L
.34 .16081 L
.344 .16111 L
.348 .16134 L
.352 .16167 L
.356 .16218 L
.36 .16276 L
.364 .16315 L
.368 .16313 L
.372 .16273 L
.376 .16218 L
.38 .16173 L
.384 .16147 L
.388 .16128 L
.392 .16097 L
.396 .16042 L
.4 .15973 L
Mistroke
.404 .15909 L
.408 .15867 L
.412 .15851 L
.416 .15855 L
.42 .15863 L
.424 .15867 L
.428 .15862 L
.432 .15854 L
.436 .15855 L
.44 .15882 L
.444 .15952 L
.448 .16073 L
.452 .16239 L
.456 .16427 L
.46 .16611 L
.464 .16771 L
.468 .16911 L
.472 .17055 L
.476 .17235 L
.48 .1747 L
.484 .17755 L
.488 .18057 L
.492 .18335 L
.496 .18556 L
.5 .18715 L
.504 .18829 L
.508 .18934 L
.512 .19063 L
.516 .19235 L
.52 .19454 L
.524 .19714 L
.528 .20008 L
.532 .20327 L
.536 .20663 L
.54 .21005 L
.544 .2133 L
.548 .21614 L
.552 .21838 L
.556 .21995 L
.56 .22102 L
.564 .22191 L
.568 .22303 L
.572 .22474 L
.576 .22721 L
.58 .23045 L
.584 .23432 L
.588 .23863 L
.592 .24325 L
.596 .24815 L
.6 .25341 L
Mistroke
.604 .25915 L
.608 .26545 L
.612 .27229 L
.616 .27952 L
.62 .2869 L
.624 .29418 L
.628 .30115 L
.632 .30773 L
.636 .314 L
.64 .32011 L
.644 .32631 L
.648 .33276 L
.652 .33959 L
.656 .34676 L
.66 .35415 L
.664 .36156 L
.668 .36877 L
.672 .3756 L
.676 .38196 L
.68 .38787 L
.684 .39342 L
.688 .39882 L
.692 .40428 L
.696 .41003 L
.7 .41621 L
.704 .42293 L
.708 .43017 L
.712 .43785 L
.716 .44585 L
.72 .45396 L
.724 .46198 L
.728 .46971 L
.732 .47697 L
.736 .48364 L
.74 .48962 L
.744 .49486 L
.748 .49935 L
.752 .50313 L
.756 .50624 L
.76 .50876 L
.764 .51075 L
.768 .5123 L
.772 .51349 L
.776 .51437 L
.78 .51502 L
.784 .51549 L
.788 .51581 L
.792 .51604 L
.796 .51618 L
.8 .51627 L
Mistroke
.804 .51631 L
.808 .51633 L
.812 .51632 L
.816 .51631 L
.82 .51628 L
.824 .51625 L
.828 .51621 L
.832 .51617 L
.836 .51613 L
.84 .51609 L
.844 .51604 L
.848 .516 L
.852 .51596 L
.856 .51591 L
.86 .51587 L
.864 .51583 L
.868 .51578 L
.872 .51574 L
.876 .51569 L
.88 .51565 L
.884 .5156 L
.888 .51556 L
.892 .51551 L
.896 .51547 L
.9 .51542 L
.904 .51538 L
.908 .51534 L
.912 .5153 L
.916 .51525 L
.92 .51521 L
.924 .51516 L
.928 .51512 L
.932 .51507 L
.936 .51503 L
.94 .51498 L
.944 .51494 L
.948 .51489 L
.952 .51486 L
.956 .5148 L
.96 .51477 L
.964 .51471 L
.968 .51468 L
.972 .51462 L
.976 .51459 L
.98 .51453 L
.984 .51451 L
.988 .51444 L
.992 .51442 L
.996 .51435 L
1 .51433 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00A7oo00<007ooOol09Woo0003
Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8004Aoo`8002Moo`00
2Woo00@007ooOol000Qoo`04001oogoo0004Ool01@00Oomoogoo0000A7oo00<007oo00009goo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02000nOol20003Ool01000Oomo
o`009Woo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02000nOol20002
Ool01@00Oomoogoo00009Woo000;Ool2000:Ool20003Ool30003Ool00`00Oomoo`0mOol01@00Ool0
07oo00000goo00<007ooOol097oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2000k
Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`0SOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`00
0goo2@0000=oo`00Ool01@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogoo
Ool00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
1@00Oomoogoo00000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@0
07ooOol0009oo`03001oogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`04Ool20002Ool01000Oomoo`0017oo00<007oo00000Woo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Aoo`80009oo`04001oogoo
0005Ool01@00Ool007oo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
00<007ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01000Oomoogoo0P0000Eoo`00Oomo
o`00009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`80
00Yoo`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`04001oogoo0003Ool01000Oomoo`000Woo00H0
07ooOomoo`00Ool20002Ool01000Oomoo`000Woo00D007ooOomoo`0000=oo`03001oo`0000Ioo`04
001oogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04
001oogooOol50003Ool20004Ool30002Ool01000Ool0000017oo0P001Goo0`000Woo1@000goo0P00
1Woo000ROol00`00Oomoo`0fOol2000@Ool2000ROol0029oo`8003Moo`03001oogoo011oo`80025o
o`008WooH`0037oo000ROol20002Ool300001Goo00000000Ool02@0000=oo`00Ool00P0000Aoo`00
Oomoo`<0009oo`L00003Ool007oo009oo`05001oogooOol00003Ool01@00Ool007oo00000Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol0000<Ool0029oo`@0009oo`<00003Ool0000000800004Ool000000002Ool40002
Ool40003Ool40002Ool00`00Oomoo`0400000goo00000002Ool30002Ool00`00Oomoo`0dOol0029o
o`03001oogoo01moo`03001oogoo00Qoo`06001oo`00001oo`000goo00<007oo0000=Woo000ROol2
000[Ool300000goo00000003Ool00`00Ool0000fOol0029oo`8002aoo`03001oogoo00Eoo`8003Mo
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0<goo0P00=goo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool0
00]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol0
0goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qo
o`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo
000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo
0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000R
Ool00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo
00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oob/003ioo`00:7oo
00<007ooOol0:7oo0`00>goo000XOol00`00Oomoo`0ZOol4000hOol000]oo`8000Aoo`03001oogoo
00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo02eoo`8003Moo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000`Ool4000dOol000=oo`D0009oo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000cOol3000bOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Ao
o`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=o
o`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00
Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00002Ool20002Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00H007ooOol007oo0003Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001o
ogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogoo
Ool00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo
0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
ogoo00Eoo`800005Ool007ooOol00004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001o
ogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uo
o`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04
001oogooOol4000017oo000000000Woo00<007oo00000goo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo
00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P00
0goo00<007ooOol00goo0P000Woo00<007oo00000goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo
0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D0009oo`<000=oo`<000Aoo`80
00Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0>7oo0P00;7oo000XOol00`00
Oomoo`0iOol00`00Oomoo`0ZOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo
00<007ooOol03goo00<007ooOol017oo00<007ooOol027oo00<007ooOol047oo00<007ooOol02Woo
000XOol00`00Oomoo`0kOol2000YOol002Qoo`03001oogoo03aoo`8002Qoo`00:7oo00<007ooOol0
?Goo00<007ooOol09Woo000XOol00`00Oomoo`0nOol00`00Oomoo`0UOol002Qoo`03001oogoo03mo
o`03001oogoo02Aoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007oo
Ool0?goo00<007ooOol097oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`000goo00@007ooOol0049oo`03001oogoo02=oo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOol0049oo`8002Aoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol00P00@Woo0P008goo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`13OolG000<Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`80
00Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007oo
Ool0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo
00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol0
00Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`00
2goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004
Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004
Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001o
ogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`00
0goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03
001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo
0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo
00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Ao
o`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D0
00=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004
Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01000Oomoogoo
1@000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:
Ool001aoo`03001oogoo02moo`80045oo`0077oo0P00<Goo1000?Woo000LOol00`00Oomoo`0cOol2
000mOol001aoo`03001oogoo03Aoo`8003aoo`0077oo0P00=Woo0`00>Woo000LOol00`00Oomoo`0h
Ool2000hOol001aoo`03001oogoo03Yoo`03001oogoo03Eoo`0077oo0P00>goo0P00=Woo000LOol0
0`00Oomoo`0kOol2000eOol001aoo`8003eoo`03001oogoo03=oo`002goo0P0017oo00<007ooOol0
0Woo0`000goo00<007ooOol0?7oo0P00=7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo03eoo`03001oogoo039oo`002Woo00@007ooOol000]oo`03001oogoo008003moo`03
001oogoo035oo`002Woo00@007ooOol000]oo`04001oogoo0010Ool2000bOol000Yoo`04001oogoo
0007Ool40003Ool00`00Oomoo`0oOol00`00Oomoo`0`Ool000Yoo`04001oogoo0007Ool00`00Oomo
o`04Ool20010Ool2000aOol000]oo`8000Qoo`D0009oo`03001oogoo041oo`03001oogoo02moo`00
77oo00<007ooOol0@Goo00<007ooOol0;Woo000LOol20012Ool00`00Oomoo`0^Ool001aoo`03001o
ogoo049oo`03001oogoo02eoo`0077oo0P00@goo0P00;Woo000LOol00`00Oomoo`13Ool00`00Oomo
o`0/Ool001aoo`03001oogoo04=oo`8002eoo`0077oo0P00AGoo0P00;7oo000FOol30003Ool00`00
Oomoo`15Ool00`00Oomoo`0ZOol001Moo`03001oogoo009oo`03001oogoo04Ioo`03001oogoo02Uo
o`005goo00<007ooOol00Woo0P00Agoo00<007ooOol0:Goo000GOol00`00Oomoo`02Ool00`00Oomo
o`17Ool00`00Oomoo`0XOol001Moo`03001oogoo009oo`03001oogoo04Moo`03001oogoo02Qoo`00
5Woo0P0017oo0P00BGoo00<007ooOol09goo000GOol00`00Oomoo`02Ool00`00Oomoo`18Ool00`00
Oomoo`0WOol001aoo`03001oogoo04Uoo`03001oogoo02Ioo`0077oo0P00BWoo0P009goo000LOol0
0`00Oomoo`1:Ool2000VOol001aoo`8004aoo`8002Eoo`0077oo00<007ooOol0CGoo6@0037oo000L
Ool00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007oo
Ool01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol0
07Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool0
0`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol0
1goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(16199\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31905 m
.008 .31908 L
.012 .31854 L
.016 .31798 L
.02 .31747 L
.024 .31766 L
.028 .31859 L
.032 .31954 L
.036 .32021 L
.04 .32034 L
.044 .32004 L
.048 .31923 L
.052 .31827 L
.056 .31789 L
.06 .31814 L
.064 .31895 L
.068 .31977 L
.072 .32024 L
.076 .32014 L
.08 .31912 L
.084 .31781 L
.088 .31705 L
.092 .31748 L
.096 .31906 L
.1 .32091 L
.104 .32239 L
.108 .32265 L
.112 .32121 L
.116 .31837 L
.12 .31527 L
.124 .31373 L
.128 .31471 L
.132 .31779 L
.136 .32163 L
.14 .32467 L
.144 .32591 L
.148 .32453 L
.152 .32072 L
.156 .31609 L
.16 .31295 L
.164 .3128 L
.168 .31517 L
.172 .31857 L
.176 .32165 L
.18 .32363 L
.184 .32414 L
.188 .32298 L
.192 .32074 L
.196 .31869 L
.2 .31792 L
Mistroke
.204 .31827 L
.208 .31853 L
.212 .31794 L
.216 .31693 L
.22 .31664 L
.224 .31765 L
.228 .31953 L
.232 .32138 L
.236 .32261 L
.24 .32307 L
.244 .32275 L
.248 .32155 L
.252 .31966 L
.256 .31779 L
.26 .31687 L
.264 .31739 L
.268 .31884 L
.272 .31991 L
.276 .31954 L
.28 .31793 L
.284 .31652 L
.288 .31684 L
.292 .31911 L
.296 .32188 L
.3 .32339 L
.304 .32318 L
.308 .32246 L
.312 .32263 L
.316 .32352 L
.32 .3234 L
.324 .32088 L
.328 .31672 L
.332 .31348 L
.336 .31314 L
.34 .31508 L
.344 .31674 L
.348 .31634 L
.352 .31498 L
.356 .31565 L
.36 .3201 L
.364 .32667 L
.368 .33126 L
.372 .3309 L
.376 .32638 L
.38 .32157 L
.384 .31997 L
.388 .32173 L
.392 .32378 L
.396 .32274 L
.4 .31802 L
Mistroke
.404 .31226 L
.408 .3091 L
.412 .31024 L
.416 .31437 L
.42 .3185 L
.424 .32028 L
.428 .31933 L
.432 .31695 L
.436 .31484 L
.44 .31405 L
.444 .31492 L
.448 .31737 L
.452 .321 L
.456 .32488 L
.46 .3275 L
.464 .32757 L
.468 .32507 L
.472 .3219 L
.476 .32117 L
.48 .3252 L
.484 .33372 L
.488 .34343 L
.492 .34967 L
.496 .34908 L
.5 .34177 L
.504 .33137 L
.508 .3231 L
.512 .32082 L
.516 .32512 L
.52 .33326 L
.524 .34098 L
.528 .34484 L
.532 .3438 L
.536 .33921 L
.54 .3335 L
.544 .32856 L
.548 .32494 L
.552 .32208 L
.556 .31942 L
.56 .31744 L
.564 .31776 L
.568 .32229 L
.572 .33181 L
.576 .34497 L
.58 .35829 L
.584 .36742 L
.588 .369 L
.592 .36208 L
.596 .34849 L
.6 .33187 L
Mistroke
.604 .31598 L
.608 .30308 L
.612 .29329 L
.616 .28492 L
.62 .27565 L
.624 .2638 L
.628 .24916 L
.632 .23308 L
.636 .21797 L
.64 .20637 L
.644 .20003 L
.648 .19922 L
.652 .20255 L
.656 .20743 L
.66 .21091 L
.664 .2107 L
.668 .20595 L
.672 .19746 L
.676 .18727 L
.68 .17793 L
.684 .17166 L
.688 .16982 L
.692 .17263 L
.696 .17924 L
.7 .18792 L
.704 .19652 L
.708 .20284 L
.712 .20521 L
.716 .20285 L
.72 .19596 L
.724 .1856 L
.728 .17336 L
.732 .16098 L
.736 .15009 L
.74 .14205 L
.744 .13782 L
.748 .13794 L
.752 .14239 L
.756 .1507 L
.76 .16202 L
.764 .17543 L
.768 .19004 L
.772 .20505 L
.776 .2198 L
.78 .23368 L
.784 .24624 L
.788 .25725 L
.792 .26666 L
.796 .27455 L
.8 .28106 L
Mistroke
.804 .28629 L
.808 .29038 L
.812 .29349 L
.816 .29583 L
.82 .2976 L
.824 .29892 L
.828 .2999 L
.832 .30057 L
.836 .30102 L
.84 .30132 L
.844 .30153 L
.848 .3017 L
.852 .30183 L
.856 .30189 L
.86 .30191 L
.864 .30192 L
.868 .30193 L
.872 .30196 L
.876 .30198 L
.88 .30198 L
.884 .30196 L
.888 .30195 L
.892 .30195 L
.896 .30197 L
.9 .30198 L
.904 .30197 L
.908 .30194 L
.912 .30193 L
.916 .30194 L
.92 .30196 L
.924 .30197 L
.928 .30195 L
.932 .30192 L
.936 .30192 L
.94 .30194 L
.944 .30195 L
.948 .30195 L
.952 .30192 L
.956 .3019 L
.96 .30191 L
.964 .30194 L
.968 .30194 L
.972 .30192 L
.976 .3019 L
.98 .30189 L
.984 .30191 L
.988 .30193 L
.992 .30192 L
.996 .30189 L
1 .30188 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14637 m
.008 .14463 L
.012 .14406 L
.016 .14478 L
.02 .14494 L
.024 .14473 L
.028 .14465 L
.032 .14473 L
.036 .1447 L
.04 .14466 L
.044 .14463 L
.048 .14467 L
.052 .14469 L
.056 .14473 L
.06 .14474 L
.064 .14476 L
.068 .14474 L
.072 .14473 L
.076 .14468 L
.08 .14465 L
.084 .14463 L
.088 .14464 L
.092 .14466 L
.096 .1447 L
.1 .14473 L
.104 .14478 L
.108 .14479 L
.112 .14478 L
.116 .14473 L
.12 .14468 L
.124 .14463 L
.128 .1446 L
.132 .14459 L
.136 .14461 L
.14 .14468 L
.144 .14476 L
.148 .14482 L
.152 .14484 L
.156 .14483 L
.16 .14479 L
.164 .14471 L
.168 .14462 L
.172 .14454 L
.176 .14452 L
.18 .14456 L
.184 .14463 L
.188 .14471 L
.192 .14478 L
.196 .14485 L
.2 .14491 L
Mistroke
.204 .1449 L
.208 .14482 L
.212 .14472 L
.216 .14462 L
.22 .14456 L
.224 .14453 L
.228 .1445 L
.232 .14452 L
.236 .14459 L
.24 .14471 L
.244 .14482 L
.248 .14489 L
.252 .14489 L
.256 .14488 L
.26 .14488 L
.264 .14487 L
.268 .14482 L
.272 .14471 L
.276 .14458 L
.28 .14448 L
.284 .14445 L
.288 .14446 L
.292 .14446 L
.296 .14445 L
.3 .14448 L
.304 .14461 L
.308 .14484 L
.312 .14508 L
.316 .14522 L
.32 .14523 L
.324 .14516 L
.328 .14511 L
.332 .14507 L
.336 .14496 L
.34 .14467 L
.344 .14426 L
.348 .14387 L
.352 .14369 L
.356 .14378 L
.36 .144 L
.364 .14422 L
.368 .14436 L
.372 .14452 L
.376 .14485 L
.38 .14535 L
.384 .14587 L
.388 .14621 L
.392 .14621 L
.396 .14596 L
.4 .14561 L
Mistroke
.404 .14535 L
.408 .14519 L
.412 .14504 L
.416 .14476 L
.42 .14431 L
.424 .14376 L
.428 .14324 L
.432 .14288 L
.436 .14269 L
.44 .14266 L
.444 .14268 L
.448 .14269 L
.452 .14263 L
.456 .1425 L
.46 .14239 L
.464 .14245 L
.468 .14284 L
.472 .14367 L
.476 .14489 L
.48 .14632 L
.484 .14773 L
.488 .14895 L
.492 .14999 L
.496 .15106 L
.5 .15241 L
.504 .15422 L
.508 .15645 L
.512 .15887 L
.516 .16116 L
.52 .16305 L
.524 .16446 L
.528 .1655 L
.532 .1664 L
.536 .1674 L
.54 .16865 L
.544 .1702 L
.548 .17207 L
.552 .17423 L
.556 .17667 L
.56 .17935 L
.564 .18216 L
.568 .18492 L
.572 .18741 L
.576 .18942 L
.58 .19088 L
.584 .19186 L
.588 .1926 L
.592 .19341 L
.596 .19457 L
.6 .19628 L
Mistroke
.604 .19856 L
.608 .20135 L
.612 .20453 L
.616 .20797 L
.62 .21165 L
.624 .21563 L
.628 .22 L
.632 .22483 L
.636 .23013 L
.64 .23581 L
.644 .24169 L
.648 .24756 L
.652 .25324 L
.656 .25863 L
.66 .26376 L
.664 .26871 L
.668 .27367 L
.672 .27878 L
.676 .28416 L
.68 .28983 L
.684 .29573 L
.688 .30172 L
.692 .30763 L
.696 .31329 L
.7 .3186 L
.704 .32353 L
.708 .32813 L
.712 .33254 L
.716 .3369 L
.72 .34141 L
.724 .3462 L
.728 .35138 L
.732 .35699 L
.736 .36299 L
.74 .36932 L
.744 .37582 L
.748 .38235 L
.752 .38874 L
.756 .39486 L
.76 .40056 L
.764 .40576 L
.768 .4104 L
.772 .41445 L
.776 .41792 L
.78 .42082 L
.784 .42322 L
.788 .42516 L
.792 .42671 L
.796 .42792 L
.8 .42885 L
Mistroke
.804 .42956 L
.808 .4301 L
.812 .43049 L
.816 .43078 L
.82 .43099 L
.824 .43115 L
.828 .43126 L
.832 .43134 L
.836 .4314 L
.84 .43144 L
.844 .43148 L
.848 .4315 L
.852 .43152 L
.856 .43154 L
.86 .43156 L
.864 .43158 L
.868 .43159 L
.872 .4316 L
.876 .43162 L
.88 .43163 L
.884 .43164 L
.888 .43166 L
.892 .43167 L
.896 .43168 L
.9 .43169 L
.904 .43171 L
.908 .43172 L
.912 .43174 L
.916 .43175 L
.92 .43176 L
.924 .43177 L
.928 .43179 L
.932 .4318 L
.936 .43182 L
.94 .43182 L
.944 .43184 L
.948 .43185 L
.952 .43187 L
.956 .43187 L
.96 .4319 L
.964 .4319 L
.968 .43192 L
.972 .43192 L
.976 .43195 L
.98 .43195 L
.984 .43198 L
.988 .43197 L
.992 .432 L
.996 .432 L
1 .43203 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15958 L
.012 .16118 L
.016 .16173 L
.02 .16128 L
.024 .16104 L
.028 .1612 L
.032 .16124 L
.036 .16121 L
.04 .16116 L
.044 .16119 L
.048 .16119 L
.052 .16121 L
.056 .16122 L
.06 .16125 L
.064 .16125 L
.068 .16126 L
.072 .16123 L
.076 .16121 L
.08 .16116 L
.084 .16114 L
.088 .16113 L
.092 .16116 L
.096 .16119 L
.1 .16125 L
.104 .16129 L
.108 .16133 L
.112 .16131 L
.116 .16125 L
.12 .16118 L
.124 .16113 L
.128 .16108 L
.132 .16107 L
.136 .1611 L
.14 .16119 L
.144 .16128 L
.148 .16136 L
.152 .16138 L
.156 .16137 L
.16 .16132 L
.164 .16124 L
.168 .16112 L
.172 .16102 L
.176 .16098 L
.18 .16102 L
.184 .16111 L
.188 .16121 L
.192 .16131 L
.196 .16142 L
.2 .16148 L
Mistroke
.204 .16146 L
.208 .16136 L
.212 .16121 L
.216 .1611 L
.22 .16103 L
.224 .16099 L
.228 .16098 L
.232 .16099 L
.236 .16108 L
.24 .16121 L
.244 .16134 L
.248 .16142 L
.252 .16144 L
.256 .16144 L
.26 .16144 L
.264 .16143 L
.268 .16136 L
.272 .16121 L
.276 .16104 L
.28 .16093 L
.284 .16089 L
.288 .16091 L
.292 .16092 L
.296 .1609 L
.3 .16093 L
.304 .16109 L
.308 .16137 L
.312 .16168 L
.316 .16186 L
.32 .16187 L
.324 .16179 L
.328 .16172 L
.332 .16166 L
.336 .16151 L
.34 .16116 L
.344 .16065 L
.348 .16017 L
.352 .15995 L
.356 .16005 L
.36 .16033 L
.364 .16059 L
.368 .16077 L
.372 .16098 L
.376 .16138 L
.38 .16201 L
.384 .16266 L
.388 .16308 L
.392 .16309 L
.396 .16276 L
.4 .16234 L
Mistroke
.404 .16201 L
.408 .16181 L
.412 .16162 L
.416 .16127 L
.42 .16071 L
.424 .16002 L
.428 .15938 L
.432 .15892 L
.436 .15869 L
.44 .15865 L
.444 .15868 L
.448 .15869 L
.452 .15861 L
.456 .15845 L
.46 .15831 L
.464 .15838 L
.468 .15888 L
.472 .15991 L
.476 .16144 L
.48 .16322 L
.484 .16497 L
.488 .16648 L
.492 .16778 L
.496 .16911 L
.5 .17079 L
.504 .17305 L
.508 .17583 L
.512 .17884 L
.516 .18168 L
.52 .18404 L
.524 .18579 L
.528 .18709 L
.532 .18821 L
.536 .18944 L
.54 .19098 L
.544 .19291 L
.548 .19524 L
.552 .19794 L
.556 .20097 L
.56 .2043 L
.564 .20779 L
.568 .21121 L
.572 .2143 L
.576 .2168 L
.58 .21862 L
.584 .21983 L
.588 .22074 L
.592 .22173 L
.596 .22317 L
.6 .22528 L
Mistroke
.604 .22813 L
.608 .2316 L
.612 .23553 L
.616 .23981 L
.62 .24438 L
.624 .24933 L
.628 .25476 L
.632 .26077 L
.636 .26736 L
.64 .27441 L
.644 .28172 L
.648 .28901 L
.652 .29607 L
.656 .30277 L
.66 .30913 L
.664 .31527 L
.668 .32141 L
.672 .32776 L
.676 .33444 L
.68 .34148 L
.684 .3488 L
.688 .35623 L
.692 .36355 L
.696 .37057 L
.7 .37715 L
.704 .38326 L
.708 .38896 L
.712 .3944 L
.716 .3998 L
.72 .40538 L
.724 .41131 L
.728 .41772 L
.732 .42467 L
.736 .4321 L
.74 .43993 L
.744 .44799 L
.748 .45608 L
.752 .464 L
.756 .47156 L
.76 .47862 L
.764 .48504 L
.768 .49077 L
.772 .49576 L
.776 .50002 L
.78 .50358 L
.784 .50651 L
.788 .50886 L
.792 .51073 L
.796 .51218 L
.8 .51328 L
Mistroke
.804 .51411 L
.808 .51471 L
.812 .51514 L
.816 .51545 L
.82 .51565 L
.824 .51578 L
.828 .51586 L
.832 .5159 L
.836 .51591 L
.84 .51591 L
.844 .51589 L
.848 .51586 L
.852 .51583 L
.856 .51579 L
.86 .51575 L
.864 .51571 L
.868 .51567 L
.872 .51563 L
.876 .51558 L
.88 .51554 L
.884 .51549 L
.888 .51545 L
.892 .5154 L
.896 .51536 L
.9 .51532 L
.904 .51527 L
.908 .51523 L
.912 .51519 L
.916 .51514 L
.92 .5151 L
.924 .51505 L
.928 .51501 L
.932 .51496 L
.936 .51492 L
.94 .51487 L
.944 .51483 L
.948 .51478 L
.952 .51475 L
.956 .51469 L
.96 .51466 L
.964 .5146 L
.968 .51457 L
.972 .51451 L
.976 .51448 L
.98 .51442 L
.984 .5144 L
.988 .51433 L
.992 .51431 L
.996 .51424 L
1 .51422 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00AWoo0P009Goo0003Ool50002
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8004Ioo`03001oo`0002Aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0004Ool01@00Oomoogoo0000AWoo00@007ooOol002Aoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00@Goo0P000Woo00D007oo
Oomoo`0002=oo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00@7oo
00<007oo00000Woo00D007ooOomoo`0002=oo`002goo0P002Woo0P000goo0`000goo00<007ooOol0
?goo00D007oo001oo`0000Aoo`03001oogoo025oo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo0P00?7oo1@000Woo0P0017oo00<007ooOol08Goo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8000eoo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000Eoo`<000=o
o`<0009oo`04001oo`000003Ool500000goo001oo`020004Ool20004Ool50002Ool30004Ool20006
Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
2goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`05001oogooOol00003Ool01000Ool000000Woo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo00H007ooOol007oo0003Ool01000Oomoo`00
0Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo00Eoo`04001oo`000002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009o
o`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
1Goo00@007oo0000009oo`03001oogoo00=oo`04001oogooOol200001Goo001oogoo00000Woo00<0
07ooOol017oo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;Ool40003Ool01000Oomoo`001goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo100000Aoo`00Ool0009oo`04
001oogoo0003Ool00`00Oomoo`0200001Goo001oogoo00000Woo00D007ooOomoo`0000=oo`03001o
o`0000<000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`8000aoo`03
001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=o
o`03001oogoo009oo`03001oo`00009oo`04001oogoo0003Ool00`00Oomoo`0200001Goo001oogoo
00000Woo00D007ooOomoo`0000=oo`03001oo`0000Ioo`04001oogoo0005Ool0029oo`8000aoo`D0
00=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol60002Ool20004Ool30004
Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo03Uoo`03001oogoo00mo
o`03001oogoo01ioo`008Woo0P00>Woo00<007ooOol047oo0P007Woo000ROomS000<Ool0029oo`L0
0003Ool0000000@00005Ool00000001oo`0400000goo0000000400000goo000000030003Ool60002
Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000037oo000ROol2
00000goo00000002Ool2000017oo000007oo0`0000Aoo`000000009oo`@00003Ool007oo00@0009o
o`D00004Ool00000Ool40002Ool00`00Oomoo`030003Ool00`00Oomoo`0aOol0029oo`03001oogoo
025oo`03001oogoo00Qoo`04001oo`00Ool30002Ool01000Oomoo`00<goo000ROol2000^Ool20000
0goo00000003Ool00`00Ool0000dOol0029oo`8003Moo`8003Aoo`002goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo00<007ooOol0=Woo0P00=7oo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001o
ogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`00
27oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@0
07ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001o
ogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04
001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000R
Ool2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00
Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<0
07ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001o
ogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0
015oo`8000Yoo`8000Aoo`03001oogoo009oobh003]oo`00:7oo00<007ooOol0:Woo0`00>Goo000X
Ool00`00Oomoo`0/Ool4000fOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=o
o`03001oogoo02moo`<003Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00
Ool000=oo`04001oogoo000cOol3000bOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogoo000eOol3000`Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`80
00=oo`<000=oo`D0009oo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo
00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000=oo`05001oogooOol00003Ool40002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eo
o`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00=oo`03001oogoo00Eoo`04001oo`000002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04
001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool2
0004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`00
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo0P00
00Aoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`00
00<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006
Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`@00003Ool0
07oo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04
001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`80
00Aoo`04001oogooOol50003Ool30002Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006
Ool002Qoo`03001oogoo03]oo`03001oogoo02Qoo`00:7oo00<007ooOol0?7oo00<007ooOol09goo
000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo
00Ioo`03001oogoo00Ioo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0?Woo00<0
07ooOol09Goo000XOol00`00Oomoo`0oOol00`00Oomoo`0TOol002Qoo`03001oogoo041oo`03001o
ogoo02=oo`00:7oo00<007ooOol0@7oo00<007ooOol08goo000XOol00`00Oomoo`11Ool00`00Oomo
o`0ROol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo049oo`03
001oogoo025oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04
001oogoo0014Ool2000ROol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eo
o`04001oogoo0015Ool00`00Oomoo`0POol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo008004Eoo`03001oogoo01moo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0AGoo5@0037oo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004
Ool20002Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03
001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo
06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03
001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007
Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]o
o`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo
0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo
0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Io
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001o
ogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`80
00eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool0
1000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<
Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool2
0003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool0
1000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003
Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo
0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo
079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`00
00=oo`<00003Ool007oo009oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol0
2Woo000LOol00`00Oomoo`0bOol2000nOol001aoo`8003Aoo`<003aoo`0077oo00<007ooOol0=Goo
0`00>Woo000LOol00`00Oomoo`0gOol2000iOol001aoo`8003Uoo`<003Moo`0077oo00<007ooOol0
>Woo0`00=Goo000LOol00`00Oomoo`0lOol2000dOol001aoo`8003ioo`8003=oo`0077oo00<007oo
Ool0?Woo00<007ooOol0<Goo000LOol20010Ool00`00Oomoo`0`Ool000]oo`8000Aoo`03001oogoo
009oo`<000=oo`03001oogoo03moo`03001oogoo031oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`10Ool00`00Oomoo`0_Ool000Yoo`04001oogoo000;Ool00`00Oomoo`02
0012Ool00`00Oomoo`0^Ool000Yoo`04001oogoo000;Ool01000Oomoo`00@goo00<007ooOol0;Woo
000:Ool01000Oomoo`001goo10000goo00<007ooOol0@Goo0P00;goo000:Ool01000Oomoo`001goo
00<007ooOol017oo0P00@goo0P00;Woo000;Ool20008Ool50002Ool00`00Oomoo`13Ool00`00Oomo
o`0/Ool001aoo`03001oogoo04=oo`03001oogoo02aoo`0077oo0P00AGoo00<007ooOol0:goo000L
Ool00`00Oomoo`15Ool00`00Oomoo`0ZOol001aoo`8004Ioo`03001oogoo02Yoo`0077oo00<007oo
Ool0AWoo00<007ooOol0:Goo000LOol00`00Oomoo`16Ool2000ZOol001aoo`8004Qoo`03001oogoo
02Qoo`005Woo0`000goo00<007ooOol0B7oo00<007ooOol09goo000GOol00`00Oomoo`02Ool00`00
Oomoo`18Ool2000XOol001Moo`03001oogoo009oo`8004Yoo`03001oogoo02Ioo`005goo00<007oo
Ool00Woo00<007ooOol0BWoo00<007ooOol09Goo000GOol00`00Oomoo`02Ool00`00Oomoo`1:Ool0
0`00Oomoo`0UOol001Ioo`8000Aoo`8004aoo`03001oogoo02Aoo`005goo00<007ooOol00Woo00<0
07ooOol0Bgoo00<007ooOol097oo000LOol00`00Oomoo`1<Ool00`00Oomoo`0SOol001aoo`8004eo
o`8002Aoo`0077oo00<007ooOol0CGoo00<007ooOol08Woo000LOol2001?Ool2000ROol001aoo`03
001oogoo04mooaL000aoo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003
Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03
001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo
00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomo
o`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(16366\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32015 m
.008 .32058 L
.012 .32033 L
.016 .31987 L
.02 .31937 L
.024 .3182 L
.028 .31696 L
.032 .31672 L
.036 .31756 L
.04 .31918 L
.044 .32088 L
.048 .32188 L
.052 .32155 L
.056 .31992 L
.06 .31774 L
.064 .31586 L
.068 .31534 L
.072 .31662 L
.076 .31929 L
.08 .32213 L
.084 .32359 L
.088 .3231 L
.092 .32075 L
.096 .31749 L
.1 .31475 L
.104 .3138 L
.108 .31539 L
.112 .31878 L
.116 .32229 L
.12 .32432 L
.124 .3241 L
.128 .32205 L
.132 .31896 L
.136 .31601 L
.14 .31454 L
.144 .3152 L
.148 .3175 L
.152 .31988 L
.156 .32126 L
.16 .32166 L
.164 .32152 L
.168 .32115 L
.172 .3205 L
.176 .31975 L
.18 .31917 L
.184 .31866 L
.188 .31777 L
.192 .31642 L
.196 .31561 L
.2 .31649 L
Mistroke
.204 .31915 L
.208 .32227 L
.212 .32426 L
.216 .32441 L
.22 .32299 L
.224 .32061 L
.228 .31788 L
.232 .31552 L
.236 .31454 L
.24 .31551 L
.244 .31792 L
.248 .32037 L
.252 .32158 L
.256 .3214 L
.26 .32071 L
.264 .32053 L
.268 .32104 L
.272 .32156 L
.276 .32127 L
.28 .32012 L
.284 .31882 L
.288 .31819 L
.292 .3183 L
.296 .31845 L
.3 .31802 L
.304 .31729 L
.308 .31727 L
.312 .31852 L
.316 .32033 L
.32 .3213 L
.324 .32093 L
.328 .32036 L
.332 .32126 L
.336 .32385 L
.34 .32607 L
.344 .32538 L
.348 .3213 L
.352 .31629 L
.356 .31365 L
.36 .31451 L
.364 .31678 L
.368 .31734 L
.372 .31531 L
.376 .31307 L
.38 .31405 L
.384 .31926 L
.388 .32599 L
.392 .33005 L
.396 .3293 L
.4 .32537 L
Mistroke
.404 .32202 L
.408 .32176 L
.412 .3238 L
.416 .32509 L
.42 .32316 L
.424 .3183 L
.428 .31318 L
.432 .31063 L
.436 .31157 L
.44 .31469 L
.444 .31779 L
.448 .31937 L
.452 .31917 L
.456 .31777 L
.46 .31591 L
.464 .31435 L
.468 .31394 L
.472 .31556 L
.476 .31939 L
.48 .32425 L
.484 .32778 L
.488 .32785 L
.492 .32425 L
.496 .31944 L
.5 .31739 L
.504 .32109 L
.508 .3303 L
.512 .34125 L
.516 .34864 L
.52 .34874 L
.524 .34158 L
.528 .33099 L
.532 .32232 L
.536 .31949 L
.54 .32312 L
.544 .33059 L
.548 .33795 L
.552 .34209 L
.556 .34211 L
.56 .3391 L
.564 .33488 L
.568 .33073 L
.572 .3268 L
.576 .32258 L
.58 .31793 L
.584 .31382 L
.588 .31227 L
.592 .31544 L
.596 .3243 L
.6 .33773 L
Mistroke
.604 .35241 L
.608 .36398 L
.612 .36869 L
.616 .36492 L
.62 .35378 L
.624 .33849 L
.628 .32282 L
.632 .3095 L
.636 .29919 L
.64 .29056 L
.644 .2813 L
.648 .26948 L
.652 .25453 L
.656 .23755 L
.66 .2209 L
.664 .20726 L
.668 .19868 L
.672 .19585 L
.676 .19785 L
.68 .2024 L
.684 .20657 L
.688 .20778 L
.692 .20459 L
.696 .19718 L
.7 .18713 L
.704 .17689 L
.708 .16891 L
.712 .165 L
.716 .16588 L
.72 .17112 L
.724 .17934 L
.728 .18849 L
.732 .19634 L
.736 .20093 L
.74 .20102 L
.744 .19632 L
.748 .18748 L
.752 .17583 L
.756 .16306 L
.76 .15087 L
.764 .14083 L
.768 .13416 L
.772 .13166 L
.776 .1336 L
.78 .13975 L
.784 .14947 L
.788 .16191 L
.792 .17616 L
.796 .19136 L
.8 .20673 L
Mistroke
.804 .22158 L
.808 .23537 L
.812 .24775 L
.816 .25855 L
.82 .26778 L
.824 .27549 L
.828 .2818 L
.832 .28683 L
.836 .29076 L
.84 .29376 L
.844 .29605 L
.848 .29777 L
.852 .29905 L
.856 .29997 L
.86 .30061 L
.864 .30104 L
.868 .30135 L
.872 .30158 L
.876 .30174 L
.88 .30184 L
.884 .30189 L
.888 .30191 L
.892 .30194 L
.896 .30197 L
.9 .302 L
.904 .30199 L
.908 .30198 L
.912 .30197 L
.916 .30197 L
.92 .30199 L
.924 .302 L
.928 .30198 L
.932 .30196 L
.936 .30196 L
.94 .30197 L
.944 .30198 L
.948 .30198 L
.952 .30196 L
.956 .30194 L
.96 .30195 L
.964 .30197 L
.968 .30197 L
.972 .30196 L
.976 .30194 L
.98 .30193 L
.984 .30195 L
.988 .30196 L
.992 .30195 L
.996 .30193 L
1 .30192 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14751 m
.008 .14514 L
.012 .14428 L
.016 .14503 L
.02 .14529 L
.024 .14507 L
.028 .14495 L
.032 .14506 L
.036 .14509 L
.04 .1451 L
.044 .14508 L
.048 .1451 L
.052 .14508 L
.056 .14508 L
.06 .14505 L
.064 .14504 L
.068 .14503 L
.072 .14505 L
.076 .14505 L
.08 .14508 L
.084 .1451 L
.088 .14512 L
.092 .14512 L
.096 .14511 L
.1 .14507 L
.104 .14504 L
.108 .14501 L
.112 .14501 L
.116 .14501 L
.12 .14505 L
.124 .1451 L
.128 .14515 L
.132 .14516 L
.136 .14515 L
.14 .14512 L
.144 .14508 L
.148 .14502 L
.152 .14497 L
.156 .14495 L
.16 .14498 L
.164 .14504 L
.168 .1451 L
.172 .14515 L
.176 .1452 L
.18 .14522 L
.184 .1452 L
.188 .14512 L
.192 .14502 L
.196 .14494 L
.2 .14491 L
Mistroke
.204 .14491 L
.208 .14495 L
.212 .14501 L
.216 .14512 L
.22 .14523 L
.224 .14529 L
.228 .14528 L
.232 .14521 L
.236 .14512 L
.24 .14505 L
.244 .14498 L
.248 .14491 L
.252 .14486 L
.256 .14487 L
.26 .14494 L
.264 .14505 L
.268 .14514 L
.272 .14519 L
.276 .14522 L
.28 .14526 L
.284 .14529 L
.288 .14529 L
.292 .14523 L
.296 .1451 L
.3 .14498 L
.304 .14491 L
.308 .14489 L
.312 .14487 L
.316 .14481 L
.32 .14475 L
.324 .14476 L
.328 .14492 L
.332 .14516 L
.336 .14538 L
.34 .1455 L
.344 .14552 L
.348 .14552 L
.352 .14557 L
.356 .1456 L
.36 .14549 L
.364 .14516 L
.368 .14472 L
.372 .14434 L
.376 .14418 L
.38 .14423 L
.384 .14435 L
.388 .14443 L
.392 .14448 L
.396 .14464 L
.4 .14501 L
Mistroke
.404 .14556 L
.408 .14611 L
.412 .14646 L
.416 .1465 L
.42 .14633 L
.424 .14609 L
.428 .14591 L
.432 .1458 L
.436 .14565 L
.44 .14537 L
.444 .14493 L
.448 .14439 L
.452 .14387 L
.456 .14346 L
.46 .14322 L
.464 .14313 L
.468 .14313 L
.472 .14313 L
.476 .14305 L
.48 .14286 L
.484 .14264 L
.488 .14255 L
.492 .14279 L
.496 .14347 L
.5 .14458 L
.504 .14592 L
.508 .14725 L
.512 .1484 L
.516 .14936 L
.52 .15034 L
.524 .15159 L
.528 .1533 L
.532 .15545 L
.536 .15784 L
.54 .16016 L
.544 .16215 L
.548 .1637 L
.552 .16488 L
.556 .16586 L
.56 .16685 L
.564 .16799 L
.568 .16937 L
.572 .17103 L
.576 .17298 L
.58 .17526 L
.584 .17786 L
.588 .18067 L
.592 .18353 L
.596 .1862 L
.6 .18843 L
Mistroke
.604 .1901 L
.608 .19124 L
.612 .19205 L
.616 .19281 L
.62 .19381 L
.624 .19527 L
.628 .19726 L
.632 .19975 L
.636 .20262 L
.64 .20579 L
.644 .2092 L
.648 .21291 L
.652 .21701 L
.656 .22158 L
.66 .22665 L
.664 .23216 L
.668 .23794 L
.672 .24379 L
.676 .24952 L
.68 .255 L
.684 .2602 L
.688 .26519 L
.692 .27013 L
.696 .27516 L
.7 .28043 L
.704 .28599 L
.708 .29181 L
.712 .29779 L
.716 .30375 L
.72 .30953 L
.724 .31501 L
.728 .32011 L
.732 .32486 L
.736 .32934 L
.74 .33371 L
.744 .33812 L
.748 .34274 L
.752 .34769 L
.756 .35306 L
.76 .35884 L
.764 .36499 L
.768 .37139 L
.772 .37792 L
.776 .38441 L
.78 .3907 L
.784 .39667 L
.788 .4022 L
.792 .40721 L
.796 .41164 L
.8 .4155 L
Mistroke
.804 .41878 L
.808 .42153 L
.812 .42378 L
.816 .42561 L
.82 .42705 L
.824 .42819 L
.828 .42906 L
.832 .42973 L
.836 .43023 L
.84 .4306 L
.844 .43087 L
.848 .43107 L
.852 .43122 L
.856 .43132 L
.86 .4314 L
.864 .43146 L
.868 .4315 L
.872 .43153 L
.876 .43156 L
.88 .43158 L
.884 .4316 L
.888 .43161 L
.892 .43163 L
.896 .43164 L
.9 .43166 L
.904 .43167 L
.908 .43168 L
.912 .4317 L
.916 .43171 L
.92 .43173 L
.924 .43173 L
.928 .43175 L
.932 .43176 L
.936 .43178 L
.94 .43178 L
.944 .4318 L
.948 .43181 L
.952 .43183 L
.956 .43184 L
.96 .43186 L
.964 .43186 L
.968 .43188 L
.972 .43189 L
.976 .43191 L
.98 .43191 L
.984 .43194 L
.988 .43193 L
.992 .43197 L
.996 .43196 L
1 .43199 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16233 L
.012 .16117 L
.016 .16081 L
.02 .16128 L
.024 .16133 L
.028 .16117 L
.032 .16111 L
.036 .16121 L
.04 .16122 L
.044 .16124 L
.048 .16123 L
.052 .16125 L
.056 .16122 L
.06 .1612 L
.064 .16117 L
.068 .16116 L
.072 .16116 L
.076 .16119 L
.08 .16121 L
.084 .16125 L
.088 .16127 L
.092 .16128 L
.096 .16125 L
.1 .16121 L
.104 .16117 L
.108 .16115 L
.112 .16113 L
.116 .16114 L
.12 .16117 L
.124 .16124 L
.128 .16129 L
.132 .16132 L
.136 .16131 L
.14 .16128 L
.144 .16123 L
.148 .16115 L
.152 .16108 L
.156 .16105 L
.16 .16108 L
.164 .16116 L
.168 .16125 L
.172 .16133 L
.176 .16138 L
.18 .16141 L
.184 .16136 L
.188 .16126 L
.192 .16113 L
.196 .16104 L
.2 .16101 L
Mistroke
.204 .16103 L
.208 .16107 L
.212 .16115 L
.216 .16126 L
.22 .16139 L
.224 .16147 L
.228 .16146 L
.232 .16138 L
.236 .16128 L
.24 .16119 L
.244 .1611 L
.248 .161 L
.252 .16093 L
.256 .16094 L
.26 .16104 L
.264 .16118 L
.268 .1613 L
.272 .16137 L
.276 .1614 L
.28 .16143 L
.284 .16147 L
.288 .16148 L
.292 .1614 L
.296 .16125 L
.3 .1611 L
.304 .161 L
.308 .16097 L
.312 .16094 L
.316 .16087 L
.32 .1608 L
.324 .16083 L
.328 .16102 L
.332 .16132 L
.336 .16159 L
.34 .16173 L
.344 .16175 L
.348 .16176 L
.352 .16183 L
.356 .16187 L
.36 .16172 L
.364 .16132 L
.368 .16076 L
.372 .16029 L
.376 .16009 L
.38 .16015 L
.384 .1603 L
.388 .1604 L
.392 .16046 L
.396 .16066 L
.4 .16112 L
Mistroke
.404 .1618 L
.408 .16249 L
.412 .16292 L
.416 .16298 L
.42 .16276 L
.424 .16247 L
.428 .16225 L
.432 .1621 L
.436 .16192 L
.44 .16156 L
.444 .16101 L
.448 .16034 L
.452 .1597 L
.456 .15919 L
.46 .15889 L
.464 .15878 L
.468 .15877 L
.472 .15877 L
.476 .15867 L
.48 .15844 L
.484 .15816 L
.488 .15805 L
.492 .15834 L
.496 .1592 L
.5 .16058 L
.504 .16226 L
.508 .16392 L
.512 .16533 L
.516 .16653 L
.52 .16774 L
.524 .1693 L
.528 .17143 L
.532 .17412 L
.536 .17709 L
.54 .17998 L
.544 .18245 L
.548 .18438 L
.552 .18584 L
.556 .18707 L
.56 .1883 L
.564 .18971 L
.568 .19142 L
.572 .19348 L
.576 .19591 L
.58 .19875 L
.584 .20198 L
.588 .20548 L
.592 .20903 L
.596 .21233 L
.6 .2151 L
Mistroke
.604 .21718 L
.608 .2186 L
.612 .21959 L
.616 .22052 L
.62 .22176 L
.624 .22357 L
.628 .22605 L
.632 .22914 L
.636 .23271 L
.64 .23663 L
.644 .24087 L
.648 .24548 L
.652 .25057 L
.656 .25626 L
.66 .26257 L
.664 .26941 L
.668 .27659 L
.672 .28386 L
.676 .29098 L
.68 .29778 L
.684 .30424 L
.688 .31044 L
.692 .31656 L
.696 .32281 L
.7 .32935 L
.704 .33625 L
.708 .34347 L
.712 .35088 L
.716 .35827 L
.72 .36544 L
.724 .37223 L
.728 .37856 L
.732 .38444 L
.736 .38999 L
.74 .39538 L
.744 .40084 L
.748 .40655 L
.752 .41269 L
.756 .41933 L
.76 .42649 L
.764 .43411 L
.768 .44204 L
.772 .45013 L
.776 .45816 L
.78 .46596 L
.784 .47334 L
.788 .48017 L
.792 .48636 L
.796 .49183 L
.8 .49658 L
Mistroke
.804 .50061 L
.808 .50397 L
.812 .50672 L
.816 .50893 L
.82 .51068 L
.824 .51203 L
.828 .51306 L
.832 .51383 L
.836 .51439 L
.84 .5148 L
.844 .51508 L
.848 .51527 L
.852 .51538 L
.856 .51546 L
.86 .51549 L
.864 .5155 L
.868 .51549 L
.872 .51547 L
.876 .51544 L
.88 .51541 L
.884 .51537 L
.888 .51534 L
.892 .51529 L
.896 .51525 L
.9 .5152 L
.904 .51516 L
.908 .51512 L
.912 .51508 L
.916 .51503 L
.92 .51499 L
.924 .51494 L
.928 .5149 L
.932 .51485 L
.936 .51481 L
.94 .51476 L
.944 .51473 L
.948 .51467 L
.952 .51464 L
.956 .51458 L
.96 .51455 L
.964 .51449 L
.968 .51446 L
.972 .5144 L
.976 .51438 L
.98 .51431 L
.984 .51429 L
.988 .51422 L
.992 .5142 L
.996 .51413 L
1 .51412 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo04Qoo`80029o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00BGoo0P008Woo0003
Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8004Qoo`04001oogoo
000QOol000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00D007ooOomoo`0004Eoo`05001oogoo
Ool00002Ool00`00Oomoo`0OOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001o
ogoo008004=oo`8000=oo`04001oogoo000QOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0
00=oo`03001oogoo008004=oo`05001oo`00Ool00003Ool00`00Oomoo`0OOol000]oo`8000Yoo`80
00=oo`<000=oo`03001oogoo03moo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo01ioo`00
2goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00?goo0P0000Aoo`00Oomoo`<000Aoo`03
001oogoo01ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000=Ool3
0004Ool20007Ool30004Ool20004Ool20005Ool30003Ool30004Ool200000goo001oo`050003Ool2
0004Ool20004Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol02goo00D007ooOomoo`00009oo`04001oogoo0007Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool00`00Oomo
o`0200000goo001oo`02Ool01000Oomoo`000Woo00@007oo0000009oo`04001oogoo0004Ool01P00
Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00<007ooOol00P0000=oo`00
Ool00goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo00Eoo`03001oogoo00800003Ool007oo00Aoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol017oo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;Ool40003
Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomo
ogoo10000goo0P0000Eoo`00Oomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00D007oo
Oomoo`0000=oo`03001oo`0000<000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03001o
ogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`8000=oo`03001oogoo00Aoo`800005Ool007ooOol00003Ool01000Oomoo`000Woo
0P0000Eoo`00Oomoo`0000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`008Woo0P00
37oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D0009oo`<000Ao
o`<000Aoo`800004Ool007ooOol20005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo03ao
o`03001oogoo00moo`03001oogoo01]oo`008Woo0P00?7oo00<007ooOol04Goo0P006goo000ROomS
000<Ool0029oo`03001oo`0000800005Ool00000001oo`0700001Goo00000000Ool00`000Woo1@00
0Woo1P0000=oo`0000001@0000Aoo`00Ool000=oo`03001oo`000080009oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
000037oo000ROol300001Goo00000000Ool00P0000Eoo`00000007oo00<0009oo`<00003Ool00000
008000=oo`@000=oo`@0009oo`03001oogoo00<0009oo`80009oo`03001oo`00009oo`03001oogoo
02moo`008Woo00<007ooOol08goo00<007ooOol02Goo00<007oo00000`000goo00<007oo0000<Goo
000ROol2000`Ool20002Ool00`00Oomoo`02Ool00`00Ool0000aOol0029oo`8003Uoo`03001oo`00
035oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0>7oo0P00<Woo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]
Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007oo
Ool00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol0
00Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00
KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000
Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo0080
06eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P00
2Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo
000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0
009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009ooc0003Uoo`00
:7oo00<007ooOol0;Goo0P00=goo000XOol00`00Oomoo`0_Ool3000dOol000]oo`8000Aoo`03001o
ogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo039oo`80039oo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000eOol3000`Ool000=oo`D0009o
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000hOol2000^Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<0
00Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000=oo`<0009oo`D000=oo`8000Aoo`80
00=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomo
o`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`020000
1Goo001oogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<0
07oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo00@0
00=oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0goo00<007ooOol01Goo00D007ooOol007oo008000Aoo`05001oogooOol00002Ool01000Oomoo`00
0Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<0
07ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol0
2Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo
0P000goo00<007ooOol017oo00<007ooOol00`000goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo
0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`800003Ool0000000<0
00Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0?Goo00<007ooOol0
9Woo000XOol00`00Oomoo`0nOol00`00Oomoo`0UOol002Qooed000aoo`00:7oo00<007ooOol03goo
00<007ooOol047oo00<007ooOol03goo00<007ooOol027oo0P001Goo00<007ooOol047oo00<007oo
Ool02Woo000XOol00`00Oomoo`10Ool2000TOol002Qoo`03001oogoo045oo`8002=oo`00:7oo00<0
07ooOol0@Woo00<007ooOol08Goo000XOol00`00Oomoo`13Ool00`00Oomoo`0POol002Qoo`03001o
ogoo04=oo`80025oo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007oo
Ool0A7oo00<007ooOol07goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`000goo00@007ooOol004Ioo`80021oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`001Goo00@007ooOol004Moo`8001moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol00P00Agoo0P007Woo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`05001oogoo001oo`040003Ool00`00Oomoo`17OolC000<Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80
009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007oo
Ool0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001o
ogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo
000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007oo
Ool00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@0
00=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P00
27oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004
Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006
Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=o
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@0
07ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo
00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0
009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo
10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03
001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=o
o`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`80
00Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004
Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00<007ooOol00`000Woo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool0
01aoo`03001oogoo03Aoo`8003aoo`0077oo0P00=goo0`00>Goo000LOol00`00Oomoo`0hOol3000g
Ool001aoo`03001oogoo03Yoo`03001oogoo03Eoo`0077oo0P00?7oo0`00=7oo000LOol00`00Oomo
o`0mOol3000bOol001aoo`03001oogoo03moo`03001oogoo031oo`0077oo0P00@Goo00<007ooOol0
;goo000LOol00`00Oomoo`11Ool00`00Oomoo`0^Ool001aoo`80049oo`8002moo`002goo0P0017oo
00<007ooOol00Woo0`000goo00<007ooOol0@Woo00<007ooOol0;Goo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo04=oo`03001oogoo02aoo`002Woo00@007ooOol000]oo`03
001oogoo008004Aoo`03001oogoo02aoo`002Woo00@007ooOol000]oo`04001oogoo0016Ool00`00
Oomoo`0[Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`14Ool2000/Ool000Yoo`04001o
ogoo0007Ool00`00Oomoo`04Ool20016Ool00`00Oomoo`0ZOol000]oo`8000Qoo`D0009oo`03001o
ogoo04Ioo`03001oogoo02Uoo`0077oo00<007ooOol0AWoo00<007ooOol0:Goo000LOol20018Ool0
0`00Oomoo`0XOol001aoo`03001oogoo04Moo`8002Uoo`0077oo0P00BGoo00<007ooOol09goo000L
Ool00`00Oomoo`18Ool2000XOol001aoo`03001oogoo04Uoo`8002Moo`0077oo0P00Bgoo00<007oo
Ool09Goo000FOol30003Ool00`00Oomoo`1;Ool00`00Oomoo`0TOol001Moo`03001oogoo009oo`03
001oogoo04]oo`03001oogoo02Aoo`005goo00<007ooOol00Woo0P00CGoo00<007ooOol08goo000G
Ool00`00Oomoo`02Ool00`00Oomoo`1=Ool00`00Oomoo`0ROol001Moo`03001oogoo009oo`03001o
ogoo04eoo`03001oogoo029oo`005Woo0P0017oo0P00CWoo00<007ooOol08Woo000GOol00`00Oomo
o`02Ool00`00Oomoo`1>Ool00`00Oomoo`0QOol001aoo`03001oogoo04ioo`80029oo`0077oo0P00
D7oo00<007ooOol087oo000LOol00`00Oomoo`1@Ool00`00Oomoo`0OOol001aoo`80059oo`8001mo
o`0077oo00<007ooOol0DWoo500037oo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo
009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079o
o`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00
Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Ao
o`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(16533\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31673 m
.008 .31614 L
.012 .317 L
.016 .3191 L
.02 .32129 L
.024 .32245 L
.028 .32188 L
.032 .32003 L
.036 .3178 L
.04 .31592 L
.044 .31535 L
.048 .31635 L
.052 .31854 L
.056 .321 L
.06 .32258 L
.064 .32256 L
.068 .32087 L
.072 .3184 L
.076 .31633 L
.08 .31555 L
.084 .31635 L
.088 .31825 L
.092 .32045 L
.096 .32186 L
.1 .32183 L
.104 .32056 L
.108 .31888 L
.112 .31781 L
.116 .31763 L
.12 .31811 L
.124 .31886 L
.128 .31944 L
.132 .3195 L
.136 .31889 L
.14 .31828 L
.144 .3186 L
.148 .31992 L
.152 .32144 L
.156 .32201 L
.16 .32124 L
.164 .31944 L
.168 .31717 L
.172 .31528 L
.176 .31474 L
.18 .31635 L
.184 .31976 L
.188 .32324 L
.192 .32494 L
.196 .32413 L
.2 .32164 L
Mistroke
.204 .31871 L
.208 .31623 L
.212 .31479 L
.216 .31488 L
.22 .31661 L
.224 .31922 L
.228 .32141 L
.232 .32228 L
.236 .32208 L
.24 .32169 L
.244 .32152 L
.248 .32116 L
.252 .32002 L
.256 .31819 L
.26 .31655 L
.264 .31596 L
.268 .31659 L
.272 .31793 L
.276 .31934 L
.28 .32054 L
.284 .32156 L
.288 .32234 L
.292 .32249 L
.296 .32165 L
.3 .32008 L
.304 .31871 L
.308 .31849 L
.312 .31939 L
.316 .32025 L
.32 .31977 L
.324 .31794 L
.328 .31627 L
.332 .31638 L
.336 .31833 L
.34 .32043 L
.344 .32093 L
.348 .31997 L
.352 .31951 L
.356 .32122 L
.36 .32442 L
.364 .32642 L
.368 .32504 L
.372 .32091 L
.376 .31705 L
.38 .31599 L
.384 .31735 L
.388 .31832 L
.392 .31664 L
.396 .31311 L
.4 .31114 L
Mistroke
.404 .31352 L
.408 .3197 L
.412 .32598 L
.416 .32862 L
.42 .32688 L
.424 .32344 L
.428 .32181 L
.432 .32325 L
.436 .32594 L
.44 .32672 L
.444 .32394 L
.448 .31868 L
.452 .3138 L
.456 .31163 L
.46 .31255 L
.464 .31519 L
.468 .31777 L
.472 .31921 L
.476 .3193 L
.48 .31825 L
.484 .31638 L
.488 .31433 L
.492 .31325 L
.496 .31448 L
.5 .31845 L
.504 .32382 L
.508 .32782 L
.512 .32788 L
.516 .32363 L
.52 .31773 L
.524 .31455 L
.528 .31753 L
.532 .32671 L
.536 .33835 L
.54 .34687 L
.544 .3481 L
.548 .34168 L
.552 .33121 L
.556 .32203 L
.56 .3183 L
.564 .32095 L
.568 .32768 L
.572 .33475 L
.576 .3392 L
.58 .34014 L
.584 .33848 L
.588 .33573 L
.592 .33268 L
.596 .32905 L
.6 .32413 L
Mistroke
.604 .31784 L
.608 .31152 L
.612 .30766 L
.616 .3089 L
.62 .31659 L
.624 .32984 L
.628 .3455 L
.632 .35916 L
.636 .36679 L
.64 .3662 L
.644 .35783 L
.648 .34437 L
.652 .32946 L
.656 .31607 L
.66 .30538 L
.664 .29651 L
.668 .28734 L
.672 .27574 L
.676 .26077 L
.68 .24317 L
.684 .22513 L
.688 .20942 L
.692 .19844 L
.696 .19334 L
.7 .19366 L
.704 .19748 L
.708 .20199 L
.712 .2044 L
.716 .20279 L
.72 .1967 L
.724 .18722 L
.728 .17651 L
.732 .1671 L
.736 .16115 L
.74 .15989 L
.744 .1634 L
.748 .17068 L
.752 .17991 L
.756 .18888 L
.76 .19543 L
.764 .19795 L
.768 .19567 L
.772 .18879 L
.776 .17828 L
.78 .16567 L
.784 .15267 L
.788 .14099 L
.792 .13206 L
.796 .12696 L
.8 .12625 L
Mistroke
.804 .12997 L
.808 .13771 L
.812 .14874 L
.816 .16222 L
.82 .17724 L
.824 .19294 L
.828 .20855 L
.832 .22342 L
.836 .23709 L
.84 .24928 L
.844 .25989 L
.848 .26891 L
.852 .27641 L
.856 .28251 L
.86 .28736 L
.864 .29114 L
.868 .29405 L
.872 .29627 L
.876 .29795 L
.88 .29916 L
.884 .30003 L
.888 .30064 L
.892 .30108 L
.896 .3014 L
.9 .30162 L
.904 .30176 L
.908 .30184 L
.912 .30189 L
.916 .30193 L
.92 .30198 L
.924 .302 L
.928 .302 L
.932 .30199 L
.936 .30199 L
.94 .302 L
.944 .30201 L
.948 .30201 L
.952 .30199 L
.956 .30198 L
.96 .30199 L
.964 .302 L
.968 .302 L
.972 .30199 L
.976 .30197 L
.98 .30197 L
.984 .30198 L
.988 .302 L
.992 .30198 L
.996 .30196 L
1 .30196 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14415 m
.008 .14551 L
.012 .14589 L
.016 .14539 L
.02 .14525 L
.024 .14548 L
.028 .1455 L
.032 .14545 L
.036 .14542 L
.04 .14546 L
.044 .14544 L
.048 .14543 L
.052 .14541 L
.056 .14542 L
.06 .14542 L
.064 .14545 L
.068 .14546 L
.072 .14548 L
.076 .14547 L
.08 .14546 L
.084 .14543 L
.088 .14541 L
.092 .1454 L
.096 .14541 L
.1 .14541 L
.104 .14544 L
.108 .14547 L
.112 .14549 L
.116 .14548 L
.12 .14547 L
.124 .14545 L
.128 .14543 L
.132 .1454 L
.136 .14537 L
.14 .14537 L
.144 .14541 L
.148 .14544 L
.152 .14548 L
.156 .14551 L
.16 .14553 L
.164 .14553 L
.168 .14548 L
.172 .14541 L
.176 .14534 L
.18 .14532 L
.184 .14533 L
.188 .14537 L
.192 .14543 L
.196 .14551 L
.2 .14558 L
Mistroke
.204 .14561 L
.208 .14558 L
.212 .14549 L
.216 .14541 L
.22 .14535 L
.224 .1453 L
.228 .14527 L
.232 .14529 L
.236 .14535 L
.24 .14546 L
.244 .14556 L
.248 .14562 L
.252 .14563 L
.256 .1456 L
.26 .14555 L
.264 .14548 L
.268 .14539 L
.272 .14528 L
.276 .14522 L
.28 .14523 L
.284 .1453 L
.288 .14539 L
.292 .14546 L
.296 .1455 L
.3 .14555 L
.304 .14562 L
.308 .14568 L
.312 .14569 L
.316 .14561 L
.32 .1455 L
.324 .1454 L
.328 .14536 L
.332 .14533 L
.336 .14526 L
.34 .14515 L
.344 .14506 L
.348 .14509 L
.352 .14526 L
.356 .14548 L
.36 .14565 L
.364 .14573 L
.368 .14578 L
.372 .14588 L
.376 .14603 L
.38 .14611 L
.384 .14598 L
.388 .14564 L
.392 .1452 L
.396 .14486 L
.4 .14471 L
Mistroke
.404 .1447 L
.408 .14471 L
.412 .14467 L
.416 .14465 L
.42 .14479 L
.424 .14518 L
.428 .14575 L
.432 .1463 L
.436 .14666 L
.44 .14676 L
.444 .14667 L
.448 .14653 L
.452 .14643 L
.456 .14636 L
.46 .14623 L
.464 .14597 L
.468 .14555 L
.472 .14503 L
.476 .14451 L
.48 .14406 L
.484 .14376 L
.488 .14363 L
.492 .14361 L
.496 .14361 L
.5 .14352 L
.504 .14328 L
.508 .14296 L
.512 .14273 L
.516 .14282 L
.52 .14337 L
.524 .14436 L
.528 .1456 L
.532 .14684 L
.536 .14791 L
.54 .1488 L
.544 .14968 L
.548 .15083 L
.552 .15242 L
.556 .15447 L
.56 .1568 L
.564 .15913 L
.568 .1612 L
.572 .16289 L
.576 .16422 L
.58 .16531 L
.584 .16633 L
.588 .16741 L
.592 .16864 L
.596 .17009 L
.6 .17184 L
Mistroke
.604 .17393 L
.608 .1764 L
.612 .17917 L
.616 .18209 L
.62 .18489 L
.624 .18733 L
.628 .18922 L
.632 .19056 L
.636 .19148 L
.64 .19224 L
.644 .19314 L
.648 .19441 L
.652 .19614 L
.656 .19834 L
.66 .20093 L
.664 .20381 L
.668 .20696 L
.672 .21039 L
.676 .21421 L
.68 .2185 L
.684 .22331 L
.688 .2286 L
.692 .23425 L
.696 .24005 L
.7 .2458 L
.704 .25135 L
.708 .25663 L
.712 .26167 L
.716 .26661 L
.72 .27159 L
.724 .27676 L
.728 .2822 L
.732 .28792 L
.736 .29384 L
.74 .29983 L
.744 .30571 L
.748 .31134 L
.752 .31662 L
.756 .32153 L
.76 .32613 L
.764 .33053 L
.768 .33489 L
.772 .33938 L
.776 .34414 L
.78 .34927 L
.784 .35481 L
.788 .36076 L
.792 .36702 L
.796 .37348 L
.8 .38 L
Mistroke
.804 .38643 L
.808 .39261 L
.812 .39842 L
.816 .40377 L
.82 .40858 L
.824 .41282 L
.828 .41649 L
.832 .4196 L
.836 .42219 L
.84 .42431 L
.844 .42602 L
.848 .42738 L
.852 .42844 L
.856 .42927 L
.86 .42989 L
.864 .43036 L
.868 .4307 L
.872 .43096 L
.876 .43115 L
.88 .43129 L
.884 .43139 L
.888 .43146 L
.892 .43151 L
.896 .43156 L
.9 .43158 L
.904 .43161 L
.908 .43163 L
.912 .43165 L
.916 .43166 L
.92 .43168 L
.924 .43169 L
.928 .43171 L
.932 .43172 L
.936 .43174 L
.94 .43175 L
.944 .43177 L
.948 .43177 L
.952 .43179 L
.956 .4318 L
.96 .43182 L
.964 .43182 L
.968 .43185 L
.972 .43185 L
.976 .43187 L
.98 .43187 L
.984 .4319 L
.988 .4319 L
.992 .43193 L
.996 .43192 L
1 .43196 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16299 L
.012 .16124 L
.016 .16057 L
.02 .16118 L
.024 .1614 L
.028 .16126 L
.032 .16116 L
.036 .16123 L
.04 .16123 L
.044 .16121 L
.048 .16117 L
.052 .16118 L
.056 .16118 L
.06 .16121 L
.064 .16121 L
.068 .16124 L
.072 .16124 L
.076 .16125 L
.08 .16122 L
.084 .16121 L
.088 .16118 L
.092 .16117 L
.096 .16116 L
.1 .16117 L
.104 .1612 L
.108 .16124 L
.112 .16127 L
.116 .16128 L
.12 .16126 L
.124 .16123 L
.128 .16119 L
.132 .16114 L
.136 .16111 L
.14 .16112 L
.144 .16117 L
.148 .16123 L
.152 .16128 L
.156 .16131 L
.16 .16132 L
.164 .1613 L
.168 .16124 L
.172 .16115 L
.176 .16109 L
.18 .16107 L
.184 .16109 L
.188 .16113 L
.192 .16119 L
.196 .16128 L
.2 .16137 L
Mistroke
.204 .16141 L
.208 .16138 L
.212 .16129 L
.216 .16119 L
.22 .1611 L
.224 .16103 L
.228 .16098 L
.232 .161 L
.236 .16109 L
.24 .16124 L
.244 .16138 L
.248 .16145 L
.252 .16144 L
.256 .1614 L
.26 .16134 L
.264 .16125 L
.268 .16114 L
.272 .16102 L
.276 .16094 L
.28 .16094 L
.284 .16103 L
.288 .16113 L
.292 .16122 L
.296 .16128 L
.3 .16135 L
.304 .16144 L
.308 .16151 L
.312 .16151 L
.316 .16141 L
.32 .16127 L
.324 .16115 L
.328 .1611 L
.332 .16107 L
.336 .16098 L
.34 .16084 L
.344 .16072 L
.348 .16076 L
.352 .16097 L
.356 .16125 L
.36 .16147 L
.364 .16156 L
.368 .16162 L
.372 .16175 L
.376 .16193 L
.38 .16203 L
.384 .16187 L
.388 .16144 L
.392 .16089 L
.396 .16047 L
.4 .16029 L
Mistroke
.404 .16028 L
.408 .16029 L
.412 .16023 L
.416 .1602 L
.42 .16038 L
.424 .16087 L
.428 .16158 L
.432 .16227 L
.436 .16271 L
.44 .16283 L
.444 .16272 L
.448 .16255 L
.452 .16243 L
.456 .16234 L
.46 .16218 L
.464 .16184 L
.468 .16132 L
.472 .16068 L
.476 .16002 L
.48 .15947 L
.484 .1591 L
.488 .15894 L
.492 .15891 L
.496 .15891 L
.5 .15879 L
.504 .15849 L
.508 .1581 L
.512 .15781 L
.516 .15792 L
.52 .1586 L
.524 .15983 L
.528 .16138 L
.532 .16294 L
.536 .16427 L
.54 .16537 L
.544 .16647 L
.548 .16789 L
.552 .16988 L
.556 .17243 L
.56 .17534 L
.564 .17823 L
.568 .18081 L
.572 .18291 L
.576 .18455 L
.58 .18591 L
.584 .18718 L
.588 .18852 L
.592 .19005 L
.596 .19185 L
.6 .19402 L
Mistroke
.604 .19662 L
.608 .19969 L
.612 .20315 L
.616 .20677 L
.62 .21025 L
.624 .21327 L
.628 .21562 L
.632 .21728 L
.636 .21842 L
.64 .21936 L
.644 .22047 L
.648 .22203 L
.652 .22419 L
.656 .22692 L
.66 .23014 L
.664 .23372 L
.668 .23762 L
.672 .24188 L
.676 .24662 L
.68 .25196 L
.684 .25794 L
.688 .26453 L
.692 .27154 L
.696 .27874 L
.7 .28589 L
.704 .29278 L
.708 .29934 L
.712 .3056 L
.716 .31173 L
.72 .3179 L
.724 .32432 L
.728 .33107 L
.732 .33817 L
.736 .34552 L
.74 .35295 L
.744 .36024 L
.748 .36722 L
.752 .37377 L
.756 .37985 L
.76 .38554 L
.764 .39098 L
.768 .39638 L
.772 .40193 L
.776 .40782 L
.78 .41417 L
.784 .42104 L
.788 .4284 L
.792 .43616 L
.796 .44416 L
.8 .45224 L
Mistroke
.804 .4602 L
.808 .46785 L
.812 .47504 L
.816 .48165 L
.82 .48758 L
.824 .49281 L
.828 .49732 L
.832 .50114 L
.836 .50431 L
.84 .5069 L
.844 .50897 L
.848 .51061 L
.852 .51187 L
.856 .51283 L
.86 .51354 L
.864 .51407 L
.868 .51444 L
.872 .5147 L
.876 .51487 L
.88 .51499 L
.884 .51505 L
.888 .51508 L
.892 .51509 L
.896 .51508 L
.9 .51505 L
.904 .51503 L
.908 .51499 L
.912 .51496 L
.916 .51491 L
.92 .51488 L
.924 .51483 L
.928 .51479 L
.932 .51474 L
.936 .5147 L
.94 .51465 L
.944 .51462 L
.948 .51456 L
.952 .51453 L
.956 .51447 L
.96 .51444 L
.964 .51438 L
.968 .51435 L
.972 .5143 L
.976 .51427 L
.98 .51421 L
.984 .51418 L
.988 .51411 L
.992 .51409 L
.996 .51402 L
1 .51401 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo04Yoo`80021o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00Bgoo00<007oo0000
7goo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8004]oo`03
001oo`0001moo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01@00Oomoogoo0000Agoo0P00
0goo00@007ooOol001ioo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol0
0P00AGoo00<007oo00000Woo00D007ooOomoo`0001ioo`002Woo00@007ooOol000Qoo`06001oogoo
001oo`000goo00<007ooOol00P00AGoo00<007oo00000Woo00D007ooOomoo`0001ioo`002goo0P00
2Woo0P000goo0`000goo00<007ooOol0@Goo00@007ooOol0009oo`8000Aoo`03001oogoo01aoo`00
2goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00@Woo0`0017oo00<007ooOol00Woo00<0
07ooOol077oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000eoo`<0
00Aoo`8000Moo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`800003Ool007oo00D000=oo`80
009oo`04001oo`000004Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol02goo00D007ooOomoo`00009oo`04001oogoo
0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool0
1000Oomoo`000Woo0P000Woo00@007ooOol0009oo`05001oogoo001oo`020002Ool00`00Oomoo`02
Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009o
o`8000=oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00]oo`@0
00=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001o
ogooOol40003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomo
o`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool00`00
Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04
001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000R
Ool2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo
0`000goo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`0nOol0
0`00Oomoo`0@Ool00`00Oomoo`0HOol0029oo`8003moo`03001oogoo011oo`8001Uoo`008WooH`00
37oo000ROol3000017oo000007oo0`0000=oo`0000000P0000Eoo`00000007oo00<00003Ool00000
0080009oo`@00003Ool007oo00@0009oo`L00003Ool00000009oo`06001oogooOol007oo0P0000Ao
o`00Ool000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol0000<Ool0029oo`@0009oo`800003Ool00000009oo`05001oo`00001oo`0300000goo
0000000200001goo00000000Ool007oo00@000=oo`@000Eoo`800003Ool007oo0080009oo`800005
Ool007ooOol0000^Ool0029oo`03001oogoo035oo`04001oo`00Ool30002Ool01000Oomoo`00;Woo
000ROol2000cOol20002Ool01`00Oomoogoo001oo`0002moo`008Woo0P00?7oo0P00;goo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0kOol00`00Oomoo`0^Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`00
2goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03
Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0
029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool2
0003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029o
o`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04
001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P00
0goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo<P00=goo000XOol0
0`00Oomoo`0_Ool3000dOol002Qoo`03001oogoo035oo`@0035oo`002goo0P0017oo00<007ooOol0
0goo0P0017oo0P000goo0`000goo00<007ooOol0=7oo0P00<7oo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`06001oogoo001oo`000goo00@007ooOol003Qoo`<002eoo`000goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol003Yoo`<002]oo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo
0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0`0000=oo`0000000`000goo0P0017oo
0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001o
ogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002
Ool200001Goo001oogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01P00Oomoo`00Ool0
00=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo0P00
0Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool0
1000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo00000Woo00D007ooOomoo`00009oo`04001o
ogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000X
Ool00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0003Ool01000Oomoogoo10000goo00D007ooOol007oo0080009oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03
001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007oo
Ool0009oo`8000=oo`03001oogoo00Aoo`05001oogoo001oo`0300001Goo001oogoo00000Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomo
o`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P00
0goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`10Ool00`00
Oomoo`0SOol002Qoo`03001oogoo041oo`8002Aoo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool0
0`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool01@00Oomoogoo00004Woo00<007ooOol0
2Woo000XOol00`00Oomoo`13Ool00`00Oomoo`0POol002Qoo`03001oogoo04Aoo`03001oogoo01mo
o`00:7oo00<007ooOol0A7oo0P0087oo000XOol00`00Oomoo`15Ool2000OOol002Qoo`03001oogoo
04Ioo`03001oogoo01eoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<0
07ooOol0AWoo0P007Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`00
0goo00@007ooOol004Uoo`03001oogoo01aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`001Goo00@007ooOol004Yoo`03001oogoo01]oo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00BGoo0`006goo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1:Ool@000<Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yo
o`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P00
17oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<0
07ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`00
2goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007oo
Ool000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=o
o`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool3
0004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool3
0004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03
001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001o
o`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009o
o`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00
77oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001o
ogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol0
00Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eo
o`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool3
0004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000goo00H007ooOomoo`00Ool30003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<0
07ooOol02Woo000LOol00`00Oomoo`0gOol2000iOol001aoo`8003Uoo`@003Ioo`0077oo00<007oo
Ool0>goo0P00=Goo000LOol00`00Oomoo`0lOol2000dOol001aoo`8003moo`<0035oo`0077oo00<0
07ooOol0@7oo0P00<7oo000LOol00`00Oomoo`12Ool00`00Oomoo`0]Ool001aoo`8004Aoo`03001o
ogoo02aoo`0077oo00<007ooOol0@goo0P00;Goo000LOol20015Ool00`00Oomoo`0[Ool000]oo`80
00Aoo`03001oogoo009oo`<000=oo`03001oogoo04Eoo`03001oogoo02Yoo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`16Ool00`00Oomoo`0YOol000Yoo`04001oogoo000;
Ool00`00Oomoo`020017Ool00`00Oomoo`0YOol000Yoo`04001oogoo000;Ool01000Oomoo`00B7oo
0P00:Woo000:Ool01000Oomoo`001goo10000goo00<007ooOol0Agoo0P00:Goo000:Ool01000Oomo
o`001goo00<007ooOol017oo0P00BGoo00<007ooOol09goo000;Ool20008Ool50002Ool00`00Oomo
o`18Ool00`00Oomoo`0WOol001aoo`03001oogoo04Uoo`03001oogoo02Ioo`0077oo0P00Bgoo00<0
07ooOol09Goo000LOol00`00Oomoo`1:Ool00`00Oomoo`0UOol001aoo`8004aoo`03001oogoo02Ao
o`0077oo00<007ooOol0Bgoo0P009Goo000LOol00`00Oomoo`1<Ool00`00Oomoo`0SOol001aoo`80
04ioo`03001oogoo029oo`005Woo0`000goo00<007ooOol0CGoo0P008goo000GOol00`00Oomoo`02
Ool00`00Oomoo`1>Ool00`00Oomoo`0QOol001Moo`03001oogoo009oo`80051oo`03001oogoo021o
o`005goo00<007ooOol00Woo00<007ooOol0Cgoo00<007ooOol087oo000GOol00`00Oomoo`02Ool0
0`00Oomoo`1?Ool2000QOol001Ioo`8000Aoo`80055oo`03001oogoo01moo`005goo00<007ooOol0
0Woo00<007ooOol0DGoo00<007ooOol07Woo000LOol00`00Oomoo`1AOol2000OOol001aoo`8005=o
o`03001oogoo01eoo`0077oo00<007ooOol0DWoo0P007Woo000LOol2001EOol2000LOol001aoo`03
001oogoo05Eooa4000aoo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003
Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03
001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo
00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomo
o`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(16700\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32154 m
.008 .32048 L
.012 .31877 L
.016 .31669 L
.02 .31543 L
.024 .31592 L
.028 .31815 L
.032 .32047 L
.036 .32184 L
.04 .32191 L
.044 .32048 L
.048 .31837 L
.052 .31661 L
.056 .31613 L
.06 .3172 L
.064 .31907 L
.068 .32074 L
.072 .32131 L
.076 .32058 L
.08 .31903 L
.084 .31753 L
.088 .31699 L
.092 .31776 L
.096 .31946 L
.1 .32095 L
.104 .32125 L
.108 .32018 L
.112 .31836 L
.116 .3168 L
.12 .31629 L
.124 .31732 L
.128 .31965 L
.132 .32205 L
.136 .32306 L
.14 .32197 L
.144 .31947 L
.148 .31688 L
.152 .31528 L
.156 .3153 L
.16 .31701 L
.164 .31984 L
.168 .32248 L
.172 .32352 L
.176 .32257 L
.18 .32042 L
.184 .3184 L
.188 .31714 L
.192 .31657 L
.196 .31664 L
.2 .31741 L
Mistroke
.204 .31879 L
.208 .32017 L
.212 .32104 L
.216 .32149 L
.22 .32185 L
.224 .32202 L
.228 .32132 L
.232 .31937 L
.236 .31686 L
.24 .31516 L
.244 .31521 L
.248 .31681 L
.252 .31906 L
.256 .3212 L
.26 .3228 L
.264 .32361 L
.268 .32326 L
.272 .32163 L
.276 .31926 L
.28 .3172 L
.284 .31636 L
.288 .3168 L
.292 .31782 L
.296 .31857 L
.3 .31888 L
.304 .31927 L
.308 .32027 L
.312 .32169 L
.316 .32257 L
.32 .32211 L
.324 .32061 L
.328 .31931 L
.332 .3192 L
.336 .31997 L
.34 .32026 L
.344 .31916 L
.348 .31737 L
.352 .31659 L
.356 .31767 L
.36 .31955 L
.364 .32024 L
.368 .31906 L
.372 .31764 L
.376 .31838 L
.38 .32187 L
.384 .32584 L
.388 .32703 L
.392 .32433 L
.396 .31992 L
.4 .31731 L
Mistroke
.404 .31799 L
.408 .32003 L
.412 .32004 L
.416 .3166 L
.42 .31189 L
.424 .30993 L
.428 .31297 L
.432 .31945 L
.436 .32525 L
.44 .32711 L
.444 .32512 L
.448 .32227 L
.452 .32165 L
.456 .32386 L
.46 .32678 L
.464 .32755 L
.468 .32489 L
.472 .31995 L
.476 .31522 L
.48 .31271 L
.484 .31291 L
.488 .31495 L
.492 .31751 L
.496 .31952 L
.5 .32024 L
.504 .31929 L
.508 .31682 L
.512 .31383 L
.516 .31213 L
.52 .3134 L
.524 .31796 L
.528 .32401 L
.532 .32828 L
.536 .32803 L
.54 .32304 L
.544 .31622 L
.548 .31219 L
.552 .31455 L
.556 .32346 L
.56 .33531 L
.564 .34456 L
.568 .34689 L
.572 .34155 L
.576 .33167 L
.58 .3223 L
.584 .31766 L
.588 .31904 L
.592 .32466 L
.596 .33121 L
.6 .3359 L
Mistroke
.604 .33775 L
.608 .33744 L
.612 .33615 L
.616 .33435 L
.62 .3314 L
.624 .32632 L
.628 .31892 L
.632 .31063 L
.636 .30432 L
.64 .30315 L
.644 .30903 L
.648 .32149 L
.652 .33765 L
.656 .35306 L
.66 .36339 L
.664 .36593 L
.668 .3605 L
.672 .34924 L
.676 .33554 L
.68 .32249 L
.684 .31168 L
.688 .3027 L
.692 .29369 L
.696 .28246 L
.7 .26772 L
.704 .24981 L
.708 .23063 L
.712 .21296 L
.716 .1995 L
.72 .19187 L
.724 .19015 L
.728 .19283 L
.732 .19729 L
.736 .20063 L
.74 .20052 L
.744 .19593 L
.748 .18737 L
.752 .17662 L
.756 .16615 L
.76 .15833 L
.764 .15484 L
.768 .1563 L
.772 .16218 L
.776 .17099 L
.78 .18061 L
.784 .18878 L
.788 .19358 L
.792 .19383 L
.796 .18923 L
.8 .18038 L
Mistroke
.804 .1685 L
.808 .15524 L
.812 .14235 L
.816 .13147 L
.82 .1239 L
.824 .12049 L
.828 .12158 L
.832 .12701 L
.836 .13624 L
.84 .14851 L
.844 .16294 L
.848 .17863 L
.852 .19472 L
.856 .21047 L
.86 .22531 L
.864 .23883 L
.868 .25084 L
.872 .26124 L
.876 .27004 L
.88 .27731 L
.884 .28319 L
.888 .28786 L
.892 .29152 L
.896 .29435 L
.9 .29651 L
.904 .2981 L
.908 .29925 L
.912 .30009 L
.916 .3007 L
.92 .30114 L
.924 .30145 L
.928 .30164 L
.932 .30176 L
.936 .30185 L
.94 .30192 L
.944 .30197 L
.948 .302 L
.952 .302 L
.956 .302 L
.96 .30201 L
.964 .30203 L
.968 .30203 L
.972 .30202 L
.976 .30201 L
.98 .302 L
.984 .30202 L
.988 .30203 L
.992 .30201 L
.996 .302 L
1 .30199 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14312 m
.008 .14578 L
.012 .14666 L
.016 .14586 L
.02 .14552 L
.024 .14581 L
.028 .1459 L
.032 .14582 L
.036 .14575 L
.04 .14579 L
.044 .1458 L
.048 .14582 L
.052 .14581 L
.056 .14583 L
.06 .14582 L
.064 .14582 L
.068 .1458 L
.072 .1458 L
.076 .14578 L
.08 .14579 L
.084 .14579 L
.088 .14581 L
.092 .14582 L
.096 .14583 L
.1 .14583 L
.104 .14583 L
.108 .14581 L
.112 .1458 L
.116 .14578 L
.12 .14576 L
.124 .14577 L
.128 .14579 L
.132 .14582 L
.136 .14585 L
.14 .14586 L
.144 .14587 L
.148 .14585 L
.152 .1458 L
.156 .14575 L
.16 .14573 L
.164 .14574 L
.168 .14576 L
.172 .1458 L
.176 .14585 L
.18 .14589 L
.184 .14591 L
.188 .14589 L
.192 .14584 L
.196 .14578 L
.2 .14574 L
Mistroke
.204 .14571 L
.208 .1457 L
.212 .14571 L
.216 .14576 L
.22 .14585 L
.224 .14593 L
.228 .14597 L
.232 .14595 L
.236 .14591 L
.24 .14584 L
.244 .14576 L
.248 .14567 L
.252 .14562 L
.256 .14562 L
.26 .1457 L
.264 .14581 L
.268 .1459 L
.272 .14596 L
.276 .14598 L
.28 .14599 L
.284 .14597 L
.288 .1459 L
.292 .14579 L
.296 .14567 L
.3 .14561 L
.304 .14561 L
.308 .14566 L
.312 .14572 L
.316 .14576 L
.32 .14581 L
.324 .14589 L
.328 .146 L
.332 .14607 L
.336 .14606 L
.34 .14598 L
.344 .14589 L
.348 .14584 L
.352 .14582 L
.356 .14578 L
.36 .14566 L
.364 .14549 L
.368 .1454 L
.372 .14544 L
.376 .14561 L
.38 .14579 L
.384 .1459 L
.388 .14595 L
.392 .14605 L
.396 .14624 L
.4 .14646 L
Mistroke
.404 .14656 L
.408 .14643 L
.412 .14609 L
.416 .1457 L
.42 .14541 L
.424 .14527 L
.428 .1452 L
.432 .14509 L
.436 .14494 L
.44 .14486 L
.444 .14498 L
.448 .14537 L
.452 .14592 L
.456 .14646 L
.46 .14682 L
.464 .14698 L
.468 .14698 L
.472 .14694 L
.476 .14691 L
.48 .14688 L
.484 .14678 L
.488 .14655 L
.492 .14618 L
.496 .14568 L
.5 .14515 L
.504 .14466 L
.508 .14432 L
.512 .14415 L
.516 .14412 L
.52 .14413 L
.524 .14403 L
.528 .14375 L
.532 .14334 L
.536 .14299 L
.54 .14294 L
.544 .14335 L
.548 .14421 L
.552 .14535 L
.556 .1465 L
.56 .14749 L
.564 .1483 L
.568 .1491 L
.572 .15014 L
.576 .15161 L
.58 .15353 L
.584 .15578 L
.588 .15808 L
.592 .16022 L
.596 .16203 L
.6 .16351 L
Mistroke
.604 .16473 L
.608 .16581 L
.612 .16686 L
.616 .16799 L
.62 .16927 L
.624 .1708 L
.628 .17269 L
.632 .17499 L
.636 .17768 L
.64 .1806 L
.644 .18351 L
.648 .18612 L
.652 .18824 L
.656 .18979 L
.66 .19086 L
.664 .19169 L
.668 .19254 L
.672 .19366 L
.676 .19517 L
.68 .19712 L
.684 .19943 L
.688 .20205 L
.692 .20492 L
.696 .20808 L
.7 .2116 L
.704 .21559 L
.708 .22012 L
.712 .22517 L
.716 .23064 L
.72 .23635 L
.724 .24209 L
.728 .24769 L
.732 .25304 L
.736 .25815 L
.74 .26311 L
.744 .26805 L
.748 .27313 L
.752 .27845 L
.756 .28406 L
.76 .28991 L
.764 .29589 L
.768 .30184 L
.772 .30759 L
.776 .31304 L
.78 .31813 L
.784 .32287 L
.788 .32735 L
.792 .33171 L
.796 .33611 L
.8 .3407 L
Mistroke
.804 .34562 L
.808 .35092 L
.812 .35664 L
.816 .36272 L
.82 .36907 L
.824 .37557 L
.828 .38206 L
.832 .38841 L
.836 .39446 L
.84 .40011 L
.844 .40527 L
.848 .40988 L
.852 .41393 L
.856 .41742 L
.86 .42036 L
.864 .42281 L
.868 .42481 L
.872 .42642 L
.876 .42769 L
.88 .42869 L
.884 .42946 L
.888 .43004 L
.892 .43048 L
.896 .43081 L
.9 .43105 L
.904 .43123 L
.908 .43135 L
.912 .43145 L
.916 .43152 L
.92 .43157 L
.924 .43161 L
.928 .43164 L
.932 .43166 L
.936 .43169 L
.94 .4317 L
.944 .43172 L
.948 .43173 L
.952 .43175 L
.956 .43176 L
.96 .43178 L
.964 .43178 L
.968 .43181 L
.972 .43181 L
.976 .43184 L
.98 .43183 L
.984 .43186 L
.988 .43186 L
.992 .43189 L
.996 .43188 L
1 .43192 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .1604 L
.012 .16131 L
.016 .16149 L
.02 .16117 L
.024 .1611 L
.028 .16125 L
.032 .16124 L
.036 .16119 L
.04 .16117 L
.044 .16121 L
.048 .1612 L
.052 .16122 L
.056 .16122 L
.06 .16124 L
.064 .16122 L
.068 .16121 L
.072 .16118 L
.076 .16118 L
.08 .16117 L
.084 .16119 L
.088 .16121 L
.092 .16124 L
.096 .16125 L
.1 .16125 L
.104 .16123 L
.108 .16121 L
.112 .16118 L
.116 .16116 L
.12 .16115 L
.124 .16118 L
.128 .16121 L
.132 .16124 L
.136 .16125 L
.14 .16126 L
.144 .16126 L
.148 .16124 L
.152 .1612 L
.156 .16116 L
.16 .16113 L
.164 .16113 L
.168 .16115 L
.172 .16118 L
.176 .16123 L
.18 .1613 L
.184 .16134 L
.188 .16133 L
.192 .16127 L
.196 .16119 L
.2 .16112 L
Mistroke
.204 .16107 L
.208 .16105 L
.212 .16108 L
.216 .16116 L
.22 .16128 L
.224 .16137 L
.228 .16141 L
.232 .16138 L
.236 .16131 L
.24 .16124 L
.244 .16115 L
.248 .16105 L
.252 .16098 L
.256 .16098 L
.26 .16107 L
.264 .16119 L
.268 .16131 L
.272 .16139 L
.276 .16143 L
.28 .16144 L
.284 .16141 L
.288 .16131 L
.292 .16117 L
.296 .16103 L
.3 .16095 L
.304 .16096 L
.308 .16102 L
.312 .16109 L
.316 .16114 L
.32 .1612 L
.324 .1613 L
.328 .16143 L
.332 .16152 L
.336 .16151 L
.34 .16141 L
.344 .1613 L
.348 .16123 L
.352 .16122 L
.356 .16116 L
.36 .16101 L
.364 .1608 L
.368 .16068 L
.372 .16074 L
.376 .16095 L
.38 .16117 L
.384 .16131 L
.388 .16137 L
.392 .16149 L
.396 .16172 L
.4 .162 L
Mistroke
.404 .16214 L
.408 .16197 L
.412 .16155 L
.416 .16105 L
.42 .16069 L
.424 .16051 L
.428 .16043 L
.432 .16031 L
.436 .16012 L
.44 .16001 L
.444 .16016 L
.448 .16064 L
.452 .16133 L
.456 .162 L
.46 .16246 L
.464 .16265 L
.468 .16264 L
.472 .16259 L
.476 .16255 L
.48 .16251 L
.484 .16239 L
.488 .16211 L
.492 .16164 L
.496 .16102 L
.5 .16035 L
.504 .15975 L
.508 .15932 L
.512 .15912 L
.516 .15908 L
.52 .15908 L
.524 .15895 L
.528 .15861 L
.532 .1581 L
.536 .15767 L
.54 .15761 L
.544 .15811 L
.548 .15919 L
.552 .1606 L
.556 .16204 L
.56 .16328 L
.564 .16429 L
.568 .16528 L
.572 .16657 L
.576 .16839 L
.58 .17079 L
.584 .17359 L
.588 .17647 L
.592 .17912 L
.596 .18137 L
.6 .1832 L
Mistroke
.604 .18472 L
.608 .18607 L
.612 .18738 L
.616 .18878 L
.62 .19036 L
.624 .19226 L
.628 .19461 L
.632 .19748 L
.636 .20083 L
.64 .20446 L
.644 .20807 L
.648 .21131 L
.652 .21394 L
.656 .21586 L
.66 .2172 L
.664 .21822 L
.668 .21926 L
.672 .22064 L
.676 .22252 L
.68 .22493 L
.684 .22781 L
.688 .23106 L
.692 .23463 L
.696 .23854 L
.7 .24292 L
.704 .24788 L
.708 .25352 L
.712 .2598 L
.716 .26659 L
.72 .27368 L
.724 .28082 L
.728 .28777 L
.732 .29442 L
.736 .30077 L
.74 .30692 L
.744 .31305 L
.748 .31935 L
.752 .32596 L
.756 .33292 L
.76 .34018 L
.764 .3476 L
.768 .35497 L
.772 .36211 L
.776 .36887 L
.78 .37517 L
.784 .38104 L
.788 .38658 L
.792 .39198 L
.796 .39742 L
.8 .4031 L
Mistroke
.804 .40918 L
.808 .41576 L
.812 .42284 L
.816 .43037 L
.82 .43824 L
.824 .44629 L
.828 .45433 L
.832 .46218 L
.836 .46967 L
.84 .47666 L
.844 .48303 L
.848 .48873 L
.852 .49371 L
.856 .498 L
.86 .50161 L
.864 .5046 L
.868 .50703 L
.872 .50898 L
.876 .5105 L
.88 .51169 L
.884 .51258 L
.888 .51325 L
.892 .51373 L
.896 .51409 L
.9 .51432 L
.904 .51449 L
.908 .51458 L
.912 .51465 L
.916 .51467 L
.92 .51468 L
.924 .51466 L
.928 .51464 L
.932 .51461 L
.936 .51458 L
.94 .51453 L
.944 .5145 L
.948 .51445 L
.952 .51442 L
.956 .51436 L
.96 .51433 L
.964 .51428 L
.968 .51425 L
.972 .51419 L
.976 .51416 L
.98 .5141 L
.984 .51407 L
.988 .51401 L
.992 .51399 L
.996 .51392 L
1 .5139 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001>Ool2000MOol000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo04eo
o`8001eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00CGoo00@0
07ooOol001aoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2
0019Ool01@00Oomoogoo00000Woo00<007ooOol06Woo000:Ool01000Oomoo`0027oo00@007ooOol0
00Aoo`05001oogooOol00019Ool20003Ool01000Oomoo`0077oo000:Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool00`00Oomoo`020018Ool01@00Ool007oo00000goo00<007ooOol06Woo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`020017Ool01P00Oomoo`00Ool0
00Aoo`03001oogoo01Uoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0@goo0P0000=oo`00
Ool00Woo0P0017oo00<007ooOol06Goo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2
0014Ool3000:Ool00`00Oomoo`0IOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00D007ooOol007oo008000Ao
o`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00H007ooOol007oo0004Ool01000Oomoo`000Woo00@007oo000000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo
00000Woo00D007ooOol007oo008000Ioo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol02goo10000goo00@0
07ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@0
00=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool0
1P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo009o
o`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0
00Aoo`8000=oo`03001oogoo00Aoo`05001oogoo001oo`020003Ool01000Oomoo`000Woo00@007oo
Ool0009oo`05001oogooOol00003Ool00`00Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool5
0003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P000Woo00<0
07oo00000P0017oo0P0017oo10000goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`11Ool0
0`00Oomoo`0?Ool2000GOol0029oo`80049oo`03001oogoo011oo`8001Ioo`008WooH`0037oo000R
Ool7000017oo000007oo0P000Woo0P0000Aoo`000000009oo`<00003Ool0000000@00003Ool00000
00800003Ool0000000<000=oo`D00009Ool00000001oo`00Ool007oo00<0009oo`80009oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0000<Ool0
029oo`800003Ool00000009oo`800004Ool00000Ool200001Goo00000000Ool0100000Aoo`000000
009oo`@00003Ool0000000@00003Ool0000000<00003Ool00000009oo`<0009oo`80009oo`03001o
o`00009oo`03001oogoo02Yoo`008Woo00<007ooOol0=7oo0P0000=oo`0000000P000Woo00<007oo
0000;7oo000ROol2000eOol20007Ool00`00Ool0000/Ool0029oo`8003ioo`03001oo`0002aoo`00
2goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0?Goo0P00;Goo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]o
o`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo
0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000R
Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P00
0goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol0
0`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05
001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000
Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=o
o`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool2
0004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oocD003Aoo`00:7oo00<0
07ooOol0<Goo0`00<Woo000XOol00`00Oomoo`0dOol3000_Ool000]oo`8000Aoo`03001oogoo00=o
o`8000Aoo`8000=oo`<000=oo`03001oogoo03Moo`8002eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000jOol3000[Ool000=oo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000mOol2000YOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`80
00Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`800003Ool0000000@000=oo`8000Aoo`80
00=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomo
o`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo
00@007oo0000009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001o
o`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0goo00<007ooOol01Goo00@007ooOol0009oo`04001oogooOol20003Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo
00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=o
o`04001oogooOol40003Ool01P00Oomoo`00Ool0009oo`80009oo`04001oogoo0002Ool01000Oomo
o`000Woo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00
Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool0
0`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qo
o`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool3000017oo001oogoo
0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`12Ool2000ROol002Qoo`03
001oogoo04=oo`03001oogoo021oo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@
Ool00`00Oomoo`0?Ool00`00Oomoo`0=Ool3000BOol00`00Oomoo`0:Ool002Qoo`03001oogoo04Eo
o`8001moo`00:7oo00<007ooOol0AWoo0P007Woo000XOol00`00Oomoo`17Ool00`00Oomoo`0LOol0
02Qoo`03001oogoo04Qoo`03001oogoo01]oo`00:7oo00<007ooOol0B7oo00<007ooOol06goo000;
Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`19Ool00`00Oomoo`0J
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00
C7oo00<007ooOol06Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool0
1000Oomoo`00C7oo0P006Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`02001<Ool2000IOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007oo
Ool007oo00@000=oo`03001oogoo04aoo`h000aoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015o
o`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogoo
Ool00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05
Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006ao
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yo
o`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`80
00Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol0
00Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool0
0`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<0
00=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P00
3Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000
Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo1000
0goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06
001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo
00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol0
17oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07
001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007oo
Ool00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0
009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000ao
o`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo0`0000=oo`00Ool00Woo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007oo
Ool0>Woo0P00=Woo000LOol2000lOol4000cOol001aoo`03001oogoo03ioo`80039oo`0077oo00<0
07ooOol0?goo0P00<Goo000LOol20012Ool3000^Ool001aoo`03001oogoo04=oo`8002eoo`0077oo
00<007ooOol0AGoo00<007ooOol0:Woo000LOol20017Ool00`00Oomoo`0YOol001aoo`03001oogoo
04Ioo`8002Yoo`0077oo0P00B7oo00<007ooOol0:7oo000;Ool20004Ool00`00Oomoo`02Ool30003
Ool00`00Oomoo`18Ool00`00Oomoo`0WOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0B7oo00<007ooOol09goo000:Ool01000Oomoo`002goo00<007ooOol00P00BWoo00<0
07ooOol09Woo000:Ool01000Oomoo`002goo00@007ooOol004]oo`8002Moo`002Woo00@007ooOol0
00Moo`@000=oo`03001oogoo04Yoo`03001oogoo02Eoo`002Woo00@007ooOol000Moo`03001oogoo
00Aoo`8004aoo`03001oogoo02Aoo`002goo0P0027oo1@000Woo00<007ooOol0Bgoo00<007ooOol0
97oo000LOol00`00Oomoo`1<Ool00`00Oomoo`0SOol001aoo`8004eoo`8002Aoo`0077oo00<007oo
Ool0CGoo00<007ooOol08Woo000LOol2001>Ool2000SOol001aoo`03001oogoo04ioo`03001oogoo
025oo`0077oo00<007ooOol0Cgoo00<007ooOol087oo000LOol2001@Ool2000QOol001Ioo`<000=o
o`03001oogoo051oo`03001oogoo01moo`005goo00<007ooOol00Woo00<007ooOol0DGoo00<007oo
Ool07Woo000GOol00`00Oomoo`02Ool2001COol00`00Oomoo`0MOol001Moo`03001oogoo009oo`03
001oogoo059oo`03001oogoo01eoo`005goo00<007ooOol00Woo00<007ooOol0DWoo00<007ooOol0
7Goo000FOol20004Ool2001DOol00`00Oomoo`0LOol001Moo`03001oogoo009oo`03001oogoo05Ao
o`03001oogoo01]oo`0077oo00<007ooOol0E7oo00<007ooOol06goo000LOol2001EOol2000LOol0
01aoo`03001oogoo05Eoo`8001]oo`0077oo0P00F7oo0P006Goo000LOol00`00Oomoo`1IOol=000<
Ool001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool0
0`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000
Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@0
00=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00
Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(16867\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31847 m
.008 .3201 L
.012 .32108 L
.016 .32037 L
.02 .31868 L
.024 .31729 L
.028 .31675 L
.032 .31734 L
.036 .3185 L
.04 .31999 L
.044 .32108 L
.048 .32092 L
.052 .3197 L
.056 .31794 L
.06 .31663 L
.064 .31657 L
.068 .31773 L
.072 .31963 L
.076 .32126 L
.08 .32178 L
.084 .32085 L
.088 .31883 L
.092 .31685 L
.096 .316 L
.1 .3167 L
.104 .31852 L
.108 .32055 L
.112 .32192 L
.116 .3219 L
.12 .32047 L
.124 .31837 L
.128 .31685 L
.132 .31663 L
.136 .3175 L
.14 .31882 L
.144 .32001 L
.148 .3207 L
.152 .3207 L
.156 .32005 L
.16 .3193 L
.164 .319 L
.168 .31916 L
.172 .3192 L
.176 .31863 L
.18 .3178 L
.184 .31746 L
.188 .31801 L
.192 .3192 L
.196 .32059 L
.2 .32188 L
Mistroke
.204 .32252 L
.208 .32187 L
.212 .31972 L
.216 .31697 L
.22 .31516 L
.224 .31528 L
.228 .31706 L
.232 .31942 L
.236 .32145 L
.24 .32281 L
.244 .32328 L
.248 .32256 L
.252 .32067 L
.256 .31832 L
.26 .31659 L
.264 .3161 L
.268 .31662 L
.272 .31752 L
.276 .3185 L
.28 .31972 L
.284 .3213 L
.288 .3228 L
.292 .32338 L
.296 .3225 L
.3 .32052 L
.304 .31844 L
.308 .31719 L
.312 .31694 L
.316 .31722 L
.32 .31755 L
.324 .31804 L
.328 .31913 L
.332 .32081 L
.336 .32224 L
.34 .32239 L
.344 .32113 L
.348 .31964 L
.352 .31936 L
.356 .32047 L
.36 .32153 L
.364 .32091 L
.368 .31863 L
.372 .31654 L
.376 .31658 L
.38 .31862 L
.384 .32048 L
.388 .32009 L
.392 .31781 L
.396 .31629 L
.4 .31789 L
Mistroke
.404 .32216 L
.408 .32599 L
.412 .32641 L
.416 .32337 L
.42 .31978 L
.424 .31866 L
.428 .32027 L
.432 .32191 L
.436 .32062 L
.44 .31613 L
.444 .31141 L
.448 .31011 L
.452 .31347 L
.456 .31928 L
.46 .32382 L
.464 .32486 L
.468 .32317 L
.472 .32147 L
.476 .32191 L
.48 .32444 L
.484 .32706 L
.488 .32761 L
.492 .32534 L
.496 .32122 L
.5 .31701 L
.504 .31419 L
.508 .31339 L
.512 .31453 L
.516 .31698 L
.52 .3197 L
.524 .32134 L
.528 .3207 L
.532 .31761 L
.536 .31349 L
.54 .3109 L
.544 .31211 L
.548 .31737 L
.552 .32432 L
.556 .32909 L
.56 .32864 L
.564 .32286 L
.568 .31505 L
.572 .31014 L
.576 .31185 L
.58 .32042 L
.584 .3323 L
.588 .34205 L
.592 .34532 L
.596 .34112 L
.6 .3321 L
Mistroke
.604 .32289 L
.608 .31754 L
.612 .31762 L
.616 .32187 L
.62 .32755 L
.624 .33218 L
.628 .33478 L
.632 .33579 L
.636 .33605 L
.64 .33568 L
.644 .33375 L
.648 .32896 L
.652 .32093 L
.656 .31104 L
.66 .30237 L
.664 .29853 L
.668 .30204 L
.672 .31305 L
.676 .32907 L
.68 .34576 L
.684 .35851 L
.688 .36411 L
.692 .36173 L
.696 .35294 L
.7 .34081 L
.704 .32848 L
.708 .31786 L
.712 .30896 L
.716 .30023 L
.72 .28951 L
.724 .27524 L
.728 .25732 L
.732 .23732 L
.736 .21791 L
.74 .202 L
.744 .19166 L
.748 .18754 L
.752 .18864 L
.756 .19262 L
.76 .19655 L
.764 .19779 L
.768 .19478 L
.772 .18743 L
.776 .17707 L
.78 .16593 L
.784 .1565 L
.788 .15083 L
.792 .15003 L
.796 .15412 L
.8 .16198 L
Mistroke
.804 .17173 L
.808 .18109 L
.812 .18793 L
.816 .19069 L
.82 .1886 L
.824 .18181 L
.828 .17122 L
.832 .15827 L
.836 .1447 L
.84 .13225 L
.844 .12244 L
.848 .1164 L
.852 .11475 L
.856 .11761 L
.86 .12468 L
.864 .13533 L
.868 .14875 L
.872 .16403 L
.876 .18028 L
.88 .19665 L
.884 .21248 L
.888 .22724 L
.892 .24061 L
.896 .25242 L
.9 .26259 L
.904 .27113 L
.908 .27817 L
.912 .28385 L
.916 .28838 L
.92 .29193 L
.924 .29466 L
.928 .2967 L
.932 .29823 L
.936 .29935 L
.94 .30017 L
.944 .30077 L
.948 .30118 L
.952 .30146 L
.956 .30165 L
.96 .30179 L
.964 .30189 L
.968 .30195 L
.972 .30199 L
.976 .302 L
.98 .30201 L
.984 .30203 L
.988 .30205 L
.992 .30204 L
.996 .30203 L
1 .30203 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14694 m
.008 .14612 L
.012 .14586 L
.016 .14625 L
.02 .14628 L
.024 .14615 L
.028 .14612 L
.032 .14619 L
.036 .14618 L
.04 .14617 L
.044 .14617 L
.048 .14619 L
.052 .14618 L
.056 .14618 L
.06 .14616 L
.064 .14616 L
.068 .14615 L
.072 .14617 L
.076 .14617 L
.08 .1462 L
.084 .1462 L
.088 .1462 L
.092 .14618 L
.096 .14616 L
.1 .14614 L
.104 .14614 L
.108 .14615 L
.112 .14618 L
.116 .14619 L
.12 .14621 L
.124 .14621 L
.128 .1462 L
.132 .14618 L
.136 .14615 L
.14 .14613 L
.144 .14614 L
.148 .14615 L
.152 .14617 L
.156 .14618 L
.16 .1462 L
.164 .14622 L
.168 .14623 L
.172 .14621 L
.176 .14618 L
.18 .14615 L
.184 .14613 L
.188 .14611 L
.192 .1461 L
.196 .14613 L
.2 .14619 L
Mistroke
.204 .14625 L
.208 .14628 L
.212 .14628 L
.216 .14624 L
.22 .14619 L
.224 .14613 L
.228 .14607 L
.232 .14604 L
.236 .14605 L
.24 .14612 L
.244 .14621 L
.248 .14628 L
.252 .14631 L
.256 .14632 L
.26 .1463 L
.264 .14625 L
.268 .14616 L
.272 .14606 L
.276 .14599 L
.28 .14599 L
.284 .14605 L
.288 .14613 L
.292 .14621 L
.296 .14628 L
.3 .14634 L
.304 .14639 L
.308 .14638 L
.312 .1463 L
.316 .14618 L
.32 .14607 L
.324 .14601 L
.328 .14601 L
.332 .14603 L
.336 .14605 L
.34 .14607 L
.344 .14613 L
.348 .14624 L
.352 .14636 L
.356 .14643 L
.36 .1464 L
.364 .14633 L
.368 .14629 L
.372 .14629 L
.376 .14628 L
.38 .1462 L
.384 .14603 L
.388 .14585 L
.392 .14577 L
.396 .14584 L
.4 .14597 L
Mistroke
.404 .14608 L
.408 .14613 L
.412 .14617 L
.416 .14632 L
.42 .14658 L
.424 .14685 L
.428 .14697 L
.432 .14684 L
.436 .14653 L
.44 .1462 L
.444 .14597 L
.448 .14584 L
.452 .14571 L
.456 .14551 L
.46 .14527 L
.464 .14512 L
.468 .14521 L
.472 .14557 L
.476 .14609 L
.48 .1466 L
.484 .14697 L
.488 .14717 L
.492 .14725 L
.496 .14729 L
.5 .14733 L
.504 .14734 L
.508 .14729 L
.512 .14712 L
.516 .14679 L
.52 .14633 L
.524 .14579 L
.528 .14527 L
.532 .14488 L
.536 .14468 L
.54 .14465 L
.544 .14466 L
.548 .14456 L
.552 .14425 L
.556 .14378 L
.56 .14332 L
.564 .14314 L
.568 .14341 L
.572 .14414 L
.576 .14517 L
.58 .14623 L
.584 .14715 L
.588 .14789 L
.592 .1486 L
.596 .14952 L
.6 .15085 L
Mistroke
.604 .15264 L
.608 .15477 L
.612 .15704 L
.616 .1592 L
.62 .16112 L
.624 .16274 L
.628 .1641 L
.632 .16528 L
.636 .16635 L
.64 .1674 L
.644 .16854 L
.648 .16988 L
.652 .17155 L
.656 .17367 L
.66 .17622 L
.664 .1791 L
.668 .18206 L
.672 .18483 L
.676 .18716 L
.68 .18893 L
.684 .19019 L
.688 .19112 L
.692 .19197 L
.696 .19299 L
.7 .19433 L
.704 .19605 L
.708 .19812 L
.712 .20048 L
.716 .20309 L
.72 .20597 L
.724 .2092 L
.728 .21289 L
.732 .21711 L
.736 .22189 L
.74 .22714 L
.744 .23272 L
.748 .23841 L
.752 .24403 L
.756 .24945 L
.76 .25463 L
.764 .25962 L
.768 .26454 L
.772 .26955 L
.776 .27476 L
.78 .28025 L
.784 .28601 L
.788 .29194 L
.792 .29792 L
.796 .30378 L
.8 .30939 L
Mistroke
.804 .31465 L
.808 .31955 L
.812 .32415 L
.816 .32855 L
.82 .3329 L
.824 .33737 L
.828 .34209 L
.832 .34717 L
.836 .35265 L
.84 .35853 L
.844 .36473 L
.848 .37115 L
.852 .37765 L
.856 .3841 L
.86 .39034 L
.864 .39625 L
.868 .40173 L
.872 .4067 L
.876 .41112 L
.88 .41499 L
.884 .4183 L
.888 .42109 L
.892 .42339 L
.896 .42528 L
.9 .42679 L
.904 .42799 L
.908 .42892 L
.912 .42964 L
.916 .43018 L
.92 .4306 L
.924 .4309 L
.928 .43113 L
.932 .4313 L
.936 .43142 L
.94 .43151 L
.944 .43158 L
.948 .43162 L
.952 .43167 L
.956 .43169 L
.96 .43172 L
.964 .43173 L
.968 .43176 L
.972 .43177 L
.976 .4318 L
.98 .43179 L
.984 .43182 L
.988 .43182 L
.992 .43185 L
.996 .43185 L
1 .43188 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15924 L
.012 .1612 L
.016 .16184 L
.02 .16124 L
.024 .16097 L
.028 .16119 L
.032 .16126 L
.036 .16123 L
.04 .16119 L
.044 .16123 L
.048 .16122 L
.052 .16122 L
.056 .16119 L
.06 .16119 L
.064 .16119 L
.068 .1612 L
.072 .16121 L
.076 .16123 L
.08 .16123 L
.084 .16123 L
.088 .16121 L
.092 .16121 L
.096 .16119 L
.1 .16119 L
.104 .16118 L
.108 .16119 L
.112 .1612 L
.116 .16122 L
.12 .16123 L
.124 .16124 L
.128 .16124 L
.132 .16123 L
.136 .1612 L
.14 .16117 L
.144 .16115 L
.148 .16116 L
.152 .16117 L
.156 .16121 L
.16 .16125 L
.164 .16129 L
.168 .16129 L
.172 .16126 L
.176 .16121 L
.18 .16116 L
.184 .16113 L
.188 .16112 L
.192 .16113 L
.196 .16117 L
.2 .16124 L
Mistroke
.204 .1613 L
.208 .16133 L
.212 .16131 L
.216 .16127 L
.22 .16123 L
.224 .16116 L
.228 .16109 L
.232 .16104 L
.236 .16105 L
.24 .16113 L
.244 .16123 L
.248 .16132 L
.252 .16138 L
.256 .16139 L
.26 .16137 L
.264 .1613 L
.268 .16118 L
.272 .16105 L
.276 .16097 L
.28 .16097 L
.284 .16105 L
.288 .16115 L
.292 .16125 L
.296 .16133 L
.3 .16141 L
.304 .16146 L
.308 .16145 L
.312 .16136 L
.316 .16121 L
.32 .16107 L
.324 .16099 L
.328 .16099 L
.332 .16102 L
.336 .16103 L
.34 .16106 L
.344 .16113 L
.348 .16127 L
.352 .16143 L
.356 .16151 L
.36 .16148 L
.364 .16139 L
.368 .16133 L
.372 .16133 L
.376 .16133 L
.38 .16123 L
.384 .16102 L
.388 .16079 L
.392 .16069 L
.396 .16076 L
.4 .16094 L
Mistroke
.404 .16108 L
.408 .16113 L
.412 .16119 L
.416 .16137 L
.42 .16169 L
.424 .16203 L
.428 .16217 L
.432 .16202 L
.436 .16164 L
.44 .16123 L
.444 .16093 L
.448 .16076 L
.452 .1606 L
.456 .16035 L
.46 .16006 L
.464 .15988 L
.468 .15999 L
.472 .16043 L
.476 .16107 L
.48 .16171 L
.484 .16218 L
.488 .16243 L
.492 .16253 L
.496 .16257 L
.5 .16261 L
.504 .16263 L
.508 .16257 L
.512 .16236 L
.516 .16195 L
.52 .16137 L
.524 .16069 L
.528 .16004 L
.532 .15956 L
.536 .15931 L
.54 .15928 L
.544 .15929 L
.548 .15916 L
.552 .15877 L
.556 .15818 L
.56 .15762 L
.564 .1574 L
.568 .15774 L
.572 .15864 L
.576 .15991 L
.58 .16124 L
.584 .16238 L
.588 .1633 L
.592 .16419 L
.596 .16534 L
.6 .16699 L
Mistroke
.604 .16922 L
.608 .17188 L
.612 .1747 L
.616 .17739 L
.62 .17977 L
.624 .18179 L
.628 .18348 L
.632 .18494 L
.636 .18627 L
.64 .18759 L
.644 .18899 L
.648 .19065 L
.652 .19274 L
.656 .19537 L
.66 .19855 L
.664 .20212 L
.668 .20581 L
.672 .20924 L
.676 .21213 L
.68 .21433 L
.684 .21589 L
.688 .21704 L
.692 .2181 L
.696 .21935 L
.7 .22102 L
.704 .22315 L
.708 .22572 L
.712 .22865 L
.716 .23189 L
.72 .23546 L
.724 .23947 L
.728 .24405 L
.732 .24931 L
.736 .25525 L
.74 .26178 L
.744 .26871 L
.748 .27578 L
.752 .28276 L
.756 .2895 L
.76 .29592 L
.764 .30212 L
.768 .30823 L
.772 .31444 L
.776 .32091 L
.78 .32772 L
.784 .33487 L
.788 .34223 L
.792 .34965 L
.796 .35692 L
.8 .36387 L
Mistroke
.804 .37039 L
.808 .37646 L
.812 .38215 L
.816 .3876 L
.82 .39298 L
.824 .39851 L
.828 .40436 L
.832 .41065 L
.836 .41743 L
.84 .42471 L
.844 .43239 L
.848 .44034 L
.852 .4484 L
.856 .45638 L
.86 .4641 L
.864 .47142 L
.868 .47819 L
.872 .48433 L
.876 .48979 L
.88 .49454 L
.884 .49861 L
.888 .50203 L
.892 .50484 L
.896 .50713 L
.9 .50895 L
.904 .51039 L
.908 .51149 L
.912 .51233 L
.916 .51294 L
.92 .5134 L
.924 .51372 L
.928 .51395 L
.932 .51409 L
.936 .51419 L
.94 .51423 L
.944 .51426 L
.948 .51426 L
.952 .51425 L
.956 .51422 L
.96 .5142 L
.964 .51415 L
.968 .51413 L
.972 .51407 L
.976 .51405 L
.98 .51399 L
.984 .51396 L
.988 .5139 L
.992 .51388 L
.996 .51381 L
1 .51379 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001@Ool3000JOol000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo04mo
o`03001oo`0001Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00
D7oo00<007oo00006Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8004]oo`8000=oo`04001oogoo000IOol000Yoo`04001oogoo0008Ool01000Oomoo`0017oo
00D007ooOomoo`0004aoo`80009oo`05001oogooOol0000IOol000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`03001oogoo008004Yoo`03001oo`00009oo`05001oogooOol0000IOol000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008004Yoo`03001oogoo008000Ao
o`03001oogoo01Moo`002goo0P002Woo0P000goo0`000goo00<007ooOol0AWoo0`000goo0P0017oo
00<007ooOol05goo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool20016Ool01000Ool0
00002Woo00<007ooOol05Woo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8000eoo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000=oo`D000=o
o`8000Aoo`800004Ool007ooOol50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol02goo00D007ooOomoo`00009oo`04001o
ogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003
Ool01000Oomoo`000Woo00H007ooOomoo`00Ool20002Ool01000Oomoo`000Woo00<007ooOol00P00
0goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`02Ool20003Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool20003
Ool01000Oomoo`000Woo00H007ooOol007oo0004Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00]oo`@0
00=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001o
ogooOol40003Ool01000Oomoo`000Woo00D007oo001oo`00009oo`04001oogoo0002Ool02000Oomo
o`00Ool007oo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool0
0`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009o
o`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D007oo001oo`00009o
o`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007oo00001Woo00@007ooOol000Eoo`00
8Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=o
o`8000Aoo`<000Aoo`8000Aoo`8000=oo`D0009oo`D000=oo`8000Ioo`008Woo00<007ooOol0A7oo
00<007ooOol03goo00<007ooOol04goo000ROol2000oOol00`00Oomoo`02Ool00`00Oomoo`0AOol2
000COol0029oof<000aoo`008Woo1@0000=oo`0000000`0000Eoo`00000007oo00L00003Ool00000
0080009oo`<0009oo`D00003Ool007oo00<00003Ool007oo00P0009oo`800006Ool007oo001oo`00
0Woo0P000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol02Woo000ROol3000017oo000007oo0P000Woo0P0000=oo`0000000goo0`0000Eoo`000000
07oo00<0009oo`D00003Ool007oo00@00003Ool000000080009oo`800006Ool00000Ool007oo0`00
00Eoo`00001oo`00009oo`03001oogoo02Moo`008Woo00<007ooOol0=Woo00@007oo001oo`<0009o
o`04001oogoo000YOol0029oo`8003Moo`8000Moo`03001oo`0002Yoo`008Woo0P00@Goo0P00:Woo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`10Ool2000ZOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`00
2goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03
Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0
029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool2
0003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029o
o`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04
001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P00
0goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo=`00<Woo000XOol0
0`00Oomoo`0dOol2000`Ool002Qoo`03001oogoo03Ioo`<002eoo`002goo0P0017oo00<007ooOol0
0goo0P0017oo0P000goo0`000goo00<007ooOol0>Goo0P00:goo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`06001oogoo001oo`000goo00@007ooOol003eoo`<002Qoo`000goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol003moo`<002Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo
0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo
1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001o
o`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01@00
Oomoo`00Ool00P000Woo00@007ooOol0009oo`04001oogoo0003Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007oo
Ool007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00L007ooOomo
o`00Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001o
ogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Ool007oo00000Woo00@007ooOol0
009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03
001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`@0009oo`04001oogoo0002Ool0
1000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<0
07ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo
00<007ooOol017oo00H007ooOol007oo0003Ool01000Ool000000Woo00@007ooOol0009oo`04001o
ogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008
Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`000goo0`0017oo
0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`15Ool00`00Oomoo`0NOol002Qoo`03
001oogoo04Eoo`8001moo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00
Oomoo`0?Ool00`00Oomoo`0?Ool2000AOol00`00Oomoo`0:Ool002Qoo`03001oogoo04Qoo`03001o
ogoo01]oo`00:7oo00<007ooOol0B7oo0P0077oo000XOol00`00Oomoo`19Ool2000KOol002Qoo`03
001oogoo04Yoo`03001oogoo01Uoo`00:7oo00<007ooOol0Bgoo00<007ooOol067oo000;Ool20004
Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1;Ool00`00Oomoo`0HOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00CWoo00<0
07ooOol05goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomo
o`00CWoo0P0067oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`02001?Ool00`00Oomoo`0EOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007oo
Ool007oo00@000=oo`03001oogoo04moo`/000aoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015o
o`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogoo
Ool00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05
Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006ao
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yo
o`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`80
00Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol0
00Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool0
0`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<0
00=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P00
3Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000
Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo1000
0goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06
001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo
00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol0
17oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07
001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007oo
Ool00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0
009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000ao
o`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00<007ooOol00`000Woo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007oo
Ool0?7oo0`00<goo000LOol2000oOol3000aOol001aoo`03001oogoo045oo`03001oogoo02ioo`00
77oo00<007ooOol0@Woo0P00;Woo000LOol20014Ool4000[Ool001aoo`03001oogoo04Ioo`8002Yo
o`0077oo00<007ooOol0Agoo0P00:Goo000LOol20019Ool2000XOol001aoo`03001oogoo04Uoo`03
001oogoo02Ioo`0077oo0P00Bgoo00<007ooOol09Goo000;Ool20004Ool00`00Oomoo`02Ool30003
Ool00`00Oomoo`1;Ool00`00Oomoo`0TOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0Bgoo00<007ooOol097oo000:Ool01000Oomoo`002goo00<007ooOol00P00C7oo0P00
9Goo000:Ool01000Oomoo`002goo00@007ooOol004ioo`8002Aoo`002Woo00@007ooOol000Moo`@0
00=oo`03001oogoo04eoo`03001oogoo029oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80
04ioo`8002=oo`002goo0P0027oo1@000Woo00<007ooOol0CWoo00<007ooOol08Goo000LOol00`00
Oomoo`1?Ool00`00Oomoo`0POol001aoo`80051oo`03001oogoo021oo`0077oo00<007ooOol0D7oo
00<007ooOol07goo000LOol2001AOol00`00Oomoo`0OOol001aoo`03001oogoo055oo`03001oogoo
01ioo`0077oo00<007ooOol0DWoo00<007ooOol07Goo000LOol2001COol2000NOol001Ioo`<000=o
o`03001oogoo05=oo`03001oogoo01aoo`005goo00<007ooOol00Woo00<007ooOol0E7oo00<007oo
Ool06goo000GOol00`00Oomoo`02Ool2001EOol00`00Oomoo`0KOol001Moo`03001oogoo009oo`03
001oogoo05Eoo`03001oogoo01Yoo`005goo00<007ooOol00Woo00<007ooOol0EGoo00<007ooOol0
6Woo000FOol20004Ool2001GOol00`00Oomoo`0IOol001Moo`03001oogoo009oo`03001oogoo05Io
o`8001Yoo`0077oo00<007ooOol0Egoo00<007ooOol067oo000LOol2001HOol2000IOol001aoo`03
001oogoo05Qoo`8001Qoo`0077oo0P00FWoo0`005Woo000LOol00`00Oomoo`1KOol;000<Ool001ao
o`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomo
o`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00
M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03
001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07
Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(17034\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31515 m
.008 .3159 L
.012 .31775 L
.016 .32061 L
.02 .32253 L
.024 .32256 L
.028 .32047 L
.032 .31765 L
.036 .31568 L
.04 .3151 L
.044 .3165 L
.048 .31911 L
.052 .32145 L
.056 .32249 L
.06 .32157 L
.064 .31941 L
.068 .31713 L
.072 .3158 L
.076 .31618 L
.08 .31795 L
.084 .3201 L
.088 .32144 L
.092 .32133 L
.096 .3201 L
.1 .31848 L
.104 .31733 L
.108 .31722 L
.112 .31816 L
.116 .31951 L
.12 .32028 L
.124 .32004 L
.128 .31915 L
.132 .31835 L
.136 .31817 L
.14 .31867 L
.144 .31963 L
.148 .32051 L
.152 .32067 L
.156 .31973 L
.16 .31809 L
.164 .31686 L
.168 .31691 L
.172 .3182 L
.176 .31994 L
.18 .32135 L
.184 .32199 L
.188 .32153 L
.192 .31995 L
.196 .31787 L
.2 .31639 L
Mistroke
.204 .31634 L
.208 .31753 L
.212 .31908 L
.216 .32033 L
.22 .32119 L
.224 .32175 L
.228 .32172 L
.232 .32081 L
.236 .31924 L
.24 .31776 L
.244 .31694 L
.248 .31679 L
.252 .31711 L
.256 .31794 L
.26 .31952 L
.264 .32159 L
.268 .32322 L
.272 .32339 L
.276 .32191 L
.28 .31959 L
.284 .31753 L
.288 .31633 L
.292 .31604 L
.296 .31648 L
.3 .31763 L
.304 .31946 L
.308 .32155 L
.312 .32306 L
.316 .32325 L
.32 .32206 L
.324 .3203 L
.328 .31896 L
.332 .31841 L
.336 .31819 L
.34 .31768 L
.344 .31698 L
.348 .31698 L
.352 .31838 L
.356 .32069 L
.36 .32237 L
.364 .32224 L
.368 .3207 L
.372 .31948 L
.376 .31986 L
.38 .32129 L
.384 .32189 L
.388 .32053 L
.392 .31814 L
.396 .31688 L
.4 .3179 L
Mistroke
.404 .31994 L
.408 .32058 L
.412 .31876 L
.416 .31616 L
.42 .31568 L
.424 .31859 L
.428 .32305 L
.432 .3257 L
.436 .32475 L
.44 .32161 L
.444 .31952 L
.448 .32038 L
.452 .32289 L
.456 .32378 L
.46 .32094 L
.464 .31551 L
.468 .31107 L
.472 .31066 L
.476 .31437 L
.48 .31943 L
.484 .32261 L
.488 .32272 L
.492 .32119 L
.496 .32044 L
.5 .32184 L
.504 .3247 L
.508 .32716 L
.512 .32762 L
.516 .32574 L
.52 .32233 L
.524 .31857 L
.528 .31552 L
.532 .31392 L
.536 .31429 L
.54 .31662 L
.544 .31992 L
.548 .32235 L
.552 .32204 L
.556 .31849 L
.56 .31339 L
.564 .30992 L
.568 .3109 L
.572 .31666 L
.576 .32448 L
.58 .32991 L
.584 .32954 L
.588 .32322 L
.592 .31448 L
.596 .30856 L
.6 .30944 L
Mistroke
.604 .31748 L
.608 .32924 L
.612 .33939 L
.616 .34355 L
.62 .34049 L
.624 .33246 L
.628 .32363 L
.632 .31781 L
.636 .31669 L
.64 .31949 L
.644 .32401 L
.648 .32821 L
.652 .33124 L
.656 .33341 L
.66 .33524 L
.664 .33649 L
.668 .3359 L
.672 .33186 L
.676 .3237 L
.68 .31263 L
.684 .30181 L
.688 .29521 L
.692 .29596 L
.696 .30492 L
.7 .32012 L
.704 .33748 L
.708 .35226 L
.712 .36074 L
.716 .36144 L
.72 .35532 L
.724 .34508 L
.728 .33381 L
.732 .32367 L
.736 .31507 L
.74 .3068 L
.744 .29675 L
.748 .28316 L
.752 .26556 L
.756 .24509 L
.76 .22424 L
.764 .206 L
.768 .19287 L
.772 .18607 L
.776 .18514 L
.78 .18815 L
.784 .19226 L
.788 .19461 L
.792 .19318 L
.796 .18727 L
.8 .17768 L
Mistroke
.804 .16631 L
.808 .15561 L
.812 .14791 L
.816 .14477 L
.82 .14673 L
.824 .15317 L
.828 .16249 L
.832 .17254 L
.836 .18107 L
.84 .18618 L
.844 .1867 L
.848 .1823 L
.852 .17348 L
.856 .16143 L
.86 .14775 L
.864 .13421 L
.868 .1225 L
.872 .11398 L
.876 .10959 L
.88 .10971 L
.884 .11431 L
.888 .12296 L
.892 .13495 L
.896 .14942 L
.9 .16545 L
.904 .18214 L
.908 .19871 L
.912 .21456 L
.916 .22923 L
.92 .24243 L
.924 .254 L
.928 .2639 L
.932 .2722 L
.936 .27902 L
.94 .28453 L
.944 .2889 L
.948 .29232 L
.952 .29492 L
.956 .29689 L
.96 .29837 L
.964 .29947 L
.968 .30026 L
.972 .30082 L
.976 .30121 L
.98 .30148 L
.984 .30168 L
.988 .30182 L
.992 .3019 L
.996 .30194 L
1 .30196 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14932 m
.008 .14657 L
.012 .1456 L
.016 .14653 L
.02 .14683 L
.024 .14656 L
.028 .14643 L
.032 .14655 L
.036 .14657 L
.04 .14655 L
.044 .14651 L
.048 .14653 L
.052 .14653 L
.056 .14654 L
.06 .14654 L
.064 .14656 L
.068 .14655 L
.072 .14655 L
.076 .14654 L
.08 .14653 L
.084 .14652 L
.088 .14653 L
.092 .14653 L
.096 .14655 L
.1 .14655 L
.104 .14656 L
.108 .14655 L
.112 .14655 L
.116 .14654 L
.12 .14653 L
.124 .14652 L
.128 .14653 L
.132 .14652 L
.136 .14653 L
.14 .14654 L
.144 .14656 L
.148 .14657 L
.152 .14658 L
.156 .14656 L
.16 .14654 L
.164 .14652 L
.168 .1465 L
.172 .14649 L
.176 .1465 L
.18 .14653 L
.184 .14658 L
.188 .1466 L
.192 .14661 L
.196 .14659 L
.2 .14656 L
Mistroke
.204 .14653 L
.208 .14649 L
.212 .14646 L
.216 .14646 L
.22 .1465 L
.224 .14655 L
.228 .1466 L
.232 .14663 L
.236 .14664 L
.24 .14663 L
.244 .14659 L
.248 .14653 L
.252 .14645 L
.256 .14641 L
.26 .14641 L
.264 .14647 L
.268 .14654 L
.272 .1466 L
.276 .14666 L
.28 .1467 L
.284 .14671 L
.288 .14665 L
.292 .14655 L
.296 .14645 L
.3 .14638 L
.304 .14637 L
.308 .1464 L
.312 .14646 L
.316 .14652 L
.32 .14661 L
.324 .1467 L
.328 .14676 L
.332 .14676 L
.336 .14669 L
.34 .14658 L
.344 .14648 L
.348 .14643 L
.352 .14641 L
.356 .14639 L
.36 .14637 L
.364 .14638 L
.368 .14646 L
.372 .14659 L
.376 .14672 L
.38 .14676 L
.384 .14672 L
.388 .14668 L
.392 .14669 L
.396 .14673 L
.4 .14673 L
Mistroke
.404 .14661 L
.408 .14641 L
.412 .14624 L
.416 .14618 L
.42 .14625 L
.424 .14634 L
.428 .14637 L
.432 .14636 L
.436 .14641 L
.44 .1466 L
.444 .14691 L
.448 .14721 L
.452 .14733 L
.456 .14722 L
.46 .14697 L
.464 .14671 L
.468 .14654 L
.472 .14641 L
.476 .14623 L
.48 .14595 L
.484 .14564 L
.488 .14545 L
.492 .14549 L
.496 .14579 L
.5 .14625 L
.504 .14673 L
.508 .14711 L
.512 .14736 L
.516 .1475 L
.52 .1476 L
.524 .14769 L
.528 .14776 L
.532 .14777 L
.536 .14766 L
.54 .1474 L
.544 .14697 L
.548 .14642 L
.552 .14588 L
.556 .14545 L
.56 .14523 L
.564 .14519 L
.568 .14521 L
.572 .14511 L
.576 .14479 L
.58 .14426 L
.584 .14372 L
.588 .14343 L
.592 .14356 L
.596 .14416 L
.6 .14506 L
Mistroke
.604 .14603 L
.608 .14687 L
.612 .14754 L
.616 .14817 L
.62 .14898 L
.624 .15017 L
.628 .15181 L
.632 .15381 L
.636 .156 L
.64 .15816 L
.644 .16016 L
.648 .16191 L
.652 .16342 L
.656 .16471 L
.66 .16584 L
.664 .16687 L
.668 .16789 L
.672 .16906 L
.676 .17053 L
.68 .17243 L
.684 .17482 L
.688 .17761 L
.692 .18058 L
.696 .18345 L
.7 .18597 L
.704 .18796 L
.708 .18943 L
.712 .1905 L
.716 .19141 L
.72 .19238 L
.724 .19359 L
.728 .19513 L
.732 .19698 L
.736 .1991 L
.74 .20146 L
.744 .20407 L
.748 .20701 L
.752 .21038 L
.756 .21429 L
.76 .21877 L
.764 .22377 L
.768 .22918 L
.772 .23478 L
.776 .24039 L
.78 .24586 L
.784 .2511 L
.788 .25613 L
.792 .26106 L
.796 .26601 L
.8 .27112 L
Mistroke
.804 .27649 L
.808 .28214 L
.812 .28801 L
.816 .29398 L
.82 .29991 L
.824 .30565 L
.828 .31108 L
.832 .31616 L
.836 .3209 L
.84 .32538 L
.844 .32974 L
.848 .33412 L
.852 .33869 L
.856 .34356 L
.86 .3488 L
.864 .35445 L
.868 .36046 L
.872 .36676 L
.876 .37322 L
.88 .37971 L
.884 .38609 L
.888 .39222 L
.892 .39797 L
.896 .40328 L
.9 .40806 L
.904 .4123 L
.908 .41598 L
.912 .41913 L
.916 .42176 L
.92 .42395 L
.924 .42571 L
.928 .42714 L
.932 .42826 L
.936 .42914 L
.94 .42981 L
.944 .43033 L
.948 .43071 L
.952 .431 L
.956 .43121 L
.96 .43138 L
.964 .43148 L
.968 .43158 L
.972 .43163 L
.976 .43169 L
.98 .43171 L
.984 .43176 L
.988 .43176 L
.992 .4318 L
.996 .4318 L
1 .43184 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16162 L
.012 .16114 L
.016 .16103 L
.02 .16128 L
.024 .16126 L
.028 .16118 L
.032 .16116 L
.036 .16123 L
.04 .16122 L
.044 .16122 L
.048 .1612 L
.052 .16121 L
.056 .16119 L
.06 .1612 L
.064 .1612 L
.068 .16122 L
.072 .16122 L
.076 .16123 L
.08 .16122 L
.084 .1612 L
.088 .16118 L
.092 .16118 L
.096 .16118 L
.1 .16121 L
.104 .16123 L
.108 .16125 L
.112 .16124 L
.116 .16123 L
.12 .16119 L
.124 .16117 L
.128 .16116 L
.132 .16118 L
.136 .1612 L
.14 .16122 L
.144 .16125 L
.148 .16126 L
.152 .16124 L
.156 .16122 L
.16 .16119 L
.164 .16117 L
.168 .16116 L
.172 .16116 L
.176 .16117 L
.18 .1612 L
.184 .16124 L
.188 .16127 L
.192 .16127 L
.196 .16126 L
.2 .16124 L
Mistroke
.204 .1612 L
.208 .16115 L
.212 .1611 L
.216 .1611 L
.22 .16114 L
.224 .16121 L
.228 .16128 L
.232 .16132 L
.236 .16133 L
.24 .16132 L
.244 .16126 L
.248 .16117 L
.252 .16108 L
.256 .16103 L
.26 .16105 L
.264 .16111 L
.268 .1612 L
.272 .16127 L
.276 .16135 L
.28 .1614 L
.284 .1614 L
.288 .16134 L
.292 .16121 L
.296 .16108 L
.3 .161 L
.304 .16098 L
.308 .16102 L
.312 .16109 L
.316 .16117 L
.32 .16128 L
.324 .16139 L
.328 .16148 L
.332 .16147 L
.336 .16138 L
.34 .16123 L
.344 .16111 L
.348 .16105 L
.352 .16103 L
.356 .16101 L
.36 .16098 L
.364 .16099 L
.368 .16109 L
.372 .16125 L
.376 .1614 L
.38 .16146 L
.384 .16142 L
.388 .16137 L
.392 .16138 L
.396 .16143 L
.4 .16142 L
Mistroke
.404 .16127 L
.408 .16103 L
.412 .16081 L
.416 .16075 L
.42 .16082 L
.424 .16093 L
.428 .16097 L
.432 .16096 L
.436 .16102 L
.44 .16126 L
.444 .16165 L
.448 .16201 L
.452 .16215 L
.456 .16202 L
.46 .16171 L
.464 .1614 L
.468 .16118 L
.472 .16102 L
.476 .16078 L
.48 .16043 L
.484 .16005 L
.488 .15981 L
.492 .15987 L
.496 .16025 L
.5 .16082 L
.504 .16141 L
.508 .16188 L
.512 .16219 L
.516 .16237 L
.52 .1625 L
.524 .1626 L
.528 .16268 L
.532 .16269 L
.536 .16257 L
.54 .16224 L
.544 .16171 L
.548 .16103 L
.552 .16034 L
.556 .1598 L
.56 .15953 L
.564 .15949 L
.568 .15951 L
.572 .15939 L
.576 .15898 L
.58 .15832 L
.584 .15765 L
.588 .15728 L
.592 .15746 L
.596 .1582 L
.6 .15932 L
Mistroke
.604 .16052 L
.608 .16157 L
.612 .16241 L
.616 .1632 L
.62 .16421 L
.624 .16568 L
.628 .16772 L
.632 .17021 L
.636 .17294 L
.64 .17564 L
.644 .17812 L
.648 .1803 L
.652 .18217 L
.656 .18377 L
.66 .18518 L
.664 .18645 L
.668 .18773 L
.672 .18917 L
.676 .191 L
.68 .19336 L
.684 .19634 L
.688 .1998 L
.692 .2035 L
.696 .20707 L
.7 .21019 L
.704 .21267 L
.708 .21449 L
.712 .21582 L
.716 .21694 L
.72 .21814 L
.724 .21964 L
.728 .22154 L
.732 .22384 L
.736 .22647 L
.74 .2294 L
.744 .23264 L
.748 .23629 L
.752 .24048 L
.756 .24533 L
.76 .2509 L
.764 .25712 L
.768 .26384 L
.772 .2708 L
.776 .27778 L
.78 .28457 L
.784 .29108 L
.788 .29733 L
.792 .30344 L
.796 .30958 L
.8 .31593 L
Mistroke
.804 .32259 L
.808 .3296 L
.812 .33688 L
.816 .3443 L
.82 .35166 L
.824 .35877 L
.828 .36551 L
.832 .3718 L
.836 .37766 L
.84 .38321 L
.844 .3886 L
.848 .39403 L
.852 .39968 L
.856 .4057 L
.86 .4122 L
.864 .41919 L
.868 .42664 L
.872 .43444 L
.876 .44245 L
.88 .45049 L
.884 .45838 L
.888 .46597 L
.892 .47309 L
.896 .47964 L
.9 .48555 L
.904 .49077 L
.908 .4953 L
.912 .49916 L
.916 .50239 L
.92 .50505 L
.924 .50719 L
.928 .50891 L
.932 .51024 L
.936 .51128 L
.94 .51205 L
.944 .51264 L
.948 .51305 L
.952 .51336 L
.956 .51356 L
.96 .5137 L
.964 .51378 L
.968 .51384 L
.972 .51384 L
.976 .51385 L
.98 .51382 L
.984 .51382 L
.988 .51376 L
.992 .51375 L
.996 .51369 L
1 .51367 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0DWoo0P00
67oo000ROol2001COol3000GOol000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001o
ogoo055oo`04001oogoo000GOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
009oo`8004ioo`05001oogooOol00002Ool00`00Oomoo`0EOol000=oo`D0009oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P00CGoo0P000goo00@007ooOol001Moo`002Woo00@0
07ooOol000Qoo`04001oogoo0004Ool01@00Oomoogoo0000CWoo00<007oo00000Woo00@007ooOol0
01Moo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00C7oo00H007oo
Ool007oo0004Ool00`00Oomoo`0DOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008004Yoo`03001oo`0000=oo`8000Aoo`03001oogoo01Aoo`002goo0P002Woo0P000goo
0`000goo00<007ooOol0B7oo10000goo00<007ooOol00goo00<007ooOol057oo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool20019Ool00`00Oomoo`0;Ool00`00Oomoo`0COol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo
0P0017oo0P001Goo0`000goo0`0017oo0P000goo1@0000=oo`00Ool00P0017oo0P0017oo1@000Woo
0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo00]oo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`05001oogooOol0
0002Ool200001Goo001oogoo00000Woo00@007ooOol000=oo`80009oo`03001oo`0000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`06001oogoo001o
o`000Woo00@007ooOol0009oo`07001oogooOol007oo00001goo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo00D007oo001oo`00009oo`04001oogoo0002
Ool00`00Oomoo`02Ool00`00Ool00006Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00]oo`@000=oo`04001oogoo0007Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomo
o`000Woo00@007ooOomoo`800005Ool007ooOol00002Ool01000Oomoo`000goo0P000Woo00<007oo
00000`000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo0P0037oo00<0
07ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo
00<007ooOol017oo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000=oo`07001oo`00Ool007oo00001Woo00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P00
27oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Aoo`@000=oo`8000Ao
o`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol0AWoo00<007ooOol03goo0P004Woo
000ROol20011Ool20004Ool00`00Oomoo`0@Ool3000@Ool0029oof<000aoo`008Woo0P0000Eoo`00
000007oo00800003Ool0000000<00004Ool00000Ool300001Goo00000000Ool00`0000=oo`000000
0`000Woo100000=oo`00Ool00`000goo1P0000=oo`0000000Woo00d007ooOomoo`00Ool007oo001o
o`00Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0000<Ool0
029oo`@00004Ool00000Ool5000017oo000007oo0`0000Eoo`00000007oo00<0009oo`<0009oo`@0
0003Ool007oo00@00003Ool0000000<00004Ool00000Ool200000goo001oo`030002Ool00`00Ool0
0002Ool00`00Oomoo`0UOol0029oo`03001oogoo03Ioo`03001oogoo0080009oo`<0009oo`03001o
o`0002Moo`008Woo0P00>Woo0P001goo00<007oo00009goo000ROol20013Ool2000XOol000]oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo04=oo`03001oogoo02Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;
Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=o
o`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
0Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000
Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool0
1P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`00
8Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool0
00Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`80
00=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo
00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@0
07ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003
Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo
0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Oolj000_Ool002Qoo`03
001oogoo03Ioo`<002eoo`00:7oo00<007ooOol0>7oo1000:Woo000;Ool20004Ool00`00Oomoo`03
Ool20004Ool20003Ool30003Ool00`00Oomoo`0kOol2000YOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00?goo0`009Woo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00@Goo0`0097oo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool2
0007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool60002Ool20004Ool20003Ool5
0002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo
00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Ool000000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06
001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001o
ogooOol00003Ool20002Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000
Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00
:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00<007ooOol00P0000Eo
o`00Oomoo`00009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol0
0`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001o
ogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`05001oogoo001oo`020002
Ool01000Oomoo`000Woo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomo
o`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P00
0goo0`0017oo0`000goo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`17Ool00`00
Oomoo`0LOol002Qoo`03001oogoo04Qoo`03001oogoo01]oo`00:7ooG@0037oo000XOol00`00Oomo
o`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`02000>Ool00`00
Oomoo`0:Ool002Qoo`03001oogoo04Yoo`8001Yoo`00:7oo00<007ooOol0Bgoo00<007ooOol067oo
000XOol00`00Oomoo`1<Ool00`00Oomoo`0GOol002Qoo`03001oogoo04aoo`8001Qoo`00:7oo00<0
07ooOol0CGoo00<007ooOol05Woo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003
Ool00`00Oomoo`1>Ool00`00Oomoo`0EOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0003Ool01000Oomoo`00D7oo0P005Woo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0005Ool01000Oomoo`00DGoo00<007ooOol057oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001AOol2000DOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo055oo`T000aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo
0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003
Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001o
ogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool0
1000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo
0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`80
00Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0
009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`00
0Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomo
o`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomo
o`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009o
o`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol0
0goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo
00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000
Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo
0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`80
00Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00H007ooOomoo`00Ool30003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool00`00Oomoo`0:Ool001aoo`03001oogoo03moo`<0031oo`0077oo0P00@Woo0`00;Woo000LOol0
0`00Oomoo`13Ool2000]Ool001aoo`03001oogoo04Eoo`8002]oo`0077oo0P00Agoo0`00:Goo000L
Ool00`00Oomoo`18Ool3000WOol001aoo`03001oogoo04Yoo`8002Ioo`0077oo0P00C7oo00<007oo
Ool097oo000LOol00`00Oomoo`1<Ool00`00Oomoo`0SOol001aoo`8004ioo`03001oogoo029oo`00
2goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0CGoo00<007ooOol08Woo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo04ioo`03001oogoo025oo`002Woo00@007oo
Ool000]oo`03001oogoo008004moo`80029oo`002Woo00@007ooOol000]oo`04001oogoo001AOol0
0`00Oomoo`0POol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1?Ool2000QOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool2001AOol00`00Oomoo`0OOol000]oo`8000Qoo`D0009oo`03
001oogoo055oo`03001oogoo01ioo`0077oo00<007ooOol0DWoo00<007ooOol07Goo000LOol2001C
Ool00`00Oomoo`0MOol001aoo`03001oogoo059oo`8001ioo`0077oo0P00E7oo00<007ooOol077oo
000LOol00`00Oomoo`1DOol00`00Oomoo`0KOol001aoo`03001oogoo05Aoo`8001aoo`0077oo0P00
EWoo00<007ooOol06Woo000FOol30003Ool00`00Oomoo`1FOol00`00Oomoo`0IOol001Moo`03001o
ogoo009oo`03001oogoo05Moo`03001oogoo01Qoo`005goo00<007ooOol00Woo0P00F7oo00<007oo
Ool067oo000GOol00`00Oomoo`02Ool00`00Oomoo`1GOol2000IOol001Moo`03001oogoo009oo`03
001oogoo05Qoo`03001oogoo01Moo`005Woo0P0017oo0P00FWoo00<007ooOol05Woo000GOol00`00
Oomoo`02Ool00`00Oomoo`1IOol00`00Oomoo`0FOol001aoo`03001oogoo05Uoo`8001Moo`0077oo
0P00Fgoo0P005Woo000LOol00`00Oomoo`1KOol00`00Oomoo`0DOol001aoo`8005eoo`<001=oo`00
77oo00<007ooOol0GWoo200037oo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009o
o`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo
000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03
001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(17201\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32115 m
.008 .31921 L
.012 .31698 L
.016 .31627 L
.02 .3172 L
.024 .31846 L
.028 .3198 L
.032 .32048 L
.036 .32042 L
.04 .3195 L
.044 .31807 L
.048 .31733 L
.052 .31747 L
.056 .31833 L
.06 .31948 L
.064 .3201 L
.068 .32 L
.072 .31916 L
.076 .31814 L
.08 .31774 L
.084 .31812 L
.088 .31904 L
.092 .31992 L
.096 .32021 L
.1 .31976 L
.104 .31868 L
.108 .31763 L
.112 .31738 L
.116 .31813 L
.12 .31946 L
.124 .32053 L
.128 .32083 L
.132 .32024 L
.136 .31904 L
.14 .31776 L
.144 .31709 L
.148 .31749 L
.152 .31874 L
.156 .32004 L
.16 .32066 L
.164 .32052 L
.168 .31997 L
.172 .31928 L
.176 .3186 L
.18 .31815 L
.184 .31816 L
.188 .31856 L
.192 .31891 L
.196 .31901 L
.2 .31918 L
Mistroke
.204 .31978 L
.208 .32063 L
.212 .32103 L
.216 .32053 L
.22 .31936 L
.224 .31816 L
.228 .3173 L
.232 .31692 L
.236 .31727 L
.24 .31861 L
.244 .32066 L
.248 .32241 L
.252 .32282 L
.256 .32169 L
.26 .31977 L
.264 .31801 L
.268 .31687 L
.272 .31636 L
.276 .31657 L
.28 .3177 L
.284 .31964 L
.288 .32169 L
.292 .32289 L
.296 .32276 L
.3 .3216 L
.304 .32012 L
.308 .31878 L
.312 .31762 L
.316 .31663 L
.32 .31612 L
.324 .31664 L
.328 .31842 L
.332 .32088 L
.336 .32282 L
.34 .32327 L
.344 .32229 L
.348 .3208 L
.352 .31973 L
.356 .31917 L
.36 .3185 L
.364 .31744 L
.368 .31658 L
.372 .31697 L
.376 .3188 L
.38 .32091 L
.384 .32173 L
.388 .32089 L
.392 .31969 L
.396 .31976 L
.4 .32128 L
Mistroke
.404 .32258 L
.408 .32191 L
.412 .3194 L
.416 .31721 L
.42 .31738 L
.424 .31967 L
.428 .32155 L
.432 .32068 L
.436 .31739 L
.44 .31464 L
.444 .31529 L
.448 .31934 L
.452 .32375 L
.456 .32518 L
.46 .32307 L
.464 .32002 L
.468 .31931 L
.472 .32175 L
.476 .32489 L
.48 .32521 L
.484 .32136 L
.488 .31545 L
.492 .3113 L
.496 .31139 L
.5 .31509 L
.504 .3194 L
.508 .32159 L
.512 .32114 L
.516 .31971 L
.52 .31946 L
.524 .32128 L
.528 .32431 L
.532 .32684 L
.536 .32761 L
.54 .32634 L
.544 .32353 L
.548 .31995 L
.552 .31649 L
.556 .3142 L
.56 .3141 L
.564 .31651 L
.568 .32038 L
.572 .32342 L
.576 .32329 L
.58 .31931 L
.584 .31337 L
.588 .30915 L
.592 .30986 L
.596 .31596 L
.6 .32449 L
Mistroke
.604 .33061 L
.608 .33054 L
.612 .32399 L
.616 .31453 L
.62 .30761 L
.624 .30745 L
.628 .31469 L
.632 .32612 L
.636 .33654 L
.64 .34156 L
.644 .3397 L
.648 .33276 L
.652 .32449 L
.656 .31841 L
.66 .31625 L
.664 .31758 L
.668 .32076 L
.672 .32419 L
.676 .32729 L
.68 .33032 L
.684 .3336 L
.688 .33658 L
.692 .33764 L
.696 .33481 L
.7 .32704 L
.704 .31528 L
.708 .30264 L
.712 .29333 L
.716 .29107 L
.72 .29743 L
.724 .31115 L
.728 .32853 L
.732 .34481 L
.736 .35587 L
.74 .35959 L
.744 .35628 L
.748 .34819 L
.752 .33828 L
.756 .3289 L
.76 .32083 L
.764 .31317 L
.768 .30398 L
.772 .29133 L
.776 .27436 L
.78 .2538 L
.784 .23186 L
.788 .21153 L
.792 .19563 L
.796 .18593 L
.8 .18258 L
Mistroke
.804 .18412 L
.808 .18793 L
.812 .19107 L
.816 .1911 L
.82 .18677 L
.824 .17828 L
.828 .16711 L
.832 .15556 L
.836 .14608 L
.84 .14063 L
.844 .14024 L
.848 .14481 L
.852 .15316 L
.856 .16336 L
.86 .17312 L
.864 .18033 L
.868 .18343 L
.872 .18163 L
.876 .175 L
.88 .16438 L
.884 .15116 L
.888 .13708 L
.892 .1239 L
.896 .1132 L
.9 .10615 L
.904 .10346 L
.908 .10537 L
.912 .11167 L
.916 .12183 L
.92 .13507 L
.924 .15048 L
.928 .16712 L
.932 .18416 L
.936 .20088 L
.94 .21672 L
.944 .23126 L
.948 .24424 L
.952 .25555 L
.956 .26519 L
.96 .27325 L
.964 .27986 L
.968 .28517 L
.972 .28937 L
.976 .29263 L
.98 .29512 L
.984 .297 L
.988 .29838 L
.992 .29934 L
.996 .29998 L
1 .30038 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14663 m
.008 .147 L
.012 .14703 L
.016 .14684 L
.02 .14682 L
.024 .14694 L
.028 .14692 L
.032 .1469 L
.036 .1469 L
.04 .14693 L
.044 .14691 L
.048 .1469 L
.052 .14689 L
.056 .1469 L
.06 .1469 L
.064 .14692 L
.068 .14691 L
.072 .14691 L
.076 .1469 L
.08 .1469 L
.084 .14689 L
.088 .1469 L
.092 .14691 L
.096 .14692 L
.1 .14692 L
.104 .14692 L
.108 .1469 L
.112 .14689 L
.116 .14688 L
.12 .14689 L
.124 .1469 L
.128 .14693 L
.132 .14694 L
.136 .14694 L
.14 .14692 L
.144 .1469 L
.148 .14688 L
.152 .14688 L
.156 .14688 L
.16 .14689 L
.164 .14692 L
.168 .14694 L
.172 .14694 L
.176 .14694 L
.18 .14692 L
.184 .14691 L
.188 .14689 L
.192 .14687 L
.196 .14686 L
.2 .14687 L
Mistroke
.204 .1469 L
.208 .14693 L
.212 .14695 L
.216 .14696 L
.22 .14697 L
.224 .14696 L
.228 .14692 L
.232 .14686 L
.236 .14682 L
.24 .14682 L
.244 .14685 L
.248 .1469 L
.252 .14694 L
.256 .14699 L
.26 .14702 L
.264 .14702 L
.268 .14698 L
.272 .1469 L
.276 .14683 L
.28 .14679 L
.284 .14679 L
.288 .14682 L
.292 .14686 L
.296 .14693 L
.3 .14701 L
.304 .14708 L
.308 .14709 L
.312 .14704 L
.316 .14695 L
.32 .14685 L
.324 .14678 L
.328 .14676 L
.332 .14675 L
.336 .14678 L
.34 .14684 L
.344 .14694 L
.348 .14706 L
.352 .14713 L
.356 .14713 L
.36 .14706 L
.364 .14697 L
.368 .1469 L
.372 .14686 L
.376 .14682 L
.38 .14675 L
.384 .1467 L
.388 .14671 L
.392 .14681 L
.396 .14695 L
.4 .14705 L
Mistroke
.404 .14707 L
.408 .14704 L
.412 .14704 L
.416 .1471 L
.42 .14717 L
.424 .14715 L
.428 .147 L
.432 .1468 L
.436 .14666 L
.44 .14663 L
.444 .14667 L
.448 .1467 L
.452 .14666 L
.456 .14661 L
.46 .14666 L
.464 .14689 L
.468 .14723 L
.472 .14752 L
.476 .14764 L
.48 .14756 L
.484 .14739 L
.488 .14722 L
.492 .1471 L
.496 .14697 L
.5 .14675 L
.504 .14642 L
.508 .14606 L
.512 .14582 L
.516 .14581 L
.52 .14604 L
.524 .14643 L
.528 .14686 L
.532 .14724 L
.536 .14752 L
.54 .14772 L
.544 .14787 L
.548 .148 L
.552 .14813 L
.556 .14821 L
.56 .14818 L
.564 .14799 L
.568 .14759 L
.572 .14705 L
.576 .14648 L
.58 .14602 L
.584 .14578 L
.588 .14575 L
.592 .14578 L
.596 .14569 L
.6 .14535 L
Mistroke
.604 .14479 L
.608 .14418 L
.612 .14378 L
.616 .14379 L
.62 .14426 L
.624 .14503 L
.628 .1459 L
.632 .14667 L
.636 .14727 L
.64 .14783 L
.644 .14853 L
.648 .14958 L
.652 .15105 L
.656 .1529 L
.66 .15498 L
.664 .15712 L
.668 .15917 L
.672 .16103 L
.676 .16268 L
.68 .16411 L
.684 .16532 L
.688 .16636 L
.692 .16732 L
.696 .16834 L
.7 .16961 L
.704 .1713 L
.708 .17349 L
.712 .17614 L
.716 .17908 L
.72 .18202 L
.724 .18469 L
.728 .1869 L
.732 .18858 L
.736 .18982 L
.74 .19082 L
.744 .1918 L
.748 .19293 L
.752 .19432 L
.756 .19598 L
.76 .19789 L
.764 .20002 L
.768 .20238 L
.772 .20503 L
.776 .20809 L
.78 .21167 L
.784 .21583 L
.788 .22055 L
.792 .22574 L
.796 .23122 L
.8 .23679 L
Mistroke
.804 .24227 L
.808 .24757 L
.812 .25265 L
.816 .25759 L
.82 .26251 L
.824 .26753 L
.828 .27278 L
.832 .27831 L
.836 .28409 L
.84 .29004 L
.844 .296 L
.848 .30185 L
.852 .30743 L
.856 .31269 L
.86 .31759 L
.864 .32218 L
.868 .32658 L
.872 .33094 L
.876 .33538 L
.88 .34007 L
.884 .34509 L
.888 .35051 L
.892 .35631 L
.896 .36244 L
.9 .36881 L
.904 .3753 L
.908 .38175 L
.912 .38804 L
.916 .39404 L
.92 .39964 L
.924 .40476 L
.928 .40937 L
.932 .41341 L
.936 .41693 L
.94 .4199 L
.944 .42241 L
.948 .42446 L
.952 .42614 L
.956 .42746 L
.96 .42853 L
.964 .42934 L
.968 .42998 L
.972 .43045 L
.976 .43083 L
.98 .43109 L
.984 .43131 L
.988 .43145 L
.992 .43158 L
.996 .43165 L
1 .43174 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16322 L
.012 .16123 L
.016 .16052 L
.02 .16121 L
.024 .16143 L
.028 .16123 L
.032 .16112 L
.036 .1612 L
.04 .16121 L
.044 .16121 L
.048 .16119 L
.052 .16122 L
.056 .16122 L
.06 .16123 L
.064 .1612 L
.068 .1612 L
.072 .16118 L
.076 .16119 L
.08 .1612 L
.084 .16122 L
.088 .16122 L
.092 .16123 L
.096 .16122 L
.1 .16121 L
.104 .16119 L
.108 .16119 L
.112 .16119 L
.116 .1612 L
.12 .1612 L
.124 .16121 L
.128 .16122 L
.132 .16123 L
.136 .16122 L
.14 .16121 L
.144 .1612 L
.148 .1612 L
.152 .16118 L
.156 .16118 L
.16 .16118 L
.164 .1612 L
.168 .16123 L
.172 .16125 L
.176 .16125 L
.18 .16124 L
.184 .16122 L
.188 .16119 L
.192 .16115 L
.196 .16113 L
.2 .16115 L
Mistroke
.204 .16119 L
.208 .16124 L
.212 .16126 L
.216 .16127 L
.22 .16127 L
.224 .16125 L
.228 .1612 L
.232 .16114 L
.236 .1611 L
.24 .1611 L
.244 .16114 L
.248 .16119 L
.252 .16124 L
.256 .16129 L
.26 .16134 L
.264 .16134 L
.268 .16129 L
.272 .1612 L
.276 .1611 L
.28 .16105 L
.284 .16105 L
.288 .16108 L
.292 .16114 L
.296 .16123 L
.3 .16133 L
.304 .16141 L
.308 .16143 L
.312 .16136 L
.316 .16124 L
.32 .16112 L
.324 .16104 L
.328 .161 L
.332 .161 L
.336 .16103 L
.34 .16111 L
.344 .16123 L
.348 .16137 L
.352 .16147 L
.356 .16147 L
.36 .16138 L
.364 .16127 L
.368 .16118 L
.372 .16113 L
.376 .16107 L
.38 .16099 L
.384 .16092 L
.388 .16094 L
.392 .16107 L
.396 .16124 L
.4 .16136 L
Mistroke
.404 .16138 L
.408 .16135 L
.412 .16135 L
.416 .16144 L
.42 .16152 L
.424 .16148 L
.428 .1613 L
.432 .16104 L
.436 .16087 L
.44 .16084 L
.444 .1609 L
.448 .16093 L
.452 .16087 L
.456 .1608 L
.46 .16087 L
.464 .16116 L
.468 .16158 L
.472 .16195 L
.476 .16209 L
.48 .16199 L
.484 .16177 L
.488 .16156 L
.492 .16142 L
.496 .16126 L
.5 .16098 L
.504 .16056 L
.508 .16011 L
.512 .15981 L
.516 .1598 L
.52 .16009 L
.524 .16058 L
.528 .16112 L
.532 .16158 L
.536 .16193 L
.54 .16218 L
.544 .16237 L
.548 .16254 L
.552 .16268 L
.556 .16278 L
.56 .16275 L
.564 .1625 L
.568 .16202 L
.572 .16135 L
.576 .16063 L
.58 .16006 L
.584 .15976 L
.588 .15971 L
.592 .15975 L
.596 .15964 L
.6 .15922 L
Mistroke
.604 .15851 L
.608 .15776 L
.612 .15726 L
.616 .15728 L
.62 .15786 L
.624 .15882 L
.628 .1599 L
.632 .16085 L
.636 .16161 L
.64 .1623 L
.644 .16318 L
.648 .16448 L
.652 .16631 L
.656 .16861 L
.66 .17121 L
.664 .17387 L
.668 .17642 L
.672 .17874 L
.676 .18079 L
.68 .18256 L
.684 .18407 L
.688 .18536 L
.692 .18655 L
.696 .18782 L
.7 .1894 L
.704 .19149 L
.708 .19422 L
.712 .19752 L
.716 .20117 L
.72 .20482 L
.724 .20814 L
.728 .21088 L
.732 .21297 L
.736 .21451 L
.74 .21575 L
.744 .21695 L
.748 .21835 L
.752 .22007 L
.756 .22213 L
.76 .22451 L
.764 .22715 L
.768 .23007 L
.772 .23337 L
.776 .23717 L
.78 .24161 L
.784 .24678 L
.788 .25266 L
.792 .2591 L
.796 .26591 L
.8 .27283 L
Mistroke
.804 .27965 L
.808 .28623 L
.812 .29254 L
.816 .29867 L
.82 .30477 L
.824 .31101 L
.828 .31753 L
.832 .32439 L
.836 .33156 L
.84 .33894 L
.844 .34634 L
.848 .35359 L
.852 .36052 L
.856 .36703 L
.86 .3731 L
.864 .37879 L
.868 .38423 L
.872 .38962 L
.876 .39512 L
.88 .40092 L
.884 .40714 L
.888 .41385 L
.892 .42103 L
.896 .42863 L
.9 .43652 L
.904 .44455 L
.908 .45254 L
.912 .46033 L
.916 .46775 L
.92 .47468 L
.924 .48101 L
.928 .48669 L
.932 .49168 L
.936 .496 L
.94 .49965 L
.944 .50271 L
.948 .5052 L
.952 .50723 L
.956 .50883 L
.96 .51009 L
.964 .51104 L
.968 .51178 L
.972 .51231 L
.976 .51272 L
.98 .51297 L
.984 .51318 L
.988 .51328 L
.992 .51337 L
.996 .51337 L
1 .5134 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008005Ioo`03001oogoo01Aoo`002goo0P002Woo0P000goo0`000goo00<0
07ooOol0E7oo0`005Goo000ROol2001EOol00`00Ool0000EOol000]oo`8000Aoo`03001oogoo00=o
o`80009oo`D0009oo`03001oogoo05Aoo`03001oo`0001Eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`000Woo0P00D7oo00<007ooOol00Woo00@007ooOol001Aoo`000goo1@00
0Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001@Ool20002Ool01@00Oomo
ogoo000057oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`05001oogooOol0001@Ool01P00
Oomoo`00Ool000=oo`03001oogoo019oo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00<007ooOol00P00Cgoo00<007ooOol00P001Goo00<007ooOol04Goo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool00`00Oomoo`02001<Ool00`00Ool00003Ool20005Ool00`00Oomoo`0A
Ool000]oo`8000Yoo`8000=oo`<000=oo`03001oogoo04Yoo`@000Yoo`03001oogoo015oo`002goo
0P0017oo00<007ooOol00goo0P000goo0`000goo0P00Bgoo00<007ooOol02goo00<007ooOol04Goo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000eoo`<000Aoo`8000Mo
o`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000=oo`D000=oo`8000Aoo`8000Aoo`D0009o
o`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`0;Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01@00Oomoogoo
00000Woo00<007ooOol00P0000Eoo`00Oomoo`00009oo`03001oogoo009oo`06001oo`00001oo`00
0goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00<0
07ooOol00Woo0P0000Eoo`00Oomoo`00009oo`03001oogoo00=oo`8000Ioo`04001oogoo0002Ool0
0`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`04001oogooOol200001Goo001o
ogoo00000Woo00<007ooOol017oo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;Ool40003Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`06001o
ogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo0P00
37oo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo
0P000goo00<007ooOol017oo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`008Woo0P0037oo1@00
0goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000=o
o`<000Aoo`8000Eoo`<00003Ool0000000@000=oo`8000Ioo`008Woo00<007ooOol0BGoo00<007oo
Ool03goo00<007ooOol03Woo000ROol20014Ool00`00Oomoo`02Ool00`00Oomoo`0AOol2000>Ool0
029oof<000aoo`008Woo0`0000=oo`0000003`0000Eoo`00000007oo0080009oo`<0009oo`<00006
Ool007oo001oo`000goo0`0000Aoo`00Oomoo`800003Ool0000000@00004Ool000000002Ool30002
Ool20002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0000<Ool0029o
o`800004Ool00000Ool2000017oo000007oo0P0000Aoo`000000009oo`<00003Ool00000009oo`<0
0004Ool000000002Ool600000goo0000000200000goo0000000700001Woo000007oo001oo`<00005
Ool007ooOol00002Ool00`00Oomoo`0ROol0029oo`03001oogoo03Qoo`03001oogoo0080009oo`<0
009oo`03001oo`0002Eoo`008Woo0P00?7oo00<007ooOol01Woo00<007oo00009Goo000ROol20016
Ool2000UOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo
000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo
00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008
Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eo
o`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool0
00Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007oo
Ool000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]
Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yo
o`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`00
8Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool2
0003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ooll000]Ool002Qo
o`03001oogoo03Qoo`<002]oo`00:7oo00<007ooOol0>goo0`00:7oo000;Ool20004Ool00`00Oomo
o`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0nOol2000VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00@Goo10008goo0003Ool50002Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00A7oo0P008Woo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004
Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50002Ool30004Ool20003
Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol0
07oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04
001oogoo0002Ool00`00Oomoo`040002Ool01000Oomoo`000goo00H007ooOol007oo0003Ool01000
Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol0
0004Ool01000Ool000000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03
001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo
00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=o
o`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool200001Goo001oogoo
00000Woo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00
Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool0
0`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool200001Goo001oogoo00000Woo
00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008
Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P000Woo
00@007oo000000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0BWoo00<007ooOol06Goo
000XOol00`00Oomoo`1:Ool2000JOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol0
47oo00<007ooOol03goo00<007ooOol03goo00<007ooOol00goo00<007ooOol02Woo00<007ooOol0
2Woo000XOol00`00Oomoo`1<Ool2000HOol002Qoo`03001oogoo04eoo`8001Moo`00:7oo00<007oo
Ool0CWoo0P005Woo000XOol00`00Oomoo`1?Ool00`00Oomoo`0DOol002Qoo`03001oogoo04moo`80
01Eoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0D7oo0P00
57oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol0
05=oo`03001oogoo019oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOol005Aoo`03001oogoo015oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol00P00Dgoo0P004Woo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`05001oogoo001oo`040003Ool00`00Oomoo`1DOol6000<Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009o
o`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0
IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogoo
Ool4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;
Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol0
0P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo
1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool2
0005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool0
01aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009o
o`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo1000
0goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Oomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001o
ogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03
001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yo
o`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool2
0006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000L
OomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool300000goo001oo`03Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001ao
o`03001oogoo049oo`8002ioo`0077oo0P00AGoo0`00:goo000LOol00`00Oomoo`16Ool2000ZOol0
01aoo`03001oogoo04Qoo`03001oogoo02Moo`0077oo0P00BWoo0`009Woo000LOol00`00Oomoo`1;
Ool3000TOol001aoo`03001oogoo04eoo`03001oogoo029oo`0077oo0P00Cgoo00<007ooOol08Goo
000LOol00`00Oomoo`1?Ool00`00Oomoo`0POol001aoo`80051oo`03001oogoo021oo`002goo0P00
17oo00<007ooOol00Woo0`000goo00<007ooOol0D7oo00<007ooOol07goo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo051oo`80021oo`002Woo00@007ooOol000]oo`03001o
ogoo0080059oo`8001moo`002Woo00@007ooOol000]oo`04001oogoo001DOol00`00Oomoo`0MOol0
00Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1BOol2000NOol000Yoo`04001oogoo0007Ool0
0`00Oomoo`04Ool2001DOol00`00Oomoo`0LOol000]oo`8000Qoo`D0009oo`03001oogoo05Aoo`03
001oogoo01]oo`0077oo00<007ooOol0E7oo00<007ooOol06goo000LOol2001FOol00`00Oomoo`0J
Ool001aoo`03001oogoo05Eoo`03001oogoo01Yoo`0077oo0P00Egoo00<007ooOol06Goo000LOol0
0`00Oomoo`1GOol00`00Oomoo`0HOol001aoo`03001oogoo05Moo`8001Uoo`0077oo0P00FGoo00<0
07ooOol05goo000FOol30003Ool00`00Oomoo`1IOol00`00Oomoo`0FOol001Moo`03001oogoo009o
o`03001oogoo05Uoo`03001oogoo01Ioo`005goo00<007ooOol00Woo0P00Fgoo00<007ooOol05Goo
000GOol00`00Oomoo`02Ool00`00Oomoo`1JOol00`00Oomoo`0EOol001Moo`03001oogoo009oo`03
001oogoo05]oo`03001oogoo01Aoo`005Woo0P0017oo0P00G7oo00<007ooOol057oo000GOol00`00
Oomoo`02Ool00`00Oomoo`1LOol00`00Oomoo`0COol001aoo`03001oogoo05aoo`8001Aoo`0077oo
0P00GWoo0P004goo000LOol00`00Oomoo`1NOol00`00Oomoo`0AOol001aoo`80061oo`<0011oo`00
77oo00<007ooOol0HWoo100037oo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009o
o`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo
000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03
001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(17368\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32158 m
.008 .32121 L
.012 .31998 L
.016 .31756 L
.02 .31588 L
.024 .31577 L
.028 .31733 L
.032 .31971 L
.036 .32133 L
.04 .32171 L
.044 .32046 L
.048 .31821 L
.052 .31644 L
.056 .31587 L
.06 .31695 L
.064 .31908 L
.068 .32098 L
.072 .32175 L
.076 .32087 L
.08 .31896 L
.084 .31714 L
.088 .31626 L
.092 .31682 L
.096 .31847 L
.1 .32028 L
.104 .32128 L
.108 .3209 L
.112 .31957 L
.116 .31813 L
.12 .3173 L
.124 .31741 L
.128 .31826 L
.132 .31939 L
.136 .32015 L
.14 .32011 L
.144 .31945 L
.148 .31877 L
.152 .31859 L
.156 .31888 L
.16 .31922 L
.164 .31934 L
.168 .31921 L
.172 .31888 L
.176 .31845 L
.18 .31825 L
.184 .31868 L
.188 .31969 L
.192 .32061 L
.196 .32074 L
.2 .32001 L
Mistroke
.204 .31894 L
.208 .31806 L
.212 .31757 L
.216 .31755 L
.22 .3182 L
.224 .31949 L
.228 .32084 L
.232 .32147 L
.236 .32107 L
.24 .32008 L
.244 .31908 L
.248 .31828 L
.252 .31759 L
.256 .31715 L
.26 .31744 L
.264 .31866 L
.268 .32034 L
.272 .32162 L
.276 .32199 L
.28 .32157 L
.284 .3207 L
.288 .31946 L
.292 .31792 L
.296 .31646 L
.3 .31589 L
.304 .31679 L
.308 .31892 L
.312 .32125 L
.316 .32271 L
.32 .32288 L
.324 .32207 L
.328 .32083 L
.332 .31945 L
.336 .31799 L
.34 .31667 L
.344 .31601 L
.348 .31659 L
.352 .31838 L
.356 .32054 L
.36 .32198 L
.364 .32224 L
.368 .32179 L
.372 .3214 L
.376 .3212 L
.38 .32052 L
.384 .31885 L
.388 .31678 L
.392 .31585 L
.396 .31702 L
.4 .31953 L
Mistroke
.404 .32134 L
.408 .3211 L
.412 .31954 L
.416 .31876 L
.42 .32006 L
.424 .32241 L
.428 .32338 L
.432 .32164 L
.436 .31853 L
.44 .31689 L
.444 .31825 L
.448 .32114 L
.452 .32242 L
.456 .32034 L
.46 .31638 L
.464 .31405 L
.468 .31563 L
.472 .32003 L
.476 .32373 L
.48 .32401 L
.484 .32138 L
.488 .31896 L
.492 .31954 L
.496 .32293 L
.5 .32611 L
.504 .32588 L
.508 .32163 L
.512 .31588 L
.516 .3122 L
.52 .31248 L
.524 .3157 L
.528 .31915 L
.532 .32063 L
.536 .31998 L
.54 .31875 L
.544 .31871 L
.548 .32048 L
.552 .32337 L
.556 .32604 L
.56 .32743 L
.564 .32703 L
.568 .32484 L
.572 .32126 L
.576 .31722 L
.58 .31423 L
.584 .31382 L
.588 .31649 L
.592 .32101 L
.596 .3246 L
.6 .32454 L
Mistroke
.604 .3201 L
.608 .31341 L
.612 .30853 L
.616 .30896 L
.62 .31528 L
.624 .32437 L
.628 .33115 L
.632 .33154 L
.636 .32504 L
.64 .31512 L
.644 .30729 L
.648 .30598 L
.652 .31218 L
.656 .32302 L
.66 .33353 L
.664 .33932 L
.668 .33869 L
.672 .33298 L
.676 .32544 L
.68 .31931 L
.684 .31628 L
.688 .31622 L
.692 .31793 L
.696 .32031 L
.7 .32307 L
.704 .32659 L
.708 .3311 L
.712 .3358 L
.716 .33874 L
.72 .33753 L
.724 .3307 L
.728 .3188 L
.732 .30476 L
.736 .29294 L
.74 .28755 L
.744 .29092 L
.748 .30253 L
.752 .31924 L
.756 .33641 L
.76 .34965 L
.764 .35621 L
.768 .35575 L
.772 .35 L
.776 .34171 L
.78 .33335 L
.784 .32602 L
.788 .31915 L
.792 .31099 L
.796 .29951 L
.8 .28352 L
Mistroke
.804 .26328 L
.808 .24066 L
.812 .21856 L
.816 .20002 L
.82 .1873 L
.824 .18118 L
.828 .18076 L
.832 .18377 L
.836 .18729 L
.84 .18857 L
.844 .18585 L
.848 .17872 L
.852 .16817 L
.856 .1562 L
.86 .14528 L
.864 .13765 L
.868 .1348 L
.872 .13717 L
.876 .14406 L
.88 .15382 L
.884 .16428 L
.888 .17321 L
.892 .17872 L
.896 .17961 L
.9 .17549 L
.904 .16678 L
.908 .15461 L
.912 .14057 L
.916 .12644 L
.92 .11392 L
.924 .10443 L
.928 .09895 L
.932 .09803 L
.936 .10172 L
.94 .10967 L
.944 .12124 L
.948 .13559 L
.952 .15178 L
.956 .16892 L
.96 .18621 L
.964 .20295 L
.968 .21861 L
.972 .23282 L
.976 .24535 L
.98 .25611 L
.984 .26512 L
.988 .27238 L
.992 .27806 L
.996 .2822 L
1 .28503 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14441 m
.008 .14728 L
.012 .1482 L
.016 .14729 L
.02 .14695 L
.024 .14728 L
.028 .14736 L
.032 .14727 L
.036 .14722 L
.04 .14727 L
.044 .14728 L
.048 .14729 L
.052 .14727 L
.056 .14728 L
.06 .14726 L
.064 .14726 L
.068 .14726 L
.072 .14727 L
.076 .14728 L
.08 .14729 L
.084 .14728 L
.088 .14728 L
.092 .14726 L
.096 .14726 L
.1 .14725 L
.104 .14727 L
.108 .14727 L
.112 .14729 L
.116 .14729 L
.12 .14728 L
.124 .14727 L
.128 .14727 L
.132 .14726 L
.136 .14726 L
.14 .14726 L
.144 .14727 L
.148 .14727 L
.152 .14728 L
.156 .14729 L
.16 .14729 L
.164 .14729 L
.168 .14728 L
.172 .14727 L
.176 .14725 L
.18 .14724 L
.184 .14725 L
.188 .14727 L
.192 .14729 L
.196 .1473 L
.2 .14731 L
Mistroke
.204 .14731 L
.208 .14729 L
.212 .14726 L
.216 .14723 L
.22 .14722 L
.224 .14723 L
.228 .14726 L
.232 .14728 L
.236 .14731 L
.24 .14733 L
.244 .14735 L
.248 .14733 L
.252 .14728 L
.256 .14724 L
.26 .14721 L
.264 .1472 L
.268 .14721 L
.272 .14723 L
.276 .14728 L
.28 .14734 L
.284 .14739 L
.288 .1474 L
.292 .14736 L
.296 .14729 L
.3 .14723 L
.304 .14718 L
.308 .14715 L
.312 .14715 L
.316 .14719 L
.32 .14727 L
.324 .14736 L
.328 .14744 L
.332 .14746 L
.336 .14742 L
.34 .14734 L
.344 .14726 L
.348 .1472 L
.352 .14714 L
.356 .14711 L
.36 .1471 L
.364 .14716 L
.368 .14728 L
.372 .1474 L
.376 .14748 L
.38 .14748 L
.384 .14743 L
.388 .14737 L
.392 .14733 L
.396 .14729 L
.4 .14721 L
Mistroke
.404 .14711 L
.408 .14704 L
.412 .14707 L
.416 .14717 L
.42 .1473 L
.424 .14736 L
.428 .14736 L
.432 .14735 L
.436 .14741 L
.44 .14752 L
.444 .14759 L
.448 .14754 L
.452 .14738 L
.456 .1472 L
.46 .1471 L
.464 .14709 L
.468 .14711 L
.472 .14706 L
.476 .14695 L
.48 .14687 L
.484 .14694 L
.488 .14719 L
.492 .14753 L
.496 .1478 L
.5 .14792 L
.504 .14788 L
.508 .14779 L
.512 .1477 L
.516 .14764 L
.52 .14752 L
.524 .14728 L
.528 .14691 L
.532 .14652 L
.536 .14624 L
.54 .14616 L
.544 .14631 L
.548 .14663 L
.552 .14701 L
.556 .14738 L
.56 .14768 L
.564 .14791 L
.568 .1481 L
.572 .14827 L
.576 .14845 L
.58 .1486 L
.584 .14866 L
.588 .14854 L
.592 .1482 L
.596 .14767 L
.6 .14708 L
Mistroke
.604 .1466 L
.608 .14635 L
.612 .14631 L
.616 .14635 L
.62 .14627 L
.624 .14594 L
.628 .14535 L
.632 .14469 L
.636 .14421 L
.64 .1441 L
.644 .14443 L
.648 .14508 L
.652 .14584 L
.656 .14653 L
.66 .14708 L
.664 .14756 L
.668 .14816 L
.672 .14907 L
.676 .15037 L
.68 .15205 L
.684 .15401 L
.688 .15609 L
.692 .15815 L
.696 .16011 L
.7 .16189 L
.704 .16345 L
.708 .16477 L
.712 .16587 L
.716 .1668 L
.72 .16771 L
.724 .16881 L
.728 .17028 L
.732 .17226 L
.736 .17474 L
.74 .17758 L
.744 .18054 L
.748 .18334 L
.752 .18573 L
.756 .18763 L
.76 .18907 L
.764 .19019 L
.768 .19121 L
.772 .1923 L
.776 .19359 L
.78 .1951 L
.784 .19684 L
.788 .19876 L
.792 .20088 L
.796 .20327 L
.8 .20602 L
Mistroke
.804 .20926 L
.808 .21309 L
.812 .2175 L
.816 .22244 L
.82 .22775 L
.824 .23323 L
.828 .23871 L
.832 .24404 L
.836 .24918 L
.84 .25414 L
.844 .25904 L
.848 .264 L
.852 .26914 L
.856 .27454 L
.86 .28021 L
.864 .28609 L
.868 .29207 L
.872 .29798 L
.876 .30371 L
.88 .30913 L
.884 .3142 L
.888 .31894 L
.892 .32342 L
.896 .32778 L
.9 .33216 L
.904 .3367 L
.908 .34152 L
.912 .3467 L
.916 .35227 L
.92 .35822 L
.924 .36445 L
.928 .37088 L
.932 .37735 L
.936 .38376 L
.94 .38994 L
.944 .39581 L
.948 .40124 L
.952 .4062 L
.956 .41061 L
.96 .41449 L
.964 .41783 L
.968 .42068 L
.972 .42304 L
.976 .42501 L
.98 .42659 L
.984 .4279 L
.988 .42892 L
.992 .42979 L
.996 .43045 L
1 .43106 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16112 L
.012 .1613 L
.016 .16122 L
.02 .16115 L
.024 .16118 L
.028 .16127 L
.032 .16123 L
.036 .16121 L
.04 .16119 L
.044 .1612 L
.048 .16119 L
.052 .16121 L
.056 .1612 L
.06 .16123 L
.064 .16122 L
.068 .16122 L
.072 .1612 L
.076 .1612 L
.08 .16119 L
.084 .16121 L
.088 .16121 L
.092 .16122 L
.096 .16121 L
.1 .1612 L
.104 .16119 L
.108 .16119 L
.112 .1612 L
.116 .16122 L
.12 .16123 L
.124 .16123 L
.128 .16122 L
.132 .1612 L
.136 .16118 L
.14 .16117 L
.144 .16118 L
.148 .1612 L
.152 .16123 L
.156 .16124 L
.16 .16124 L
.164 .16122 L
.168 .1612 L
.172 .16118 L
.176 .16117 L
.18 .16117 L
.184 .16118 L
.188 .16121 L
.192 .16123 L
.196 .16123 L
.2 .16124 L
Mistroke
.204 .16124 L
.208 .16122 L
.212 .16119 L
.216 .16116 L
.22 .16114 L
.224 .16115 L
.228 .16117 L
.232 .1612 L
.236 .16124 L
.24 .16128 L
.244 .16129 L
.248 .16127 L
.252 .16122 L
.256 .16115 L
.26 .16111 L
.264 .1611 L
.268 .16111 L
.272 .16115 L
.276 .16121 L
.28 .16128 L
.284 .16134 L
.288 .16135 L
.292 .1613 L
.296 .16121 L
.3 .16113 L
.304 .16108 L
.308 .16105 L
.312 .16105 L
.316 .16109 L
.32 .16118 L
.324 .1613 L
.328 .1614 L
.332 .16142 L
.336 .16137 L
.34 .16128 L
.344 .16118 L
.348 .16109 L
.352 .16102 L
.356 .16098 L
.36 .16098 L
.364 .16105 L
.368 .1612 L
.372 .16135 L
.376 .16144 L
.38 .16144 L
.384 .16138 L
.388 .16131 L
.392 .16126 L
.396 .16121 L
.4 .1611 L
Mistroke
.404 .16097 L
.408 .16089 L
.412 .16092 L
.416 .16106 L
.42 .16122 L
.424 .16129 L
.428 .16128 L
.432 .16128 L
.436 .16135 L
.44 .16148 L
.444 .16157 L
.448 .16151 L
.452 .16131 L
.456 .16108 L
.46 .16095 L
.464 .16094 L
.468 .16097 L
.472 .16092 L
.476 .16078 L
.48 .16067 L
.484 .16075 L
.488 .16106 L
.492 .16149 L
.496 .16184 L
.5 .16198 L
.504 .16193 L
.508 .1618 L
.512 .1617 L
.516 .16162 L
.52 .16148 L
.524 .16118 L
.528 .16072 L
.532 .16023 L
.536 .15987 L
.54 .15977 L
.544 .15997 L
.548 .16036 L
.552 .16084 L
.556 .1613 L
.56 .16167 L
.564 .16196 L
.568 .16219 L
.572 .16241 L
.576 .16263 L
.58 .16281 L
.584 .16288 L
.588 .16273 L
.592 .16231 L
.596 .16165 L
.6 .16091 L
Mistroke
.604 .16031 L
.608 .15999 L
.612 .15994 L
.616 .16 L
.62 .1599 L
.624 .15948 L
.628 .15876 L
.632 .15793 L
.636 .15732 L
.64 .15719 L
.644 .1576 L
.648 .15841 L
.652 .15936 L
.656 .16022 L
.66 .1609 L
.664 .1615 L
.668 .16225 L
.672 .16338 L
.676 .165 L
.68 .1671 L
.684 .16953 L
.688 .17212 L
.692 .17469 L
.696 .17712 L
.7 .17934 L
.704 .18128 L
.708 .18292 L
.712 .18428 L
.716 .18544 L
.72 .18658 L
.724 .18793 L
.728 .18976 L
.732 .19222 L
.736 .19531 L
.74 .19885 L
.744 .20253 L
.748 .206 L
.752 .20897 L
.756 .21133 L
.76 .21311 L
.764 .2145 L
.768 .21576 L
.772 .21711 L
.776 .2187 L
.78 .22058 L
.784 .22273 L
.788 .22511 L
.792 .22775 L
.796 .23071 L
.8 .23413 L
Mistroke
.804 .23816 L
.808 .24291 L
.812 .2484 L
.816 .25453 L
.82 .26113 L
.824 .26795 L
.828 .27476 L
.832 .28138 L
.836 .28776 L
.84 .29392 L
.844 .3 L
.848 .30615 L
.852 .31253 L
.856 .31924 L
.86 .32628 L
.864 .33358 L
.868 .34099 L
.872 .34834 L
.876 .35543 L
.88 .36215 L
.884 .36844 L
.888 .37431 L
.892 .37986 L
.896 .38525 L
.9 .39066 L
.904 .39628 L
.908 .40225 L
.912 .40867 L
.916 .41557 L
.92 .42293 L
.924 .43065 L
.928 .43861 L
.932 .44663 L
.936 .45457 L
.94 .46222 L
.944 .46947 L
.948 .47618 L
.952 .4823 L
.956 .48773 L
.96 .49251 L
.964 .49659 L
.968 .50006 L
.972 .50292 L
.976 .50527 L
.98 .50712 L
.984 .5086 L
.988 .50969 L
.992 .51053 L
.996 .51106 L
1 .51144 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008005Uoo`03001oogoo015oo`002goo0P002Woo0P000goo0`000goo00<0
07ooOol0Egoo00<007oo00004Woo000ROol2001HOol00`00Ool0000BOol000]oo`8000Aoo`03001o
ogoo00=oo`80009oo`D0009oo`03001oogoo05Ioo`04001oogoo000BOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol0009oo`80059oo`8000=oo`04001oogoo000BOol000=oo`D0
009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00DWoo00<007oo00000Woo
00D007ooOomoo`00015oo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01@00Oomoogoo0000
Dgoo00<007oo00000Woo00D007ooOomoo`00015oo`002Woo00@007ooOol000Qoo`06001oogoo001o
o`000goo00<007ooOol00P00DGoo00@007ooOomoo`8000Aoo`03001oogoo00moo`002Woo00@007oo
Ool000Qoo`06001oogoo001oo`000goo00<007ooOol00P00CWoo0P0000=oo`00Ool00Woo00<007oo
Ool00goo00<007ooOol03goo000;Ool2000:Ool20003Ool30003Ool00`00Oomoo`1=Ool00`00Ool0
000;Ool00`00Oomoo`0>Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8004ioo`03
001oogoo00]oo`03001oogoo00ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2000=Ool30004Ool20007Ool30004Ool20004Ool20005Ool30003Ool30004Ool20003Ool5
0003Ool2000017oo001oogoo0P0017oo1P0000Aoo`00000000Aoo`8000Ioo`000goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo0000
0Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007oo
Oomoo`0000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0002Ool00`00Oomoo`02Ool00`00Oomoo`030003Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`04001o
ogoo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000Aoo`03001oogoo00]oo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`000Woo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`00
1Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`00
1Woo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomo
o`000Woo00D007ooOomoo`00009oo`04001oo`000002Ool01000Oomoo`000goo00H007ooOomoo`00
Ool20005Ool01000Oomoo`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004
Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo
0P001Woo000ROol00`00Oomoo`15Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool2000<Ool0029oo`80
04Ioo`8000Aoo`03001oogoo01ioo`008WooH`0037oo000ROol00`00Ool0000400000goo00000004
00000goo0000000200001Goo00000000Ool0100000Eoo`00000007oo00<0009oo`800005Ool007oo
001oo`0400000goo0000000200001goo00000000Ool007oo00800003Ool007oo00<00004Ool00000
Ool20002Ool20003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo00Yoo`00
8Woo0P0000=oo`0000000Woo0P0000Aoo`00001oo`800003Ool007oo00<00005Ool00000001oo`03
0002Ool20002Ool300000goo0000000200000goo0000000500000goo001oo`03000017oo000007oo
0P0000Eoo`00Ool007oo00800004Ool007oo0003Ool00`00Oomoo`0OOol0029oo`03001oogoo03Yo
o`800004Ool000000002Ool30002Ool00`00Ool0000ROol0029oo`8004Qoo`<0029oo`008Woo0P00
BGoo00<007ooOol08Goo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Ao
o`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool0
0`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000
Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003
Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo
0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yo
o`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007oo
Ool00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;
Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2
001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomo
ogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool5
0002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo?`00
:Woo000XOol00`00Oomoo`0kOol3000XOol002Qoo`03001oogoo03eoo`@002Eoo`002goo0P0017oo
00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0@7oo0P0097oo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol004Aoo`<0025oo`000goo
1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol004Ioo`<0
01moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00
2goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0`00
0goo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05
001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol0009oo`800005Ool007ooOol00003Ool01P00Oomoo`00
Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00D007ooOomoo`0000Aoo`03001oogoo00800005Ool007ooOol00004Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=
Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04
001oo`000002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo
000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol0
0`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001o
ogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00
Oomoo`0200001Goo001oogoo00000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007oo
Ool02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`80
00=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0C7oo00<0
07ooOol05goo000XOol00`00Oomoo`1<Ool2000HOol002Qooed000aoo`00:7oo00<007ooOol03goo
00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol01Goo0P002Goo00<007oo
Ool02Woo000XOol00`00Oomoo`1?Ool00`00Oomoo`0DOol002Qoo`03001oogoo051oo`03001oogoo
01=oo`00:7oo00<007ooOol0DGoo00<007ooOol04Woo000XOol00`00Oomoo`1AOol2000COol002Qo
o`03001oogoo059oo`03001oogoo015oo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo
0`000goo00<007ooOol0Dgoo00<007ooOol047oo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`000goo00@007ooOol005Eoo`03001oogoo011oo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol005Ioo`80011oo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00EWoo0P003goo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1FOol4000<Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol0
00]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Io
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool0
1000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`00
2Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo
00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004
Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005
Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007oo
Ool0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06
001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<0
07ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001o
ogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool0
01aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo
00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0
01aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003
Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoogoo
0P000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo
Ool00Woo00<007ooOol02Woo000LOol00`00Oomoo`15Ool2000[Ool001aoo`8004Moo`@002Qoo`00
77oo00<007ooOol0BGoo0P009goo000LOol00`00Oomoo`1:Ool2000VOol001aoo`8004eoo`<002=o
o`0077oo00<007ooOol0CWoo0P008Woo000LOol00`00Oomoo`1@Ool00`00Oomoo`0OOol001aoo`80
059oo`03001oogoo01ioo`0077oo00<007ooOol0DWoo00<007ooOol07Goo000LOol2001COol00`00
Oomoo`0MOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo05=oo`03001oogoo01ao
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1COol2000MOol000Yoo`04
001oogoo000;Ool00`00Oomoo`02001EOol00`00Oomoo`0KOol000Yoo`04001oogoo000;Ool01000
Oomoo`00EWoo0P0077oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0EGoo00<007ooOol0
6Woo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Egoo00<007ooOol06Goo000;Ool20008
Ool50002Ool00`00Oomoo`1GOol00`00Oomoo`0HOol001aoo`03001oogoo05Moo`03001oogoo01Qo
o`0077oo0P00F7oo0P006Goo000LOol00`00Oomoo`1HOol00`00Oomoo`0GOol001aoo`8005Yoo`03
001oogoo01Ioo`0077oo00<007ooOol0FGoo0P005goo000LOol00`00Oomoo`1JOol00`00Oomoo`0E
Ool001aoo`8005aoo`03001oogoo01Aoo`005Woo0`000goo00<007ooOol0Fgoo00<007ooOol057oo
000GOol00`00Oomoo`02Ool00`00Oomoo`1LOol00`00Oomoo`0COol001Moo`03001oogoo009oo`80
05ioo`03001oogoo019oo`005goo00<007ooOol00Woo00<007ooOol0GGoo00<007ooOol04Woo000G
Ool00`00Oomoo`02Ool00`00Oomoo`1NOol00`00Oomoo`0AOol001Ioo`8000Aoo`8005moo`03001o
ogoo015oo`005goo00<007ooOol00Woo00<007ooOol0Ggoo00<007ooOol047oo000LOol00`00Oomo
o`1OOol2000AOol001aoo`80065oo`03001oogoo00moo`0077oo00<007ooOol0H7oo0P0047oo000L
Ool2001SOol4000<Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool0
0`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001o
ogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00
Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(17535\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3156 m
.008 .31742 L
.012 .31996 L
.016 .32122 L
.02 .32066 L
.024 .31958 L
.028 .31814 L
.032 .31706 L
.036 .31681 L
.04 .31752 L
.044 .31903 L
.048 .32015 L
.052 .32042 L
.056 .31987 L
.06 .3187 L
.064 .31782 L
.068 .31758 L
.072 .31799 L
.076 .31882 L
.08 .31944 L
.084 .31965 L
.088 .31937 L
.092 .31881 L
.096 .31851 L
.1 .31858 L
.104 .31891 L
.108 .31918 L
.112 .31913 L
.116 .31886 L
.12 .31855 L
.124 .31841 L
.128 .31864 L
.132 .31919 L
.136 .31981 L
.14 .32 L
.144 .31953 L
.148 .31872 L
.152 .31808 L
.156 .31794 L
.16 .31828 L
.164 .31894 L
.168 .31974 L
.172 .32029 L
.176 .32021 L
.18 .31953 L
.184 .31872 L
.188 .31832 L
.192 .31836 L
.196 .31856 L
.2 .31876 L
Mistroke
.204 .31907 L
.208 .31953 L
.212 .31989 L
.216 .31993 L
.22 .31976 L
.224 .31963 L
.228 .31949 L
.232 .31901 L
.236 .31822 L
.24 .31766 L
.244 .3179 L
.248 .3189 L
.252 .32006 L
.256 .32086 L
.26 .32116 L
.264 .32101 L
.268 .32028 L
.272 .31891 L
.276 .31735 L
.28 .31649 L
.284 .31695 L
.288 .31849 L
.292 .32024 L
.296 .32144 L
.3 .32189 L
.304 .32176 L
.308 .32111 L
.312 .31988 L
.316 .31821 L
.32 .31673 L
.324 .31619 L
.328 .31693 L
.332 .31856 L
.336 .32032 L
.34 .32161 L
.344 .3223 L
.348 .32245 L
.352 .32199 L
.356 .32069 L
.36 .31862 L
.364 .31653 L
.368 .31557 L
.372 .31638 L
.376 .31846 L
.38 .32047 L
.384 .32136 L
.388 .32128 L
.392 .32123 L
.396 .32178 L
.4 .32225 L
Mistroke
.404 .32144 L
.408 .31909 L
.412 .31659 L
.416 .31588 L
.42 .3175 L
.424 .31994 L
.428 .321 L
.432 .32002 L
.436 .31855 L
.44 .31871 L
.444 .32089 L
.448 .32317 L
.452 .32319 L
.456 .32067 L
.46 .31785 L
.464 .3174 L
.468 .31973 L
.472 .32243 L
.476 .32254 L
.48 .31944 L
.484 .31556 L
.488 .31424 L
.492 .31667 L
.496 .3208 L
.5 .32325 L
.504 .32237 L
.508 .31964 L
.512 .31822 L
.516 .32003 L
.52 .32396 L
.524 .32682 L
.528 .32603 L
.532 .32172 L
.536 .31652 L
.54 .31346 L
.544 .31378 L
.548 .31634 L
.552 .31889 L
.556 .31982 L
.56 .31917 L
.564 .31817 L
.568 .31813 L
.572 .31956 L
.576 .32211 L
.58 .32493 L
.584 .32707 L
.588 .32767 L
.592 .32613 L
.596 .32247 L
.6 .31779 L
Mistroke
.604 .3141 L
.608 .31344 L
.612 .31647 L
.616 .32168 L
.62 .32582 L
.624 .32584 L
.628 .32095 L
.632 .31355 L
.636 .30802 L
.64 .30815 L
.644 .31456 L
.648 .32412 L
.652 .33153 L
.656 .33252 L
.66 .3263 L
.664 .31617 L
.668 .30756 L
.672 .30509 L
.676 .31006 L
.68 .32005 L
.684 .33041 L
.688 .33685 L
.692 .33742 L
.696 .33303 L
.7 .32642 L
.704 .32046 L
.708 .31678 L
.712 .31543 L
.716 .31564 L
.72 .31673 L
.724 .31878 L
.728 .32237 L
.732 .32777 L
.736 .33405 L
.74 .33899 L
.744 .33977 L
.748 .3344 L
.752 .32296 L
.756 .30804 L
.76 .29403 L
.764 .28555 L
.768 .28563 L
.772 .29461 L
.776 .30997 L
.78 .32738 L
.784 .34227 L
.788 .35139 L
.792 .35372 L
.796 .35043 L
.8 .34398 L
Mistroke
.804 .33686 L
.808 .33045 L
.812 .32454 L
.816 .31757 L
.82 .3075 L
.824 .29279 L
.828 .2733 L
.832 .25047 L
.836 .22699 L
.84 .20604 L
.844 .1903 L
.848 .18116 L
.852 .17834 L
.856 .18001 L
.86 .18342 L
.864 .18564 L
.868 .18445 L
.872 .17886 L
.876 .1693 L
.88 .15737 L
.884 .14542 L
.888 .13584 L
.892 .13055 L
.896 .13048 L
.9 .13544 L
.904 .1442 L
.908 .15479 L
.912 .16496 L
.916 .1726 L
.92 .17611 L
.924 .17466 L
.928 .16823 L
.932 .15759 L
.936 .14412 L
.94 .1295 L
.944 .1155 L
.948 .10367 L
.952 .09529 L
.956 .09111 L
.96 .09149 L
.964 .09623 L
.968 .10485 L
.972 .11652 L
.976 .13035 L
.98 .14531 L
.984 .1605 L
.988 .17502 L
.992 .18821 L
.996 .19957 L
1 .2087 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14735 m
.008 .14757 L
.012 .14766 L
.016 .14772 L
.02 .14765 L
.024 .14762 L
.028 .14763 L
.032 .14765 L
.036 .14761 L
.04 .14762 L
.044 .14762 L
.048 .14765 L
.052 .14765 L
.056 .14765 L
.06 .14764 L
.064 .14763 L
.068 .14762 L
.072 .14763 L
.076 .14763 L
.08 .14764 L
.084 .14764 L
.088 .14765 L
.092 .14763 L
.096 .14763 L
.1 .14762 L
.104 .14763 L
.108 .14764 L
.112 .14765 L
.116 .14765 L
.12 .14764 L
.124 .14763 L
.128 .14762 L
.132 .14762 L
.136 .14763 L
.14 .14764 L
.144 .14766 L
.148 .14766 L
.152 .14765 L
.156 .14763 L
.16 .14762 L
.164 .14761 L
.168 .14762 L
.172 .14764 L
.176 .14765 L
.18 .14766 L
.184 .14766 L
.188 .14766 L
.192 .14764 L
.196 .14762 L
.2 .14761 L
Mistroke
.204 .14761 L
.208 .14762 L
.212 .14763 L
.216 .14764 L
.22 .14766 L
.224 .14768 L
.228 .14768 L
.232 .14766 L
.236 .14763 L
.24 .14761 L
.244 .1476 L
.248 .14759 L
.252 .1476 L
.256 .14762 L
.26 .14766 L
.264 .1477 L
.268 .14772 L
.272 .1477 L
.276 .14766 L
.28 .14762 L
.284 .14759 L
.288 .14756 L
.292 .14755 L
.296 .14757 L
.3 .14763 L
.304 .1477 L
.308 .14775 L
.312 .14776 L
.316 .14773 L
.32 .14768 L
.324 .14763 L
.328 .14757 L
.332 .14752 L
.336 .1475 L
.34 .14752 L
.344 .1476 L
.348 .14771 L
.352 .14779 L
.356 .14782 L
.36 .14779 L
.364 .14774 L
.368 .14768 L
.372 .1476 L
.376 .14752 L
.38 .14746 L
.384 .14744 L
.388 .14751 L
.392 .14762 L
.396 .14774 L
.4 .1478 L
Mistroke
.404 .14781 L
.408 .1478 L
.412 .14779 L
.416 .14777 L
.42 .14771 L
.424 .14759 L
.428 .14746 L
.432 .1474 L
.436 .14745 L
.44 .14755 L
.444 .14764 L
.448 .14765 L
.452 .14764 L
.456 .14767 L
.46 .14778 L
.464 .14792 L
.468 .14798 L
.472 .14791 L
.476 .14775 L
.48 .1476 L
.484 .14755 L
.488 .14756 L
.492 .14754 L
.496 .14743 L
.5 .14727 L
.504 .14717 L
.508 .14724 L
.512 .14749 L
.516 .14781 L
.52 .14806 L
.524 .14818 L
.528 .14819 L
.532 .14816 L
.536 .14816 L
.54 .14815 L
.544 .14805 L
.548 .14781 L
.552 .14743 L
.556 .14702 L
.56 .14669 L
.564 .14655 L
.568 .14662 L
.572 .14686 L
.576 .14719 L
.58 .14754 L
.584 .14784 L
.588 .14809 L
.592 .1483 L
.596 .1485 L
.6 .14873 L
Mistroke
.604 .14896 L
.608 .1491 L
.612 .14906 L
.616 .14877 L
.62 .14827 L
.624 .14767 L
.628 .14718 L
.632 .14691 L
.636 .14687 L
.64 .14692 L
.644 .14686 L
.648 .14653 L
.652 .14595 L
.656 .14525 L
.66 .14469 L
.664 .14447 L
.668 .14467 L
.672 .14519 L
.676 .14585 L
.68 .14646 L
.684 .14695 L
.688 .14737 L
.692 .14788 L
.696 .14865 L
.7 .14978 L
.704 .15129 L
.708 .15309 L
.712 .15508 L
.716 .15713 L
.72 .15914 L
.724 .16103 L
.728 .16274 L
.732 .16419 L
.736 .16536 L
.74 .16631 L
.744 .16716 L
.748 .16811 L
.752 .16937 L
.756 .17112 L
.76 .17341 L
.764 .17612 L
.768 .17906 L
.772 .18192 L
.776 .18448 L
.78 .18658 L
.784 .18821 L
.788 .1895 L
.792 .1906 L
.796 .1917 L
.8 .19292 L
Mistroke
.804 .19432 L
.808 .19591 L
.812 .19765 L
.816 .19956 L
.82 .2017 L
.824 .20416 L
.828 .20708 L
.832 .21055 L
.836 .21464 L
.84 .21929 L
.844 .22439 L
.848 .22975 L
.852 .23518 L
.856 .24053 L
.86 .24571 L
.864 .25071 L
.868 .2556 L
.872 .26051 L
.876 .26555 L
.88 .27083 L
.884 .27638 L
.888 .28218 L
.892 .28812 L
.896 .29408 L
.9 .29991 L
.904 .30549 L
.908 .31073 L
.912 .31564 L
.916 .32024 L
.92 .32465 L
.924 .32899 L
.928 .33343 L
.932 .33807 L
.936 .34305 L
.94 .3484 L
.944 .35414 L
.948 .36022 L
.952 .36656 L
.956 .37304 L
.96 .37956 L
.964 .38594 L
.968 .39212 L
.972 .39794 L
.976 .40338 L
.98 .40835 L
.984 .41288 L
.988 .41692 L
.992 .42058 L
.996 .42382 L
1 .4268 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15916 L
.012 .16124 L
.016 .16188 L
.02 .16122 L
.024 .16096 L
.028 .1612 L
.032 .16127 L
.036 .16122 L
.04 .16118 L
.044 .16123 L
.048 .16121 L
.052 .16121 L
.056 .16119 L
.06 .1612 L
.064 .1612 L
.068 .16122 L
.072 .16121 L
.076 .16122 L
.08 .1612 L
.084 .1612 L
.088 .16119 L
.092 .1612 L
.096 .1612 L
.1 .16122 L
.104 .16122 L
.108 .16122 L
.112 .1612 L
.116 .1612 L
.12 .16119 L
.124 .16119 L
.128 .16119 L
.132 .16121 L
.136 .16121 L
.14 .16122 L
.144 .16121 L
.148 .16121 L
.152 .16121 L
.156 .1612 L
.16 .16119 L
.164 .16119 L
.168 .16119 L
.172 .1612 L
.176 .16121 L
.18 .16122 L
.184 .16123 L
.188 .16123 L
.192 .16122 L
.196 .16119 L
.2 .16117 L
Mistroke
.204 .16116 L
.208 .16117 L
.212 .16119 L
.216 .16121 L
.22 .16123 L
.224 .16126 L
.228 .16125 L
.232 .16123 L
.236 .16119 L
.24 .16116 L
.244 .16115 L
.248 .16115 L
.252 .16115 L
.256 .16118 L
.26 .16123 L
.264 .16128 L
.268 .16129 L
.272 .16127 L
.276 .16122 L
.28 .16118 L
.284 .16114 L
.288 .1611 L
.292 .16109 L
.296 .16111 L
.3 .16118 L
.304 .16127 L
.308 .16133 L
.312 .16135 L
.316 .16131 L
.32 .16125 L
.324 .16118 L
.328 .1611 L
.332 .16104 L
.336 .16101 L
.34 .16105 L
.344 .16115 L
.348 .16128 L
.352 .16137 L
.356 .1614 L
.36 .16137 L
.364 .16131 L
.368 .16124 L
.372 .16115 L
.376 .16105 L
.38 .16096 L
.384 .16093 L
.388 .16101 L
.392 .16116 L
.396 .16131 L
.4 .16139 L
Mistroke
.404 .1614 L
.408 .16137 L
.412 .16136 L
.416 .16134 L
.42 .16127 L
.424 .16112 L
.428 .16096 L
.432 .16088 L
.436 .16093 L
.44 .16106 L
.444 .16117 L
.448 .1612 L
.452 .16119 L
.456 .16122 L
.46 .16135 L
.464 .16152 L
.468 .1616 L
.472 .16151 L
.476 .16131 L
.48 .16113 L
.484 .16106 L
.488 .16106 L
.492 .16104 L
.496 .16091 L
.5 .16071 L
.504 .16059 L
.508 .16067 L
.512 .16098 L
.516 .16137 L
.52 .16169 L
.524 .16184 L
.528 .16185 L
.532 .16182 L
.536 .16181 L
.54 .16179 L
.544 .16167 L
.548 .16137 L
.552 .1609 L
.556 .16039 L
.56 .15998 L
.564 .1598 L
.568 .15988 L
.572 .16019 L
.576 .1606 L
.58 .16103 L
.584 .16141 L
.588 .16171 L
.592 .16197 L
.596 .16223 L
.6 .16251 L
Mistroke
.604 .1628 L
.608 .16297 L
.612 .16292 L
.616 .16256 L
.62 .16193 L
.624 .16119 L
.628 .16057 L
.632 .16023 L
.636 .16018 L
.64 .16024 L
.644 .16017 L
.648 .15977 L
.652 .15903 L
.656 .15816 L
.66 .15746 L
.664 .15719 L
.668 .15744 L
.672 .15809 L
.676 .15891 L
.68 .15967 L
.684 .16028 L
.688 .1608 L
.692 .16144 L
.696 .16239 L
.7 .1638 L
.704 .16568 L
.708 .16793 L
.712 .1704 L
.716 .17295 L
.72 .17546 L
.724 .17781 L
.728 .17993 L
.732 .18173 L
.736 .18319 L
.74 .18437 L
.744 .18542 L
.748 .1866 L
.752 .18817 L
.756 .19035 L
.76 .19319 L
.764 .19657 L
.768 .20021 L
.772 .20378 L
.776 .20695 L
.78 .20956 L
.784 .21159 L
.788 .21317 L
.792 .21454 L
.796 .2159 L
.8 .21741 L
Mistroke
.804 .21915 L
.808 .22111 L
.812 .22328 L
.816 .22565 L
.82 .2283 L
.824 .23135 L
.828 .23498 L
.832 .2393 L
.836 .24437 L
.84 .25016 L
.844 .25649 L
.848 .26315 L
.852 .26991 L
.856 .27656 L
.86 .28298 L
.864 .28919 L
.868 .29527 L
.872 .30136 L
.876 .30761 L
.88 .31417 L
.884 .32106 L
.888 .32825 L
.892 .33563 L
.896 .34303 L
.9 .35025 L
.904 .35717 L
.908 .36367 L
.912 .36975 L
.916 .37544 L
.92 .3809 L
.924 .38627 L
.928 .39175 L
.932 .39749 L
.936 .40364 L
.94 .41024 L
.944 .41733 L
.948 .42481 L
.952 .43262 L
.956 .44056 L
.96 .44851 L
.964 .45625 L
.968 .46367 L
.972 .47057 L
.976 .4769 L
.98 .48249 L
.984 .48739 L
.988 .49146 L
.992 .49482 L
.996 .49735 L
1 .49921 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001KOol2000@Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`03001oogoo008005Yoo`<0011oo`002goo0P002Woo0P000goo0`000goo00<0
07ooOol0FGoo00<007oo000047oo000ROol2001JOol01000Oomoo`003goo000;Ool20004Ool00`00
Oomoo`03Ool20002Ool50002Ool00`00Oomoo`1DOol00`00Oomoo`02Ool01000Oomoo`003goo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001EOol20002Ool01@00Oomo
ogoo00003goo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
05Aoo`06001oogoo001oo`0017oo00<007ooOol037oo000:Ool01000Oomoo`0027oo00@007ooOol0
00Aoo`05001oogooOol0001EOol01P00Oomoo`00Ool000Aoo`03001oogoo00aoo`002Woo00@007oo
Ool000Qoo`06001oogoo001oo`000goo00<007ooOol00P00Dgoo00@007ooOomoo`<000Aoo`03001o
ogoo00aoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00DGoo0`00
17oo00<007ooOol00goo00<007ooOol037oo000;Ool2000:Ool20003Ool30003Ool00`00Oomoo`1?
Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`80051oo`03001oogoo00aoo`03001oogoo00]oo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2000=Ool30004Ool20007Ool30004Ool20004Ool20005Ool30003Ool30004
Ool20003Ool50003Ool20003Ool30004Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol02goo00D007ooOomoo`00009o
o`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogoo
Ool00003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
0Woo00<007ooOol00Woo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol0
17oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool2
0004Ool00`00Oomoo`0;Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol0009oo`05001oogooOol00002Ool0
1@00Oomoo`00Ool00P000Woo00D007ooOomoo`0000=oo`03001oo`0000<000=oo`04001oogoo0005
Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006
Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo
0002Ool01@00Oomoogoo00000Woo00D007ooOol007oo0080009oo`05001oogooOol00003Ool00`00
Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004
Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P000Woo00@007oo000000Eoo`<0009o
o`D000=oo`8000Ioo`008Woo00<007ooOol0B7oo00<007ooOol00goo00<007ooOol06goo000ROol2
0018Ool20004Ool00`00Oomoo`0LOol0029oof<000aoo`008Woo0P0000Aoo`00001oo`P00004Ool0
0000Ool30002Ool20002Ool20002Ool20002Ool300002Goo00000000Ool007oo001oo`0200000goo
000000040003Ool2000017oo000007oo0P000Woo0`000Woo00T007oo001oo`00Ool007oo00000goo
00D007ooOomoo`0000=oo`05001oogooOol0000<Ool0029oo`<0009oo`800003Ool0000000=oo`80
009oo`800004Ool000000002Ool20002Ool300001Goo00000000Ool0400000=oo`00Ool00`0000Ao
o`00001oo`800003Ool007oo00800004Ool007oo0002Ool01000Oomoo`007goo000ROol00`00Oomo
o`0mOol00`00Oomoo`020003Ool20002Ool01000Ool000007goo000ROol2001;Ool2000POol0029o
o`8004]oo`80021oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0K7oo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2
001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<0
07ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04
001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool0
00Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007oo
Ool000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo
0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`80
06eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo
008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo
0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00
KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo
0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomo
o`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@00
0Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009ood4002Qo
o`00:7oo00<007ooOol0?Goo0`009Woo000XOol00`00Oomoo`0oOol4000SOol000]oo`8000Aoo`03
001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo04=oo`80025oo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo0016Ool3000OOol000=oo`D0
009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo0019Ool2000M
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]o
o`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`80009o
o`@000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00
Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03
001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool200000goo001oo`03Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomo
o`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009o
o`03001oogoo00@000Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03
001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01@00Oomo
o`00Ool00P000Woo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09
Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool2
0003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=o
o`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool2
0004Ool2000017oo001oogoo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1>Ool2000FOol0
02Qoo`03001oogoo04moo`03001oogoo01Aoo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00
Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00
Oomoo`0:Ool002Qoo`03001oogoo055oo`8001=oo`00:7oo00<007ooOol0DWoo0P004Woo000XOol0
0`00Oomoo`1COol00`00Oomoo`0@Ool002Qoo`03001oogoo05Aoo`03001oogoo00moo`00:7oo00<0
07ooOol0EGoo00<007ooOol03Woo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003
Ool00`00Oomoo`1EOol00`00Oomoo`0>Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0003Ool01000Oomoo`00F7oo00<007ooOol03Goo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool01000Oomoo`00F7oo0P003Woo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001HOol2000=Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo05Qoo`8000aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo
0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003
Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001o
ogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool0
1000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo
0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`80
00Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0
009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`00
0Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomo
o`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomo
o`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009o
o`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol0
0goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo
00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000
Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo
0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`80
00Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00002
Ool30003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool00`00
Oomoo`0:Ool001aoo`03001oogoo04Qoo`8002Qoo`0077oo0P00BWoo0`009Woo000LOol00`00Oomo
o`1<Ool2000TOol001aoo`03001oogoo04eoo`8002=oo`0077oo0P00D7oo0`0087oo000LOol00`00
Oomoo`1AOol2000OOol001aoo`03001oogoo059oo`8001ioo`0077oo0P00EGoo00<007ooOol06goo
000LOol00`00Oomoo`1DOol00`00Oomoo`0KOol001aoo`8005Ioo`03001oogoo01Yoo`002goo0P00
17oo00<007ooOol00Woo0`000goo00<007ooOol0EGoo0P006goo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo05Ioo`8001Yoo`002Woo00@007ooOol000]oo`03001oogoo0080
05Qoo`03001oogoo01Qoo`002Woo00@007ooOol000]oo`04001oogoo001IOol2000IOol000Yoo`04
001oogoo0007Ool40003Ool00`00Oomoo`1HOol00`00Oomoo`0GOol000Yoo`04001oogoo0007Ool0
0`00Oomoo`04Ool2001JOol00`00Oomoo`0FOol000]oo`8000Qoo`D0009oo`03001oogoo05Uoo`03
001oogoo01Ioo`0077oo00<007ooOol0FWoo00<007ooOol05Goo000LOol2001KOol00`00Oomoo`0E
Ool001aoo`03001oogoo05]oo`03001oogoo01Aoo`0077oo0P00G7oo0P005Goo000LOol00`00Oomo
o`1LOol00`00Oomoo`0COol001aoo`03001oogoo05eoo`03001oogoo019oo`0077oo0P00Ggoo00<0
07ooOol04Goo000FOol30003Ool00`00Oomoo`1NOol00`00Oomoo`0AOol001Moo`03001oogoo009o
o`03001oogoo05moo`03001oogoo011oo`005goo00<007ooOol00Woo0P00H7oo0P004Goo000GOol0
0`00Oomoo`02Ool00`00Oomoo`1POol00`00Oomoo`0?Ool001Moo`03001oogoo009oo`03001oogoo
061oo`03001oogoo00moo`005Woo0P0017oo0P00HWoo00<007ooOol03Woo000GOol00`00Oomoo`02
Ool00`00Oomoo`1QOol2000?Ool001aoo`03001oogoo069oo`03001oogoo00eoo`0077oo0P00I7oo
00<007ooOol037oo000LOol00`00Oomoo`1TOol2000<Ool001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo
00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@0
07ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool4
0003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<0
07ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(17702\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31642 m
.008 .31672 L
.012 .31757 L
.016 .31945 L
.02 .32071 L
.024 .32074 L
.028 .31958 L
.032 .31781 L
.036 .31677 L
.04 .31673 L
.044 .31781 L
.048 .31958 L
.052 .32071 L
.056 .32074 L
.06 .31959 L
.064 .31789 L
.068 .31682 L
.072 .31681 L
.076 .31794 L
.08 .31961 L
.084 .32076 L
.088 .32086 L
.092 .31976 L
.096 .31815 L
.1 .31703 L
.104 .31693 L
.108 .31789 L
.112 .31934 L
.116 .32046 L
.12 .32076 L
.124 .32003 L
.128 .31875 L
.132 .31769 L
.136 .31741 L
.14 .31798 L
.144 .31889 L
.148 .31966 L
.152 .32005 L
.156 .31992 L
.16 .31938 L
.164 .31874 L
.168 .31843 L
.172 .31858 L
.176 .31887 L
.18 .31899 L
.184 .31896 L
.188 .31899 L
.192 .31918 L
.196 .31937 L
.2 .31947 L
Mistroke
.204 .31955 L
.208 .31961 L
.212 .31944 L
.216 .31889 L
.22 .31825 L
.224 .31806 L
.228 .31851 L
.232 .31926 L
.236 .31986 L
.24 .3202 L
.244 .32035 L
.248 .32022 L
.252 .31961 L
.256 .31861 L
.26 .31778 L
.264 .31768 L
.268 .31829 L
.272 .31913 L
.276 .31981 L
.28 .32038 L
.284 .32091 L
.288 .32114 L
.292 .32063 L
.296 .31932 L
.3 .31784 L
.304 .31698 L
.308 .31709 L
.312 .31798 L
.316 .31922 L
.32 .32055 L
.324 .32174 L
.328 .3224 L
.332 .32203 L
.336 .3205 L
.34 .31836 L
.344 .31667 L
.348 .31623 L
.352 .31705 L
.356 .31848 L
.36 .3198 L
.364 .32079 L
.368 .32166 L
.372 .32244 L
.376 .32261 L
.38 .32154 L
.384 .31928 L
.388 .31689 L
.392 .31579 L
.396 .31653 L
.4 .31831 L
Mistroke
.404 .31977 L
.408 .32031 L
.412 .32054 L
.416 .32133 L
.42 .32254 L
.424 .32294 L
.428 .32149 L
.432 .31875 L
.436 .31667 L
.44 .31677 L
.444 .31864 L
.448 .32024 L
.452 .32 L
.456 .31848 L
.46 .31778 L
.464 .31929 L
.468 .32209 L
.472 .32365 L
.476 .32237 L
.48 .31931 L
.484 .31733 L
.488 .31836 L
.492 .32142 L
.496 .32347 L
.5 .32223 L
.504 .31837 L
.508 .31501 L
.512 .3149 L
.516 .31798 L
.52 .32152 L
.524 .32258 L
.528 .32068 L
.532 .31806 L
.536 .31766 L
.54 .32047 L
.544 .32465 L
.548 .3271 L
.552 .32592 L
.556 .32179 L
.56 .31727 L
.564 .31479 L
.568 .31506 L
.572 .31698 L
.576 .31876 L
.58 .31933 L
.584 .31874 L
.588 .31786 L
.592 .31762 L
.596 .31854 L
.6 .32068 L
Mistroke
.604 .32366 L
.608 .3266 L
.612 .32821 L
.616 .3273 L
.62 .32355 L
.624 .31823 L
.628 .31387 L
.632 .31299 L
.636 .3164 L
.64 .3223 L
.644 .32702 L
.648 .32716 L
.652 .3219 L
.656 .31384 L
.66 .30768 L
.664 .3074 L
.668 .31379 L
.672 .32369 L
.676 .33173 L
.68 .33341 L
.684 .3277 L
.688 .31759 L
.692 .30838 L
.696 .30476 L
.7 .3084 L
.704 .31731 L
.708 .32729 L
.712 .33418 L
.716 .33588 L
.72 .33285 L
.724 .32734 L
.728 .32181 L
.732 .31772 L
.736 .31527 L
.74 .31398 L
.744 .3136 L
.748 .31458 L
.752 .31781 L
.756 .3237 L
.76 .33133 L
.764 .33825 L
.768 .34128 L
.772 .33786 L
.776 .32747 L
.78 .31228 L
.784 .29653 L
.788 .28513 L
.792 .28179 L
.796 .28768 L
.8 .30107 L
Mistroke
.804 .31804 L
.808 .33399 L
.812 .34527 L
.816 .35023 L
.82 .34943 L
.824 .34497 L
.828 .33927 L
.832 .33395 L
.836 .32914 L
.84 .32351 L
.844 .31504 L
.848 .30194 L
.852 .28363 L
.856 .26107 L
.86 .23669 L
.864 .21367 L
.868 .19502 L
.872 .1827 L
.876 .17709 L
.88 .1769 L
.884 .17965 L
.888 .18239 L
.892 .18254 L
.896 .17856 L
.9 .17025 L
.904 .15874 L
.908 .14613 L
.912 .13486 L
.916 .12711 L
.92 .12428 L
.924 .12669 L
.928 .13355 L
.932 .14318 L
.936 .1534 L
.94 .16189 L
.944 .16672 L
.948 .16653 L
.952 .16085 L
.956 .14995 L
.96 .13485 L
.964 .11701 L
.968 .09813 L
.972 .07995 L
.976 .06385 L
.98 .05116 L
.984 .04234 L
.988 .03807 L
.992 .03787 L
.996 .04199 L
1 .04938 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15078 m
.008 .14801 L
.012 .14705 L
.016 .14801 L
.02 .14829 L
.024 .148 L
.028 .14788 L
.032 .14802 L
.036 .14804 L
.04 .14801 L
.044 .14798 L
.048 .148 L
.052 .14799 L
.056 .148 L
.06 .148 L
.064 .14801 L
.068 .148 L
.072 .148 L
.076 .14799 L
.08 .14799 L
.084 .14799 L
.088 .148 L
.092 .148 L
.096 .14801 L
.1 .148 L
.104 .148 L
.108 .14799 L
.112 .14799 L
.116 .14799 L
.12 .148 L
.124 .14801 L
.128 .14801 L
.132 .14801 L
.136 .148 L
.14 .148 L
.144 .14799 L
.148 .14799 L
.152 .148 L
.156 .148 L
.16 .148 L
.164 .14801 L
.168 .14801 L
.172 .14801 L
.176 .14801 L
.18 .148 L
.184 .14799 L
.188 .14799 L
.192 .14799 L
.196 .14799 L
.2 .148 L
Mistroke
.204 .14802 L
.208 .14803 L
.212 .14803 L
.216 .14801 L
.22 .148 L
.224 .14798 L
.228 .14798 L
.232 .14797 L
.236 .14798 L
.24 .148 L
.244 .14803 L
.248 .14805 L
.252 .14804 L
.256 .14803 L
.26 .14801 L
.264 .14799 L
.268 .14797 L
.272 .14795 L
.276 .14795 L
.28 .14798 L
.284 .14803 L
.288 .14806 L
.292 .14807 L
.296 .14807 L
.3 .14805 L
.304 .14802 L
.308 .14797 L
.312 .14793 L
.316 .1479 L
.32 .14792 L
.324 .14798 L
.328 .14805 L
.332 .1481 L
.336 .14812 L
.34 .14811 L
.344 .14808 L
.348 .14803 L
.352 .14795 L
.356 .14789 L
.36 .14785 L
.364 .14788 L
.368 .14795 L
.372 .14805 L
.376 .14812 L
.38 .14815 L
.384 .14816 L
.388 .14814 L
.392 .1481 L
.396 .14801 L
.4 .1479 L
Mistroke
.404 .14781 L
.408 .1478 L
.412 .14786 L
.416 .14797 L
.42 .14807 L
.424 .14811 L
.428 .14814 L
.432 .14816 L
.436 .1482 L
.44 .14819 L
.444 .14811 L
.448 .14797 L
.452 .14784 L
.456 .14779 L
.46 .14784 L
.464 .14793 L
.468 .14797 L
.472 .14795 L
.476 .14794 L
.48 .14801 L
.484 .14815 L
.488 .1483 L
.492 .14834 L
.496 .14826 L
.5 .14812 L
.504 .14802 L
.508 .14801 L
.512 .14802 L
.516 .14797 L
.52 .14781 L
.524 .14761 L
.528 .1475 L
.532 .14757 L
.536 .1478 L
.54 .14808 L
.544 .14831 L
.548 .14842 L
.552 .14847 L
.556 .14852 L
.56 .14858 L
.564 .14862 L
.568 .14856 L
.572 .14833 L
.576 .14797 L
.58 .14754 L
.584 .14718 L
.588 .14698 L
.592 .14696 L
.596 .14712 L
.6 .1474 L
Mistroke
.604 .14772 L
.608 .14801 L
.612 .14825 L
.616 .14847 L
.62 .14869 L
.624 .14897 L
.628 .14927 L
.632 .1495 L
.636 .14955 L
.64 .14932 L
.644 .14884 L
.648 .14826 L
.652 .14775 L
.656 .14747 L
.66 .14743 L
.664 .14748 L
.668 .14744 L
.672 .14714 L
.676 .14656 L
.68 .14584 L
.684 .14522 L
.688 .1449 L
.692 .14498 L
.696 .14538 L
.7 .14593 L
.704 .14647 L
.708 .1469 L
.712 .14726 L
.716 .14768 L
.72 .14832 L
.724 .14929 L
.728 .15061 L
.732 .15225 L
.736 .15411 L
.74 .15611 L
.744 .15815 L
.748 .16013 L
.752 .16196 L
.756 .16355 L
.76 .16484 L
.764 .16584 L
.768 .16666 L
.772 .16749 L
.776 .16858 L
.78 .1701 L
.784 .17217 L
.788 .17472 L
.792 .17757 L
.796 .18047 L
.8 .18315 L
Mistroke
.804 .18543 L
.808 .18727 L
.812 .18872 L
.816 .18994 L
.82 .19108 L
.824 .19228 L
.828 .19361 L
.832 .19508 L
.836 .19668 L
.84 .19841 L
.844 .20032 L
.848 .20251 L
.852 .20511 L
.856 .20824 L
.86 .21198 L
.864 .21632 L
.868 .22116 L
.872 .22636 L
.876 .23171 L
.88 .23705 L
.884 .24225 L
.888 .24729 L
.892 .25219 L
.896 .25706 L
.9 .26202 L
.904 .26719 L
.908 .27262 L
.912 .27832 L
.916 .28421 L
.92 .2902 L
.924 .29612 L
.928 .30187 L
.932 .30732 L
.936 .31246 L
.94 .31729 L
.944 .3219 L
.948 .3264 L
.952 .33098 L
.956 .33574 L
.96 .34087 L
.964 .34641 L
.968 .35247 L
.972 .35899 L
.976 .36601 L
.98 .37337 L
.984 .38103 L
.988 .38882 L
.992 .39667 L
.996 .40442 L
1 .41199 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16089 L
.012 .16116 L
.016 .16129 L
.02 .16129 L
.024 .16116 L
.028 .16116 L
.032 .16117 L
.036 .16123 L
.04 .16121 L
.044 .16123 L
.048 .16122 L
.052 .16122 L
.056 .16119 L
.06 .16119 L
.064 .16118 L
.068 .16121 L
.072 .16121 L
.076 .16123 L
.08 .16122 L
.084 .16121 L
.088 .16119 L
.092 .16119 L
.096 .16119 L
.1 .16121 L
.104 .16121 L
.108 .16122 L
.112 .16121 L
.116 .1612 L
.12 .16119 L
.124 .1612 L
.128 .1612 L
.132 .16122 L
.136 .16122 L
.14 .16122 L
.144 .1612 L
.148 .16119 L
.152 .16118 L
.156 .16119 L
.16 .1612 L
.164 .16122 L
.168 .16123 L
.172 .16123 L
.176 .16121 L
.18 .16119 L
.184 .16118 L
.188 .16118 L
.192 .16118 L
.196 .16119 L
.2 .16121 L
Mistroke
.204 .16123 L
.208 .16123 L
.212 .16123 L
.216 .16121 L
.22 .16119 L
.224 .16118 L
.228 .16117 L
.232 .16117 L
.236 .16117 L
.24 .1612 L
.244 .16123 L
.248 .16125 L
.252 .16125 L
.256 .16123 L
.26 .16121 L
.264 .16118 L
.268 .16115 L
.272 .16113 L
.276 .16113 L
.28 .16117 L
.284 .16122 L
.288 .16127 L
.292 .16128 L
.296 .16127 L
.3 .16125 L
.304 .1612 L
.308 .16115 L
.312 .16109 L
.316 .16107 L
.32 .1611 L
.324 .16117 L
.328 .16125 L
.332 .16131 L
.336 .16133 L
.34 .16132 L
.344 .16129 L
.348 .16122 L
.352 .16113 L
.356 .16104 L
.36 .16099 L
.364 .16102 L
.368 .16112 L
.372 .16124 L
.376 .16133 L
.38 .16137 L
.384 .16137 L
.388 .16135 L
.392 .1613 L
.396 .1612 L
.4 .16106 L
Mistroke
.404 .16095 L
.408 .16092 L
.412 .161 L
.416 .16113 L
.42 .16125 L
.424 .16132 L
.428 .16135 L
.432 .16138 L
.436 .16141 L
.44 .16141 L
.444 .16131 L
.448 .16113 L
.452 .16097 L
.456 .16091 L
.46 .16097 L
.464 .16107 L
.468 .16112 L
.472 .1611 L
.476 .16109 L
.48 .16118 L
.484 .16136 L
.488 .16153 L
.492 .16158 L
.496 .16148 L
.5 .16131 L
.504 .1612 L
.508 .16117 L
.512 .16118 L
.516 .16111 L
.52 .16091 L
.524 .16067 L
.528 .16054 L
.532 .16062 L
.536 .1609 L
.54 .16125 L
.544 .16153 L
.548 .16168 L
.552 .16175 L
.556 .1618 L
.56 .16188 L
.564 .16192 L
.568 .16184 L
.572 .16156 L
.576 .16111 L
.58 .16058 L
.584 .16013 L
.588 .15987 L
.592 .15985 L
.596 .16005 L
.6 .1604 L
Mistroke
.604 .16079 L
.608 .16115 L
.612 .16145 L
.616 .16172 L
.62 .16201 L
.624 .16235 L
.628 .16273 L
.632 .16301 L
.636 .16306 L
.64 .16278 L
.644 .16218 L
.648 .16146 L
.652 .16082 L
.656 .16047 L
.66 .16041 L
.664 .16049 L
.668 .16044 L
.672 .16006 L
.676 .15934 L
.68 .15844 L
.684 .15766 L
.688 .15727 L
.692 .15736 L
.696 .15786 L
.7 .15855 L
.704 .15921 L
.708 .15975 L
.712 .1602 L
.716 .16073 L
.72 .16152 L
.724 .16272 L
.728 .16437 L
.732 .16641 L
.736 .16874 L
.74 .17122 L
.744 .17376 L
.748 .17622 L
.752 .1785 L
.756 .18047 L
.76 .18208 L
.764 .18332 L
.768 .18434 L
.772 .18537 L
.776 .18672 L
.78 .18861 L
.784 .19118 L
.788 .19436 L
.792 .19791 L
.796 .20151 L
.8 .20484 L
Mistroke
.804 .20767 L
.808 .20995 L
.812 .21175 L
.816 .21326 L
.82 .21467 L
.824 .21616 L
.828 .21781 L
.832 .21963 L
.836 .22161 L
.84 .22375 L
.844 .22612 L
.848 .22884 L
.852 .23207 L
.856 .23596 L
.86 .2406 L
.864 .24599 L
.868 .25202 L
.872 .25847 L
.876 .26512 L
.88 .27176 L
.884 .27822 L
.888 .28448 L
.892 .29056 L
.896 .29661 L
.9 .30276 L
.904 .30916 L
.908 .31589 L
.912 .32294 L
.916 .33023 L
.92 .33762 L
.924 .34491 L
.928 .35197 L
.932 .35862 L
.936 .36483 L
.94 .3706 L
.944 .37603 L
.948 .38122 L
.952 .38638 L
.956 .39162 L
.96 .39712 L
.964 .40291 L
.968 .40906 L
.972 .41546 L
.976 .42209 L
.98 .42873 L
.984 .43527 L
.988 .44147 L
.992 .44722 L
.996 .45232 L
1 .4567 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8005ioo`8000eoo`002goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo00<007ooOol0GGoo00<007oo000037oo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`02001NOol00`00Oomoo`0<Ool000=oo`D0009oo`04001oogoo0008Ool0
1000Oomoo`001Goo00<007ooOol00P00GGoo00<007ooOol03Goo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`8000=oo`03001oogoo05aoo`03001oogoo00eoo`002Woo00@007ooOol000Qoo`04
001oogoo0005Ool00`00Oomoo`02001MOol00`00Oomoo`0=Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`03001oogoo008005aoo`03001oogoo00ioo`002goo0P002Woo0P000goo0`00
0goo00<007ooOol0Fgoo00<007ooOol03Woo000ROol2001LOol00`00Oomoo`0>Ool000]oo`8000Ao
o`03001oogoo00=oo`80009oo`D0009oo`03001oogoo05Ioo`<0009oo`03001oogoo00ioo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00Egoo00<007oo00000Woo00<0
07ooOol03Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
05Moo`05001oo`00Ool0000AOol000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00D007ooOomo
o`0005Moo`04001oogooOol2000AOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008005Ioo`05001oogooOol0000BOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0
00=oo`03001oogoo008005=oo`<001Moo`002goo0P002Woo0P000goo0`000goo00<007ooOol0DWoo
00<007ooOol05goo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001COol00`00Oomo
o`0GOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo
0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo1@000goo0P0017oo0P0017oo
1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`05001o
ogooOol00002Ool01000Oomoo`000Woo00D007ooOol007oo008000Aoo`06001oogoo001oo`000goo
00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00<007oo
Ool00Woo00@007ooOol0009oo`04001oo`000005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04
001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00D007oo
Ool007oo008000Ioo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol02goo10000goo00@007ooOol000Moo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo
0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oo`000003Ool01P00Oomoogoo001o
o`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`8000aoo`03001o
ogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03
001oogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oo`00
0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0029oo`8000aoo`D000=oo`8000Qo
o`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20004Ool30004Ool20004Ool2
0005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo04Yoo`8000Aoo`03001oogoo01Uoo`00
8Woo0P00Bgoo0P0017oo00<007ooOol06Goo000ROomS000<Ool0029oo`800004Ool00000Ool30000
0goo0000000300000goo0000000:00001Goo00000000Ool00`000Woo0P000Woo0P0000=oo`00Ool0
1P000Woo1@0000Aoo`00001oo`@00003Ool0000000@00004Ool007oo0003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`03001oogoo00Yoo`008Woo100000Aoo`00001oo`800003Ool00000
009oo`80009oo`<00005Ool00000001oo`0300001Goo00000000Ool00`000Woo0`0000=oo`00Ool0
100000=oo`0000000P000Woo00<007oo00001@0000Moo`00001oo`00Ool00002Ool01@00Ool007oo
00000goo00<007ooOol06Woo000ROol00`00Oomoo`0oOol01@00Oomoogoo00000goo0P000goo00<0
07oo00007Goo000ROol20019Ool01000Oomoogoo0P007Woo000ROol2001>Ool00`00Oomoo`0LOol0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:
Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009o
o`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<0
07ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=o
o`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<0
00=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomo
ogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomo
o`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00
Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Oom3000VOol002Qoo`03001oogoo
03Moo`03001oogoo00Ioo`<002=oo`00:7oo00<007ooOol0@Woo0`008Goo000;Ool20004Ool00`00
Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`15Ool2000OOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00B7oo0`007Goo0003Ool50002
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00Bgoo0`006Woo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool3
0004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool2
0003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007oo
Ool007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOol007oo008000=oo`06001oogoo001oo`00
0goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00
Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo
0002Ool20004Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomo
o`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oo`000003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool0
0`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003
Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07oo000000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`80
00Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004
Ool20003Ool40002Ool50003Ool20006Ool002Qoo`03001oogoo055oo`03001oogoo019oo`00:7oo
00<007ooOol0DWoo00<007ooOol04Goo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo
011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo
00Yoo`00:7oo00<007ooOol0E7oo00<007ooOol03goo000XOol00`00Oomoo`1EOol00`00Oomoo`0>
Ool002Qoo`03001oogoo05Eoo`8000moo`00:7oo00<007ooOol0EWoo00<007ooOol03Goo000XOol0
0`00Oomoo`1GOol00`00Oomoo`0<Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<0
00=oo`03001oogoo05Moo`03001oogoo00aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1P00Oomoo`00Ool000=oo`04001oogoo001JOol00`00Oomoo`0;Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001JOol00`00Oomoo`0;Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008005Yoo`03001oogoo00Yo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0
IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0
IWoo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomo
o`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@00
0Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001d
Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00
Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol03Goo
0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo
0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol0
00Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005
Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011o
o`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001ao
o`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool0
0`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`00
1Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0
009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`00
1Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo
1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007oo
Ool00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo
Ool00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000Aoo`<00003Ool007oo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1:Ool3000UOol001aoo`8004eoo`<002=o
o`0077oo00<007ooOol0Cgoo00<007ooOol087oo000LOol00`00Oomoo`1@Ool2000POol001aoo`80
05=oo`8001ioo`0077oo00<007ooOol0E7oo0P0077oo000LOol00`00Oomoo`1EOol2000KOol001ao
o`8005Qoo`03001oogoo01Qoo`0077oo00<007ooOol0Egoo00<007ooOol067oo000LOol2001IOol0
0`00Oomoo`0GOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo05Qoo`8001Qoo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1IOol00`00Oomoo`0FOol000Yo
o`04001oogoo000;Ool00`00Oomoo`02001JOol2000GOol000Yoo`04001oogoo000;Ool01000Oomo
o`00G7oo00<007ooOol05Goo000:Ool01000Oomoo`001goo10000goo00<007ooOol0Fgoo00<007oo
Ool057oo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00G7oo00<007ooOol057oo000;Ool2
0008Ool50002Ool00`00Oomoo`1LOol00`00Oomoo`0COol001aoo`03001oogoo05aoo`8001Aoo`00
77oo0P00GWoo00<007ooOol04Woo000LOol00`00Oomoo`1NOol00`00Oomoo`0AOol001aoo`8005mo
o`80019oo`0077oo00<007ooOol0Ggoo00<007ooOol047oo000LOol00`00Oomoo`1POol00`00Oomo
o`0?Ool001aoo`80065oo`80011oo`005Woo0`000goo00<007ooOol0HGoo00<007ooOol03Woo000G
Ool00`00Oomoo`02Ool00`00Oomoo`1ROol00`00Oomoo`0=Ool001Moo`03001oogoo009oo`8006=o
o`03001oogoo00eoo`005goo00<007ooOol00Woo00<007ooOol0Hgoo00<007ooOol037oo000GOol0
0`00Oomoo`02Ool00`00Oomoo`1TOol00`00Oomoo`0;Ool001Ioo`8000Aoo`8006Ioo`03001oogoo
00Yoo`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03
001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo
000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`80
07=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(17869\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32134 m
.008 .31982 L
.012 .31754 L
.016 .31643 L
.02 .31702 L
.024 .31794 L
.028 .31911 L
.032 .32004 L
.036 .32025 L
.04 .31967 L
.044 .31837 L
.048 .31745 L
.052 .31733 L
.056 .31784 L
.06 .31884 L
.064 .31961 L
.068 .31985 L
.072 .31956 L
.076 .31882 L
.08 .31822 L
.084 .31801 L
.088 .31817 L
.092 .31862 L
.096 .31898 L
.1 .31919 L
.104 .31926 L
.108 .31914 L
.112 .31901 L
.116 .31887 L
.12 .31876 L
.124 .31866 L
.128 .31849 L
.132 .31844 L
.136 .31868 L
.14 .31912 L
.144 .31952 L
.148 .31964 L
.152 .31948 L
.156 .31908 L
.16 .31854 L
.164 .3181 L
.168 .31809 L
.172 .31862 L
.176 .31938 L
.18 .31988 L
.184 .31993 L
.188 .31963 L
.192 .31917 L
.196 .31867 L
.2 .31826 L
Mistroke
.204 .31822 L
.208 .31865 L
.212 .31928 L
.216 .31965 L
.22 .31965 L
.224 .31954 L
.228 .3195 L
.232 .31944 L
.236 .31916 L
.24 .31878 L
.244 .3186 L
.248 .31868 L
.252 .31882 L
.256 .31891 L
.26 .31914 L
.264 .31974 L
.268 .32045 L
.272 .32067 L
.276 .32007 L
.28 .31899 L
.284 .31809 L
.288 .31775 L
.292 .31791 L
.296 .31844 L
.3 .31932 L
.304 .32047 L
.308 .32141 L
.312 .32154 L
.316 .32065 L
.32 .31922 L
.324 .31801 L
.328 .31746 L
.332 .3175 L
.336 .31788 L
.34 .31859 L
.344 .31978 L
.348 .32128 L
.352 .32244 L
.356 .32247 L
.36 .32111 L
.364 .31899 L
.368 .3172 L
.372 .31653 L
.376 .31696 L
.38 .31793 L
.384 .31899 L
.388 .32015 L
.392 .32152 L
.396 .32273 L
.4 .32299 L
Mistroke
.404 .32172 L
.408 .3194 L
.412 .31735 L
.416 .31668 L
.42 .31732 L
.424 .31824 L
.428 .31865 L
.432 .31887 L
.436 .31985 L
.44 .32179 L
.444 .32349 L
.448 .32334 L
.452 .32104 L
.456 .31821 L
.46 .31701 L
.464 .31809 L
.468 .31991 L
.472 .3203 L
.476 .31877 L
.48 .31706 L
.484 .31741 L
.488 .32015 L
.492 .32313 L
.496 .32367 L
.5 .32124 L
.504 .31807 L
.508 .31719 L
.512 .3195 L
.516 .32287 L
.52 .32405 L
.524 .32166 L
.528 .31749 L
.532 .31491 L
.536 .31587 L
.54 .31926 L
.544 .322 L
.548 .32182 L
.552 .3192 L
.556 .31684 L
.56 .31728 L
.564 .32072 L
.568 .32491 L
.572 .32701 L
.576 .32569 L
.58 .32195 L
.584 .3181 L
.588 .31605 L
.592 .31618 L
.596 .31754 L
.6 .31881 L
Mistroke
.604 .31921 L
.608 .31872 L
.612 .31781 L
.616 .31716 L
.62 .31743 L
.624 .31915 L
.628 .32233 L
.632 .32608 L
.636 .32865 L
.64 .32831 L
.644 .32446 L
.648 .31854 L
.652 .31357 L
.656 .3125 L
.66 .31626 L
.664 .32282 L
.668 .32811 L
.672 .32846 L
.676 .32295 L
.68 .31433 L
.684 .30751 L
.688 .30674 L
.692 .31294 L
.696 .32305 L
.7 .33168 L
.704 .33416 L
.708 .32915 L
.712 .31931 L
.716 .30969 L
.72 .30501 L
.724 .30724 L
.728 .3149 L
.732 .32425 L
.736 .33137 L
.74 .33406 L
.744 .3324 L
.748 .32812 L
.752 .32326 L
.756 .31905 L
.76 .31573 L
.764 .31303 L
.768 .31107 L
.772 .31069 L
.776 .31312 L
.78 .31904 L
.784 .32766 L
.788 .33643 L
.792 .34184 L
.796 .34077 L
.8 .33204 L
Mistroke
.804 .31721 L
.808 .30028 L
.812 .28628 L
.816 .27953 L
.82 .28204 L
.824 .29288 L
.828 .30873 L
.832 .32512 L
.836 .33808 L
.84 .3454 L
.844 .34703 L
.848 .34462 L
.852 .34048 L
.856 .33638 L
.86 .33276 L
.864 .32856 L
.868 .32184 L
.872 .31061 L
.876 .29384 L
.88 .27202 L
.884 .24717 L
.888 .22237 L
.892 .20086 L
.896 .18507 L
.9 .17602 L
.904 .17301 L
.908 .17392 L
.912 .17587 L
.916 .17597 L
.92 .17215 L
.924 .16353 L
.928 .15066 L
.932 .13517 L
.936 .11937 L
.94 .10561 L
.944 .09562 L
.948 .09033 L
.952 .08942 L
.956 .09188 L
.96 .09571 L
.964 .09909 L
.968 .09988 L
.972 .09709 L
.976 .08985 L
.98 .0788 L
.984 .0647 L
.988 .04926 L
.992 .03435 L
.996 .02144 L
1 .0126 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14913 m
.008 .14846 L
.012 .14814 L
.016 .14829 L
.02 .14838 L
.024 .14839 L
.028 .14833 L
.032 .14837 L
.036 .14838 L
.04 .14839 L
.044 .14836 L
.048 .14835 L
.052 .14834 L
.056 .14835 L
.06 .14835 L
.064 .14838 L
.068 .14838 L
.072 .14838 L
.076 .14836 L
.08 .14835 L
.084 .14834 L
.088 .14835 L
.092 .14836 L
.096 .14837 L
.1 .14837 L
.104 .14837 L
.108 .14836 L
.112 .14836 L
.116 .14835 L
.12 .14836 L
.124 .14837 L
.128 .14837 L
.132 .14837 L
.136 .14836 L
.14 .14835 L
.144 .14835 L
.148 .14836 L
.152 .14837 L
.156 .14838 L
.16 .14838 L
.164 .14837 L
.168 .14836 L
.172 .14835 L
.176 .14835 L
.18 .14835 L
.184 .14836 L
.188 .14838 L
.192 .14838 L
.196 .14838 L
.2 .14837 L
Mistroke
.204 .14836 L
.208 .14836 L
.212 .14835 L
.216 .14834 L
.22 .14835 L
.224 .14837 L
.228 .14838 L
.232 .14839 L
.236 .14839 L
.24 .14838 L
.244 .14837 L
.248 .14836 L
.252 .14834 L
.256 .14833 L
.26 .14834 L
.264 .14836 L
.268 .14839 L
.272 .1484 L
.276 .1484 L
.28 .1484 L
.284 .14839 L
.288 .14837 L
.292 .14833 L
.296 .14831 L
.3 .14831 L
.304 .14834 L
.308 .14838 L
.312 .14841 L
.316 .14843 L
.32 .14844 L
.324 .14843 L
.328 .1484 L
.332 .14835 L
.336 .14829 L
.34 .14827 L
.344 .14828 L
.348 .14833 L
.352 .14839 L
.356 .14844 L
.36 .14847 L
.364 .14849 L
.368 .14848 L
.372 .14842 L
.376 .14834 L
.38 .14825 L
.384 .14821 L
.388 .14823 L
.392 .1483 L
.396 .14838 L
.4 .14844 L
Mistroke
.404 .14849 L
.408 .14853 L
.412 .14854 L
.416 .14851 L
.42 .14842 L
.424 .14829 L
.428 .14819 L
.432 .14817 L
.436 .14823 L
.44 .14831 L
.444 .14838 L
.448 .14842 L
.452 .14846 L
.456 .14854 L
.46 .1486 L
.464 .1486 L
.468 .1485 L
.472 .14835 L
.476 .14823 L
.48 .1482 L
.484 .14825 L
.488 .14829 L
.492 .14828 L
.496 .14824 L
.5 .14825 L
.504 .14835 L
.508 .14852 L
.512 .14865 L
.516 .14868 L
.52 .1486 L
.524 .14849 L
.528 .14845 L
.532 .14847 L
.536 .14848 L
.54 .14839 L
.544 .14819 L
.548 .14797 L
.552 .14786 L
.556 .14791 L
.56 .14811 L
.564 .14835 L
.568 .14854 L
.572 .14866 L
.576 .14875 L
.58 .14885 L
.584 .14897 L
.588 .14906 L
.592 .14903 L
.596 .14885 L
.6 .14851 L
Mistroke
.604 .14809 L
.608 .1477 L
.612 .14743 L
.616 .14734 L
.62 .14743 L
.624 .14765 L
.628 .14792 L
.632 .14819 L
.636 .14841 L
.64 .14862 L
.644 .14886 L
.648 .14918 L
.652 .14955 L
.656 .14986 L
.66 .14999 L
.664 .14983 L
.668 .1494 L
.672 .14883 L
.676 .14832 L
.68 .14803 L
.684 .14798 L
.688 .14804 L
.692 .14802 L
.696 .14775 L
.7 .14719 L
.704 .14647 L
.708 .1458 L
.712 .1454 L
.716 .14535 L
.72 .14563 L
.724 .14607 L
.728 .14653 L
.732 .14691 L
.736 .14722 L
.74 .14756 L
.744 .14808 L
.748 .14889 L
.752 .15003 L
.756 .15149 L
.76 .15321 L
.764 .15512 L
.768 .15714 L
.772 .15918 L
.776 .16112 L
.78 .16285 L
.784 .16427 L
.788 .16536 L
.792 .16619 L
.796 .16696 L
.8 .16788 L
Mistroke
.804 .16919 L
.808 .17103 L
.812 .17339 L
.816 .17612 L
.82 .179 L
.824 .18176 L
.828 .1842 L
.832 .18623 L
.836 .18786 L
.84 .18921 L
.844 .19044 L
.848 .19165 L
.852 .19295 L
.856 .19434 L
.86 .19582 L
.864 .19741 L
.868 .19912 L
.872 .20107 L
.876 .20337 L
.88 .20616 L
.884 .20955 L
.888 .21356 L
.892 .21814 L
.896 .22315 L
.9 .2284 L
.904 .23374 L
.908 .23901 L
.912 .24416 L
.916 .24918 L
.92 .25417 L
.924 .25925 L
.928 .26456 L
.932 .27017 L
.936 .27615 L
.94 .28246 L
.944 .28904 L
.948 .29577 L
.952 .30254 L
.956 .30923 L
.96 .31581 L
.964 .32224 L
.968 .32859 L
.972 .33494 L
.976 .3414 L
.98 .3481 L
.984 .35512 L
.988 .36254 L
.992 .37035 L
.996 .37852 L
1 .38697 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16315 L
.012 .16118 L
.016 .16052 L
.02 .16123 L
.024 .16143 L
.028 .16123 L
.032 .16113 L
.036 .16122 L
.04 .16122 L
.044 .1612 L
.048 .16118 L
.052 .16121 L
.056 .16121 L
.06 .16122 L
.064 .1612 L
.068 .16121 L
.072 .1612 L
.076 .1612 L
.08 .1612 L
.084 .16121 L
.088 .16121 L
.092 .16121 L
.096 .1612 L
.1 .1612 L
.104 .1612 L
.108 .1612 L
.112 .16121 L
.116 .16121 L
.12 .16121 L
.124 .16121 L
.128 .1612 L
.132 .1612 L
.136 .16119 L
.14 .1612 L
.144 .1612 L
.148 .16121 L
.152 .16121 L
.156 .16121 L
.16 .16121 L
.164 .1612 L
.168 .1612 L
.172 .16119 L
.176 .16119 L
.18 .16119 L
.184 .1612 L
.188 .16121 L
.192 .16122 L
.196 .16122 L
.2 .16121 L
Mistroke
.204 .1612 L
.208 .16119 L
.212 .16118 L
.216 .16117 L
.22 .16118 L
.224 .1612 L
.228 .16122 L
.232 .16123 L
.236 .16123 L
.24 .16122 L
.244 .1612 L
.248 .16118 L
.252 .16116 L
.256 .16115 L
.26 .16116 L
.264 .16119 L
.268 .16122 L
.272 .16124 L
.276 .16124 L
.28 .16124 L
.284 .16122 L
.288 .16119 L
.292 .16115 L
.296 .16112 L
.3 .16113 L
.304 .16116 L
.308 .1612 L
.312 .16124 L
.316 .16127 L
.32 .16128 L
.324 .16127 L
.328 .16123 L
.332 .16116 L
.336 .16109 L
.34 .16106 L
.344 .16108 L
.348 .16115 L
.352 .16122 L
.356 .16128 L
.36 .16132 L
.364 .16133 L
.368 .16132 L
.372 .16125 L
.376 .16115 L
.38 .16105 L
.384 .16099 L
.388 .16101 L
.392 .16109 L
.396 .16119 L
.4 .16128 L
Mistroke
.404 .16134 L
.408 .16138 L
.412 .16139 L
.416 .16135 L
.42 .16123 L
.424 .16108 L
.428 .16096 L
.432 .16093 L
.436 .161 L
.44 .1611 L
.444 .16118 L
.448 .16123 L
.452 .1613 L
.456 .16139 L
.46 .16146 L
.464 .16145 L
.468 .16132 L
.472 .16114 L
.476 .161 L
.48 .16097 L
.484 .16102 L
.488 .16107 L
.492 .16106 L
.496 .16101 L
.5 .16102 L
.504 .16115 L
.508 .16135 L
.512 .16152 L
.516 .16154 L
.52 .16144 L
.524 .16131 L
.528 .16126 L
.532 .16129 L
.536 .16129 L
.54 .16118 L
.544 .16093 L
.548 .16066 L
.552 .16052 L
.556 .16059 L
.56 .16083 L
.564 .16113 L
.568 .16136 L
.572 .16151 L
.576 .16162 L
.58 .16175 L
.584 .1619 L
.588 .162 L
.592 .16197 L
.596 .16174 L
.6 .16132 L
Mistroke
.604 .1608 L
.608 .16031 L
.612 .15997 L
.616 .15986 L
.62 .15997 L
.624 .16024 L
.628 .16059 L
.632 .16092 L
.636 .16119 L
.64 .16145 L
.644 .16175 L
.648 .16215 L
.652 .16261 L
.656 .163 L
.66 .16315 L
.664 .16295 L
.668 .16241 L
.672 .1617 L
.676 .16107 L
.68 .16071 L
.684 .16064 L
.688 .16072 L
.692 .1607 L
.696 .16036 L
.7 .15966 L
.704 .15876 L
.708 .15792 L
.712 .15742 L
.716 .15737 L
.72 .15771 L
.724 .15827 L
.728 .15883 L
.732 .1593 L
.736 .15968 L
.74 .16011 L
.744 .16076 L
.748 .16177 L
.752 .16319 L
.756 .165 L
.76 .16714 L
.764 .16952 L
.768 .17204 L
.772 .17458 L
.776 .17699 L
.78 .17914 L
.784 .18091 L
.788 .18226 L
.792 .1833 L
.796 .18424 L
.8 .18539 L
Mistroke
.804 .18702 L
.808 .1893 L
.812 .19224 L
.816 .19564 L
.82 .19922 L
.824 .20265 L
.828 .20568 L
.832 .2082 L
.836 .21022 L
.84 .2119 L
.844 .21341 L
.848 .21492 L
.852 .21652 L
.856 .21824 L
.86 .22008 L
.864 .22204 L
.868 .22416 L
.872 .22657 L
.876 .22941 L
.88 .23288 L
.884 .23707 L
.888 .24203 L
.892 .24768 L
.896 .25385 L
.9 .26031 L
.904 .26684 L
.908 .27324 L
.912 .27944 L
.916 .28541 L
.92 .29126 L
.924 .29709 L
.928 .30306 L
.932 .30923 L
.936 .31564 L
.94 .3222 L
.944 .32878 L
.948 .33518 L
.952 .34123 L
.956 .34672 L
.96 .35158 L
.964 .35575 L
.968 .35931 L
.972 .36235 L
.976 .36507 L
.98 .36768 L
.984 .37037 L
.988 .37334 L
.992 .3767 L
.996 .38055 L
1 .38491 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0GWoo0P0037oo000ROol2001OOol00`00Oomoo`0;Ool0029oo`8005moo`03001oogoo00]oo`00
2goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0GGoo00<007ooOol037oo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001NOol00`00Oomoo`0<Ool0
00=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00GWoo00<007ooOol0
37oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo05eoo`03001oogoo
00aoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001JOol200000goo001o
o`0>Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008005Yoo`04001o
o`00000?Ool000]oo`8000Yoo`8000=oo`<000=oo`03001oogoo05Uoo`03001oogoo011oo`008Woo
0P00FGoo00<007ooOol04Goo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool00`00Oomo
o`1HOol00`00Oomoo`0AOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009o
o`8005Uoo`03001oogoo015oo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2001IOol00`00Oomoo`0AOol000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00D0
07ooOomoo`0005Uoo`03001oogoo019oo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00<007ooOol00P00EWoo0`0057oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00
Oomoo`02001EOol3000EOol000]oo`8000Yoo`8000=oo`<000=oo`03001oogoo05Aoo`03001oogoo
01Eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00EGoo00<007ooOol05Goo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000eoo`<000Aoo`8000Moo`<0
00Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000=oo`D000=oo`8000Aoo`80009oo`03001oo`00
00@0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Ool00002Ool01P00Oomoo`00
Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009o
o`03001oogoo009oo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`05001oogooOol0
0002Ool01000Oomoo`000Woo0P001Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;Ool40003Ool01000
Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo1000
0goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00P000Woo
00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool00`00Oomoo`02
Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo
0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo
0002Ool00`00Oomoo`020002Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0029oo`80
00aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20004
Ool30004Ool20004Ool200000goo001oo`02Ool30002Ool50003Ool20006Ool0029oo`03001oogoo
04aoo`8000Eoo`03001oogoo01Ioo`008Woo0P00CGoo0P0017oo00<007ooOol05goo000ROomS000<
Ool0029oo`L00003Ool0000000P00005Ool00000001oo`0300001Goo00000000Ool00`0000=oo`00
00001`0000Eoo`00Ool007oo00L00003Ool0000000H00005Ool007oo001oo`020002Ool3000017oo
001oogoo0P000Woo0P000goo00D007ooOomoo`0000=oo`03001oogoo00Yoo`008Woo0P0000Aoo`00
001oo`8000Ioo`800003Ool00000009oo`<0009oo`800004Ool000000002Ool20002Ool30002Ool2
00000goo001oo`0400000goo000000030003Ool3000017oo000007oo100000=oo`00Ool00Woo0P00
0Woo00<007ooOol00P006Goo000ROol00`00Oomoo`11Ool20002Ool20003Ool20003Ool00`00Ool0
000JOol0029oo`8004]oo`8000=oo`8001]oo`008Woo0P00KGoo000;Ool20004Ool00`00Oomoo`03
Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
06eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo
00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000
Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00
KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo
00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo
0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol0
06ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eo
o`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uo
o`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1Y
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo
000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P00
2Woo0P0017oo00<007ooOol00Woo?00000=oo`0000001`008goo000XOol00`00Oomoo`0iOol20007
Ool3000QOol002Qoo`03001oogoo04Aoo`@001ioo`002goo0P0017oo00<007ooOol00goo0P0017oo
0P000goo0`000goo00<007ooOol0Agoo0P007Goo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`000goo00@007ooOol004]oo`<001Yoo`000goo1@000Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol004eoo`<001Qoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`00
17oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P0000=oo`00Ool01@00
0Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`04
0003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Ool007oo00000Woo00<007oo00000goo
00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00
Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomo
ogoo000017oo00@007ooOol0009oo`05001oogoo001oo`0200000goo001oo`06Ool01000Oomoo`00
0Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo
0002Ool00`00Oomoo`0200000goo001oo`05Ool01000Oomoo`000Woo00<007ooOol00goo000XOol0
0`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007oo
Ool0009oo`03001oogoo0080009oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001o
ogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0
009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo
0002Ool02P00Oomoo`00Ool007oo001oo`001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo
1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<0
00Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0Dgoo00<007ooOol0
47oo000XOol00`00Oomoo`1DOol00`00Oomoo`0?Ool002Qooed000aoo`00:7oo00<007ooOol03goo
00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol037oo00D007ooOomoo`00
00aoo`00:7oo00<007ooOol0EWoo00<007ooOol03Goo000XOol00`00Oomoo`1FOol00`00Oomoo`0=
Ool002Qoo`03001oogoo05Moo`03001oogoo00aoo`00:7oo00<007ooOol0Egoo00<007ooOol037oo
000XOol00`00Oomoo`1HOol00`00Oomoo`0;Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`80
00=oo`<000=oo`03001oogoo05Uoo`03001oogoo00Yoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool20002Ool50002
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`00
4Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007oo
Oomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000
K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P00
2Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo
0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=o
o`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009o
o`03001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo
0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2
000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo
00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04
001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol4
0003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04
Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomo
o`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00
Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo
0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@00
37oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`03001oogoo00<0009oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00
Oomoo`1=Ool3000ROol001aoo`80051oo`<0021oo`0077oo00<007ooOol0DWoo00<007ooOol07Goo
000LOol00`00Oomoo`1BOol3000MOol001aoo`8005Eoo`<001]oo`0077oo00<007ooOol0Egoo0P00
6Goo000LOol00`00Oomoo`1HOol2000HOol001aoo`8005Yoo`03001oogoo01Ioo`0077oo00<007oo
Ool0FWoo00<007ooOol05Goo000LOol2001KOol2000FOol000]oo`8000Aoo`03001oogoo009oo`<0
00=oo`03001oogoo05]oo`03001oogoo01Aoo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1LOol00`00Oomoo`0COol000Yoo`04001oogoo000;Ool00`00Oomoo`02001MOol2
000DOol000Yoo`04001oogoo000;Ool01000Oomoo`00Ggoo00<007ooOol04Woo000:Ool01000Oomo
o`001goo10000goo00<007ooOol0GWoo00<007ooOol04Goo000:Ool01000Oomoo`001goo00<007oo
Ool017oo0P00Ggoo00<007ooOol04Goo000;Ool20008Ool50002Ool00`00Oomoo`1OOol00`00Oomo
o`0@Ool001aoo`03001oogoo061oo`03001oogoo00moo`0077oo0P00HGoo0P0047oo000LOol00`00
Oomoo`1QOol2000?Ool001aoo`8006=oo`8000ioo`0077oo00<007ooOol0I7oo0P0037oo000LOol0
0`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02
Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol00Woo00<007oo
Ool0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<0
07ooOol00Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004
Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03
001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool0
0`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(18036\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32042 m
.008 .32 L
.012 .31924 L
.016 .31778 L
.02 .317 L
.024 .31717 L
.028 .31814 L
.032 .31949 L
.036 .32015 L
.04 .31996 L
.044 .31896 L
.048 .31765 L
.052 .31708 L
.056 .31746 L
.06 .31855 L
.064 .31981 L
.068 .32031 L
.072 .3199 L
.076 .31876 L
.08 .31754 L
.084 .3171 L
.088 .31762 L
.092 .3188 L
.096 .31998 L
.1 .32041 L
.104 .31996 L
.108 .31886 L
.112 .3177 L
.116 .31722 L
.12 .31765 L
.124 .31874 L
.128 .31983 L
.132 .3203 L
.136 .32005 L
.14 .31924 L
.144 .31828 L
.148 .31767 L
.152 .31773 L
.156 .31844 L
.16 .31932 L
.164 .31986 L
.168 .31991 L
.172 .31958 L
.176 .31909 L
.18 .31858 L
.184 .31824 L
.188 .3183 L
.192 .31871 L
.196 .31917 L
.2 .3194 L
Mistroke
.204 .31942 L
.208 .31943 L
.212 .31946 L
.216 .31932 L
.22 .319 L
.224 .3187 L
.228 .31864 L
.232 .31875 L
.236 .31885 L
.24 .31897 L
.244 .31931 L
.248 .31981 L
.252 .32008 L
.256 .31983 L
.26 .31921 L
.264 .31871 L
.268 .31855 L
.272 .31859 L
.276 .31864 L
.28 .31881 L
.284 .3193 L
.288 .31999 L
.292 .32043 L
.296 .32033 L
.3 .31985 L
.304 .3193 L
.308 .31881 L
.312 .31829 L
.316 .31782 L
.32 .31784 L
.324 .3187 L
.328 .32018 L
.332 .32146 L
.336 .32176 L
.34 .32098 L
.344 .31966 L
.348 .31847 L
.352 .31772 L
.356 .3174 L
.36 .3175 L
.364 .31819 L
.368 .31953 L
.372 .32116 L
.376 .32232 L
.38 .32234 L
.384 .3212 L
.388 .31953 L
.392 .31812 L
.396 .31736 L
.4 .31711 L
Mistroke
.404 .31722 L
.408 .31789 L
.412 .31941 L
.416 .32151 L
.42 .32317 L
.424 .32324 L
.428 .32159 L
.432 .31933 L
.436 .31793 L
.44 .31784 L
.444 .31823 L
.448 .31809 L
.452 .31747 L
.456 .31761 L
.46 .31946 L
.464 .3223 L
.468 .32406 L
.472 .3232 L
.476 .32039 L
.48 .31797 L
.484 .31784 L
.488 .31954 L
.492 .32082 L
.496 .31992 L
.5 .31752 L
.504 .31614 L
.508 .31762 L
.512 .32111 L
.516 .32371 L
.52 .32313 L
.524 .31997 L
.528 .31722 L
.532 .31752 L
.536 .32071 L
.54 .32389 L
.544 .32409 L
.548 .32092 L
.552 .31691 L
.556 .31526 L
.56 .31703 L
.564 .32037 L
.568 .32223 L
.572 .32105 L
.576 .31804 L
.58 .31603 L
.584 .31705 L
.588 .32075 L
.592 .32477 L
.596 .32661 L
.6 .32538 L
Mistroke
.604 .32217 L
.608 .31894 L
.612 .31715 L
.616 .31707 L
.62 .31799 L
.624 .31901 L
.628 .31946 L
.632 .31909 L
.636 .31801 L
.64 .31677 L
.644 .31629 L
.648 .3176 L
.652 .321 L
.656 .32553 L
.66 .32901 L
.664 .32917 L
.668 .32521 L
.672 .31874 L
.676 .31321 L
.68 .31196 L
.684 .31602 L
.688 .32318 L
.692 .32907 L
.696 .3297 L
.7 .32409 L
.704 .31502 L
.708 .30757 L
.712 .30619 L
.716 .31204 L
.72 .32222 L
.724 .33138 L
.728 .33472 L
.732 .33059 L
.736 .32124 L
.74 .31143 L
.744 .30581 L
.748 .30662 L
.752 .31289 L
.756 .32138 L
.76 .32849 L
.764 .33198 L
.768 .33162 L
.772 .32867 L
.776 .32471 L
.78 .32069 L
.784 .31678 L
.788 .31284 L
.792 .30927 L
.796 .30728 L
.8 .3085 L
Mistroke
.804 .31397 L
.808 .32313 L
.812 .3335 L
.816 .34129 L
.82 .34286 L
.824 .33632 L
.828 .32252 L
.832 .30503 L
.836 .28889 L
.84 .27887 L
.844 .27778 L
.848 .28559 L
.852 .29962 L
.856 .31568 L
.86 .32966 L
.864 .3388 L
.868 .34245 L
.872 .34176 L
.876 .3388 L
.88 .3354 L
.884 .33224 L
.888 .32851 L
.892 .32232 L
.896 .3115 L
.9 .29455 L
.904 .27137 L
.908 .24351 L
.912 .21376 L
.916 .18546 L
.92 .16145 L
.924 .14347 L
.928 .13151 L
.932 .12425 L
.936 .11913 L
.94 .11364 L
.944 .10546 L
.948 .09379 L
.952 .07878 L
.956 .06225 L
.96 .04653 L
.964 .03426 L
.968 .02775 L
.972 .02798 L
.976 .03538 L
.98 .04812 L
.984 .06461 L
.988 .08134 L
.992 .09589 L
.996 .10551 L
1 .10834 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14606 m
.008 .14875 L
.012 .14961 L
.016 .14872 L
.02 .14842 L
.024 .14875 L
.028 .14882 L
.032 .14872 L
.036 .14867 L
.04 .14873 L
.044 .14873 L
.048 .14873 L
.052 .14872 L
.056 .14873 L
.06 .14872 L
.064 .14873 L
.068 .14872 L
.072 .14873 L
.076 .14872 L
.08 .14873 L
.084 .14872 L
.088 .14873 L
.092 .14872 L
.096 .14873 L
.1 .14872 L
.104 .14873 L
.108 .14872 L
.112 .14873 L
.116 .14872 L
.12 .14872 L
.124 .14872 L
.128 .14872 L
.132 .14873 L
.136 .14873 L
.14 .14873 L
.144 .14873 L
.148 .14872 L
.152 .14873 L
.156 .14872 L
.16 .14872 L
.164 .14872 L
.168 .14872 L
.172 .14873 L
.176 .14873 L
.18 .14873 L
.184 .14873 L
.188 .14873 L
.192 .14873 L
.196 .14872 L
.2 .14871 L
Mistroke
.204 .14872 L
.208 .14873 L
.212 .14873 L
.216 .14874 L
.22 .14874 L
.224 .14874 L
.228 .14874 L
.232 .14872 L
.236 .14871 L
.24 .1487 L
.244 .14871 L
.248 .14873 L
.252 .14874 L
.256 .14875 L
.26 .14876 L
.264 .14875 L
.268 .14874 L
.272 .14872 L
.276 .1487 L
.28 .14869 L
.284 .14871 L
.288 .14873 L
.292 .14874 L
.296 .14875 L
.3 .14877 L
.304 .14878 L
.308 .14876 L
.312 .14874 L
.316 .1487 L
.32 .14868 L
.324 .14868 L
.328 .14869 L
.332 .14872 L
.336 .14876 L
.34 .14879 L
.344 .14882 L
.348 .14881 L
.352 .14878 L
.356 .14872 L
.36 .14866 L
.364 .14864 L
.368 .14865 L
.372 .14868 L
.376 .14872 L
.38 .14877 L
.384 .14883 L
.388 .14887 L
.392 .14887 L
.396 .14882 L
.4 .14872 L
Mistroke
.404 .14863 L
.408 .14859 L
.412 .1486 L
.416 .14865 L
.42 .1487 L
.424 .14876 L
.428 .14883 L
.432 .1489 L
.436 .14893 L
.44 .1489 L
.444 .1488 L
.448 .14867 L
.452 .14858 L
.456 .14856 L
.46 .1486 L
.464 .14864 L
.468 .14868 L
.472 .14872 L
.476 .1488 L
.48 .14891 L
.484 .14899 L
.488 .14898 L
.492 .14887 L
.496 .14873 L
.5 .14864 L
.504 .14863 L
.508 .14866 L
.512 .14866 L
.516 .1486 L
.52 .14855 L
.524 .14858 L
.528 .1487 L
.532 .14887 L
.536 .14899 L
.54 .14899 L
.544 .14892 L
.548 .14886 L
.552 .14887 L
.556 .14892 L
.56 .14892 L
.564 .14881 L
.568 .14859 L
.572 .14837 L
.576 .14824 L
.58 .14828 L
.584 .14843 L
.588 .14862 L
.592 .14878 L
.596 .1489 L
.6 .14901 L
Mistroke
.604 .14915 L
.608 .14932 L
.612 .14945 L
.616 .14948 L
.62 .14934 L
.624 .14905 L
.628 .14864 L
.632 .14823 L
.636 .14791 L
.64 .14775 L
.644 .14777 L
.648 .14793 L
.652 .14816 L
.656 .14839 L
.66 .14858 L
.664 .14876 L
.668 .14901 L
.672 .14935 L
.676 .14978 L
.68 .15018 L
.684 .15039 L
.688 .1503 L
.692 .14992 L
.696 .14938 L
.7 .14888 L
.704 .14858 L
.708 .14852 L
.712 .14859 L
.716 .1486 L
.72 .14836 L
.724 .14783 L
.728 .14712 L
.732 .14642 L
.736 .14594 L
.74 .14578 L
.744 .14594 L
.748 .14628 L
.752 .14666 L
.756 .14698 L
.76 .14724 L
.764 .14752 L
.768 .14794 L
.772 .14859 L
.776 .14955 L
.78 .15082 L
.784 .15237 L
.788 .15417 L
.792 .15614 L
.796 .1582 L
.8 .16023 L
Mistroke
.804 .16209 L
.808 .16365 L
.812 .16485 L
.816 .16574 L
.82 .16648 L
.824 .16728 L
.828 .1684 L
.832 .17 L
.836 .17214 L
.84 .17473 L
.844 .17754 L
.848 .18035 L
.852 .18291 L
.856 .18511 L
.86 .18694 L
.864 .18846 L
.868 .1898 L
.872 .1911 L
.876 .19243 L
.88 .19384 L
.884 .19531 L
.888 .19688 L
.892 .19856 L
.896 .20046 L
.9 .20271 L
.904 .20548 L
.908 .20889 L
.912 .21303 L
.916 .21787 L
.92 .22335 L
.924 .22931 L
.928 .23559 L
.932 .24205 L
.936 .24859 L
.94 .2552 L
.944 .26191 L
.948 .26881 L
.952 .276 L
.956 .28354 L
.96 .29145 L
.964 .29967 L
.968 .30808 L
.972 .31652 L
.976 .32482 L
.98 .33278 L
.984 .34034 L
.988 .34738 L
.992 .35401 L
.996 .36025 L
1 .36634 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16185 L
.012 .16128 L
.016 .16097 L
.02 .16116 L
.024 .16127 L
.028 .16128 L
.032 .1612 L
.036 .1612 L
.04 .16118 L
.044 .16119 L
.048 .16118 L
.052 .16121 L
.056 .16122 L
.06 .16124 L
.064 .16122 L
.068 .16121 L
.072 .16118 L
.076 .16119 L
.08 .16119 L
.084 .16121 L
.088 .16122 L
.092 .16122 L
.096 .16121 L
.1 .1612 L
.104 .16119 L
.108 .16119 L
.112 .16119 L
.116 .16121 L
.12 .16121 L
.124 .16121 L
.128 .1612 L
.132 .1612 L
.136 .16119 L
.14 .1612 L
.144 .1612 L
.148 .16121 L
.152 .16121 L
.156 .1612 L
.16 .16119 L
.164 .16119 L
.168 .16119 L
.172 .1612 L
.176 .16121 L
.18 .16121 L
.184 .16121 L
.188 .16121 L
.192 .1612 L
.196 .16119 L
.2 .16118 L
Mistroke
.204 .16118 L
.208 .1612 L
.212 .16121 L
.216 .16122 L
.22 .16122 L
.224 .16121 L
.228 .1612 L
.232 .16119 L
.236 .16117 L
.24 .16117 L
.244 .16118 L
.248 .1612 L
.252 .16121 L
.256 .16122 L
.26 .16122 L
.264 .16122 L
.268 .16121 L
.272 .16118 L
.276 .16116 L
.28 .16115 L
.284 .16116 L
.288 .16118 L
.292 .1612 L
.296 .16122 L
.3 .16124 L
.304 .16125 L
.308 .16123 L
.312 .16119 L
.316 .16114 L
.32 .16112 L
.324 .16112 L
.328 .16115 L
.332 .16118 L
.336 .16122 L
.34 .16125 L
.344 .16129 L
.348 .16129 L
.352 .16125 L
.356 .16117 L
.36 .1611 L
.364 .16107 L
.368 .16107 L
.372 .16112 L
.376 .16117 L
.38 .16124 L
.384 .1613 L
.388 .16135 L
.392 .16134 L
.396 .16128 L
.4 .16117 L
Mistroke
.404 .16106 L
.408 .16101 L
.412 .16102 L
.416 .16107 L
.42 .16113 L
.424 .16121 L
.428 .1613 L
.432 .16138 L
.436 .16143 L
.44 .16139 L
.444 .16125 L
.448 .16109 L
.452 .16098 L
.456 .16096 L
.46 .16101 L
.464 .16106 L
.468 .1611 L
.472 .16115 L
.476 .16125 L
.48 .16139 L
.484 .16149 L
.488 .16147 L
.492 .16133 L
.496 .16115 L
.5 .16104 L
.504 .16104 L
.508 .16107 L
.512 .16107 L
.516 .161 L
.52 .16093 L
.524 .16096 L
.528 .16112 L
.532 .16134 L
.536 .16148 L
.54 .16148 L
.544 .16139 L
.548 .16132 L
.552 .16133 L
.556 .16139 L
.56 .16139 L
.564 .16124 L
.568 .16097 L
.572 .16069 L
.576 .16054 L
.58 .16058 L
.584 .16077 L
.588 .16101 L
.592 .1612 L
.596 .16135 L
.6 .16149 L
Mistroke
.604 .16167 L
.608 .16187 L
.612 .16204 L
.616 .16207 L
.62 .1619 L
.624 .16153 L
.628 .16103 L
.632 .16052 L
.636 .16012 L
.64 .15991 L
.644 .15993 L
.648 .16014 L
.652 .16042 L
.656 .1607 L
.66 .16094 L
.664 .16117 L
.668 .16147 L
.672 .1619 L
.676 .16244 L
.68 .16293 L
.684 .16319 L
.688 .16308 L
.692 .1626 L
.696 .16193 L
.7 .1613 L
.704 .16093 L
.708 .16086 L
.712 .16095 L
.716 .16095 L
.72 .16065 L
.724 .15999 L
.728 .1591 L
.732 .15823 L
.736 .15763 L
.74 .15744 L
.744 .15764 L
.748 .15806 L
.752 .15853 L
.756 .15893 L
.76 .15925 L
.764 .1596 L
.768 .16012 L
.772 .16094 L
.776 .16213 L
.78 .16371 L
.784 .16564 L
.788 .16787 L
.792 .17033 L
.796 .1729 L
.8 .17542 L
Mistroke
.804 .17773 L
.808 .17968 L
.812 .18117 L
.816 .18228 L
.82 .18318 L
.824 .18418 L
.828 .18556 L
.832 .18756 L
.836 .19022 L
.84 .19343 L
.844 .19693 L
.848 .20041 L
.852 .20358 L
.856 .2063 L
.86 .20854 L
.864 .21039 L
.868 .21201 L
.872 .21354 L
.876 .21509 L
.88 .2167 L
.884 .21834 L
.888 .22003 L
.892 .22178 L
.896 .2237 L
.9 .22592 L
.904 .22861 L
.908 .23189 L
.912 .23583 L
.916 .24034 L
.92 .24532 L
.924 .25049 L
.928 .25564 L
.932 .26052 L
.936 .26501 L
.94 .26906 L
.944 .27274 L
.948 .27618 L
.952 .27955 L
.956 .28302 L
.96 .28669 L
.964 .29061 L
.968 .29476 L
.972 .29905 L
.976 .30338 L
.98 .30761 L
.984 .31168 L
.988 .31547 L
.992 .31908 L
.996 .32242 L
1 .32572 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001LOol2000?Ool0029oo`8005aoo`8000moo`002goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo00<007ooOol0Fgoo00<007oo00003Woo000:Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool00`00Oomoo`02001KOol01000Oomoo`003Woo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol000Eoo`03001oogoo008005]oo`04001oogoo000>Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo0P000goo00<007ooOol0FWoo00@007ooOol000ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0005Ool00`00Oomoo`02001KOol01000Oomoo`003Woo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001JOol00`00Oomoo`02Ool00`00Oomoo`0;
Ool000]oo`8000Yoo`8000=oo`<000=oo`03001oogoo05Uoo`03001oogoo009oo`8000aoo`008Woo
0P00FGoo00<007ooOol04Goo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool00`00Oomo
o`1HOol00`00Oomoo`0AOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009o
o`8005Qoo`03001oogoo019oo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2001HOol00`00Oomoo`0BOol000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00D0
07ooOomoo`0005Uoo`03001oogoo019oo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00<007ooOol00P00F7oo00<007ooOol04Woo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001GOol00`00Oomoo`0COol000]oo`8000Yoo`8000=oo`<000=oo`03001oogoo
05Ioo`03001oogoo01=oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00Egoo00<0
07ooOol04goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000eoo`<0
00Aoo`8000Moo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000=oo`D000=oo`8000Aoo`80
00Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoogoo0P000Woo00<0
07oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
0Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00007Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00]oo`@0
00=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001o
ogooOol40003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomo
o`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool00`00
Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04
001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007oo00001Woo00@007ooOol000Eoo`008Woo
0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`80
00Aoo`<000Aoo`8000=oo`<000=oo`03001oo`000080009oo`D000=oo`8000Ioo`008Woo00<007oo
Ool0Cgoo0P0017oo00<007ooOol057oo000ROol2001@Ool20004Ool00`00Oomoo`0DOol0029oof<0
00aoo`008Woo1`0000Aoo`00001oo`800003Ool0000000D00003Ool0000000D00005Ool00000001o
o`03000017oo000000000Woo0`0000=oo`00Ool0100000=oo`0000000P0000=oo`0000000`000Woo
0P0000Aoo`00001oo`<0009oo`80009oo`800003Ool007oo0080009oo`05001oogooOol00003Ool0
0`00Oomoo`0:Ool0029oo`800004Ool00000Ool20002Ool01000Oomoo`000Woo0P000Woo0P000Woo
0P000Woo0P000Woo0`0000Eoo`00000007oo00<0009oo`@00003Ool0000000P00004Ool007ooOol2
000027oo000007oo001oo`00Ool30002Ool00`00Ool00002Ool01000Oomoo`005goo000ROol00`00
Oomoo`11Ool01000Oomoo`000goo00@007ooOomoo`8000=oo`<001Qoo`008Woo0P00CWoo00<007oo
Ool00Woo00<007ooOol05goo000ROol2001]Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2
001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/
Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool0
1000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`80
00Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03
Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001o
ogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04
001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00
Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yo
o`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool0
0`00Oomoo`02Oolo00000goo00000006000QOol002Qoo`8003aoo`8000Moo`<001moo`00:7oo00<0
07ooOol0Agoo0`0077oo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00
Oomoo`1:Ool2000JOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003
Ool01000Oomoo`00CGoo0`0067oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04
001oogoo0005Ool01000Oomoo`00D7oo0P005Woo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool3
0003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001o
ogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol0
0goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0
3Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo
00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yo
o`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo009oo`8000Ioo`04
001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`800003Ool00000
008000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006
Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo
001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo0P0000=oo`00Ool0
1Goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P00
17oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`@00003Ool00000
00<000=oo`8000Ioo`00:7oo00<007ooOol0EGoo00<007ooOol03Woo000XOol00`00Oomoo`1EOol0
0`00Oomoo`0>Ool002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol0
3goo00<007ooOol03goo00<007ooOol03Goo00@007ooOol000aoo`00:7oo00<007ooOol0EWoo0P00
3Woo000XOol00`00Oomoo`1GOol00`00Oomoo`0<Ool002Qoo`03001oogoo05Moo`8000eoo`00:7oo
00<007ooOol0F7oo0P0037oo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`80
00Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00
Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06
001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomo
o`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P00
2Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3
0003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`00
00=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo
00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03
001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P00
17oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo
00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo
00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001o
ogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo
0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool0
1@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo
0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool0
1000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007oo
Oomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000
Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool0
1000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007oo
Oomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03
Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo
1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000L
Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`06001oogooOol007oo0`000goo00D007oo
Oomoo`0000=oo`05001oogooOol00004Ool00`00Oomoo`0:Ool001aoo`03001oogoo051oo`<001mo
o`0077oo0P00Dgoo0`007Goo000LOol00`00Oomoo`1DOol2000LOol001aoo`03001oogoo05Eoo`<0
01Yoo`0077oo0P00F7oo0`0067oo000LOol00`00Oomoo`1IOol3000FOol001aoo`03001oogoo05]o
o`8001Eoo`0077oo0P00GGoo0P0057oo000LOol00`00Oomoo`1MOol00`00Oomoo`0BOol001aoo`80
05moo`03001oogoo015oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0Ggoo00<0
07ooOol047oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo061oo`03001o
ogoo00moo`002Woo00@007ooOol000]oo`03001oogoo0080069oo`03001oogoo00ioo`002Woo00@0
07ooOol000]oo`04001oogoo001TOol00`00Oomoo`0=Ool000Yoo`04001oogoo0007Ool40003Ool0
0`00Oomoo`1SOol00`00Oomoo`0<Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001UOol2
000<Ool000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001o
ogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol0
01Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001o
ogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo
079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol0
0P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo
00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(18203\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3164 m
.008 .31762 L
.012 .31947 L
.016 .3202 L
.02 .31953 L
.024 .31883 L
.028 .31813 L
.032 .31763 L
.036 .31759 L
.04 .31805 L
.044 .31895 L
.048 .3195 L
.052 .31949 L
.056 .31914 L
.06 .31849 L
.064 .31803 L
.068 .31795 L
.072 .31818 L
.076 .31869 L
.08 .31909 L
.084 .31925 L
.088 .31923 L
.092 .31896 L
.096 .31864 L
.1 .31838 L
.104 .31826 L
.108 .31839 L
.112 .31862 L
.116 .31892 L
.12 .31925 L
.124 .31941 L
.128 .31931 L
.132 .31892 L
.136 .31846 L
.14 .3182 L
.144 .3182 L
.148 .31851 L
.152 .31904 L
.156 .31958 L
.16 .31983 L
.164 .31958 L
.168 .31894 L
.172 .31832 L
.176 .31803 L
.18 .31817 L
.184 .31863 L
.188 .31926 L
.192 .31985 L
.196 .32004 L
.2 .31966 L
Mistroke
.204 .31892 L
.208 .31831 L
.212 .31814 L
.216 .31838 L
.22 .3188 L
.224 .31929 L
.228 .31973 L
.232 .31992 L
.236 .31966 L
.24 .31911 L
.244 .31869 L
.248 .31867 L
.252 .31887 L
.256 .31897 L
.26 .31891 L
.264 .31897 L
.268 .31927 L
.272 .31962 L
.276 .31976 L
.28 .31969 L
.284 .31957 L
.288 .31939 L
.292 .31899 L
.296 .31843 L
.3 .3181 L
.304 .31842 L
.308 .31931 L
.312 .32018 L
.316 .32052 L
.32 .32033 L
.324 .31994 L
.328 .31955 L
.332 .31906 L
.336 .31837 L
.34 .31779 L
.344 .3178 L
.348 .31863 L
.352 .31992 L
.356 .32101 L
.36 .32142 L
.364 .32112 L
.368 .32035 L
.372 .31933 L
.376 .31821 L
.38 .31726 L
.384 .31694 L
.388 .31767 L
.392 .31933 L
.396 .32116 L
.4 .32224 L
Mistroke
.404 .32211 L
.408 .32111 L
.412 .31997 L
.416 .31907 L
.42 .31826 L
.424 .31733 L
.428 .31662 L
.432 .31699 L
.436 .31886 L
.44 .32149 L
.444 .32326 L
.448 .32306 L
.452 .3213 L
.456 .31953 L
.46 .31889 L
.464 .31907 L
.468 .31883 L
.472 .3176 L
.476 .31642 L
.48 .31693 L
.484 .31959 L
.488 .32273 L
.492 .32398 L
.496 .32245 L
.5 .31969 L
.504 .31824 L
.508 .31914 L
.512 .32094 L
.516 .32121 L
.52 .31912 L
.524 .31643 L
.528 .31584 L
.532 .31834 L
.536 .32203 L
.54 .32378 L
.544 .32214 L
.548 .31873 L
.552 .31679 L
.556 .31822 L
.56 .32184 L
.564 .32445 L
.568 .3237 L
.572 .32013 L
.576 .31664 L
.58 .31594 L
.584 .31825 L
.588 .32127 L
.592 .32226 L
.596 .32036 L
.6 .31724 L
Mistroke
.604 .31558 L
.608 .31693 L
.612 .32059 L
.616 .3243 L
.62 .32599 L
.624 .32506 L
.628 .32244 L
.632 .31972 L
.636 .31804 L
.64 .31769 L
.644 .31834 L
.648 .31934 L
.652 .32002 L
.656 .31978 L
.66 .31843 L
.664 .31647 L
.668 .31519 L
.672 .31607 L
.676 .3197 L
.68 .32497 L
.684 .32928 L
.688 .32989 L
.692 .32583 L
.696 .31887 L
.7 .31282 L
.704 .31137 L
.708 .31566 L
.712 .32336 L
.716 .32984 L
.72 .33087 L
.724 .3253 L
.728 .3159 L
.732 .30784 L
.736 .30578 L
.74 .31111 L
.744 .32119 L
.748 .33078 L
.752 .33502 L
.756 .33192 L
.76 .32329 L
.764 .31351 L
.768 .30711 L
.772 .30656 L
.776 .31135 L
.78 .31878 L
.784 .32562 L
.788 .32967 L
.792 .33049 L
.796 .3289 L
.8 .32603 L
Mistroke
.804 .32251 L
.808 .31831 L
.812 .31336 L
.816 .30822 L
.82 .30442 L
.824 .30399 L
.828 .30842 L
.832 .31751 L
.836 .32893 L
.84 .33874 L
.844 .3428 L
.848 .33845 L
.852 .32576 L
.856 .30763 L
.86 .28892 L
.864 .27465 L
.868 .2683 L
.872 .27068 L
.876 .27982 L
.88 .29189 L
.884 .30268 L
.888 .30904 L
.892 .30973 L
.896 .30542 L
.9 .29803 L
.904 .2895 L
.908 .28104 L
.912 .27234 L
.916 .26215 L
.92 .24848 L
.924 .23006 L
.928 .20659 L
.932 .17958 L
.936 .15177 L
.94 .1266 L
.944 .10735 L
.948 .09583 L
.952 .09265 L
.956 .09592 L
.96 .10313 L
.964 .11033 L
.968 .11439 L
.972 .11295 L
.976 .10489 L
.98 .09162 L
.984 .07443 L
.988 .05743 L
.992 .0427 L
.996 .03378 L
1 .0318 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14781 m
.008 .14902 L
.012 .14944 L
.016 .14917 L
.02 .14899 L
.024 .14908 L
.028 .14911 L
.032 .14909 L
.036 .14905 L
.04 .14907 L
.044 .14908 L
.048 .14911 L
.052 .1491 L
.056 .1491 L
.06 .14908 L
.064 .14907 L
.068 .14906 L
.072 .14908 L
.076 .14909 L
.08 .1491 L
.084 .1491 L
.088 .1491 L
.092 .14908 L
.096 .14908 L
.1 .14907 L
.104 .14908 L
.108 .14909 L
.112 .1491 L
.116 .14909 L
.12 .14909 L
.124 .14908 L
.128 .14908 L
.132 .14908 L
.136 .14909 L
.14 .14909 L
.144 .14909 L
.148 .14909 L
.152 .14909 L
.156 .14908 L
.16 .14909 L
.164 .14909 L
.168 .14909 L
.172 .14909 L
.176 .14909 L
.18 .14909 L
.184 .14908 L
.188 .14908 L
.192 .14908 L
.196 .14909 L
.2 .14909 L
Mistroke
.204 .1491 L
.208 .1491 L
.212 .1491 L
.216 .14909 L
.22 .14908 L
.224 .14907 L
.228 .14908 L
.232 .14909 L
.236 .14909 L
.24 .1491 L
.244 .14911 L
.248 .14911 L
.252 .1491 L
.256 .14908 L
.26 .14907 L
.264 .14907 L
.268 .14908 L
.272 .14908 L
.276 .14909 L
.28 .14911 L
.284 .14912 L
.288 .14912 L
.292 .14911 L
.296 .14909 L
.3 .14907 L
.304 .14906 L
.308 .14906 L
.312 .14907 L
.316 .14909 L
.32 .14912 L
.324 .14914 L
.328 .14915 L
.332 .14913 L
.336 .1491 L
.34 .14907 L
.344 .14905 L
.348 .14905 L
.352 .14905 L
.356 .14906 L
.36 .1491 L
.364 .14915 L
.368 .14918 L
.372 .14919 L
.376 .14915 L
.38 .14909 L
.384 .14904 L
.388 .14901 L
.392 .14901 L
.396 .14902 L
.4 .14906 L
Mistroke
.404 .14911 L
.408 .14918 L
.412 .14924 L
.416 .14924 L
.42 .14919 L
.424 .14911 L
.428 .14903 L
.432 .14898 L
.436 .14897 L
.44 .14899 L
.444 .14902 L
.448 .14908 L
.452 .14917 L
.456 .14927 L
.46 .14931 L
.464 .14928 L
.468 .14918 L
.472 .14906 L
.476 .14899 L
.48 .14897 L
.484 .14897 L
.488 .14897 L
.492 .14898 L
.496 .14903 L
.5 .14914 L
.504 .14928 L
.508 .14936 L
.512 .14933 L
.516 .14923 L
.52 .14911 L
.524 .14906 L
.528 .14906 L
.532 .14906 L
.536 .14901 L
.54 .14893 L
.544 .14887 L
.548 .14892 L
.552 .14906 L
.556 .14922 L
.56 .14931 L
.564 .1493 L
.568 .14925 L
.572 .14923 L
.576 .14928 L
.58 .14935 L
.584 .14935 L
.588 .14922 L
.592 .149 L
.596 .14878 L
.6 .14865 L
Mistroke
.604 .14866 L
.608 .14876 L
.612 .1489 L
.616 .14903 L
.62 .14913 L
.624 .14926 L
.628 .14943 L
.632 .14963 L
.636 .14981 L
.64 .1499 L
.644 .14982 L
.648 .14957 L
.652 .1492 L
.656 .14878 L
.66 .14842 L
.664 .1482 L
.668 .14815 L
.672 .14826 L
.676 .14844 L
.68 .14861 L
.684 .14876 L
.688 .14891 L
.692 .14914 L
.696 .14951 L
.7 .14998 L
.704 .15045 L
.708 .15074 L
.712 .15073 L
.716 .15041 L
.72 .14991 L
.724 .14942 L
.728 .14912 L
.732 .14906 L
.736 .14913 L
.74 .14916 L
.744 .14896 L
.748 .14847 L
.752 .14778 L
.756 .14706 L
.76 .14652 L
.764 .14627 L
.768 .14631 L
.772 .14655 L
.776 .14685 L
.78 .14712 L
.784 .14733 L
.788 .14755 L
.792 .14788 L
.796 .1484 L
.8 .14918 L
Mistroke
.804 .15026 L
.808 .15163 L
.812 .15328 L
.816 .15517 L
.82 .15722 L
.824 .15931 L
.828 .16129 L
.832 .163 L
.836 .16435 L
.84 .16535 L
.844 .16612 L
.848 .16688 L
.852 .16788 L
.856 .16933 L
.86 .17134 L
.864 .17386 L
.868 .17674 L
.872 .17975 L
.876 .18267 L
.88 .18537 L
.884 .18781 L
.888 .19005 L
.892 .19219 L
.896 .19439 L
.9 .19673 L
.904 .19927 L
.908 .20203 L
.912 .20501 L
.916 .20823 L
.92 .21177 L
.924 .21572 L
.928 .2202 L
.932 .22531 L
.936 .23111 L
.94 .23754 L
.944 .2445 L
.948 .25179 L
.952 .2592 L
.956 .26653 L
.96 .27366 L
.964 .2805 L
.968 .28715 L
.972 .29366 L
.976 .30025 L
.98 .30703 L
.984 .31415 L
.988 .32166 L
.992 .32951 L
.996 .33764 L
1 .34584 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15935 L
.012 .16127 L
.016 .16183 L
.02 .1612 L
.024 .16097 L
.028 .16122 L
.032 .16126 L
.036 .16121 L
.04 .16117 L
.044 .16122 L
.048 .16121 L
.052 .16121 L
.056 .16119 L
.06 .16121 L
.064 .1612 L
.068 .16121 L
.072 .1612 L
.076 .16121 L
.08 .1612 L
.084 .16121 L
.088 .1612 L
.092 .16121 L
.096 .1612 L
.1 .1612 L
.104 .1612 L
.108 .1612 L
.112 .1612 L
.116 .16121 L
.12 .1612 L
.124 .16121 L
.128 .1612 L
.132 .1612 L
.136 .1612 L
.14 .1612 L
.144 .1612 L
.148 .1612 L
.152 .1612 L
.156 .1612 L
.16 .1612 L
.164 .1612 L
.168 .1612 L
.172 .1612 L
.176 .1612 L
.18 .1612 L
.184 .16119 L
.188 .16119 L
.192 .16119 L
.196 .1612 L
.2 .1612 L
Mistroke
.204 .16121 L
.208 .16121 L
.212 .16121 L
.216 .1612 L
.22 .16118 L
.224 .16118 L
.228 .16118 L
.232 .16119 L
.236 .1612 L
.24 .16121 L
.244 .16122 L
.248 .16122 L
.252 .16121 L
.256 .16118 L
.26 .16117 L
.264 .16117 L
.268 .16117 L
.272 .16118 L
.276 .1612 L
.28 .16122 L
.284 .16123 L
.288 .16123 L
.292 .16121 L
.296 .16118 L
.3 .16116 L
.304 .16116 L
.308 .16116 L
.312 .16117 L
.316 .16118 L
.32 .16121 L
.324 .16124 L
.328 .16126 L
.332 .16124 L
.336 .1612 L
.34 .16116 L
.344 .16113 L
.348 .16112 L
.352 .16113 L
.356 .16115 L
.36 .1612 L
.364 .16125 L
.368 .16129 L
.372 .16129 L
.376 .16125 L
.38 .16118 L
.384 .16112 L
.388 .16108 L
.392 .16107 L
.396 .16108 L
.4 .16113 L
Mistroke
.404 .1612 L
.408 .16129 L
.412 .16136 L
.416 .16136 L
.42 .16129 L
.424 .16118 L
.428 .16109 L
.432 .16103 L
.436 .16102 L
.44 .16104 L
.444 .16107 L
.448 .16114 L
.452 .16126 L
.456 .16138 L
.46 .16145 L
.464 .1614 L
.468 .16127 L
.472 .16112 L
.476 .16103 L
.48 .16101 L
.484 .16101 L
.488 .16101 L
.492 .16102 L
.496 .16108 L
.5 .16122 L
.504 .16139 L
.508 .16149 L
.512 .16146 L
.516 .16132 L
.52 .16118 L
.524 .16111 L
.528 .16111 L
.532 .16112 L
.536 .16106 L
.54 .16094 L
.544 .16087 L
.548 .16093 L
.552 .16111 L
.556 .16131 L
.56 .16142 L
.564 .1614 L
.568 .16134 L
.572 .16132 L
.576 .16138 L
.58 .16147 L
.584 .16146 L
.588 .1613 L
.592 .16102 L
.596 .16074 L
.6 .16058 L
Mistroke
.604 .16059 L
.608 .16073 L
.612 .1609 L
.616 .16105 L
.62 .16118 L
.624 .16134 L
.628 .16156 L
.632 .16181 L
.636 .16203 L
.64 .16213 L
.644 .16203 L
.648 .16173 L
.652 .16126 L
.656 .16074 L
.66 .16028 L
.664 .16001 L
.668 .15995 L
.672 .16008 L
.676 .1603 L
.68 .16052 L
.684 .1607 L
.688 .16089 L
.692 .16118 L
.696 .16163 L
.7 .16223 L
.704 .16281 L
.708 .16317 L
.712 .16315 L
.716 .16275 L
.72 .16213 L
.724 .16152 L
.728 .16115 L
.732 .16107 L
.736 .16116 L
.74 .16118 L
.744 .16093 L
.748 .16033 L
.752 .15946 L
.756 .15857 L
.76 .1579 L
.764 .15759 L
.768 .15764 L
.772 .15793 L
.776 .15831 L
.78 .15864 L
.784 .1589 L
.788 .15918 L
.792 .15958 L
.796 .16023 L
.8 .1612 L
Mistroke
.804 .16254 L
.808 .16424 L
.812 .1663 L
.816 .16864 L
.82 .17119 L
.824 .17378 L
.828 .17623 L
.832 .17834 L
.836 .17998 L
.84 .18118 L
.844 .18206 L
.848 .18291 L
.852 .18402 L
.856 .18566 L
.86 .18792 L
.864 .19075 L
.868 .19391 L
.872 .19711 L
.876 .20004 L
.88 .2025 L
.884 .20439 L
.888 .20576 L
.892 .20668 L
.896 .20729 L
.9 .20766 L
.904 .20782 L
.908 .20776 L
.912 .20748 L
.916 .20699 L
.92 .20641 L
.924 .2059 L
.928 .20568 L
.932 .20597 L
.936 .20693 L
.94 .20862 L
.944 .21104 L
.948 .21404 L
.952 .21747 L
.956 .22113 L
.96 .2249 L
.964 .22866 L
.968 .23245 L
.972 .23624 L
.976 .24019 L
.98 .24428 L
.984 .24861 L
.988 .25311 L
.992 .25773 L
.996 .26238 L
1 .26688 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001POol00`00Oomoo`0:Ool0029oo`8005moo`03001oogoo00]oo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0GWoo00<007ooOol02goo000:Ool01000
Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001NOol00`00Oomoo`0<Ool000=oo`D0
009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00GWoo00<007ooOol037oo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo05eoo`03001oogoo00aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001KOol01000Oomoo`003Woo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001JOol300000goo001oo`0=
Ool000]oo`8000Yoo`8000=oo`<000=oo`03001oogoo05Uoo`04001oo`00000?Ool0029oo`8005Yo
o`03001oo`00011oo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo00<007ooOol0FGoo
00<007ooOol047oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001J
Ool00`00Oomoo`0@Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P00FGoo00<007ooOol04Goo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`05001oogoo
Ool0001JOol00`00Oomoo`0AOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001o
ogoo008005Uoo`03001oogoo015oo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<0
07ooOol00P00FGoo00<007ooOol04Goo000;Ool2000:Ool20003Ool30003Ool00`00Oomoo`1HOol0
0`00Oomoo`0AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8005Uoo`03001oogoo
015oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000=Ool30004Ool2
0007Ool30004Ool20004Ool20005Ool30003Ool30004Ool20003Ool50003Ool20004Ool20004Ool5
0002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol02goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00D007oo
Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo0P0000Aoo`00Ool0
00=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo0P001goo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`00009oo`04001oogoo
0002Ool00`00Oomoo`02Ool00`00Ool00006Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00]oo`@000=oo`04001oogoo0007
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000
Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo0P000Woo00<0
07oo00000`000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo0P0037oo
00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P00
0goo00<007ooOol017oo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@0
07ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`008Woo0P0037oo1@000goo
0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`80
00Aoo`<000=oo`@0009oo`D000=oo`8000Ioo`008Woo00<007ooOol0DGoo0P000goo00<007ooOol0
4goo000ROol2001BOol01@00Ool007oo00005Woo000ROomS000<Ool0029oo`D00003Ool0000000/0
0005Ool00000001oo`0400000goo0000000500001Goo00000000Ool00`0000Eoo`00000007oo00@0
0003Ool0000000800004Ool007ooOol500000goo0000000300001Goo00000000Ool00P0000Ioo`00
001oo`00Ool20002Ool01@00Oomoogoo00000goo00<007ooOol02Woo000ROol30002Ool00`00Oomo
o`04Ool200000goo00000002Ool200000goo00000003Ool200001Goo00000000Ool00`0000Aoo`00
0000009oo`<00003Ool0000000800004Ool00000Ool400000goo0000000300001Goo00000000Ool0
0P0000=oo`0000000Woo0P000goo0P006goo000ROol00`00Oomoo`10Ool01000Oomoo`000Woo0P00
0Woo00<007ooOol00Woo0P006goo000ROol2001@Ool00`00Oomoo`0JOol0029oo`8006eoo`002goo
0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
06eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`80
00Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@00
0Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool0
1P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001o
o`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomo
o`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol0
00Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007oo
Ool000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo
0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo
0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol0
0003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eo
o`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000
0goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo
00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P00
17oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00
Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009ooc/00003Ool000000080009oo`P001mo
o`00:7oo00<007ooOol0=goo0P0017oo0`001goo0P007Goo000XOol00`00Oomoo`19Ool4000IOol0
00]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo04aoo`8001Qoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001?Ool3
000FOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001o
ogoo001AOol2000EOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009o
o`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001o
ogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Oomoo`800004Ool007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo
00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000Io
o`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001o
ogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool0
02Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo
00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000goo0`001Woo00@007ooOol000Eoo`00:7oo00<007ooOol0
2Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=o
o`<000Aoo`8000Aoo`8000Aoo`<00003Ool0000000@000=oo`8000Ioo`00:7oo00<007ooOol0EWoo
00<007ooOol03Goo000XOol00`00Oomoo`1FOol00`00Oomoo`0=Ool002Qooed000aoo`00:7oo00<0
07ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol03Woo00<0
07oo000037oo000XOol00`00Oomoo`1HOol00`00Oomoo`0;Ool002Qoo`03001oogoo05Qoo`8000ao
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P00
17oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Ao
o`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04
001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0
KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<0
07ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Mo
o`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo
0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool2
0004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool2
0006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo
00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo
00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001o
ogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007oo
Ool0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`00
0Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P00
3Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04
001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00ao
o`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`80
00=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04
001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=o
o`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool2
0004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomo
o`0000=oo`<00003Ool007oo009oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:
Ool001aoo`03001oogoo059oo`<001eoo`0077oo0P00EWoo0`006Woo000LOol00`00Oomoo`1GOol2
000IOol001aoo`03001oogoo05Qoo`P0019oo`0077oo0P00H7oo0P004Goo000LOol00`00Oomoo`1P
Ool2000@Ool001aoo`03001oogoo065oo`8000moo`0077oo0P00Hgoo0P003Woo000LOol00`00Oomo
o`1SOol2000=Ool001aoo`8006Eoo`8000aoo`002goo0P0017oo00<007ooOol00Woo0`000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo
00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol0
00Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomo
o`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009o
o`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomo
o`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00
Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Ao
o`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03
001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<0
07ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03
001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(18370\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31672 m
.008 .31737 L
.012 .31821 L
.016 .31939 L
.02 .3198 L
.024 .31948 L
.028 .31866 L
.032 .31767 L
.036 .31733 L
.04 .31771 L
.044 .31863 L
.048 .31961 L
.052 .31983 L
.056 .31931 L
.06 .31838 L
.064 .31752 L
.068 .31743 L
.072 .31806 L
.076 .31904 L
.08 .31985 L
.084 .31986 L
.088 .31921 L
.092 .31826 L
.096 .31752 L
.1 .31752 L
.104 .31822 L
.108 .31922 L
.112 .31996 L
.116 .31994 L
.12 .31929 L
.124 .31839 L
.128 .31769 L
.132 .31761 L
.136 .31817 L
.14 .31909 L
.144 .31987 L
.148 .32002 L
.152 .31955 L
.156 .31877 L
.16 .31809 L
.164 .31782 L
.168 .31805 L
.172 .31871 L
.176 .31948 L
.18 .31993 L
.184 .31982 L
.188 .31927 L
.192 .31868 L
.196 .31831 L
.2 .31822 L
Mistroke
.204 .3184 L
.208 .31883 L
.212 .31937 L
.216 .31972 L
.22 .31968 L
.224 .31937 L
.228 .31904 L
.232 .31882 L
.236 .31862 L
.24 .31846 L
.244 .31853 L
.248 .31897 L
.252 .31954 L
.256 .31984 L
.26 .31974 L
.264 .31943 L
.268 .31914 L
.272 .3189 L
.276 .31866 L
.28 .31854 L
.284 .31874 L
.288 .31921 L
.292 .31959 L
.296 .31964 L
.3 .3195 L
.304 .31951 L
.308 .31968 L
.312 .31968 L
.316 .31923 L
.32 .31854 L
.324 .31816 L
.328 .3184 L
.332 .31906 L
.336 .31976 L
.34 .32023 L
.344 .32049 L
.348 .32048 L
.352 .32007 L
.356 .3192 L
.36 .31819 L
.364 .31762 L
.368 .31784 L
.372 .31874 L
.376 .31979 L
.38 .32058 L
.384 .321 L
.388 .32111 L
.392 .32088 L
.396 .32011 L
.4 .31875 L
Mistroke
.404 .3173 L
.408 .31663 L
.412 .31731 L
.416 .31909 L
.42 .32094 L
.424 .3219 L
.428 .32178 L
.432 .32116 L
.436 .3206 L
.44 .32001 L
.444 .31892 L
.448 .31732 L
.452 .31615 L
.456 .31658 L
.46 .31876 L
.464 .32142 L
.468 .32282 L
.472 .32235 L
.476 .32096 L
.48 .32012 L
.484 .32022 L
.488 .32021 L
.492 .31898 L
.496 .31686 L
.5 .31566 L
.504 .3169 L
.508 .32009 L
.512 .32291 L
.516 .32327 L
.52 .32128 L
.524 .31915 L
.528 .31899 L
.532 .32069 L
.536 .32207 L
.54 .32111 L
.544 .31813 L
.548 .31566 L
.552 .31611 L
.556 .31935 L
.56 .32273 L
.564 .32339 L
.568 .32091 L
.572 .31768 L
.576 .31675 L
.58 .3191 L
.584 .32276 L
.588 .32459 L
.592 .32304 L
.596 .3194 L
.6 .31663 L
Mistroke
.604 .31679 L
.608 .3194 L
.612 .32196 L
.616 .3222 L
.62 .31985 L
.624 .31679 L
.628 .31542 L
.632 .31685 L
.636 .32025 L
.64 .32363 L
.644 .32528 L
.648 .32475 L
.652 .32272 L
.656 .32037 L
.66 .31866 L
.664 .31806 L
.668 .31858 L
.672 .31977 L
.676 .3208 L
.68 .32073 L
.684 .31905 L
.688 .3163 L
.692 .31418 L
.696 .31462 L
.7 .31846 L
.704 .32442 L
.708 .32947 L
.712 .3305 L
.716 .32635 L
.72 .31894 L
.724 .31241 L
.728 .31073 L
.732 .31516 L
.736 .32333 L
.74 .33039 L
.744 .33192 L
.748 .32655 L
.752 .31696 L
.756 .30835 L
.76 .30553 L
.764 .31019 L
.768 .31998 L
.772 .32989 L
.776 .335 L
.78 .33302 L
.784 .32529 L
.788 .31576 L
.792 .30875 L
.796 .30688 L
.8 .31007 L
Mistroke
.804 .31616 L
.808 .32229 L
.812 .32643 L
.816 .32794 L
.82 .32726 L
.824 .32508 L
.828 .32159 L
.832 .31651 L
.836 .30961 L
.84 .30148 L
.844 .29383 L
.848 .28904 L
.852 .28902 L
.856 .294 L
.86 .30193 L
.864 .30884 L
.868 .31025 L
.872 .30285 L
.876 .286 L
.88 .26204 L
.884 .23581 L
.888 .21276 L
.892 .19746 L
.896 .19194 L
.9 .19557 L
.904 .20543 L
.908 .21778 L
.912 .22942 L
.916 .2386 L
.92 .24541 L
.924 .25088 L
.928 .25656 L
.932 .26275 L
.936 .26886 L
.94 .27258 L
.944 .27123 L
.948 .26246 L
.952 .24492 L
.956 .21983 L
.96 .18926 L
.964 .15784 L
.968 .12926 L
.972 .10753 L
.976 .09456 L
.98 .09007 L
.984 .09292 L
.988 .09882 L
.992 .10523 L
.996 .108 L
1 .10545 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15184 m
.008 .14943 L
.012 .14861 L
.016 .14948 L
.02 .14972 L
.024 .14944 L
.028 .14934 L
.032 .14946 L
.036 .14948 L
.04 .14946 L
.044 .14943 L
.048 .14945 L
.052 .14944 L
.056 .14945 L
.06 .14944 L
.064 .14945 L
.068 .14944 L
.072 .14945 L
.076 .14945 L
.08 .14945 L
.084 .14944 L
.088 .14945 L
.092 .14944 L
.096 .14944 L
.1 .14944 L
.104 .14945 L
.108 .14945 L
.112 .14945 L
.116 .14945 L
.12 .14945 L
.124 .14944 L
.128 .14944 L
.132 .14944 L
.136 .14945 L
.14 .14945 L
.144 .14945 L
.148 .14945 L
.152 .14945 L
.156 .14945 L
.16 .14945 L
.164 .14945 L
.168 .14945 L
.172 .14945 L
.176 .14945 L
.18 .14945 L
.184 .14945 L
.188 .14945 L
.192 .14945 L
.196 .14945 L
.2 .14945 L
Mistroke
.204 .14945 L
.208 .14945 L
.212 .14945 L
.216 .14944 L
.22 .14945 L
.224 .14945 L
.228 .14946 L
.232 .14946 L
.236 .14946 L
.24 .14945 L
.244 .14945 L
.248 .14944 L
.252 .14944 L
.256 .14944 L
.26 .14945 L
.264 .14947 L
.268 .14948 L
.272 .14947 L
.276 .14946 L
.28 .14945 L
.284 .14944 L
.288 .14944 L
.292 .14944 L
.296 .14944 L
.3 .14946 L
.304 .14947 L
.308 .14948 L
.312 .14948 L
.316 .14947 L
.32 .14946 L
.324 .14944 L
.328 .14943 L
.332 .14942 L
.336 .14942 L
.34 .14944 L
.344 .14948 L
.348 .1495 L
.352 .14951 L
.356 .1495 L
.36 .14947 L
.364 .14945 L
.368 .14942 L
.372 .14941 L
.376 .1494 L
.38 .14941 L
.384 .14945 L
.388 .1495 L
.392 .14954 L
.396 .14955 L
.4 .14952 L
Mistroke
.404 .14948 L
.408 .14943 L
.412 .14939 L
.416 .14937 L
.42 .14936 L
.424 .14939 L
.428 .14946 L
.432 .14954 L
.436 .1496 L
.44 .14961 L
.444 .14956 L
.448 .14949 L
.452 .14943 L
.456 .14938 L
.46 .14935 L
.464 .14932 L
.468 .14934 L
.472 .1494 L
.476 .14952 L
.48 .14963 L
.484 .14968 L
.488 .14964 L
.492 .14955 L
.496 .14946 L
.5 .14941 L
.504 .14938 L
.508 .14934 L
.512 .1493 L
.516 .14929 L
.52 .14935 L
.524 .14949 L
.528 .14964 L
.532 .14971 L
.536 .14967 L
.54 .14958 L
.544 .14951 L
.548 .14949 L
.552 .14949 L
.556 .14946 L
.56 .14937 L
.564 .14926 L
.568 .14921 L
.572 .14927 L
.576 .14942 L
.58 .14955 L
.584 .14962 L
.588 .1496 L
.592 .14957 L
.596 .1496 L
.6 .14968 L
Mistroke
.604 .14977 L
.608 .14977 L
.612 .14964 L
.616 .14942 L
.62 .1492 L
.624 .14907 L
.628 .14905 L
.632 .14911 L
.636 .1492 L
.64 .14929 L
.644 .14938 L
.648 .14951 L
.652 .14969 L
.656 .14992 L
.66 .15014 L
.664 .15028 L
.668 .15027 L
.672 .15008 L
.676 .14975 L
.68 .14933 L
.684 .14894 L
.688 .14867 L
.692 .14858 L
.696 .14863 L
.7 .14875 L
.704 .14887 L
.708 .14896 L
.712 .14907 L
.716 .14927 L
.72 .14964 L
.724 .15015 L
.728 .15068 L
.732 .15105 L
.736 .15112 L
.74 .15087 L
.744 .15041 L
.748 .14995 L
.752 .14965 L
.756 .14958 L
.76 .14966 L
.764 .1497 L
.768 .14954 L
.772 .1491 L
.776 .14845 L
.78 .14773 L
.784 .14714 L
.788 .14681 L
.792 .14675 L
.796 .14689 L
.8 .14711 L
Mistroke
.804 .14733 L
.808 .14752 L
.812 .14771 L
.816 .14798 L
.82 .14841 L
.824 .14908 L
.828 .15003 L
.832 .1513 L
.836 .15289 L
.84 .15482 L
.844 .15702 L
.848 .15939 L
.852 .1618 L
.856 .16407 L
.86 .16609 L
.864 .16784 L
.868 .16944 L
.872 .17108 L
.876 .17304 L
.88 .17556 L
.884 .17878 L
.888 .1827 L
.892 .1872 L
.896 .19205 L
.9 .19701 L
.904 .20186 L
.908 .20648 L
.912 .21083 L
.916 .21493 L
.92 .21883 L
.924 .22258 L
.928 .22618 L
.932 .22962 L
.936 .23292 L
.94 .23607 L
.944 .23922 L
.948 .24247 L
.952 .24607 L
.956 .25019 L
.96 .25498 L
.964 .26053 L
.968 .26679 L
.972 .27365 L
.976 .28087 L
.98 .28827 L
.984 .29562 L
.988 .30281 L
.992 .30979 L
.996 .31658 L
1 .32334 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16019 L
.012 .16117 L
.016 .16153 L
.02 .16127 L
.024 .16108 L
.028 .16116 L
.032 .16121 L
.036 .16123 L
.04 .16121 L
.044 .16123 L
.048 .16122 L
.052 .16121 L
.056 .16118 L
.06 .16119 L
.064 .16119 L
.068 .16122 L
.072 .16122 L
.076 .16123 L
.08 .16121 L
.084 .1612 L
.088 .16118 L
.092 .16119 L
.096 .16119 L
.1 .16121 L
.104 .16121 L
.108 .16122 L
.112 .16121 L
.116 .1612 L
.12 .16119 L
.124 .16119 L
.128 .16119 L
.132 .1612 L
.136 .16121 L
.14 .16121 L
.144 .1612 L
.148 .1612 L
.152 .16119 L
.156 .1612 L
.16 .1612 L
.164 .1612 L
.168 .1612 L
.172 .1612 L
.176 .1612 L
.18 .16119 L
.184 .16119 L
.188 .1612 L
.192 .1612 L
.196 .16121 L
.2 .1612 L
Mistroke
.204 .16119 L
.208 .16119 L
.212 .16119 L
.216 .16118 L
.22 .16119 L
.224 .1612 L
.228 .16121 L
.232 .16121 L
.236 .1612 L
.24 .16119 L
.244 .16118 L
.248 .16118 L
.252 .16118 L
.256 .16118 L
.26 .16119 L
.264 .1612 L
.268 .16121 L
.272 .16121 L
.276 .1612 L
.28 .16119 L
.284 .16118 L
.288 .16117 L
.292 .16116 L
.296 .16117 L
.3 .16119 L
.304 .16121 L
.308 .16123 L
.312 .16123 L
.316 .16121 L
.32 .16118 L
.324 .16117 L
.328 .16115 L
.332 .16115 L
.336 .16115 L
.34 .16117 L
.344 .16121 L
.348 .16124 L
.352 .16125 L
.356 .16123 L
.36 .16121 L
.364 .16117 L
.368 .16114 L
.372 .16111 L
.376 .1611 L
.38 .16112 L
.384 .16118 L
.388 .16124 L
.392 .16129 L
.396 .16129 L
.4 .16125 L
Mistroke
.404 .1612 L
.408 .16115 L
.412 .1611 L
.416 .16107 L
.42 .16106 L
.424 .16108 L
.428 .16116 L
.432 .16127 L
.436 .16135 L
.44 .16136 L
.444 .1613 L
.448 .16121 L
.452 .16113 L
.456 .16107 L
.46 .16103 L
.464 .161 L
.468 .16102 L
.472 .16109 L
.476 .16123 L
.48 .16137 L
.484 .16144 L
.488 .1614 L
.492 .16128 L
.496 .16117 L
.5 .1611 L
.504 .16106 L
.508 .16102 L
.512 .16096 L
.516 .16095 L
.52 .16103 L
.524 .16119 L
.528 .16138 L
.532 .16147 L
.536 .16143 L
.54 .16131 L
.544 .16121 L
.548 .16118 L
.552 .16119 L
.556 .16116 L
.56 .16104 L
.564 .16091 L
.568 .16084 L
.572 .16092 L
.576 .16109 L
.58 .16126 L
.584 .16134 L
.588 .16132 L
.592 .16128 L
.596 .16131 L
.6 .16142 L
Mistroke
.604 .16153 L
.608 .16152 L
.612 .16136 L
.616 .16109 L
.62 .16082 L
.624 .16065 L
.628 .16063 L
.632 .1607 L
.636 .16081 L
.64 .16092 L
.644 .16103 L
.648 .16119 L
.652 .16142 L
.656 .1617 L
.66 .16198 L
.664 .16215 L
.668 .16213 L
.672 .1619 L
.676 .16148 L
.68 .16096 L
.684 .16047 L
.688 .16014 L
.692 .16002 L
.696 .16008 L
.7 .16023 L
.704 .16038 L
.708 .16049 L
.712 .16063 L
.716 .16088 L
.72 .16134 L
.724 .16198 L
.728 .16264 L
.732 .16309 L
.736 .16318 L
.74 .16286 L
.744 .16229 L
.748 .16171 L
.752 .16134 L
.756 .16126 L
.76 .16135 L
.764 .1614 L
.768 .1612 L
.772 .16065 L
.776 .15983 L
.78 .15894 L
.784 .1582 L
.788 .15778 L
.792 .1577 L
.796 .15786 L
.8 .15813 L
Mistroke
.804 .15838 L
.808 .15858 L
.812 .15877 L
.816 .15904 L
.82 .15949 L
.824 .16021 L
.828 .16123 L
.832 .16258 L
.836 .16428 L
.84 .16628 L
.844 .16851 L
.848 .17081 L
.852 .17295 L
.856 .17471 L
.86 .17589 L
.864 .17643 L
.868 .1764 L
.872 .17604 L
.876 .17563 L
.88 .17544 L
.884 .17562 L
.888 .17618 L
.892 .17696 L
.896 .17774 L
.9 .17824 L
.904 .1783 L
.908 .17785 L
.912 .17696 L
.916 .17579 L
.92 .17451 L
.924 .17326 L
.928 .17216 L
.932 .1712 L
.936 .17041 L
.94 .16976 L
.944 .16931 L
.948 .1691 L
.952 .1693 L
.956 .16999 L
.96 .17129 L
.964 .17321 L
.968 .17569 L
.972 .17864 L
.976 .18187 L
.98 .18526 L
.984 .18866 L
.988 .19202 L
.992 .19538 L
.996 .19876 L
1 .20234 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001NOol00`00Oomoo`0<Ool000Yoo`04001oogoo0008
Ool01P00Oomoo`00Ool000=oo`03001oogoo008005eoo`8000ioo`002goo0P002Woo0P000goo0`00
0goo00<007ooOol0G7oo00@007oo000000aoo`008Woo0P00GGoo00<007ooOol03Goo000;Ool20004
Ool00`00Oomoo`03Ool20002Ool50002Ool00`00Oomoo`1KOol00`00Oomoo`0>Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8005aoo`03001oogoo00ioo`000goo1@00
0Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001LOol00`00Oomoo`0>Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`0017oo00D007ooOomoo`0005eoo`03001oogoo00ioo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00G7oo00<007ooOol03Woo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001LOol00`00Oomoo`0>
Ool000]oo`8000Yoo`8000=oo`<000=oo`03001oogoo05Aoo`8000Eoo`03001oogoo00ioo`002goo
0P0017oo00<007ooOol00goo0P000goo0`000goo0P00EGoo0P001Goo00<007ooOol03Woo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000eoo`<000Aoo`8000Moo`<000Ao
o`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000=oo`D000=oo`8000Aoo`80009oo`L0009oo`<000Ao
o`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`0;Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0002Ool01000Ool007oo0P000Woo00<007oo00000goo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo
00@007ooOol0009oo`03001oogoo0080009oo`05001oo`00Ool00005Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04
001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`80009oo`800003Ool0000000Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol02goo10000goo00@007ooOol000Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001o
ogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo0080009oo`<00003Ool0
07oo00@000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`8000aoo`03
001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=o
o`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001o
ogoo0080009oo`03001oo`0000800003Ool007oo00Eoo`04001oogoo0005Ool0029oo`8000aoo`D0
00=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20004Ool30004
Ool20004Ool200000goo001oo`02Ool30002Ool50003Ool20006Ool0029oo`03001oogoo059oo`03
001oogoo01Moo`008Woo0P00D7oo10006Goo000ROomS000<Ool0029oo`800004Ool00000Ool?0000
1Goo00000000Ool00`000Woo0P000Woo0P000Woo0`0000Eoo`00000007oo00<00003Ool0000000D0
0003Ool007oo00800003Ool0000000<00004Ool00000Ool300000goo00000002Ool20002Ool20003
Ool01@00Oomoogoo00000goo00<007ooOol02Woo000ROol30002Ool200001Goo001oogoo00000Woo
0P0000=oo`0000000Woo0P000Woo0P000Woo0`0000=oo`0000000Woo0`0000Eoo`00000007oo00@0
0003Ool0000000@00003Ool0000000H00004Ool007ooOol2000027oo000007oo001oo`00Ool3000M
Ool0029oo`03001oogoo04=oo`05001oo`00001oo`02000ROol0029oo`8006eoo`008Woo0P00KGoo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P00
2Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002
Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`80
06eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol0
00Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007oo
Ool007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03
001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000
Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool3
0003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001o
ogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007oo
Oomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogoo
Ool40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<0
07ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000A
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Ao
o`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo:00000Eoo`00000007oo00@0
0003Ool000000080009oo`@0009oo`D000Aoo`D001eoo`00:7oo00<007oo00007Goo00@007ooOomo
o`80009oo`80009oo`80009oo`<0009oo`@0009oo`@000=oo`D000Eoo`<001Yoo`00:7oo00<007oo
Ool0Bgoo0`0067oo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomo
o`1=Ool2000GOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool0
1000Oomoo`00D7oo0P005Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0005Ool01000Oomoo`00DGoo0P005Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04
001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003
Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogoo
Ool00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool0
1@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogooOol2000017oo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04
001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=o
o`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001o
ogoo0004Ool20006Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002
Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo
00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool20005Ool01000Oomoo`000Woo
00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool60003Ool01000Oomoo`001Goo000X
Ool00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04
001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol000=oo`<000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uo
o`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool3
0004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo05Ioo`8000ioo`00
:7oo00<007ooOol0Egoo00<007ooOol037oo000XOomM000<Ool002Qoo`03001oogoo00moo`03001o
ogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo00moo`8000aoo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001o
ogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo
001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo0080
06Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007oo
Ool0IWoo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo
1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo
001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
0`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0
3Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P00
17oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007oo
Ool000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo
011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool0
01aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002
Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomo
ogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000Aoo`05001oogooOol00003Ool01000Oomoogoo0P000Woo00@007ooOomoo`D000Ao
o`03001oogoo00Yoo`0077oo00<007ooOol0EWoo20000goo0P003goo000LOol2001SOol2000>Ool0
01aoo`03001oogoo06Aoo`03001oogoo00]oo`0077oo00<007ooOol0IGoo00<007ooOol02Woo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomo
o`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@0
07ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80
07=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007oo
Ool0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`00
5goo00<007ooOol00Woo00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009o
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007oo
Ool00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02
001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol0
17oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(18537\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31984 m
.008 .31896 L
.012 .31764 L
.016 .31738 L
.02 .31812 L
.024 .3186 L
.028 .31884 L
.032 .31896 L
.036 .31894 L
.04 .31874 L
.044 .31831 L
.048 .31813 L
.052 .31821 L
.056 .31837 L
.06 .31866 L
.064 .31885 L
.068 .31891 L
.072 .3189 L
.076 .31872 L
.08 .31853 L
.084 .31836 L
.088 .31827 L
.092 .31841 L
.096 .31865 L
.1 .31892 L
.104 .31916 L
.108 .31915 L
.112 .31892 L
.116 .31852 L
.12 .31817 L
.124 .31815 L
.128 .31844 L
.132 .3189 L
.136 .31934 L
.14 .31952 L
.144 .31934 L
.148 .31882 L
.152 .31822 L
.156 .31795 L
.16 .31816 L
.164 .31873 L
.168 .31936 L
.172 .31975 L
.176 .31975 L
.18 .3193 L
.184 .31856 L
.188 .31795 L
.192 .31786 L
.196 .31838 L
.2 .31916 L
Mistroke
.204 .31978 L
.208 .31999 L
.212 .31973 L
.216 .31912 L
.22 .31838 L
.224 .31791 L
.228 .31807 L
.232 .31876 L
.236 .31952 L
.24 .31988 L
.244 .31978 L
.248 .31945 L
.252 .31909 L
.256 .31873 L
.26 .31849 L
.264 .31851 L
.268 .31883 L
.272 .31923 L
.276 .31943 L
.28 .31942 L
.284 .31944 L
.288 .31957 L
.292 .31957 L
.296 .31923 L
.3 .31873 L
.304 .31847 L
.308 .31867 L
.312 .31909 L
.316 .3194 L
.32 .31952 L
.324 .31963 L
.328 .31982 L
.332 .31988 L
.336 .3196 L
.34 .31907 L
.344 .31863 L
.348 .31851 L
.352 .31864 L
.356 .31889 L
.36 .31924 L
.364 .31983 L
.368 .32052 L
.372 .3209 L
.376 .32053 L
.38 .31944 L
.384 .31824 L
.388 .31762 L
.392 .31786 L
.396 .31865 L
.4 .3195 L
Mistroke
.404 .32017 L
.408 .32073 L
.412 .32122 L
.416 .32132 L
.42 .32062 L
.424 .31908 L
.428 .31742 L
.432 .31667 L
.436 .31733 L
.44 .31892 L
.444 .32042 L
.448 .32118 L
.452 .32134 L
.456 .32143 L
.46 .32148 L
.464 .32089 L
.468 .31924 L
.472 .3171 L
.476 .31591 L
.48 .3167 L
.484 .319 L
.488 .32117 L
.492 .32189 L
.496 .32131 L
.5 .32075 L
.504 .32106 L
.508 .32164 L
.512 .32103 L
.516 .31873 L
.52 .31613 L
.524 .3154 L
.528 .31741 L
.532 .3207 L
.536 .32269 L
.54 .32208 L
.544 .32001 L
.548 .31893 L
.552 .32006 L
.556 .32217 L
.56 .32276 L
.564 .32061 L
.568 .31717 L
.572 .31534 L
.576 .31682 L
.58 .32043 L
.584 .32312 L
.588 .32268 L
.592 .31967 L
.596 .31693 L
.6 .31703 L
Mistroke
.604 .32001 L
.608 .32339 L
.612 .32439 L
.616 .32226 L
.62 .31881 L
.624 .31682 L
.628 .31768 L
.632 .32036 L
.636 .32245 L
.64 .32213 L
.644 .31957 L
.648 .31667 L
.652 .31547 L
.656 .31678 L
.66 .31979 L
.664 .32285 L
.668 .32457 L
.672 .32448 L
.676 .32297 L
.68 .32085 L
.684 .31901 L
.688 .31818 L
.692 .3187 L
.696 .32024 L
.7 .32175 L
.704 .32187 L
.708 .31982 L
.712 .31627 L
.716 .3133 L
.72 .31331 L
.724 .3173 L
.728 .32387 L
.732 .3296 L
.736 .33101 L
.74 .3268 L
.744 .319 L
.748 .31199 L
.752 .31 L
.756 .31447 L
.76 .32298 L
.764 .33059 L
.768 .33263 L
.772 .32755 L
.776 .31781 L
.78 .30857 L
.784 .30473 L
.788 .30828 L
.792 .3172 L
.796 .32674 L
.8 .33195 L
Mistroke
.804 .33024 L
.808 .32241 L
.812 .31184 L
.816 .30256 L
.82 .29718 L
.824 .29597 L
.828 .2972 L
.832 .29843 L
.836 .29783 L
.84 .29472 L
.844 .28933 L
.848 .28205 L
.852 .27291 L
.856 .26152 L
.86 .2478 L
.864 .23265 L
.868 .21841 L
.872 .20819 L
.876 .20488 L
.88 .20964 L
.884 .22111 L
.888 .23562 L
.892 .24827 L
.896 .2549 L
.9 .25332 L
.904 .2445 L
.908 .23167 L
.912 .21951 L
.916 .212 L
.92 .21124 L
.924 .21694 L
.928 .22641 L
.932 .23664 L
.936 .24437 L
.94 .24867 L
.944 .24976 L
.948 .24968 L
.952 .25073 L
.956 .25402 L
.96 .25994 L
.964 .26595 L
.968 .26965 L
.972 .26741 L
.976 .25703 L
.98 .23869 L
.984 .21314 L
.988 .18539 L
.992 .15852 L
.996 .13785 L
1 .12608 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15149 m
.008 .14989 L
.012 .14927 L
.016 .14975 L
.02 .14994 L
.024 .14984 L
.028 .14975 L
.032 .14982 L
.036 .14983 L
.04 .14983 L
.044 .14979 L
.048 .14979 L
.052 .14978 L
.056 .1498 L
.06 .14981 L
.064 .14983 L
.068 .14982 L
.072 .14982 L
.076 .1498 L
.08 .1498 L
.084 .14979 L
.088 .1498 L
.092 .14981 L
.096 .14982 L
.1 .14982 L
.104 .14981 L
.108 .1498 L
.112 .1498 L
.116 .1498 L
.12 .1498 L
.124 .14981 L
.128 .14982 L
.132 .14982 L
.136 .14981 L
.14 .14981 L
.144 .1498 L
.148 .1498 L
.152 .14981 L
.156 .14981 L
.16 .14981 L
.164 .14981 L
.168 .14981 L
.172 .14981 L
.176 .14981 L
.18 .14981 L
.184 .14981 L
.188 .14981 L
.192 .14981 L
.196 .14981 L
.2 .14981 L
Mistroke
.204 .1498 L
.208 .14981 L
.212 .14981 L
.216 .14982 L
.22 .14982 L
.224 .14982 L
.228 .14981 L
.232 .14981 L
.236 .1498 L
.24 .1498 L
.244 .14981 L
.248 .14982 L
.252 .14982 L
.256 .14982 L
.26 .14982 L
.264 .14982 L
.268 .14981 L
.272 .1498 L
.276 .1498 L
.28 .1498 L
.284 .14981 L
.288 .14982 L
.292 .14983 L
.296 .14983 L
.3 .14983 L
.304 .14982 L
.308 .14981 L
.312 .14979 L
.316 .14979 L
.32 .1498 L
.324 .14982 L
.328 .14984 L
.332 .14984 L
.336 .14984 L
.34 .14983 L
.344 .14983 L
.348 .14981 L
.352 .1498 L
.356 .14978 L
.36 .14978 L
.364 .1498 L
.368 .14983 L
.372 .14986 L
.376 .14987 L
.38 .14986 L
.384 .14985 L
.388 .14983 L
.392 .1498 L
.396 .14977 L
.4 .14975 L
Mistroke
.404 .14976 L
.408 .14981 L
.412 .14986 L
.416 .1499 L
.42 .14991 L
.424 .14989 L
.428 .14986 L
.432 .14982 L
.436 .14978 L
.44 .14973 L
.444 .1497 L
.448 .14973 L
.452 .1498 L
.456 .14989 L
.46 .14995 L
.464 .14996 L
.468 .14993 L
.472 .14988 L
.476 .14983 L
.48 .14978 L
.484 .14972 L
.488 .14966 L
.492 .14966 L
.496 .14974 L
.5 .14986 L
.504 .14998 L
.508 .15002 L
.512 .14999 L
.516 .14993 L
.52 .14987 L
.524 .14984 L
.528 .14979 L
.532 .14971 L
.536 .14963 L
.54 .14961 L
.544 .14969 L
.548 .14984 L
.552 .14998 L
.556 .15004 L
.56 .15 L
.564 .14994 L
.568 .1499 L
.572 .14991 L
.576 .14992 L
.58 .14986 L
.584 .14974 L
.588 .14961 L
.592 .14957 L
.596 .14964 L
.6 .14977 L
Mistroke
.604 .14988 L
.608 .14992 L
.612 .1499 L
.616 .14989 L
.62 .14995 L
.624 .15007 L
.628 .15016 L
.632 .15017 L
.636 .15005 L
.64 .14984 L
.644 .14964 L
.648 .14951 L
.652 .14946 L
.656 .14948 L
.66 .14952 L
.664 .14957 L
.668 .14964 L
.672 .14975 L
.676 .14994 L
.68 .15018 L
.684 .15044 L
.688 .15063 L
.692 .15069 L
.696 .15057 L
.7 .15028 L
.704 .14987 L
.708 .14947 L
.712 .14917 L
.716 .14903 L
.72 .14903 L
.724 .1491 L
.728 .14916 L
.732 .14919 L
.736 .14924 L
.74 .14941 L
.744 .14977 L
.748 .1503 L
.752 .15088 L
.756 .15132 L
.76 .15147 L
.764 .1513 L
.768 .1509 L
.772 .15047 L
.776 .15019 L
.78 .15013 L
.784 .15022 L
.788 .15031 L
.792 .15022 L
.796 .14988 L
.8 .14933 L
Mistroke
.804 .14871 L
.808 .1482 L
.812 .14794 L
.816 .14797 L
.82 .14825 L
.824 .14871 L
.828 .14927 L
.832 .14991 L
.836 .15066 L
.84 .1516 L
.844 .15281 L
.848 .15438 L
.852 .15635 L
.856 .1588 L
.86 .16176 L
.864 .16524 L
.868 .1692 L
.872 .17351 L
.876 .17799 L
.88 .18241 L
.884 .18655 L
.888 .19031 L
.892 .19367 L
.896 .19675 L
.9 .19976 L
.904 .20292 L
.908 .20639 L
.912 .21025 L
.916 .21442 L
.92 .21878 L
.924 .22316 L
.928 .22743 L
.932 .23151 L
.936 .23542 L
.94 .23921 L
.944 .24295 L
.948 .24669 L
.952 .25041 L
.956 .2541 L
.96 .25769 L
.964 .26114 L
.968 .26451 L
.972 .26785 L
.976 .2714 L
.98 .27529 L
.984 .27973 L
.988 .28482 L
.992 .29054 L
.996 .29685 L
1 .30347 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16284 L
.012 .16117 L
.016 .16062 L
.02 .16125 L
.024 .16139 L
.028 .1612 L
.032 .16113 L
.036 .16123 L
.04 .16122 L
.044 .16121 L
.048 .16119 L
.052 .16121 L
.056 .1612 L
.06 .16121 L
.064 .1612 L
.068 .16122 L
.072 .16121 L
.076 .16121 L
.08 .16119 L
.084 .1612 L
.088 .16119 L
.092 .1612 L
.096 .1612 L
.1 .16121 L
.104 .16121 L
.108 .16121 L
.112 .16119 L
.116 .16119 L
.12 .16119 L
.124 .1612 L
.128 .1612 L
.132 .16121 L
.136 .16121 L
.14 .1612 L
.144 .16119 L
.148 .16119 L
.152 .16119 L
.156 .1612 L
.16 .1612 L
.164 .1612 L
.168 .1612 L
.172 .1612 L
.176 .1612 L
.18 .1612 L
.184 .16119 L
.188 .16119 L
.192 .16119 L
.196 .1612 L
.2 .16119 L
Mistroke
.204 .16119 L
.208 .16119 L
.212 .1612 L
.216 .1612 L
.22 .1612 L
.224 .1612 L
.228 .1612 L
.232 .16119 L
.236 .16118 L
.24 .16118 L
.244 .16118 L
.248 .16119 L
.252 .1612 L
.256 .16121 L
.26 .1612 L
.264 .1612 L
.268 .16118 L
.272 .16117 L
.276 .16117 L
.28 .16117 L
.284 .16119 L
.288 .16121 L
.292 .16121 L
.296 .16121 L
.3 .1612 L
.304 .16119 L
.308 .16118 L
.312 .16117 L
.316 .16116 L
.32 .16116 L
.324 .16118 L
.328 .1612 L
.332 .16122 L
.336 .16122 L
.34 .16121 L
.344 .1612 L
.348 .16118 L
.352 .16115 L
.356 .16113 L
.36 .16114 L
.364 .16116 L
.368 .1612 L
.372 .16123 L
.376 .16124 L
.38 .16123 L
.384 .16122 L
.388 .16119 L
.392 .16115 L
.396 .16111 L
.4 .16109 L
Mistroke
.404 .1611 L
.408 .16116 L
.412 .16123 L
.416 .16127 L
.42 .16128 L
.424 .16126 L
.428 .16122 L
.432 .16117 L
.436 .16112 L
.44 .16106 L
.444 .16103 L
.448 .16105 L
.452 .16114 L
.456 .16125 L
.46 .16133 L
.464 .16134 L
.468 .16131 L
.472 .16124 L
.476 .16118 L
.48 .16111 L
.484 .16103 L
.488 .16097 L
.492 .16097 L
.496 .16106 L
.5 .16121 L
.504 .16135 L
.508 .16141 L
.512 .16137 L
.516 .16129 L
.52 .16122 L
.524 .16117 L
.528 .16111 L
.532 .16101 L
.536 .16092 L
.54 .1609 L
.544 .16099 L
.548 .16117 L
.552 .16134 L
.556 .16142 L
.56 .16138 L
.564 .1613 L
.568 .16125 L
.572 .16126 L
.576 .16126 L
.58 .16119 L
.584 .16104 L
.588 .16089 L
.592 .16083 L
.596 .16092 L
.6 .16108 L
Mistroke
.604 .16121 L
.608 .16126 L
.612 .16123 L
.616 .16123 L
.62 .1613 L
.624 .16144 L
.628 .16156 L
.632 .16156 L
.636 .16141 L
.64 .16116 L
.644 .1609 L
.648 .16073 L
.652 .16068 L
.656 .1607 L
.66 .16075 L
.664 .16081 L
.668 .16089 L
.672 .16104 L
.676 .16127 L
.68 .16157 L
.684 .16188 L
.688 .16213 L
.692 .1622 L
.696 .16205 L
.7 .16168 L
.704 .16118 L
.708 .16068 L
.712 .1603 L
.716 .16013 L
.72 .16013 L
.724 .16021 L
.728 .16029 L
.732 .16032 L
.736 .16038 L
.74 .16059 L
.744 .16104 L
.748 .1617 L
.752 .16242 L
.756 .16296 L
.76 .16314 L
.764 .16292 L
.768 .16241 L
.772 .16186 L
.776 .16149 L
.78 .16138 L
.784 .16145 L
.788 .1615 L
.792 .16131 L
.796 .16078 L
.8 .15993 L
Mistroke
.804 .15895 L
.808 .15804 L
.812 .15735 L
.816 .15691 L
.82 .15664 L
.824 .15642 L
.828 .1561 L
.832 .15564 L
.836 .15502 L
.84 .15429 L
.844 .15352 L
.848 .15275 L
.852 .15204 L
.856 .15142 L
.86 .15095 L
.864 .15064 L
.868 .15045 L
.872 .1503 L
.876 .15 L
.88 .14938 L
.884 .14828 L
.888 .14667 L
.892 .14465 L
.896 .14249 L
.9 .14052 L
.904 .13909 L
.908 .13839 L
.912 .13849 L
.916 .13924 L
.92 .1404 L
.924 .1416 L
.928 .14257 L
.932 .14311 L
.936 .14313 L
.94 .1427 L
.944 .14189 L
.948 .14087 L
.952 .1397 L
.956 .1385 L
.96 .13729 L
.964 .13613 L
.968 .13513 L
.972 .13436 L
.976 .13402 L
.98 .13421 L
.984 .13506 L
.988 .13666 L
.992 .13893 L
.996 .14191 L
1 .14532 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo05moo`03001o
ogoo00Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00Ggoo00<0
07ooOol02goo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
05moo`03001oogoo00]oo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01@00Oomoogoo0000
H7oo00<007ooOol02goo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001OOol00`00Oomoo`0;Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008005ioo`03001oogoo00aoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0GGoo00<007oo
Ool037oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001COol00`00Oomoo`08Ool0
0`00Oomoo`0<Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo
0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo1@000goo0P0017oo
10000Woo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomoo`001goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009o
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`80009oo`<00003Ool007oo
0080009oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009o
o`03001oogoo009oo`04001oogoo0002Ool02P00Ool00000Ool007oo001oo`0017oo00@007ooOol0
009oo`04001oogoo0005Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`05001oogooOol00002
Ool01@00Oomoo`00Ool00P0000=oo`0000000Woo0P000goo00@007ooOol0009oo`04001oogoo0005
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol02goo10000goo00@0
07ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@0
00=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`05001oo`00001oo`03
0002Ool200000goo000000020003Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool00`00Oomo
o`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001o
ogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Ool000000goo00@007ooOomoo`<000Ioo`04001oogoo0005Ool0029oo`8000ao
o`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20004Ool3
0004Ool20004Ool20005Ool300000goo000000040003Ool20006Ool0029oo`03001oogoo051oo`03
001oogoo01Uoo`008Woo0P00CWoo0`0077oo000ROomS000<Ool0029oo`h00004Ool00000Ool:0000
1Goo00000000Ool00`000Woo0P0000Aoo`000000009oo`80009oo`<00005Ool00000001oo`020000
0goo0000000200001Goo00000000Ool00P0000Aoo`00001oo`@0009oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00<007ooOol02Woo000ROol2000;Ool20002Ool00`00Oomoo`0200000goo
00000002Ool3000017oo000000000Woo0P0000Eoo`00000007oo00<0009oo`<00003Ool000000080
0003Ool0000000800003Ool0000000<00004Ool00000Ool200000goo00000002Ool2000OOol0029o
o`03001oogoo04Aoo`80009oo`04001oogoo000POol0029oo`8006eoo`008Woo0P00KGoo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P00
17oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo
0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo
06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]
Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2
001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06ao
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`00
00=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo
00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003
Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0
17oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004
Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001o
ogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo0P00>Woo00<007ooOol00Woo100017oo
100077oo000XOom10003Ool60002Ool3000JOol002Qoo`03001oogoo04aoo`03001oogoo01Moo`00
2goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0CGoo00<007ooOol0
5Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol0
051oo`03001oogoo01Eoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOol0055oo`8001Eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo
0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo
00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D0
07ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoogoo0P0000Aoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomo
o`0017oo0P001Woo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo
1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo0P001Goo00@007ooOol0009oo`03
001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo1P000goo00@007ooOol000Eoo`00:7oo
00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000
Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0003Ool30006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool5
0003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`00
17oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1GOol2000=Ool002Qo
o`03001oogoo05Qoo`03001oogoo00]oo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomo
o`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool0
0`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool0
1000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000
Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03
001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03
001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo
00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo
009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000
Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001o
ogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=o
o`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04
001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol0
0003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00
Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
0goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo
00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomo
o`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@0
07ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04
001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@0
07ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@0
07ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo
00<007ooOol0FWoo200000=oo`0000003Goo000LOol00`00Oomoo`1DOol6000;Ool00`00Oomoo`0:
Ool001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo
00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol0
00Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomo
o`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009o
o`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomo
o`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00
Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Ao
o`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03
001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<0
07ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03
001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(18704\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32003 m
.008 .31923 L
.012 .31838 L
.016 .31753 L
.02 .31748 L
.024 .3179 L
.028 .31857 L
.032 .31925 L
.036 .31939 L
.04 .31902 L
.044 .31829 L
.048 .31765 L
.052 .31764 L
.056 .31816 L
.06 .31891 L
.064 .31947 L
.068 .31939 L
.072 .31885 L
.076 .31815 L
.08 .31767 L
.084 .3178 L
.088 .31841 L
.092 .31915 L
.096 .31961 L
.1 .31944 L
.104 .31883 L
.108 .31814 L
.112 .31773 L
.116 .31789 L
.12 .3185 L
.124 .31924 L
.128 .31971 L
.132 .31958 L
.136 .31897 L
.14 .31825 L
.144 .31781 L
.148 .31791 L
.152 .31845 L
.156 .31917 L
.16 .31972 L
.164 .31976 L
.168 .31926 L
.172 .31853 L
.176 .31801 L
.18 .31798 L
.184 .31835 L
.188 .31893 L
.192 .31948 L
.196 .31976 L
.2 .31962 L
Mistroke
.204 .31909 L
.208 .31849 L
.212 .31817 L
.216 .31824 L
.22 .31857 L
.224 .319 L
.228 .31945 L
.232 .31979 L
.236 .31978 L
.24 .31932 L
.244 .31865 L
.248 .3182 L
.252 .31821 L
.256 .31858 L
.26 .31909 L
.264 .31958 L
.268 .31991 L
.272 .31989 L
.276 .31942 L
.28 .31873 L
.284 .31831 L
.288 .31843 L
.292 .3189 L
.296 .31927 L
.3 .31939 L
.304 .31941 L
.308 .31952 L
.312 .31961 L
.316 .31949 L
.32 .31918 L
.324 .31892 L
.328 .31885 L
.332 .31888 L
.336 .31889 L
.34 .31894 L
.344 .31925 L
.348 .31978 L
.352 .32016 L
.356 .32008 L
.36 .31957 L
.364 .31904 L
.368 .31877 L
.372 .31873 L
.376 .31871 L
.38 .3187 L
.384 .31895 L
.388 .31964 L
.392 .32053 L
.396 .32103 L
.4 .32069 L
Mistroke
.404 .31965 L
.408 .31853 L
.412 .31793 L
.416 .31798 L
.42 .31842 L
.424 .31899 L
.428 .31969 L
.432 .3206 L
.436 .32148 L
.44 .32173 L
.444 .32088 L
.448 .31919 L
.452 .3176 L
.456 .31704 L
.46 .31765 L
.464 .31876 L
.468 .31965 L
.472 .32023 L
.476 .32095 L
.48 .32189 L
.484 .32238 L
.488 .32151 L
.492 .31925 L
.496 .3169 L
.5 .31608 L
.504 .31725 L
.508 .3193 L
.512 .3206 L
.516 .32061 L
.52 .32028 L
.524 .32083 L
.528 .32218 L
.532 .32282 L
.536 .32137 L
.54 .31825 L
.544 .31568 L
.548 .31572 L
.552 .31828 L
.556 .32116 L
.56 .32202 L
.564 .32062 L
.568 .31892 L
.572 .3191 L
.576 .32129 L
.58 .32336 L
.584 .32297 L
.588 .31989 L
.592 .31645 L
.596 .31549 L
.6 .3178 L
Mistroke
.604 .32138 L
.608 .32318 L
.612 .32177 L
.616 .31857 L
.62 .31652 L
.624 .31752 L
.628 .32081 L
.632 .32372 L
.636 .32396 L
.64 .32148 L
.644 .3184 L
.648 .31713 L
.652 .31847 L
.656 .3211 L
.66 .32276 L
.664 .32209 L
.668 .31954 L
.672 .31682 L
.676 .31567 L
.68 .31669 L
.684 .31924 L
.688 .32204 L
.692 .32392 L
.696 .32429 L
.7 .32319 L
.704 .32114 L
.708 .31908 L
.712 .31804 L
.716 .31868 L
.72 .3207 L
.724 .32276 L
.728 .32307 L
.732 .32064 L
.736 .31626 L
.74 .31241 L
.744 .31189 L
.748 .31588 L
.752 .32283 L
.756 .32896 L
.76 .33046 L
.764 .32585 L
.768 .31719 L
.772 .30903 L
.776 .30579 L
.78 .30902 L
.784 .31632 L
.788 .32262 L
.792 .32302 L
.796 .31563 L
.8 .30264 L
Mistroke
.804 .289 L
.808 .27971 L
.812 .27703 L
.816 .27943 L
.82 .28259 L
.824 .2818 L
.828 .27448 L
.832 .2612 L
.836 .24522 L
.84 .23061 L
.844 .22044 L
.848 .21569 L
.852 .21555 L
.856 .21832 L
.86 .22261 L
.864 .22778 L
.868 .23365 L
.872 .2399 L
.876 .24544 L
.88 .24878 L
.884 .24853 L
.888 .24455 L
.892 .23828 L
.896 .23246 L
.9 .23017 L
.904 .23301 L
.908 .24077 L
.912 .25054 L
.916 .25853 L
.92 .26087 L
.924 .25572 L
.928 .244 L
.932 .22875 L
.936 .21492 L
.94 .20628 L
.944 .20552 L
.948 .21235 L
.952 .22424 L
.956 .2382 L
.96 .25034 L
.964 .25986 L
.968 .26625 L
.972 .27175 L
.976 .27881 L
.98 .28824 L
.984 .30143 L
.988 .31475 L
.992 .3264 L
.996 .33168 L
1 .32772 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14806 m
.008 .15022 L
.012 .15088 L
.016 .15014 L
.02 .1499 L
.024 .1502 L
.028 .15025 L
.032 .15017 L
.036 .15013 L
.04 .15017 L
.044 .15017 L
.048 .15017 L
.052 .15015 L
.056 .15018 L
.06 .15017 L
.064 .15018 L
.068 .15016 L
.072 .15017 L
.076 .15016 L
.08 .15016 L
.084 .15016 L
.088 .15018 L
.092 .15017 L
.096 .15018 L
.1 .15017 L
.104 .15016 L
.108 .15016 L
.112 .15016 L
.116 .15016 L
.12 .15018 L
.124 .15018 L
.128 .15018 L
.132 .15017 L
.136 .15016 L
.14 .15016 L
.144 .15016 L
.148 .15017 L
.152 .15017 L
.156 .15017 L
.16 .15018 L
.164 .15017 L
.168 .15017 L
.172 .15016 L
.176 .15017 L
.18 .15017 L
.184 .15017 L
.188 .15017 L
.192 .15017 L
.196 .15017 L
.2 .15017 L
Mistroke
.204 .15017 L
.208 .15017 L
.212 .15017 L
.216 .15017 L
.22 .15017 L
.224 .15017 L
.228 .15017 L
.232 .15017 L
.236 .15017 L
.24 .15017 L
.244 .15018 L
.248 .15018 L
.252 .15018 L
.256 .15017 L
.26 .15016 L
.264 .15016 L
.268 .15017 L
.272 .15018 L
.276 .15018 L
.28 .15019 L
.284 .15019 L
.288 .15018 L
.292 .15017 L
.296 .15016 L
.3 .15016 L
.304 .15017 L
.308 .15018 L
.312 .15018 L
.316 .15019 L
.32 .15019 L
.324 .15019 L
.328 .15019 L
.332 .15017 L
.336 .15016 L
.34 .15015 L
.344 .15016 L
.348 .15017 L
.352 .15019 L
.356 .1502 L
.36 .1502 L
.364 .15021 L
.368 .1502 L
.372 .15018 L
.376 .15016 L
.38 .15014 L
.384 .15014 L
.388 .15016 L
.392 .15018 L
.396 .15021 L
.4 .15022 L
Mistroke
.404 .15023 L
.408 .15023 L
.412 .15021 L
.416 .15017 L
.42 .15012 L
.424 .15011 L
.428 .15012 L
.432 .15016 L
.436 .15021 L
.44 .15024 L
.444 .15026 L
.448 .15026 L
.452 .15025 L
.456 .15022 L
.46 .15015 L
.464 .15009 L
.468 .15006 L
.472 .15008 L
.476 .15015 L
.48 .15023 L
.484 .15029 L
.488 .15031 L
.492 .1503 L
.496 .15028 L
.5 .15024 L
.504 .15018 L
.508 .15008 L
.512 .15001 L
.516 .15001 L
.52 .15008 L
.524 .15021 L
.528 .15031 L
.532 .15035 L
.536 .15034 L
.54 .15031 L
.544 .15029 L
.548 .15026 L
.552 .15019 L
.556 .15008 L
.56 .14998 L
.564 .14996 L
.568 .15004 L
.572 .15019 L
.576 .15031 L
.58 .15035 L
.584 .15033 L
.588 .1503 L
.592 .1503 L
.596 .15033 L
.6 .15033 L
Mistroke
.604 .15024 L
.608 .1501 L
.612 .14998 L
.616 .14995 L
.62 .15002 L
.624 .15013 L
.628 .15021 L
.632 .15022 L
.636 .1502 L
.64 .15021 L
.644 .1503 L
.648 .15043 L
.652 .15054 L
.656 .15055 L
.66 .15045 L
.664 .15027 L
.668 .15008 L
.672 .14995 L
.676 .14988 L
.68 .14986 L
.684 .14986 L
.688 .14988 L
.692 .14991 L
.696 .15001 L
.7 .15017 L
.704 .15042 L
.708 .1507 L
.712 .15095 L
.716 .15108 L
.72 .15103 L
.724 .15079 L
.728 .15041 L
.732 .15001 L
.736 .1497 L
.74 .14953 L
.744 .14949 L
.748 .14952 L
.752 .14953 L
.756 .14951 L
.76 .14952 L
.764 .14967 L
.768 .15005 L
.772 .15064 L
.776 .15133 L
.78 .15193 L
.784 .1523 L
.788 .15238 L
.792 .15228 L
.796 .15218 L
.8 .15228 L
Mistroke
.804 .15268 L
.808 .15334 L
.812 .15415 L
.816 .15494 L
.82 .15565 L
.824 .1563 L
.828 .15703 L
.832 .158 L
.836 .15933 L
.84 .16107 L
.844 .16317 L
.848 .16554 L
.852 .16805 L
.856 .17064 L
.86 .17325 L
.864 .17588 L
.868 .17852 L
.872 .1812 L
.876 .18394 L
.88 .18679 L
.884 .18981 L
.888 .19307 L
.892 .19658 L
.896 .20033 L
.9 .20419 L
.904 .20803 L
.908 .21168 L
.912 .21507 L
.916 .21818 L
.92 .22113 L
.924 .2241 L
.928 .22729 L
.932 .23084 L
.936 .23482 L
.94 .23914 L
.944 .24369 L
.948 .24825 L
.952 .25269 L
.956 .2569 L
.96 .26086 L
.964 .26462 L
.968 .2682 L
.972 .2717 L
.976 .27503 L
.98 .27819 L
.984 .28109 L
.988 .28367 L
.992 .286 L
.996 .28809 L
1 .2902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16249 L
.012 .16127 L
.016 .16076 L
.02 .16117 L
.024 .16134 L
.028 .16127 L
.032 .16117 L
.036 .1612 L
.04 .16119 L
.044 .1612 L
.048 .16118 L
.052 .16122 L
.056 .16122 L
.06 .16123 L
.064 .16121 L
.068 .1612 L
.072 .16118 L
.076 .16119 L
.08 .16119 L
.084 .16121 L
.088 .16121 L
.092 .16122 L
.096 .1612 L
.1 .1612 L
.104 .16118 L
.108 .16119 L
.112 .16119 L
.116 .16121 L
.12 .16121 L
.124 .16121 L
.128 .1612 L
.132 .1612 L
.136 .16119 L
.14 .16119 L
.144 .16119 L
.148 .1612 L
.152 .1612 L
.156 .16121 L
.16 .1612 L
.164 .1612 L
.168 .16119 L
.172 .16119 L
.176 .16119 L
.18 .1612 L
.184 .1612 L
.188 .1612 L
.192 .16119 L
.196 .16119 L
.2 .16119 L
Mistroke
.204 .16119 L
.208 .1612 L
.212 .1612 L
.216 .16119 L
.22 .16119 L
.224 .16118 L
.228 .16119 L
.232 .16119 L
.236 .1612 L
.24 .1612 L
.244 .1612 L
.248 .16119 L
.252 .16119 L
.256 .16118 L
.26 .16118 L
.264 .16118 L
.268 .16118 L
.272 .16119 L
.276 .16119 L
.28 .1612 L
.284 .1612 L
.288 .1612 L
.292 .16119 L
.296 .16117 L
.3 .16116 L
.304 .16117 L
.308 .16118 L
.312 .1612 L
.316 .1612 L
.32 .16121 L
.324 .1612 L
.328 .16119 L
.332 .16117 L
.336 .16116 L
.34 .16115 L
.344 .16116 L
.348 .16118 L
.352 .16119 L
.356 .1612 L
.36 .16121 L
.364 .16122 L
.368 .16121 L
.372 .16118 L
.376 .16115 L
.38 .16112 L
.384 .16113 L
.388 .16115 L
.392 .16119 L
.396 .16121 L
.4 .16123 L
Mistroke
.404 .16123 L
.408 .16123 L
.412 .1612 L
.416 .16116 L
.42 .16111 L
.424 .16108 L
.428 .16109 L
.432 .16114 L
.436 .1612 L
.44 .16125 L
.444 .16127 L
.448 .16127 L
.452 .16125 L
.456 .1612 L
.46 .16113 L
.464 .16105 L
.468 .16101 L
.472 .16104 L
.476 .16112 L
.48 .16122 L
.484 .16129 L
.488 .16132 L
.492 .16131 L
.496 .16128 L
.5 .16123 L
.504 .16115 L
.508 .16103 L
.512 .16094 L
.516 .16094 L
.52 .16103 L
.524 .16118 L
.528 .16131 L
.532 .16136 L
.536 .16134 L
.54 .16131 L
.544 .16128 L
.548 .16124 L
.552 .16115 L
.556 .16101 L
.56 .16089 L
.564 .16087 L
.568 .16097 L
.572 .16115 L
.576 .1613 L
.58 .16135 L
.584 .16132 L
.588 .16128 L
.592 .16129 L
.596 .16133 L
.6 .16132 L
Mistroke
.604 .16121 L
.608 .16104 L
.612 .16088 L
.616 .16084 L
.62 .16093 L
.624 .16106 L
.628 .16116 L
.632 .16117 L
.636 .16115 L
.64 .16117 L
.644 .16127 L
.648 .16144 L
.652 .16157 L
.656 .16159 L
.66 .16146 L
.664 .16123 L
.668 .161 L
.672 .16083 L
.676 .16074 L
.68 .16072 L
.684 .16072 L
.688 .16073 L
.692 .16078 L
.696 .16089 L
.7 .1611 L
.704 .16141 L
.708 .16176 L
.712 .16207 L
.716 .16223 L
.72 .16216 L
.724 .16185 L
.728 .16138 L
.732 .16088 L
.736 .16048 L
.74 .16026 L
.744 .1602 L
.748 .16021 L
.752 .16019 L
.756 .16012 L
.76 .16008 L
.764 .16019 L
.768 .16056 L
.772 .16115 L
.776 .16182 L
.78 .16231 L
.784 .16242 L
.788 .16207 L
.792 .16135 L
.796 .16048 L
.8 .15966 L
Mistroke
.804 .15897 L
.808 .15832 L
.812 .15753 L
.816 .15635 L
.82 .15465 L
.824 .15243 L
.828 .14983 L
.832 .14704 L
.836 .14421 L
.84 .14142 L
.844 .13865 L
.848 .13584 L
.852 .13294 L
.856 .12995 L
.86 .12692 L
.864 .12395 L
.868 .12117 L
.872 .11868 L
.876 .11658 L
.88 .11497 L
.884 .11392 L
.888 .11344 L
.892 .11349 L
.896 .11391 L
.9 .11443 L
.904 .11477 L
.908 .11464 L
.912 .11385 L
.916 .11242 L
.92 .11052 L
.924 .10847 L
.928 .10663 L
.932 .10532 L
.936 .10471 L
.94 .10478 L
.944 .10539 L
.948 .10624 L
.952 .1071 L
.956 .10772 L
.96 .108 L
.964 .10795 L
.968 .1076 L
.972 .10715 L
.976 .10662 L
.98 .10619 L
.984 .10588 L
.988 .10574 L
.992 .10588 L
.996 .10631 L
1 .10724 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001JOol00`00Oomoo`0@Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo
0`0017oo0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol0
0002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00
Oomoogoo00000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00D007oo
Ool007oo008000Aoo`800004Ool007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00D007oo000007oo
0080009oo`03001oo`0000Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`000Woo00H007oo001oo`00Ool30005
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`03001oogoo00]oo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Oomoo`020002Ool20002Ool60003Ool01000Oomoo`001Goo000;Ool2000:
Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@0
07ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D007oo
Oomoo`00009oo`05001oogoo001oo`020002Ool01000Oomoogoo0P000Woo0`001Woo00@007ooOol0
00Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomo
o`D000=oo`8000Aoo`<000Aoo`<00003Ool007oo008000Eoo`<0009oo`D000=oo`8000Ioo`008Woo
00<007ooOol0C7oo0P003Woo0P003Woo000ROol2001<Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool0
029oof<000aoo`008Woo4`0000Eoo`00000007oo00800005Ool00000001oo`0;00001Goo00000000
Ool01@0000=oo`0000000P0000=oo`0000001@0000Aoo`00001oo`800003Ool0000000800003Ool0
000000=oo`05001oogooOol00003Ool02@00Oomoogoo001oo`00Ool0000<Ool0029oo`80009oo`04
001oo`000002Ool01000Oomoo`000Woo00<007ooOol00P0000Eoo`00000007oo00800004Ool00000
0002Ool20002Ool300000goo00000002Ool300001Goo00000000Ool0100000=oo`0000000P0000Ao
o`00001oo`D00006Ool00000001oo`004goo0P0037oo000ROol00`00Oomoo`17Ool00`00Oomoo`0D
Ool00`00Oomoo`0;Ool0029oo`8006eoo`008Woo0P00KGoo000;Ool20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<0
07ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomo
o`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<0
07ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo
000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006io
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo
0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`00
8Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`00
0goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;
Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003
Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo
000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo
0P0017oo00<007ooOol00Woo00<007ooOol0@Goo00<007ooOol08Woo000XOom>000KOol002Qoo`03
001oogoo04Yoo`8001Yoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<0
07ooOol0C7oo0P0067oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`00
0goo00@007ooOol004moo`8001Moo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`001Goo00@007ooOol0055oo`03001oogoo01Aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo
0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000Woo1P000Woo0`0017oo0P001Woo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09
Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoogoo0P0000Aoo`00Ool000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00
Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo
0002Ool01000Oomoo`0017oo0P001Woo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo
0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol0
17oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol0
00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06
001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo1P000goo
00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Ao
o`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool30006Ool01000Oomoo`001Goo
000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomo
ogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00
Oomoo`1GOol3000<Ool002Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool0
0`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool3
0003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005
Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool0
0`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool0
00Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo
0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03
001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomo
o`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo0080
06Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogoo
Ool5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009o
o`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;
Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001ao
o`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eo
o`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00
009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001o
ogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000L
Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool20006Ool01000Oomo
o`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00<007ooOol01`0000=oo`0000001@000goo00@007ooOol0
00Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo
0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<007ooOol00P000goo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomo
ogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00
Oomoo`1DOol2000LOol001aoo`03001oogoo059oo`<001eoo`0077ooJ@0037oo000LOol01@00Oomo
ogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2
001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00
Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@00
0Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Io
o`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomo
o`02Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo00<0
07ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo
000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;
Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo
00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;
Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(18871\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31758 m
.008 .31815 L
.012 .31904 L
.016 .319 L
.02 .31831 L
.024 .3181 L
.028 .31827 L
.032 .31843 L
.036 .31844 L
.04 .31845 L
.044 .31855 L
.048 .31852 L
.052 .31848 L
.056 .31857 L
.06 .3186 L
.064 .3186 L
.068 .3185 L
.072 .31835 L
.076 .31835 L
.08 .31845 L
.084 .31864 L
.088 .31888 L
.092 .31893 L
.096 .31879 L
.1 .3185 L
.104 .31821 L
.108 .31819 L
.112 .31843 L
.116 .31881 L
.12 .31916 L
.124 .31923 L
.128 .31899 L
.132 .31855 L
.136 .31812 L
.14 .31803 L
.144 .31835 L
.148 .31891 L
.152 .31941 L
.156 .31954 L
.16 .31926 L
.164 .31869 L
.168 .3181 L
.172 .31785 L
.176 .31815 L
.18 .31888 L
.184 .3196 L
.188 .31986 L
.192 .31958 L
.196 .31891 L
.2 .3182 L
Mistroke
.204 .31782 L
.208 .31798 L
.212 .31869 L
.216 .31956 L
.22 .32004 L
.224 .31985 L
.228 .31918 L
.232 .31849 L
.236 .31811 L
.24 .31812 L
.244 .31849 L
.248 .31909 L
.252 .31967 L
.256 .31989 L
.26 .31963 L
.264 .31912 L
.268 .31869 L
.272 .31851 L
.276 .31849 L
.28 .31858 L
.284 .31888 L
.288 .31939 L
.292 .31985 L
.296 .31991 L
.3 .3195 L
.304 .31895 L
.308 .31862 L
.312 .31859 L
.316 .31872 L
.32 .31892 L
.324 .31924 L
.328 .3196 L
.332 .3198 L
.336 .31966 L
.34 .31932 L
.344 .31909 L
.348 .31911 L
.352 .31916 L
.356 .31902 L
.36 .31875 L
.364 .31873 L
.368 .31915 L
.372 .31978 L
.376 .32017 L
.38 .32009 L
.384 .31969 L
.388 .3193 L
.392 .31905 L
.396 .31882 L
.4 .31856 L
Mistroke
.404 .31845 L
.408 .31881 L
.412 .31965 L
.416 .32056 L
.42 .32098 L
.424 .32064 L
.428 .31981 L
.432 .31897 L
.436 .31843 L
.44 .31818 L
.444 .31812 L
.448 .31838 L
.452 .31923 L
.456 .32057 L
.46 .32176 L
.464 .32197 L
.468 .32092 L
.472 .31924 L
.476 .31797 L
.48 .31769 L
.484 .31807 L
.488 .31845 L
.492 .3187 L
.496 .31934 L
.5 .32077 L
.504 .32244 L
.508 .32303 L
.512 .32169 L
.516 .31909 L
.52 .31698 L
.524 .31674 L
.528 .31806 L
.532 .31941 L
.536 .31966 L
.54 .31922 L
.544 .31953 L
.548 .32125 L
.552 .32325 L
.556 .32353 L
.56 .32122 L
.564 .31774 L
.568 .31571 L
.572 .31657 L
.576 .31928 L
.58 .32129 L
.584 .32097 L
.588 .31913 L
.592 .31817 L
.596 .3196 L
.6 .32246 L
Mistroke
.604 .32412 L
.608 .32274 L
.612 .3191 L
.616 .31606 L
.62 .31603 L
.624 .3189 L
.628 .32212 L
.632 .32295 L
.636 .32081 L
.64 .31772 L
.644 .31643 L
.648 .31812 L
.652 .32145 L
.656 .32378 L
.66 .32339 L
.664 .32079 L
.668 .31815 L
.672 .31748 L
.676 .31911 L
.68 .32158 L
.684 .32292 L
.688 .32213 L
.692 .3197 L
.696 .31716 L
.7 .3159 L
.704 .3165 L
.708 .31855 L
.712 .32111 L
.716 .32314 L
.72 .32385 L
.724 .32288 L
.728 .32057 L
.732 .31794 L
.736 .31635 L
.74 .3167 L
.744 .31865 L
.748 .32045 L
.752 .31989 L
.756 .31572 L
.76 .30881 L
.764 .30195 L
.768 .29825 L
.772 .299 L
.776 .30249 L
.78 .30465 L
.784 .30134 L
.788 .29099 L
.792 .27573 L
.796 .2604 L
.8 .24982 L
Mistroke
.804 .24601 L
.808 .24704 L
.812 .24822 L
.816 .24493 L
.82 .23546 L
.824 .22206 L
.828 .20986 L
.832 .20409 L
.836 .20735 L
.84 .21846 L
.844 .23307 L
.848 .24614 L
.852 .25403 L
.856 .25604 L
.86 .25384 L
.864 .25023 L
.868 .24741 L
.872 .24604 L
.876 .2456 L
.88 .24496 L
.884 .24375 L
.888 .24219 L
.892 .24122 L
.896 .24131 L
.9 .24209 L
.904 .24249 L
.908 .241 L
.912 .23743 L
.916 .23258 L
.92 .22898 L
.924 .22936 L
.928 .23538 L
.932 .24723 L
.936 .26203 L
.94 .27642 L
.944 .28612 L
.948 .28888 L
.952 .285 L
.956 .27638 L
.96 .26794 L
.964 .26262 L
.968 .26376 L
.972 .27127 L
.976 .28313 L
.98 .29714 L
.984 .30914 L
.988 .31836 L
.992 .32385 L
.996 .3265 L
1 .32875 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14844 m
.008 .15048 L
.012 .15117 L
.016 .1506 L
.02 .15032 L
.024 .15052 L
.028 .15058 L
.032 .15053 L
.036 .15048 L
.04 .15052 L
.044 .15053 L
.048 .15055 L
.052 .15053 L
.056 .15054 L
.06 .15052 L
.064 .15052 L
.068 .15051 L
.072 .15052 L
.076 .15053 L
.08 .15054 L
.084 .15053 L
.088 .15053 L
.092 .15052 L
.096 .15052 L
.1 .15051 L
.104 .15052 L
.108 .15053 L
.112 .15054 L
.116 .15054 L
.12 .15053 L
.124 .15052 L
.128 .15052 L
.132 .15052 L
.136 .15052 L
.14 .15053 L
.144 .15054 L
.148 .15054 L
.152 .15053 L
.156 .15053 L
.16 .15052 L
.164 .15052 L
.168 .15052 L
.172 .15053 L
.176 .15053 L
.18 .15053 L
.184 .15053 L
.188 .15053 L
.192 .15053 L
.196 .15053 L
.2 .15053 L
Mistroke
.204 .15053 L
.208 .15053 L
.212 .15053 L
.216 .15053 L
.22 .15053 L
.224 .15053 L
.228 .15053 L
.232 .15053 L
.236 .15053 L
.24 .15053 L
.244 .15053 L
.248 .15053 L
.252 .15053 L
.256 .15053 L
.26 .15053 L
.264 .15053 L
.268 .15054 L
.272 .15054 L
.276 .15054 L
.28 .15053 L
.284 .15053 L
.288 .15052 L
.292 .15052 L
.296 .15053 L
.3 .15054 L
.304 .15055 L
.308 .15055 L
.312 .15054 L
.316 .15053 L
.32 .15052 L
.324 .15052 L
.328 .15053 L
.332 .15053 L
.336 .15054 L
.34 .15055 L
.344 .15055 L
.348 .15056 L
.352 .15055 L
.356 .15053 L
.36 .15052 L
.364 .15051 L
.368 .15052 L
.372 .15053 L
.376 .15054 L
.38 .15055 L
.384 .15057 L
.388 .15058 L
.392 .15057 L
.396 .15054 L
.4 .15052 L
Mistroke
.404 .1505 L
.408 .15051 L
.412 .15052 L
.416 .15053 L
.42 .15055 L
.424 .15058 L
.428 .1506 L
.432 .1506 L
.436 .15058 L
.44 .15053 L
.444 .15049 L
.448 .15047 L
.452 .15048 L
.456 .15051 L
.46 .15055 L
.464 .15058 L
.468 .15061 L
.472 .15063 L
.476 .15064 L
.48 .1506 L
.484 .15053 L
.488 .15045 L
.492 .15042 L
.496 .15044 L
.5 .1505 L
.504 .15057 L
.508 .15061 L
.512 .15065 L
.516 .15067 L
.52 .15068 L
.524 .15064 L
.528 .15056 L
.532 .15045 L
.536 .15037 L
.54 .15036 L
.544 .15044 L
.548 .15054 L
.552 .15063 L
.556 .15066 L
.56 .15068 L
.564 .15069 L
.568 .1507 L
.572 .15067 L
.576 .15058 L
.58 .15044 L
.584 .15034 L
.588 .15032 L
.592 .15041 L
.596 .15053 L
.6 .15063 L
Mistroke
.604 .15065 L
.608 .15064 L
.612 .15065 L
.616 .1507 L
.62 .15074 L
.624 .15073 L
.628 .15063 L
.632 .15048 L
.636 .15036 L
.64 .15034 L
.644 .1504 L
.648 .15048 L
.652 .15053 L
.656 .15052 L
.66 .15051 L
.664 .15054 L
.668 .15064 L
.672 .15078 L
.676 .1509 L
.68 .15093 L
.684 .15085 L
.688 .15069 L
.692 .15053 L
.696 .15039 L
.7 .15031 L
.704 .15026 L
.708 .15024 L
.712 .15022 L
.716 .15022 L
.72 .15029 L
.724 .15044 L
.728 .1507 L
.732 .15102 L
.736 .15134 L
.74 .15158 L
.744 .15164 L
.748 .15153 L
.752 .15129 L
.756 .15103 L
.76 .15088 L
.764 .15091 L
.768 .15112 L
.772 .15144 L
.776 .15183 L
.78 .15229 L
.784 .15289 L
.788 .15378 L
.792 .15506 L
.796 .15674 L
.8 .15872 L
Mistroke
.804 .16081 L
.808 .16284 L
.812 .16475 L
.816 .16658 L
.82 .16849 L
.824 .17061 L
.828 .17299 L
.832 .17558 L
.836 .17819 L
.84 .18061 L
.844 .18272 L
.848 .18448 L
.852 .18596 L
.856 .18731 L
.86 .18865 L
.864 .19009 L
.868 .19165 L
.872 .19333 L
.876 .19511 L
.88 .19699 L
.884 .19899 L
.888 .20114 L
.892 .20346 L
.896 .20596 L
.9 .20866 L
.904 .21157 L
.908 .21472 L
.912 .21814 L
.916 .22183 L
.92 .22575 L
.924 .22977 L
.928 .23374 L
.932 .23748 L
.936 .24087 L
.94 .24389 L
.944 .24656 L
.948 .2491 L
.952 .25163 L
.956 .25435 L
.96 .25731 L
.964 .26049 L
.968 .26382 L
.972 .2671 L
.976 .27026 L
.98 .27316 L
.984 .27581 L
.988 .27825 L
.992 .28052 L
.996 .28271 L
1 .28484 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15978 L
.012 .16128 L
.016 .16168 L
.02 .16118 L
.024 .16103 L
.028 .16124 L
.032 .16126 L
.036 .1612 L
.04 .16117 L
.044 .16121 L
.048 .16121 L
.052 .16122 L
.056 .16121 L
.06 .16121 L
.064 .16119 L
.068 .1612 L
.072 .16119 L
.076 .1612 L
.08 .1612 L
.084 .16122 L
.088 .16121 L
.092 .16121 L
.096 .16119 L
.1 .16119 L
.104 .16119 L
.108 .1612 L
.112 .16121 L
.116 .16121 L
.12 .16121 L
.124 .1612 L
.128 .16119 L
.132 .16119 L
.136 .16119 L
.14 .1612 L
.144 .1612 L
.148 .16121 L
.152 .1612 L
.156 .1612 L
.16 .16119 L
.164 .16119 L
.168 .16118 L
.172 .16119 L
.176 .1612 L
.18 .1612 L
.184 .1612 L
.188 .1612 L
.192 .16119 L
.196 .16119 L
.2 .16119 L
Mistroke
.204 .16119 L
.208 .16119 L
.212 .1612 L
.216 .16119 L
.22 .16119 L
.224 .16119 L
.228 .16119 L
.232 .16119 L
.236 .16119 L
.24 .16119 L
.244 .16119 L
.248 .16118 L
.252 .16118 L
.256 .16118 L
.26 .16119 L
.264 .16119 L
.268 .1612 L
.272 .1612 L
.276 .16119 L
.28 .16117 L
.284 .16117 L
.288 .16117 L
.292 .16118 L
.296 .16118 L
.3 .16119 L
.304 .1612 L
.308 .1612 L
.312 .16119 L
.316 .16118 L
.32 .16117 L
.324 .16116 L
.328 .16116 L
.332 .16117 L
.336 .16118 L
.34 .16119 L
.344 .16121 L
.348 .16121 L
.352 .16119 L
.356 .16117 L
.36 .16115 L
.364 .16115 L
.368 .16116 L
.372 .16117 L
.376 .16118 L
.38 .16119 L
.384 .16121 L
.388 .16122 L
.392 .16121 L
.396 .16118 L
.4 .16115 L
Mistroke
.404 .16112 L
.408 .16112 L
.412 .16114 L
.416 .16116 L
.42 .16119 L
.424 .16122 L
.428 .16124 L
.432 .16124 L
.436 .16121 L
.44 .16116 L
.444 .16111 L
.448 .16108 L
.452 .16109 L
.456 .16112 L
.46 .16117 L
.464 .16121 L
.468 .16125 L
.472 .16128 L
.476 .16128 L
.48 .16123 L
.484 .16114 L
.488 .16105 L
.492 .161 L
.496 .16103 L
.5 .1611 L
.504 .16118 L
.508 .16124 L
.512 .16128 L
.516 .16131 L
.52 .16132 L
.524 .16128 L
.528 .16117 L
.532 .16104 L
.536 .16093 L
.54 .16093 L
.544 .16102 L
.548 .16115 L
.552 .16125 L
.556 .16129 L
.56 .16131 L
.564 .16133 L
.568 .16134 L
.572 .1613 L
.576 .16118 L
.58 .16101 L
.584 .16088 L
.588 .16086 L
.592 .16097 L
.596 .16112 L
.6 .16124 L
Mistroke
.604 .16127 L
.608 .16126 L
.612 .16127 L
.616 .16133 L
.62 .16138 L
.624 .16136 L
.628 .16123 L
.632 .16104 L
.636 .1609 L
.64 .16087 L
.644 .16094 L
.648 .16105 L
.652 .16111 L
.656 .1611 L
.66 .16107 L
.664 .16111 L
.668 .16124 L
.672 .16142 L
.676 .16156 L
.68 .16159 L
.684 .16149 L
.688 .1613 L
.692 .16109 L
.696 .16092 L
.7 .16081 L
.704 .16075 L
.708 .16071 L
.712 .16067 L
.716 .16067 L
.72 .16073 L
.724 .16089 L
.728 .16117 L
.732 .16152 L
.736 .16185 L
.74 .16204 L
.744 .16199 L
.748 .16166 L
.752 .16112 L
.756 .16047 L
.76 .15986 L
.764 .15934 L
.768 .1589 L
.772 .15841 L
.776 .15777 L
.78 .15695 L
.784 .156 L
.788 .15505 L
.792 .15419 L
.796 .15339 L
.8 .1525 L
Mistroke
.804 .15127 L
.808 .14947 L
.812 .14705 L
.816 .14409 L
.82 .14083 L
.824 .13753 L
.828 .13435 L
.832 .13131 L
.836 .1283 L
.84 .12518 L
.844 .12188 L
.848 .11843 L
.852 .11498 L
.856 .1117 L
.86 .10873 L
.864 .10613 L
.868 .1038 L
.872 .10165 L
.876 .09951 L
.88 .09729 L
.884 .09493 L
.888 .09245 L
.892 .08989 L
.896 .08733 L
.9 .08491 L
.904 .08275 L
.908 .08102 L
.912 .07985 L
.916 .07927 L
.92 .07923 L
.924 .07952 L
.928 .07986 L
.932 .07994 L
.936 .07952 L
.94 .07856 L
.944 .07716 L
.948 .07564 L
.952 .07432 L
.956 .07361 L
.96 .07371 L
.964 .07468 L
.968 .07643 L
.972 .07865 L
.976 .08112 L
.98 .08352 L
.984 .0857 L
.988 .08761 L
.992 .08921 L
.996 .09062 L
1 .09184 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001?Ool00`00Oomoo`0KOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo
0`0017oo0P000goo1@000goo0P000Woo100017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol0
0002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00
Oomoogoo00000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo0P0000Eo
o`00Oomoo`0000Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00P0000Eoo`00Oomoo`00
00=oo`<000Moo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`06001oogooOol007oo0`0000Aoo`00001oo`D00003Ool0000000Ioo`04001oogoo0002Ool0
0`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol02goo
10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007oo0000009oo`@000=o
o`06001oo`00Ool007oo10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol0
0Woo0P0037oo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomo
o`0017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001oogooOol00002Ool01000Ool0
00000Woo00@007ooOol000=oo`04001oo`00Ool30006Ool01000Oomoo`001Goo000ROol2000<Ool5
0003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`00
17oo0P0017oo0P001Goo100000=oo`0000000`000goo0P001Woo000ROol00`00Oomoo`1:Ool00`00
Oomoo`0<Ool200000goo001oo`0>Ool0029oo`8004Uoo`03001oo`0000ioo`05001oogooOol0000>
Ool0029oof<000aoo`008Woo6@0000Eoo`00000007oo00<00005Ool00000001oo`0300001Goo0000
0000Ool00`0000=oo`0000000P0000=oo`0000001`0000Aoo`00001oo`L000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007oo001oo`0000aoo`008Woo0P003Goo00<007ooOol00P00
00=oo`0000000Woo00<007ooOol00P000Woo0P000Woo0`0000Aoo`000000009oo`800005Ool00000
001oo`0400001Goo00000000Ool00P0000=oo`0000000`0000Eoo`00001oo`0001Moo`8000aoo`00
8Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo
0P000goo0`000goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03
001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007oo
Ool000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006io
o`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`00
0goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001o
o`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0
029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol0
00=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`00
2goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Io
o`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yo
o`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7ooBP007goo000XOol00`00Oomoo`17Ool2
000MOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo04Uoo`80
01]oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo
001<Ool3000IOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eo
o`04001oogoo001?Ool3000FOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Ao
o`80009oo`D000=oo`8000Aoo`80009oo`H0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009o
o`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogoo
Ool00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo
00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`00
17oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P00
0Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009o
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00Woo0P001Woo00@007ooOol0009o
o`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo1P000goo00@007ooOol000Eoo`00
:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool0
1000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0003Ool30006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09
Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo
0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1HOol2000<Ool0
02Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00
Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1V
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00
J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo06Io
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Io
o`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
2goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009o
o`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo
000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007oo
Ool017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<0
00Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`80
00Eoo`H00004Ool000000004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomo
o`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
009oo`X0009oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo
0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00D0
07ooOol007oo008000=oo`03001oogoo009oo`@0009oo`04001oogoo0005Ool001aoo`03001oogoo
011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`8000Ioo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001ao
o`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002
Ool40004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03
001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=o
o`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`800003
Ool007oo00=oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo
0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`80
009oo`@000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0DWoo00<007ooOol07Goo000L
Ool00`00Oomoo`1?Ool4000OOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo
009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo
009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00
Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<0
07ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol0
00]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1b
Ool001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol0
0`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P00
17oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo
00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`00
2goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomo
o`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@00
0Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(19038\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31692 m
.008 .31781 L
.012 .31863 L
.016 .31916 L
.02 .31897 L
.024 .31861 L
.028 .31823 L
.032 .31789 L
.036 .31785 L
.04 .31813 L
.044 .31865 L
.048 .31906 L
.052 .31901 L
.056 .31866 L
.06 .3182 L
.064 .31788 L
.068 .31798 L
.072 .31836 L
.076 .31885 L
.08 .31917 L
.084 .31906 L
.088 .31866 L
.092 .31818 L
.096 .31791 L
.1 .31806 L
.104 .3185 L
.108 .31901 L
.112 .31931 L
.116 .31917 L
.12 .3187 L
.124 .31819 L
.128 .31793 L
.132 .31811 L
.136 .31859 L
.14 .31912 L
.144 .31943 L
.148 .31931 L
.152 .31883 L
.156 .31828 L
.16 .31799 L
.164 .31814 L
.168 .3186 L
.172 .31911 L
.176 .31945 L
.18 .31945 L
.184 .31912 L
.188 .31858 L
.192 .31815 L
.196 .31809 L
.2 .31841 L
Mistroke
.204 .31892 L
.208 .31938 L
.212 .31962 L
.216 .31954 L
.22 .31911 L
.224 .31847 L
.228 .318 L
.232 .31803 L
.236 .31858 L
.24 .3193 L
.244 .3198 L
.248 .31989 L
.252 .31954 L
.256 .31889 L
.26 .31821 L
.264 .31791 L
.268 .31824 L
.272 .31903 L
.276 .31975 L
.28 .31998 L
.284 .3197 L
.288 .31923 L
.292 .31881 L
.296 .31852 L
.3 .3184 L
.304 .31856 L
.308 .31901 L
.312 .31951 L
.316 .31976 L
.32 .31966 L
.324 .31941 L
.328 .3192 L
.332 .31901 L
.336 .31877 L
.34 .31858 L
.344 .31869 L
.348 .31915 L
.352 .31966 L
.356 .31983 L
.36 .31963 L
.364 .31934 L
.368 .31926 L
.372 .31931 L
.376 .31923 L
.38 .31894 L
.384 .3187 L
.388 .31878 L
.392 .3192 L
.396 .31969 L
.4 .31995 L
Mistroke
.404 .31997 L
.408 .31987 L
.412 .31971 L
.416 .31939 L
.42 .31887 L
.424 .31835 L
.428 .31823 L
.432 .31875 L
.436 .31969 L
.44 .32052 L
.444 .32079 L
.448 .32051 L
.452 .32 L
.456 .3195 L
.46 .31898 L
.464 .31833 L
.468 .31777 L
.472 .31785 L
.476 .31893 L
.48 .32061 L
.484 .32188 L
.488 .32191 L
.492 .32077 L
.496 .3194 L
.5 .31865 L
.504 .31851 L
.508 .31837 L
.512 .31792 L
.516 .31775 L
.52 .31873 L
.524 .32087 L
.528 .32289 L
.532 .32321 L
.536 .32145 L
.54 .31893 L
.544 .31749 L
.548 .31781 L
.552 .31888 L
.556 .31918 L
.56 .31846 L
.564 .318 L
.568 .31921 L
.572 .32188 L
.576 .32404 L
.58 .32365 L
.584 .32071 L
.588 .3174 L
.592 .31624 L
.596 .31779 L
.6 .3202 L
Mistroke
.604 .32106 L
.608 .31969 L
.612 .31783 L
.616 .31783 L
.62 .32032 L
.624 .32343 L
.628 .32441 L
.632 .32219 L
.636 .31839 L
.64 .31601 L
.644 .31684 L
.648 .31996 L
.652 .32258 L
.656 .3225 L
.66 .31991 L
.664 .31711 L
.668 .31654 L
.672 .31868 L
.676 .32182 L
.68 .32353 L
.684 .32264 L
.688 .32 L
.692 .3177 L
.696 .31733 L
.7 .31887 L
.704 .32089 L
.708 .3217 L
.712 .32049 L
.716 .31768 L
.72 .31445 L
.724 .31194 L
.728 .3107 L
.732 .31059 L
.736 .31092 L
.74 .3106 L
.744 .30851 L
.748 .30393 L
.752 .29702 L
.756 .28898 L
.76 .28154 L
.764 .2759 L
.768 .27178 L
.772 .26729 L
.776 .26005 L
.78 .24897 L
.784 .23541 L
.788 .22293 L
.792 .21541 L
.796 .21473 L
.8 .21946 L
Mistroke
.804 .22556 L
.808 .22879 L
.812 .2273 L
.816 .22293 L
.82 .22006 L
.824 .22302 L
.828 .23315 L
.832 .24778 L
.836 .26129 L
.84 .2681 L
.844 .26556 L
.848 .25521 L
.852 .24198 L
.856 .23142 L
.86 .22724 L
.864 .22962 L
.868 .23593 L
.872 .24235 L
.876 .24609 L
.88 .24663 L
.884 .24524 L
.888 .24421 L
.892 .24495 L
.896 .2477 L
.9 .25152 L
.904 .25513 L
.908 .25829 L
.912 .26121 L
.916 .26522 L
.92 .27085 L
.924 .27776 L
.928 .28479 L
.932 .2897 L
.936 .29198 L
.94 .29146 L
.944 .29052 L
.948 .29187 L
.952 .29751 L
.956 .30861 L
.96 .32269 L
.964 .3367 L
.968 .34601 L
.972 .34694 L
.976 .33874 L
.98 .32209 L
.984 .30091 L
.988 .2803 L
.992 .26346 L
.996 .25526 L
1 .25481 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15257 m
.008 .15084 L
.012 .15027 L
.016 .15095 L
.02 .1511 L
.024 .15087 L
.028 .1508 L
.032 .1509 L
.036 .1509 L
.04 .15089 L
.044 .15087 L
.048 .1509 L
.052 .15089 L
.056 .15089 L
.06 .15087 L
.064 .15088 L
.068 .15088 L
.072 .15089 L
.076 .15089 L
.08 .1509 L
.084 .15088 L
.088 .15088 L
.092 .15087 L
.096 .15088 L
.1 .15088 L
.104 .15089 L
.108 .15089 L
.112 .15089 L
.116 .15088 L
.12 .15088 L
.124 .15087 L
.128 .15088 L
.132 .15088 L
.136 .15089 L
.14 .15089 L
.144 .15089 L
.148 .15089 L
.152 .15088 L
.156 .15088 L
.16 .15088 L
.164 .15088 L
.168 .15089 L
.172 .1509 L
.176 .1509 L
.18 .15089 L
.184 .15088 L
.188 .15088 L
.192 .15088 L
.196 .15089 L
.2 .15089 L
Mistroke
.204 .15089 L
.208 .15089 L
.212 .15089 L
.216 .15089 L
.22 .15088 L
.224 .15089 L
.228 .15089 L
.232 .15089 L
.236 .15089 L
.24 .15089 L
.244 .15089 L
.248 .15089 L
.252 .15089 L
.256 .1509 L
.26 .15089 L
.264 .15089 L
.268 .15089 L
.272 .15089 L
.276 .15088 L
.28 .15089 L
.284 .15089 L
.288 .1509 L
.292 .1509 L
.296 .1509 L
.3 .15089 L
.304 .15089 L
.308 .15089 L
.312 .15089 L
.316 .15088 L
.32 .15089 L
.324 .1509 L
.328 .15091 L
.332 .15091 L
.336 .15091 L
.34 .15089 L
.344 .15089 L
.348 .15088 L
.352 .15088 L
.356 .15088 L
.36 .1509 L
.364 .15091 L
.368 .15092 L
.372 .15092 L
.376 .15091 L
.38 .1509 L
.384 .15089 L
.388 .15088 L
.392 .15088 L
.396 .15088 L
.4 .15089 L
Mistroke
.404 .15091 L
.408 .15093 L
.412 .15094 L
.416 .15093 L
.42 .15091 L
.424 .15088 L
.428 .15087 L
.432 .15087 L
.436 .15087 L
.44 .15088 L
.444 .1509 L
.448 .15093 L
.452 .15096 L
.456 .15097 L
.46 .15095 L
.464 .1509 L
.468 .15086 L
.472 .15084 L
.476 .15084 L
.48 .15086 L
.484 .15088 L
.488 .15092 L
.492 .15097 L
.496 .15101 L
.5 .15101 L
.504 .15098 L
.508 .1509 L
.512 .15083 L
.516 .15079 L
.52 .1508 L
.524 .15084 L
.528 .15089 L
.532 .15094 L
.536 .15099 L
.54 .15104 L
.544 .15107 L
.548 .15104 L
.552 .15094 L
.556 .15082 L
.56 .15074 L
.564 .15074 L
.568 .1508 L
.572 .15088 L
.576 .15093 L
.58 .15097 L
.584 .15102 L
.588 .15107 L
.592 .15111 L
.596 .15107 L
.6 .15096 L
Mistroke
.604 .15082 L
.608 .15071 L
.612 .1507 L
.616 .15077 L
.62 .15087 L
.624 .15094 L
.628 .15095 L
.632 .15096 L
.636 .15101 L
.64 .15108 L
.644 .15114 L
.648 .15112 L
.652 .151 L
.656 .15086 L
.66 .15075 L
.664 .15074 L
.668 .15079 L
.672 .15085 L
.676 .15087 L
.68 .15084 L
.684 .15083 L
.688 .15087 L
.692 .15099 L
.696 .15115 L
.7 .15129 L
.704 .15135 L
.708 .15133 L
.712 .15124 L
.716 .15115 L
.72 .15109 L
.724 .15108 L
.728 .15114 L
.732 .15124 L
.736 .15139 L
.74 .15162 L
.744 .15198 L
.748 .15251 L
.752 .15325 L
.756 .15421 L
.76 .15533 L
.764 .15651 L
.768 .1577 L
.772 .15886 L
.776 .16004 L
.78 .16135 L
.784 .1629 L
.788 .16474 L
.792 .16685 L
.796 .16912 L
.8 .17144 L
Mistroke
.804 .17377 L
.808 .17614 L
.812 .17861 L
.816 .18126 L
.82 .18406 L
.824 .18687 L
.828 .1895 L
.832 .19177 L
.836 .19363 L
.84 .19516 L
.844 .19655 L
.848 .19803 L
.852 .19973 L
.856 .20169 L
.86 .20381 L
.864 .20594 L
.868 .20797 L
.872 .20983 L
.876 .21156 L
.88 .21322 L
.884 .2149 L
.888 .21663 L
.892 .21842 L
.896 .22024 L
.9 .22206 L
.904 .2239 L
.908 .22575 L
.912 .22764 L
.916 .22959 L
.92 .23158 L
.924 .23364 L
.928 .23574 L
.932 .23794 L
.936 .24027 L
.94 .24275 L
.944 .2454 L
.948 .24811 L
.952 .25077 L
.956 .25321 L
.96 .25531 L
.964 .25704 L
.968 .25843 L
.972 .25966 L
.976 .26094 L
.98 .2625 L
.984 .26451 L
.988 .26704 L
.992 .27001 L
.996 .27337 L
1 .27681 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15963 L
.012 .16118 L
.016 .16171 L
.02 .16126 L
.024 .16102 L
.028 .16118 L
.032 .16124 L
.036 .16123 L
.04 .16119 L
.044 .16122 L
.048 .16121 L
.052 .16121 L
.056 .16119 L
.06 .1612 L
.064 .16119 L
.068 .16121 L
.072 .16121 L
.076 .16122 L
.08 .16121 L
.084 .1612 L
.088 .16119 L
.092 .16119 L
.096 .16119 L
.1 .16121 L
.104 .16121 L
.108 .16121 L
.112 .1612 L
.116 .1612 L
.12 .16118 L
.124 .16119 L
.128 .16119 L
.132 .1612 L
.136 .16121 L
.14 .16121 L
.144 .1612 L
.148 .16119 L
.152 .16118 L
.156 .16119 L
.16 .16119 L
.164 .1612 L
.168 .1612 L
.172 .1612 L
.176 .1612 L
.18 .16119 L
.184 .16119 L
.188 .16119 L
.192 .16119 L
.196 .16119 L
.2 .16119 L
Mistroke
.204 .16119 L
.208 .16119 L
.212 .16119 L
.216 .16119 L
.22 .16119 L
.224 .16118 L
.228 .16118 L
.232 .16119 L
.236 .16119 L
.24 .16119 L
.244 .16119 L
.248 .16119 L
.252 .16119 L
.256 .16119 L
.26 .16118 L
.264 .16119 L
.268 .16119 L
.272 .16118 L
.276 .16118 L
.28 .16117 L
.284 .16118 L
.288 .16119 L
.292 .1612 L
.296 .16119 L
.3 .16119 L
.304 .16118 L
.308 .16117 L
.312 .16117 L
.316 .16117 L
.32 .16118 L
.324 .16119 L
.328 .1612 L
.332 .1612 L
.336 .16119 L
.34 .16117 L
.344 .16117 L
.348 .16116 L
.352 .16116 L
.356 .16116 L
.36 .16117 L
.364 .16119 L
.368 .1612 L
.372 .16121 L
.376 .16119 L
.38 .16117 L
.384 .16115 L
.388 .16115 L
.392 .16115 L
.396 .16115 L
.4 .16116 L
Mistroke
.404 .16118 L
.408 .16121 L
.412 .16122 L
.416 .16121 L
.42 .16118 L
.424 .16115 L
.428 .16113 L
.432 .16112 L
.436 .16112 L
.44 .16114 L
.444 .16117 L
.448 .16121 L
.452 .16124 L
.456 .16125 L
.46 .16122 L
.464 .16116 L
.468 .16111 L
.472 .16108 L
.476 .16109 L
.48 .1611 L
.484 .16113 L
.488 .16118 L
.492 .16124 L
.496 .16129 L
.5 .1613 L
.504 .16124 L
.508 .16115 L
.512 .16106 L
.516 .16101 L
.52 .16103 L
.524 .16108 L
.528 .16113 L
.532 .16119 L
.536 .16125 L
.54 .16132 L
.544 .16135 L
.548 .16131 L
.552 .16119 L
.556 .16104 L
.56 .16094 L
.564 .16094 L
.568 .16101 L
.572 .16111 L
.576 .16118 L
.58 .16122 L
.584 .16128 L
.588 .16135 L
.592 .16139 L
.596 .16135 L
.6 .16121 L
Mistroke
.604 .16102 L
.608 .16089 L
.612 .16088 L
.616 .16097 L
.62 .16109 L
.624 .16117 L
.628 .16119 L
.632 .1612 L
.636 .16126 L
.64 .16135 L
.644 .16141 L
.648 .16138 L
.652 .16124 L
.656 .16106 L
.66 .16093 L
.664 .16091 L
.668 .16096 L
.672 .16103 L
.676 .16105 L
.68 .16102 L
.684 .16099 L
.688 .16103 L
.692 .16116 L
.696 .16134 L
.7 .16147 L
.704 .1615 L
.708 .1614 L
.712 .1612 L
.716 .16095 L
.72 .16071 L
.724 .16047 L
.728 .16023 L
.732 .15996 L
.736 .15963 L
.74 .15926 L
.744 .15885 L
.748 .15846 L
.752 .15807 L
.756 .15766 L
.76 .15709 L
.764 .15624 L
.768 .15496 L
.772 .15319 L
.776 .15098 L
.78 .14844 L
.784 .14573 L
.788 .14294 L
.792 .14006 L
.796 .13706 L
.8 .13387 L
Mistroke
.804 .13054 L
.808 .12722 L
.812 .12412 L
.816 .12141 L
.82 .11915 L
.824 .11722 L
.828 .1154 L
.832 .11347 L
.836 .11129 L
.84 .10889 L
.844 .10638 L
.848 .10393 L
.852 .1016 L
.856 .09933 L
.86 .09696 L
.864 .0943 L
.868 .09125 L
.872 .08783 L
.876 .08419 L
.88 .08054 L
.884 .07708 L
.888 .07394 L
.892 .07113 L
.896 .0686 L
.9 .06624 L
.904 .06397 L
.908 .06172 L
.912 .05947 L
.916 .05723 L
.92 .05507 L
.924 .05311 L
.928 .0515 L
.932 .05045 L
.936 .05011 L
.94 .05056 L
.944 .05179 L
.948 .05357 L
.952 .05563 L
.956 .05758 L
.96 .05914 L
.964 .06016 L
.968 .06063 L
.972 .06078 L
.976 .06087 L
.98 .06121 L
.984 .062 L
.988 .06329 L
.992 .06496 L
.996 .0669 L
1 .0688 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool00`00Oomoo`0500001Goo001oogoo000017oo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool200000goo001oo`0200000goo00000005Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomo
ogoo0P0000=oo`00Ool00`0000Aoo`00000000Aoo`03001oogoo00Aoo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol02goo1000
0goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Oomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00D007ooOol007oo00<00003Ool0
07oo00<000=oo`03001oo`0000<000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03001o
ogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01P00Oomoogoo001oo`80009o
o`04001oogoo0002Ool01@00Oomoogoo00000goo00D007oo001oo`0000Aoo`04001oogoo0005Ool0
029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003
Ool20004Ool30002Ool01000Ool000000goo0`001Goo0`000Woo1@000goo0P001Woo000ROol00`00
Oomoo`17Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool0029oo`8004Moo`80011o
o`<0009oo`03001oogoo00aoo`008WooH`0037oo000ROolE00000goo0000000@00001Goo00000000
Ool00`0000Eoo`00000007oo00<00003Ool0000000800004Ool00000Ool200000goo001oo`030000
0goo001oo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`800004Ool007oo000<Ool0
029oo`8000Uoo`03001oogoo00800004Ool00000Ool20002Ool200000goo00000002Ool2000017oo
000000000Woo0`0000Eoo`00000007oo0080009oo`8000=oo`800003Ool007oo00@00004Ool00000
Ool2000GOol00`00Ool0000>Ool0029oo`03001oogoo05]oo`8000moo`008Woo0P00G7oo0P003goo
000ROol2001]Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00
KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001o
ogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`80
06eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]
Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@0
07ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02
001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`80
00Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eo
o`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol5
0002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol002QoodP0025oo`00:7oo00<007ooOol0A7oo0`007goo000;Ool20004Ool00`00Oomoo`03
Ool20004Ool20003Ool30003Ool00`00Oomoo`16Ool3000MOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00BWoo0P0077oo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00C7oo0`006Goo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool2
0007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool400000goo
000000030002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007oo
Ool007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`D0009oo`03001oo`0000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007oo
Ool007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomo
o`0000Aoo`04001oogoo0002Ool01000Oomoo`000goo0P001goo00@007ooOol0009oo`03001oogoo
00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool00Woo0P001Woo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo
00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomo
o`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
0goo1P000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol0
00Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool01000Ool00000
1Goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P00
17oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=o
o`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<0
07ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<0
07ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P00
17oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06
001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001o
ogoo001oo`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:
Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo0000
0goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool0
0`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<0
07ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004
Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool0
0`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool0
1000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8005eoo`D0015oo`002goo0P0027oo1@000Woo
00<007ooOol0FWoo0`000goo1@003Goo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool2
0004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20002Ool200000goo00000003
0002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0
009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00`000goo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000
Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00
Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00
009oo`03001oogoo00@000Moo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001ao
o`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`05001oogoo001o
o`020002Ool00`00Oomoo`02Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03
001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00<007oo
Ool010000Woo00<007ooOol00Woo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2
000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P00
1Woo0`0017oo0`000goo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1?Ool00`00
Oomoo`0POol001aoo`03001oogoo04eoo`8002=oo`0077ooJ@0037oo000LOol01@00Oomoogoo0000
0goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000;
Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:
Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2
001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Ioo`<000=o
o`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2
001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0
LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool0
0`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000
Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@0
00=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00
Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(19205\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3187 m
.008 .31843 L
.012 .31789 L
.016 .31808 L
.02 .31867 L
.024 .31873 L
.028 .31838 L
.032 .31814 L
.036 .3182 L
.04 .31834 L
.044 .31845 L
.048 .31861 L
.052 .31861 L
.056 .31843 L
.06 .31828 L
.064 .31821 L
.068 .31834 L
.072 .31859 L
.076 .31875 L
.08 .31877 L
.084 .31858 L
.088 .3183 L
.092 .31817 L
.096 .31825 L
.1 .31854 L
.104 .31887 L
.108 .31901 L
.112 .31889 L
.116 .31855 L
.12 .31818 L
.124 .31806 L
.128 .31828 L
.132 .31875 L
.136 .31917 L
.14 .31927 L
.144 .31901 L
.148 .31851 L
.152 .31805 L
.156 .31794 L
.16 .3183 L
.164 .31895 L
.168 .31949 L
.172 .31955 L
.176 .31912 L
.18 .31846 L
.184 .31796 L
.188 .3179 L
.192 .31834 L
.196 .31907 L
.2 .31967 L
Mistroke
.204 .31975 L
.208 .31926 L
.212 .31853 L
.216 .31803 L
.22 .31801 L
.224 .31839 L
.228 .31898 L
.232 .31952 L
.236 .31976 L
.24 .31955 L
.244 .31897 L
.248 .31839 L
.252 .31814 L
.256 .31828 L
.26 .31867 L
.264 .31915 L
.268 .3196 L
.272 .31984 L
.276 .31966 L
.28 .31906 L
.284 .31837 L
.288 .31804 L
.292 .31828 L
.296 .31888 L
.3 .31948 L
.304 .31983 L
.308 .31988 L
.312 .31958 L
.316 .31902 L
.32 .31844 L
.324 .31824 L
.328 .31855 L
.332 .31913 L
.336 .31956 L
.34 .31964 L
.344 .31955 L
.348 .31948 L
.352 .31939 L
.356 .31915 L
.36 .31879 L
.364 .31859 L
.368 .31876 L
.372 .31919 L
.376 .31953 L
.38 .31962 L
.384 .31955 L
.388 .31953 L
.392 .31956 L
.396 .31946 L
.4 .31917 L
Mistroke
.404 .31883 L
.408 .31873 L
.412 .31893 L
.416 .31926 L
.42 .31951 L
.424 .31968 L
.428 .31987 L
.432 .32008 L
.436 .32009 L
.44 .31966 L
.444 .31889 L
.448 .31822 L
.452 .31815 L
.456 .31878 L
.46 .31968 L
.464 .32032 L
.468 .32049 L
.472 .32042 L
.476 .32032 L
.48 .3201 L
.484 .31944 L
.488 .31834 L
.492 .31744 L
.496 .31755 L
.5 .31888 L
.504 .32066 L
.508 .32171 L
.512 .32151 L
.516 .32057 L
.52 .31982 L
.524 .31958 L
.528 .3193 L
.532 .3184 L
.536 .31725 L
.54 .31702 L
.544 .31854 L
.548 .32115 L
.552 .32306 L
.556 .32288 L
.56 .32094 L
.564 .31898 L
.568 .31844 L
.572 .3191 L
.576 .31949 L
.58 .31862 L
.584 .31724 L
.588 .31715 L
.592 .31931 L
.596 .32255 L
.6 .32438 L
Mistroke
.604 .32324 L
.608 .32003 L
.612 .31737 L
.616 .31722 L
.62 .31916 L
.624 .32088 L
.628 .3205 L
.632 .31838 L
.636 .31683 L
.64 .31783 L
.644 .32105 L
.648 .324 L
.652 .32418 L
.656 .32131 L
.66 .31761 L
.664 .31594 L
.668 .31734 L
.672 .32024 L
.676 .32191 L
.68 .32072 L
.684 .31746 L
.688 .3145 L
.692 .31375 L
.696 .3151 L
.7 .31664 L
.704 .31618 L
.708 .31294 L
.712 .30791 L
.716 .30292 L
.72 .29915 L
.724 .29637 L
.728 .29328 L
.732 .28847 L
.736 .2813 L
.74 .27213 L
.744 .26202 L
.748 .25218 L
.752 .2436 L
.756 .23684 L
.76 .23183 L
.764 .2279 L
.768 .22405 L
.772 .21962 L
.776 .21503 L
.78 .21186 L
.784 .21223 L
.788 .21732 L
.792 .22635 L
.796 .23643 L
.8 .24403 L
Mistroke
.804 .24692 L
.808 .24562 L
.812 .24304 L
.816 .24262 L
.82 .24594 L
.824 .25139 L
.828 .25506 L
.832 .25302 L
.836 .24423 L
.84 .23148 L
.844 .22038 L
.848 .21642 L
.852 .22196 L
.856 .23499 L
.86 .24997 L
.864 .26095 L
.868 .2643 L
.872 .26044 L
.876 .25329 L
.88 .24775 L
.884 .24764 L
.888 .25355 L
.892 .26368 L
.896 .27483 L
.9 .28438 L
.904 .2917 L
.908 .29719 L
.912 .30258 L
.916 .30835 L
.92 .31444 L
.924 .31986 L
.928 .32343 L
.932 .32545 L
.936 .32627 L
.94 .32738 L
.944 .32917 L
.948 .33063 L
.952 .33008 L
.956 .32485 L
.96 .31391 L
.964 .2987 L
.968 .28193 L
.972 .2697 L
.976 .26575 L
.98 .27272 L
.984 .29038 L
.988 .31222 L
.992 .33429 L
.996 .34753 L
1 .34894 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .1536 m
.008 .1513 L
.012 .15046 L
.016 .15121 L
.02 .15147 L
.024 .15127 L
.028 .15115 L
.032 .15124 L
.036 .15127 L
.04 .15126 L
.044 .15123 L
.048 .15124 L
.052 .15123 L
.056 .15124 L
.06 .15124 L
.064 .15125 L
.068 .15125 L
.072 .15125 L
.076 .15124 L
.08 .15124 L
.084 .15123 L
.088 .15124 L
.092 .15124 L
.096 .15125 L
.1 .15125 L
.104 .15125 L
.108 .15124 L
.112 .15124 L
.116 .15123 L
.12 .15124 L
.124 .15124 L
.128 .15125 L
.132 .15125 L
.136 .15125 L
.14 .15124 L
.144 .15124 L
.148 .15123 L
.152 .15124 L
.156 .15124 L
.16 .15125 L
.164 .15125 L
.168 .15125 L
.172 .15124 L
.176 .15124 L
.18 .15124 L
.184 .15124 L
.188 .15124 L
.192 .15125 L
.196 .15125 L
.2 .15125 L
Mistroke
.204 .15125 L
.208 .15125 L
.212 .15124 L
.216 .15124 L
.22 .15124 L
.224 .15125 L
.228 .15125 L
.232 .15125 L
.236 .15125 L
.24 .15125 L
.244 .15124 L
.248 .15124 L
.252 .15125 L
.256 .15125 L
.26 .15125 L
.264 .15125 L
.268 .15125 L
.272 .15125 L
.276 .15125 L
.28 .15125 L
.284 .15125 L
.288 .15126 L
.292 .15125 L
.296 .15124 L
.3 .15124 L
.304 .15124 L
.308 .15125 L
.312 .15126 L
.316 .15126 L
.32 .15126 L
.324 .15125 L
.328 .15125 L
.332 .15125 L
.336 .15124 L
.34 .15124 L
.344 .15125 L
.348 .15126 L
.352 .15127 L
.356 .15127 L
.36 .15126 L
.364 .15126 L
.368 .15125 L
.372 .15124 L
.376 .15124 L
.38 .15124 L
.384 .15125 L
.388 .15127 L
.392 .15128 L
.396 .15128 L
.4 .15127 L
Mistroke
.404 .15126 L
.408 .15125 L
.412 .15124 L
.416 .15124 L
.42 .15123 L
.424 .15124 L
.428 .15127 L
.432 .15129 L
.436 .1513 L
.44 .15129 L
.444 .15127 L
.448 .15125 L
.452 .15124 L
.456 .15123 L
.46 .15122 L
.464 .15123 L
.468 .15125 L
.472 .15129 L
.476 .15132 L
.48 .15133 L
.484 .15131 L
.488 .15127 L
.492 .15124 L
.496 .15121 L
.5 .1512 L
.504 .1512 L
.508 .15122 L
.512 .15126 L
.516 .15132 L
.52 .15137 L
.524 .15138 L
.528 .15134 L
.532 .15127 L
.536 .15121 L
.54 .15117 L
.544 .15117 L
.548 .15119 L
.552 .15121 L
.556 .15126 L
.56 .15133 L
.564 .15141 L
.568 .15145 L
.572 .15142 L
.576 .15132 L
.58 .1512 L
.584 .15113 L
.588 .15112 L
.592 .15116 L
.596 .1512 L
.6 .15124 L
Mistroke
.604 .15128 L
.608 .15136 L
.612 .15145 L
.616 .1515 L
.62 .15146 L
.624 .15134 L
.628 .1512 L
.632 .1511 L
.636 .15109 L
.64 .15115 L
.644 .15121 L
.648 .15125 L
.652 .15126 L
.656 .1513 L
.66 .15138 L
.664 .15148 L
.668 .15155 L
.672 .15153 L
.676 .15144 L
.68 .15133 L
.684 .15128 L
.688 .15131 L
.692 .15141 L
.696 .15153 L
.7 .15163 L
.704 .15175 L
.708 .15192 L
.712 .15221 L
.716 .15264 L
.72 .1532 L
.724 .15382 L
.728 .1545 L
.732 .15521 L
.736 .15601 L
.74 .15694 L
.744 .15805 L
.748 .15937 L
.752 .1609 L
.756 .16262 L
.76 .16452 L
.764 .1666 L
.768 .16886 L
.772 .17133 L
.776 .174 L
.78 .17681 L
.784 .17967 L
.788 .18241 L
.792 .18489 L
.796 .18705 L
.8 .18889 L
Mistroke
.804 .19052 L
.808 .19207 L
.812 .19363 L
.816 .19522 L
.82 .19683 L
.824 .19842 L
.828 .20002 L
.832 .20175 L
.836 .20375 L
.84 .20611 L
.844 .20883 L
.848 .21176 L
.852 .21468 L
.856 .21736 L
.86 .21966 L
.864 .22161 L
.868 .22331 L
.872 .22498 L
.876 .22672 L
.88 .2286 L
.884 .23053 L
.888 .2324 L
.892 .23409 L
.896 .23553 L
.9 .23672 L
.904 .2377 L
.908 .23853 L
.912 .23924 L
.916 .23986 L
.92 .24039 L
.924 .24083 L
.928 .24123 L
.932 .24163 L
.936 .24206 L
.94 .24257 L
.944 .24315 L
.948 .24387 L
.952 .24476 L
.956 .24592 L
.96 .24746 L
.964 .24947 L
.968 .25196 L
.972 .25487 L
.976 .25795 L
.98 .261 L
.984 .26369 L
.988 .26588 L
.992 .26752 L
.996 .26866 L
1 .26966 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16231 L
.012 .16116 L
.016 .1608 L
.02 .16127 L
.024 .16133 L
.028 .16118 L
.032 .16114 L
.036 .16123 L
.04 .16123 L
.044 .16122 L
.048 .16119 L
.052 .1612 L
.056 .16119 L
.06 .1612 L
.064 .1612 L
.068 .16122 L
.072 .16121 L
.076 .16121 L
.08 .16119 L
.084 .16119 L
.088 .16119 L
.092 .1612 L
.096 .1612 L
.1 .16121 L
.104 .16121 L
.108 .1612 L
.112 .16119 L
.116 .16119 L
.12 .16118 L
.124 .1612 L
.128 .1612 L
.132 .16121 L
.136 .1612 L
.14 .1612 L
.144 .16119 L
.148 .16118 L
.152 .16118 L
.156 .16119 L
.16 .1612 L
.164 .16121 L
.168 .1612 L
.172 .16119 L
.176 .16118 L
.18 .16118 L
.184 .16118 L
.188 .16119 L
.192 .1612 L
.196 .1612 L
.2 .1612 L
Mistroke
.204 .16119 L
.208 .16118 L
.212 .16118 L
.216 .16118 L
.22 .16119 L
.224 .16119 L
.228 .16119 L
.232 .16119 L
.236 .16119 L
.24 .16118 L
.244 .16118 L
.248 .16119 L
.252 .16119 L
.256 .16118 L
.26 .16118 L
.264 .16118 L
.268 .16118 L
.272 .16119 L
.276 .16119 L
.28 .16118 L
.284 .16118 L
.288 .16118 L
.292 .16118 L
.296 .16118 L
.3 .16117 L
.304 .16117 L
.308 .16118 L
.312 .16118 L
.316 .16119 L
.32 .16119 L
.324 .16119 L
.328 .16118 L
.332 .16117 L
.336 .16116 L
.34 .16116 L
.344 .16117 L
.348 .16118 L
.352 .16119 L
.356 .16119 L
.36 .16118 L
.364 .16117 L
.368 .16117 L
.372 .16116 L
.376 .16115 L
.38 .16115 L
.384 .16116 L
.388 .16118 L
.392 .1612 L
.396 .1612 L
.4 .16119 L
Mistroke
.404 .16117 L
.408 .16116 L
.412 .16115 L
.416 .16114 L
.42 .16114 L
.424 .16115 L
.428 .16118 L
.432 .1612 L
.436 .16121 L
.44 .1612 L
.444 .16118 L
.448 .16116 L
.452 .16114 L
.456 .16112 L
.46 .16111 L
.464 .16112 L
.468 .16115 L
.472 .1612 L
.476 .16124 L
.48 .16125 L
.484 .16122 L
.488 .16117 L
.492 .16112 L
.496 .1611 L
.5 .16108 L
.504 .16108 L
.508 .1611 L
.512 .16115 L
.516 .16122 L
.52 .16129 L
.524 .1613 L
.528 .16125 L
.532 .16116 L
.536 .16107 L
.54 .16103 L
.544 .16103 L
.548 .16105 L
.552 .16108 L
.556 .16113 L
.56 .16122 L
.564 .16132 L
.568 .16137 L
.572 .16133 L
.576 .16121 L
.58 .16106 L
.584 .16097 L
.588 .16096 L
.592 .161 L
.596 .16106 L
.6 .1611 L
Mistroke
.604 .16116 L
.608 .16125 L
.612 .16136 L
.616 .16142 L
.62 .16137 L
.624 .16122 L
.628 .16104 L
.632 .16092 L
.636 .16091 L
.64 .16097 L
.644 .16105 L
.648 .16109 L
.652 .1611 L
.656 .16113 L
.66 .16122 L
.664 .16133 L
.668 .16139 L
.672 .16134 L
.676 .16118 L
.68 .16098 L
.684 .16082 L
.688 .16074 L
.692 .1607 L
.696 .16063 L
.7 .16048 L
.704 .16024 L
.708 .15997 L
.712 .15971 L
.716 .15945 L
.72 .15914 L
.724 .15868 L
.728 .158 L
.732 .15704 L
.736 .15581 L
.74 .15434 L
.744 .15266 L
.748 .15078 L
.752 .14867 L
.756 .14633 L
.76 .14375 L
.764 .14097 L
.768 .13807 L
.772 .13515 L
.776 .1323 L
.78 .12955 L
.784 .12688 L
.788 .12421 L
.792 .12146 L
.796 .11859 L
.8 .11566 L
Mistroke
.804 .11281 L
.808 .11015 L
.812 .10772 L
.816 .10545 L
.82 .10319 L
.824 .1008 L
.828 .09822 L
.832 .09551 L
.836 .09282 L
.84 .09031 L
.844 .08803 L
.848 .08591 L
.852 .08379 L
.856 .08148 L
.86 .07893 L
.864 .07619 L
.868 .07342 L
.872 .0708 L
.876 .06843 L
.88 .06625 L
.884 .06413 L
.888 .06188 L
.892 .0594 L
.896 .05666 L
.9 .05383 L
.904 .05109 L
.908 .04865 L
.912 .04665 L
.916 .04511 L
.92 .044 L
.924 .04321 L
.928 .04261 L
.932 .0421 L
.936 .04159 L
.94 .04105 L
.944 .04046 L
.948 .03987 L
.952 .03939 L
.956 .03913 L
.96 .03923 L
.964 .03978 L
.968 .04076 L
.972 .04211 L
.976 .04357 L
.98 .045 L
.984 .04613 L
.988 .04695 L
.992 .04748 L
.996 .04781 L
1 .04829 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000Woo0`0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00002000017oo001oogoo0P0000=oo`00
Ool00goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`02Ool00`00Oomoo`0300000goo00000002Ool01000Ool000001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo
0P000Woo00<007oo00000P0000=oo`00Ool00P001Woo00<007ooOol017oo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;Ool4
0003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000
Oomoogoo10000goo00@007ooOol0009oo`05001oogooOol00002Ool00`00Oomoo`0400000goo0000
000200000goo001oo`02Ool00`00Ool000030003Ool01000Oomoo`001Goo000;Ool2000:Ool20004
Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0
009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D007ooOomoo`00
009oo`04001oogoo0002Ool02000Ool00000Ool007oo0003Ool00`00Ool00006Ool01000Oomoo`00
1Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo
1@000goo0P0017oo0`0017oo0P0017oo0P000Woo00<007ooOol00`000Woo1@000goo0P001Woo000R
Ool00`00Oomoo`14Ool2000?Ool00`00Oomoo`03Ool00`00Ool0000>Ool0029oo`8004Eoo`03001o
ogoo00ioo`8000Aoo`03001oo`0000ioo`008WooH`0037oo000ROolG00000goo0000000400000goo
00000002Ool20002Ool300001Goo00000000Ool00`0000Eoo`00000007oo00<00003Ool000000080
0003Ool0000000D000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00T007ooOomoo`00
Ool007oo000037oo000ROol2000?Ool01000Oomoo`000Woo0P0000Aoo`00001oo`<00003Ool00000
009oo`<00005Ool00000001oo`03000017oo000000000Woo0`0000Ioo`00001oo`00Ool200000goo
001oo`0FOol40002Ool00`00Oomoo`0<Ool0029oo`03001oogoo05Uoo`8000=oo`03001oogoo00]o
o`008Woo0P00Ggoo0P0037oo000ROol2001]Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2
001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/
Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool0
1000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`80
00Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03
Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001o
ogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04
001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00
Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yo
o`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol002QoodH002=oo`00:7oo00<007ooOol0@Woo0`008Goo000;
Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`14Ool2000POol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00Agoo0`00
7Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomo
o`00BGoo10006goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool5
0003Ool20003Ool30003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol010000goo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0
009oo`05001oogooOol00004Ool01000Oomoo`000Woo00<007ooOol00`000Woo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007oo
Ool03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002
Ool01000Oomoo`000Woo00<007ooOol01P0017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo
00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`000goo1P000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<0
07ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo
00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool2
0008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P00
17oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomo
o`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool2
0004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo06Ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P00
17oo0P000Woo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool0
0`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomo
o`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool0
0`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`00
1goo10000goo00<007ooOol0Fgoo2@003Woo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00
Fgoo0P0027oo0P0037oo000;Ool20008Ool50002Ool00`00Oomoo`1HOol2000HOol001aoo`03001o
ogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=o
o`8000Aoo`@000=oo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04
001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol0
0003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool40005
Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011o
o`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomo
o`00Ool00P000Woo00<007ooOol017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=o
o`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05
001oogooOol00002Ool40002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002
Ool00`00Ool0000200001Goo001oogoo000017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`00
1Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0
009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`@0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001ao
o`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool2
0006Ool30002Ool40004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo04aoo`80
02Aoo`0077oo00<007ooOol0BWoo0P009Woo000LOomY000<Ool001aoo`05001oogooOol00003Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol000]oo`80
00Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04
001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<0
07ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=o
o`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol0
01Ioo`8000Aoo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001o
ogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo
001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo
00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo
00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(19372\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31946 m
.008 .31861 L
.012 .31792 L
.016 .31768 L
.02 .31805 L
.024 .31835 L
.028 .31847 L
.032 .31858 L
.036 .31863 L
.04 .31852 L
.044 .31824 L
.048 .31805 L
.052 .31811 L
.056 .3183 L
.06 .31856 L
.064 .31875 L
.068 .31872 L
.072 .31854 L
.076 .31828 L
.08 .31811 L
.084 .31817 L
.088 .3184 L
.092 .31869 L
.096 .31889 L
.1 .31883 L
.104 .3186 L
.108 .3183 L
.112 .31813 L
.116 .31823 L
.12 .3185 L
.124 .31881 L
.128 .319 L
.132 .31895 L
.136 .31869 L
.14 .31836 L
.144 .31818 L
.148 .31826 L
.152 .31854 L
.156 .31887 L
.16 .3191 L
.164 .31912 L
.168 .3189 L
.172 .31852 L
.176 .3182 L
.18 .31816 L
.184 .31844 L
.188 .31889 L
.192 .31927 L
.196 .3194 L
.2 .3192 L
Mistroke
.204 .31872 L
.208 .31818 L
.212 .31795 L
.216 .31824 L
.22 .31891 L
.224 .31954 L
.228 .31975 L
.232 .31946 L
.236 .31884 L
.24 .3182 L
.244 .3179 L
.248 .31813 L
.252 .31884 L
.256 .31961 L
.26 .31994 L
.264 .31966 L
.268 .31902 L
.272 .31843 L
.276 .31816 L
.28 .31823 L
.284 .31861 L
.288 .31918 L
.292 .31971 L
.296 .31988 L
.3 .31958 L
.304 .319 L
.308 .31851 L
.312 .31832 L
.316 .31842 L
.32 .31873 L
.324 .31921 L
.328 .31973 L
.332 .32 L
.336 .31977 L
.34 .31912 L
.344 .3185 L
.348 .31833 L
.352 .31861 L
.356 .31905 L
.36 .31937 L
.364 .31955 L
.368 .31966 L
.372 .31967 L
.376 .31947 L
.38 .31909 L
.384 .31878 L
.388 .31874 L
.392 .31896 L
.396 .3192 L
.4 .31931 L
Mistroke
.404 .31938 L
.408 .31954 L
.412 .31975 L
.416 .31979 L
.42 .31953 L
.424 .31912 L
.428 .31884 L
.432 .31886 L
.436 .31905 L
.44 .3192 L
.444 .31928 L
.448 .31946 L
.452 .31986 L
.456 .32031 L
.46 .32036 L
.464 .31981 L
.468 .31889 L
.472 .31824 L
.476 .31827 L
.48 .31886 L
.484 .31953 L
.488 .31992 L
.492 .32013 L
.496 .32044 L
.5 .32078 L
.504 .32066 L
.508 .3197 L
.512 .31823 L
.516 .31725 L
.52 .31758 L
.524 .31904 L
.528 .32057 L
.532 .32119 L
.536 .3209 L
.54 .32049 L
.544 .32052 L
.548 .32059 L
.552 .31986 L
.556 .31817 L
.56 .31662 L
.564 .31669 L
.568 .31873 L
.572 .32141 L
.576 .32279 L
.58 .32209 L
.584 .32038 L
.588 .31936 L
.592 .31969 L
.596 .32032 L
.6 .31975 L
Mistroke
.604 .31783 L
.608 .3162 L
.612 .31676 L
.616 .31969 L
.62 .32298 L
.624 .3241 L
.628 .32227 L
.632 .31916 L
.636 .31738 L
.64 .31805 L
.644 .31985 L
.648 .3204 L
.652 .31855 L
.656 .3156 L
.66 .31404 L
.664 .31519 L
.668 .31782 L
.672 .31909 L
.676 .31692 L
.68 .31173 L
.684 .30604 L
.688 .30222 L
.692 .30056 L
.696 .29906 L
.7 .29519 L
.704 .28795 L
.708 .27862 L
.712 .26953 L
.716 .26228 L
.72 .25657 L
.724 .25075 L
.728 .24332 L
.732 .23424 L
.736 .22496 L
.74 .2175 L
.744 .21316 L
.748 .21203 L
.752 .21323 L
.756 .21565 L
.76 .21853 L
.764 .22166 L
.768 .22524 L
.772 .22965 L
.776 .23519 L
.78 .24177 L
.784 .24855 L
.788 .25391 L
.792 .25592 L
.796 .25339 L
.8 .24677 L
Mistroke
.804 .23842 L
.808 .23156 L
.812 .22866 L
.816 .22998 L
.82 .23344 L
.824 .23609 L
.828 .23613 L
.832 .23436 L
.836 .23371 L
.84 .23741 L
.844 .24643 L
.848 .25844 L
.852 .26878 L
.856 .27289 L
.86 .26947 L
.864 .26125 L
.868 .25417 L
.872 .2542 L
.876 .26413 L
.88 .28238 L
.884 .30325 L
.888 .32048 L
.892 .32954 L
.896 .33001 L
.9 .32512 L
.904 .3194 L
.908 .31695 L
.912 .31875 L
.916 .32353 L
.92 .32833 L
.924 .33028 L
.928 .32832 L
.932 .32271 L
.936 .31496 L
.94 .30712 L
.944 .30004 L
.948 .29533 L
.952 .29338 L
.956 .29498 L
.96 .30148 L
.964 .31127 L
.968 .32418 L
.972 .33559 L
.976 .34183 L
.98 .34041 L
.984 .32822 L
.988 .31027 L
.992 .28922 L
.996 .27281 L
1 .26721 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15032 m
.008 .15167 L
.012 .15205 L
.016 .15155 L
.02 .15141 L
.024 .15164 L
.028 .15165 L
.032 .1516 L
.036 .15158 L
.04 .15161 L
.044 .1516 L
.048 .15159 L
.052 .15158 L
.056 .15161 L
.06 .1516 L
.064 .15161 L
.068 .1516 L
.072 .1516 L
.076 .15159 L
.08 .15159 L
.084 .15159 L
.088 .15161 L
.092 .15161 L
.096 .15161 L
.1 .1516 L
.104 .1516 L
.108 .15159 L
.112 .15159 L
.116 .1516 L
.12 .15161 L
.124 .15161 L
.128 .15161 L
.132 .1516 L
.136 .15159 L
.14 .15159 L
.144 .15159 L
.148 .1516 L
.152 .15161 L
.156 .15161 L
.16 .15161 L
.164 .1516 L
.168 .15159 L
.172 .15159 L
.176 .15159 L
.18 .1516 L
.184 .15161 L
.188 .15161 L
.192 .15161 L
.196 .1516 L
.2 .1516 L
Mistroke
.204 .15159 L
.208 .1516 L
.212 .1516 L
.216 .15161 L
.22 .15161 L
.224 .15161 L
.228 .1516 L
.232 .1516 L
.236 .1516 L
.24 .1516 L
.244 .1516 L
.248 .1516 L
.252 .15161 L
.256 .15161 L
.26 .15161 L
.264 .15161 L
.268 .15161 L
.272 .15161 L
.276 .1516 L
.28 .1516 L
.284 .15161 L
.288 .15161 L
.292 .15161 L
.296 .15161 L
.3 .15161 L
.304 .15161 L
.308 .15161 L
.312 .15161 L
.316 .15161 L
.32 .1516 L
.324 .1516 L
.328 .1516 L
.332 .15161 L
.336 .15161 L
.34 .15162 L
.344 .15162 L
.348 .15162 L
.352 .15161 L
.356 .1516 L
.36 .1516 L
.364 .1516 L
.368 .15161 L
.372 .15162 L
.376 .15162 L
.38 .15162 L
.384 .15163 L
.388 .15162 L
.392 .15161 L
.396 .1516 L
.4 .15159 L
Mistroke
.404 .1516 L
.408 .15161 L
.412 .15163 L
.416 .15163 L
.42 .15163 L
.424 .15163 L
.428 .15163 L
.432 .15162 L
.436 .1516 L
.44 .15159 L
.444 .15159 L
.448 .1516 L
.452 .15162 L
.456 .15164 L
.46 .15165 L
.464 .15165 L
.468 .15164 L
.472 .15163 L
.476 .15161 L
.48 .15159 L
.484 .15157 L
.488 .15158 L
.492 .1516 L
.496 .15165 L
.5 .15168 L
.504 .15169 L
.508 .15167 L
.512 .15165 L
.516 .15162 L
.52 .15159 L
.524 .15156 L
.528 .15154 L
.532 .15156 L
.536 .15161 L
.54 .15168 L
.544 .15173 L
.548 .15174 L
.552 .15171 L
.556 .15165 L
.56 .1516 L
.564 .15156 L
.568 .15154 L
.572 .15153 L
.576 .15153 L
.58 .15158 L
.584 .15167 L
.588 .15177 L
.592 .15182 L
.596 .15178 L
.6 .15169 L
Mistroke
.604 .15159 L
.608 .15153 L
.612 .15151 L
.616 .15152 L
.62 .15153 L
.624 .15155 L
.628 .15161 L
.632 .15171 L
.636 .15183 L
.64 .1519 L
.644 .15188 L
.648 .15178 L
.652 .15167 L
.656 .15161 L
.66 .15165 L
.664 .15174 L
.668 .15185 L
.672 .15197 L
.676 .15211 L
.68 .15235 L
.684 .15268 L
.688 .1531 L
.692 .15354 L
.696 .15398 L
.7 .15445 L
.704 .15504 L
.708 .1558 L
.712 .15679 L
.716 .15799 L
.72 .15935 L
.724 .16087 L
.728 .16256 L
.732 .16445 L
.736 .16658 L
.74 .16894 L
.744 .17145 L
.748 .17404 L
.752 .17662 L
.756 .17912 L
.76 .18152 L
.764 .1838 L
.768 .18597 L
.772 .18802 L
.776 .18995 L
.78 .19174 L
.784 .19342 L
.788 .19502 L
.792 .19664 L
.796 .19837 L
.8 .20032 L
Mistroke
.804 .20251 L
.808 .2049 L
.812 .20737 L
.816 .2098 L
.82 .21208 L
.824 .2142 L
.828 .2162 L
.832 .21815 L
.836 .22009 L
.84 .22199 L
.844 .22378 L
.848 .22542 L
.852 .22693 L
.856 .22843 L
.86 .23007 L
.864 .23198 L
.868 .23417 L
.872 .23651 L
.876 .23876 L
.88 .24069 L
.884 .24215 L
.888 .24311 L
.892 .2437 L
.896 .24411 L
.9 .2445 L
.904 .24496 L
.908 .24547 L
.912 .24597 L
.916 .24637 L
.92 .24663 L
.924 .24678 L
.928 .24689 L
.932 .24705 L
.936 .24733 L
.94 .24778 L
.944 .2484 L
.948 .24917 L
.952 .25001 L
.956 .2509 L
.96 .25171 L
.964 .2524 L
.968 .25294 L
.972 .25332 L
.976 .25373 L
.98 .25427 L
.984 .25518 L
.988 .25666 L
.992 .25869 L
.996 .26133 L
1 .26421 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16296 L
.012 .16126 L
.016 .16061 L
.02 .16119 L
.024 .16139 L
.028 .16124 L
.032 .16114 L
.036 .16121 L
.04 .16121 L
.044 .16121 L
.048 .16118 L
.052 .16121 L
.056 .1612 L
.06 .16122 L
.064 .1612 L
.068 .16121 L
.072 .16119 L
.076 .1612 L
.08 .16119 L
.084 .1612 L
.088 .1612 L
.092 .16121 L
.096 .1612 L
.1 .1612 L
.104 .16119 L
.108 .16119 L
.112 .16119 L
.116 .1612 L
.12 .1612 L
.124 .16121 L
.128 .1612 L
.132 .1612 L
.136 .16119 L
.14 .16119 L
.144 .16119 L
.148 .1612 L
.152 .1612 L
.156 .1612 L
.16 .1612 L
.164 .16119 L
.168 .16119 L
.172 .16118 L
.176 .16118 L
.18 .16119 L
.184 .16119 L
.188 .1612 L
.192 .1612 L
.196 .16119 L
.2 .16118 L
Mistroke
.204 .16118 L
.208 .16118 L
.212 .16118 L
.216 .16119 L
.22 .1612 L
.224 .16119 L
.228 .16119 L
.232 .16118 L
.236 .16118 L
.24 .16118 L
.244 .16118 L
.248 .16119 L
.252 .16119 L
.256 .16119 L
.26 .16118 L
.264 .16118 L
.268 .16118 L
.272 .16118 L
.276 .16118 L
.28 .16118 L
.284 .16118 L
.288 .16117 L
.292 .16117 L
.296 .16118 L
.3 .16118 L
.304 .16118 L
.308 .16118 L
.312 .16118 L
.316 .16117 L
.32 .16117 L
.324 .16117 L
.328 .16117 L
.332 .16117 L
.336 .16118 L
.34 .16118 L
.344 .16118 L
.348 .16118 L
.352 .16118 L
.356 .16116 L
.36 .16115 L
.364 .16115 L
.368 .16116 L
.372 .16118 L
.376 .16118 L
.38 .16119 L
.384 .16118 L
.388 .16118 L
.392 .16116 L
.396 .16115 L
.4 .16114 L
Mistroke
.404 .16115 L
.408 .16116 L
.412 .16117 L
.416 .16118 L
.42 .16119 L
.424 .16119 L
.428 .16118 L
.432 .16116 L
.436 .16114 L
.44 .16113 L
.444 .16112 L
.448 .16114 L
.452 .16117 L
.456 .16119 L
.46 .1612 L
.464 .16119 L
.468 .16118 L
.472 .16117 L
.476 .16115 L
.48 .16112 L
.484 .16109 L
.488 .1611 L
.492 .16113 L
.496 .16119 L
.5 .16123 L
.504 .16123 L
.508 .16121 L
.512 .16118 L
.516 .16115 L
.52 .16111 L
.524 .16108 L
.528 .16105 L
.532 .16106 L
.536 .16112 L
.54 .16121 L
.544 .16128 L
.548 .1613 L
.552 .16125 L
.556 .16117 L
.56 .16111 L
.564 .16106 L
.568 .16104 L
.572 .16102 L
.576 .16102 L
.58 .16108 L
.584 .1612 L
.588 .16132 L
.592 .16137 L
.596 .16133 L
.6 .16121 L
Mistroke
.604 .16109 L
.608 .16101 L
.612 .16099 L
.616 .16099 L
.62 .161 L
.624 .16102 L
.628 .16108 L
.632 .1612 L
.636 .16133 L
.64 .1614 L
.644 .16133 L
.648 .16116 L
.652 .16096 L
.656 .16082 L
.66 .16075 L
.664 .16071 L
.668 .16064 L
.672 .16051 L
.676 .16034 L
.68 .16018 L
.684 .16001 L
.688 .15977 L
.692 .15938 L
.696 .15875 L
.7 .1579 L
.704 .15687 L
.708 .15572 L
.712 .15446 L
.716 .15302 L
.72 .15134 L
.724 .14937 L
.728 .14714 L
.732 .14471 L
.736 .14214 L
.74 .13947 L
.744 .1367 L
.748 .13381 L
.752 .13079 L
.756 .12767 L
.76 .12451 L
.764 .12141 L
.768 .11845 L
.772 .11565 L
.776 .11304 L
.78 .11057 L
.784 .10821 L
.788 .10592 L
.792 .10369 L
.796 .10155 L
.8 .0995 L
Mistroke
.804 .0975 L
.808 .09545 L
.812 .09321 L
.816 .09065 L
.82 .08776 L
.824 .08463 L
.828 .08142 L
.832 .07832 L
.836 .07545 L
.84 .0728 L
.844 .07027 L
.848 .06772 L
.852 .06512 L
.856 .06252 L
.86 .06007 L
.864 .05793 L
.868 .05616 L
.872 .05471 L
.876 .05343 L
.88 .05217 L
.884 .05085 L
.888 .0495 L
.892 .04826 L
.896 .04728 L
.9 .04661 L
.904 .04619 L
.908 .04586 L
.912 .04541 L
.916 .04467 L
.92 .04358 L
.924 .0422 L
.928 .04064 L
.932 .03903 L
.936 .03747 L
.94 .03599 L
.944 .03458 L
.948 .03325 L
.952 .03196 L
.956 .03079 L
.96 .02974 L
.964 .02888 L
.968 .02825 L
.972 .02779 L
.976 .0276 L
.98 .02763 L
.984 .02797 L
.988 .02869 L
.992 .02969 L
.996 .03111 L
1 .03264 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1P000Woo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`06001oogooOol007oo1@000Woo00@007ooOol0009oo`03001oogoo009oo`06
001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00Woo00@007ooOomoo`80009oo`@0009oo`03001oogoo00=oo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`8000=oo`04001o
o`000002Ool01000Oomoo`001Woo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;Ool40003Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo
00@007ooOol0009oo`<00004Ool007ooOol40002Ool01000Oomoo`000goo00H007ooOomoo`00Ool4
0003Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomo
o`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00
Oomoo`04Ool01000Oomoo`000Woo0P000Woo00@007ooOol0009oo`03001oogoo00@000=oo`07001o
ogooOol007oo00000Woo00D007ooOomoo`00009oo`03001oogoo00=oo`008Woo0P0037oo1@000goo
0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`80
00Aoo`<000Aoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol0@Woo00<007ooOol03Woo00<0
07ooOol027oo00<007ooOol02goo000ROol20012Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool20003
Ool00`00Oomoo`0;Ool0029oof<000aoo`008Woo7@0000=oo`000000100000Eoo`00000007oo00<0
009oo`80009oo`80009oo`8000=oo`800003Ool007oo00<000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00<007ooOol00`000Woo00D007oo001oo`0000aoo`008Woo0P004Goo00<007oo
Ool00P0000=oo`0000000Woo00<007ooOol00P0000Eoo`00000007oo00<0009oo`800003Ool00000
00800005Ool00000001oo`0600000goo001oo`0FOol50002Ool00`00Ool0000>Ool0029oo`03001o
ogoo05Aoo`04001oogoo0004Ool2000>Ool0029oo`8005eoo`8000ioo`008Woo0P00KGoo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P00
17oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo
0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo
06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]
Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2
001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06ao
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`00
00=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo
00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003
Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0
17oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004
Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001o
ogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOom3000VOol0
02Qoo`03001oogoo03moo`<002Aoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`00
0goo00<007ooOol0@Goo0`008Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`000goo00@007ooOol004Eoo`80025oo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOol004Moo`<001ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo
0P000goo0`000goo0`0017oo0P000Woo1@000goo10000Woo0P000goo1@000Woo0`0017oo0P001Woo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09
Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oo`0000800003Ool007oo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03
001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007oo
Ool0009oo`@000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yo
o`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`L000Ioo`04001oogoo0002Ool0
0`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`L000=oo`04001oogoo0005Ool002Qo
o`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@0
07ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`000goo00@007oo001oo`8000=oo`04001oogoo0005Ool002Qoo`03
001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003
Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03
001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo
06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo
001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001X
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Mo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0
IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0
IWoo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomo
o`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@00
0Woo00@007ooOol000]oo`03001oogoo008006=oo`03001oogoo00eoo`002Woo00@007ooOol000]o
o`04001oogoo001POol4000017oo0000000037oo000:Ool01000Oomoo`001goo10000goo00<007oo
Ool0FWoo1@004goo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00F7oo10005goo000;Ool2
0008Ool50002Ool00`00Oomoo`1EOol3000JOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<0
00Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000=oo`<000Eoo`D0009oo`<0
00Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<0
07ooOol00goo00@007ooOol0009oo`03001oogoo00@0009oo`03001oogoo00=oo`06001oogoo001o
o`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009o
o`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00800005Ool007oo
Ool00006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@
Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00@007ooOomoo`@0009oo`04
001oogoo0007Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool4
0003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000
Oomoogoo10000goo00@007ooOol000Aoo`06001oogooOol007oo0`0000Eoo`00Oomoo`00009oo`03
001oogoo009oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo
00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P00
0goo00<007ooOol017oo00@007ooOol000Aoo`04001oogooOol40002Ool01000Oomoo`000Woo00<0
07ooOol00Woo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2
000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo10000goo0P00
17oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`19Ool2000WOol001aoo`03001o
ogoo04Moo`<002Qoo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Ao
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009o
o`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02
Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@0
07ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Ioo`<000=oo`03001oogoo079oo`005goo
00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo
009oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000FOol20004Ool2001c
Ool001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00
Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`00
2Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001c
Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(19539\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31807 m
.008 .31812 L
.012 .31852 L
.016 .31836 L
.02 .31792 L
.024 .31796 L
.028 .31836 L
.032 .3186 L
.036 .31854 L
.04 .3184 L
.044 .31825 L
.048 .3181 L
.052 .31813 L
.056 .31833 L
.06 .31855 L
.064 .31869 L
.068 .3186 L
.072 .31836 L
.076 .31816 L
.08 .3181 L
.084 .31829 L
.088 .31859 L
.092 .3188 L
.096 .31881 L
.1 .31858 L
.104 .31825 L
.108 .31806 L
.112 .31816 L
.116 .31851 L
.12 .31889 L
.124 .31904 L
.128 .31888 L
.132 .31848 L
.136 .31811 L
.14 .31801 L
.144 .31829 L
.148 .31878 L
.152 .31919 L
.156 .31921 L
.16 .31886 L
.164 .31836 L
.168 .31803 L
.172 .31808 L
.176 .31847 L
.18 .31899 L
.184 .31935 L
.188 .3193 L
.192 .31888 L
.196 .31837 L
.2 .31809 L
Mistroke
.204 .31818 L
.208 .31855 L
.212 .31901 L
.216 .31935 L
.22 .31942 L
.224 .31914 L
.228 .31863 L
.232 .31821 L
.236 .31812 L
.24 .31841 L
.244 .31889 L
.248 .31936 L
.252 .31963 L
.256 .31953 L
.26 .31903 L
.264 .31837 L
.268 .31795 L
.272 .31811 L
.276 .31875 L
.28 .31947 L
.284 .31985 L
.288 .31976 L
.292 .31929 L
.296 .31866 L
.3 .31814 L
.304 .31805 L
.308 .31849 L
.312 .31923 L
.316 .31981 L
.32 .3199 L
.324 .31954 L
.328 .31906 L
.332 .31867 L
.336 .31844 L
.34 .3184 L
.344 .31864 L
.348 .31917 L
.352 .31975 L
.356 .31998 L
.36 .31972 L
.364 .31918 L
.368 .31873 L
.372 .31857 L
.376 .31865 L
.38 .31885 L
.384 .31915 L
.388 .31954 L
.392 .31982 L
.396 .3198 L
.4 .31945 L
Mistroke
.404 .31905 L
.408 .31887 L
.412 .31895 L
.416 .31909 L
.42 .31912 L
.424 .31911 L
.428 .31926 L
.432 .31959 L
.436 .31988 L
.44 .31986 L
.444 .31953 L
.448 .31916 L
.452 .319 L
.456 .31906 L
.46 .31911 L
.464 .31904 L
.468 .31902 L
.472 .31932 L
.476 .31995 L
.48 .32051 L
.484 .32049 L
.488 .31981 L
.492 .31893 L
.496 .31844 L
.5 .31855 L
.504 .31894 L
.508 .31922 L
.512 .3194 L
.516 .31983 L
.52 .32063 L
.524 .32128 L
.528 .32103 L
.532 .31972 L
.536 .3181 L
.54 .31733 L
.544 .31792 L
.548 .31924 L
.552 .3202 L
.556 .32037 L
.56 .32028 L
.564 .32066 L
.568 .32138 L
.572 .32144 L
.576 .32006 L
.58 .31776 L
.584 .31623 L
.588 .3168 L
.592 .3191 L
.596 .32135 L
.6 .32191 L
Mistroke
.604 .32086 L
.608 .31967 L
.612 .31965 L
.616 .32045 L
.62 .32045 L
.624 .31852 L
.628 .31546 L
.632 .31345 L
.636 .31404 L
.64 .31648 L
.644 .31818 L
.648 .31693 L
.652 .31279 L
.656 .30788 L
.66 .30436 L
.664 .30233 L
.668 .29981 L
.672 .29462 L
.676 .28653 L
.68 .27755 L
.684 .27015 L
.688 .26506 L
.692 .26058 L
.696 .2541 L
.7 .2445 L
.704 .23318 L
.708 .22315 L
.712 .21671 L
.716 .21393 L
.72 .21302 L
.724 .21207 L
.728 .21076 L
.732 .21053 L
.736 .21326 L
.74 .21962 L
.744 .22836 L
.748 .2371 L
.752 .2437 L
.756 .24734 L
.76 .24853 L
.764 .24828 L
.768 .24732 L
.772 .24574 L
.776 .24321 L
.78 .23947 L
.784 .23466 L
.788 .22942 L
.792 .22489 L
.796 .22247 L
.8 .22353 L
Mistroke
.804 .22865 L
.808 .23713 L
.812 .24677 L
.816 .25467 L
.82 .25859 L
.824 .25826 L
.828 .25576 L
.832 .25433 L
.836 .25666 L
.84 .26311 L
.844 .27171 L
.848 .27953 L
.852 .28473 L
.856 .28815 L
.86 .29251 L
.864 .30089 L
.868 .31386 L
.872 .32873 L
.876 .34051 L
.88 .34433 L
.884 .33874 L
.888 .32625 L
.892 .31276 L
.896 .30424 L
.9 .30361 L
.904 .30965 L
.908 .31746 L
.912 .32141 L
.916 .31846 L
.92 .30905 L
.924 .29782 L
.928 .2902 L
.932 .29012 L
.936 .29885 L
.94 .31266 L
.944 .32752 L
.948 .33795 L
.952 .34108 L
.956 .33749 L
.96 .32786 L
.964 .31705 L
.968 .30681 L
.972 .29975 L
.976 .29779 L
.98 .29933 L
.984 .30614 L
.988 .31518 L
.992 .32532 L
.996 .33469 L
1 .33884 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14935 m
.008 .15194 L
.012 .15279 L
.016 .152 L
.02 .15167 L
.024 .15195 L
.028 .15204 L
.032 .15197 L
.036 .15192 L
.04 .15195 L
.044 .15196 L
.048 .15196 L
.052 .15195 L
.056 .15196 L
.06 .15195 L
.064 .15196 L
.068 .15195 L
.072 .15195 L
.076 .15195 L
.08 .15196 L
.084 .15196 L
.088 .15196 L
.092 .15196 L
.096 .15195 L
.1 .15195 L
.104 .15195 L
.108 .15195 L
.112 .15196 L
.116 .15196 L
.12 .15196 L
.124 .15196 L
.128 .15195 L
.132 .15195 L
.136 .15195 L
.14 .15195 L
.144 .15196 L
.148 .15196 L
.152 .15196 L
.156 .15196 L
.16 .15195 L
.164 .15195 L
.168 .15195 L
.172 .15195 L
.176 .15196 L
.18 .15197 L
.184 .15197 L
.188 .15196 L
.192 .15195 L
.196 .15195 L
.2 .15195 L
Mistroke
.204 .15196 L
.208 .15196 L
.212 .15197 L
.216 .15197 L
.22 .15196 L
.224 .15195 L
.228 .15195 L
.232 .15195 L
.236 .15196 L
.24 .15197 L
.244 .15197 L
.248 .15196 L
.252 .15196 L
.256 .15196 L
.26 .15196 L
.264 .15196 L
.268 .15196 L
.272 .15196 L
.276 .15196 L
.28 .15196 L
.284 .15196 L
.288 .15196 L
.292 .15197 L
.296 .15197 L
.3 .15196 L
.304 .15196 L
.308 .15196 L
.312 .15196 L
.316 .15196 L
.32 .15196 L
.324 .15197 L
.328 .15197 L
.332 .15197 L
.336 .15197 L
.34 .15197 L
.344 .15196 L
.348 .15196 L
.352 .15196 L
.356 .15196 L
.36 .15197 L
.364 .15198 L
.368 .15198 L
.372 .15198 L
.376 .15197 L
.38 .15196 L
.384 .15196 L
.388 .15196 L
.392 .15197 L
.396 .15197 L
.4 .15198 L
Mistroke
.404 .15198 L
.408 .15199 L
.412 .15198 L
.416 .15197 L
.42 .15196 L
.424 .15195 L
.428 .15196 L
.432 .15197 L
.436 .15198 L
.44 .15199 L
.444 .15199 L
.448 .152 L
.452 .15199 L
.456 .15198 L
.46 .15196 L
.464 .15195 L
.468 .15195 L
.472 .15196 L
.476 .15198 L
.48 .15199 L
.484 .152 L
.488 .15201 L
.492 .15201 L
.496 .152 L
.5 .15198 L
.504 .15194 L
.508 .15192 L
.512 .15193 L
.516 .15196 L
.52 .152 L
.524 .15203 L
.528 .15204 L
.532 .15203 L
.536 .15202 L
.54 .152 L
.544 .15196 L
.548 .15192 L
.552 .15189 L
.556 .1519 L
.56 .15195 L
.564 .15203 L
.568 .15208 L
.572 .15209 L
.576 .15207 L
.58 .15203 L
.584 .15199 L
.588 .15195 L
.592 .15191 L
.596 .15187 L
.6 .15187 L
Mistroke
.604 .15193 L
.608 .15204 L
.612 .15215 L
.616 .15221 L
.62 .1522 L
.624 .15214 L
.628 .15209 L
.632 .15209 L
.636 .15212 L
.64 .15216 L
.644 .15224 L
.648 .15238 L
.652 .15262 L
.656 .15296 L
.66 .15337 L
.664 .15379 L
.668 .1542 L
.672 .15464 L
.676 .15519 L
.68 .15592 L
.684 .15686 L
.688 .15799 L
.692 .15928 L
.696 .16075 L
.7 .16243 L
.704 .16435 L
.708 .1665 L
.712 .16882 L
.716 .17121 L
.72 .17361 L
.724 .176 L
.728 .1784 L
.732 .18081 L
.736 .18321 L
.74 .18554 L
.744 .18772 L
.748 .18974 L
.752 .1916 L
.756 .19339 L
.76 .19515 L
.764 .19695 L
.768 .1988 L
.772 .20069 L
.776 .20263 L
.78 .20461 L
.784 .20665 L
.788 .20876 L
.792 .21094 L
.796 .21317 L
.8 .2154 L
Mistroke
.804 .21755 L
.808 .21959 L
.812 .22149 L
.816 .22331 L
.82 .22513 L
.824 .22704 L
.828 .22909 L
.832 .23123 L
.836 .23338 L
.84 .23539 L
.844 .23718 L
.848 .23871 L
.852 .24 L
.856 .24112 L
.86 .24208 L
.864 .24286 L
.868 .2434 L
.872 .24368 L
.876 .24375 L
.88 .24377 L
.884 .24392 L
.888 .24439 L
.892 .24523 L
.896 .24638 L
.9 .24766 L
.904 .24887 L
.908 .24989 L
.912 .2507 L
.916 .25141 L
.92 .25214 L
.924 .253 L
.928 .25396 L
.932 .25496 L
.936 .25581 L
.94 .25637 L
.944 .25661 L
.948 .25652 L
.952 .25626 L
.956 .25599 L
.96 .25584 L
.964 .25595 L
.968 .25627 L
.972 .25686 L
.976 .25753 L
.98 .25825 L
.984 .25887 L
.988 .25931 L
.992 .25959 L
.996 .25968 L
1 .25971 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .1604 L
.012 .1613 L
.016 .16148 L
.02 .16117 L
.024 .16109 L
.028 .16125 L
.032 .16124 L
.036 .1612 L
.04 .16117 L
.044 .16121 L
.048 .1612 L
.052 .16121 L
.056 .1612 L
.06 .16122 L
.064 .1612 L
.068 .1612 L
.072 .16119 L
.076 .1612 L
.08 .1612 L
.084 .16121 L
.088 .16121 L
.092 .16121 L
.096 .16119 L
.1 .16119 L
.104 .16118 L
.108 .16119 L
.112 .1612 L
.116 .16121 L
.12 .16121 L
.124 .1612 L
.128 .16119 L
.132 .16118 L
.136 .16118 L
.14 .16119 L
.144 .1612 L
.148 .16121 L
.152 .1612 L
.156 .16119 L
.16 .16118 L
.164 .16118 L
.168 .16118 L
.172 .16119 L
.176 .1612 L
.18 .1612 L
.184 .16119 L
.188 .16119 L
.192 .16118 L
.196 .16118 L
.2 .16118 L
Mistroke
.204 .16119 L
.208 .16119 L
.212 .16119 L
.216 .16119 L
.22 .16119 L
.224 .16118 L
.228 .16118 L
.232 .16118 L
.236 .16118 L
.24 .16118 L
.244 .16119 L
.248 .16119 L
.252 .16119 L
.256 .16118 L
.26 .16118 L
.264 .16117 L
.268 .16117 L
.272 .16118 L
.276 .16118 L
.28 .16118 L
.284 .16118 L
.288 .16118 L
.292 .16117 L
.296 .16117 L
.3 .16118 L
.304 .16118 L
.308 .16118 L
.312 .16117 L
.316 .16117 L
.32 .16117 L
.324 .16117 L
.328 .16118 L
.332 .16118 L
.336 .16118 L
.34 .16117 L
.344 .16116 L
.348 .16116 L
.352 .16116 L
.356 .16117 L
.36 .16117 L
.364 .16118 L
.368 .16118 L
.372 .16118 L
.376 .16117 L
.38 .16116 L
.384 .16115 L
.388 .16115 L
.392 .16116 L
.396 .16116 L
.4 .16117 L
Mistroke
.404 .16118 L
.408 .16118 L
.412 .16118 L
.416 .16116 L
.42 .16114 L
.424 .16114 L
.428 .16114 L
.432 .16115 L
.436 .16116 L
.44 .16117 L
.444 .16118 L
.448 .16118 L
.452 .16118 L
.456 .16117 L
.46 .16114 L
.464 .16112 L
.468 .16112 L
.472 .16113 L
.476 .16116 L
.48 .16118 L
.484 .16119 L
.488 .16119 L
.492 .16119 L
.496 .16118 L
.5 .16115 L
.504 .16111 L
.508 .16108 L
.512 .16108 L
.516 .16112 L
.52 .16117 L
.524 .16121 L
.528 .16122 L
.532 .16121 L
.536 .1612 L
.54 .16117 L
.544 .16112 L
.548 .16107 L
.552 .16103 L
.556 .16104 L
.56 .1611 L
.564 .1612 L
.568 .16126 L
.572 .16128 L
.576 .16124 L
.58 .16119 L
.584 .16114 L
.588 .16109 L
.592 .16103 L
.596 .16098 L
.6 .16097 L
Mistroke
.604 .16103 L
.608 .16115 L
.612 .16127 L
.616 .16131 L
.62 .16125 L
.624 .16113 L
.628 .16099 L
.632 .16087 L
.636 .16077 L
.64 .16064 L
.644 .16047 L
.648 .16031 L
.652 .16018 L
.656 .16005 L
.66 .15985 L
.664 .15949 L
.668 .15889 L
.672 .15807 L
.676 .1571 L
.68 .15601 L
.684 .1548 L
.688 .15341 L
.692 .15178 L
.696 .1499 L
.7 .14782 L
.704 .14557 L
.708 .14317 L
.712 .14059 L
.716 .13777 L
.72 .13471 L
.724 .1315 L
.728 .12824 L
.732 .12507 L
.736 .12204 L
.74 .11916 L
.744 .11641 L
.748 .11377 L
.752 .11128 L
.756 .10896 L
.76 .10681 L
.764 .10481 L
.768 .10285 L
.772 .10083 L
.776 .09863 L
.78 .09621 L
.784 .09357 L
.788 .09074 L
.792 .08779 L
.796 .08481 L
.8 .08184 L
Mistroke
.804 .07891 L
.808 .07605 L
.812 .07329 L
.816 .07068 L
.82 .0683 L
.824 .06618 L
.828 .0643 L
.832 .06255 L
.836 .06078 L
.84 .05884 L
.844 .05669 L
.848 .05443 L
.852 .05222 L
.856 .05026 L
.86 .04867 L
.864 .04743 L
.868 .04643 L
.872 .04552 L
.876 .0446 L
.88 .0437 L
.884 .04291 L
.888 .04237 L
.892 .0421 L
.896 .04201 L
.9 .04194 L
.904 .04165 L
.908 .04102 L
.912 .04003 L
.916 .0388 L
.92 .0375 L
.924 .03629 L
.928 .03522 L
.932 .03432 L
.936 .0335 L
.94 .03267 L
.944 .03182 L
.948 .03088 L
.952 .02991 L
.956 .02888 L
.96 .02778 L
.964 .02663 L
.968 .02538 L
.972 .02416 L
.976 .02294 L
.98 .02191 L
.984 .02106 L
.988 .02043 L
.992 .02004 L
.996 .0198 L
1 .01974 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`03001oogoo00800003Ool00000009oo`@0009oo`04001oogoo0004Ool01P00
Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`08001o
ogoo001oo`00Ool0009oo`@0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011o
o`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Ool00003Ool50002Ool01000Oomoo`000Woo
00<007ooOol017oo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;Ool40003Ool01000Oomoo`001goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00D007ooOol0
07oo008000=oo`@0009oo`@0009oo`05001oogooOol00003Ool00`00Ool000030003Ool01000Oomo
o`001Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomo
o`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool00`00
Oomoo`040003Ool01000Oomoo`000Woo0P0000Eoo`00Oomoo`0000=oo`07001oogooOol007oo0000
1Woo00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P00
1Woo00@007ooOomoo`D000=oo`@0009oo`<000Aoo`8000=oo`<000Eoo`<0009oo`D000=oo`8000Io
o`008Woo00<007ooOol0?goo00<007ooOol03Woo0P006Woo000ROol20010Ool00`00Oomoo`0?Ool0
0`00Oomoo`03Ool20003Ool00`00Oomoo`0=Ool0029oof<000aoo`008Woo700000=oo`0000006@00
00Eoo`00000007oo00@00003Ool007oo009oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo
1P0000Qoo`00Ool007oo001oo`0037oo000ROol2000@Ool00`00Oomoo`02000017oo000007oo0P00
0Woo0P0000=oo`0000000Woo0P000Woo0P000Woo0`0000Eoo`00000007oo00<00003Ool000000080
01Moo`05001oo`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`0;Ool0029oo`03001oogoo059o
o`8000Eoo`8000=oo`8000aoo`008Woo0P00Dgoo0P001Woo00<007ooOol03goo000ROol2001]Ool0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:
Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009o
o`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<0
07ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=o
o`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<0
00=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomo
ogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomo
o`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00
Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qood00
02Uoo`00:7oo00<007ooOol0?Goo0`009Woo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003
Ool30003Ool00`00Oomoo`0oOol2000UOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0003Ool01000Oomoo`00@Woo0`008goo0003Ool50002Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool01000Oomoo`00A7oo0`008Goo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool2
0004Ool20003Ool30003Ool30004Ool20002Ool50002Ool30004Ool20003Ool50002Ool30004Ool2
0006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001o
ogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01@00
Oomoo`00Ool00`0000Eoo`00Oomoo`0000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03
001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00<007oo
Ool010000Woo00<007ooOol00Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`00
2goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo
00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`060003Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`00
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo00X000=oo`04001o
ogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol0
00Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@0
07ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<0
07ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`00
0goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`00
0goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003
Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006
Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo
06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0
06Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001W
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo
1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3
0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00HGoo1P0037oo000:Ool01000Oomo
o`002goo00@007ooOol005ioo`D0015oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo05Mo
o`H001Eoo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8005Eoo`@001Yoo`002goo0P0027oo
1@000Woo00<007ooOol0DWoo0`007Goo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool2
0004Ool20005Ool30003Ool30004Ool20005Ool50003Ool40002Ool20005Ool50002Ool30004Ool2
0006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo
00=oo`04001oogoo0002Ool40002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomo
o`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol017oo00<007ooOol00Woo0P0000Eoo`00Oomoo`00009oo`03001oogoo00Aoo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo
0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Ool000020002Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo
10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOomoo`@000=oo`04001oogoo0004Ool01000Oomoogoo0P0000Eoo`00Oomoo`00009oo`04001o
ogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03
001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=o
o`03001oogoo00Aoo`04001oogoo0004Ool00`00Ool000020002Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P00
2Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Ao
o`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0AWoo0`00:Goo000LOol00`00Oomo
o`14Ool3000[Ool001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool0
0`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo
0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo
079oo`002Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001o
ogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03
001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`02
Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo
000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
00Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomo
o`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007oo
Ool02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yo
o`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
0001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(19706\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31717 m
.008 .31799 L
.012 .31861 L
.016 .31871 L
.02 .31826 L
.024 .31807 L
.028 .31818 L
.032 .31825 L
.036 .31821 L
.04 .31823 L
.044 .31837 L
.048 .31844 L
.052 .31841 L
.056 .31836 L
.06 .31829 L
.064 .31825 L
.068 .31828 L
.072 .31833 L
.076 .31842 L
.08 .31849 L
.084 .31851 L
.088 .31848 L
.092 .3184 L
.096 .31833 L
.1 .31832 L
.104 .31836 L
.108 .31846 L
.112 .31859 L
.116 .31866 L
.12 .31865 L
.124 .31852 L
.128 .31837 L
.132 .31829 L
.136 .31834 L
.14 .31851 L
.144 .31874 L
.148 .31889 L
.152 .31886 L
.156 .31862 L
.16 .3183 L
.164 .31815 L
.168 .31829 L
.172 .31865 L
.176 .31903 L
.18 .31919 L
.184 .31903 L
.188 .3186 L
.192 .31815 L
.196 .31801 L
.2 .31831 L
Mistroke
.204 .31889 L
.208 .31937 L
.212 .31944 L
.216 .31907 L
.22 .31852 L
.224 .31808 L
.228 .31802 L
.232 .3184 L
.236 .31903 L
.24 .31953 L
.244 .31958 L
.248 .31917 L
.252 .31859 L
.256 .31819 L
.26 .31815 L
.264 .31842 L
.268 .3189 L
.272 .31941 L
.276 .31968 L
.28 .31953 L
.284 .319 L
.288 .31841 L
.292 .31811 L
.296 .31825 L
.3 .31871 L
.304 .31927 L
.308 .31973 L
.312 .31986 L
.316 .31951 L
.32 .31881 L
.324 .31817 L
.328 .31803 L
.332 .31848 L
.336 .31919 L
.34 .31971 L
.344 .31985 L
.348 .31966 L
.352 .31928 L
.356 .3188 L
.36 .3184 L
.364 .31831 L
.368 .31865 L
.372 .31926 L
.376 .31974 L
.38 .31985 L
.384 .31963 L
.388 .3193 L
.392 .31901 L
.396 .31876 L
.4 .3186 L
Mistroke
.404 .31868 L
.408 .31907 L
.412 .31958 L
.416 .31988 L
.42 .31977 L
.424 .31942 L
.428 .31913 L
.432 .31907 L
.436 .31913 L
.44 .3191 L
.444 .31898 L
.448 .31899 L
.452 .31927 L
.456 .31967 L
.46 .3199 L
.464 .3198 L
.468 .31951 L
.472 .3193 L
.476 .31927 L
.48 .31926 L
.484 .31907 L
.488 .31881 L
.492 .3188 L
.496 .31931 L
.5 .32009 L
.504 .3206 L
.508 .32043 L
.512 .31974 L
.516 .31909 L
.52 .31885 L
.524 .31891 L
.528 .31889 L
.532 .31874 L
.536 .31889 L
.54 .31971 L
.544 .32093 L
.548 .32164 L
.552 .32109 L
.556 .31954 L
.56 .31808 L
.564 .31771 L
.568 .31837 L
.572 .31916 L
.576 .31934 L
.58 .31916 L
.584 .31945 L
.588 .32051 L
.592 .32143 L
.596 .32086 L
.6 .31843 L
Mistroke
.604 .31538 L
.608 .31357 L
.612 .31374 L
.616 .31479 L
.62 .31478 L
.624 .31273 L
.628 .30944 L
.632 .30643 L
.636 .30415 L
.64 .3013 L
.644 .29605 L
.648 .28796 L
.652 .27873 L
.656 .2708 L
.66 .26516 L
.664 .26044 L
.668 .25417 L
.672 .24509 L
.676 .23447 L
.68 .22502 L
.684 .21866 L
.688 .21501 L
.692 .21214 L
.696 .20868 L
.7 .20543 L
.704 .20482 L
.708 .20882 L
.712 .21701 L
.716 .22665 L
.72 .23458 L
.724 .23933 L
.728 .24179 L
.732 .24387 L
.736 .24652 L
.74 .24879 L
.744 .24866 L
.748 .24478 L
.752 .2378 L
.756 .23012 L
.76 .22444 L
.764 .22226 L
.768 .22338 L
.772 .22652 L
.776 .23042 L
.78 .23453 L
.784 .23896 L
.788 .24395 L
.792 .24937 L
.796 .25465 L
.8 .25901 L
Mistroke
.804 .26186 L
.808 .26297 L
.812 .26287 L
.816 .26275 L
.82 .26449 L
.824 .27001 L
.828 .28027 L
.832 .29451 L
.836 .30988 L
.84 .32268 L
.844 .32991 L
.848 .3309 L
.852 .32781 L
.856 .32409 L
.86 .32268 L
.864 .32394 L
.868 .32567 L
.872 .32466 L
.876 .31891 L
.88 .30947 L
.884 .29988 L
.888 .29431 L
.892 .2952 L
.896 .30138 L
.9 .30932 L
.904 .31476 L
.908 .31539 L
.912 .31266 L
.916 .30952 L
.92 .31008 L
.924 .31537 L
.928 .32327 L
.932 .33013 L
.936 .33087 L
.94 .32493 L
.944 .31367 L
.948 .30188 L
.952 .29536 L
.956 .29587 L
.96 .30442 L
.964 .31656 L
.968 .32794 L
.972 .33549 L
.976 .33658 L
.98 .33356 L
.984 .32785 L
.988 .32184 L
.992 .31733 L
.996 .31372 L
1 .31145 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15309 m
.008 .15226 L
.012 .15199 L
.016 .15239 L
.02 .15242 L
.024 .15229 L
.028 .15226 L
.032 .15233 L
.036 .15231 L
.04 .15231 L
.044 .1523 L
.048 .15233 L
.052 .15231 L
.056 .15232 L
.06 .1523 L
.064 .15231 L
.068 .1523 L
.072 .15231 L
.076 .15231 L
.08 .15232 L
.084 .15231 L
.088 .15231 L
.092 .1523 L
.096 .15231 L
.1 .1523 L
.104 .15232 L
.108 .15232 L
.112 .15232 L
.116 .15231 L
.12 .15231 L
.124 .1523 L
.128 .15231 L
.132 .15231 L
.136 .15232 L
.14 .15232 L
.144 .15232 L
.148 .15231 L
.152 .15231 L
.156 .1523 L
.16 .15231 L
.164 .15231 L
.168 .15232 L
.172 .15232 L
.176 .15232 L
.18 .15231 L
.184 .15231 L
.188 .15231 L
.192 .15231 L
.196 .15231 L
.2 .15232 L
Mistroke
.204 .15232 L
.208 .15232 L
.212 .15232 L
.216 .15231 L
.22 .15231 L
.224 .15231 L
.228 .15231 L
.232 .15232 L
.236 .15232 L
.24 .15232 L
.244 .15232 L
.248 .15232 L
.252 .15231 L
.256 .15231 L
.26 .15231 L
.264 .15232 L
.268 .15232 L
.272 .15232 L
.276 .15232 L
.28 .15232 L
.284 .15231 L
.288 .15232 L
.292 .15232 L
.296 .15232 L
.3 .15232 L
.304 .15232 L
.308 .15232 L
.312 .15232 L
.316 .15232 L
.32 .15232 L
.324 .15232 L
.328 .15232 L
.332 .15232 L
.336 .15232 L
.34 .15232 L
.344 .15232 L
.348 .15233 L
.352 .15233 L
.356 .15233 L
.36 .15233 L
.364 .15232 L
.368 .15232 L
.372 .15232 L
.376 .15232 L
.38 .15232 L
.384 .15232 L
.388 .15233 L
.392 .15234 L
.396 .15234 L
.4 .15233 L
Mistroke
.404 .15232 L
.408 .15232 L
.412 .15232 L
.416 .15232 L
.42 .15232 L
.424 .15233 L
.428 .15234 L
.432 .15235 L
.436 .15234 L
.44 .15233 L
.444 .15232 L
.448 .15231 L
.452 .15232 L
.456 .15232 L
.46 .15233 L
.464 .15234 L
.468 .15235 L
.472 .15236 L
.476 .15236 L
.48 .15234 L
.484 .15232 L
.488 .15231 L
.492 .15231 L
.496 .15232 L
.5 .15233 L
.504 .15234 L
.508 .15236 L
.512 .15237 L
.516 .15238 L
.52 .15237 L
.524 .15234 L
.528 .1523 L
.532 .15228 L
.536 .15229 L
.54 .15231 L
.544 .15235 L
.548 .15237 L
.552 .15239 L
.556 .1524 L
.56 .1524 L
.564 .15238 L
.568 .15234 L
.572 .15228 L
.576 .15225 L
.58 .15227 L
.584 .15233 L
.588 .15241 L
.592 .15247 L
.596 .15251 L
.6 .15253 L
Mistroke
.604 .15256 L
.608 .15258 L
.612 .15261 L
.616 .15263 L
.62 .1527 L
.624 .15285 L
.628 .15312 L
.632 .15349 L
.636 .15393 L
.64 .15439 L
.644 .15489 L
.648 .15547 L
.652 .15618 L
.656 .15705 L
.66 .15807 L
.664 .15926 L
.668 .16063 L
.672 .16224 L
.676 .16411 L
.68 .16622 L
.684 .16849 L
.688 .17083 L
.692 .1732 L
.696 .17557 L
.7 .17798 L
.704 .18042 L
.708 .18283 L
.712 .18517 L
.716 .18737 L
.72 .18944 L
.724 .19142 L
.728 .19335 L
.732 .19524 L
.736 .19707 L
.74 .19883 L
.744 .20054 L
.748 .20227 L
.752 .20409 L
.756 .20606 L
.76 .20819 L
.764 .21042 L
.768 .21268 L
.772 .21493 L
.776 .21713 L
.78 .21928 L
.784 .2214 L
.788 .22348 L
.792 .2255 L
.796 .22746 L
.8 .22933 L
Mistroke
.804 .23112 L
.808 .23286 L
.812 .23456 L
.816 .23623 L
.82 .23786 L
.824 .23937 L
.828 .2407 L
.832 .24176 L
.836 .24256 L
.84 .24313 L
.844 .24359 L
.848 .24408 L
.852 .24468 L
.856 .2454 L
.86 .24618 L
.864 .24693 L
.868 .24759 L
.872 .24814 L
.876 .24867 L
.88 .24925 L
.884 .24992 L
.888 .25067 L
.892 .25141 L
.896 .25206 L
.9 .25259 L
.904 .25305 L
.908 .25354 L
.912 .25415 L
.916 .25492 L
.92 .25581 L
.924 .25669 L
.928 .25746 L
.932 .25808 L
.936 .25857 L
.94 .25907 L
.944 .25965 L
.948 .26042 L
.952 .26128 L
.956 .26214 L
.96 .26284 L
.964 .26322 L
.968 .26327 L
.972 .26299 L
.976 .26251 L
.98 .26194 L
.984 .26137 L
.988 .26089 L
.992 .26048 L
.996 .26018 L
1 .25993 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15928 L
.012 .16119 L
.016 .16182 L
.02 .16124 L
.024 .16099 L
.028 .1612 L
.032 .16126 L
.036 .16122 L
.04 .16117 L
.044 .16121 L
.048 .16121 L
.052 .16121 L
.056 .16119 L
.06 .1612 L
.064 .16119 L
.068 .1612 L
.072 .1612 L
.076 .16121 L
.08 .1612 L
.084 .16121 L
.088 .1612 L
.092 .1612 L
.096 .16119 L
.1 .1612 L
.104 .16119 L
.108 .1612 L
.112 .1612 L
.116 .1612 L
.12 .16119 L
.124 .16119 L
.128 .16118 L
.132 .16119 L
.136 .16119 L
.14 .1612 L
.144 .1612 L
.148 .1612 L
.152 .16119 L
.156 .16118 L
.16 .16118 L
.164 .16119 L
.168 .16119 L
.172 .1612 L
.176 .1612 L
.18 .16119 L
.184 .16118 L
.188 .16117 L
.192 .16117 L
.196 .16118 L
.2 .16119 L
Mistroke
.204 .1612 L
.208 .16119 L
.212 .16118 L
.216 .16117 L
.22 .16117 L
.224 .16117 L
.228 .16118 L
.232 .16119 L
.236 .16119 L
.24 .16119 L
.244 .16118 L
.248 .16117 L
.252 .16117 L
.256 .16118 L
.26 .16118 L
.264 .16118 L
.268 .16118 L
.272 .16118 L
.276 .16118 L
.28 .16118 L
.284 .16117 L
.288 .16117 L
.292 .16117 L
.296 .16117 L
.3 .16117 L
.304 .16117 L
.308 .16118 L
.312 .16117 L
.316 .16117 L
.32 .16117 L
.324 .16117 L
.328 .16117 L
.332 .16117 L
.336 .16117 L
.34 .16116 L
.344 .16116 L
.348 .16117 L
.352 .16117 L
.356 .16118 L
.36 .16117 L
.364 .16117 L
.368 .16116 L
.372 .16115 L
.376 .16115 L
.38 .16116 L
.384 .16117 L
.388 .16117 L
.392 .16118 L
.396 .16117 L
.4 .16116 L
Mistroke
.404 .16115 L
.408 .16115 L
.412 .16115 L
.416 .16115 L
.42 .16115 L
.424 .16116 L
.428 .16118 L
.432 .16118 L
.436 .16117 L
.44 .16116 L
.444 .16114 L
.448 .16113 L
.452 .16114 L
.456 .16114 L
.46 .16115 L
.464 .16116 L
.468 .16117 L
.472 .16118 L
.476 .16118 L
.48 .16116 L
.484 .16113 L
.488 .16112 L
.492 .16111 L
.496 .16112 L
.5 .16114 L
.504 .16116 L
.508 .16117 L
.512 .16119 L
.516 .1612 L
.52 .16118 L
.524 .16115 L
.528 .1611 L
.532 .16107 L
.536 .16108 L
.54 .16111 L
.544 .16115 L
.548 .16118 L
.552 .1612 L
.556 .16121 L
.56 .16121 L
.564 .16118 L
.568 .16112 L
.572 .16105 L
.576 .161 L
.58 .161 L
.584 .16106 L
.588 .16113 L
.592 .16116 L
.596 .16116 L
.6 .16111 L
Mistroke
.604 .16104 L
.608 .16094 L
.612 .16079 L
.616 .16058 L
.62 .16035 L
.624 .16013 L
.628 .15994 L
.632 .15974 L
.636 .15945 L
.64 .15898 L
.644 .15831 L
.648 .15745 L
.652 .15644 L
.656 .15525 L
.66 .15386 L
.664 .15224 L
.668 .15039 L
.672 .14837 L
.676 .14621 L
.68 .14391 L
.684 .1414 L
.688 .13863 L
.692 .13561 L
.696 .13243 L
.7 .1292 L
.704 .12603 L
.708 .12296 L
.712 .11999 L
.716 .11714 L
.72 .11445 L
.724 .11198 L
.728 .10973 L
.732 .10768 L
.736 .10569 L
.74 .10365 L
.744 .10146 L
.748 .09911 L
.752 .09663 L
.756 .09404 L
.76 .09135 L
.764 .08856 L
.768 .08566 L
.772 .08271 L
.776 .07977 L
.78 .07695 L
.784 .07433 L
.788 .07193 L
.792 .06972 L
.796 .06762 L
.8 .06553 L
Mistroke
.804 .06339 L
.808 .06117 L
.812 .05891 L
.816 .05664 L
.82 .05446 L
.824 .05241 L
.828 .05053 L
.832 .04884 L
.836 .04738 L
.84 .0462 L
.844 .04537 L
.848 .04491 L
.852 .04475 L
.856 .04475 L
.86 .04471 L
.864 .04443 L
.868 .04381 L
.872 .04288 L
.876 .04176 L
.88 .04059 L
.884 .03944 L
.888 .0383 L
.892 .03708 L
.896 .03567 L
.9 .0341 L
.904 .0325 L
.908 .03112 L
.912 .03018 L
.916 .02979 L
.92 .0299 L
.924 .03025 L
.928 .03056 L
.932 .03056 L
.936 .03012 L
.94 .02932 L
.944 .02826 L
.948 .02723 L
.952 .02629 L
.956 .02556 L
.96 .025 L
.964 .02452 L
.968 .02407 L
.972 .02355 L
.976 .02299 L
.98 .02241 L
.984 .02181 L
.988 .0213 L
.992 .02085 L
.996 .02055 L
1 .02037 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool20012Ool2000YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo
0P0000=oo`0000001@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol0
0002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00
Oomoogoo00000goo00@007ooOol0009oo`80009oo`03001oogoo00@0009oo`04001oogoo0002Ool0
0`00Oomoo`02Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001o
ogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@0
07ooOol0009oo`04001oogooOol20002Ool00`00Ool00002Ool01000Oomoo`000Woo00<007ooOol0
0goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00Woo0`000Woo0P0000Eoo`00Oomoo`00009oo`03001oogoo00Aoo`03001oogoo00Aoo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
00<007ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00@007ooOomoo`@000=oo`04001oo`000002Ool00`00Oomoo`020002Ool40002Ool0
1000Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:Ool20004
Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0
009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool40002Ool01@00Oomoogoo00000Woo00<0
07oo00000P0000Eoo`00Oomoo`0000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`00
8Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=o
o`8000Aoo`<000Aoo`800004Ool007ooOol20005Ool30002Ool50003Ool20006Ool0029oo`03001o
ogoo03aoo`80011oo`03001oogoo01]oo`008Woo0P00?Goo00<007ooOol03goo00<007ooOol00goo
00<007ooOol00goo00<007ooOol03goo000ROomS000<Ool0029oobD00005Ool00000001oo`030000
1Goo00000000Ool00`000Woo0`0000=oo`0000000P000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool00`00Oomoo`02000027oo00000000Ool007oo0002Ool2000<Ool0029oo`80019oo`80
009oo`04001oogoo0002Ool200000goo00000002Ool200000goo00000003Ool2000017oo00000000
0Woo0P0000Aoo`00000001Moo`@000Eoo`800004Ool007oo000>Ool0029oo`03001oogoo04moo`80
00Moo`04001oogooOol2000>Ool0029oo`8006eoo`008Woo0P00KGoo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol0
0Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`00
0goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomo
o`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007oo
Ool006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007oo
Ool007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`80
06eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3
001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo
06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00
Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1V
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0
IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03
Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo
0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOoln000[Ool002Qoo`03001oogoo
03Yoo`<002Uoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0
?7oo0P00:7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@0
07ooOol0041oo`8002Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOol0049oo`<002=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo
0`0017oo0P000Woo2P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo
00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomo
o`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol010000Woo00@007ooOol000=o
o`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04
001oogoo0002Ool01@00Oomoogoo000017oo00<007oo00000P0000Eoo`00Oomoo`0000Aoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009o
o`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000Woo1`001Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<0
07ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo
0002Ool800000goo000000020003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomo
o`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00
Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
009oo`L000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo
00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002
Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool0
02Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo
011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo
00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool20002Ool50002
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`00
4Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007oo
Oomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000
K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P00
2Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo
0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo0080061o
o`L000aoo`002Woo00@007ooOol000]oo`04001oogoo001KOol7000BOol000Yoo`04001oogoo0007
Ool40003Ool00`00Oomoo`1DOol6000HOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001C
Ool3000MOol000]oo`8000Qoo`D0009oo`03001oogoo051oo`80021oo`0077oo00<007ooOol03Goo
0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000Woo0`0017oo
0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol0
00Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool01@00Oomoo`00Ool00P000Woo00@007ooOol0009oo`03001o
ogoo00=oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007oo
Ool047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`06001oo`00001oo`00
0Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05
Ool20002Ool01000Oomoo`000Woo00@007ooOol000Moo`03001oogoo00Aoo`04001oogoo0002Ool0
0`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo0`0000Eoo`00Oomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`02Ool01P00Oomoogoo001oo`@000=oo`04001oogoo
0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomo
o`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0003Ool20003Ool01000
Oomoo`000Woo00@007ooOol0009oo`03001oogoo009oo`07001oogooOol007oo00001Woo00@007oo
Ool000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007oo
Oomoo`D000=oo`8000=oo`800004Ool000000004Ool20004Ool20006Ool30002Ool50003Ool20006
Ool001aoo`03001oogoo04=oo`<002aoo`0077oo00<007ooOol0@Woo0P00;Woo000LOomY000<Ool0
01aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo000;Ool0
0`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`00
1goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;
Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol0
01Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00
Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol00Woo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02Ool3
0003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]o
o`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`00
2goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00
Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol0
0`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(19873\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31821 m
.008 .31834 L
.012 .31805 L
.016 .31817 L
.02 .31851 L
.024 .31846 L
.028 .31813 L
.032 .31798 L
.036 .31807 L
.04 .31821 L
.044 .31836 L
.048 .31851 L
.052 .31849 L
.056 .31833 L
.06 .31814 L
.064 .31805 L
.068 .31816 L
.072 .31838 L
.076 .31857 L
.08 .31864 L
.084 .3185 L
.088 .31827 L
.092 .3181 L
.096 .31812 L
.1 .31835 L
.104 .31862 L
.108 .31875 L
.112 .31869 L
.116 .31845 L
.12 .3182 L
.124 .31813 L
.128 .31827 L
.132 .31856 L
.136 .31882 L
.14 .31886 L
.144 .31868 L
.148 .31841 L
.152 .31822 L
.156 .31823 L
.16 .31841 L
.164 .31869 L
.168 .31891 L
.172 .31894 L
.176 .31876 L
.18 .31848 L
.184 .31829 L
.188 .31828 L
.192 .31844 L
.196 .31873 L
.2 .31901 L
Mistroke
.204 .31913 L
.208 .31899 L
.212 .31862 L
.216 .31826 L
.22 .31815 L
.224 .31838 L
.228 .31881 L
.232 .31923 L
.236 .31941 L
.24 .31922 L
.244 .3187 L
.248 .31817 L
.252 .31798 L
.256 .31832 L
.26 .31897 L
.264 .31951 L
.268 .31963 L
.272 .31931 L
.276 .31875 L
.28 .31825 L
.284 .31805 L
.288 .3183 L
.292 .31891 L
.296 .31953 L
.3 .31977 L
.304 .31952 L
.308 .31898 L
.312 .31849 L
.316 .31824 L
.32 .31828 L
.324 .31863 L
.328 .3192 L
.332 .31974 L
.336 .31992 L
.34 .31955 L
.344 .31886 L
.348 .3183 L
.352 .31818 L
.356 .31849 L
.36 .31901 L
.364 .31952 L
.368 .31985 L
.372 .31986 L
.376 .31947 L
.38 .31885 L
.384 .31836 L
.388 .31832 L
.392 .31874 L
.396 .31927 L
.4 .31962 L
Mistroke
.404 .31972 L
.408 .31966 L
.412 .3195 L
.416 .3192 L
.42 .31881 L
.424 .31855 L
.428 .31866 L
.432 .31911 L
.436 .31959 L
.44 .31979 L
.444 .31967 L
.448 .31943 L
.452 .31931 L
.456 .3193 L
.46 .31922 L
.464 .31903 L
.468 .31888 L
.472 .31899 L
.476 .31934 L
.48 .3197 L
.484 .31981 L
.488 .31967 L
.492 .31952 L
.496 .31953 L
.5 .31958 L
.504 .3194 L
.508 .31895 L
.512 .31858 L
.516 .31871 L
.52 .31939 L
.524 .32017 L
.528 .32048 L
.532 .32018 L
.536 .31965 L
.54 .31933 L
.544 .31925 L
.548 .319 L
.552 .31839 L
.556 .31783 L
.56 .318 L
.564 .31904 L
.568 .32018 L
.572 .32029 L
.576 .31892 L
.58 .31676 L
.584 .31492 L
.588 .31385 L
.592 .31292 L
.596 .31119 L
.6 .30853 L
Mistroke
.604 .30572 L
.608 .30351 L
.612 .30144 L
.616 .29794 L
.62 .29174 L
.624 .28314 L
.628 .27395 L
.632 .26594 L
.636 .25923 L
.64 .25245 L
.644 .24427 L
.648 .23496 L
.652 .22628 L
.656 .21986 L
.66 .21566 L
.664 .21211 L
.668 .20794 L
.672 .20378 L
.676 .202 L
.68 .20473 L
.684 .21183 L
.688 .22081 L
.692 .22868 L
.696 .23414 L
.7 .23811 L
.704 .24219 L
.708 .24662 L
.712 .2496 L
.716 .2488 L
.72 .24348 L
.724 .23553 L
.728 .22828 L
.732 .22424 L
.736 .22353 L
.74 .22444 L
.744 .22523 L
.748 .22578 L
.752 .22763 L
.756 .23235 L
.76 .23997 L
.764 .24851 L
.768 .25524 L
.772 .2584 L
.776 .25833 L
.78 .25706 L
.784 .25695 L
.788 .25951 L
.792 .2649 L
.796 .27244 L
.8 .2813 L
Mistroke
.804 .29089 L
.808 .30088 L
.812 .31081 L
.816 .32002 L
.82 .32763 L
.824 .33271 L
.828 .33455 L
.832 .33269 L
.836 .32747 L
.84 .32006 L
.844 .31252 L
.848 .30717 L
.852 .30537 L
.856 .3068 L
.86 .30922 L
.864 .30972 L
.868 .30665 L
.872 .30079 L
.876 .29559 L
.88 .29518 L
.884 .3017 L
.888 .31405 L
.892 .32722 L
.896 .33565 L
.9 .33545 L
.904 .32677 L
.908 .31441 L
.912 .30376 L
.916 .29991 L
.92 .30332 L
.924 .31087 L
.928 .31835 L
.932 .32123 L
.936 .31966 L
.94 .31549 L
.944 .31241 L
.948 .31366 L
.952 .31842 L
.956 .32504 L
.96 .32948 L
.964 .32918 L
.968 .32445 L
.972 .31695 L
.976 .31062 L
.98 .30822 L
.984 .31077 L
.988 .31713 L
.992 .32504 L
.996 .33121 L
1 .3341 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15538 m
.008 .15269 L
.012 .15175 L
.016 .15266 L
.02 .15296 L
.024 .15269 L
.028 .15256 L
.032 .15267 L
.036 .15269 L
.04 .15268 L
.044 .15265 L
.048 .15267 L
.052 .15267 L
.056 .15267 L
.06 .15266 L
.064 .15267 L
.068 .15266 L
.072 .15267 L
.076 .15267 L
.08 .15267 L
.084 .15266 L
.088 .15267 L
.092 .15266 L
.096 .15267 L
.1 .15267 L
.104 .15267 L
.108 .15267 L
.112 .15267 L
.116 .15266 L
.12 .15266 L
.124 .15266 L
.128 .15267 L
.132 .15267 L
.136 .15268 L
.14 .15267 L
.144 .15267 L
.148 .15266 L
.152 .15266 L
.156 .15266 L
.16 .15267 L
.164 .15268 L
.168 .15268 L
.172 .15267 L
.176 .15266 L
.18 .15266 L
.184 .15266 L
.188 .15267 L
.192 .15268 L
.196 .15268 L
.2 .15268 L
Mistroke
.204 .15267 L
.208 .15266 L
.212 .15266 L
.216 .15267 L
.22 .15267 L
.224 .15268 L
.228 .15268 L
.232 .15268 L
.236 .15267 L
.24 .15267 L
.244 .15267 L
.248 .15267 L
.252 .15267 L
.256 .15267 L
.26 .15268 L
.264 .15268 L
.268 .15268 L
.272 .15267 L
.276 .15267 L
.28 .15267 L
.284 .15267 L
.288 .15267 L
.292 .15268 L
.296 .15268 L
.3 .15268 L
.304 .15267 L
.308 .15267 L
.312 .15267 L
.316 .15267 L
.32 .15268 L
.324 .15268 L
.328 .15268 L
.332 .15268 L
.336 .15268 L
.34 .15268 L
.344 .15268 L
.348 .15268 L
.352 .15268 L
.356 .15268 L
.36 .15267 L
.364 .15267 L
.368 .15268 L
.372 .15268 L
.376 .15269 L
.38 .15269 L
.384 .15268 L
.388 .15268 L
.392 .15268 L
.396 .15267 L
.4 .15267 L
Mistroke
.404 .15267 L
.408 .15268 L
.412 .15269 L
.416 .1527 L
.42 .15269 L
.424 .15269 L
.428 .15268 L
.432 .15268 L
.436 .15267 L
.44 .15267 L
.444 .15268 L
.448 .15269 L
.452 .1527 L
.456 .1527 L
.46 .1527 L
.464 .15269 L
.468 .15268 L
.472 .15268 L
.476 .15267 L
.48 .15267 L
.484 .15268 L
.488 .15269 L
.492 .15271 L
.496 .15272 L
.5 .15272 L
.504 .1527 L
.508 .15268 L
.512 .15267 L
.516 .15267 L
.52 .15267 L
.524 .15268 L
.528 .15269 L
.532 .15271 L
.536 .15274 L
.54 .15275 L
.544 .15274 L
.548 .15271 L
.552 .15268 L
.556 .15267 L
.56 .15268 L
.564 .15272 L
.568 .15276 L
.572 .15281 L
.576 .15287 L
.58 .15295 L
.584 .15303 L
.588 .1531 L
.592 .15316 L
.596 .15325 L
.6 .15341 L
Mistroke
.604 .15367 L
.608 .15404 L
.612 .15449 L
.616 .15502 L
.62 .15564 L
.624 .15638 L
.628 .15725 L
.632 .15825 L
.636 .15938 L
.64 .16067 L
.644 .16215 L
.648 .16387 L
.652 .16585 L
.656 .16804 L
.66 .17036 L
.664 .17275 L
.668 .17519 L
.672 .17765 L
.676 .18012 L
.68 .18255 L
.684 .18487 L
.688 .18706 L
.692 .18915 L
.696 .19117 L
.7 .19314 L
.704 .19508 L
.708 .19693 L
.712 .19869 L
.716 .20038 L
.72 .20208 L
.724 .20387 L
.728 .2058 L
.732 .20786 L
.736 .21 L
.74 .2122 L
.744 .21444 L
.748 .21673 L
.752 .21903 L
.756 .2213 L
.76 .22347 L
.764 .22547 L
.768 .2273 L
.772 .22902 L
.776 .23069 L
.78 .23239 L
.784 .23411 L
.788 .23582 L
.792 .23747 L
.796 .23901 L
.8 .2404 L
Mistroke
.804 .24162 L
.808 .24268 L
.812 .24359 L
.816 .24434 L
.82 .24495 L
.824 .24543 L
.828 .24582 L
.832 .24618 L
.836 .24658 L
.84 .24706 L
.844 .24765 L
.848 .2483 L
.852 .24897 L
.856 .24962 L
.86 .25023 L
.864 .25085 L
.868 .25156 L
.872 .25245 L
.876 .25351 L
.88 .25467 L
.884 .25579 L
.888 .25668 L
.892 .25728 L
.896 .25759 L
.9 .25773 L
.904 .25788 L
.908 .25815 L
.912 .25857 L
.916 .2591 L
.92 .2596 L
.924 .26003 L
.928 .26035 L
.932 .26063 L
.936 .26096 L
.94 .26138 L
.944 .26192 L
.948 .26246 L
.952 .26291 L
.956 .26319 L
.96 .26325 L
.964 .2632 L
.968 .26309 L
.972 .26302 L
.976 .26302 L
.98 .26306 L
.984 .26305 L
.988 .26293 L
.992 .26263 L
.996 .26215 L
1 .26155 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16163 L
.012 .16114 L
.016 .16102 L
.02 .16128 L
.024 .16126 L
.028 .16118 L
.032 .16116 L
.036 .16123 L
.04 .16121 L
.044 .16121 L
.048 .1612 L
.052 .16121 L
.056 .16119 L
.06 .1612 L
.064 .16119 L
.068 .16121 L
.072 .1612 L
.076 .16121 L
.08 .1612 L
.084 .1612 L
.088 .16119 L
.092 .16119 L
.096 .16119 L
.1 .16121 L
.104 .1612 L
.108 .1612 L
.112 .16119 L
.116 .16119 L
.12 .16118 L
.124 .16119 L
.128 .1612 L
.132 .1612 L
.136 .1612 L
.14 .16119 L
.144 .16118 L
.148 .16118 L
.152 .16118 L
.156 .16119 L
.16 .16119 L
.164 .1612 L
.168 .16119 L
.172 .16119 L
.176 .16118 L
.18 .16118 L
.184 .16118 L
.188 .16118 L
.192 .16119 L
.196 .16119 L
.2 .16119 L
Mistroke
.204 .16119 L
.208 .16118 L
.212 .16117 L
.216 .16117 L
.22 .16118 L
.224 .16118 L
.228 .16119 L
.232 .16119 L
.236 .16118 L
.24 .16117 L
.244 .16117 L
.248 .16117 L
.252 .16117 L
.256 .16118 L
.26 .16119 L
.264 .16118 L
.268 .16118 L
.272 .16117 L
.276 .16117 L
.28 .16117 L
.284 .16117 L
.288 .16118 L
.292 .16118 L
.296 .16117 L
.3 .16117 L
.304 .16117 L
.308 .16117 L
.312 .16117 L
.316 .16117 L
.32 .16117 L
.324 .16116 L
.328 .16117 L
.332 .16117 L
.336 .16117 L
.34 .16117 L
.344 .16117 L
.348 .16117 L
.352 .16117 L
.356 .16116 L
.36 .16116 L
.364 .16116 L
.368 .16116 L
.372 .16116 L
.376 .16117 L
.38 .16117 L
.384 .16117 L
.388 .16116 L
.392 .16116 L
.396 .16115 L
.4 .16114 L
Mistroke
.404 .16115 L
.408 .16116 L
.412 .16117 L
.416 .16117 L
.42 .16117 L
.424 .16116 L
.428 .16115 L
.432 .16115 L
.436 .16114 L
.44 .16114 L
.444 .16114 L
.448 .16116 L
.452 .16117 L
.456 .16118 L
.46 .16117 L
.464 .16115 L
.468 .16114 L
.472 .16113 L
.476 .16113 L
.48 .16113 L
.484 .16113 L
.488 .16115 L
.492 .16117 L
.496 .16118 L
.5 .16118 L
.504 .16116 L
.508 .16113 L
.512 .16112 L
.516 .16111 L
.52 .16111 L
.524 .16112 L
.528 .16113 L
.532 .16116 L
.536 .16118 L
.54 .16119 L
.544 .16118 L
.548 .16113 L
.552 .16108 L
.556 .16104 L
.56 .16103 L
.564 .16104 L
.568 .16103 L
.572 .16103 L
.576 .16101 L
.58 .16098 L
.584 .16091 L
.588 .16077 L
.592 .16056 L
.596 .16029 L
.6 .16 L
Mistroke
.604 .15969 L
.608 .15935 L
.612 .15892 L
.616 .15836 L
.62 .15764 L
.624 .15676 L
.628 .15569 L
.632 .1544 L
.636 .15284 L
.64 .15102 L
.644 .14899 L
.648 .14681 L
.652 .14449 L
.656 .14201 L
.66 .13933 L
.664 .13645 L
.668 .1334 L
.672 .13026 L
.676 .12712 L
.68 .12401 L
.684 .12095 L
.688 .11799 L
.692 .11519 L
.696 .11264 L
.7 .11035 L
.704 .10826 L
.708 .10625 L
.712 .1042 L
.716 .10204 L
.72 .09976 L
.724 .09736 L
.728 .09485 L
.732 .09221 L
.736 .08942 L
.74 .0865 L
.744 .08355 L
.748 .08068 L
.752 .07796 L
.756 .07542 L
.76 .07301 L
.764 .07067 L
.768 .06835 L
.772 .06606 L
.776 .0638 L
.78 .06159 L
.784 .05941 L
.788 .05724 L
.792 .05508 L
.796 .05298 L
.8 .05102 L
Mistroke
.804 .04933 L
.808 .04797 L
.812 .04698 L
.816 .04633 L
.82 .04589 L
.824 .04556 L
.828 .0452 L
.832 .04474 L
.836 .04414 L
.84 .04342 L
.844 .0426 L
.848 .04168 L
.852 .04064 L
.856 .03946 L
.86 .03817 L
.864 .03683 L
.868 .03556 L
.872 .03447 L
.876 .03364 L
.88 .03303 L
.884 .03258 L
.888 .03218 L
.892 .03173 L
.896 .03123 L
.9 .03071 L
.904 .0302 L
.908 .02966 L
.912 .02899 L
.916 .0281 L
.92 .02686 L
.924 .02539 L
.928 .02385 L
.932 .02256 L
.936 .02177 L
.94 .02158 L
.944 .02195 L
.948 .02263 L
.952 .02334 L
.956 .02388 L
.96 .02411 L
.964 .02414 L
.968 .02407 L
.972 .02408 L
.976 .02425 L
.98 .02455 L
.984 .02491 L
.988 .02519 L
.992 .02532 L
.996 .02526 L
1 .02501 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool20010Ool00`00Oomoo`0ZOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo
0`0017oo0P0000=oo`00Ool01@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool5
0002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001o
ogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool01@00Oomoogoo00000goo00<007ooOol00P0000=oo`0000000Woo10000Woo00@007ooOol0009o
o`04001oogoo0004Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`03001oo`00009oo`06001oo`00001oo`000Woo00@007ooOol0009oo`03001o
ogoo00=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009o
o`03001oo`0000800006Ool007oo001oo`000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001o
ogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo0P0017oo00<007ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOomoo`@0009oo`80009oo`03001oogoo0080009oo`03001o
o`0000800005Ool007ooOol00002Ool01@00Oomoogoo00000goo00<007oo00000`000goo00@007oo
Ool000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo0P0037oo00<007ooOol017oo00@007oo
Ool000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol00goo0P00
0Woo00@007ooOol000=oo`03001oo`0000800005Ool007ooOol00002Ool01@00Oomoogoo00000goo
00<007oo00001Woo00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo
0P0017oo0P001Woo00@007ooOomoo`H0009oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D0
00=oo`8000Ioo`008Woo00<007ooOol0>Woo00<007ooOol03Woo00<007ooOol07Woo000ROol2000j
Ool2000@Ool00`00Oomoo`04Ool2000HOol0029oof<000aoo`008Woo6P0000=oo`000000100000Ao
o`00001oo`<00005Ool00000001oo`030002Ool200000goo000000050002Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`80009oo`04001oo`00Ool200000goo0000000600000goo001oo`0;
Ool0029oo`8001Eoo`03001oogoo00800004Ool00000Ool20002Ool200000goo00000002Ool20002
Ool300001Goo00000000Ool00P005goo00<007oo000017oo0P000Woo00@007oo0000009oo`03001o
ogoo00]oo`008Woo00<007ooOol0CGoo0P001Goo0P0027oo0P0037oo000ROol2001]Ool0029oo`80
06eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]o
o`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo
0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000R
Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P00
0goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol0
0`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05
001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000
Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=o
o`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool2
0004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00
:7oo>`00;Woo000XOol00`00Oomoo`0hOol2000/Ool000]oo`8000Aoo`03001oogoo00=oo`8000Ao
o`8000=oo`<000=oo`03001oogoo03Yoo`8002Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000=oo`04001oogoo000mOol3000XOol000=oo`D0009oo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000oOol3000VOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<0
00Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<0
00Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo
00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009o
o`@0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Io
o`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo00000goo0`00
00Eoo`00Oomoo`00009oo`03001oogoo009oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`02Ool01P00Oomoogoo001oo`D0009oo`03001oogoo00=oo`03
001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04
001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol4
0003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`080002Ool00`00Ool00003
0003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo
0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00
Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol02P000goo00@007ooOol000Eo
o`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007oo
Oomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007oo
Ool047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo
00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo
00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool0
0`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool0
0`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Io
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00
Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo
0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00GGoo2P0037oo000:Ool01000Oomoo`00
2goo00@007ooOol005Uoo`H001Eoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo055oo`H0
01]oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80051oo`<0021oo`002goo0P0027oo1@00
0Woo00<007ooOol0CGoo0`008Woo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004
Ool20005Ool30003Ool30004Ool20005Ool700000goo00000004Ool20005Ool50002Ool30004Ool2
0006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo
00=oo`04001oo`000002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo
00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001o
ogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00=oo`<000=oo`04001oogoo0002Ool01000Oomoo`001Woo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009o
o`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo009oo`800003Ool007oo009oo`04001oogoo0002Ool01000
Oomoo`001goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo1000
0goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Oomoo`@000=oo`04001oogoo0002Ool30003Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<0
07ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo
00<007ooOol017oo00<007ooOol0100000=oo`00Ool00Woo00@007ooOol0009oo`04001oogoo0002
Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D0
00=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool40004Ool30004
Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo045oo`8002moo`0077oo
00<007ooOol0?goo0`00<7oo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo
Ool00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;
Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo
000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<0
07ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Ao
o`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]o
o`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0
LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009o
o`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(20040\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31908 m
.008 .31834 L
.012 .31777 L
.016 .31778 L
.02 .3183 L
.024 .31847 L
.028 .31823 L
.032 .31809 L
.036 .31815 L
.04 .31822 L
.044 .31822 L
.048 .31827 L
.052 .31832 L
.056 .3183 L
.06 .31824 L
.064 .31821 L
.068 .31824 L
.072 .31833 L
.076 .3184 L
.08 .31842 L
.084 .31836 L
.088 .31826 L
.092 .31821 L
.096 .31827 L
.1 .31841 L
.104 .31856 L
.108 .31858 L
.112 .31846 L
.116 .31828 L
.12 .31818 L
.124 .31825 L
.128 .31846 L
.132 .31869 L
.136 .31878 L
.14 .31864 L
.144 .31836 L
.148 .31814 L
.152 .31817 L
.156 .31844 L
.16 .31877 L
.164 .31896 L
.168 .31887 L
.172 .31856 L
.176 .31822 L
.18 .3181 L
.184 .3183 L
.188 .3187 L
.192 .31904 L
.196 .31909 L
.2 .31885 L
Mistroke
.204 .31848 L
.208 .31821 L
.212 .31819 L
.216 .31844 L
.22 .31884 L
.224 .31916 L
.228 .3192 L
.232 .31893 L
.236 .31855 L
.24 .31828 L
.244 .31824 L
.248 .31844 L
.252 .31883 L
.256 .31923 L
.26 .31942 L
.264 .31922 L
.268 .31873 L
.272 .31825 L
.276 .3181 L
.28 .31836 L
.284 .31888 L
.288 .31939 L
.292 .31964 L
.296 .31947 L
.3 .31893 L
.304 .31829 L
.308 .31799 L
.312 .31825 L
.316 .3189 L
.32 .31952 L
.324 .31975 L
.328 .31957 L
.332 .31913 L
.336 .31862 L
.34 .31824 L
.344 .31819 L
.348 .31859 L
.352 .31925 L
.356 .31979 L
.36 .31988 L
.364 .31951 L
.368 .31896 L
.372 .31851 L
.376 .31832 L
.38 .31843 L
.384 .31883 L
.388 .31942 L
.392 .31992 L
.396 .31998 L
.4 .31953 L
Mistroke
.404 .31888 L
.408 .31845 L
.412 .31846 L
.416 .31878 L
.42 .31915 L
.424 .31945 L
.428 .31968 L
.432 .31979 L
.436 .31967 L
.44 .31927 L
.444 .31881 L
.448 .31858 L
.452 .31876 L
.456 .31917 L
.46 .31952 L
.464 .31962 L
.468 .31956 L
.472 .31952 L
.476 .31953 L
.48 .31947 L
.484 .31923 L
.488 .31894 L
.492 .31885 L
.496 .31906 L
.5 .3194 L
.504 .3196 L
.508 .31955 L
.512 .31944 L
.516 .3195 L
.52 .31965 L
.524 .31958 L
.528 .31905 L
.532 .31826 L
.536 .31773 L
.54 .31778 L
.544 .31816 L
.548 .31826 L
.552 .31769 L
.556 .31658 L
.56 .31536 L
.564 .31409 L
.568 .31232 L
.572 .30954 L
.576 .30591 L
.58 .3022 L
.584 .29903 L
.588 .29605 L
.592 .29209 L
.596 .28617 L
.6 .2784 L
Mistroke
.604 .26986 L
.608 .26148 L
.612 .25327 L
.616 .24453 L
.62 .23505 L
.624 .22582 L
.628 .21841 L
.632 .21356 L
.636 .21049 L
.64 .20771 L
.644 .20466 L
.648 .20247 L
.652 .20308 L
.656 .20741 L
.66 .21435 L
.664 .22171 L
.668 .22799 L
.672 .23337 L
.676 .23887 L
.68 .24457 L
.684 .24875 L
.688 .24905 L
.692 .24456 L
.696 .23695 L
.7 .22945 L
.704 .22459 L
.708 .2226 L
.712 .22193 L
.716 .22125 L
.72 .22103 L
.724 .22318 L
.728 .22906 L
.732 .23782 L
.736 .24657 L
.74 .25234 L
.744 .25422 L
.748 .25385 L
.752 .25395 L
.756 .2563 L
.76 .26064 L
.764 .26559 L
.768 .27026 L
.772 .27536 L
.776 .28265 L
.78 .29322 L
.784 .30632 L
.788 .31924 L
.792 .32887 L
.796 .33331 L
.8 .33273 L
Mistroke
.804 .32896 L
.808 .32414 L
.812 .31982 L
.816 .31645 L
.82 .31372 L
.824 .31112 L
.828 .30827 L
.832 .30517 L
.836 .30217 L
.84 .29989 L
.844 .29916 L
.848 .30046 L
.852 .30375 L
.856 .30826 L
.86 .31273 L
.864 .31643 L
.868 .31906 L
.872 .32117 L
.876 .32309 L
.88 .32416 L
.884 .3233 L
.888 .3188 L
.892 .31105 L
.896 .30229 L
.9 .29636 L
.904 .29733 L
.908 .30569 L
.912 .31917 L
.916 .33191 L
.92 .33805 L
.924 .3353 L
.928 .32488 L
.932 .31291 L
.936 .30546 L
.94 .30614 L
.944 .31446 L
.948 .32517 L
.952 .33268 L
.956 .33311 L
.96 .32673 L
.964 .3176 L
.968 .311 L
.972 .31021 L
.976 .31525 L
.98 .32312 L
.984 .32847 L
.988 .32937 L
.992 .32488 L
.996 .31745 L
1 .31248 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15272 m
.008 .1531 L
.012 .15315 L
.016 .15297 L
.02 .15295 L
.024 .15306 L
.028 .15304 L
.032 .15302 L
.036 .15301 L
.04 .15304 L
.044 .15302 L
.048 .15302 L
.052 .15301 L
.056 .15303 L
.06 .15302 L
.064 .15303 L
.068 .15302 L
.072 .15303 L
.076 .15302 L
.08 .15302 L
.084 .15301 L
.088 .15302 L
.092 .15302 L
.096 .15303 L
.1 .15302 L
.104 .15302 L
.108 .15302 L
.112 .15302 L
.116 .15302 L
.12 .15303 L
.124 .15303 L
.128 .15303 L
.132 .15302 L
.136 .15302 L
.14 .15302 L
.144 .15302 L
.148 .15302 L
.152 .15302 L
.156 .15303 L
.16 .15303 L
.164 .15303 L
.168 .15302 L
.172 .15302 L
.176 .15302 L
.18 .15302 L
.184 .15302 L
.188 .15303 L
.192 .15303 L
.196 .15303 L
.2 .15302 L
Mistroke
.204 .15302 L
.208 .15302 L
.212 .15302 L
.216 .15303 L
.22 .15303 L
.224 .15303 L
.228 .15303 L
.232 .15302 L
.236 .15302 L
.24 .15302 L
.244 .15302 L
.248 .15303 L
.252 .15304 L
.256 .15303 L
.26 .15303 L
.264 .15302 L
.268 .15302 L
.272 .15302 L
.276 .15303 L
.28 .15303 L
.284 .15303 L
.288 .15303 L
.292 .15303 L
.296 .15303 L
.3 .15303 L
.304 .15303 L
.308 .15303 L
.312 .15303 L
.316 .15303 L
.32 .15303 L
.324 .15303 L
.328 .15303 L
.332 .15303 L
.336 .15303 L
.34 .15303 L
.344 .15303 L
.348 .15303 L
.352 .15303 L
.356 .15303 L
.36 .15303 L
.364 .15303 L
.368 .15304 L
.372 .15304 L
.376 .15304 L
.38 .15303 L
.384 .15303 L
.388 .15303 L
.392 .15303 L
.396 .15304 L
.4 .15304 L
Mistroke
.404 .15304 L
.408 .15304 L
.412 .15304 L
.416 .15304 L
.42 .15303 L
.424 .15303 L
.428 .15303 L
.432 .15304 L
.436 .15305 L
.44 .15305 L
.444 .15305 L
.448 .15305 L
.452 .15304 L
.456 .15303 L
.46 .15303 L
.464 .15303 L
.468 .15303 L
.472 .15305 L
.476 .15306 L
.48 .15306 L
.484 .15306 L
.488 .15305 L
.492 .15304 L
.496 .15304 L
.5 .15303 L
.504 .15303 L
.508 .15303 L
.512 .15305 L
.516 .15307 L
.52 .15309 L
.524 .15309 L
.528 .15308 L
.532 .15308 L
.536 .15308 L
.54 .1531 L
.544 .15311 L
.548 .15315 L
.552 .15321 L
.556 .1533 L
.56 .15342 L
.564 .15354 L
.568 .15367 L
.572 .15383 L
.576 .15403 L
.58 .15432 L
.584 .15469 L
.588 .15515 L
.592 .15573 L
.596 .15644 L
.6 .1573 L
Mistroke
.604 .15832 L
.608 .15947 L
.612 .16076 L
.616 .1622 L
.62 .16381 L
.624 .16564 L
.628 .16768 L
.632 .16989 L
.636 .17224 L
.64 .17468 L
.644 .17719 L
.648 .17972 L
.652 .18222 L
.656 .18462 L
.66 .18687 L
.664 .18898 L
.668 .19098 L
.672 .19292 L
.676 .19481 L
.68 .19665 L
.684 .19843 L
.688 .20016 L
.692 .20191 L
.696 .20373 L
.7 .20565 L
.704 .20765 L
.708 .20971 L
.712 .21183 L
.716 .21402 L
.72 .2163 L
.724 .21864 L
.728 .22095 L
.732 .22316 L
.736 .22519 L
.74 .22706 L
.744 .22882 L
.748 .23053 L
.752 .23221 L
.756 .23388 L
.76 .23552 L
.764 .23711 L
.768 .23866 L
.772 .24016 L
.776 .24158 L
.78 .24285 L
.784 .24391 L
.788 .24469 L
.792 .24522 L
.796 .24558 L
.8 .24586 L
Mistroke
.804 .24617 L
.808 .24655 L
.812 .24701 L
.816 .24755 L
.82 .24814 L
.824 .24878 L
.828 .24949 L
.832 .25028 L
.836 .25116 L
.84 .25211 L
.844 .2531 L
.848 .25407 L
.852 .25496 L
.856 .25574 L
.86 .25638 L
.864 .25691 L
.868 .25731 L
.872 .25762 L
.876 .25784 L
.88 .258 L
.884 .25817 L
.888 .25843 L
.892 .25891 L
.896 .25962 L
.9 .26057 L
.904 .2616 L
.908 .26255 L
.912 .26324 L
.916 .26358 L
.92 .26362 L
.924 .26347 L
.928 .26328 L
.932 .26316 L
.936 .26307 L
.94 .26297 L
.944 .26271 L
.948 .26228 L
.952 .26171 L
.956 .26115 L
.96 .26075 L
.964 .26061 L
.968 .26073 L
.972 .26102 L
.976 .26134 L
.98 .26158 L
.984 .26167 L
.988 .26169 L
.992 .26166 L
.996 .26172 L
1 .26183 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16318 L
.012 .16124 L
.016 .16053 L
.02 .16121 L
.024 .16141 L
.028 .16122 L
.032 .16112 L
.036 .16121 L
.04 .16122 L
.044 .16122 L
.048 .16119 L
.052 .16121 L
.056 .1612 L
.06 .16121 L
.064 .16119 L
.068 .16121 L
.072 .1612 L
.076 .16121 L
.08 .16119 L
.084 .1612 L
.088 .16119 L
.092 .1612 L
.096 .1612 L
.1 .16121 L
.104 .1612 L
.108 .1612 L
.112 .16119 L
.116 .16119 L
.12 .16119 L
.124 .1612 L
.128 .1612 L
.132 .1612 L
.136 .16119 L
.14 .16118 L
.144 .16118 L
.148 .16118 L
.152 .16119 L
.156 .1612 L
.16 .1612 L
.164 .16119 L
.168 .16118 L
.172 .16118 L
.176 .16117 L
.18 .16118 L
.184 .16119 L
.188 .1612 L
.192 .16119 L
.196 .16118 L
.2 .16117 L
Mistroke
.204 .16117 L
.208 .16117 L
.212 .16118 L
.216 .16119 L
.22 .16119 L
.224 .16118 L
.228 .16118 L
.232 .16117 L
.236 .16117 L
.24 .16117 L
.244 .16117 L
.248 .16118 L
.252 .16118 L
.256 .16118 L
.26 .16118 L
.264 .16117 L
.268 .16117 L
.272 .16116 L
.276 .16117 L
.28 .16117 L
.284 .16118 L
.288 .16118 L
.292 .16117 L
.296 .16117 L
.3 .16116 L
.304 .16116 L
.308 .16117 L
.312 .16117 L
.316 .16117 L
.32 .16117 L
.324 .16117 L
.328 .16116 L
.332 .16117 L
.336 .16117 L
.34 .16116 L
.344 .16116 L
.348 .16116 L
.352 .16116 L
.356 .16116 L
.36 .16116 L
.364 .16116 L
.368 .16117 L
.372 .16116 L
.376 .16116 L
.38 .16115 L
.384 .16115 L
.388 .16115 L
.392 .16115 L
.396 .16116 L
.4 .16116 L
Mistroke
.404 .16116 L
.408 .16117 L
.412 .16116 L
.416 .16115 L
.42 .16114 L
.424 .16114 L
.428 .16114 L
.432 .16115 L
.436 .16116 L
.44 .16116 L
.444 .16116 L
.448 .16116 L
.452 .16115 L
.456 .16114 L
.46 .16113 L
.464 .16113 L
.468 .16114 L
.472 .16115 L
.476 .16116 L
.48 .16117 L
.484 .16116 L
.488 .16115 L
.492 .16114 L
.496 .16113 L
.5 .16112 L
.504 .16111 L
.508 .16112 L
.512 .16114 L
.516 .16115 L
.52 .16116 L
.524 .16115 L
.528 .16112 L
.532 .16109 L
.536 .16106 L
.54 .16103 L
.544 .16099 L
.548 .16094 L
.552 .1609 L
.556 .16085 L
.56 .16078 L
.564 .16066 L
.568 .16046 L
.572 .16019 L
.576 .15986 L
.58 .15946 L
.584 .15899 L
.588 .15841 L
.592 .15772 L
.596 .15689 L
.6 .15591 L
Mistroke
.604 .15475 L
.608 .15335 L
.612 .15168 L
.616 .14975 L
.62 .14758 L
.624 .14522 L
.628 .14269 L
.632 .14 L
.636 .13716 L
.64 .13419 L
.644 .13115 L
.648 .12809 L
.652 .12504 L
.656 .12201 L
.66 .11902 L
.664 .11614 L
.668 .11344 L
.672 .11098 L
.676 .10875 L
.68 .10666 L
.684 .10462 L
.688 .10254 L
.692 .10039 L
.696 .09813 L
.7 .09574 L
.704 .09316 L
.708 .09039 L
.712 .08746 L
.716 .08449 L
.72 .08159 L
.724 .07884 L
.728 .07626 L
.732 .07378 L
.736 .07137 L
.74 .06901 L
.744 .06672 L
.748 .0645 L
.752 .06232 L
.756 .06014 L
.76 .05793 L
.764 .05571 L
.768 .05358 L
.772 .05167 L
.776 .05004 L
.78 .04872 L
.784 .04768 L
.788 .04686 L
.792 .04618 L
.796 .04562 L
.8 .04514 L
Mistroke
.804 .04469 L
.808 .04419 L
.812 .04357 L
.816 .04279 L
.82 .04186 L
.824 .04081 L
.828 .03972 L
.832 .03866 L
.836 .03766 L
.84 .03672 L
.844 .03579 L
.848 .03486 L
.852 .0339 L
.856 .03295 L
.86 .03209 L
.864 .03138 L
.868 .03084 L
.872 .03042 L
.876 .02999 L
.88 .02943 L
.884 .02865 L
.888 .02766 L
.892 .02657 L
.896 .02555 L
.9 .02476 L
.904 .02424 L
.908 .02397 L
.912 .02386 L
.916 .02379 L
.92 .02374 L
.924 .02371 L
.928 .02373 L
.932 .02381 L
.936 .02386 L
.94 .02383 L
.944 .02359 L
.948 .02317 L
.952 .02267 L
.956 .02228 L
.96 .02219 L
.964 .02249 L
.968 .02316 L
.972 .02403 L
.976 .02488 L
.98 .02552 L
.984 .02585 L
.988 .02593 L
.992 .02583 L
.996 .02578 L
1 .02581 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2000mOol2000^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`000Woo
00@007oo000000=oo`D000=oo`8000Aoo`8000Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo
00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D0
07ooOomoo`0000=oo`800003Ool007oo0080009oo`<00005Ool007ooOol00002Ool01000Oomoo`00
0Woo00<007ooOol00Woo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`800003Ool007oo00800005Ool007ooOol00004Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oo`00
009oo`8000=oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol017oo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;
Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
1000Oomoogoo1@000Woo00<007ooOol00P0000Aoo`00Oomoo`<00005Ool007ooOol00002Ool01000
Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool0
0`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009o
o`04001oogoo0004Ool20003Ool01000Oomoo`000goo00@007ooOol0009oo`04001oogooOol40002
Ool01000Oomoo`000Woo00D007ooOomoo`0000=oo`03001oo`0000Ioo`04001oogoo0005Ool0029o
o`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool2
0004Ool30002Ool01000Ool0000017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomo
o`0gOol2000@Ool00`00Oomoo`0POol0029oo`8003Moo`80015oo`03001oogoo00Uoo`03001oogoo
01Aoo`008WooH`0037oo000ROolZ00001Goo00000000Ool00P000Woo1P000Woo00@007ooOol000=o
o`05001oogooOol00003Ool00`00Oomoo`0200001Goo001oo`00Ool0100000=oo`0000000P0000Ao
o`00001oo`8000aoo`008Woo0P005goo00<007ooOol00P0000=oo`0000000Woo0P0000Aoo`00001o
o`<00005Ool00000001oo`03000IOol30005Ool20002Ool01`00Ool00000Ool007oo008000eoo`00
8Woo00<007ooOol0Bgoo00<007ooOol027oo0P000Woo00<007ooOol03goo000ROol2001]Ool0029o
o`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool0
00]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol0
0goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qo
o`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo
000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo
0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000R
Ool00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo
00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Io
o`00:7oo>@00<7oo000XOol00`00Oomoo`0eOol3000^Ool000]oo`8000Aoo`03001oogoo00=oo`80
00Aoo`8000=oo`<000=oo`03001oogoo03Moo`<002aoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000kOol3000ZOol000=oo`D0009oo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000mOol3000XOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Mo
o`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009o
o`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool01000
0goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol0
10000Woo00@007ooOol0009oo`04001oogoo0003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006
Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00H007ooOomoo`00Ool40002
Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo009oo`03001oogoo00H00005Ool007ooOol00005Ool00`00Oomo
o`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo
00H007ooOol007oo0003Ool01000Oomoo`000Woo200000=oo`00Ool00Woo00<007oo00000`000goo
00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Ao
o`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003
Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oo`0000X000=oo`04001oogoo0005Ool002Qo
o`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol5
0003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011o
o`03001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001o
ogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo
001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo0080
06Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007oo
Ool0IWoo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo
1@000Woo00@007ooOol000]oo`03001oogoo008005Yoo`d000aoo`002Woo00@007ooOol000]oo`04
001oogoo001FOol6000HOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1?Ool6000MOol0
00Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001=Ool3000SOol000]oo`8000Qoo`D0009oo`03
001oogoo04]oo`8002Eoo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P00
1Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000L
Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`02Ool20002
Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo00=oo`06001oogoo001oo`000goo00@0
07ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo
00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007oo
Ool0009oo`04001oogooOol200000goo001oo`03Ool01000Oomoo`000Woo00@007ooOol000Ioo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo
0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Ool000020003Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`80
00eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`04001oogooOol40003Ool00`00Oomoo`020003Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo
00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Ao
o`8000=oo`03001oogoo00Aoo`04001oo`000004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D0
00=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50002Ool30006Ool30004
Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo03ioo`80039oo`0077oo
00<007ooOol0?7oo0`00<goo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo
Ool00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;
Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo
000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<0
07ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Ao
o`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]o
o`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0
LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009o
o`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(20207\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31817 m
.008 .31792 L
.012 .31816 L
.016 .31812 L
.02 .31793 L
.024 .31804 L
.028 .31829 L
.032 .31836 L
.036 .31827 L
.04 .31818 L
.044 .3181 L
.048 .31806 L
.052 .31813 L
.056 .31826 L
.06 .31837 L
.064 .31839 L
.068 .31831 L
.072 .31821 L
.076 .31815 L
.08 .31818 L
.084 .31829 L
.088 .3184 L
.092 .31844 L
.096 .31842 L
.1 .31834 L
.104 .31828 L
.108 .31826 L
.112 .3183 L
.116 .31838 L
.12 .31846 L
.124 .3185 L
.128 .31849 L
.132 .31845 L
.136 .31839 L
.14 .31835 L
.144 .31833 L
.148 .31838 L
.152 .31851 L
.156 .31864 L
.16 .31869 L
.164 .31861 L
.168 .31844 L
.172 .3183 L
.176 .31827 L
.18 .31842 L
.184 .31869 L
.188 .31891 L
.192 .31891 L
.196 .31866 L
.2 .31833 L
Mistroke
.204 .31815 L
.208 .31827 L
.212 .31862 L
.216 .31899 L
.22 .31916 L
.224 .31901 L
.228 .31861 L
.232 .31821 L
.236 .3181 L
.24 .31838 L
.244 .31886 L
.248 .31923 L
.252 .31928 L
.256 .31901 L
.26 .3186 L
.264 .31826 L
.268 .31817 L
.272 .31842 L
.276 .3189 L
.28 .31933 L
.284 .31945 L
.288 .31919 L
.292 .31873 L
.296 .31834 L
.3 .31819 L
.304 .31836 L
.308 .31881 L
.312 .31936 L
.316 .31969 L
.32 .31955 L
.324 .31898 L
.328 .31835 L
.332 .31808 L
.336 .31829 L
.34 .31883 L
.344 .31939 L
.348 .31973 L
.352 .31972 L
.356 .31931 L
.36 .31869 L
.364 .31819 L
.368 .31816 L
.372 .31862 L
.376 .31928 L
.38 .31973 L
.384 .3198 L
.388 .31956 L
.392 .31914 L
.396 .31868 L
.4 .31834 L
Mistroke
.404 .31833 L
.408 .31876 L
.412 .31944 L
.416 .31994 L
.42 .31996 L
.424 .31953 L
.428 .31899 L
.432 .31865 L
.436 .31859 L
.44 .31872 L
.444 .31898 L
.448 .31934 L
.452 .31972 L
.456 .3199 L
.46 .31972 L
.464 .31926 L
.468 .31882 L
.472 .31868 L
.476 .31886 L
.48 .31913 L
.484 .31929 L
.488 .31932 L
.492 .31935 L
.496 .31941 L
.5 .31936 L
.504 .31904 L
.508 .31849 L
.512 .31795 L
.516 .31763 L
.52 .31743 L
.524 .31704 L
.528 .31623 L
.532 .31509 L
.536 .31386 L
.54 .31255 L
.544 .31078 L
.548 .30807 L
.552 .30432 L
.556 .29993 L
.56 .2954 L
.564 .29075 L
.568 .28548 L
.572 .27909 L
.576 .27163 L
.58 .26362 L
.584 .25549 L
.588 .24707 L
.592 .23794 L
.596 .22821 L
.6 .21893 L
Mistroke
.604 .2115 L
.608 .20665 L
.612 .20394 L
.616 .2024 L
.62 .20168 L
.624 .20242 L
.628 .20551 L
.632 .21091 L
.636 .21738 L
.64 .22349 L
.644 .22876 L
.648 .23381 L
.652 .23922 L
.656 .24424 L
.66 .2469 L
.664 .2455 L
.668 .24023 L
.672 .2332 L
.676 .22694 L
.68 .22261 L
.684 .21975 L
.688 .21761 L
.692 .2166 L
.696 .21836 L
.7 .22413 L
.704 .23314 L
.708 .24253 L
.712 .24925 L
.716 .2522 L
.72 .25282 L
.724 .25362 L
.728 .25601 L
.732 .25952 L
.736 .26282 L
.74 .26567 L
.744 .26969 L
.748 .27718 L
.752 .28902 L
.756 .3034 L
.76 .31669 L
.764 .32569 L
.768 .32952 L
.772 .32965 L
.776 .32833 L
.78 .32677 L
.784 .32456 L
.788 .32071 L
.792 .31506 L
.796 .30893 L
.8 .30431 L
Mistroke
.804 .30241 L
.808 .3028 L
.812 .30379 L
.816 .30372 L
.82 .30225 L
.824 .30055 L
.828 .30058 L
.832 .30376 L
.836 .31002 L
.84 .31794 L
.844 .32498 L
.848 .32885 L
.852 .32815 L
.856 .32281 L
.86 .3147 L
.864 .30641 L
.868 .30106 L
.872 .30052 L
.876 .30459 L
.88 .31155 L
.884 .31814 L
.888 .32233 L
.892 .32349 L
.896 .32273 L
.9 .32223 L
.904 .32264 L
.908 .32365 L
.912 .32346 L
.916 .32065 L
.92 .31598 L
.924 .31156 L
.928 .31067 L
.932 .31492 L
.936 .32303 L
.94 .33132 L
.944 .3353 L
.948 .33238 L
.952 .32356 L
.956 .31325 L
.96 .30625 L
.964 .30662 L
.968 .31383 L
.972 .3239 L
.976 .33259 L
.98 .33427 L
.984 .32929 L
.988 .32014 L
.992 .30998 L
.996 .30582 L
1 .30702 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15058 m
.008 .15339 L
.012 .15429 L
.016 .15339 L
.02 .15305 L
.024 .15338 L
.028 .15347 L
.032 .15339 L
.036 .15333 L
.04 .15338 L
.044 .15338 L
.048 .15338 L
.052 .15336 L
.056 .15338 L
.06 .15337 L
.064 .15338 L
.068 .15337 L
.072 .15338 L
.076 .15337 L
.08 .15337 L
.084 .15337 L
.088 .15338 L
.092 .15338 L
.096 .15338 L
.1 .15337 L
.104 .15337 L
.108 .15337 L
.112 .15337 L
.116 .15338 L
.12 .15338 L
.124 .15338 L
.128 .15338 L
.132 .15337 L
.136 .15337 L
.14 .15337 L
.144 .15338 L
.148 .15338 L
.152 .15339 L
.156 .15338 L
.16 .15337 L
.164 .15337 L
.168 .15337 L
.172 .15337 L
.176 .15338 L
.18 .15338 L
.184 .15338 L
.188 .15338 L
.192 .15337 L
.196 .15337 L
.2 .15337 L
Mistroke
.204 .15338 L
.208 .15338 L
.212 .15338 L
.216 .15338 L
.22 .15338 L
.224 .15338 L
.228 .15337 L
.232 .15337 L
.236 .15338 L
.24 .15338 L
.244 .15339 L
.248 .15339 L
.252 .15338 L
.256 .15338 L
.26 .15337 L
.264 .15337 L
.268 .15338 L
.272 .15339 L
.276 .15339 L
.28 .15339 L
.284 .15338 L
.288 .15338 L
.292 .15338 L
.296 .15338 L
.3 .15338 L
.304 .15339 L
.308 .15339 L
.312 .15339 L
.316 .15339 L
.32 .15338 L
.324 .15338 L
.328 .15338 L
.332 .15338 L
.336 .15338 L
.34 .15339 L
.344 .15339 L
.348 .15339 L
.352 .15339 L
.356 .15339 L
.36 .15339 L
.364 .15339 L
.368 .15339 L
.372 .15339 L
.376 .15339 L
.38 .15339 L
.384 .15339 L
.388 .15339 L
.392 .15339 L
.396 .15339 L
.4 .15339 L
Mistroke
.404 .15339 L
.408 .15339 L
.412 .15339 L
.416 .15339 L
.42 .15339 L
.424 .1534 L
.428 .1534 L
.432 .1534 L
.436 .1534 L
.44 .15339 L
.444 .15338 L
.448 .15338 L
.452 .15339 L
.456 .15339 L
.46 .1534 L
.464 .1534 L
.468 .15341 L
.472 .15341 L
.476 .1534 L
.48 .15339 L
.484 .15339 L
.488 .15339 L
.492 .1534 L
.496 .15342 L
.5 .15343 L
.504 .15344 L
.508 .15346 L
.512 .15347 L
.516 .15349 L
.52 .15352 L
.524 .15355 L
.528 .1536 L
.532 .15369 L
.536 .15381 L
.54 .15397 L
.544 .15415 L
.548 .15437 L
.552 .15465 L
.556 .15499 L
.56 .15542 L
.564 .15595 L
.568 .15658 L
.572 .15736 L
.576 .15831 L
.58 .15942 L
.584 .16071 L
.588 .16216 L
.592 .16377 L
.596 .16554 L
.6 .1675 L
Mistroke
.604 .16961 L
.608 .17187 L
.612 .17423 L
.616 .17668 L
.62 .1792 L
.624 .18173 L
.628 .18421 L
.632 .18659 L
.636 .18881 L
.64 .19089 L
.644 .19283 L
.648 .19468 L
.652 .19646 L
.656 .19819 L
.66 .1999 L
.664 .20165 L
.668 .20347 L
.672 .2054 L
.676 .20741 L
.68 .20949 L
.684 .2116 L
.688 .21376 L
.692 .21598 L
.696 .21824 L
.7 .22051 L
.704 .2227 L
.708 .22478 L
.712 .22674 L
.716 .2286 L
.72 .23038 L
.724 .23211 L
.728 .23377 L
.732 .23536 L
.736 .2369 L
.74 .23842 L
.744 .23994 L
.748 .24141 L
.752 .24276 L
.756 .24388 L
.76 .24474 L
.764 .24536 L
.768 .24579 L
.772 .24613 L
.776 .24643 L
.78 .24673 L
.784 .24707 L
.788 .24749 L
.792 .24803 L
.796 .24873 L
.8 .24956 L
Mistroke
.804 .25048 L
.808 .25142 L
.812 .25233 L
.816 .25319 L
.82 .25401 L
.824 .2548 L
.828 .25557 L
.832 .25628 L
.836 .25687 L
.84 .25731 L
.844 .2576 L
.848 .2578 L
.852 .25799 L
.856 .25828 L
.86 .25875 L
.864 .25942 L
.868 .26024 L
.872 .26112 L
.876 .26195 L
.88 .26263 L
.884 .26311 L
.888 .2634 L
.892 .26352 L
.896 .26351 L
.9 .26336 L
.904 .2631 L
.908 .26276 L
.912 .2624 L
.916 .26212 L
.92 .26198 L
.924 .26203 L
.928 .2622 L
.932 .2624 L
.936 .26252 L
.94 .26249 L
.944 .26232 L
.948 .26209 L
.952 .26189 L
.956 .2618 L
.96 .26176 L
.964 .26174 L
.968 .26158 L
.972 .26126 L
.976 .26081 L
.98 .26034 L
.984 .26002 L
.988 .25997 L
.992 .26022 L
.996 .26076 L
1 .26134 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16112 L
.012 .16131 L
.016 .16125 L
.02 .16116 L
.024 .16117 L
.028 .16125 L
.032 .16121 L
.036 .1612 L
.04 .16119 L
.044 .16121 L
.048 .1612 L
.052 .16121 L
.056 .1612 L
.06 .16121 L
.064 .1612 L
.068 .1612 L
.072 .16119 L
.076 .1612 L
.08 .16119 L
.084 .1612 L
.088 .1612 L
.092 .1612 L
.096 .16119 L
.1 .1612 L
.104 .16119 L
.108 .16119 L
.112 .16119 L
.116 .1612 L
.12 .16119 L
.124 .1612 L
.128 .16119 L
.132 .16119 L
.136 .16119 L
.14 .16119 L
.144 .16119 L
.148 .16119 L
.152 .16119 L
.156 .16119 L
.16 .16119 L
.164 .16118 L
.168 .16118 L
.172 .16118 L
.176 .16118 L
.18 .16119 L
.184 .16119 L
.188 .16119 L
.192 .16118 L
.196 .16117 L
.2 .16117 L
Mistroke
.204 .16118 L
.208 .16118 L
.212 .16119 L
.216 .16119 L
.22 .16118 L
.224 .16117 L
.228 .16117 L
.232 .16117 L
.236 .16118 L
.24 .16118 L
.244 .16119 L
.248 .16118 L
.252 .16117 L
.256 .16117 L
.26 .16117 L
.264 .16117 L
.268 .16117 L
.272 .16117 L
.276 .16118 L
.28 .16118 L
.284 .16117 L
.288 .16117 L
.292 .16116 L
.296 .16116 L
.3 .16116 L
.304 .16117 L
.308 .16117 L
.312 .16117 L
.316 .16117 L
.32 .16116 L
.324 .16116 L
.328 .16116 L
.332 .16116 L
.336 .16116 L
.34 .16116 L
.344 .16116 L
.348 .16116 L
.352 .16116 L
.356 .16116 L
.36 .16116 L
.364 .16116 L
.368 .16116 L
.372 .16116 L
.376 .16115 L
.38 .16115 L
.384 .16115 L
.388 .16116 L
.392 .16116 L
.396 .16116 L
.4 .16115 L
Mistroke
.404 .16115 L
.408 .16115 L
.412 .16115 L
.416 .16115 L
.42 .16115 L
.424 .16115 L
.428 .16116 L
.432 .16116 L
.436 .16116 L
.44 .16114 L
.444 .16113 L
.448 .16113 L
.452 .16114 L
.456 .16114 L
.46 .16115 L
.464 .16115 L
.468 .16116 L
.472 .16115 L
.476 .16114 L
.48 .16113 L
.484 .16112 L
.488 .16111 L
.492 .16112 L
.496 .16112 L
.5 .16112 L
.504 .16112 L
.508 .1611 L
.512 .16107 L
.516 .16103 L
.52 .16098 L
.524 .16091 L
.528 .16082 L
.532 .16073 L
.536 .16062 L
.54 .16047 L
.544 .16026 L
.548 .15998 L
.552 .15962 L
.556 .15917 L
.56 .15861 L
.564 .15792 L
.568 .15709 L
.572 .15611 L
.576 .15497 L
.58 .15365 L
.584 .15212 L
.588 .15034 L
.592 .14831 L
.596 .14603 L
.6 .14354 L
Mistroke
.604 .14086 L
.608 .13801 L
.612 .13503 L
.616 .13197 L
.62 .1289 L
.624 .12587 L
.628 .12289 L
.632 .11997 L
.636 .11712 L
.64 .1144 L
.644 .11183 L
.648 .10944 L
.652 .1072 L
.656 .10506 L
.66 .10296 L
.664 .10086 L
.668 .0987 L
.672 .09644 L
.676 .09402 L
.68 .09139 L
.684 .08856 L
.688 .0856 L
.692 .08264 L
.696 .07976 L
.7 .07703 L
.704 .07443 L
.708 .07195 L
.712 .0696 L
.716 .06737 L
.72 .06522 L
.724 .06311 L
.728 .06096 L
.732 .05874 L
.736 .0565 L
.74 .05434 L
.744 .05237 L
.748 .05067 L
.752 .04924 L
.756 .04807 L
.76 .04711 L
.764 .04636 L
.768 .04578 L
.772 .04533 L
.776 .04492 L
.78 .04443 L
.784 .04379 L
.788 .043 L
.792 .04209 L
.796 .04116 L
.8 .04024 L
Mistroke
.804 .03934 L
.808 .03842 L
.812 .03743 L
.816 .03637 L
.82 .03528 L
.824 .0342 L
.828 .03321 L
.832 .03232 L
.836 .03155 L
.84 .03088 L
.844 .03031 L
.848 .0298 L
.852 .02932 L
.856 .02884 L
.86 .0283 L
.864 .02767 L
.868 .02694 L
.872 .0261 L
.876 .02523 L
.88 .02443 L
.884 .02381 L
.888 .02344 L
.892 .02333 L
.896 .02339 L
.9 .02349 L
.904 .02348 L
.908 .02331 L
.912 .02303 L
.916 .02277 L
.92 .02269 L
.924 .02289 L
.928 .02335 L
.932 .02396 L
.936 .02456 L
.94 .02502 L
.944 .02532 L
.948 .0255 L
.952 .02565 L
.956 .02581 L
.96 .02591 L
.964 .02588 L
.968 .02559 L
.972 .02506 L
.976 .02438 L
.98 .02375 L
.984 .02338 L
.988 .02333 L
.992 .02359 L
.996 .02405 L
1 .02442 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2000jOol2000aOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`000Woo
00@007oo0000009oo`H000=oo`8000Aoo`8000Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo
00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D0
07ooOomoo`00009oo`800003Ool00000009oo`<00005Ool007ooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`03Ool0
0`00Ool00002Ool01000Oomoo`000Woo00<007oo000017oo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo009oo`800004Ool007ooOol40002
Ool01000Oomoo`000goo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`04Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001o
ogoo00]oo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`04001oogooOol40003Ool01000Oomoo`000Woo0`0000Eoo`00Oomoo`00009oo`04001oogoo
0002Ool01@00Oomoogoo00000goo00<007oo00000`000goo00@007ooOol000Eoo`002goo0P002Woo
0P0017oo00<007ooOol00Woo0P0037oo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001o
ogoo0002Ool01000Oomoo`0017oo0P000goo0P001Goo00@007ooOol0009oo`03001oo`000080009o
o`04001oogoo0002Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo
000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@00
0goo0P0017oo10000goo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`0d
Ool2000@Ool00`00Oomoo`0SOol0029oo`8003Eoo`03001oogoo00moo`03001oogoo02=oo`008Woo
H`0037oo000ROolR00000goo00000004000017oo000007oo0`0000=oo`0000000`0000=oo`00Ool0
0Woo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`020003Ool01@00Ool007oo0000
0goo0P0000=oo`0000000Woo0P0037oo000ROol2000IOol20002Ool00`00Oomoo`02000017oo0000
07oo0P000Woo0P000Woo0P006Goo0`0017oo0`000Woo0`0000Eoo`00Ool007oo008000ioo`008Woo
00<007ooOol0B7oo00<007ooOol03Woo00<007ooOol00P003Woo000ROol2001]Ool0029oo`8006eo
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`80
00Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P00
0Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2
001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo
000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001o
ogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol0
0`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P00
0goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo
0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00
Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001o
ogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomo
ogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03
001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
4Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004
Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo
=P00<goo000XOol00`00Oomoo`0cOol2000aOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`80
00=oo`<000=oo`03001oogoo03Eoo`8002moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1P00Oomoo`00Ool000=oo`04001oogoo000iOol2000]Ool000=oo`D0009oo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000jOol3000[Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Ao
o`8000Aoo`8000=oo`<000=oo`<000Aoo`T000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Io
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0
2Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo10000Woo00@007ooOol0009oo`04
001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo
00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`030003Ool01000Oomoo`000Woo
00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yo
o`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`02Ool600001Goo001oogoo00000Woo00<007ooOol00goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001o
o`000goo00D007ooOol007oo00P0009oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`00
:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool0
1000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00D007ooOol007oo00h000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qo
o`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool2
0004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
OomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00mo
o`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Ao
o`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool2
0002Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000A
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001o
ogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03
Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000
Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eo
o`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001o
ogoo008005Qoo`l000aoo`002Woo00@007ooOol000]oo`04001oogoo001COol6000KOol000Yoo`04
001oogoo0007Ool40003Ool00`00Oomoo`1<Ool6000POol000Yoo`04001oogoo0007Ool00`00Oomo
o`04Ool2001:Ool3000VOol000]oo`8000Qoo`D0009oo`03001oogoo04Qoo`8002Qoo`0077oo00<0
07ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P0017oo1P00
0goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo
00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomo
o`0000=oo`04001oogoo0002Ool00`00Ool0000200001Goo001oogoo00000Woo00@007ooOol0009o
o`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001ao
o`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool30004Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`05001oogoo001oo`030006Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool0
0`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool40004Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001ao
o`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`8000=oo`03001oogoo00=oo`80009oo`03001oogoo009oo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eo
o`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`L0
0003Ool0000000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007oo
Ool0>goo0P00=Goo000LOol00`00Oomoo`0iOol3000fOol001aoofT000aoo`0077oo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=o
o`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009o
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol3
0003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol0
0Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001o
ogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`00
2goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo
00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07
Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo
00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(20374\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3172 m
.008 .31787 L
.012 .31844 L
.016 .31841 L
.02 .31789 L
.024 .31781 L
.028 .31817 L
.032 .31837 L
.036 .31827 L
.04 .31815 L
.044 .3181 L
.048 .31806 L
.052 .31808 L
.056 .3182 L
.06 .31833 L
.064 .31837 L
.068 .31829 L
.072 .31816 L
.076 .31808 L
.08 .31812 L
.084 .31826 L
.088 .31843 L
.092 .31847 L
.096 .31839 L
.1 .31823 L
.104 .31812 L
.108 .31815 L
.112 .31831 L
.116 .31849 L
.12 .31858 L
.124 .31851 L
.128 .31834 L
.132 .31819 L
.136 .31818 L
.14 .31833 L
.144 .31852 L
.148 .31865 L
.152 .31863 L
.156 .31849 L
.16 .31832 L
.164 .31824 L
.168 .3183 L
.172 .31848 L
.176 .31866 L
.18 .31873 L
.184 .31868 L
.188 .31855 L
.192 .3184 L
.196 .31831 L
.2 .31834 L
Mistroke
.204 .31852 L
.208 .31876 L
.212 .3189 L
.216 .31885 L
.22 .31865 L
.224 .3184 L
.228 .31826 L
.232 .31831 L
.236 .31859 L
.24 .31896 L
.244 .31917 L
.248 .31906 L
.252 .31867 L
.256 .31827 L
.26 .31815 L
.264 .31836 L
.268 .3188 L
.272 .3192 L
.276 .31935 L
.28 .31915 L
.284 .31869 L
.288 .31824 L
.292 .31811 L
.296 .31842 L
.3 .31895 L
.304 .31937 L
.308 .31946 L
.312 .31923 L
.316 .31882 L
.32 .3184 L
.324 .31817 L
.328 .31832 L
.332 .31882 L
.336 .31941 L
.34 .3197 L
.344 .31952 L
.348 .31901 L
.352 .31848 L
.356 .31821 L
.36 .31829 L
.364 .3187 L
.368 .31929 L
.372 .31978 L
.376 .31985 L
.38 .3194 L
.384 .31871 L
.388 .31823 L
.392 .31823 L
.396 .31865 L
.4 .31919 L
Mistroke
.404 .31961 L
.408 .3198 L
.412 .3197 L
.416 .31931 L
.42 .31875 L
.424 .31831 L
.428 .31831 L
.432 .31879 L
.436 .31943 L
.44 .31984 L
.444 .31983 L
.448 .31953 L
.452 .31913 L
.456 .31878 L
.46 .31853 L
.464 .31845 L
.468 .31861 L
.472 .31898 L
.476 .3193 L
.48 .31927 L
.484 .31877 L
.488 .31799 L
.492 .31722 L
.496 .31657 L
.5 .31592 L
.504 .31504 L
.508 .31383 L
.512 .31235 L
.516 .3106 L
.52 .30838 L
.524 .30538 L
.528 .30149 L
.532 .29684 L
.536 .29171 L
.54 .28612 L
.544 .27984 L
.548 .2726 L
.552 .26451 L
.556 .25602 L
.56 .24755 L
.564 .23912 L
.568 .23052 L
.572 .22174 L
.576 .21341 L
.58 .2065 L
.584 .2017 L
.588 .19902 L
.592 .19811 L
.596 .19887 L
.6 .20163 L
Mistroke
.604 .20664 L
.608 .21338 L
.612 .22054 L
.616 .22681 L
.62 .23177 L
.624 .23587 L
.628 .2395 L
.632 .24215 L
.636 .24261 L
.64 .24009 L
.644 .23515 L
.648 .22941 L
.652 .22438 L
.656 .22047 L
.66 .21736 L
.664 .2151 L
.668 .2149 L
.672 .21828 L
.676 .22556 L
.68 .23501 L
.684 .24375 L
.688 .24971 L
.692 .25288 L
.696 .25478 L
.7 .25682 L
.704 .25908 L
.708 .26089 L
.712 .26233 L
.716 .26512 L
.72 .27166 L
.724 .28299 L
.728 .29745 L
.732 .31147 L
.736 .32181 L
.74 .32748 L
.744 .32972 L
.748 .3303 L
.752 .32971 L
.756 .32709 L
.76 .32162 L
.764 .31413 L
.768 .30715 L
.772 .30323 L
.776 .30305 L
.78 .30479 L
.784 .30559 L
.788 .30376 L
.792 .30008 L
.796 .29723 L
.8 .29774 L
Mistroke
.804 .30228 L
.808 .30937 L
.812 .31645 L
.816 .32163 L
.82 .32421 L
.824 .32452 L
.828 .32302 L
.832 .3197 L
.836 .31471 L
.84 .30862 L
.844 .3031 L
.848 .30022 L
.852 .3014 L
.856 .30693 L
.86 .31509 L
.864 .32347 L
.868 .32943 L
.872 .33115 L
.876 .32862 L
.88 .32289 L
.884 .31654 L
.888 .3122 L
.892 .31161 L
.896 .31509 L
.9 .32066 L
.904 .32562 L
.908 .32747 L
.912 .32552 L
.916 .32146 L
.92 .31811 L
.924 .31778 L
.928 .32054 L
.932 .32426 L
.936 .32551 L
.94 .32269 L
.944 .31663 L
.948 .31065 L
.952 .30935 L
.956 .31372 L
.96 .32248 L
.964 .33091 L
.968 .33304 L
.972 .32833 L
.976 .31766 L
.98 .30706 L
.984 .30369 L
.988 .30775 L
.992 .31974 L
.996 .33252 L
1 .33826 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .1535 m
.008 .15367 L
.012 .15374 L
.016 .15381 L
.02 .15372 L
.024 .1537 L
.028 .15371 L
.032 .15375 L
.036 .15372 L
.04 .15373 L
.044 .15372 L
.048 .15374 L
.052 .15372 L
.056 .15373 L
.06 .15372 L
.064 .15373 L
.068 .15372 L
.072 .15373 L
.076 .15373 L
.08 .15373 L
.084 .15373 L
.088 .15373 L
.092 .15373 L
.096 .15373 L
.1 .15373 L
.104 .15373 L
.108 .15373 L
.112 .15373 L
.116 .15373 L
.12 .15373 L
.124 .15373 L
.128 .15373 L
.132 .15372 L
.136 .15373 L
.14 .15373 L
.144 .15373 L
.148 .15373 L
.152 .15373 L
.156 .15373 L
.16 .15372 L
.164 .15372 L
.168 .15373 L
.172 .15373 L
.176 .15374 L
.18 .15374 L
.184 .15373 L
.188 .15372 L
.192 .15372 L
.196 .15373 L
.2 .15373 L
Mistroke
.204 .15374 L
.208 .15374 L
.212 .15373 L
.216 .15373 L
.22 .15372 L
.224 .15373 L
.228 .15373 L
.232 .15374 L
.236 .15374 L
.24 .15374 L
.244 .15373 L
.248 .15373 L
.252 .15373 L
.256 .15373 L
.26 .15373 L
.264 .15374 L
.268 .15374 L
.272 .15374 L
.276 .15374 L
.28 .15373 L
.284 .15373 L
.288 .15373 L
.292 .15373 L
.296 .15374 L
.3 .15374 L
.304 .15374 L
.308 .15374 L
.312 .15374 L
.316 .15373 L
.32 .15373 L
.324 .15374 L
.328 .15374 L
.332 .15374 L
.336 .15374 L
.34 .15374 L
.344 .15374 L
.348 .15374 L
.352 .15374 L
.356 .15374 L
.36 .15374 L
.364 .15374 L
.368 .15374 L
.372 .15374 L
.376 .15374 L
.38 .15374 L
.384 .15374 L
.388 .15374 L
.392 .15374 L
.396 .15374 L
.4 .15374 L
Mistroke
.404 .15374 L
.408 .15374 L
.412 .15375 L
.416 .15375 L
.42 .15375 L
.424 .15375 L
.428 .15375 L
.432 .15374 L
.436 .15374 L
.44 .15374 L
.444 .15375 L
.448 .15375 L
.452 .15376 L
.456 .15376 L
.46 .15376 L
.464 .15376 L
.468 .15376 L
.472 .15376 L
.476 .15377 L
.48 .15379 L
.484 .15381 L
.488 .15384 L
.492 .15388 L
.496 .15392 L
.5 .15397 L
.504 .15403 L
.508 .15412 L
.512 .15425 L
.516 .15442 L
.52 .15464 L
.524 .15492 L
.528 .15526 L
.532 .15568 L
.536 .15619 L
.54 .1568 L
.544 .15753 L
.548 .1584 L
.552 .15943 L
.556 .16065 L
.56 .16204 L
.564 .16361 L
.568 .16536 L
.572 .16728 L
.576 .16936 L
.58 .17158 L
.584 .17391 L
.588 .17632 L
.592 .17877 L
.596 .18125 L
.6 .18372 L
Mistroke
.604 .18614 L
.608 .18846 L
.612 .19064 L
.616 .19268 L
.62 .19459 L
.624 .1964 L
.628 .19812 L
.632 .19979 L
.636 .20146 L
.64 .2032 L
.644 .20505 L
.648 .20703 L
.652 .20912 L
.656 .21128 L
.66 .21349 L
.664 .21573 L
.668 .21797 L
.672 .22019 L
.676 .22235 L
.68 .22441 L
.684 .22638 L
.688 .22826 L
.692 .23009 L
.696 .23188 L
.7 .2336 L
.704 .23524 L
.708 .23681 L
.712 .23833 L
.716 .23982 L
.72 .24126 L
.724 .24258 L
.728 .24372 L
.732 .24466 L
.736 .24538 L
.74 .24594 L
.744 .24638 L
.748 .24673 L
.752 .24701 L
.756 .24729 L
.76 .24763 L
.764 .2481 L
.768 .24875 L
.772 .24956 L
.776 .25046 L
.78 .25138 L
.784 .25227 L
.788 .25314 L
.792 .254 L
.796 .25483 L
.8 .25562 L
Mistroke
.804 .25631 L
.808 .25687 L
.812 .25729 L
.816 .25763 L
.82 .25793 L
.824 .25826 L
.828 .25866 L
.832 .25913 L
.836 .25969 L
.84 .26033 L
.844 .26105 L
.848 .26179 L
.852 .2625 L
.856 .26309 L
.86 .26348 L
.864 .26364 L
.868 .26357 L
.872 .26336 L
.876 .2631 L
.88 .26289 L
.884 .26279 L
.888 .26279 L
.892 .26286 L
.896 .26292 L
.9 .26291 L
.904 .26282 L
.908 .26266 L
.912 .26249 L
.916 .26233 L
.92 .26218 L
.924 .262 L
.928 .26176 L
.932 .26145 L
.936 .2611 L
.94 .26084 L
.944 .26074 L
.948 .26085 L
.952 .26112 L
.956 .26146 L
.96 .26175 L
.964 .26194 L
.968 .26203 L
.972 .26214 L
.976 .26227 L
.98 .26251 L
.984 .2627 L
.988 .26275 L
.992 .26255 L
.996 .26203 L
1 .26133 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .1592 L
.012 .16122 L
.016 .16186 L
.02 .16122 L
.024 .16097 L
.028 .16122 L
.032 .16127 L
.036 .16121 L
.04 .16117 L
.044 .16121 L
.048 .1612 L
.052 .16121 L
.056 .1612 L
.06 .16121 L
.064 .1612 L
.068 .1612 L
.072 .16119 L
.076 .1612 L
.08 .1612 L
.084 .16121 L
.088 .1612 L
.092 .1612 L
.096 .16119 L
.1 .16119 L
.104 .16119 L
.108 .1612 L
.112 .1612 L
.116 .1612 L
.12 .16119 L
.124 .16119 L
.128 .16118 L
.132 .16119 L
.136 .16119 L
.14 .1612 L
.144 .16119 L
.148 .16119 L
.152 .16118 L
.156 .16118 L
.16 .16118 L
.164 .16118 L
.168 .16119 L
.172 .16119 L
.176 .16119 L
.18 .16119 L
.184 .16118 L
.188 .16118 L
.192 .16118 L
.196 .16118 L
.2 .16118 L
Mistroke
.204 .16118 L
.208 .16119 L
.212 .16118 L
.216 .16118 L
.22 .16117 L
.224 .16117 L
.228 .16117 L
.232 .16118 L
.236 .16118 L
.24 .16118 L
.244 .16118 L
.248 .16117 L
.252 .16116 L
.256 .16116 L
.26 .16117 L
.264 .16118 L
.268 .16118 L
.272 .16118 L
.276 .16117 L
.28 .16116 L
.284 .16116 L
.288 .16116 L
.292 .16117 L
.296 .16117 L
.3 .16117 L
.304 .16117 L
.308 .16117 L
.312 .16116 L
.316 .16116 L
.32 .16116 L
.324 .16116 L
.328 .16116 L
.332 .16116 L
.336 .16117 L
.34 .16116 L
.344 .16116 L
.348 .16116 L
.352 .16115 L
.356 .16115 L
.36 .16115 L
.364 .16116 L
.368 .16116 L
.372 .16116 L
.376 .16115 L
.38 .16115 L
.384 .16115 L
.388 .16115 L
.392 .16115 L
.396 .16115 L
.4 .16114 L
Mistroke
.404 .16114 L
.408 .16115 L
.412 .16115 L
.416 .16115 L
.42 .16115 L
.424 .16115 L
.428 .16114 L
.432 .16114 L
.436 .16114 L
.44 .16114 L
.444 .16114 L
.448 .16114 L
.452 .16115 L
.456 .16115 L
.46 .16114 L
.464 .16113 L
.468 .16111 L
.472 .1611 L
.476 .16109 L
.48 .16108 L
.484 .16107 L
.488 .16105 L
.492 .16101 L
.496 .16096 L
.5 .16088 L
.504 .16077 L
.508 .16064 L
.512 .16048 L
.516 .16028 L
.52 .16002 L
.524 .1597 L
.528 .15929 L
.532 .15878 L
.536 .15814 L
.54 .15736 L
.544 .15641 L
.548 .15529 L
.552 .15399 L
.556 .1525 L
.56 .1508 L
.564 .14887 L
.568 .1467 L
.572 .14431 L
.576 .14172 L
.58 .13894 L
.584 .13601 L
.588 .13295 L
.592 .12984 L
.596 .12673 L
.6 .12369 L
Mistroke
.604 .12075 L
.608 .11792 L
.612 .11521 L
.616 .11264 L
.62 .11022 L
.624 .10793 L
.628 .10573 L
.632 .10357 L
.636 .10141 L
.64 .09923 L
.644 .09699 L
.648 .09465 L
.652 .09216 L
.656 .0895 L
.66 .08668 L
.664 .08377 L
.668 .08086 L
.672 .078 L
.676 .07526 L
.68 .07264 L
.684 .07018 L
.688 .06789 L
.692 .06576 L
.696 .06371 L
.7 .06167 L
.704 .05957 L
.708 .05742 L
.712 .05526 L
.716 .05322 L
.72 .05136 L
.724 .04975 L
.728 .04839 L
.732 .0473 L
.736 .04648 L
.74 .04591 L
.744 .04551 L
.748 .04516 L
.752 .04472 L
.756 .04413 L
.76 .04337 L
.764 .04251 L
.768 .04161 L
.772 .0407 L
.776 .03978 L
.78 .03882 L
.784 .0378 L
.788 .03676 L
.792 .03573 L
.796 .03472 L
.8 .03373 L
Mistroke
.804 .03276 L
.808 .03183 L
.812 .03101 L
.816 .03034 L
.82 .02986 L
.824 .02954 L
.828 .02926 L
.832 .02889 L
.836 .02834 L
.84 .02756 L
.844 .02663 L
.848 .02566 L
.852 .02476 L
.856 .02404 L
.86 .02354 L
.864 .02324 L
.868 .02311 L
.872 .0231 L
.876 .02315 L
.88 .02324 L
.884 .02338 L
.888 .02353 L
.892 .02371 L
.896 .02388 L
.9 .02405 L
.904 .02422 L
.908 .02443 L
.912 .02469 L
.916 .02501 L
.92 .02531 L
.924 .02552 L
.928 .02554 L
.932 .02536 L
.936 .025 L
.94 .02463 L
.944 .02438 L
.948 .02438 L
.952 .0246 L
.956 .02497 L
.96 .02533 L
.964 .02554 L
.968 .02556 L
.972 .02546 L
.976 .02527 L
.98 .02517 L
.984 .0251 L
.988 .02506 L
.992 .02498 L
.996 .02472 L
1 .02438 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2000gOol3000cOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000Woo100017oo
0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool0
1000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo
00000goo00<007ooOol00P0000=oo`00Ool00Woo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`0017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo0004Ool20000
1Goo001oogoo000017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogoo0004Ool40002Ool20004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol02goo10000goo
00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo0000
1@000goo00<007ooOol010000goo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo0000
0goo00<007oo00000`000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo
0P0037oo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`00
17oo0P0000Aoo`00Ool000Ioo`04001oogoo0002Ool20002Ool01000Oomoo`000Woo00@007ooOol0
009oo`05001oogooOol00003Ool00`00Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool50003
Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Ool007oo1@000goo0P0017oo0`0017oo
0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`0bOol00`00Oomoo`0?Ool0
0`00Oomoo`0UOol0029oo`80039oo`03001oogoo011oo`03001oogoo00Aoo`03001oogoo01ioo`00
8WooH`0037oo000ROolN000017oo000007oo0`0000Aoo`00001oo`/000=oo`05001oogooOol00002
Ool01@00Oomoogoo00000goo0P000Woo0P000Woo0P000Woo00@007oo001oo`80009oo`03001oo`00
00@00003Ool007oo00]oo`008Woo0P006Goo00@007ooOol0009oo`800003Ool00000009oo`800003
Ool0000001]oo`03001oo`0000Eoo`80009oo`<00004Ool00000Ool200001Goo000007oo00003Goo
000ROol00`00Oomoo`16Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`02000<Ool0029o
o`8006eoo`008Woo0P00KGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomo
o`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004
Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`80
06eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool3
0003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<0
07ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo
000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000R
Ool2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000
Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009
Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo
00<007ooOol0IWoo000XOold000eOol002Qoo`03001oogoo031oo`<003=oo`002goo0P0017oo00<0
07ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0<Woo0`00<Goo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol003Ioo`80031oo`000goo1@00
0Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol003Qoo`<002eo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo
0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`000goo0`000Woo1@000goo0P0017oo
0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001o
ogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`05001oogoo001o
o`020002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool01P00Oomoo`00Ool0
00=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo1@00
17oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol01`000Woo00@007ooOol0009oo`03001oogoo00=oo`03001o
ogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001o
ogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003
Ool01P00Oomoo`00Ool000=oo`03001oo`0000L0009oo`04001oogoo0003Ool00`00Ool000030003
Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P00
17oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool0
00=oo`04001oogoo0002Ool00`00Ool0000@0003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09
Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo
0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?
Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo06Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo
0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003
Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001o
ogoo000;Ool00`00Oomoo`02001EOolB000<Ool000Yoo`04001oogoo000;Ool01000Oomoo`00DGoo
1P007Goo000:Ool01000Oomoo`001goo10000goo00<007ooOol0BGoo1P008goo000:Ool01000Oomo
o`001goo00<007ooOol017oo0P00B7oo0`00:7oo000;Ool20008Ool50002Ool00`00Oomoo`15Ool2
000[Ool001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<0
00Aoo`800003Ool00000009oo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo
0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo0P0017oo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<0
07ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool00`00Oomoo`040006Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`03001oogoo00800003Ool0
07oo00Ioo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo
00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@00004Ool000000002Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomo
ogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001o
ogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo0080009o
o`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00
Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo
00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002
Ool50003Ool20006Ool001aoo`03001oogoo03Uoo`8003Moo`0077oo00<007ooOol0=goo0P00>Goo
000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04
001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:
Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol0
17oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool0
0`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0
LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007oo
Ool00Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool0
0`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001o
ogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00
Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(20541\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3179 m
.008 .31828 L
.012 .3181 L
.016 .31807 L
.02 .31814 L
.024 .31808 L
.028 .31798 L
.032 .31804 L
.036 .31816 L
.04 .31818 L
.044 .31817 L
.048 .31815 L
.052 .31812 L
.056 .31812 L
.06 .31815 L
.064 .3182 L
.068 .31824 L
.072 .31822 L
.076 .31819 L
.08 .31819 L
.084 .31821 L
.088 .31828 L
.092 .31831 L
.096 .31829 L
.1 .31824 L
.104 .3182 L
.108 .31823 L
.112 .31832 L
.116 .31841 L
.12 .31844 L
.124 .31837 L
.128 .31825 L
.132 .31819 L
.136 .31825 L
.14 .31841 L
.144 .31856 L
.148 .31858 L
.152 .31846 L
.156 .31829 L
.16 .31819 L
.164 .31825 L
.168 .31845 L
.172 .31867 L
.176 .31874 L
.18 .31861 L
.184 .31837 L
.188 .31821 L
.192 .31824 L
.196 .31844 L
.2 .31869 L
Mistroke
.204 .31884 L
.208 .3188 L
.212 .31859 L
.216 .31835 L
.22 .31824 L
.224 .31835 L
.228 .3186 L
.232 .31885 L
.236 .31894 L
.24 .31886 L
.244 .31865 L
.248 .3184 L
.252 .31826 L
.256 .31835 L
.26 .31866 L
.264 .319 L
.268 .31916 L
.272 .31903 L
.276 .31871 L
.28 .31837 L
.284 .31821 L
.288 .31834 L
.292 .31874 L
.296 .3192 L
.3 .31942 L
.304 .31923 L
.308 .31873 L
.312 .31827 L
.316 .31815 L
.32 .31842 L
.324 .3189 L
.328 .31933 L
.332 .31952 L
.336 .31936 L
.34 .31891 L
.344 .31838 L
.348 .31813 L
.352 .31834 L
.356 .31888 L
.36 .31942 L
.364 .31966 L
.368 .31952 L
.372 .31912 L
.376 .31863 L
.38 .31826 L
.384 .31822 L
.388 .31862 L
.392 .31929 L
.396 .31982 L
.4 .31986 L
Mistroke
.404 .31941 L
.408 .31878 L
.412 .31836 L
.416 .3183 L
.42 .31855 L
.424 .31898 L
.428 .31945 L
.432 .31976 L
.436 .31968 L
.44 .31915 L
.444 .31842 L
.448 .31788 L
.452 .31776 L
.456 .31795 L
.46 .31815 L
.464 .31805 L
.468 .31757 L
.472 .31671 L
.476 .31547 L
.48 .31386 L
.484 .31196 L
.488 .30994 L
.492 .30786 L
.496 .30549 L
.5 .30245 L
.504 .2984 L
.508 .2933 L
.512 .28738 L
.516 .28083 L
.52 .27368 L
.524 .26585 L
.528 .25739 L
.532 .24858 L
.536 .23976 L
.54 .23112 L
.544 .22268 L
.548 .21459 L
.552 .2073 L
.556 .2015 L
.56 .19772 L
.564 .19602 L
.568 .19619 L
.572 .1981 L
.576 .20187 L
.58 .20757 L
.584 .21475 L
.588 .22234 L
.592 .22913 L
.596 .2344 L
.6 .23808 L
Mistroke
.604 .24026 L
.608 .24068 L
.612 .23887 L
.616 .2348 L
.62 .22934 L
.624 .22395 L
.628 .21976 L
.632 .21699 L
.636 .21532 L
.64 .21483 L
.644 .21632 L
.648 .2207 L
.652 .22783 L
.656 .23621 L
.66 .24381 L
.664 .24944 L
.668 .25336 L
.672 .25648 L
.676 .25924 L
.68 .26134 L
.684 .2626 L
.688 .26412 L
.692 .26812 L
.696 .27645 L
.7 .28889 L
.704 .30298 L
.708 .31551 L
.712 .32451 L
.716 .32992 L
.72 .33263 L
.724 .33294 L
.728 .33019 L
.732 .32391 L
.736 .31524 L
.74 .30703 L
.744 .30216 L
.748 .3015 L
.752 .30324 L
.756 .30439 L
.76 .30317 L
.764 .30028 L
.768 .29812 L
.772 .29874 L
.776 .30224 L
.78 .30704 L
.784 .31151 L
.788 .31519 L
.792 .31876 L
.796 .32258 L
.8 .32556 L
Mistroke
.804 .32553 L
.808 .32081 L
.812 .31217 L
.816 .30278 L
.82 .29687 L
.824 .2972 L
.828 .30348 L
.832 .31294 L
.836 .32172 L
.84 .3272 L
.844 .32871 L
.848 .32714 L
.852 .32422 L
.856 .32108 L
.86 .31851 L
.864 .31682 L
.868 .31605 L
.872 .31644 L
.876 .31776 L
.88 .31984 L
.884 .32225 L
.888 .32445 L
.892 .32596 L
.896 .32615 L
.9 .32456 L
.904 .32123 L
.908 .31707 L
.912 .31362 L
.916 .31274 L
.92 .31515 L
.924 .31982 L
.928 .32472 L
.932 .32675 L
.936 .32486 L
.94 .32013 L
.944 .31473 L
.948 .31263 L
.952 .31449 L
.956 .31925 L
.96 .32471 L
.964 .32625 L
.968 .32417 L
.972 .31938 L
.976 .31417 L
.98 .31371 L
.984 .31644 L
.988 .32174 L
.992 .32717 L
.996 .32683 L
1 .32351 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15679 m
.008 .15408 L
.012 .15315 L
.016 .1541 L
.02 .15438 L
.024 .15409 L
.028 .15397 L
.032 .15408 L
.036 .15411 L
.04 .15409 L
.044 .15406 L
.048 .15409 L
.052 .15408 L
.056 .15408 L
.06 .15407 L
.064 .15408 L
.068 .15408 L
.072 .15409 L
.076 .15408 L
.08 .15409 L
.084 .15408 L
.088 .15408 L
.092 .15407 L
.096 .15408 L
.1 .15408 L
.104 .15409 L
.108 .15408 L
.112 .15408 L
.116 .15408 L
.12 .15408 L
.124 .15408 L
.128 .15408 L
.132 .15408 L
.136 .15409 L
.14 .15408 L
.144 .15408 L
.148 .15408 L
.152 .15408 L
.156 .15408 L
.16 .15408 L
.164 .15408 L
.168 .15409 L
.172 .15409 L
.176 .15409 L
.18 .15408 L
.184 .15408 L
.188 .15408 L
.192 .15408 L
.196 .15409 L
.2 .15409 L
Mistroke
.204 .15409 L
.208 .15409 L
.212 .15408 L
.216 .15408 L
.22 .15408 L
.224 .15409 L
.228 .15409 L
.232 .15409 L
.236 .15409 L
.24 .15408 L
.244 .15408 L
.248 .15408 L
.252 .15408 L
.256 .15409 L
.26 .15409 L
.264 .15409 L
.268 .15409 L
.272 .15408 L
.276 .15408 L
.28 .15408 L
.284 .15409 L
.288 .15409 L
.292 .15409 L
.296 .15409 L
.3 .15409 L
.304 .15409 L
.308 .15408 L
.312 .15408 L
.316 .15409 L
.32 .15409 L
.324 .15409 L
.328 .1541 L
.332 .1541 L
.336 .15409 L
.34 .15409 L
.344 .15409 L
.348 .15409 L
.352 .15409 L
.356 .1541 L
.36 .1541 L
.364 .15409 L
.368 .15409 L
.372 .15409 L
.376 .15409 L
.38 .15409 L
.384 .15409 L
.388 .15409 L
.392 .1541 L
.396 .1541 L
.4 .1541 L
Mistroke
.404 .1541 L
.408 .1541 L
.412 .1541 L
.416 .1541 L
.42 .1541 L
.424 .1541 L
.428 .1541 L
.432 .15411 L
.436 .15411 L
.44 .15412 L
.444 .15412 L
.448 .15413 L
.452 .15414 L
.456 .15415 L
.46 .15417 L
.464 .1542 L
.468 .15425 L
.472 .15431 L
.476 .15438 L
.48 .15448 L
.484 .15459 L
.488 .15474 L
.492 .15494 L
.496 .15519 L
.5 .1555 L
.504 .1559 L
.508 .15639 L
.512 .15699 L
.516 .1577 L
.52 .15854 L
.524 .15952 L
.528 .16066 L
.532 .16198 L
.536 .16349 L
.54 .16517 L
.544 .16704 L
.548 .16907 L
.552 .17125 L
.556 .17356 L
.56 .17596 L
.564 .17841 L
.568 .18088 L
.572 .18333 L
.576 .18574 L
.58 .18807 L
.584 .1903 L
.588 .1924 L
.592 .19438 L
.596 .19625 L
.6 .19802 L
Mistroke
.604 .19973 L
.608 .20141 L
.612 .2031 L
.616 .20486 L
.62 .20673 L
.624 .20873 L
.628 .21085 L
.632 .21307 L
.636 .21533 L
.64 .21762 L
.644 .21989 L
.648 .22209 L
.652 .22418 L
.656 .22615 L
.66 .22802 L
.664 .22981 L
.668 .23156 L
.672 .23329 L
.676 .23498 L
.68 .23662 L
.684 .23821 L
.688 .23974 L
.692 .24119 L
.696 .24252 L
.7 .24367 L
.704 .24462 L
.708 .24538 L
.712 .24598 L
.716 .24648 L
.72 .24688 L
.724 .24723 L
.728 .24754 L
.732 .24789 L
.736 .24833 L
.74 .2489 L
.744 .2496 L
.748 .2504 L
.752 .25125 L
.756 .25212 L
.76 .25302 L
.764 .25393 L
.768 .25483 L
.772 .25567 L
.776 .25639 L
.78 .25697 L
.784 .25743 L
.788 .25781 L
.792 .25816 L
.796 .2585 L
.8 .25886 L
Mistroke
.804 .25925 L
.808 .25972 L
.812 .2603 L
.816 .261 L
.82 .26177 L
.824 .26252 L
.828 .26314 L
.832 .26354 L
.836 .26371 L
.84 .2637 L
.844 .26359 L
.848 .26346 L
.852 .26336 L
.856 .26328 L
.86 .26323 L
.864 .2632 L
.868 .26316 L
.872 .26311 L
.876 .26303 L
.88 .26291 L
.884 .26273 L
.888 .2625 L
.892 .26222 L
.896 .26192 L
.9 .26165 L
.904 .26146 L
.908 .2614 L
.912 .26144 L
.916 .26157 L
.92 .26171 L
.924 .26183 L
.928 .2619 L
.932 .26193 L
.936 .26198 L
.94 .26208 L
.944 .26221 L
.948 .26235 L
.952 .26239 L
.956 .26231 L
.96 .26208 L
.964 .26177 L
.968 .26149 L
.972 .2613 L
.976 .26126 L
.98 .26135 L
.984 .26147 L
.988 .26163 L
.992 .2617 L
.996 .26177 L
1 .26185 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .1609 L
.012 .16113 L
.016 .16126 L
.02 .16128 L
.024 .16118 L
.028 .16118 L
.032 .1612 L
.036 .16123 L
.04 .1612 L
.044 .1612 L
.048 .16119 L
.052 .16121 L
.056 .1612 L
.06 .16121 L
.064 .16119 L
.068 .1612 L
.072 .16119 L
.076 .1612 L
.08 .16119 L
.084 .1612 L
.088 .1612 L
.092 .1612 L
.096 .16119 L
.1 .16119 L
.104 .16119 L
.108 .1612 L
.112 .1612 L
.116 .1612 L
.12 .16119 L
.124 .16119 L
.128 .16118 L
.132 .16119 L
.136 .16119 L
.14 .1612 L
.144 .16119 L
.148 .16119 L
.152 .16118 L
.156 .16118 L
.16 .16118 L
.164 .16119 L
.168 .16119 L
.172 .16119 L
.176 .16118 L
.18 .16118 L
.184 .16117 L
.188 .16118 L
.192 .16118 L
.196 .16119 L
.2 .16119 L
Mistroke
.204 .16118 L
.208 .16117 L
.212 .16117 L
.216 .16117 L
.22 .16117 L
.224 .16118 L
.228 .16118 L
.232 .16118 L
.236 .16118 L
.24 .16117 L
.244 .16117 L
.248 .16116 L
.252 .16117 L
.256 .16117 L
.26 .16118 L
.264 .16118 L
.268 .16117 L
.272 .16117 L
.276 .16116 L
.28 .16116 L
.284 .16116 L
.288 .16117 L
.292 .16117 L
.296 .16117 L
.3 .16117 L
.304 .16116 L
.308 .16115 L
.312 .16115 L
.316 .16116 L
.32 .16116 L
.324 .16117 L
.328 .16116 L
.332 .16116 L
.336 .16116 L
.34 .16115 L
.344 .16115 L
.348 .16115 L
.352 .16116 L
.356 .16116 L
.36 .16116 L
.364 .16116 L
.368 .16115 L
.372 .16115 L
.376 .16115 L
.38 .16115 L
.384 .16115 L
.388 .16115 L
.392 .16115 L
.396 .16115 L
.4 .16115 L
Mistroke
.404 .16115 L
.408 .16115 L
.412 .16115 L
.416 .16114 L
.42 .16114 L
.424 .16113 L
.428 .16113 L
.432 .16113 L
.436 .16113 L
.44 .16113 L
.444 .16112 L
.448 .16111 L
.452 .16109 L
.456 .16106 L
.46 .16103 L
.464 .16099 L
.468 .16095 L
.472 .16089 L
.476 .16081 L
.48 .16069 L
.484 .16054 L
.488 .16034 L
.492 .16008 L
.496 .15976 L
.5 .15937 L
.504 .15888 L
.508 .15829 L
.512 .15757 L
.516 .15669 L
.52 .15564 L
.524 .15439 L
.528 .15294 L
.532 .15128 L
.536 .14941 L
.54 .14731 L
.544 .14499 L
.548 .14248 L
.552 .13978 L
.556 .13692 L
.56 .13393 L
.564 .13084 L
.568 .12773 L
.572 .12463 L
.576 .12161 L
.58 .11871 L
.584 .11595 L
.588 .11335 L
.592 .11089 L
.596 .10858 L
.6 .10638 L
Mistroke
.604 .10424 L
.608 .1021 L
.612 .09991 L
.616 .09765 L
.62 .09531 L
.624 .09284 L
.628 .09025 L
.632 .08754 L
.636 .08472 L
.64 .08187 L
.644 .07903 L
.648 .07625 L
.652 .07356 L
.656 .071 L
.66 .06858 L
.664 .06632 L
.668 .0642 L
.672 .06218 L
.676 .06017 L
.68 .05815 L
.684 .05612 L
.688 .05411 L
.692 .05221 L
.696 .05047 L
.7 .04893 L
.704 .04765 L
.708 .04665 L
.712 .04596 L
.716 .04551 L
.72 .0452 L
.724 .04488 L
.728 .04444 L
.732 .04383 L
.736 .04306 L
.74 .04218 L
.744 .04121 L
.748 .04019 L
.752 .03914 L
.756 .03808 L
.76 .03706 L
.764 .03609 L
.768 .03517 L
.772 .03423 L
.776 .03327 L
.78 .0323 L
.784 .03139 L
.788 .03065 L
.792 .03011 L
.796 .02973 L
.8 .02942 L
Mistroke
.804 .02906 L
.808 .02857 L
.812 .02793 L
.816 .02714 L
.82 .02626 L
.824 .02536 L
.828 .02449 L
.832 .02376 L
.836 .02323 L
.84 .02297 L
.844 .02298 L
.848 .02319 L
.852 .0235 L
.856 .02378 L
.86 .02397 L
.864 .02406 L
.868 .0241 L
.872 .02415 L
.876 .02426 L
.88 .02445 L
.884 .02467 L
.888 .02489 L
.892 .02505 L
.896 .02513 L
.9 .02517 L
.904 .0252 L
.908 .02524 L
.912 .02531 L
.916 .02538 L
.92 .02542 L
.924 .02542 L
.928 .02538 L
.932 .02537 L
.936 .0254 L
.94 .02546 L
.944 .02549 L
.948 .02542 L
.952 .02513 L
.956 .02469 L
.96 .02418 L
.964 .02378 L
.968 .02368 L
.972 .02389 L
.976 .02439 L
.98 .02499 L
.984 .02547 L
.988 .02578 L
.992 .02584 L
.996 .02584 L
1 .02587 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0=7oo00<007ooOol0=Goo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool2000dOol3000fOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo
10000Woo0`000Woo10000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool5
0002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001o
ogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool20002Ool20002Ool40002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002
Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo0P0017oo00D007oo
000007oo00800003Ool007oo00=oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`04Ool20002Ool200000goo001oo`04
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oo`000002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`03001oogoo00800003Ool007oo
009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`0000=oo`03001oo`0000Ioo`04
001oogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Eoo`80
00=oo`D000=oo`80009oo`03001oo`00008000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Io
o`008Woo00<007ooOol0;goo00<007ooOol03goo00<007ooOol0:7oo000ROol2000_Ool2000AOol0
0`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0LOol0029oof<000aoo`008Woo:P0000=oo`00
000010000Woo00D007ooOomoo`0000=oo`04001oogoo0003Ool00`00Oomoo`02000017oo001oo`00
0Woo0`0000Aoo`00001oo`<0009oo`800003Ool0000000<00003Ool007oo00]oo`008Woo0P006goo
00<007ooOol00P0000=oo`0000000Woo0P0000=oo`0000006Woo0P001Woo0P000Woo0`0000Eoo`00
000007oo00<00003Ool0000000<000aoo`008Woo00<007ooOol0@goo0P009goo000ROol2001]Ool0
029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]
Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007oo
Ool00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol0
00Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00
KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000
Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo0080
06eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P00
2Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo
000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0
009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo
06Ioo`00:7oo<@00>7oo000XOol00`00Oomoo`0]Ool4000eOol000]oo`8000Aoo`03001oogoo00=o
o`8000Aoo`8000=oo`<000=oo`03001oogoo031oo`8003Aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000cOol3000bOol000=oo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000eOol3000`Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`80
00Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`H00003Ool00000009oo`D000=oo`8000Aoo`8000=o
o`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00
Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool00`00Ool0000200001Goo
001oogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo
00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo00@000=o
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007ooOol01Goo00@007ooOol0009oo`H000=oo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@0
07ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@0
00=oo`06001oogoo001oo`000Woo20000Woo00@007ooOol0009oo`06001oogooOol007oo10000goo
00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Ao
o`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003
Ool01@00Oomoo`00Ool050000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P00
27oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Ao
o`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol0
3goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P00
17oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Ao
o`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04
001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0
KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<0
07ooOol00P00Dgoo500037oo000:Ool01000Oomoo`002goo00@007ooOol004ioo`H0021oo`002Woo
00@007ooOol000Moo`@000=oo`03001oogoo04Ioo`H002Ioo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`8004Eoo`<002]oo`002goo0P0027oo1@000Woo00<007ooOol0@Woo0P00;Woo000LOol0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002
Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomo
ogoo00000goo00<007ooOol00P0000=oo`00Ool017oo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol0
0`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool00`00Oomoo`05Ool40002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool0
01aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`800005Ool007ooOol00007Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00
Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009o
o`04001oogoo0004Ool20003Ool30004Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2
000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool00`00Oomoo`060003Ool20006
Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo03Ioo`8003Yo
o`0077oo00<007ooOol0=7oo0P00?7oo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol0
0`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol000]oo`8000Ao
o`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001o
ogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1b
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<007oo
Ool0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`00
5goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Io
o`8000Aoo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo
00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001d
Ool000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<0
07ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Mo
o`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(20708\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31884 m
.008 .31829 L
.012 .31774 L
.016 .31775 L
.02 .31826 L
.024 .31831 L
.028 .31795 L
.032 .31782 L
.036 .31801 L
.04 .31817 L
.044 .31821 L
.048 .31821 L
.052 .31815 L
.056 .31806 L
.06 .31802 L
.064 .31806 L
.068 .31818 L
.072 .31828 L
.076 .31829 L
.08 .31823 L
.084 .31814 L
.088 .3181 L
.092 .31815 L
.096 .31824 L
.1 .31831 L
.104 .31833 L
.108 .3183 L
.112 .31825 L
.116 .31822 L
.12 .31824 L
.124 .31828 L
.128 .31833 L
.132 .31835 L
.136 .31837 L
.14 .31837 L
.144 .31837 L
.148 .31835 L
.152 .31831 L
.156 .3183 L
.16 .31834 L
.164 .31842 L
.168 .31851 L
.172 .31855 L
.176 .31849 L
.18 .31837 L
.184 .31826 L
.188 .31829 L
.192 .31845 L
.196 .31864 L
.2 .31874 L
Mistroke
.204 .31866 L
.208 .31847 L
.212 .31828 L
.216 .31823 L
.22 .31839 L
.224 .31868 L
.228 .31889 L
.232 .31888 L
.236 .31865 L
.24 .31837 L
.244 .31823 L
.248 .31833 L
.252 .31859 L
.256 .31888 L
.26 .31903 L
.264 .31895 L
.268 .31867 L
.272 .31836 L
.276 .31824 L
.28 .31839 L
.284 .31872 L
.288 .31904 L
.292 .31916 L
.296 .31906 L
.3 .31876 L
.304 .31841 L
.308 .31821 L
.312 .31834 L
.316 .31877 L
.32 .31924 L
.324 .31943 L
.328 .31923 L
.332 .31879 L
.336 .31837 L
.34 .31821 L
.344 .31837 L
.348 .31881 L
.352 .31933 L
.356 .31961 L
.36 .31946 L
.364 .31893 L
.368 .31839 L
.372 .31817 L
.376 .31838 L
.38 .31885 L
.384 .31932 L
.388 .3196 L
.392 .31958 L
.396 .31921 L
.4 .31863 L
Mistroke
.404 .31813 L
.408 .31804 L
.412 .31842 L
.416 .31899 L
.42 .31933 L
.424 .31919 L
.428 .3186 L
.432 .31779 L
.436 .31696 L
.44 .31621 L
.444 .31563 L
.448 .31517 L
.452 .31461 L
.456 .31354 L
.46 .31164 L
.464 .30887 L
.468 .30549 L
.472 .30179 L
.476 .29783 L
.48 .29344 L
.484 .28837 L
.488 .2825 L
.492 .27575 L
.496 .26806 L
.5 .25945 L
.504 .25014 L
.508 .2406 L
.512 .23136 L
.516 .22277 L
.52 .21494 L
.524 .20789 L
.528 .2018 L
.532 .19714 L
.536 .19436 L
.54 .19368 L
.544 .19503 L
.548 .19824 L
.552 .20315 L
.556 .20955 L
.56 .21691 L
.564 .22433 L
.568 .23079 L
.572 .23559 L
.576 .2385 L
.58 .23952 L
.584 .23858 L
.588 .23554 L
.592 .23059 L
.596 .22462 L
.6 .21899 L
Mistroke
.604 .21488 L
.608 .21279 L
.612 .21265 L
.616 .21437 L
.62 .21809 L
.624 .22394 L
.628 .23134 L
.632 .23899 L
.636 .24546 L
.64 .25016 L
.644 .25356 L
.648 .25649 L
.652 .25936 L
.656 .26204 L
.66 .2646 L
.664 .26804 L
.668 .27395 L
.672 .28326 L
.676 .29526 L
.68 .30777 L
.684 .31855 L
.688 .32648 L
.692 .33154 L
.696 .33387 L
.7 .33301 L
.704 .32828 L
.708 .32014 L
.712 .31079 L
.716 .30328 L
.72 .29958 L
.724 .29931 L
.728 .30033 L
.732 .30061 L
.736 .29985 L
.74 .29933 L
.744 .30039 L
.748 .30304 L
.752 .30613 L
.756 .30866 L
.76 .31098 L
.764 .31433 L
.768 .31926 L
.772 .32429 L
.776 .32646 L
.78 .32344 L
.784 .31556 L
.788 .30611 L
.792 .29934 L
.796 .29796 L
.8 .30178 L
Mistroke
.804 .30832 L
.808 .31507 L
.812 .3206 L
.816 .32486 L
.82 .32797 L
.824 .32927 L
.828 .32788 L
.832 .32351 L
.836 .31762 L
.84 .3129 L
.844 .31164 L
.848 .31449 L
.852 .31973 L
.856 .3246 L
.86 .32691 L
.864 .32616 L
.868 .32364 L
.872 .32109 L
.876 .31967 L
.88 .31937 L
.884 .31942 L
.888 .319 L
.892 .31801 L
.896 .31701 L
.9 .31672 L
.904 .31785 L
.908 .32 L
.912 .32242 L
.916 .32396 L
.92 .32319 L
.924 .32044 L
.928 .31635 L
.932 .31292 L
.936 .3128 L
.94 .31597 L
.944 .32213 L
.948 .32809 L
.952 .32983 L
.956 .32701 L
.96 .31946 L
.964 .31167 L
.968 .30879 L
.972 .31135 L
.976 .32003 L
.98 .32912 L
.984 .33257 L
.988 .32999 L
.992 .32016 L
.996 .30976 L
1 .3056 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15513 m
.008 .15451 L
.012 .15422 L
.016 .15438 L
.02 .15448 L
.024 .15448 L
.028 .15441 L
.032 .15442 L
.036 .15443 L
.04 .15445 L
.044 .15443 L
.048 .15444 L
.052 .15443 L
.056 .15444 L
.06 .15443 L
.064 .15443 L
.068 .15443 L
.072 .15444 L
.076 .15443 L
.08 .15444 L
.084 .15443 L
.088 .15443 L
.092 .15443 L
.096 .15443 L
.1 .15443 L
.104 .15444 L
.108 .15443 L
.112 .15443 L
.116 .15443 L
.12 .15443 L
.124 .15443 L
.128 .15444 L
.132 .15444 L
.136 .15444 L
.14 .15443 L
.144 .15443 L
.148 .15443 L
.152 .15443 L
.156 .15444 L
.16 .15444 L
.164 .15444 L
.168 .15444 L
.172 .15443 L
.176 .15443 L
.18 .15443 L
.184 .15444 L
.188 .15444 L
.192 .15444 L
.196 .15444 L
.2 .15444 L
Mistroke
.204 .15443 L
.208 .15443 L
.212 .15443 L
.216 .15444 L
.22 .15444 L
.224 .15444 L
.228 .15444 L
.232 .15444 L
.236 .15443 L
.24 .15443 L
.244 .15443 L
.248 .15444 L
.252 .15444 L
.256 .15445 L
.26 .15444 L
.264 .15444 L
.268 .15443 L
.272 .15443 L
.276 .15444 L
.28 .15444 L
.284 .15445 L
.288 .15445 L
.292 .15444 L
.296 .15444 L
.3 .15443 L
.304 .15444 L
.308 .15444 L
.312 .15444 L
.316 .15445 L
.32 .15445 L
.324 .15444 L
.328 .15444 L
.332 .15444 L
.336 .15444 L
.34 .15444 L
.344 .15444 L
.348 .15445 L
.352 .15445 L
.356 .15445 L
.36 .15445 L
.364 .15444 L
.368 .15444 L
.372 .15444 L
.376 .15445 L
.38 .15445 L
.384 .15445 L
.388 .15445 L
.392 .15445 L
.396 .15445 L
.4 .15445 L
Mistroke
.404 .15445 L
.408 .15446 L
.412 .15446 L
.416 .15447 L
.42 .15448 L
.424 .15449 L
.428 .15451 L
.432 .15453 L
.436 .15455 L
.44 .15459 L
.444 .15464 L
.448 .1547 L
.452 .15479 L
.456 .15491 L
.46 .15506 L
.464 .15525 L
.468 .15549 L
.472 .15579 L
.476 .15616 L
.48 .15661 L
.484 .15716 L
.488 .15783 L
.492 .15864 L
.496 .15959 L
.5 .1607 L
.504 .16197 L
.508 .16342 L
.512 .16504 L
.516 .16684 L
.52 .1688 L
.524 .17092 L
.528 .17318 L
.532 .17556 L
.536 .17801 L
.54 .18049 L
.544 .18296 L
.548 .18538 L
.552 .18773 L
.556 .18999 L
.56 .19212 L
.564 .19414 L
.568 .19604 L
.572 .19784 L
.576 .19959 L
.58 .20129 L
.584 .20299 L
.588 .20473 L
.592 .20655 L
.596 .20847 L
.6 .21051 L
Mistroke
.604 .21266 L
.608 .2149 L
.612 .21718 L
.616 .21946 L
.62 .22172 L
.624 .22389 L
.628 .22594 L
.632 .22786 L
.636 .22967 L
.64 .23139 L
.644 .23306 L
.648 .2347 L
.652 .23633 L
.656 .23794 L
.66 .23951 L
.664 .24102 L
.668 .24243 L
.672 .24367 L
.676 .2447 L
.68 .24551 L
.684 .24612 L
.688 .2466 L
.692 .24698 L
.696 .24732 L
.7 .24766 L
.704 .24804 L
.708 .2485 L
.712 .24906 L
.716 .24974 L
.72 .25049 L
.724 .25127 L
.728 .25208 L
.732 .25292 L
.736 .2538 L
.74 .25469 L
.744 .25557 L
.748 .25636 L
.752 .25705 L
.756 .25761 L
.76 .25808 L
.764 .25846 L
.768 .25878 L
.772 .25906 L
.776 .25935 L
.78 .25972 L
.784 .26024 L
.788 .26091 L
.792 .2617 L
.796 .26248 L
.8 .26316 L
Mistroke
.804 .26364 L
.808 .26392 L
.812 .26401 L
.816 .26397 L
.82 .26385 L
.824 .26369 L
.828 .26353 L
.832 .26341 L
.836 .26336 L
.84 .26336 L
.844 .26339 L
.848 .26336 L
.852 .26322 L
.856 .26298 L
.86 .26266 L
.864 .26234 L
.868 .26209 L
.872 .26192 L
.876 .26185 L
.88 .26184 L
.884 .26186 L
.888 .2619 L
.892 .26196 L
.896 .26202 L
.9 .2621 L
.904 .26217 L
.908 .26222 L
.912 .26222 L
.916 .26218 L
.92 .26213 L
.924 .26211 L
.928 .26213 L
.932 .26222 L
.936 .26231 L
.94 .26235 L
.944 .2623 L
.948 .26214 L
.952 .26194 L
.956 .26177 L
.96 .2617 L
.964 .26179 L
.968 .26193 L
.972 .26205 L
.976 .26205 L
.98 .26186 L
.984 .26155 L
.988 .26126 L
.992 .26107 L
.996 .26112 L
1 .26131 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16313 L
.012 .16121 L
.016 .16054 L
.02 .16123 L
.024 .16141 L
.028 .16121 L
.032 .16112 L
.036 .16122 L
.04 .16123 L
.044 .16121 L
.048 .16118 L
.052 .1612 L
.056 .16119 L
.06 .1612 L
.064 .1612 L
.068 .16121 L
.072 .1612 L
.076 .1612 L
.08 .16119 L
.084 .1612 L
.088 .16119 L
.092 .1612 L
.096 .16119 L
.1 .1612 L
.104 .16119 L
.108 .16119 L
.112 .16119 L
.116 .16119 L
.12 .16119 L
.124 .16119 L
.128 .16119 L
.132 .16119 L
.136 .16119 L
.14 .16119 L
.144 .16119 L
.148 .16118 L
.152 .16118 L
.156 .16118 L
.16 .16118 L
.164 .16119 L
.168 .16119 L
.172 .16118 L
.176 .16118 L
.18 .16117 L
.184 .16117 L
.188 .16118 L
.192 .16118 L
.196 .16119 L
.2 .16118 L
Mistroke
.204 .16117 L
.208 .16117 L
.212 .16117 L
.216 .16117 L
.22 .16118 L
.224 .16118 L
.228 .16118 L
.232 .16117 L
.236 .16116 L
.24 .16116 L
.244 .16117 L
.248 .16117 L
.252 .16118 L
.256 .16118 L
.26 .16117 L
.264 .16116 L
.268 .16116 L
.272 .16116 L
.276 .16116 L
.28 .16117 L
.284 .16117 L
.288 .16117 L
.292 .16117 L
.296 .16116 L
.3 .16116 L
.304 .16115 L
.308 .16115 L
.312 .16116 L
.316 .16117 L
.32 .16117 L
.324 .16116 L
.328 .16115 L
.332 .16115 L
.336 .16115 L
.34 .16115 L
.344 .16116 L
.348 .16116 L
.352 .16116 L
.356 .16115 L
.36 .16115 L
.364 .16115 L
.368 .16115 L
.372 .16115 L
.376 .16115 L
.38 .16115 L
.384 .16115 L
.388 .16115 L
.392 .16115 L
.396 .16114 L
.4 .16114 L
Mistroke
.404 .16113 L
.408 .16113 L
.412 .16113 L
.416 .16112 L
.42 .16111 L
.424 .16109 L
.428 .16108 L
.432 .16105 L
.436 .16102 L
.44 .16097 L
.444 .1609 L
.448 .16081 L
.452 .16071 L
.456 .16057 L
.46 .16039 L
.464 .16015 L
.468 .15986 L
.472 .15949 L
.476 .15902 L
.48 .15844 L
.484 .15774 L
.488 .1569 L
.492 .15591 L
.496 .15474 L
.5 .15336 L
.504 .15178 L
.508 .14998 L
.512 .14794 L
.516 .14569 L
.52 .14322 L
.524 .14057 L
.528 .13775 L
.532 .13481 L
.536 .13178 L
.54 .1287 L
.544 .12561 L
.548 .12256 L
.552 .11961 L
.556 .11678 L
.56 .1141 L
.564 .11157 L
.568 .1092 L
.572 .10696 L
.576 .10482 L
.58 .10271 L
.584 .10058 L
.588 .09837 L
.592 .09606 L
.596 .09363 L
.6 .09107 L
Mistroke
.604 .08838 L
.608 .0856 L
.612 .08276 L
.616 .07992 L
.62 .07714 L
.624 .07445 L
.628 .07187 L
.632 .06941 L
.636 .06708 L
.64 .06487 L
.644 .06276 L
.648 .06073 L
.652 .05873 L
.656 .05675 L
.66 .05481 L
.664 .05294 L
.668 .0512 L
.672 .04962 L
.676 .04824 L
.68 .04709 L
.684 .04621 L
.688 .04559 L
.692 .04517 L
.696 .04486 L
.7 .04452 L
.704 .04408 L
.708 .04348 L
.712 .04273 L
.716 .04182 L
.72 .04079 L
.724 .03966 L
.728 .03851 L
.732 .03739 L
.736 .03636 L
.74 .03542 L
.744 .03453 L
.748 .03365 L
.752 .03276 L
.756 .03191 L
.76 .03115 L
.764 .03052 L
.768 .03002 L
.772 .02958 L
.776 .02915 L
.78 .02868 L
.784 .02813 L
.788 .02749 L
.792 .02675 L
.796 .02591 L
.8 .02502 L
Mistroke
.804 .02418 L
.808 .02353 L
.812 .02315 L
.816 .02307 L
.82 .02323 L
.824 .02351 L
.828 .02379 L
.832 .02401 L
.836 .02417 L
.84 .02429 L
.844 .02441 L
.848 .02451 L
.852 .02459 L
.856 .02467 L
.86 .02475 L
.864 .02487 L
.868 .02505 L
.872 .02526 L
.876 .02548 L
.88 .02565 L
.884 .02574 L
.888 .02574 L
.892 .02568 L
.896 .02561 L
.9 .02555 L
.904 .02553 L
.908 .02551 L
.912 .02546 L
.916 .02533 L
.92 .02511 L
.924 .02483 L
.928 .02455 L
.932 .02438 L
.936 .02435 L
.94 .02448 L
.944 .02474 L
.948 .02504 L
.952 .02534 L
.956 .02559 L
.96 .02577 L
.964 .02594 L
.968 .02603 L
.972 .02605 L
.976 .02594 L
.98 .02566 L
.984 .02525 L
.988 .02482 L
.992 .02443 L
.996 .0243 L
1 .02433 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0<Goo0P00>Goo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool2000bOol00`00Ool0000hOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo
10000Woo10000goo0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool5
0002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001o
ogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool00`00Ool00002Ool200000goo0000000200001Goo001oogoo00000goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`0017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007oo
Ool00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001o
ogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03
001oo`00009oo`@00005Ool00000Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000goo
0P000Woo00@007oo0000009oo`03001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`000Woo
00<007ooOol017oo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;Ool40003Ool01000Oomoo`001goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo10000Woo0P000Woo
00@007ooOol000=oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`0000=oo`03001o
o`0000<000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`8000aoo`03
001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
o`000003Ool00`00Oomoo`04Ool200001Goo001oogoo00000goo00@007ooOol0009oo`04001oogoo
0002Ool01@00Oomoogoo00000goo00<007oo00001Woo00@007ooOol000Eoo`008Woo0P0037oo1@00
0goo0P0027oo00<007ooOol00goo0P0017oo0P000Woo00D007ooOomoo`0000=oo`D000=oo`8000Ao
o`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol0;7oo0P004Goo
00<007ooOol0:Woo000ROol2000]Ool00`00Oomoo`0@Ool00`00Oomoo`09Ool00`00Oomoo`0NOol0
029oof<000aoo`008Woo9P0000=oo`0000001@0000=oo`00Ool00Woo00D007ooOomoo`0000=oo`04
001oogoo0003Ool20002Ool01000Oomoogoo0P0000Aoo`000000009oo`80009oo`<00005Ool00000
001oo`0200000goo0000000<Ool0029oo`8001ioo`04001oo`000002Ool01000Oomoo`006Goo00<0
07oo00001Goo0P000Woo0`0000=oo`0000000P000Woo0P0000=oo`00000010003Goo000ROol00`00
Oomoo`11Ool00`00Oomoo`0FOol01000Oomoo`003Woo000ROol2001]Ool0029oo`8006eoo`002goo
0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
06eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`80
00Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@00
0Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool0
1P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001o
o`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomo
o`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol0
00Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007oo
Ool000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo
0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo
0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol0
0003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eo
o`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000
0goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo
00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P00
17oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00
Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo;P00>goo
000XOol00`00Oomoo`0[Ool3000hOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<0
00=oo`03001oogoo02eoo`8003Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000=oo`04001oogoo000aOol2000eOol000=oo`D0009oo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogoo000cOol3000bOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Ao
o`8000=oo`<000=oo`@000=oo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Io
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0
2Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`05001oogooOol00003Ool40002Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo
00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000=oo`03001oogoo00Eoo`03001oo`0000800003Ool007oo009oo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`00
2goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo
00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00<007oo
Ool01P000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`00
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00D0
07ooOol007oo00P0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@0
07ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04
001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool0
0`00Oomoo`0F0003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00
Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo
0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@00
37oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00
Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00
Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00D007ooOol007oo00@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo
1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P00
17oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1V
Ool0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05
001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomo
o`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]o
o`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
00]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02
001@OolG000<Ool000Yoo`04001oogoo000;Ool01000Oomoo`00Bgoo1P008goo000:Ool01000Oomo
o`001goo10000goo00<007ooOol0@goo1P00:Goo000:Ool01000Oomoo`001goo00<007ooOol017oo
0P00@Woo0`00;Woo000;Ool20008Ool50002Ool00`00Oomoo`0oOol3000`Ool001aoo`03001oogoo
00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<0009oo`@000Eoo`D000=oo`80
00Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001o
ogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003
Ool200001Goo001oogoo00001Goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo
00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool0
1000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`04Ool20002Ool01000Oomoo`001Woo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomo
o`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool00`00Oomoo`02Ool200001Goo001oogoo00000Woo00<007ooOol01Goo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`050003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009o
o`04001oogoo0004Ool2000017oo000000001Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`00
77oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo0P000Woo1@000goo0P00
1Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`0cOol2000m
Ool001aoo`03001oogoo035oo`<003ioo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000;Ool20004
Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000
Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Ioo`<000=oo`03001o
ogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol0
01Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000F
Ool20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomo
o`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00
M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03
001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07
Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(20875\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31816 m
.008 .31774 L
.012 .31793 L
.016 .31805 L
.02 .31806 L
.024 .31809 L
.028 .31805 L
.032 .31794 L
.036 .31794 L
.04 .31805 L
.044 .31815 L
.048 .31818 L
.052 .31813 L
.056 .31805 L
.06 .31801 L
.064 .31803 L
.068 .31812 L
.072 .31823 L
.076 .31826 L
.08 .3182 L
.084 .31811 L
.088 .31806 L
.092 .3181 L
.096 .31821 L
.1 .31831 L
.104 .31834 L
.108 .31827 L
.112 .31817 L
.116 .31811 L
.12 .31816 L
.124 .31828 L
.128 .31839 L
.132 .31841 L
.136 .31835 L
.14 .31825 L
.144 .31819 L
.148 .31822 L
.152 .31832 L
.156 .31843 L
.16 .31848 L
.164 .31845 L
.168 .31837 L
.172 .3183 L
.176 .31829 L
.18 .31834 L
.184 .31842 L
.188 .3185 L
.192 .31856 L
.196 .31854 L
.2 .31846 L
Mistroke
.204 .31836 L
.208 .31831 L
.212 .31837 L
.216 .3185 L
.22 .31864 L
.224 .31873 L
.228 .31868 L
.232 .31851 L
.236 .31832 L
.24 .31826 L
.244 .31842 L
.248 .31869 L
.252 .3189 L
.256 .3189 L
.26 .31871 L
.264 .31844 L
.268 .31826 L
.272 .3183 L
.276 .31856 L
.28 .31891 L
.284 .31911 L
.288 .31901 L
.292 .31869 L
.296 .31837 L
.3 .31826 L
.304 .31841 L
.308 .31872 L
.312 .31905 L
.316 .31923 L
.32 .31914 L
.324 .31879 L
.328 .31839 L
.332 .31821 L
.336 .31839 L
.34 .31881 L
.344 .31923 L
.348 .31939 L
.352 .31925 L
.356 .31888 L
.36 .31843 L
.364 .31816 L
.368 .31826 L
.372 .31873 L
.376 .31926 L
.38 .3195 L
.384 .31925 L
.388 .31866 L
.392 .31805 L
.396 .31767 L
.4 .31756 L
Mistroke
.404 .31765 L
.408 .31776 L
.412 .31764 L
.416 .31701 L
.42 .31574 L
.424 .31399 L
.428 .31212 L
.432 .31034 L
.436 .30858 L
.44 .30647 L
.444 .30363 L
.448 .29987 L
.452 .2951 L
.456 .28936 L
.46 .28278 L
.464 .2756 L
.468 .26811 L
.472 .26037 L
.476 .25223 L
.48 .24346 L
.484 .23409 L
.488 .22453 L
.492 .2154 L
.496 .20728 L
.5 .20059 L
.504 .19561 L
.508 .19259 L
.512 .19167 L
.516 .19277 L
.52 .19558 L
.524 .1998 L
.528 .20522 L
.532 .21169 L
.536 .21882 L
.54 .2259 L
.544 .23198 L
.548 .23624 L
.552 .23826 L
.556 .238 L
.56 .23563 L
.564 .23141 L
.568 .22586 L
.572 .21987 L
.576 .21461 L
.58 .21114 L
.584 .20996 L
.588 .21111 L
.592 .21437 L
.596 .21956 L
.6 .22641 L
Mistroke
.604 .23422 L
.608 .24181 L
.612 .24797 L
.616 .25222 L
.62 .25494 L
.624 .25705 L
.628 .25933 L
.632 .2622 L
.636 .26605 L
.64 .27161 L
.644 .27966 L
.648 .29029 L
.652 .30235 L
.656 .31384 L
.66 .32298 L
.664 .32901 L
.668 .33207 L
.672 .33234 L
.676 .32963 L
.68 .32383 L
.684 .31581 L
.688 .3076 L
.692 .30141 L
.696 .29827 L
.7 .29748 L
.704 .29749 L
.708 .29741 L
.712 .29762 L
.716 .29904 L
.72 .30193 L
.724 .30539 L
.728 .30832 L
.732 .31054 L
.736 .31306 L
.74 .31682 L
.744 .32126 L
.748 .32412 L
.752 .323 L
.756 .31746 L
.76 .30963 L
.764 .30301 L
.768 .30014 L
.772 .30132 L
.776 .30513 L
.78 .30998 L
.784 .31534 L
.788 .32119 L
.792 .32694 L
.796 .33081 L
.8 .33072 L
Mistroke
.804 .32621 L
.808 .31926 L
.812 .31349 L
.816 .31186 L
.82 .31463 L
.824 .31956 L
.828 .32342 L
.832 .32451 L
.836 .32341 L
.84 .32203 L
.844 .32192 L
.848 .32284 L
.852 .32329 L
.856 .32192 L
.86 .3188 L
.864 .31548 L
.868 .31393 L
.872 .31511 L
.876 .31831 L
.88 .32184 L
.884 .32378 L
.888 .32332 L
.892 .32098 L
.896 .3178 L
.9 .31551 L
.904 .31498 L
.908 .31642 L
.912 .31959 L
.916 .32268 L
.92 .32466 L
.924 .32449 L
.928 .32182 L
.932 .31878 L
.936 .31639 L
.94 .31622 L
.944 .31867 L
.948 .32108 L
.952 .32278 L
.956 .32211 L
.96 .31912 L
.964 .31719 L
.968 .31642 L
.972 .31815 L
.976 .32171 L
.98 .32291 L
.984 .32245 L
.988 .3196 L
.992 .31565 L
.996 .31563 L
1 .31792 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15218 m
.008 .15482 L
.012 .15565 L
.016 .15477 L
.02 .15447 L
.024 .1548 L
.028 .15488 L
.032 .15479 L
.036 .15474 L
.04 .15479 L
.044 .15479 L
.048 .15479 L
.052 .15477 L
.056 .15479 L
.06 .15478 L
.064 .15479 L
.068 .15478 L
.072 .15479 L
.076 .15478 L
.08 .15479 L
.084 .15478 L
.088 .15479 L
.092 .15478 L
.096 .15479 L
.1 .15478 L
.104 .15479 L
.108 .15478 L
.112 .15479 L
.116 .15478 L
.12 .15478 L
.124 .15478 L
.128 .15479 L
.132 .15479 L
.136 .15479 L
.14 .15478 L
.144 .15478 L
.148 .15478 L
.152 .15479 L
.156 .15479 L
.16 .15479 L
.164 .15479 L
.168 .15478 L
.172 .15478 L
.176 .15478 L
.18 .15479 L
.184 .15479 L
.188 .15479 L
.192 .15479 L
.196 .15478 L
.2 .15478 L
Mistroke
.204 .15478 L
.208 .15479 L
.212 .15479 L
.216 .15479 L
.22 .15479 L
.224 .15479 L
.228 .15478 L
.232 .15478 L
.236 .15479 L
.24 .15479 L
.244 .15479 L
.248 .15479 L
.252 .15479 L
.256 .15479 L
.26 .15479 L
.264 .15479 L
.268 .15479 L
.272 .15479 L
.276 .15479 L
.28 .1548 L
.284 .1548 L
.288 .15479 L
.292 .15479 L
.296 .15479 L
.3 .15479 L
.304 .15479 L
.308 .1548 L
.312 .1548 L
.316 .1548 L
.32 .15479 L
.324 .15479 L
.328 .15479 L
.332 .15479 L
.336 .1548 L
.34 .1548 L
.344 .1548 L
.348 .1548 L
.352 .15479 L
.356 .15479 L
.36 .15479 L
.364 .1548 L
.368 .1548 L
.372 .1548 L
.376 .15481 L
.38 .15481 L
.384 .15481 L
.388 .15481 L
.392 .15482 L
.396 .15483 L
.4 .15485 L
Mistroke
.404 .15487 L
.408 .1549 L
.412 .15493 L
.416 .15498 L
.42 .15504 L
.424 .15512 L
.428 .15523 L
.432 .15537 L
.436 .15555 L
.44 .15577 L
.444 .15605 L
.448 .15641 L
.452 .15684 L
.456 .15737 L
.46 .15801 L
.464 .15877 L
.468 .15967 L
.472 .16073 L
.476 .16195 L
.48 .16334 L
.484 .16491 L
.488 .16666 L
.492 .16858 L
.496 .17065 L
.5 .17286 L
.504 .17518 L
.508 .17759 L
.512 .18005 L
.516 .18253 L
.52 .18499 L
.524 .18738 L
.528 .18968 L
.532 .19186 L
.536 .19392 L
.54 .19585 L
.544 .19768 L
.548 .19943 L
.552 .20113 L
.556 .20284 L
.56 .20457 L
.564 .20637 L
.568 .20825 L
.572 .21024 L
.576 .21234 L
.58 .21452 L
.584 .21677 L
.588 .21904 L
.592 .2213 L
.596 .2235 L
.6 .22561 L
Mistroke
.604 .22761 L
.608 .22949 L
.612 .23125 L
.616 .23292 L
.62 .23455 L
.624 .23614 L
.628 .23771 L
.632 .23926 L
.636 .24076 L
.64 .2422 L
.644 .24352 L
.648 .24467 L
.652 .2456 L
.656 .24632 L
.66 .24684 L
.664 .24722 L
.668 .24752 L
.672 .24781 L
.676 .24813 L
.68 .24855 L
.684 .24909 L
.688 .24976 L
.692 .25053 L
.696 .25134 L
.7 .25217 L
.704 .25299 L
.708 .25381 L
.712 .25463 L
.716 .25545 L
.72 .25624 L
.724 .25698 L
.728 .25764 L
.732 .25821 L
.736 .2587 L
.74 .25909 L
.744 .25938 L
.748 .25963 L
.752 .2599 L
.756 .26028 L
.76 .26082 L
.764 .26152 L
.768 .26229 L
.772 .26305 L
.776 .26368 L
.78 .26413 L
.784 .26437 L
.788 .26442 L
.792 .2643 L
.796 .26406 L
.8 .26379 L
Mistroke
.804 .26357 L
.808 .26347 L
.812 .26348 L
.816 .26355 L
.82 .26357 L
.824 .2635 L
.828 .2633 L
.832 .26302 L
.836 .26272 L
.84 .26246 L
.844 .26226 L
.848 .26211 L
.852 .26203 L
.856 .26201 L
.86 .26205 L
.864 .26216 L
.868 .26229 L
.872 .2624 L
.876 .26244 L
.88 .2624 L
.884 .26231 L
.888 .26223 L
.892 .2622 L
.896 .26226 L
.9 .2624 L
.904 .26255 L
.908 .26268 L
.912 .26272 L
.916 .26266 L
.92 .26252 L
.924 .26233 L
.928 .26215 L
.932 .26202 L
.936 .26192 L
.94 .26187 L
.944 .26181 L
.948 .26175 L
.952 .2617 L
.956 .26168 L
.96 .26171 L
.964 .26181 L
.968 .26191 L
.972 .26203 L
.976 .26208 L
.98 .26211 L
.984 .26212 L
.988 .26211 L
.992 .26212 L
.996 .26211 L
1 .26199 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16184 L
.012 .16131 L
.016 .16101 L
.02 .16116 L
.024 .16124 L
.028 .16124 L
.032 .16118 L
.036 .1612 L
.04 .1612 L
.044 .16122 L
.048 .16119 L
.052 .1612 L
.056 .16119 L
.06 .1612 L
.064 .1612 L
.068 .16121 L
.072 .1612 L
.076 .1612 L
.08 .16119 L
.084 .16119 L
.088 .16119 L
.092 .1612 L
.096 .1612 L
.1 .1612 L
.104 .16119 L
.108 .16119 L
.112 .16118 L
.116 .16119 L
.12 .16119 L
.124 .1612 L
.128 .16119 L
.132 .16119 L
.136 .16118 L
.14 .16118 L
.144 .16118 L
.148 .16119 L
.152 .16119 L
.156 .16119 L
.16 .16118 L
.164 .16118 L
.168 .16118 L
.172 .16118 L
.176 .16118 L
.18 .16118 L
.184 .16118 L
.188 .16118 L
.192 .16118 L
.196 .16118 L
.2 .16117 L
Mistroke
.204 .16117 L
.208 .16117 L
.212 .16117 L
.216 .16118 L
.22 .16118 L
.224 .16118 L
.228 .16117 L
.232 .16116 L
.236 .16116 L
.24 .16117 L
.244 .16117 L
.248 .16118 L
.252 .16117 L
.256 .16117 L
.26 .16116 L
.264 .16116 L
.268 .16116 L
.272 .16117 L
.276 .16117 L
.28 .16117 L
.284 .16117 L
.288 .16116 L
.292 .16115 L
.296 .16115 L
.3 .16116 L
.304 .16116 L
.308 .16116 L
.312 .16116 L
.316 .16116 L
.32 .16115 L
.324 .16115 L
.328 .16115 L
.332 .16115 L
.336 .16115 L
.34 .16116 L
.344 .16116 L
.348 .16115 L
.352 .16115 L
.356 .16114 L
.36 .16114 L
.364 .16114 L
.368 .16115 L
.372 .16115 L
.376 .16114 L
.38 .16114 L
.384 .16113 L
.388 .16112 L
.392 .16111 L
.396 .1611 L
.4 .16108 L
Mistroke
.404 .16106 L
.408 .16102 L
.412 .16098 L
.416 .16092 L
.42 .16084 L
.424 .16074 L
.428 .1606 L
.432 .16043 L
.436 .16021 L
.44 .15992 L
.444 .15957 L
.448 .15914 L
.452 .1586 L
.456 .15794 L
.46 .15714 L
.464 .15619 L
.468 .15506 L
.472 .15374 L
.476 .15222 L
.48 .15049 L
.484 .14853 L
.488 .14636 L
.492 .14398 L
.496 .14139 L
.5 .13862 L
.504 .13571 L
.508 .13269 L
.512 .12962 L
.516 .12654 L
.52 .12348 L
.524 .12051 L
.528 .11764 L
.532 .11491 L
.536 .11233 L
.54 .10989 L
.544 .10759 L
.548 .10539 L
.552 .10326 L
.556 .10116 L
.56 .09901 L
.564 .09677 L
.568 .09441 L
.572 .09191 L
.576 .08927 L
.58 .08652 L
.584 .08369 L
.588 .08083 L
.592 .07801 L
.596 .07528 L
.6 .07267 L
Mistroke
.604 .07018 L
.608 .06783 L
.612 .0656 L
.616 .06347 L
.62 .06141 L
.624 .05939 L
.628 .05741 L
.632 .05546 L
.636 .05357 L
.64 .0518 L
.644 .0502 L
.648 .04878 L
.652 .04759 L
.656 .04662 L
.66 .04589 L
.664 .04535 L
.668 .04495 L
.672 .04459 L
.676 .04418 L
.68 .04368 L
.684 .04304 L
.688 .04225 L
.692 .04132 L
.696 .04027 L
.7 .03913 L
.704 .03796 L
.708 .03683 L
.712 .03577 L
.716 .0348 L
.72 .03389 L
.724 .03304 L
.728 .03225 L
.732 .03154 L
.736 .03093 L
.74 .0304 L
.744 .02992 L
.748 .02944 L
.752 .02892 L
.756 .02836 L
.76 .02773 L
.764 .02704 L
.768 .02626 L
.772 .02543 L
.776 .02463 L
.78 .02397 L
.784 .02352 L
.788 .02333 L
.792 .02336 L
.796 .02352 L
.8 .02373 L
Mistroke
.804 .02395 L
.808 .02417 L
.812 .02438 L
.816 .02456 L
.82 .02468 L
.824 .02475 L
.828 .02479 L
.832 .02486 L
.836 .025 L
.84 .02519 L
.844 .0254 L
.848 .02558 L
.852 .02572 L
.856 .0258 L
.86 .02585 L
.864 .02589 L
.868 .0259 L
.872 .02587 L
.876 .02577 L
.88 .02561 L
.884 .02542 L
.888 .02524 L
.892 .0251 L
.896 .025 L
.9 .02493 L
.904 .02485 L
.908 .0248 L
.912 .02479 L
.916 .02488 L
.92 .02509 L
.924 .02538 L
.928 .0257 L
.932 .02595 L
.936 .02604 L
.94 .02597 L
.944 .02576 L
.948 .02551 L
.952 .02531 L
.956 .02522 L
.96 .02522 L
.964 .02528 L
.968 .02527 L
.972 .02524 L
.976 .02516 L
.98 .02515 L
.984 .0253 L
.988 .02557 L
.992 .02594 L
.996 .02624 L
1 .02629 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0;Woo0`00>goo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool2000_Ool01000Ool00000>Woo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8000eoo`<000Aoo`8000Moo`<000Aoo`8000Aoo`80009o
o`03001oogoo00<0009oo`@000Aoo`8000=oo`D000=oo`8000Aoo`8000Aoo`D0009oo`<000Aoo`80
00Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`0;Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool0
1P00Oomoo`00Ool000=oo`800004Ool00000Ool30002Ool01000Oomoo`000goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04
001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007ooOol00P00
17oo10000goo0P000Woo00@007ooOol000Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol00Woo00@007ooOol0009oo`03001oogoo008000Aoo`03001oo`0000Aoo`80009oo`04001o
ogoo0005Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Ao
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P00
17oo00<007ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool0
0`00Oomoo`020004Ool01000Oomoogoo1P0000Eoo`00Oomoo`00009oo`05001oogooOol00002Ool0
1000Oomoo`000Woo00@007ooOol000=oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`00
2goo0P002Woo0P0017oo00<007ooOol00Woo0P0037oo00<007ooOol017oo00@007ooOol000Ioo`80
00Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol00Woo0`000Woo00@007oo
Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`0000=oo`03001oo`0000Io
o`04001oogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`<000Eo
o`04001oogooOol500000goo001oo`020004Ool30004Ool20004Ool20005Ool30002Ool50003Ool2
0006Ool0029oo`03001oogoo02Yoo`03001oogoo00moo`03001oogoo02eoo`008Woo0P00:Woo0P00
4Goo00<007ooOol00Woo0`00:7oo000ROomS000<Ool0029oob`000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000Woo00@007oo001oo`80009oo`<00003Ool007oo00D00003Ool007oo00T00004
Ool00000Ool2000<Ool0029oo`80021oo`04001oogoo000JOol30006Ool01000Oomoogoo0P0000=o
o`0000000`0000Aoo`00001oo`D00003Ool0000000ioo`008Woo00<007ooOol0?Woo0P002goo00<0
07ooOol07Woo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo
06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Ao
o`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo
0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<0
07ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03
001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0
009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P00
2Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2
001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Ao
o`03001oogoo009oo`03001oogoo06Ioo`00:7oo;000?Goo000XOol00`00Oomoo`0XOol3000kOol0
00]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo02]oo`8003Uoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000^Ool3
000gOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001o
ogoo000`Ool3000eOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<00003Ool0000000<000Ao
o`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009o
o`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogoo
Ool007oo0`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
00=oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Ao
o`<00005Ool007ooOol00003Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Aoo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0
009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000=oo`03001oogoo00Eoo`03001oo`0000@000Aoo`05001oogooOol00002
Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo
00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo00L0009oo`04001oogoo0002
Ool01000Oomoo`000Woo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000XOol00`00Oomo
o`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002
Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=ooaT000=oo`04001oogoo0005Ool002Qo
o`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol5
0003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011o
o`03001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001o
ogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo
001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo0080
06Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007oo
Ool0IWoo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo
1@000Woo00@007ooOol000]oo`03001oogoo008004eooaX000aoo`002Woo00@007ooOol000]oo`04
001oogoo0018Ool6000VOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`11Ool6000[Ool0
00Yoo`04001oogoo0007Ool00`00Oomoo`04Ool20010Ool3000`Ool000]oo`8000Qoo`D0009oo`03
001oogoo03aoo`<003=oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P00
1Goo0`000goo10000goo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000L
Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00T007ooOomoo`00Ool007oo00000Woo00@007ooOol000Eoo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009o
o`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`80009oo`04001oogoo0002
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oo`000080
00=oo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@0
00=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`<00003
Ool00000008000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03
001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=o
o`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`80
00Yoo`03001oogoo00=oo`8000Aoo`8000Aoo`<000=oo`D000=oo`8000Ioo`<000Aoo`8000Aoo`80
00Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0<7oo0P00@7oo000LOol00`00Oomoo`0^
Ool30011Ool001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00
Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`00
0goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079o
o`002Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo
001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
0`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001o
ogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`02Ool0
0`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000G
Ool00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yo
o`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00
009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol0
2goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`80
00Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000L
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(21042\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31706 m
.008 .31755 L
.012 .31821 L
.016 .31832 L
.02 .31786 L
.024 .31779 L
.028 .31809 L
.032 .31814 L
.036 .31797 L
.04 .31793 L
.044 .318 L
.048 .31807 L
.052 .31809 L
.056 .31809 L
.06 .31808 L
.064 .31806 L
.068 .31806 L
.072 .3181 L
.076 .31814 L
.08 .31815 L
.084 .31814 L
.088 .31812 L
.092 .31812 L
.096 .31816 L
.1 .31821 L
.104 .31823 L
.108 .31821 L
.112 .31816 L
.116 .31814 L
.12 .31818 L
.124 .31826 L
.128 .31833 L
.132 .31833 L
.136 .31826 L
.14 .31819 L
.144 .31817 L
.148 .31824 L
.152 .31836 L
.156 .31844 L
.16 .31843 L
.164 .31833 L
.168 .31823 L
.172 .3182 L
.176 .31829 L
.18 .31843 L
.184 .31853 L
.188 .31852 L
.192 .31843 L
.196 .31832 L
.2 .31826 L
Mistroke
.204 .31831 L
.208 .31844 L
.212 .31858 L
.216 .31864 L
.22 .31857 L
.224 .31845 L
.228 .31835 L
.232 .31833 L
.236 .3184 L
.24 .31854 L
.244 .3187 L
.248 .31877 L
.252 .31869 L
.256 .3185 L
.26 .31833 L
.264 .31832 L
.268 .31847 L
.272 .3187 L
.276 .31889 L
.28 .31893 L
.284 .31877 L
.288 .31848 L
.292 .31827 L
.296 .3183 L
.3 .31858 L
.304 .31894 L
.308 .31913 L
.312 .31903 L
.316 .31874 L
.32 .31842 L
.324 .31826 L
.328 .31835 L
.332 .31867 L
.336 .31906 L
.34 .31926 L
.344 .31911 L
.348 .31869 L
.352 .31825 L
.356 .31805 L
.36 .31813 L
.364 .31839 L
.368 .31862 L
.372 .31864 L
.376 .31828 L
.38 .31752 L
.384 .31651 L
.388 .31557 L
.392 .31488 L
.396 .31431 L
.4 .31349 L
Mistroke
.404 .31203 L
.408 .30978 L
.412 .30679 L
.416 .3032 L
.42 .29914 L
.424 .29472 L
.428 .28994 L
.432 .28461 L
.436 .27837 L
.44 .27094 L
.444 .26236 L
.448 .25303 L
.452 .24348 L
.456 .2341 L
.46 .22511 L
.464 .21665 L
.468 .20888 L
.472 .20197 L
.476 .19613 L
.48 .19164 L
.484 .18897 L
.488 .18859 L
.492 .19076 L
.496 .19523 L
.5 .20136 L
.504 .20834 L
.508 .21548 L
.512 .22224 L
.516 .22811 L
.52 .2326 L
.524 .23529 L
.528 .23602 L
.532 .23481 L
.536 .23183 L
.54 .2273 L
.544 .22169 L
.548 .21583 L
.552 .21087 L
.556 .20792 L
.56 .20768 L
.564 .21018 L
.568 .21504 L
.572 .22166 L
.576 .22934 L
.58 .23726 L
.584 .24445 L
.588 .25006 L
.592 .25382 L
.596 .25617 L
.6 .25803 L
Mistroke
.604 .26033 L
.608 .26371 L
.612 .26865 L
.616 .27562 L
.62 .28492 L
.624 .29626 L
.628 .30837 L
.632 .31935 L
.636 .32747 L
.64 .3319 L
.644 .3327 L
.648 .33034 L
.652 .3253 L
.656 .31822 L
.66 .3103 L
.664 .30329 L
.668 .29865 L
.672 .2967 L
.676 .29651 L
.68 .29679 L
.684 .29696 L
.688 .29749 L
.692 .29915 L
.696 .30207 L
.7 .30561 L
.704 .30905 L
.708 .31238 L
.712 .31608 L
.716 .32008 L
.72 .32309 L
.724 .32312 L
.728 .31913 L
.732 .31217 L
.736 .30502 L
.74 .30052 L
.744 .29987 L
.748 .30247 L
.752 .307 L
.756 .31261 L
.76 .31902 L
.764 .32551 L
.768 .33031 L
.772 .33134 L
.776 .32773 L
.78 .32119 L
.784 .31515 L
.788 .31269 L
.792 .31449 L
.796 .31852 L
.8 .32197 L
Mistroke
.804 .32323 L
.808 .32285 L
.812 .3225 L
.816 .32305 L
.82 .32387 L
.824 .32344 L
.828 .32107 L
.832 .31773 L
.836 .31537 L
.84 .31538 L
.844 .31743 L
.848 .31984 L
.852 .32093 L
.856 .32041 L
.86 .31924 L
.864 .31872 L
.868 .31924 L
.872 .31985 L
.876 .31963 L
.88 .3183 L
.884 .31688 L
.888 .31713 L
.892 .31937 L
.896 .32288 L
.9 .32552 L
.904 .32513 L
.908 .32201 L
.912 .31732 L
.916 .31377 L
.92 .31366 L
.924 .31642 L
.928 .32114 L
.932 .32499 L
.936 .32557 L
.94 .3234 L
.944 .31873 L
.948 .31444 L
.952 .31324 L
.956 .31482 L
.96 .31968 L
.964 .32479 L
.968 .32687 L
.972 .32596 L
.976 .32091 L
.98 .31504 L
.984 .31235 L
.988 .31292 L
.992 .31824 L
.996 .32474 L
1 .32759 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15394 m
.008 .15509 L
.012 .15548 L
.016 .1552 L
.02 .15501 L
.024 .15511 L
.028 .15516 L
.032 .15516 L
.036 .15512 L
.04 .15513 L
.044 .15513 L
.048 .15514 L
.052 .15513 L
.056 .15514 L
.06 .15513 L
.064 .15514 L
.068 .15513 L
.072 .15513 L
.076 .15513 L
.08 .15514 L
.084 .15513 L
.088 .15514 L
.092 .15513 L
.096 .15514 L
.1 .15513 L
.104 .15513 L
.108 .15513 L
.112 .15514 L
.116 .15514 L
.12 .15514 L
.124 .15513 L
.128 .15513 L
.132 .15513 L
.136 .15514 L
.14 .15514 L
.144 .15514 L
.148 .15514 L
.152 .15514 L
.156 .15514 L
.16 .15514 L
.164 .15514 L
.168 .15514 L
.172 .15513 L
.176 .15514 L
.18 .15514 L
.184 .15514 L
.188 .15514 L
.192 .15514 L
.196 .15513 L
.2 .15513 L
Mistroke
.204 .15514 L
.208 .15514 L
.212 .15514 L
.216 .15514 L
.22 .15514 L
.224 .15513 L
.228 .15513 L
.232 .15514 L
.236 .15514 L
.24 .15515 L
.244 .15514 L
.248 .15514 L
.252 .15514 L
.256 .15513 L
.26 .15514 L
.264 .15514 L
.268 .15515 L
.272 .15515 L
.276 .15514 L
.28 .15514 L
.284 .15514 L
.288 .15514 L
.292 .15514 L
.296 .15514 L
.3 .15515 L
.304 .15515 L
.308 .15515 L
.312 .15514 L
.316 .15514 L
.32 .15514 L
.324 .15514 L
.328 .15515 L
.332 .15515 L
.336 .15515 L
.34 .15515 L
.344 .15515 L
.348 .15515 L
.352 .15515 L
.356 .15516 L
.36 .15517 L
.364 .15518 L
.368 .15519 L
.372 .1552 L
.376 .15521 L
.38 .15523 L
.384 .15527 L
.388 .15531 L
.392 .15538 L
.396 .15546 L
.4 .15556 L
Mistroke
.404 .15569 L
.408 .15585 L
.412 .15607 L
.416 .15633 L
.42 .15666 L
.424 .15707 L
.428 .15758 L
.432 .15819 L
.436 .15892 L
.44 .15978 L
.444 .16078 L
.448 .16195 L
.452 .16329 L
.456 .1648 L
.46 .16649 L
.464 .16834 L
.468 .17037 L
.472 .17254 L
.476 .17483 L
.48 .17722 L
.484 .17966 L
.488 .18213 L
.492 .18458 L
.496 .18699 L
.5 .18932 L
.504 .19155 L
.508 .19366 L
.512 .19565 L
.516 .19753 L
.52 .19931 L
.524 .20102 L
.528 .2027 L
.532 .20441 L
.536 .20616 L
.54 .20801 L
.544 .20996 L
.548 .21202 L
.552 .21417 L
.556 .2164 L
.56 .21866 L
.564 .22092 L
.568 .22313 L
.572 .22526 L
.576 .2273 L
.58 .22923 L
.584 .23104 L
.588 .23276 L
.592 .2344 L
.596 .23599 L
.6 .23755 L
Mistroke
.604 .23908 L
.608 .24057 L
.612 .242 L
.616 .24333 L
.62 .24454 L
.624 .24557 L
.628 .2464 L
.632 .24702 L
.636 .24747 L
.64 .2478 L
.644 .24807 L
.648 .24835 L
.652 .24869 L
.656 .24914 L
.66 .24973 L
.664 .25046 L
.668 .25128 L
.672 .25215 L
.676 .25303 L
.68 .25388 L
.684 .2547 L
.688 .25549 L
.692 .25624 L
.696 .25695 L
.7 .2576 L
.704 .2582 L
.708 .25874 L
.712 .25922 L
.716 .25961 L
.72 .25993 L
.724 .26021 L
.728 .26053 L
.732 .26094 L
.736 .26149 L
.74 .26214 L
.744 .26285 L
.748 .26354 L
.752 .26412 L
.756 .26454 L
.76 .26475 L
.764 .26475 L
.768 .26456 L
.772 .26425 L
.776 .26393 L
.78 .2637 L
.784 .26359 L
.788 .26359 L
.792 .26363 L
.796 .26363 L
.8 .26355 L
Mistroke
.804 .2634 L
.808 .26318 L
.812 .26293 L
.816 .26267 L
.82 .26243 L
.824 .26224 L
.828 .26214 L
.832 .26216 L
.836 .26228 L
.84 .26243 L
.844 .26257 L
.848 .26264 L
.852 .26264 L
.856 .26259 L
.86 .26254 L
.864 .26251 L
.868 .26253 L
.872 .26258 L
.876 .26266 L
.88 .26276 L
.884 .26286 L
.888 .26292 L
.892 .26291 L
.896 .26279 L
.9 .26257 L
.904 .26229 L
.908 .26204 L
.912 .26186 L
.916 .26182 L
.92 .26187 L
.924 .26197 L
.928 .26207 L
.932 .26213 L
.936 .26216 L
.94 .26219 L
.944 .26224 L
.948 .26234 L
.952 .26243 L
.956 .26247 L
.96 .26241 L
.964 .26224 L
.968 .26199 L
.972 .26175 L
.976 .26156 L
.98 .26152 L
.984 .26155 L
.988 .26166 L
.992 .26175 L
.996 .26177 L
1 .26175 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15938 L
.012 .16126 L
.016 .16181 L
.02 .1612 L
.024 .16098 L
.028 .16123 L
.032 .16127 L
.036 .16121 L
.04 .16117 L
.044 .16121 L
.048 .1612 L
.052 .16121 L
.056 .16119 L
.06 .1612 L
.064 .16119 L
.068 .1612 L
.072 .16119 L
.076 .1612 L
.08 .16119 L
.084 .1612 L
.088 .16119 L
.092 .1612 L
.096 .16119 L
.1 .1612 L
.104 .16119 L
.108 .16119 L
.112 .16118 L
.116 .16119 L
.12 .16119 L
.124 .16119 L
.128 .16119 L
.132 .16119 L
.136 .16118 L
.14 .16118 L
.144 .16118 L
.148 .16119 L
.152 .16119 L
.156 .16119 L
.16 .16118 L
.164 .16118 L
.168 .16118 L
.172 .16118 L
.176 .16118 L
.18 .16118 L
.184 .16118 L
.188 .16118 L
.192 .16117 L
.196 .16117 L
.2 .16117 L
Mistroke
.204 .16118 L
.208 .16118 L
.212 .16118 L
.216 .16117 L
.22 .16117 L
.224 .16117 L
.228 .16117 L
.232 .16117 L
.236 .16117 L
.24 .16117 L
.244 .16117 L
.248 .16117 L
.252 .16116 L
.256 .16116 L
.26 .16116 L
.264 .16116 L
.268 .16117 L
.272 .16117 L
.276 .16117 L
.28 .16116 L
.284 .16115 L
.288 .16115 L
.292 .16115 L
.296 .16116 L
.3 .16116 L
.304 .16116 L
.308 .16116 L
.312 .16115 L
.316 .16115 L
.32 .16115 L
.324 .16115 L
.328 .16115 L
.332 .16116 L
.336 .16115 L
.34 .16115 L
.344 .16114 L
.348 .16114 L
.352 .16113 L
.356 .16113 L
.36 .16113 L
.364 .16112 L
.368 .16111 L
.372 .16109 L
.376 .16106 L
.38 .16103 L
.384 .16098 L
.388 .16093 L
.392 .16086 L
.396 .16076 L
.4 .16064 L
Mistroke
.404 .16047 L
.408 .16026 L
.412 .16 L
.416 .15966 L
.42 .15925 L
.424 .15873 L
.428 .15811 L
.432 .15735 L
.436 .15645 L
.44 .15537 L
.444 .15412 L
.448 .15266 L
.452 .15099 L
.456 .1491 L
.46 .147 L
.464 .14468 L
.468 .14216 L
.472 .13946 L
.476 .1366 L
.48 .13363 L
.484 .13057 L
.488 .12749 L
.492 .12441 L
.496 .1214 L
.5 .11849 L
.504 .11571 L
.508 .11308 L
.512 .1106 L
.516 .10826 L
.52 .10603 L
.524 .10388 L
.528 .10175 L
.532 .09961 L
.536 .09741 L
.54 .09511 L
.544 .09268 L
.548 .09011 L
.552 .08743 L
.556 .08464 L
.56 .0818 L
.564 .07896 L
.568 .07616 L
.572 .07348 L
.576 .07093 L
.58 .06854 L
.584 .06628 L
.588 .06413 L
.592 .06208 L
.596 .06007 L
.6 .05811 L
Mistroke
.604 .05616 L
.608 .05426 L
.612 .05245 L
.616 .05077 L
.62 .04928 L
.624 .04801 L
.628 .04698 L
.632 .04618 L
.636 .04558 L
.64 .04514 L
.644 .04477 L
.648 .04438 L
.652 .04391 L
.656 .04331 L
.66 .04257 L
.664 .0417 L
.668 .04071 L
.672 .03964 L
.676 .03852 L
.68 .03739 L
.684 .03629 L
.688 .03526 L
.692 .03428 L
.696 .03337 L
.7 .03253 L
.704 .03179 L
.708 .03116 L
.712 .03064 L
.716 .03019 L
.72 .02975 L
.724 .02928 L
.728 .02874 L
.732 .02812 L
.736 .0274 L
.74 .02661 L
.744 .02577 L
.748 .02496 L
.752 .02427 L
.756 .0238 L
.76 .02357 L
.764 .02355 L
.768 .02366 L
.772 .02384 L
.776 .02404 L
.78 .02423 L
.784 .02441 L
.788 .02457 L
.792 .02469 L
.796 .02479 L
.8 .02489 L
Mistroke
.804 .02503 L
.808 .02522 L
.812 .02543 L
.816 .0256 L
.82 .02572 L
.824 .02579 L
.828 .02583 L
.832 .02589 L
.836 .02597 L
.84 .02603 L
.844 .02603 L
.848 .02595 L
.852 .0258 L
.856 .02562 L
.86 .02547 L
.864 .02536 L
.868 .02525 L
.872 .02514 L
.876 .02501 L
.88 .02492 L
.884 .02491 L
.888 .02502 L
.892 .02524 L
.896 .02553 L
.9 .02578 L
.904 .02595 L
.908 .02599 L
.912 .02592 L
.916 .0258 L
.92 .02567 L
.924 .02559 L
.928 .02556 L
.932 .02555 L
.936 .02555 L
.94 .02554 L
.944 .0255 L
.948 .02548 L
.952 .02549 L
.956 .02555 L
.96 .02564 L
.964 .02572 L
.968 .02577 L
.972 .02576 L
.976 .02569 L
.98 .02565 L
.984 .02559 L
.988 .02558 L
.992 .02559 L
.996 .02559 L
1 .02559 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0;7oo0P00?Woo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool2000/Ool200000goo001oo`0lOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0`00
0Woo1`0000Aoo`00000000Aoo`8000=oo`D000=oo`8000Aoo`8000Aoo`D0009oo`<000Aoo`8000Io
o`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0;
Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000
Ool000000goo00@007oo0000009oo`05001oogooOol00002Ool01000Oomoo`000goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011o
o`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo0000
00=oo`@0009oo`05001oogooOol00002Ool01000Oomoo`0017oo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo0P0000=oo`00Ool017oo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001o
ogoo00Aoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo0P0017oo00<007ooOol02goo10000goo00@007ooOol000Moo`03001oogoo
009oo`04001oogoo0002Ool200000goo001oo`04Ool01000Oomoogoo10000goo00@007ooOol0009o
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogooOol007oo1000
0goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo0P0037oo00<007ooOol0
17oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00@007oo
Ool000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003
Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03
001oogoo00=oo`8000=oo`<000Ioo`04001oogooOol50003Ool20004Ool30004Ool20004Ool20005
Ool30002Ool50003Ool20006Ool0029oo`03001oogoo02Moo`80015oo`03001oogoo02moo`008Woo
0P009goo0P004Woo00@007ooOomoo`<002]oo`008WooH`0037oo000ROolY0002Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`08001oo`00001oo`00Ool0009oo`<0009oo`03001oogoo0080
009oo`800003Ool0000000800004Ool00000Ool3000017oo0000000037oo000ROol2000lOol00`00
Ool00005Ool20003Ool200000goo0000000200001Goo00000000Ool00`0000Aoo`00001oo`800003
Ool0000000aoo`008Woo00<007ooOol0>goo0P002goo00<007ooOol08Goo000ROol2001]Ool0029o
o`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool0
00]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol0
0goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qo
o`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo
000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo
0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000R
Ool00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo
00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Io
o`00:7oo:@00@7oo000XOol00`00Oomoo`0VOol3000mOol000]oo`8000Aoo`03001oogoo00=oo`80
00Aoo`8000=oo`<000=oo`03001oogoo02Qoo`<003]oo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000/Ool2000jOol000=oo`D0009oo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000^Ool2000hOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Mo
o`<000Aoo`8000Aoo`8000=oo`D00004Ool000000004Ool20002Ool50003Ool20004Ool20003Ool5
0002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo
00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`020003Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`02Ool40002Ool01000Oomoo`000goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Oomoo`04Ool50002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03
001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo
00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=o
o`04001oogooOol40003Ool70002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003
Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool0
1000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04
Ool01@00Oomoo`00Ool07@000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P00
27oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Ao
o`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol0
3goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P00
17oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Ao
o`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04
001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0
KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<0
07ooOol00P00BWoo7@0037oo000:Ool01000Oomoo`002goo00@007ooOol004Eoo`L002Qoo`002Woo
00@007ooOol000Moo`@000=oo`03001oogoo03ioo`H002ioo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`8003eoo`<003=oo`002goo0P0027oo1@000Woo00<007ooOol0>Woo0P00=Woo000LOol0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30002Ool40004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002
Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`020003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol0
0`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool30005Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo
000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0004Ool30006Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0003Ool30003Ool40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000L
Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`05
001oogoo001oo`0200000goo00000003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool200000goo00000003
Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo
000LOol00`00Oomoo`0^Ool00`00Oomoo`11Ool001aoo`03001oogoo02aoo`8004Aoo`0077ooJ@00
37oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2
001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`00
2goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007oo
Ool000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=o
o`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0
LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo
00<007ooOol00Woo00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03
001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol0
0Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo
000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001c
Ool000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo
00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`00
77oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(21209\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31756 m
.008 .31805 L
.012 .31797 L
.016 .31791 L
.02 .31788 L
.024 .31789 L
.028 .31801 L
.032 .3181 L
.036 .31804 L
.04 .31793 L
.044 .31789 L
.048 .31794 L
.052 .31804 L
.056 .31811 L
.06 .31812 L
.064 .31808 L
.068 .31801 L
.072 .31798 L
.076 .31803 L
.08 .31811 L
.084 .31817 L
.088 .31817 L
.092 .31813 L
.096 .31809 L
.1 .31808 L
.104 .31812 L
.108 .31818 L
.112 .31821 L
.116 .31821 L
.12 .31819 L
.124 .31818 L
.128 .31819 L
.132 .31821 L
.136 .31822 L
.14 .31823 L
.144 .31825 L
.148 .31827 L
.152 .3183 L
.156 .31831 L
.16 .31829 L
.164 .31826 L
.168 .31824 L
.172 .31827 L
.176 .31835 L
.18 .31843 L
.184 .31844 L
.188 .31838 L
.192 .31829 L
.196 .31825 L
.2 .3183 L
Mistroke
.204 .31842 L
.208 .31854 L
.212 .31858 L
.216 .3185 L
.22 .31835 L
.224 .31826 L
.228 .3183 L
.232 .31845 L
.236 .31861 L
.24 .31868 L
.244 .31863 L
.248 .31849 L
.252 .31835 L
.256 .3183 L
.26 .3184 L
.264 .31859 L
.268 .31877 L
.272 .31881 L
.276 .31869 L
.28 .3185 L
.284 .31836 L
.288 .31834 L
.292 .31848 L
.296 .31871 L
.3 .31892 L
.304 .31895 L
.308 .31875 L
.312 .31843 L
.316 .31822 L
.32 .31824 L
.324 .31847 L
.328 .31873 L
.332 .31884 L
.336 .31869 L
.34 .31828 L
.344 .31772 L
.348 .31722 L
.352 .31695 L
.356 .31685 L
.36 .31665 L
.364 .31604 L
.368 .31486 L
.372 .31319 L
.376 .3112 L
.38 .309 L
.384 .30661 L
.388 .30394 L
.392 .30077 L
.396 .29678 L
.4 .2917 L
Mistroke
.404 .28548 L
.408 .27841 L
.412 .27084 L
.416 .26296 L
.42 .25473 L
.424 .24606 L
.428 .23691 L
.432 .22743 L
.436 .21791 L
.44 .20882 L
.444 .20079 L
.448 .19445 L
.452 .19018 L
.456 .18801 L
.46 .18769 L
.464 .18902 L
.468 .19196 L
.472 .19651 L
.476 .20249 L
.48 .20951 L
.484 .21696 L
.488 .22412 L
.492 .23015 L
.496 .23424 L
.5 .23577 L
.504 .23463 L
.508 .23127 L
.512 .22648 L
.516 .22111 L
.52 .21584 L
.524 .21128 L
.528 .20805 L
.532 .20672 L
.536 .20771 L
.54 .21106 L
.544 .21649 L
.548 .2235 L
.552 .23145 L
.556 .23952 L
.56 .24674 L
.564 .25229 L
.568 .25587 L
.572 .25791 L
.576 .25947 L
.58 .26173 L
.584 .26565 L
.588 .27175 L
.592 .28016 L
.596 .29065 L
.6 .30245 L
Mistroke
.604 .31418 L
.608 .32408 L
.612 .33068 L
.616 .33326 L
.62 .332 L
.624 .32762 L
.628 .321 L
.632 .31315 L
.636 .30535 L
.64 .29905 L
.644 .29531 L
.648 .29428 L
.652 .29505 L
.656 .29642 L
.66 .29766 L
.664 .29891 L
.668 .30067 L
.672 .30319 L
.676 .30626 L
.68 .30965 L
.684 .31337 L
.688 .31745 L
.692 .32125 L
.696 .32327 L
.7 .32188 L
.704 .31671 L
.708 .30929 L
.712 .30239 L
.716 .2985 L
.72 .2986 L
.724 .30219 L
.728 .30825 L
.732 .31575 L
.736 .32362 L
.74 .3301 L
.744 .33302 L
.748 .33105 L
.752 .32492 L
.756 .31764 L
.76 .31273 L
.764 .31211 L
.768 .31509 L
.772 .31923 L
.776 .32243 L
.78 .32406 L
.784 .32481 L
.788 .32524 L
.792 .32495 L
.796 .32316 L
.8 .31983 L
Mistroke
.804 .31635 L
.808 .31468 L
.812 .3157 L
.816 .3184 L
.82 .32063 L
.824 .32085 L
.828 .31939 L
.832 .31808 L
.836 .31837 L
.84 .32001 L
.844 .32125 L
.848 .32035 L
.852 .31754 L
.856 .3149 L
.86 .31491 L
.864 .31851 L
.868 .32371 L
.872 .32737 L
.876 .32703 L
.88 .32255 L
.884 .31681 L
.888 .31288 L
.892 .31283 L
.896 .31646 L
.9 .32103 L
.904 .32434 L
.908 .32474 L
.912 .32226 L
.916 .31905 L
.92 .31631 L
.924 .31549 L
.928 .31703 L
.932 .31926 L
.936 .3217 L
.94 .32281 L
.944 .32179 L
.948 .32022 L
.952 .31828 L
.956 .31754 L
.96 .31887 L
.964 .3202 L
.968 .32143 L
.972 .32118 L
.976 .31893 L
.98 .31757 L
.984 .31725 L
.988 .31878 L
.992 .32208 L
.996 .32343 L
1 .32267 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15784 m
.008 .15547 L
.012 .15466 L
.016 .15552 L
.02 .15575 L
.024 .15548 L
.028 .15538 L
.032 .1555 L
.036 .15551 L
.04 .15549 L
.044 .15546 L
.048 .15549 L
.052 .15548 L
.056 .15549 L
.06 .15548 L
.064 .15549 L
.068 .15548 L
.072 .15549 L
.076 .15548 L
.08 .15549 L
.084 .15548 L
.088 .15549 L
.092 .15548 L
.096 .15549 L
.1 .15548 L
.104 .15548 L
.108 .15548 L
.112 .15549 L
.116 .15549 L
.12 .15549 L
.124 .15548 L
.128 .15548 L
.132 .15548 L
.136 .15549 L
.14 .15549 L
.144 .15549 L
.148 .15549 L
.152 .15549 L
.156 .15548 L
.16 .15548 L
.164 .15549 L
.168 .15549 L
.172 .15549 L
.176 .15549 L
.18 .15549 L
.184 .15549 L
.188 .15549 L
.192 .15549 L
.196 .15549 L
.2 .15549 L
Mistroke
.204 .15549 L
.208 .15549 L
.212 .15549 L
.216 .15549 L
.22 .15549 L
.224 .15549 L
.228 .15549 L
.232 .15549 L
.236 .15549 L
.24 .15549 L
.244 .15549 L
.248 .15549 L
.252 .15548 L
.256 .15549 L
.26 .15549 L
.264 .1555 L
.268 .1555 L
.272 .15549 L
.276 .15549 L
.28 .15549 L
.284 .15549 L
.288 .15549 L
.292 .1555 L
.296 .1555 L
.3 .1555 L
.304 .15549 L
.308 .15549 L
.312 .15549 L
.316 .15549 L
.32 .1555 L
.324 .15551 L
.328 .15551 L
.332 .15551 L
.336 .15552 L
.34 .15552 L
.344 .15553 L
.348 .15555 L
.352 .15558 L
.356 .15562 L
.36 .15566 L
.364 .15571 L
.368 .15578 L
.372 .15588 L
.376 .156 L
.38 .15616 L
.384 .15636 L
.388 .15662 L
.392 .15693 L
.396 .15732 L
.4 .15779 L
Mistroke
.404 .15837 L
.408 .15906 L
.412 .15988 L
.416 .16085 L
.42 .16197 L
.424 .16325 L
.428 .16471 L
.432 .16634 L
.436 .16814 L
.44 .17011 L
.444 .17223 L
.448 .17448 L
.452 .17683 L
.456 .17926 L
.46 .18172 L
.464 .18418 L
.468 .18661 L
.472 .18897 L
.476 .19124 L
.48 .19339 L
.484 .19541 L
.488 .19733 L
.492 .19914 L
.496 .20088 L
.5 .20258 L
.504 .20428 L
.508 .20601 L
.512 .20781 L
.516 .2097 L
.52 .2117 L
.524 .21381 L
.528 .216 L
.532 .21826 L
.536 .22053 L
.54 .22277 L
.544 .22494 L
.548 .22701 L
.552 .22898 L
.556 .23082 L
.56 .23256 L
.564 .23422 L
.568 .23581 L
.572 .23738 L
.576 .23891 L
.58 .2404 L
.584 .24184 L
.588 .24319 L
.592 .24442 L
.596 .2455 L
.6 .2464 L
Mistroke
.604 .24711 L
.608 .24764 L
.612 .24803 L
.616 .24833 L
.62 .2486 L
.624 .24891 L
.628 .2493 L
.632 .2498 L
.636 .25045 L
.64 .25121 L
.644 .25206 L
.648 .25296 L
.652 .25385 L
.656 .25471 L
.66 .25553 L
.664 .2563 L
.668 .25702 L
.672 .25767 L
.676 .25826 L
.68 .2588 L
.684 .25927 L
.688 .2597 L
.692 .26007 L
.696 .26041 L
.7 .26075 L
.704 .26114 L
.708 .26161 L
.712 .26218 L
.716 .26282 L
.72 .26346 L
.724 .26406 L
.728 .26454 L
.732 .26487 L
.736 .265 L
.74 .26494 L
.744 .26472 L
.748 .26442 L
.752 .26412 L
.756 .2639 L
.76 .26377 L
.764 .26372 L
.768 .2637 L
.772 .26366 L
.776 .26359 L
.78 .26348 L
.784 .26331 L
.788 .2631 L
.792 .26285 L
.796 .26262 L
.8 .26244 L
Mistroke
.804 .26237 L
.808 .26239 L
.812 .26249 L
.816 .26261 L
.82 .26272 L
.824 .26281 L
.828 .26286 L
.832 .2629 L
.836 .2629 L
.84 .26288 L
.844 .26284 L
.848 .26282 L
.852 .26286 L
.856 .26295 L
.86 .26306 L
.864 .26312 L
.868 .26306 L
.872 .26289 L
.876 .26263 L
.88 .26237 L
.884 .26218 L
.888 .26209 L
.892 .26209 L
.896 .26214 L
.9 .26221 L
.904 .26228 L
.908 .26235 L
.912 .26244 L
.916 .26255 L
.92 .26264 L
.924 .26269 L
.928 .26265 L
.932 .26253 L
.936 .26235 L
.94 .26214 L
.944 .26197 L
.948 .26187 L
.952 .26183 L
.956 .26188 L
.96 .26193 L
.964 .262 L
.968 .26206 L
.972 .26211 L
.976 .26215 L
.98 .2622 L
.984 .2622 L
.988 .26217 L
.992 .26206 L
.996 .26193 L
1 .26178 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16021 L
.012 .16114 L
.016 .16149 L
.02 .16128 L
.024 .16111 L
.028 .16119 L
.032 .16122 L
.036 .16122 L
.04 .16118 L
.044 .1612 L
.048 .1612 L
.052 .16121 L
.056 .1612 L
.06 .1612 L
.064 .16119 L
.068 .1612 L
.072 .16119 L
.076 .1612 L
.08 .16119 L
.084 .1612 L
.088 .16119 L
.092 .16119 L
.096 .16119 L
.1 .16119 L
.104 .16119 L
.108 .16119 L
.112 .16119 L
.116 .16119 L
.12 .16119 L
.124 .16119 L
.128 .16119 L
.132 .16119 L
.136 .16118 L
.14 .16118 L
.144 .16118 L
.148 .16119 L
.152 .16118 L
.156 .16118 L
.16 .16118 L
.164 .16118 L
.168 .16118 L
.172 .16118 L
.176 .16118 L
.18 .16118 L
.184 .16118 L
.188 .16117 L
.192 .16117 L
.196 .16117 L
.2 .16118 L
Mistroke
.204 .16118 L
.208 .16118 L
.212 .16117 L
.216 .16117 L
.22 .16116 L
.224 .16117 L
.228 .16117 L
.232 .16117 L
.236 .16117 L
.24 .16117 L
.244 .16116 L
.248 .16116 L
.252 .16116 L
.256 .16116 L
.26 .16117 L
.264 .16117 L
.268 .16117 L
.272 .16116 L
.276 .16116 L
.28 .16115 L
.284 .16115 L
.288 .16116 L
.292 .16116 L
.296 .16116 L
.3 .16116 L
.304 .16115 L
.308 .16115 L
.312 .16114 L
.316 .16114 L
.32 .16115 L
.324 .16115 L
.328 .16114 L
.332 .16113 L
.336 .16112 L
.34 .1611 L
.344 .16108 L
.348 .16107 L
.352 .16104 L
.356 .16101 L
.36 .16095 L
.364 .16088 L
.368 .16078 L
.372 .16066 L
.376 .16051 L
.38 .16031 L
.384 .16006 L
.388 .15975 L
.392 .15936 L
.396 .15888 L
.4 .15828 L
Mistroke
.404 .15755 L
.408 .15669 L
.412 .15567 L
.416 .15447 L
.42 .15308 L
.424 .15148 L
.428 .14966 L
.432 .14762 L
.436 .14537 L
.44 .14291 L
.444 .14027 L
.448 .13747 L
.452 .13453 L
.456 .1315 L
.46 .12843 L
.464 .12536 L
.468 .12232 L
.472 .11938 L
.476 .11655 L
.48 .11385 L
.484 .11131 L
.488 .10892 L
.492 .10665 L
.496 .10448 L
.5 .10236 L
.504 .10024 L
.508 .09807 L
.512 .09581 L
.516 .09343 L
.52 .09092 L
.524 .08828 L
.528 .08553 L
.532 .08273 L
.536 .0799 L
.54 .0771 L
.544 .07437 L
.548 .07176 L
.552 .06929 L
.556 .06697 L
.56 .06478 L
.564 .0627 L
.568 .0607 L
.572 .05875 L
.576 .05685 L
.58 .05497 L
.584 .05315 L
.588 .05142 L
.592 .04985 L
.596 .04848 L
.6 .04734 L
Mistroke
.604 .04645 L
.608 .04578 L
.612 .0453 L
.616 .04492 L
.62 .04457 L
.624 .04416 L
.628 .04362 L
.632 .04294 L
.636 .0421 L
.64 .04114 L
.644 .04008 L
.648 .03898 L
.652 .03786 L
.656 .03677 L
.66 .03572 L
.664 .03474 L
.668 .03381 L
.672 .03294 L
.676 .03214 L
.68 .03144 L
.684 .03084 L
.688 .03034 L
.692 .02991 L
.696 .0295 L
.7 .02905 L
.704 .02851 L
.708 .02786 L
.712 .0271 L
.716 .02626 L
.72 .02539 L
.724 .02461 L
.728 .02401 L
.732 .02366 L
.736 .02358 L
.74 .0237 L
.744 .02393 L
.748 .0242 L
.752 .02443 L
.756 .02461 L
.76 .02472 L
.764 .02478 L
.768 .02481 L
.772 .02488 L
.776 .02503 L
.78 .02526 L
.784 .02554 L
.788 .02579 L
.792 .02597 L
.796 .02605 L
.8 .02606 L
Mistroke
.804 .02605 L
.808 .02605 L
.812 .02605 L
.816 .02604 L
.82 .02599 L
.824 .02593 L
.828 .02586 L
.832 .02579 L
.836 .0257 L
.84 .02557 L
.844 .02539 L
.848 .0252 L
.852 .02505 L
.856 .02501 L
.86 .02508 L
.864 .02527 L
.868 .02551 L
.872 .02576 L
.876 .02597 L
.88 .02611 L
.884 .02617 L
.888 .02613 L
.892 .026 L
.896 .02583 L
.9 .02567 L
.904 .02559 L
.908 .0256 L
.912 .02569 L
.916 .02579 L
.92 .02583 L
.924 .02579 L
.928 .02569 L
.932 .02559 L
.936 .02556 L
.94 .02561 L
.944 .02574 L
.948 .02588 L
.952 .02596 L
.956 .02598 L
.96 .02591 L
.964 .02584 L
.968 .02581 L
.972 .02585 L
.976 .02594 L
.98 .02605 L
.984 .02607 L
.988 .02604 L
.992 .02591 L
.996 .02576 L
1 .02567 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0:Goo0`00@7oo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool2000YOol00`00Oomoo`02000oOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P000goo0`00
00=oo`00Ool00Woo0`000goo0`0017oo0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo
0P001Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo00]oo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009o
o`03001oogoo00<00008Ool007oo001oo`00Ool000=oo`04001oogoo0002Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`05001oogoo001o
o`020002Ool00`00Ool00002000017oo001oo`001Goo00@007ooOol0009oo`03001oogoo009oo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@
Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00P0000Eoo`00Oomo
o`0000Eoo`04001oo`000004Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`00009o
o`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol0
0goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00]oo`@000=oo`04
001oogoo0007Ool00`00Oomoo`02Ool00`00Oomoo`0200001Goo001oogoo00001Goo00<007ooOol0
1@000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=o
o`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol0
0Woo0P0037oo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`03001oogoo00800005Ool007oo
Ool00004Ool20003Ool20005Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002
Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool5
0003Ool20008Ool00`00Oomoo`03Ool30003Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`00
17oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`0UOol00`00Oomoo`0?
Ool00`00Oomoo`0bOol0029oo`8002Eoo`03001oogoo011oo`03001oogoo009oo`8000Eoo`03001o
ogoo02Ioo`008WooH`0037oo000ROolV00000goo001oo`02Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`04001oogoo0003Ool2000017oo000000000Woo0P000Woo1`0000Aoo`00001oo`<0
0003Ool0000000800003Ool007oo00]oo`008Woo0P00>Goo00<007oo00001Woo00@007ooOomoo`80
009oo`<00003Ool0000000800004Ool00000Ool2000017oo000007oo0P0000=oo`00000037oo000R
Ool00`00Oomoo`0iOol2000:Ool2000UOol0029oo`8006eoo`008Woo0P00KGoo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<0
07ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo
0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo
001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
1000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`00
2goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo
00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yo
o`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0
029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03
001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool0
0`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007oo
Ool00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00
Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<0
07ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00
Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Io
o`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOolW0012Ool002Qoo`03
001oogoo02=oo`<0041oo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<0
07ooOol09Woo0P00?Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`00
0goo00@007ooOol002Yoo`8003aoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`001Goo00@007ooOol002]oo`<003Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000Woo
10000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00
Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0goo0`0000=oo`00Ool00Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol0
0goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0
3Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007oo00000P000goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`80
00Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol50002Ool01000Oomo
o`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo2`0000=oo`00Ool0
0Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@0
07ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04
001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol07`000goo00@0
07ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P00
17oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol0
3goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol0
2Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P00
0goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001o
o`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Mo
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03
001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@0
07ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0
JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000
Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomo
o`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Agoo800037oo000:Ool0
1000Oomoo`002goo00@007ooOol004=oo`H002]oo`002Woo00@007ooOol000Moo`@000=oo`03001o
ogoo03aoo`H0031oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8003Yoo`<003Ioo`002goo
0P0027oo1@000Woo00<007ooOol0=goo0P00>Goo000LOol00`00Oomoo`0=Ool30004Ool20009Ool3
0004Ool20004Ool20005Ool5000017oo0000000017oo0P001Goo1@000goo0P0017oo0P001Goo1@00
0Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo0P000Woo00D007ooOomoo`00009oo`04001o
ogoo0005Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool0
00=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000Moo`04001o
ogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo
0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00D007ooOol007oo00<00003
Ool007oo00Ioo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`80
00eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007ooOol00`00
0goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo
00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Ao
o`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D0
00=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004
Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo02]oo`8004Eoo`0077oo
00<007ooOol0:Goo0P00Agoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo
Ool00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;
Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo
000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<0
07ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Ao
o`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]o
o`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0
LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009o
o`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(21376\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31877 m
.008 .31835 L
.012 .3176 L
.016 .31744 L
.02 .31794 L
.024 .31811 L
.028 .31792 L
.032 .31792 L
.036 .31802 L
.04 .31798 L
.044 .31788 L
.048 .31788 L
.052 .31798 L
.056 .31808 L
.06 .31809 L
.064 .31805 L
.068 .31798 L
.072 .31795 L
.076 .31799 L
.08 .31808 L
.084 .31815 L
.088 .31816 L
.092 .3181 L
.096 .31803 L
.1 .31802 L
.104 .31807 L
.108 .31816 L
.112 .31822 L
.116 .31821 L
.12 .31815 L
.124 .3181 L
.128 .31809 L
.132 .31815 L
.136 .31823 L
.14 .31828 L
.144 .31827 L
.148 .31823 L
.152 .31819 L
.156 .31818 L
.16 .31822 L
.164 .31827 L
.168 .31831 L
.172 .31833 L
.176 .31832 L
.18 .31831 L
.184 .31829 L
.188 .31827 L
.192 .31828 L
.196 .31833 L
.2 .31839 L
Mistroke
.204 .31844 L
.208 .31844 L
.212 .3184 L
.216 .31833 L
.22 .31829 L
.224 .31832 L
.228 .31843 L
.232 .31856 L
.236 .3186 L
.24 .31852 L
.244 .31839 L
.248 .3183 L
.252 .31832 L
.256 .31845 L
.26 .31861 L
.264 .31872 L
.268 .31868 L
.272 .31852 L
.276 .31833 L
.28 .31827 L
.284 .31837 L
.288 .31857 L
.292 .31871 L
.296 .3187 L
.3 .31853 L
.304 .31826 L
.308 .31799 L
.312 .31781 L
.316 .31777 L
.32 .31779 L
.324 .31766 L
.328 .31721 L
.332 .3164 L
.336 .31534 L
.34 .31419 L
.344 .31297 L
.348 .31164 L
.352 .31001 L
.356 .30786 L
.36 .30494 L
.364 .30114 L
.368 .2966 L
.372 .29151 L
.376 .28601 L
.38 .27999 L
.384 .27319 L
.388 .26545 L
.392 .25677 L
.396 .24734 L
.4 .2375 L
Mistroke
.404 .22768 L
.408 .21835 L
.412 .20985 L
.416 .2023 L
.42 .19574 L
.424 .1903 L
.428 .18636 L
.432 .1844 L
.436 .18476 L
.44 .18751 L
.444 .19236 L
.448 .19882 L
.452 .20616 L
.456 .21357 L
.46 .22027 L
.464 .2258 L
.468 .22991 L
.472 .23245 L
.476 .23317 L
.48 .23182 L
.484 .22837 L
.488 .22323 L
.492 .21718 L
.496 .21127 L
.5 .20652 L
.504 .20388 L
.508 .20402 L
.512 .20711 L
.516 .21273 L
.52 .21996 L
.524 .22779 L
.528 .23541 L
.532 .24229 L
.536 .24814 L
.54 .25276 L
.544 .25619 L
.548 .25883 L
.552 .26138 L
.556 .26474 L
.56 .26962 L
.564 .27647 L
.568 .28538 L
.572 .29603 L
.576 .30762 L
.58 .31875 L
.584 .32771 L
.588 .33301 L
.592 .3339 L
.596 .33063 L
.6 .32425 L
Mistroke
.604 .31615 L
.608 .30773 L
.612 .30035 L
.616 .29509 L
.62 .29257 L
.624 .2926 L
.628 .29426 L
.632 .29643 L
.636 .29838 L
.64 .30014 L
.644 .30213 L
.648 .30469 L
.652 .3078 L
.656 .31125 L
.66 .31483 L
.664 .3183 L
.668 .32095 L
.672 .3216 L
.676 .31922 L
.68 .31384 L
.684 .30697 L
.688 .301 L
.692 .29801 L
.696 .29889 L
.7 .30329 L
.704 .31025 L
.708 .31854 L
.712 .32658 L
.716 .33234 L
.72 .33387 L
.724 .33052 L
.728 .32369 L
.732 .3165 L
.736 .31202 L
.74 .31158 L
.744 .31437 L
.748 .31846 L
.752 .32229 L
.756 .32523 L
.76 .32713 L
.764 .32754 L
.768 .32579 L
.772 .32192 L
.776 .31728 L
.78 .31405 L
.784 .31371 L
.788 .31589 L
.792 .31864 L
.796 .3201 L
.8 .31992 L
Mistroke
.804 .31934 L
.808 .31973 L
.812 .32104 L
.816 .32174 L
.82 .32035 L
.824 .31701 L
.828 .31391 L
.832 .3136 L
.836 .31695 L
.84 .32234 L
.844 .32653 L
.848 .3272 L
.852 .32431 L
.856 .31976 L
.86 .31619 L
.864 .31481 L
.868 .3154 L
.872 .3171 L
.876 .31887 L
.88 .3207 L
.884 .32238 L
.888 .32315 L
.892 .3226 L
.896 .32011 L
.9 .3168 L
.904 .31478 L
.908 .31512 L
.912 .31833 L
.916 .32244 L
.92 .32467 L
.924 .32418 L
.928 .3208 L
.932 .31696 L
.936 .31535 L
.94 .31617 L
.944 .3193 L
.948 .3224 L
.952 .32317 L
.956 .32209 L
.96 .31926 L
.964 .31662 L
.968 .31619 L
.972 .31718 L
.976 .31975 L
.98 .32248 L
.984 .32327 L
.988 .32273 L
.992 .32031 L
.996 .3171 L
1 .31552 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15744 m
.008 .1559 L
.012 .15532 L
.016 .15579 L
.02 .15598 L
.024 .15587 L
.028 .15577 L
.032 .15582 L
.036 .15584 L
.04 .15585 L
.044 .15582 L
.048 .15584 L
.052 .15583 L
.056 .15584 L
.06 .15583 L
.064 .15584 L
.068 .15583 L
.072 .15584 L
.076 .15583 L
.08 .15584 L
.084 .15583 L
.088 .15584 L
.092 .15583 L
.096 .15584 L
.1 .15583 L
.104 .15584 L
.108 .15583 L
.112 .15584 L
.116 .15583 L
.12 .15584 L
.124 .15583 L
.128 .15583 L
.132 .15583 L
.136 .15584 L
.14 .15584 L
.144 .15584 L
.148 .15584 L
.152 .15583 L
.156 .15583 L
.16 .15583 L
.164 .15584 L
.168 .15584 L
.172 .15584 L
.176 .15584 L
.18 .15583 L
.184 .15583 L
.188 .15583 L
.192 .15584 L
.196 .15584 L
.2 .15584 L
Mistroke
.204 .15584 L
.208 .15584 L
.212 .15583 L
.216 .15584 L
.22 .15584 L
.224 .15584 L
.228 .15584 L
.232 .15584 L
.236 .15584 L
.24 .15584 L
.244 .15584 L
.248 .15584 L
.252 .15584 L
.256 .15584 L
.26 .15584 L
.264 .15584 L
.268 .15584 L
.272 .15584 L
.276 .15584 L
.28 .15584 L
.284 .15584 L
.288 .15585 L
.292 .15585 L
.296 .15585 L
.3 .15585 L
.304 .15585 L
.308 .15586 L
.312 .15587 L
.316 .15589 L
.32 .15591 L
.324 .15593 L
.328 .15595 L
.332 .15599 L
.336 .15604 L
.34 .15611 L
.344 .15621 L
.348 .15633 L
.352 .15648 L
.356 .15666 L
.36 .1569 L
.364 .15719 L
.368 .15756 L
.372 .15801 L
.376 .15857 L
.38 .15923 L
.384 .16001 L
.388 .16093 L
.392 .162 L
.396 .16323 L
.4 .16463 L
Mistroke
.404 .16621 L
.408 .16796 L
.412 .16987 L
.416 .17194 L
.42 .17415 L
.424 .17646 L
.428 .17886 L
.432 .18131 L
.436 .18378 L
.44 .18622 L
.444 .18861 L
.448 .19091 L
.452 .1931 L
.456 .19517 L
.46 .19713 L
.464 .19898 L
.468 .20074 L
.472 .20245 L
.476 .20414 L
.48 .20585 L
.484 .20762 L
.488 .20947 L
.492 .21143 L
.496 .21349 L
.5 .21564 L
.504 .21786 L
.508 .22012 L
.512 .22237 L
.516 .22457 L
.52 .22669 L
.524 .2287 L
.528 .2306 L
.532 .23238 L
.536 .23406 L
.54 .23566 L
.544 .2372 L
.548 .23872 L
.552 .2402 L
.556 .24165 L
.56 .24303 L
.564 .24431 L
.568 .24545 L
.572 .24642 L
.576 .24719 L
.58 .24779 L
.584 .24822 L
.588 .24854 L
.592 .24882 L
.596 .24911 L
.6 .24946 L
Mistroke
.604 .24992 L
.608 .25051 L
.612 .25121 L
.616 .25202 L
.62 .25289 L
.624 .25379 L
.628 .25467 L
.632 .25552 L
.636 .25632 L
.64 .25706 L
.644 .25774 L
.648 .25836 L
.652 .25891 L
.656 .25939 L
.66 .25982 L
.664 .2602 L
.668 .26055 L
.672 .26089 L
.676 .26127 L
.68 .26171 L
.684 .26224 L
.688 .26284 L
.692 .26347 L
.696 .26408 L
.7 .2646 L
.704 .26497 L
.708 .26517 L
.712 .26518 L
.716 .26504 L
.72 .26479 L
.724 .26451 L
.728 .26426 L
.732 .26408 L
.736 .26397 L
.74 .26391 L
.744 .26385 L
.748 .26377 L
.752 .26367 L
.756 .26353 L
.76 .26336 L
.764 .26317 L
.768 .26298 L
.772 .26282 L
.776 .26271 L
.78 .26267 L
.784 .26268 L
.788 .26273 L
.792 .2628 L
.796 .26288 L
.8 .26298 L
Mistroke
.804 .26308 L
.808 .26316 L
.812 .2632 L
.816 .26319 L
.82 .26316 L
.824 .26314 L
.828 .26316 L
.832 .2632 L
.836 .26322 L
.84 .26318 L
.844 .26307 L
.848 .26291 L
.852 .26272 L
.856 .26257 L
.86 .26246 L
.864 .26239 L
.868 .26237 L
.872 .26238 L
.876 .26243 L
.88 .26252 L
.884 .26262 L
.888 .26272 L
.892 .2628 L
.896 .26283 L
.9 .26283 L
.904 .26279 L
.908 .26269 L
.912 .26255 L
.916 .26236 L
.92 .26217 L
.924 .26203 L
.928 .26197 L
.932 .26204 L
.936 .26218 L
.94 .26235 L
.944 .26247 L
.948 .2625 L
.952 .26244 L
.956 .26233 L
.96 .2622 L
.964 .26212 L
.968 .26207 L
.972 .26204 L
.976 .26201 L
.98 .26197 L
.984 .2619 L
.988 .26187 L
.992 .26184 L
.996 .26191 L
1 .26198 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16282 L
.012 .16117 L
.016 .16063 L
.02 .16125 L
.024 .16139 L
.028 .1612 L
.032 .16113 L
.036 .16121 L
.04 .16121 L
.044 .16121 L
.048 .16119 L
.052 .16121 L
.056 .1612 L
.06 .1612 L
.064 .16119 L
.068 .1612 L
.072 .16119 L
.076 .1612 L
.08 .1612 L
.084 .1612 L
.088 .16119 L
.092 .16119 L
.096 .16119 L
.1 .16119 L
.104 .16119 L
.108 .1612 L
.112 .16119 L
.116 .16119 L
.12 .16118 L
.124 .16119 L
.128 .16119 L
.132 .16119 L
.136 .16119 L
.14 .16118 L
.144 .16118 L
.148 .16118 L
.152 .16118 L
.156 .16118 L
.16 .16118 L
.164 .16118 L
.168 .16118 L
.172 .16118 L
.176 .16118 L
.18 .16118 L
.184 .16117 L
.188 .16117 L
.192 .16117 L
.196 .16117 L
.2 .16117 L
Mistroke
.204 .16117 L
.208 .16117 L
.212 .16117 L
.216 .16116 L
.22 .16117 L
.224 .16117 L
.228 .16117 L
.232 .16117 L
.236 .16117 L
.24 .16116 L
.244 .16116 L
.248 .16116 L
.252 .16116 L
.256 .16117 L
.26 .16117 L
.264 .16116 L
.268 .16116 L
.272 .16115 L
.276 .16115 L
.28 .16115 L
.284 .16116 L
.288 .16116 L
.292 .16115 L
.296 .16115 L
.3 .16114 L
.304 .16113 L
.308 .16112 L
.312 .16111 L
.316 .1611 L
.32 .16108 L
.324 .16105 L
.328 .16101 L
.332 .16096 L
.336 .16089 L
.34 .1608 L
.344 .1607 L
.348 .16056 L
.352 .16037 L
.356 .16013 L
.36 .15983 L
.364 .15945 L
.368 .15899 L
.372 .15843 L
.376 .15775 L
.38 .15694 L
.384 .15596 L
.388 .15481 L
.392 .15347 L
.396 .15193 L
.4 .15018 L
Mistroke
.404 .14822 L
.408 .14604 L
.412 .14365 L
.416 .14107 L
.42 .13832 L
.424 .13543 L
.428 .13243 L
.432 .12937 L
.436 .12629 L
.44 .12324 L
.444 .12027 L
.448 .1174 L
.452 .11466 L
.456 .11206 L
.46 .10961 L
.464 .1073 L
.468 .10509 L
.472 .10295 L
.476 .10084 L
.48 .09869 L
.484 .09648 L
.488 .09416 L
.492 .09172 L
.496 .08914 L
.5 .08644 L
.504 .08365 L
.508 .08082 L
.512 .07801 L
.516 .07525 L
.52 .0726 L
.524 .07008 L
.528 .0677 L
.532 .06547 L
.536 .06336 L
.54 .06134 L
.544 .05938 L
.548 .05747 L
.552 .05561 L
.556 .0538 L
.56 .05208 L
.564 .05047 L
.568 .04903 L
.572 .0478 L
.576 .0468 L
.58 .04603 L
.584 .04546 L
.588 .04503 L
.592 .04468 L
.596 .04433 L
.6 .04388 L
Mistroke
.604 .04329 L
.608 .04253 L
.612 .04161 L
.616 .04057 L
.62 .03946 L
.624 .03832 L
.628 .0372 L
.632 .03614 L
.636 .03514 L
.64 .03421 L
.644 .03335 L
.648 .03255 L
.652 .03182 L
.656 .03116 L
.66 .03059 L
.664 .0301 L
.668 .02966 L
.672 .02923 L
.676 .02876 L
.68 .0282 L
.684 .02753 L
.688 .02677 L
.692 .02593 L
.696 .02511 L
.7 .0244 L
.704 .02389 L
.708 .02364 L
.712 .02365 L
.716 .02385 L
.72 .02416 L
.724 .0245 L
.728 .02478 L
.732 .02496 L
.736 .02504 L
.74 .02505 L
.744 .02504 L
.748 .02508 L
.752 .02522 L
.756 .02546 L
.76 .02575 L
.764 .02603 L
.768 .02623 L
.772 .02634 L
.776 .02637 L
.78 .02633 L
.784 .02625 L
.788 .02614 L
.792 .02604 L
.796 .02595 L
.8 .02591 L
Mistroke
.804 .0259 L
.808 .02589 L
.812 .02584 L
.816 .02573 L
.82 .02556 L
.824 .02538 L
.828 .02525 L
.832 .0252 L
.836 .02525 L
.84 .0254 L
.844 .02562 L
.848 .0259 L
.852 .02618 L
.856 .02639 L
.86 .02648 L
.864 .02639 L
.868 .02617 L
.872 .02591 L
.876 .02572 L
.88 .02566 L
.884 .02572 L
.888 .02583 L
.892 .02592 L
.896 .02592 L
.9 .02587 L
.904 .0258 L
.908 .02577 L
.912 .0258 L
.916 .02588 L
.92 .02597 L
.924 .02603 L
.928 .02605 L
.932 .02606 L
.936 .02607 L
.94 .02611 L
.944 .02615 L
.948 .02617 L
.952 .02614 L
.956 .02608 L
.96 .02597 L
.964 .02588 L
.968 .02583 L
.972 .02584 L
.976 .02589 L
.98 .02597 L
.984 .02604 L
.988 .0261 L
.992 .02613 L
.996 .0262 L
1 .02625 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008002Qoo`8004=oo`002goo0P002Woo0P000goo0`000goo00<007ooOol09Woo0`00@goo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool2000WOol01000Oomoo`0017oo0P00?7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000eoo`<000Aoo`8000Moo`<000Ao
o`<000=oo`80009oo`H000=oo`<000Aoo`8000=oo`D000=oo`8000Aoo`8000Aoo`D0009oo`<000Ao
o`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`0;Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002
Ool01P00Ool00000Ool0009oo`8000=oo`05001oogooOol00002Ool01000Oomoo`000goo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOol007oo0003Ool01000Oomoo`00
0Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
Ool00P000goo0P001goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol00Woo00@007oo0000009oo`04001oogoo0005Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`03001oogoo00]oo`@000=oo`04001oogoo0007Ool00`00Oomoo`02
Ool200001Goo001oogoo00000Woo00<007ooOol00goo0P000Woo10000goo00@007ooOol0009oo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogooOol007oo10000goo
00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo0P0037oo00<007ooOol017oo
00@007ooOol000Ioo`8000Aoo`800005Ool007ooOol00002Ool00`00Oomoo`02Ool2000017oo001o
o`001Woo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=o
o`07001oogooOol007oo00001Woo00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00<0
07ooOol00goo0P0017oo0P001Woo00<007ooOol01P000goo0P0017oo0`0017oo0P0017oo0P001Goo
0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`0ROol00`00Oomoo`0?Ool00`00Oomoo`0eOol0
029oo`80029oo`03001oogoo015oo`04001oogooOol30005Ool00`00Oomoo`0XOol0029oof<000ao
o`008Woo90000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Ool007oo00000Woo
00<007oo00000P000Woo1P0000Eoo`00000007oo00<00005Ool00000001oo`05000017oo000007oo
0P0037oo000ROol2000gOol00`00Ool00005Ool20003Ool2000017oo000000000Woo0`0000Eoo`00
000007oo00800003Ool0000000<00004Ool00000000=Ool0029oo`03001oogoo03Ioo`8000]oo`80
02Moo`008Woo0P00KGoo000ROol2001]Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool0
00]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000
Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]
Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yo
o`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo
0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001o
ogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomo
o`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`80
00Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol002Qoob@004Eoo`00:7oo00<007ooOol08Goo0`00@Woo000;Ool2
0004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0SOol30010Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`009goo0P00?goo
0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00
:Goo0`00?7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`02000;Ool30004Ool20007Ool30004Ool20004Ool4000017oo000000000goo0`0017oo0P000Woo
1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007oo
Ool000Moo`03001oogoo009oo`04001oogoo0002Ool01@00Oomoo`00Ool00`000goo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool20006Ool01000Oomoo`00
0Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0
3Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007oo00000`000Woo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002
Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo
00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`000goo00@007ooOomoo`P0009oo`03001oo`0000=oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03
001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007oo
Ool0009oo`8000=oo`03001oogoo00Aoob8000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uo
o`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool3
0004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00mo
o`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2
000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=o
o`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007oo
Ool000]oo`03001oogoo008004Eoob8000aoo`002Woo00@007ooOol000]oo`04001oogoo0010Ool6
000^Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0iOol6000cOol000Yoo`04001oogoo
0007Ool00`00Oomoo`04Ool2000gOol3000iOol000]oo`8000Qoo`D0009oo`03001oogoo03Aoo`<0
03]oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`00
17oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00
Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0Woo0P0000=oo`00Ool00Woo00D007ooOomoo`00009oo`04001oogoo0005Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00D007ooOol007oo0080009oo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007ooOol00P0017oo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo
00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool40005Ool01000Oomoogoo10000goo
00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001o
ogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@0
07ooOol000Qoo`8000Aoo`04001oogoo0002Ool200000goo001oo`03Ool20003Ool00`00Oomoo`04
Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L0
07ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomo
o`03Ool2000017oo000007oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`80
00Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0:7oo0P00B7oo000LOol00`00Oomoo`0V
Ool2001:Ool001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00
Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`00
0goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079o
o`002Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo
001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
0`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001o
ogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`02Ool0
0`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000G
Ool00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yo
o`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00
009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol0
2goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`80
00Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000L
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(21543\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31843 m
.008 .31787 L
.012 .31776 L
.016 .31772 L
.02 .31785 L
.024 .31795 L
.028 .3179 L
.032 .31787 L
.036 .31793 L
.04 .31796 L
.044 .31793 L
.048 .31791 L
.052 .31793 L
.056 .31798 L
.06 .318 L
.064 .318 L
.068 .31799 L
.072 .31797 L
.076 .31799 L
.08 .31803 L
.084 .31806 L
.088 .31808 L
.092 .31806 L
.096 .31803 L
.1 .31803 L
.104 .31807 L
.108 .31812 L
.112 .31816 L
.116 .31815 L
.12 .3181 L
.124 .31807 L
.128 .31808 L
.132 .31815 L
.136 .31821 L
.14 .31824 L
.144 .31822 L
.148 .31816 L
.152 .31812 L
.156 .31815 L
.16 .31822 L
.164 .3183 L
.168 .31832 L
.172 .31828 L
.176 .31823 L
.18 .31819 L
.184 .31821 L
.188 .31828 L
.192 .31835 L
.196 .31839 L
.2 .31838 L
Mistroke
.204 .31833 L
.208 .31828 L
.212 .31827 L
.216 .31831 L
.22 .31837 L
.224 .31843 L
.228 .31847 L
.232 .31846 L
.236 .3184 L
.24 .31833 L
.244 .31829 L
.248 .31834 L
.252 .31845 L
.256 .31854 L
.26 .31854 L
.264 .31845 L
.268 .31829 L
.272 .31814 L
.276 .31807 L
.28 .3181 L
.284 .31815 L
.288 .31808 L
.292 .31778 L
.296 .31727 L
.3 .31666 L
.304 .31604 L
.308 .31541 L
.312 .31467 L
.316 .31366 L
.32 .31222 L
.324 .31024 L
.328 .3077 L
.332 .30469 L
.336 .3013 L
.34 .29748 L
.344 .29305 L
.348 .28777 L
.352 .28151 L
.356 .27429 L
.36 .26623 L
.364 .25754 L
.368 .24847 L
.372 .23924 L
.376 .22996 L
.38 .22064 L
.384 .21141 L
.388 .20264 L
.392 .1949 L
.396 .18878 L
.4 .18469 L
Mistroke
.404 .18278 L
.408 .183 L
.412 .18519 L
.416 .18905 L
.42 .19427 L
.424 .20055 L
.428 .20762 L
.432 .21503 L
.436 .22208 L
.44 .22784 L
.444 .23151 L
.448 .23264 L
.452 .23124 L
.456 .2277 L
.46 .22268 L
.464 .217 L
.468 .21157 L
.472 .20715 L
.476 .20425 L
.48 .2032 L
.484 .2043 L
.488 .20777 L
.492 .2136 L
.496 .22133 L
.5 .23003 L
.504 .23857 L
.508 .24599 L
.512 .25166 L
.516 .25547 L
.52 .25779 L
.524 .25954 L
.528 .26191 L
.532 .26606 L
.536 .27263 L
.54 .28155 L
.544 .29214 L
.548 .3034 L
.552 .3142 L
.556 .3234 L
.56 .32986 L
.564 .33275 L
.568 .33175 L
.572 .32724 L
.576 .32017 L
.58 .31183 L
.584 .30355 L
.588 .29656 L
.592 .29186 L
.596 .28998 L
.6 .29077 L
Mistroke
.604 .29336 L
.608 .29659 L
.612 .29956 L
.616 .30199 L
.62 .30416 L
.624 .30654 L
.628 .30936 L
.632 .31254 L
.636 .3158 L
.64 .31861 L
.644 .32022 L
.648 .31969 L
.652 .31644 L
.656 .31083 L
.66 .30443 L
.664 .29945 L
.668 .29777 L
.672 .3001 L
.676 .30587 L
.68 .31377 L
.684 .32212 L
.688 .32919 L
.692 .33323 L
.696 .33303 L
.7 .32868 L
.704 .32191 L
.708 .31552 L
.712 .31195 L
.716 .31205 L
.72 .31496 L
.724 .31903 L
.728 .3229 L
.732 .32588 L
.736 .32752 L
.74 .3273 L
.744 .32488 L
.748 .3208 L
.752 .31665 L
.756 .3142 L
.76 .31421 L
.764 .31585 L
.768 .31757 L
.772 .31844 L
.776 .31881 L
.78 .3197 L
.784 .32135 L
.788 .3227 L
.792 .32217 L
.796 .31933 L
.8 .31559 L
Mistroke
.804 .31345 L
.808 .31452 L
.812 .3183 L
.816 .32265 L
.82 .32525 L
.824 .32533 L
.828 .32358 L
.832 .32113 L
.836 .31875 L
.84 .31648 L
.844 .3146 L
.848 .31415 L
.852 .31593 L
.856 .3199 L
.86 .32412 L
.864 .32582 L
.868 .32373 L
.872 .31875 L
.876 .31414 L
.88 .31319 L
.884 .31632 L
.888 .32157 L
.892 .32522 L
.896 .3247 L
.9 .32096 L
.904 .31651 L
.908 .31459 L
.912 .3165 L
.916 .32018 L
.92 .32332 L
.924 .32366 L
.928 .32094 L
.932 .31771 L
.936 .31566 L
.94 .31605 L
.944 .31871 L
.948 .3212 L
.952 .32257 L
.956 .32219 L
.96 .32016 L
.964 .31854 L
.968 .31777 L
.972 .31809 L
.976 .31964 L
.98 .32065 L
.984 .32089 L
.988 .32028 L
.992 .31876 L
.996 .31796 L
1 .31821 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .1541 m
.008 .15623 L
.012 .15689 L
.016 .15616 L
.02 .15593 L
.024 .15621 L
.028 .15626 L
.032 .15618 L
.036 .15614 L
.04 .15619 L
.044 .15619 L
.048 .15619 L
.052 .15617 L
.056 .15618 L
.06 .15618 L
.064 .15619 L
.068 .15618 L
.072 .15619 L
.076 .15618 L
.08 .15618 L
.084 .15618 L
.088 .15618 L
.092 .15618 L
.096 .15619 L
.1 .15618 L
.104 .15619 L
.108 .15618 L
.112 .15618 L
.116 .15618 L
.12 .15619 L
.124 .15618 L
.128 .15619 L
.132 .15618 L
.136 .15618 L
.14 .15618 L
.144 .15618 L
.148 .15618 L
.152 .15619 L
.156 .15618 L
.16 .15618 L
.164 .15618 L
.168 .15619 L
.172 .15619 L
.176 .15618 L
.18 .15618 L
.184 .15618 L
.188 .15619 L
.192 .15619 L
.196 .15619 L
.2 .15619 L
Mistroke
.204 .15618 L
.208 .15618 L
.212 .15618 L
.216 .15619 L
.22 .15619 L
.224 .15619 L
.228 .15619 L
.232 .15619 L
.236 .15618 L
.24 .15619 L
.244 .15619 L
.248 .15619 L
.252 .15619 L
.256 .15619 L
.26 .15619 L
.264 .15619 L
.268 .15619 L
.272 .1562 L
.276 .1562 L
.28 .15621 L
.284 .15622 L
.288 .15623 L
.292 .15624 L
.296 .15626 L
.3 .15629 L
.304 .15633 L
.308 .15638 L
.312 .15645 L
.316 .15654 L
.32 .15664 L
.324 .15678 L
.328 .15696 L
.332 .15718 L
.336 .15747 L
.34 .15782 L
.344 .15825 L
.348 .15877 L
.352 .15939 L
.356 .16014 L
.36 .16101 L
.364 .16204 L
.368 .16323 L
.372 .16458 L
.376 .1661 L
.38 .16779 L
.384 .16965 L
.388 .17166 L
.392 .17382 L
.396 .1761 L
.4 .17848 L
Mistroke
.404 .18092 L
.408 .18338 L
.412 .18583 L
.416 .18823 L
.42 .19056 L
.424 .19279 L
.428 .19491 L
.432 .19691 L
.436 .1988 L
.44 .20059 L
.444 .20232 L
.448 .20401 L
.452 .2057 L
.456 .20744 L
.46 .20925 L
.464 .21116 L
.468 .21318 L
.472 .21529 L
.476 .21748 L
.48 .21972 L
.484 .22198 L
.488 .2242 L
.492 .22635 L
.496 .22841 L
.5 .23034 L
.504 .23217 L
.508 .23388 L
.512 .2355 L
.516 .23706 L
.52 .23857 L
.524 .24004 L
.528 .24147 L
.532 .24286 L
.536 .24416 L
.54 .24534 L
.544 .24638 L
.548 .24724 L
.552 .24792 L
.556 .24842 L
.56 .24878 L
.564 .24906 L
.568 .24932 L
.572 .24963 L
.576 .25003 L
.58 .25056 L
.584 .25122 L
.588 .252 L
.592 .25286 L
.596 .25375 L
.6 .25465 L
Mistroke
.604 .25551 L
.608 .25632 L
.612 .25707 L
.616 .25777 L
.62 .25841 L
.624 .25899 L
.628 .25951 L
.632 .25997 L
.636 .26037 L
.64 .26072 L
.644 .26106 L
.648 .26141 L
.652 .26181 L
.656 .26228 L
.66 .26284 L
.664 .26346 L
.668 .26408 L
.672 .26465 L
.676 .26509 L
.68 .26537 L
.684 .26545 L
.688 .26536 L
.692 .26514 L
.696 .26485 L
.7 .26456 L
.704 .26434 L
.708 .26421 L
.712 .26413 L
.716 .26409 L
.72 .26404 L
.724 .26394 L
.728 .2638 L
.732 .26362 L
.736 .26342 L
.74 .26323 L
.744 .26307 L
.748 .26297 L
.752 .26294 L
.756 .26295 L
.76 .26299 L
.764 .26303 L
.768 .26307 L
.772 .26313 L
.776 .26319 L
.78 .26327 L
.784 .26334 L
.788 .2634 L
.792 .26343 L
.796 .26345 L
.8 .26347 L
Mistroke
.804 .26348 L
.808 .26346 L
.812 .26339 L
.816 .26326 L
.82 .2631 L
.824 .26294 L
.828 .26281 L
.832 .26272 L
.836 .26267 L
.84 .26265 L
.844 .26267 L
.848 .26271 L
.852 .26277 L
.856 .26283 L
.86 .26286 L
.864 .26288 L
.868 .2629 L
.872 .26294 L
.876 .26299 L
.88 .26301 L
.884 .26294 L
.888 .26279 L
.892 .26256 L
.896 .26234 L
.9 .2622 L
.904 .26218 L
.908 .26229 L
.912 .26245 L
.916 .26259 L
.92 .26267 L
.924 .26266 L
.928 .2626 L
.932 .26253 L
.936 .26244 L
.94 .26236 L
.944 .26228 L
.948 .2622 L
.952 .26213 L
.956 .2621 L
.96 .26212 L
.964 .26218 L
.968 .26224 L
.972 .26229 L
.976 .26228 L
.98 .26223 L
.984 .26215 L
.988 .26206 L
.992 .26199 L
.996 .26197 L
1 .26194 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16246 L
.012 .16129 L
.016 .16079 L
.02 .16117 L
.024 .16132 L
.028 .16124 L
.032 .16115 L
.036 .1612 L
.04 .1612 L
.044 .16121 L
.048 .16119 L
.052 .16121 L
.056 .1612 L
.06 .1612 L
.064 .16119 L
.068 .1612 L
.072 .16119 L
.076 .1612 L
.08 .16119 L
.084 .1612 L
.088 .16119 L
.092 .16119 L
.096 .16119 L
.1 .16119 L
.104 .16119 L
.108 .16119 L
.112 .16119 L
.116 .16119 L
.12 .16118 L
.124 .16119 L
.128 .16118 L
.132 .16119 L
.136 .16118 L
.14 .16118 L
.144 .16118 L
.148 .16118 L
.152 .16118 L
.156 .16118 L
.16 .16118 L
.164 .16118 L
.168 .16118 L
.172 .16117 L
.176 .16117 L
.18 .16117 L
.184 .16117 L
.188 .16118 L
.192 .16117 L
.196 .16117 L
.2 .16117 L
Mistroke
.204 .16117 L
.208 .16117 L
.212 .16117 L
.216 .16117 L
.22 .16117 L
.224 .16117 L
.228 .16117 L
.232 .16116 L
.236 .16116 L
.24 .16116 L
.244 .16116 L
.248 .16116 L
.252 .16116 L
.256 .16116 L
.26 .16116 L
.264 .16115 L
.268 .16114 L
.272 .16114 L
.276 .16114 L
.28 .16113 L
.284 .16112 L
.288 .16111 L
.292 .16108 L
.296 .16105 L
.3 .16102 L
.304 .16097 L
.308 .16092 L
.312 .16084 L
.316 .16073 L
.32 .16059 L
.324 .16041 L
.328 .16018 L
.332 .1599 L
.336 .15955 L
.34 .15912 L
.344 .15859 L
.348 .15794 L
.352 .15716 L
.356 .15622 L
.36 .15512 L
.364 .15384 L
.368 .15237 L
.372 .1507 L
.376 .1488 L
.38 .14669 L
.384 .14436 L
.388 .14184 L
.392 .13914 L
.396 .1363 L
.4 .13335 L
Mistroke
.404 .13031 L
.408 .12724 L
.412 .12418 L
.416 .12117 L
.42 .11826 L
.424 .11547 L
.428 .11282 L
.432 .11032 L
.436 .10796 L
.44 .10572 L
.444 .10356 L
.448 .10144 L
.452 .09931 L
.456 .09713 L
.46 .09486 L
.464 .09247 L
.468 .08996 L
.472 .08731 L
.476 .08457 L
.48 .08176 L
.484 .07894 L
.488 .07616 L
.492 .07346 L
.496 .07088 L
.5 .06844 L
.504 .06616 L
.508 .06401 L
.512 .06198 L
.516 .06002 L
.52 .05813 L
.524 .05627 L
.528 .05446 L
.532 .05271 L
.536 .05107 L
.54 .04957 L
.544 .04827 L
.548 .04718 L
.552 .04633 L
.556 .04569 L
.56 .04521 L
.564 .04483 L
.568 .04447 L
.572 .04407 L
.576 .04355 L
.58 .04288 L
.584 .04205 L
.588 .04107 L
.592 .03998 L
.596 .03884 L
.6 .0377 L
Mistroke
.604 .03659 L
.608 .03554 L
.612 .03458 L
.616 .0337 L
.62 .0329 L
.624 .03217 L
.628 .03151 L
.632 .03091 L
.636 .03037 L
.64 .02989 L
.644 .02944 L
.648 .02898 L
.652 .02846 L
.656 .02786 L
.66 .02717 L
.664 .0264 L
.668 .02561 L
.672 .02486 L
.676 .02426 L
.68 .02387 L
.684 .02373 L
.688 .02382 L
.692 .02408 L
.696 .02443 L
.7 .02478 L
.704 .02506 L
.708 .02523 L
.712 .02531 L
.716 .02531 L
.72 .02531 L
.724 .02536 L
.728 .02549 L
.732 .02571 L
.736 .02598 L
.74 .02623 L
.744 .02643 L
.748 .02654 L
.752 .02658 L
.756 .02654 L
.76 .02644 L
.764 .02629 L
.768 .02614 L
.772 .02602 L
.776 .02594 L
.78 .02592 L
.784 .02591 L
.788 .02588 L
.792 .02581 L
.796 .02571 L
.8 .02561 L
Mistroke
.804 .02551 L
.808 .02546 L
.812 .02546 L
.816 .02556 L
.82 .02577 L
.824 .02606 L
.828 .02636 L
.832 .02659 L
.836 .02666 L
.84 .02656 L
.844 .02635 L
.848 .0261 L
.852 .02591 L
.856 .02582 L
.86 .02581 L
.864 .02585 L
.868 .0259 L
.872 .02594 L
.876 .02599 L
.88 .02603 L
.884 .02607 L
.888 .02611 L
.892 .02613 L
.896 .02615 L
.9 .02617 L
.904 .0262 L
.908 .02623 L
.912 .02623 L
.916 .02623 L
.92 .02622 L
.924 .02622 L
.928 .02622 L
.932 .02621 L
.936 .02617 L
.94 .02611 L
.944 .02602 L
.948 .02596 L
.952 .02597 L
.956 .02606 L
.96 .02622 L
.964 .0264 L
.968 .02651 L
.972 .02656 L
.976 .0265 L
.98 .02639 L
.984 .02627 L
.988 .02618 L
.992 .02613 L
.996 .02614 L
1 .02613 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008002Eoo`8004Ioo`002goo0P002Woo0P000goo0`000goo00<007ooOol08goo0P0000=oo`00Ool0
A7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2000TOol01000Oomoo`001Goo00<0
07ooOol0?Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000eoo`<0
00Aoo`8000Moo`<000Aoo`80009oo`03001oo`0000800004Ool007ooOol30003Ool30004Ool20003
Ool50003Ool20004Ool20004Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol02goo00D007ooOomoo`00009oo`04001o
ogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00H007oo000007oo0003Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009o
o`03001oogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`@0009oo`04001oogoo0007Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool01000Oomoogoo0P00
0Woo00@007ooOol0009oo`03001oogoo00800003Ool007oo00Ioo`04001oogoo0002Ool00`00Oomo
o`03Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
00<007ooOol02goo10000goo00@007ooOol000Moo`04001oogooOol20002Ool01000Oomoo`000Woo
00L007ooOomoo`00Ool00003Ool40003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2
000:Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P000Woo
00<007oo00000Woo00@007ooOol0009oo`03001oogoo009oo`8000=oo`03001oogoo00Aoo`04001o
ogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo
001oo`0000Ioo`04001oogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`04001oogoo0002Ool2
0004Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@00
0goo0P001Woo000ROol00`00Oomoo`0OOol00`00Oomoo`0@Ool00`00Oomoo`0gOol0029oo`8001mo
o`80019oo`04001oogooOol30005Ool00`00Oomoo`0[Ool0029oof<000aoo`008Woo8@000Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`0200001Goo001oo`00Ool00P0000Ao
o`00Ool0009oo`<00003Ool0000000800003Ool00000009oo`800004Ool00000Ool5000017oo0000
07oo0P0037oo000ROol2000dOol00`00Ool00006Ool01000Oomoogoo0`0000Aoo`000000009oo`<0
0003Ool00000009oo`800003Ool0000000P000ioo`008Woo00<007ooOol0=7oo00<007ooOol02Woo
00<007ooOol0:7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001o
ogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol0
00Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001o
ogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`00
2goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`00
0goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029o
o`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=o
o`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo
0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo
0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`80
00Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo8P00Agoo000XOol00`00Oomoo`0NOol30015
Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo025oo`8004=o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000T
Ool30011Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04
001oogoo000VOol3000oOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000=oo`<000=oo`<000=oo`<000Aoo`80
009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04
001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo00000P000Woo00D007ooOomo
o`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool0
1@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo
0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007ooOol01@001goo00@0
07ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03
001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol0009oo`@000Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03
Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oogoo00L00007Ool007ooOol007oo00000goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo
00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000
Oomoo`000Woo0P000goo00<007ooOol00Woo90000goo00@007ooOol000Eoo`00:7oo00<007ooOol0
2Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=o
o`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol0
3goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1VOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]o
o`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P00
0goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000
Oomoo`002goo00<007ooOol00P00@Woo9@0037oo000:Ool01000Oomoo`002goo00@007ooOol003io
o`H0031oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo03Ioo`H003Ioo`002Woo00@007oo
Ool000Moo`03001oogoo00Aoo`8003Aoo`<003aoo`002goo0P0027oo1@000Woo00<007ooOol0<Goo
0`00?Woo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20002Ool2000017oo
000000000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000L
Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002
Ool00`00Oomoo`020004Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Ool000001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009o
o`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool200000goo001oo`04Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool4
0003Ool01000Oomoo`002Goo00<007ooOol00Woo00<007ooOol010000Woo00<007ooOol00goo00@0
07ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03
001oogoo00Aoo`04001oogoo0008Ool20004Ool00`00Oomoo`0200001Goo001oogoo000017oo0P00
0goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo
0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`80
00Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol09Goo0P00Bgoo000LOol00`00
Oomoo`0SOol3001<Ool001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol0
0Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04
001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Mo
o`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomo
o`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00
Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1b
Ool000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007oo
Oomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<0
07ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol0
00Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(21710\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31703 m
.008 .31739 L
.012 .31813 L
.016 .31825 L
.02 .31776 L
.024 .31763 L
.028 .31786 L
.032 .31792 L
.036 .31786 L
.04 .31789 L
.044 .31796 L
.048 .31795 L
.052 .31789 L
.056 .31787 L
.06 .31791 L
.064 .31796 L
.068 .318 L
.072 .31801 L
.076 .31799 L
.08 .31797 L
.084 .31797 L
.088 .31799 L
.092 .31803 L
.096 .31805 L
.1 .31806 L
.104 .31805 L
.108 .31805 L
.112 .31806 L
.116 .31807 L
.12 .31808 L
.124 .31809 L
.128 .31811 L
.132 .31813 L
.136 .31815 L
.14 .31815 L
.144 .31814 L
.148 .31813 L
.152 .31814 L
.156 .31817 L
.16 .31821 L
.164 .31825 L
.168 .31824 L
.172 .3182 L
.176 .31817 L
.18 .31818 L
.184 .31823 L
.188 .3183 L
.192 .31834 L
.196 .31832 L
.2 .31827 L
Mistroke
.204 .31822 L
.208 .31822 L
.212 .31827 L
.216 .31835 L
.22 .3184 L
.224 .31839 L
.228 .31832 L
.232 .31824 L
.236 .31819 L
.24 .31819 L
.244 .31821 L
.248 .31823 L
.252 .31817 L
.256 .31801 L
.26 .31775 L
.264 .31744 L
.268 .31711 L
.272 .31676 L
.276 .31632 L
.28 .31571 L
.284 .31484 L
.288 .31363 L
.292 .31205 L
.296 .31015 L
.3 .30794 L
.304 .30539 L
.308 .30232 L
.312 .29853 L
.316 .29391 L
.32 .28843 L
.324 .28217 L
.328 .27521 L
.332 .26764 L
.336 .25947 L
.34 .2507 L
.344 .24132 L
.348 .23146 L
.352 .22147 L
.356 .21184 L
.36 .20303 L
.364 .1954 L
.368 .18915 L
.372 .18449 L
.376 .18156 L
.38 .18049 L
.384 .18141 L
.388 .18441 L
.392 .18944 L
.396 .19613 L
.4 .20378 L
Mistroke
.404 .21149 L
.408 .21846 L
.412 .22408 L
.416 .22799 L
.42 .22994 L
.424 .22986 L
.428 .22784 L
.432 .2241 L
.436 .21899 L
.44 .21309 L
.444 .20727 L
.448 .20264 L
.452 .20025 L
.456 .20072 L
.46 .2041 L
.464 .20995 L
.468 .21748 L
.472 .2258 L
.476 .234 L
.48 .24136 L
.484 .24748 L
.488 .25234 L
.492 .25617 L
.496 .25931 L
.5 .26222 L
.504 .26558 L
.508 .27021 L
.512 .27686 L
.516 .28581 L
.52 .29664 L
.524 .30828 L
.528 .31924 L
.532 .32794 L
.536 .33301 L
.54 .33365 L
.544 .32992 L
.548 .32281 L
.552 .31397 L
.556 .30519 L
.56 .29785 L
.564 .29275 L
.568 .29013 L
.572 .28981 L
.576 .2913 L
.58 .2939 L
.584 .29689 L
.588 .29978 L
.592 .3025 L
.596 .30527 L
.6 .30831 L
Mistroke
.604 .31156 L
.608 .3147 L
.612 .31725 L
.616 .31874 L
.62 .3187 L
.624 .31676 L
.628 .31285 L
.632 .30755 L
.636 .30226 L
.64 .29879 L
.644 .29863 L
.648 .30227 L
.652 .30903 L
.656 .31736 L
.66 .32539 L
.664 .33132 L
.668 .33373 L
.672 .33199 L
.676 .32674 L
.68 .31988 L
.684 .31404 L
.688 .31132 L
.692 .31231 L
.696 .31602 L
.7 .32066 L
.704 .32466 L
.708 .32709 L
.712 .32758 L
.716 .32605 L
.72 .32282 L
.724 .31885 L
.728 .31561 L
.732 .31425 L
.736 .3149 L
.74 .31652 L
.744 .31783 L
.748 .31835 L
.752 .31867 L
.756 .31957 L
.76 .321 L
.764 .3219 L
.768 .32116 L
.772 .31883 L
.776 .31628 L
.78 .31525 L
.784 .31645 L
.788 .3191 L
.792 .32174 L
.796 .32331 L
.8 .3237 L
Mistroke
.804 .32325 L
.808 .32194 L
.812 .31961 L
.816 .3165 L
.82 .31392 L
.824 .31372 L
.828 .31654 L
.832 .32114 L
.836 .32462 L
.84 .32451 L
.844 .32093 L
.848 .31639 L
.852 .3142 L
.856 .31597 L
.86 .32013 L
.864 .3237 L
.868 .32417 L
.872 .3214 L
.876 .31784 L
.88 .3158 L
.884 .3164 L
.888 .31884 L
.892 .32091 L
.896 .32167 L
.9 .32109 L
.904 .31988 L
.908 .31923 L
.912 .31881 L
.916 .31836 L
.92 .31806 L
.924 .31785 L
.928 .31868 L
.932 .32046 L
.936 .32195 L
.94 .32257 L
.944 .32137 L
.948 .31892 L
.952 .31704 L
.956 .31641 L
.96 .31764 L
.964 .31994 L
.968 .32147 L
.972 .32184 L
.976 .32077 L
.98 .319 L
.984 .318 L
.988 .31789 L
.992 .31889 L
.996 .32035 L
1 .32113 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15452 m
.008 .1565 L
.012 .15715 L
.016 .15659 L
.02 .15632 L
.024 .15651 L
.028 .15658 L
.032 .15655 L
.036 .1565 L
.04 .15653 L
.044 .15653 L
.048 .15654 L
.052 .15652 L
.056 .15653 L
.06 .15652 L
.064 .15653 L
.068 .15653 L
.072 .15654 L
.076 .15653 L
.08 .15653 L
.084 .15652 L
.088 .15653 L
.092 .15653 L
.096 .15654 L
.1 .15653 L
.104 .15653 L
.108 .15653 L
.112 .15653 L
.116 .15653 L
.12 .15653 L
.124 .15653 L
.128 .15653 L
.132 .15653 L
.136 .15653 L
.14 .15653 L
.144 .15653 L
.148 .15653 L
.152 .15654 L
.156 .15653 L
.16 .15653 L
.164 .15653 L
.168 .15653 L
.172 .15653 L
.176 .15653 L
.18 .15653 L
.184 .15653 L
.188 .15653 L
.192 .15653 L
.196 .15653 L
.2 .15653 L
Mistroke
.204 .15653 L
.208 .15653 L
.212 .15653 L
.216 .15654 L
.22 .15654 L
.224 .15654 L
.228 .15654 L
.232 .15654 L
.236 .15654 L
.24 .15654 L
.244 .15655 L
.248 .15655 L
.252 .15656 L
.256 .15656 L
.26 .15657 L
.264 .15659 L
.268 .15661 L
.272 .15664 L
.276 .15667 L
.28 .15672 L
.284 .15678 L
.288 .15686 L
.292 .15696 L
.296 .15709 L
.3 .15727 L
.304 .15748 L
.308 .15775 L
.312 .15808 L
.316 .15848 L
.32 .15897 L
.324 .15957 L
.328 .16028 L
.332 .16112 L
.336 .16211 L
.34 .16324 L
.344 .16454 L
.348 .166 L
.352 .16763 L
.356 .16944 L
.36 .17141 L
.364 .17353 L
.368 .17577 L
.372 .17811 L
.376 .18052 L
.38 .18296 L
.384 .18542 L
.388 .18784 L
.392 .1902 L
.396 .19247 L
.4 .19463 L
Mistroke
.404 .19667 L
.408 .1986 L
.412 .20042 L
.416 .20217 L
.42 .20387 L
.424 .20556 L
.428 .20728 L
.432 .20906 L
.436 .21093 L
.44 .21289 L
.444 .21495 L
.448 .21711 L
.452 .21933 L
.456 .22158 L
.46 .22381 L
.464 .226 L
.468 .22809 L
.472 .23008 L
.476 .23194 L
.48 .23369 L
.484 .23534 L
.488 .2369 L
.492 .23841 L
.496 .23988 L
.5 .24131 L
.504 .2427 L
.508 .24402 L
.512 .24523 L
.516 .24632 L
.52 .24725 L
.524 .24799 L
.528 .24856 L
.532 .24898 L
.536 .2493 L
.54 .24957 L
.544 .24984 L
.548 .25019 L
.552 .25065 L
.556 .25125 L
.56 .25197 L
.564 .25279 L
.568 .25368 L
.572 .2546 L
.576 .25549 L
.58 .25634 L
.584 .25712 L
.588 .25782 L
.592 .25847 L
.596 .25905 L
.6 .25959 L
Mistroke
.604 .26007 L
.608 .2605 L
.612 .26089 L
.616 .26124 L
.62 .26159 L
.624 .26196 L
.628 .26238 L
.632 .26287 L
.636 .26344 L
.64 .26404 L
.644 .26464 L
.648 .26515 L
.652 .26552 L
.656 .2657 L
.66 .26569 L
.664 .26552 L
.668 .26523 L
.672 .26491 L
.676 .26463 L
.68 .26443 L
.684 .26431 L
.688 .26427 L
.692 .26425 L
.696 .2642 L
.7 .2641 L
.704 .26395 L
.708 .26374 L
.712 .26353 L
.716 .26333 L
.72 .26319 L
.724 .26312 L
.728 .26313 L
.732 .26318 L
.736 .26326 L
.74 .26333 L
.744 .26338 L
.748 .26343 L
.752 .26347 L
.756 .26351 L
.76 .26355 L
.764 .26359 L
.768 .26363 L
.772 .26368 L
.776 .26372 L
.78 .26374 L
.784 .2637 L
.788 .26359 L
.792 .26342 L
.796 .26323 L
.8 .26304 L
Mistroke
.804 .2629 L
.808 .26282 L
.812 .26281 L
.816 .26286 L
.82 .26296 L
.824 .26307 L
.828 .26314 L
.832 .26316 L
.836 .26312 L
.84 .26307 L
.844 .26304 L
.848 .26307 L
.852 .26312 L
.856 .26315 L
.86 .2631 L
.864 .26297 L
.868 .26278 L
.872 .26261 L
.876 .2625 L
.88 .26247 L
.884 .26252 L
.888 .26261 L
.892 .26271 L
.896 .26279 L
.9 .26284 L
.904 .26284 L
.908 .2628 L
.912 .2627 L
.916 .26259 L
.92 .26247 L
.924 .26238 L
.928 .26234 L
.932 .26233 L
.936 .26235 L
.94 .26238 L
.944 .26241 L
.948 .26244 L
.952 .26245 L
.956 .26245 L
.96 .26241 L
.964 .26233 L
.968 .26222 L
.972 .26212 L
.976 .26205 L
.98 .26205 L
.984 .26209 L
.988 .26216 L
.992 .2622 L
.996 .26221 L
1 .26217 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .1598 L
.012 .16129 L
.016 .16168 L
.02 .16118 L
.024 .16102 L
.028 .16123 L
.032 .16125 L
.036 .16121 L
.04 .16117 L
.044 .16121 L
.048 .1612 L
.052 .1612 L
.056 .16119 L
.06 .16121 L
.064 .1612 L
.068 .1612 L
.072 .16119 L
.076 .1612 L
.08 .16119 L
.084 .1612 L
.088 .16119 L
.092 .1612 L
.096 .16119 L
.1 .16119 L
.104 .16119 L
.108 .16119 L
.112 .16119 L
.116 .16119 L
.12 .16118 L
.124 .16119 L
.128 .16118 L
.132 .16119 L
.136 .16118 L
.14 .16118 L
.144 .16118 L
.148 .16118 L
.152 .16118 L
.156 .16118 L
.16 .16118 L
.164 .16118 L
.168 .16117 L
.172 .16117 L
.176 .16117 L
.18 .16117 L
.184 .16117 L
.188 .16118 L
.192 .16117 L
.196 .16117 L
.2 .16117 L
Mistroke
.204 .16117 L
.208 .16117 L
.212 .16117 L
.216 .16117 L
.22 .16117 L
.224 .16116 L
.228 .16116 L
.232 .16116 L
.236 .16116 L
.24 .16115 L
.244 .16115 L
.248 .16114 L
.252 .16114 L
.256 .16112 L
.26 .16111 L
.264 .16109 L
.268 .16107 L
.272 .16103 L
.276 .16099 L
.28 .16093 L
.284 .16085 L
.288 .16075 L
.292 .16062 L
.296 .16045 L
.3 .16025 L
.304 .15998 L
.308 .15965 L
.312 .15924 L
.316 .15872 L
.32 .1581 L
.324 .15736 L
.328 .15648 L
.332 .15544 L
.336 .15422 L
.34 .1528 L
.344 .15118 L
.348 .14934 L
.352 .1473 L
.356 .14505 L
.36 .1426 L
.364 .13997 L
.368 .13718 L
.372 .13425 L
.376 .13124 L
.38 .12817 L
.384 .12511 L
.388 .12208 L
.392 .11914 L
.396 .11631 L
.4 .11361 L
Mistroke
.404 .11106 L
.408 .10864 L
.412 .10635 L
.416 .10416 L
.42 .10204 L
.424 .09992 L
.428 .09778 L
.432 .09555 L
.436 .09322 L
.44 .09075 L
.444 .08816 L
.448 .08546 L
.452 .08268 L
.456 .07987 L
.46 .07707 L
.464 .07434 L
.468 .07171 L
.472 .06922 L
.476 .06688 L
.48 .06468 L
.484 .06261 L
.488 .06064 L
.492 .05875 L
.496 .0569 L
.5 .0551 L
.504 .05336 L
.508 .0517 L
.512 .05016 L
.516 .04878 L
.52 .04761 L
.524 .04665 L
.528 .04592 L
.532 .04538 L
.536 .04497 L
.54 .04463 L
.544 .04426 L
.548 .0438 L
.552 .04321 L
.556 .04244 L
.56 .04152 L
.564 .04047 L
.568 .03934 L
.572 .0382 L
.576 .03707 L
.58 .036 L
.584 .035 L
.588 .03409 L
.592 .03325 L
.596 .03249 L
.6 .03181 L
Mistroke
.604 .03119 L
.608 .03065 L
.612 .03015 L
.616 .02969 L
.62 .02924 L
.624 .02874 L
.628 .02817 L
.632 .02752 L
.636 .0268 L
.64 .02604 L
.644 .02529 L
.648 .02465 L
.652 .02417 L
.656 .02391 L
.66 .02389 L
.664 .02407 L
.668 .02438 L
.672 .02474 L
.676 .02507 L
.68 .02532 L
.684 .02547 L
.688 .02552 L
.692 .02554 L
.696 .02556 L
.7 .02564 L
.704 .02579 L
.708 .02601 L
.712 .02625 L
.716 .02646 L
.72 .02662 L
.724 .0267 L
.728 .02671 L
.732 .02666 L
.736 .02655 L
.74 .02641 L
.744 .02627 L
.748 .02615 L
.752 .02606 L
.756 .026 L
.76 .02595 L
.764 .0259 L
.768 .02585 L
.772 .0258 L
.776 .02576 L
.78 .02573 L
.784 .02572 L
.788 .02575 L
.792 .02585 L
.796 .02603 L
.8 .02627 L
Mistroke
.804 .02651 L
.808 .02668 L
.812 .02673 L
.816 .02665 L
.82 .02649 L
.824 .0263 L
.828 .02613 L
.832 .02601 L
.836 .02594 L
.84 .02592 L
.844 .02595 L
.848 .02601 L
.852 .0261 L
.856 .02618 L
.86 .02626 L
.864 .02633 L
.868 .02639 L
.872 .02644 L
.876 .02646 L
.88 .02643 L
.884 .02635 L
.888 .02626 L
.892 .0262 L
.896 .02622 L
.9 .0263 L
.904 .0264 L
.908 .02645 L
.912 .02641 L
.916 .02631 L
.92 .02618 L
.924 .02612 L
.928 .02615 L
.932 .02627 L
.936 .02643 L
.94 .02656 L
.944 .02661 L
.948 .02662 L
.952 .02658 L
.956 .02652 L
.96 .02645 L
.964 .02638 L
.968 .02629 L
.972 .02623 L
.976 .02618 L
.98 .02622 L
.984 .02632 L
.988 .02648 L
.992 .02664 L
.996 .02676 L
1 .02678 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
0080029oo`<004Qoo`002goo0P002Woo0P000goo0`000goo00<007ooOol08Goo00<007oo0000B7oo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2000QOol01@00Oomoogoo000017oo0P00
@Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000eoo`<000Aoo`80
00Moo`<00004Ool007ooOol30002Ool30005Ool30003Ool30004Ool20003Ool50003Ool20004Ool2
0004Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol02goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Ool0
0002Ool01@00Oomoo`00Ool00P000Woo00<007ooOol00goo00D007ooOomoo`0000=oo`04001oogoo
0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001o
o`00009oo`03001oogoo00@0009oo`8000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oo`00009oo`04001oogoo0002Ool0
0`00Oomoo`020004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00]oo`@0
00=oo`04001oogoo0007Ool20003Ool01000Oomoo`000Woo00<007ooOol00`000goo00@007ooOomo
o`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003
Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo
009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool30003Ool01000Oomoo`000Woo00D007oo
Ool007oo00800003Ool0000000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`03001oo`0000=o
o`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007oo
Ool077oo0P004Goo00<007ooOol0>Woo000ROol2000MOol00`00Oomoo`0AOol01000Oomoogoo0`00
1Goo00<007ooOol0;Goo000ROomS000<Ool0029ooah00003Ool007oo009oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo0P0000=oo`0000000goo100000=oo`00Ool00`0000=oo`0000001`00
00=oo`0000001P0000=oo`000000100000Aoo`00000000aoo`008Woo0P00<Woo00<007oo00002Goo
00@007oo001oo`<000=oo`800005Ool00000001oo`02000017oo000007oo0P000Woo0P0000Aoo`00
001oo`8000aoo`008Woo00<007ooOol0<Goo0P002goo0P00;7oo000ROol2001]Ool0029oo`8006eo
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`80
00Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P00
0Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2
001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo
000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001o
ogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol0
0`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P00
0goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo
0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00
Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001o
ogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomo
ogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03
001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
4Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004
Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo
7`00BWoo000XOol00`00Oomoo`0KOol40017Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`80
00=oo`<000=oo`03001oogoo01ioo`8004Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1P00Oomoo`00Ool000=oo`04001oogoo000ROol20014Ool000=oo`D0009oo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000TOol30011Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Ao
o`800003Ool0000000<000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009o
o`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool01000
0goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000
Oomoo`000Woo10000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0
009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool0
00Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00<007oo00000P000Woo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004
Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007ooOol01@001goo00@007ooOol0
009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@0
07ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo20000goo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00003
0003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo
0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`0V0003Ool01000Oomo
o`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool0
1000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool0
0`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool3
0003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005
Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool0
0`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool0
00Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo
0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03
001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomo
o`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo0080
06Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogoo
Ool5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009o
o`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`020010OolW000<Ool000Yoo`04001o
ogoo000;Ool01000Oomoo`00>goo1P00<goo000:Ool01000Oomoo`001goo10000goo00<007ooOol0
<goo1P00>Goo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00<Goo1000?Woo000;Ool20008
Ool50002Ool00`00Oomoo`0_Ool20011Ool001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Ao
o`8000Aoo`<000Aoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Ao
o`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo10001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool01@00Oomoo`00Ool00P000Woo00<007ooOol00goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007oo
Ool0009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00800005Ool007ooOol00005Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo
0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2
000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007oo0000009oo`04001oogoo0005
Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol0
37oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`800005Ool007ooOol00002Ool00`00Oomo
o`02Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=
Ool50003Ool2000:Ool01000Oomoogoo100017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<0
00Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol08Woo0P00CWoo000L
Ool00`00Oomoo`0POol3001?Ool001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo
009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo
009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00
Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<0
07ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol0
00]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1b
Ool001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol0
0`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P00
17oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo
00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`00
2goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomo
o`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@00
0Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(21877\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31699 m
.008 .31767 L
.012 .31799 L
.016 .31809 L
.02 .31784 L
.024 .31769 L
.028 .31776 L
.032 .31783 L
.036 .31784 L
.04 .31788 L
.044 .31793 L
.048 .31793 L
.052 .31787 L
.056 .31782 L
.06 .31785 L
.064 .31792 L
.068 .31798 L
.072 .318 L
.076 .31796 L
.08 .31791 L
.084 .3179 L
.088 .31794 L
.092 .31801 L
.096 .31806 L
.1 .31805 L
.104 .31801 L
.108 .31798 L
.112 .31798 L
.116 .31803 L
.12 .31808 L
.124 .31811 L
.128 .31811 L
.132 .31808 L
.136 .31806 L
.14 .31806 L
.144 .3181 L
.148 .31814 L
.152 .31817 L
.156 .31817 L
.16 .31816 L
.164 .31815 L
.168 .31815 L
.172 .31816 L
.176 .31818 L
.18 .3182 L
.184 .31823 L
.188 .31824 L
.192 .31823 L
.196 .3182 L
.2 .31817 L
Mistroke
.204 .31816 L
.208 .31817 L
.212 .31819 L
.216 .31818 L
.22 .31811 L
.224 .31797 L
.228 .31779 L
.232 .31761 L
.236 .31744 L
.24 .31722 L
.244 .31687 L
.248 .31636 L
.252 .31563 L
.256 .3147 L
.26 .31356 L
.264 .3122 L
.268 .31057 L
.272 .30854 L
.276 .30598 L
.28 .30279 L
.284 .29895 L
.288 .29445 L
.292 .28927 L
.296 .2834 L
.3 .27678 L
.304 .26938 L
.308 .26115 L
.312 .25215 L
.316 .24257 L
.32 .23271 L
.324 .2229 L
.328 .21339 L
.332 .20443 L
.336 .19625 L
.34 .18917 L
.344 .18352 L
.348 .17966 L
.352 .17792 L
.356 .1785 L
.36 .18132 L
.364 .186 L
.368 .19206 L
.372 .19898 L
.376 .20627 L
.38 .21344 L
.384 .21991 L
.388 .22507 L
.392 .2284 L
.396 .22947 L
.4 .22807 L
Mistroke
.404 .22438 L
.408 .21903 L
.412 .21297 L
.416 .20723 L
.42 .20269 L
.424 .19994 L
.428 .19939 L
.432 .20124 L
.436 .20545 L
.44 .21174 L
.444 .2196 L
.448 .22833 L
.452 .23708 L
.456 .24495 L
.46 .25114 L
.464 .2554 L
.468 .25811 L
.472 .26022 L
.476 .26289 L
.48 .26711 L
.484 .2735 L
.488 .28215 L
.492 .2926 L
.496 .30385 L
.5 .31458 L
.504 .32352 L
.508 .32965 L
.512 .33233 L
.516 .33128 L
.52 .32665 L
.524 .31912 L
.528 .30996 L
.532 .30083 L
.536 .29329 L
.54 .28846 L
.544 .28678 L
.548 .28797 L
.552 .29124 L
.556 .29543 L
.56 .29942 L
.564 .30252 L
.568 .30471 L
.572 .30653 L
.576 .30871 L
.58 .31155 L
.584 .31479 L
.588 .3176 L
.592 .31903 L
.596 .31833 L
.6 .31525 L
Mistroke
.604 .31021 L
.608 .30439 L
.612 .29952 L
.616 .29741 L
.62 .29921 L
.624 .30489 L
.628 .31316 L
.632 .32198 L
.636 .32923 L
.64 .33331 L
.644 .33349 L
.648 .32995 L
.652 .32393 L
.656 .31742 L
.66 .31267 L
.664 .3112 L
.668 .31323 L
.672 .3176 L
.676 .32245 L
.68 .32616 L
.684 .32781 L
.688 .32723 L
.692 .32474 L
.696 .32104 L
.7 .31723 L
.704 .31454 L
.708 .31378 L
.712 .31486 L
.716 .31676 L
.72 .31835 L
.724 .31916 L
.728 .31953 L
.732 .31999 L
.736 .32056 L
.74 .32061 L
.744 .31963 L
.748 .3179 L
.752 .31651 L
.756 .31652 L
.76 .31806 L
.764 .3203 L
.768 .32217 L
.772 .3231 L
.776 .32312 L
.78 .32236 L
.784 .32066 L
.788 .31806 L
.792 .31532 L
.796 .31394 L
.8 .31524 L
Mistroke
.804 .31888 L
.808 .3228 L
.812 .32439 L
.816 .32243 L
.82 .31835 L
.824 .315 L
.828 .31474 L
.832 .31767 L
.836 .32154 L
.84 .32388 L
.844 .3235 L
.848 .32108 L
.852 .3185 L
.856 .31686 L
.86 .31643 L
.864 .31696 L
.868 .31798 L
.872 .31969 L
.876 .32172 L
.88 .32298 L
.884 .32259 L
.888 .32003 L
.892 .31661 L
.896 .31471 L
.9 .31559 L
.904 .3191 L
.908 .32291 L
.912 .32422 L
.916 .3225 L
.92 .3189 L
.924 .31607 L
.928 .31616 L
.932 .31848 L
.936 .32121 L
.94 .32224 L
.944 .32066 L
.948 .31818 L
.952 .31669 L
.956 .31727 L
.96 .31974 L
.964 .32199 L
.968 .32259 L
.972 .32127 L
.976 .31878 L
.98 .31703 L
.984 .31685 L
.988 .31814 L
.992 .32023 L
.996 .32145 L
1 .32157 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15856 m
.008 .15684 L
.012 .15627 L
.016 .15694 L
.02 .15708 L
.024 .15686 L
.028 .15679 L
.032 .1569 L
.036 .1569 L
.04 .15688 L
.044 .15686 L
.048 .15689 L
.052 .15688 L
.056 .15688 L
.06 .15687 L
.064 .15688 L
.068 .15688 L
.072 .15688 L
.076 .15688 L
.08 .15688 L
.084 .15687 L
.088 .15688 L
.092 .15688 L
.096 .15688 L
.1 .15688 L
.104 .15688 L
.108 .15688 L
.112 .15688 L
.116 .15688 L
.12 .15688 L
.124 .15688 L
.128 .15688 L
.132 .15688 L
.136 .15688 L
.14 .15688 L
.144 .15688 L
.148 .15688 L
.152 .15688 L
.156 .15688 L
.16 .15688 L
.164 .15688 L
.168 .15688 L
.172 .15688 L
.176 .15688 L
.18 .15688 L
.184 .15688 L
.188 .15688 L
.192 .15688 L
.196 .15688 L
.2 .15688 L
Mistroke
.204 .15689 L
.208 .15689 L
.212 .15689 L
.216 .15689 L
.22 .15689 L
.224 .1569 L
.228 .15691 L
.232 .15692 L
.236 .15693 L
.24 .15695 L
.244 .15698 L
.248 .15701 L
.252 .15705 L
.256 .15711 L
.26 .15718 L
.264 .15728 L
.268 .15741 L
.272 .15757 L
.276 .15777 L
.28 .15802 L
.284 .15833 L
.288 .15872 L
.292 .15919 L
.296 .15976 L
.3 .16044 L
.304 .16124 L
.308 .16217 L
.312 .16326 L
.316 .16451 L
.32 .16592 L
.324 .16751 L
.328 .16926 L
.332 .17117 L
.336 .17324 L
.34 .17543 L
.344 .17774 L
.348 .18012 L
.352 .18256 L
.356 .18502 L
.36 .18746 L
.364 .18984 L
.368 .19214 L
.372 .19433 L
.376 .19641 L
.38 .19838 L
.384 .20025 L
.388 .20203 L
.392 .20374 L
.396 .20543 L
.4 .20713 L
Mistroke
.404 .20887 L
.408 .2107 L
.412 .21262 L
.416 .21464 L
.42 .21676 L
.424 .21895 L
.428 .22119 L
.432 .22342 L
.436 .22562 L
.44 .22775 L
.444 .22978 L
.448 .2317 L
.452 .23349 L
.456 .23517 L
.46 .23676 L
.464 .23827 L
.468 .23973 L
.472 .24115 L
.476 .24254 L
.48 .24386 L
.484 .24511 L
.488 .24624 L
.492 .24723 L
.496 .24805 L
.5 .24869 L
.504 .24917 L
.508 .24952 L
.512 .2498 L
.516 .25006 L
.52 .25037 L
.524 .25078 L
.528 .25131 L
.532 .25197 L
.536 .25276 L
.54 .25362 L
.544 .25453 L
.548 .25544 L
.552 .25631 L
.556 .25713 L
.56 .25787 L
.564 .25854 L
.568 .25914 L
.572 .25968 L
.576 .26018 L
.58 .26062 L
.584 .26101 L
.588 .26138 L
.592 .26174 L
.596 .26211 L
.6 .26251 L
Mistroke
.604 .26297 L
.608 .26349 L
.612 .26405 L
.616 .26462 L
.62 .26516 L
.624 .26559 L
.628 .26586 L
.632 .26595 L
.636 .26587 L
.64 .26564 L
.644 .26532 L
.648 .265 L
.652 .26472 L
.656 .26453 L
.66 .26443 L
.664 .2644 L
.668 .26439 L
.672 .26434 L
.676 .26424 L
.68 .26408 L
.684 .26387 L
.688 .26366 L
.692 .26348 L
.696 .26335 L
.7 .26331 L
.704 .26334 L
.708 .26341 L
.712 .26351 L
.716 .2636 L
.72 .26367 L
.724 .26372 L
.728 .26375 L
.732 .26378 L
.736 .2638 L
.74 .26382 L
.744 .26385 L
.748 .26388 L
.752 .26392 L
.756 .26392 L
.76 .26387 L
.764 .26376 L
.768 .26359 L
.772 .26339 L
.776 .2632 L
.78 .26305 L
.784 .26297 L
.788 .26297 L
.792 .26306 L
.796 .2632 L
.8 .26335 L
Mistroke
.804 .26344 L
.808 .26346 L
.812 .26341 L
.816 .26333 L
.82 .26327 L
.824 .26325 L
.828 .26324 L
.832 .26323 L
.836 .26318 L
.84 .26309 L
.844 .26298 L
.848 .26288 L
.852 .26281 L
.856 .26277 L
.86 .26278 L
.864 .26283 L
.868 .26289 L
.872 .26296 L
.876 .263 L
.88 .263 L
.884 .26296 L
.888 .26289 L
.892 .26282 L
.896 .26275 L
.9 .26269 L
.904 .26261 L
.908 .26254 L
.912 .26249 L
.916 .26248 L
.92 .26252 L
.924 .26261 L
.928 .26269 L
.932 .26272 L
.936 .26267 L
.94 .26256 L
.944 .26242 L
.948 .26233 L
.952 .26228 L
.956 .26229 L
.96 .26232 L
.964 .26235 L
.968 .26236 L
.972 .26235 L
.976 .26233 L
.98 .26233 L
.984 .26229 L
.988 .26226 L
.992 .26218 L
.996 .2621 L
1 .26202 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15967 L
.012 .16117 L
.016 .16168 L
.02 .16126 L
.024 .16103 L
.028 .16119 L
.032 .16125 L
.036 .16123 L
.04 .16118 L
.044 .1612 L
.048 .16119 L
.052 .1612 L
.056 .16119 L
.06 .16121 L
.064 .1612 L
.068 .1612 L
.072 .16119 L
.076 .16119 L
.08 .16119 L
.084 .1612 L
.088 .16119 L
.092 .1612 L
.096 .16119 L
.1 .16119 L
.104 .16118 L
.108 .16119 L
.112 .16119 L
.116 .16119 L
.12 .16119 L
.124 .16119 L
.128 .16118 L
.132 .16118 L
.136 .16118 L
.14 .16118 L
.144 .16118 L
.148 .16118 L
.152 .16118 L
.156 .16118 L
.16 .16118 L
.164 .16118 L
.168 .16117 L
.172 .16117 L
.176 .16117 L
.18 .16117 L
.184 .16117 L
.188 .16117 L
.192 .16117 L
.196 .16117 L
.2 .16116 L
Mistroke
.204 .16116 L
.208 .16116 L
.212 .16116 L
.216 .16115 L
.22 .16115 L
.224 .16114 L
.228 .16113 L
.232 .16112 L
.236 .1611 L
.24 .16108 L
.244 .16105 L
.248 .161 L
.252 .16094 L
.256 .16087 L
.26 .16078 L
.264 .16066 L
.268 .1605 L
.272 .1603 L
.276 .16005 L
.28 .15973 L
.284 .15934 L
.288 .15886 L
.292 .15828 L
.296 .15757 L
.3 .15673 L
.304 .15573 L
.308 .15456 L
.312 .1532 L
.316 .15164 L
.32 .14988 L
.324 .14791 L
.328 .14573 L
.332 .14334 L
.336 .14076 L
.34 .13802 L
.344 .13513 L
.348 .13215 L
.352 .12911 L
.356 .12605 L
.36 .12302 L
.364 .12004 L
.368 .11716 L
.372 .11441 L
.376 .1118 L
.38 .10934 L
.384 .10701 L
.388 .1048 L
.392 .10265 L
.396 .10053 L
.4 .0984 L
Mistroke
.404 .09621 L
.408 .09392 L
.412 .09152 L
.416 .08899 L
.42 .08635 L
.424 .0836 L
.428 .08081 L
.432 .078 L
.436 .07523 L
.44 .07256 L
.444 .07002 L
.448 .06762 L
.452 .06537 L
.456 .06327 L
.46 .06127 L
.464 .05936 L
.468 .05752 L
.472 .05573 L
.476 .05399 L
.48 .05232 L
.484 .05075 L
.488 .04932 L
.492 .04807 L
.496 .04703 L
.5 .04621 L
.504 .04559 L
.508 .04513 L
.512 .04476 L
.516 .04441 L
.52 .04401 L
.524 .04349 L
.528 .04281 L
.532 .04196 L
.536 .04097 L
.54 .03986 L
.544 .03871 L
.548 .03755 L
.552 .03644 L
.556 .03541 L
.56 .03447 L
.564 .03362 L
.568 .03285 L
.572 .03215 L
.576 .03151 L
.58 .03093 L
.584 .0304 L
.588 .02992 L
.592 .02946 L
.596 .02899 L
.6 .02848 L
Mistroke
.604 .02789 L
.608 .02722 L
.612 .02648 L
.616 .02573 L
.62 .02503 L
.624 .02447 L
.628 .02411 L
.632 .02399 L
.636 .02409 L
.64 .02436 L
.644 .02473 L
.648 .0251 L
.652 .0254 L
.656 .0256 L
.66 .02569 L
.664 .02572 L
.668 .02574 L
.672 .02578 L
.676 .02589 L
.68 .02608 L
.684 .02631 L
.688 .02653 L
.692 .02672 L
.696 .02683 L
.7 .02686 L
.704 .02682 L
.708 .02673 L
.712 .02661 L
.716 .02649 L
.72 .02637 L
.724 .02627 L
.728 .02619 L
.732 .02612 L
.736 .02605 L
.74 .02599 L
.744 .02593 L
.748 .02589 L
.752 .02588 L
.756 .02588 L
.76 .02593 L
.764 .02602 L
.768 .02616 L
.772 .02635 L
.776 .02655 L
.78 .02672 L
.784 .0268 L
.788 .02678 L
.792 .02668 L
.796 .02654 L
.8 .02639 L
Mistroke
.804 .02627 L
.808 .02618 L
.812 .02613 L
.816 .02611 L
.82 .02613 L
.824 .02616 L
.828 .02621 L
.832 .02628 L
.836 .02637 L
.84 .02649 L
.844 .02662 L
.848 .02672 L
.852 .02674 L
.856 .02666 L
.86 .02651 L
.864 .02635 L
.868 .02625 L
.872 .02627 L
.876 .02636 L
.88 .02648 L
.884 .02657 L
.888 .02657 L
.892 .02653 L
.896 .02647 L
.9 .02643 L
.904 .02642 L
.908 .02645 L
.912 .0265 L
.916 .02657 L
.92 .02664 L
.924 .02671 L
.928 .02674 L
.932 .02672 L
.936 .02665 L
.94 .02655 L
.944 .02644 L
.948 .02638 L
.952 .02638 L
.956 .02644 L
.96 .02654 L
.964 .02665 L
.968 .02675 L
.972 .02684 L
.976 .02688 L
.98 .02689 L
.984 .02681 L
.988 .02671 L
.992 .02655 L
.996 .02644 L
1 .02638 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
0080021oo`8004]oo`002goo0P002Woo0P000goo0`000goo00<007ooOol07Woo00@007ooOol004Yo
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P007Woo0P000Woo0P000goo0`00@goo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000eoo`<000Aoo`8000Mo
o`<000=oo`D00004Ool000000005Ool30003Ool30004Ool20003Ool50003Ool20004Ool20004Ool5
0002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol02goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool2
00001Goo001oogoo00000Woo00<007ooOol00goo00D007ooOomoo`0000=oo`04001oogoo0002Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Aoo`8000Aoo`@0009o
o`800003Ool007oo00Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@0
07ooOol0009oo`03001oogoo00Aoo`8000Aoo`04001oogoo0002Ool01000Ool000001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`000Woo
00<007ooOol017oo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;Ool40003Ool01000Oomoo`001Woo0P00
17oo00@007ooOol0009oo`04001oo`000005Ool01000Oomoogoo10000goo00@007ooOol0009oo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogooOol007oo10000goo
00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo0P0037oo00<007ooOol017oo
00@007ooOol000Eoo`<000Aoo`04001oogoo0002Ool00`00Oomoo`020003Ool20003Ool00`00Oomo
o`04Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo
00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool50003Ool20005Ool20000
0goo001oo`04Ool20004Ool200000goo001oo`03Ool01000Oomoogoo1@000goo0P0017oo0`0017oo
0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`0JOol00`00Oomoo`0@Ool0
0`00Oomoo`02Ool2000hOol0029oo`8001Yoo`80019oo`07001oogooOol007oo00001Goo00<007oo
Ool0<7oo000ROomS000<Ool0029ooa`000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00@007oo001oo`80009oo`03001oo`0000800004Ool00000Ool300000goo0000000200000goo0000
0002Ool200000goo0000000700000goo0000000500000goo001oo`0;Ool0029oo`8002moo`03001o
o`0000Yoo`04001oo`00Ool30002Ool300001Goo00000000Ool00P0000Aoo`00001oo`<00003Ool0
07oo00800004Ool00000Ool2000<Ool0029oo`03001oogoo02moo`03001oogoo00Uoo`8002moo`00
8Woo0P00KGoo000ROol2001]Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001o
ogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`80
00Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo
0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=o
o`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eo
o`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool0
0`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^
Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0
029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04
001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo
06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
00Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol002Qooa`004eoo`00:7oo00<007ooOol06Goo0`00BWoo000;Ool20004Ool0
0`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0LOol20018Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`007goo0`00AWoo0003Ool5
0002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`008Goo0`00
A7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;
Ool30004Ool20007Ool30004Ool30003Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004
Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D0
07ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<0
07ooOol00Woo00<007ooOol010000Woo00D007ooOomoo`0000=oo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00H007ooOol007oo
0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001o
ogoo009oo`05001oogoo001oo`0300000goo001oo`02Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00002
0002Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo
000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009o
o`03001oogoo00`000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<0
07ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo
:@000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo
0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D0
00=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo
00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo
00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo
0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05
001oogoo001oo`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2
000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo
00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05
Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo
00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool2
0004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004
Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00?Goo:P00
37oo000:Ool01000Oomoo`002goo00@007ooOol003Qoo`H003Ioo`002Woo00@007ooOol000Moo`@0
00=oo`03001oogoo031oo`H003aoo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8002moo`<0
045oo`002goo0P0027oo1@000Woo00<007ooOol0;7oo0`00@goo000LOol00`00Oomoo`0=Ool30004
Ool20009Ool30004Ool20002Ool40005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005
Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo
00<007ooOol00Woo00<007ooOol010000Woo00<007ooOol00goo00D007ooOomoo`0000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04
001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Ool0000200001Goo001oogoo0000
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo
00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`@0009oo`04001o
ogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009o
o`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol0
0goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00@007ooOomoo`80009oo`04001oogoo0002
Ool00`00Oomoo`03Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`00
77oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`800005Ool00000Ool00002Ool0
1000Oomoo`000Woo00<007ooOol00Woo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@0
07ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo0`000goo0P0017oo0P001Woo00@007ooOomo
o`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007oo
Ool087oo0P00D7oo000LOol00`00Oomoo`0MOol3001BOol001aoofT000aoo`0077oo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=o
o`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009o
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol3
0003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol0
0Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001o
ogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`00
2goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo
00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07
Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo
00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(22044\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31828 m
.008 .3181 L
.012 .31751 L
.016 .31748 L
.02 .31793 L
.024 .31797 L
.028 .31772 L
.032 .31768 L
.036 .31781 L
.04 .31789 L
.044 .31787 L
.048 .31786 L
.052 .31785 L
.056 .31783 L
.06 .31783 L
.064 .31788 L
.068 .31793 L
.072 .31795 L
.076 .31792 L
.08 .31789 L
.084 .31788 L
.088 .31792 L
.092 .31798 L
.096 .31802 L
.1 .31801 L
.104 .31797 L
.108 .31794 L
.112 .31795 L
.116 .31801 L
.12 .31807 L
.124 .31809 L
.128 .31806 L
.132 .31802 L
.136 .318 L
.14 .31803 L
.144 .31809 L
.148 .31814 L
.152 .31815 L
.156 .31811 L
.16 .31807 L
.164 .31806 L
.168 .31808 L
.172 .31812 L
.176 .31814 L
.18 .31813 L
.184 .31807 L
.188 .318 L
.192 .31793 L
.196 .31786 L
.2 .31777 L
Mistroke
.204 .31764 L
.208 .31745 L
.212 .31715 L
.216 .31676 L
.22 .31625 L
.224 .31559 L
.228 .31477 L
.232 .31376 L
.236 .31248 L
.24 .31086 L
.244 .3088 L
.248 .30625 L
.252 .30318 L
.256 .29955 L
.26 .2953 L
.264 .29036 L
.268 .28465 L
.272 .27809 L
.276 .27067 L
.28 .26245 L
.284 .25359 L
.288 .24425 L
.292 .23458 L
.296 .22473 L
.3 .21493 L
.304 .20547 L
.308 .19671 L
.312 .18906 L
.316 .18292 L
.32 .17864 L
.324 .17641 L
.328 .17627 L
.332 .17812 L
.336 .18185 L
.34 .18725 L
.344 .19396 L
.348 .20149 L
.352 .20919 L
.356 .21633 L
.36 .22215 L
.364 .22602 L
.368 .22759 L
.372 .22683 L
.376 .22404 L
.38 .21969 L
.384 .21432 L
.388 .20859 L
.392 .20327 L
.396 .19919 L
.4 .19713 L
Mistroke
.404 .19766 L
.408 .20101 L
.412 .20701 L
.416 .21503 L
.42 .22404 L
.424 .23294 L
.428 .24088 L
.432 .2474 L
.436 .25245 L
.44 .25629 L
.444 .2594 L
.448 .26245 L
.452 .26621 L
.456 .27132 L
.46 .27821 L
.464 .28699 L
.468 .29737 L
.472 .30855 L
.476 .3192 L
.48 .32769 L
.484 .33256 L
.488 .33301 L
.492 .32914 L
.496 .32185 L
.5 .31261 L
.504 .30315 L
.508 .29507 L
.512 .2895 L
.516 .28683 L
.52 .2868 L
.524 .28875 L
.528 .29194 L
.532 .29574 L
.536 .29964 L
.54 .30324 L
.544 .30635 L
.548 .309 L
.552 .31137 L
.556 .31359 L
.56 .31549 L
.564 .3167 L
.568 .31673 L
.572 .31525 L
.576 .31219 L
.58 .3079 L
.584 .30324 L
.588 .29958 L
.592 .29844 L
.596 .3009 L
.6 .30704 L
Mistroke
.604 .31569 L
.608 .32472 L
.612 .33181 L
.616 .33516 L
.62 .33406 L
.624 .32909 L
.628 .32195 L
.632 .31503 L
.636 .31064 L
.64 .31018 L
.644 .31352 L
.648 .31911 L
.652 .32468 L
.656 .32829 L
.66 .329 L
.664 .32695 L
.668 .32311 L
.672 .31874 L
.676 .31511 L
.68 .31322 L
.684 .31339 L
.688 .31517 L
.692 .31746 L
.696 .31921 L
.7 .31998 L
.704 .32005 L
.708 .31999 L
.712 .31996 L
.716 .31967 L
.72 .3188 L
.724 .31758 L
.728 .31678 L
.732 .31714 L
.736 .31873 L
.74 .32086 L
.744 .32266 L
.748 .32352 L
.752 .32326 L
.756 .32189 L
.76 .31945 L
.764 .31645 L
.768 .31404 L
.772 .31364 L
.776 .316 L
.78 .32014 L
.784 .32373 L
.788 .32453 L
.792 .32201 L
.796 .31793 L
.8 .31492 L
Mistroke
.804 .31477 L
.808 .3173 L
.812 .32066 L
.816 .32304 L
.82 .32354 L
.824 .32234 L
.828 .32023 L
.832 .31778 L
.836 .31569 L
.84 .31492 L
.844 .31607 L
.848 .31915 L
.852 .32262 L
.856 .32426 L
.86 .32292 L
.864 .31922 L
.868 .31572 L
.872 .315 L
.876 .31731 L
.88 .32092 L
.884 .32302 L
.888 .32201 L
.892 .31914 L
.896 .31678 L
.9 .31681 L
.904 .31918 L
.908 .32157 L
.912 .32207 L
.916 .32034 L
.92 .31772 L
.924 .31653 L
.928 .3175 L
.932 .31964 L
.936 .32138 L
.94 .32132 L
.944 .31997 L
.948 .31875 L
.952 .31855 L
.956 .31948 L
.96 .32034 L
.964 .32009 L
.968 .31897 L
.972 .31771 L
.976 .31766 L
.98 .31904 L
.984 .32066 L
.988 .32177 L
.992 .32124 L
.996 .31945 L
1 .31822 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15951 m
.008 .15727 L
.012 .15647 L
.016 .15719 L
.02 .15745 L
.024 .15726 L
.028 .15714 L
.032 .15722 L
.036 .15724 L
.04 .15723 L
.044 .15721 L
.048 .15723 L
.052 .15722 L
.056 .15723 L
.06 .15722 L
.064 .15723 L
.068 .15722 L
.072 .15723 L
.076 .15722 L
.08 .15723 L
.084 .15722 L
.088 .15723 L
.092 .15722 L
.096 .15723 L
.1 .15722 L
.104 .15723 L
.108 .15722 L
.112 .15723 L
.116 .15722 L
.12 .15723 L
.124 .15722 L
.128 .15723 L
.132 .15722 L
.136 .15723 L
.14 .15723 L
.144 .15723 L
.148 .15723 L
.152 .15723 L
.156 .15723 L
.16 .15723 L
.164 .15723 L
.168 .15723 L
.172 .15723 L
.176 .15723 L
.18 .15723 L
.184 .15723 L
.188 .15723 L
.192 .15724 L
.196 .15724 L
.2 .15725 L
Mistroke
.204 .15726 L
.208 .15728 L
.212 .15729 L
.216 .15731 L
.22 .15735 L
.224 .15739 L
.228 .15745 L
.232 .15752 L
.236 .15761 L
.24 .15773 L
.244 .15788 L
.248 .15807 L
.252 .15831 L
.256 .1586 L
.26 .15897 L
.264 .15941 L
.268 .15995 L
.272 .1606 L
.276 .16136 L
.28 .16226 L
.284 .1633 L
.288 .1645 L
.292 .16586 L
.296 .16739 L
.3 .16909 L
.304 .17095 L
.308 .17296 L
.312 .17511 L
.316 .17738 L
.32 .17975 L
.324 .18217 L
.328 .18462 L
.332 .18706 L
.336 .18945 L
.34 .19178 L
.344 .19402 L
.348 .19615 L
.352 .19816 L
.356 .20006 L
.36 .20187 L
.364 .2036 L
.368 .20529 L
.372 .20698 L
.376 .20871 L
.38 .2105 L
.384 .21237 L
.388 .21435 L
.392 .21642 L
.396 .21858 L
.4 .22079 L
Mistroke
.404 .22302 L
.408 .22524 L
.412 .22741 L
.416 .22948 L
.42 .23144 L
.424 .23327 L
.428 .23499 L
.432 .2366 L
.436 .23813 L
.44 .2396 L
.444 .24102 L
.448 .2424 L
.452 .24372 L
.456 .24498 L
.46 .24614 L
.464 .24718 L
.468 .24806 L
.472 .24878 L
.476 .24933 L
.48 .24973 L
.484 .25004 L
.488 .2503 L
.492 .25058 L
.496 .25093 L
.5 .2514 L
.504 .252 L
.508 .25273 L
.512 .25357 L
.516 .25447 L
.52 .25539 L
.524 .25628 L
.528 .25713 L
.532 .2579 L
.536 .25859 L
.54 .25921 L
.544 .25977 L
.548 .26027 L
.552 .26073 L
.556 .26115 L
.56 .26154 L
.564 .2619 L
.568 .26226 L
.572 .26264 L
.576 .26306 L
.58 .26354 L
.584 .26407 L
.588 .26463 L
.592 .26518 L
.596 .26566 L
.6 .266 L
Mistroke
.604 .26617 L
.608 .26616 L
.612 .26598 L
.616 .2657 L
.62 .26537 L
.624 .26506 L
.628 .26482 L
.632 .26466 L
.636 .26459 L
.64 .26456 L
.644 .26454 L
.648 .26447 L
.652 .26436 L
.656 .26418 L
.66 .26399 L
.664 .2638 L
.668 .26364 L
.672 .26355 L
.676 .26353 L
.68 .26358 L
.684 .26366 L
.688 .26376 L
.692 .26385 L
.696 .26393 L
.7 .26398 L
.704 .26402 L
.708 .26404 L
.712 .26406 L
.716 .26407 L
.72 .26408 L
.724 .2641 L
.728 .2641 L
.732 .26408 L
.736 .26401 L
.74 .26389 L
.744 .26373 L
.748 .26355 L
.752 .26338 L
.756 .26325 L
.76 .26318 L
.764 .26321 L
.768 .2633 L
.772 .26345 L
.776 .26358 L
.78 .26367 L
.784 .26369 L
.788 .26365 L
.792 .26359 L
.796 .26352 L
.8 .26347 L
Mistroke
.804 .26342 L
.808 .26336 L
.812 .26329 L
.816 .26321 L
.82 .26313 L
.824 .26308 L
.828 .26305 L
.832 .26305 L
.836 .26308 L
.84 .26312 L
.844 .26316 L
.848 .26318 L
.852 .26316 L
.856 .26311 L
.86 .26307 L
.864 .26304 L
.868 .26303 L
.872 .26302 L
.876 .26297 L
.88 .26289 L
.884 .26278 L
.888 .26269 L
.892 .26266 L
.896 .26269 L
.9 .26277 L
.904 .26284 L
.908 .26288 L
.912 .26286 L
.916 .26281 L
.92 .26273 L
.924 .26265 L
.928 .26257 L
.932 .26251 L
.936 .26246 L
.94 .26245 L
.944 .26247 L
.948 .26251 L
.952 .26255 L
.956 .26257 L
.96 .26254 L
.964 .26248 L
.968 .26239 L
.972 .26232 L
.976 .26226 L
.98 .26223 L
.984 .26222 L
.988 .26223 L
.992 .26223 L
.996 .26226 L
1 .26227 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .1623 L
.012 .16115 L
.016 .1608 L
.02 .16126 L
.024 .16133 L
.028 .16119 L
.032 .16114 L
.036 .16122 L
.04 .16121 L
.044 .1612 L
.048 .16118 L
.052 .1612 L
.056 .16119 L
.06 .1612 L
.064 .16119 L
.068 .1612 L
.072 .16119 L
.076 .16119 L
.08 .16119 L
.084 .1612 L
.088 .16119 L
.092 .1612 L
.096 .16119 L
.1 .16119 L
.104 .16118 L
.108 .16119 L
.112 .16119 L
.116 .16119 L
.12 .16118 L
.124 .16118 L
.128 .16118 L
.132 .16118 L
.136 .16118 L
.14 .16118 L
.144 .16118 L
.148 .16118 L
.152 .16117 L
.156 .16117 L
.16 .16117 L
.164 .16117 L
.168 .16117 L
.172 .16117 L
.176 .16117 L
.18 .16117 L
.184 .16116 L
.188 .16116 L
.192 .16115 L
.196 .16115 L
.2 .16114 L
Mistroke
.204 .16112 L
.208 .16111 L
.212 .16109 L
.216 .16105 L
.22 .16101 L
.224 .16096 L
.228 .16089 L
.232 .1608 L
.236 .16069 L
.24 .16054 L
.244 .16035 L
.248 .16011 L
.252 .15981 L
.256 .15944 L
.26 .15899 L
.264 .15844 L
.268 .15776 L
.272 .15696 L
.276 .156 L
.28 .15488 L
.284 .15358 L
.288 .15209 L
.292 .1504 L
.296 .14849 L
.3 .14637 L
.304 .14405 L
.308 .14153 L
.312 .13885 L
.316 .13601 L
.32 .13307 L
.324 .13005 L
.328 .12699 L
.332 .12394 L
.336 .12094 L
.34 .11802 L
.344 .11523 L
.348 .11258 L
.352 .11007 L
.356 .10769 L
.36 .10543 L
.364 .10325 L
.368 .10113 L
.372 .09901 L
.376 .09685 L
.38 .09462 L
.384 .09227 L
.388 .0898 L
.392 .0872 L
.396 .08449 L
.4 .08172 L
Mistroke
.404 .07892 L
.408 .07614 L
.412 .07344 L
.416 .07085 L
.42 .06839 L
.424 .06608 L
.428 .06392 L
.432 .06189 L
.436 .05997 L
.44 .05813 L
.444 .05635 L
.448 .05462 L
.452 .05294 L
.456 .05135 L
.46 .04987 L
.464 .04856 L
.468 .04744 L
.472 .04653 L
.476 .04584 L
.48 .04531 L
.484 .04491 L
.488 .04456 L
.492 .04419 L
.496 .04373 L
.5 .04313 L
.504 .04236 L
.508 .04143 L
.512 .04037 L
.516 .03923 L
.52 .03806 L
.524 .03692 L
.528 .03585 L
.532 .03487 L
.536 .03398 L
.54 .03318 L
.544 .03247 L
.548 .03182 L
.552 .03123 L
.556 .03069 L
.56 .03019 L
.564 .02971 L
.568 .02923 L
.572 .02873 L
.576 .02818 L
.58 .02757 L
.584 .02689 L
.588 .02617 L
.592 .02547 L
.596 .02486 L
.6 .0244 L
Mistroke
.604 .02415 L
.608 .02413 L
.612 .02432 L
.616 .02466 L
.62 .02506 L
.624 .02544 L
.628 .02572 L
.632 .02589 L
.636 .02595 L
.64 .02595 L
.644 .02594 L
.648 .02599 L
.652 .02612 L
.656 .02633 L
.66 .02657 L
.664 .0268 L
.668 .02697 L
.672 .02704 L
.676 .02702 L
.68 .02693 L
.684 .02681 L
.688 .02667 L
.692 .02654 L
.696 .02644 L
.7 .02636 L
.704 .0263 L
.708 .02624 L
.712 .02618 L
.716 .02612 L
.72 .02606 L
.724 .02602 L
.728 .02601 L
.732 .02604 L
.736 .02612 L
.74 .02626 L
.744 .02643 L
.748 .02663 L
.752 .02682 L
.756 .02694 L
.76 .02696 L
.764 .02689 L
.768 .02675 L
.772 .02658 L
.776 .02643 L
.78 .02633 L
.784 .02629 L
.788 .02629 L
.792 .02632 L
.796 .02636 L
.8 .02638 L
Mistroke
.804 .0264 L
.808 .02643 L
.812 .02651 L
.816 .02662 L
.82 .02677 L
.824 .02688 L
.828 .02691 L
.832 .02684 L
.836 .0267 L
.84 .02653 L
.844 .02642 L
.848 .02639 L
.852 .02644 L
.856 .02653 L
.86 .02662 L
.864 .02669 L
.868 .02673 L
.872 .02673 L
.876 .02672 L
.88 .02669 L
.884 .02666 L
.888 .02665 L
.892 .02668 L
.896 .02672 L
.9 .02677 L
.904 .02679 L
.908 .02679 L
.912 .02677 L
.916 .02674 L
.92 .02671 L
.924 .02669 L
.928 .02666 L
.932 .02664 L
.936 .02664 L
.94 .02669 L
.944 .0268 L
.948 .02694 L
.952 .02704 L
.956 .02707 L
.96 .02699 L
.964 .02685 L
.968 .0267 L
.972 .0266 L
.976 .02658 L
.98 .02664 L
.984 .02674 L
.988 .02687 L
.992 .02696 L
.996 .02705 L
1 .02709 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008001eoo`<004eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol077oo00@007oo000004ao
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P0077oo00D007ooOomoo`0000=oo`<0
04Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000=Ool30004Ool2
0005Ool00`00Ool000040002Ool40002Ool20005Ool30003Ool30004Ool20003Ool50003Ool20004
Ool20004Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol02goo00D007ooOomoo`00009oo`04001oogoo0004Ool01000
Oomoo`000Woo0`000Woo0P0000Eoo`00Oomoo`0000Eoo`05001oogooOol00003Ool01000Oomoo`00
0Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`02Ool01000Oomo
o`000goo0P000Woo0P0000Eoo`00Oomoo`0000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P0047oo00@007ooOol0009oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomo
o`00Ool00P000Woo00<007ooOol00goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=o
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00
Oomoo`0;Ool40003Ool01000Oomoo`000goo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000
Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`80
00Yoo`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0002Ool01000Oomo
ogoo0P0017oo00@007ooOol0009oo`800003Ool007oo00=oo`8000=oo`03001oogoo00Aoo`04001o
ogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo
001oo`0000Ioo`04001oogoo0005Ool0029oo`8000aoo`D000=oo`8000=oo`03001oogoo009oo`03
001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20004Ool30004Ool20004Ool20005
Ool30002Ool50003Ool20006Ool0029oo`03001oogoo01Moo`03001oogoo011oo`03001oogoo009o
o`8003]oo`008Woo0P005goo0P004goo00@007ooOomoo`<000Eoo`03001oogoo039oo`008WooH`00
37oo000ROolI0002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`09001oogooOol007oo
001oo`00009oo`<0009oo`03001oogoo0080009oo`<00005Ool00000001oo`03000017oo000007oo
200000=oo`0000001@0000=oo`00Ool02goo000ROol2000]Ool2000:Ool00`00Ool00002Ool20002
Ool300001Goo00000000Ool00P0000Eoo`00000007oo00800006Ool00000Ool007oo100000=oo`00
00003Goo000ROol00`00Oomoo`0/Ool2000;Ool2000aOol0029oo`8006eoo`008Woo0P00KGoo000;
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo
0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool5
0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qo
o`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001o
ogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2
001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000
Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003
Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo
06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03
Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomo
o`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
1Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4
0003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007oo
Ool017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03
001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOolJ001?
Ool002Qoo`03001oogoo01Ioo`@004aoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo
0`000goo00<007ooOol06Goo0`00BWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001o
ogoo001oo`000goo00@007ooOol001eoo`8004Uoo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00@007ooOol001moo`8004Moo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`000Woo1000
17oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P00
1Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomo
o`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`@0009oo`04001oogoo
0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007oo
Ool00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007oo
Ool03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00@0009oo`05
001oogooOol00007Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000
Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P00
17oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
009oo`05001oogoo001oo`050003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo
00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomo
o`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007oo
Ool00Woo00@007ooOol0009oo`03001oo`0000H0009oo`@000=oo`06001oogoo001oo`000goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol0
00Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo
0002Ool01000Oomoo`000Woo;P000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo
0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`80
00Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007oo
Ool03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo
0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`80
00Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007oo
Ool0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo
00<007ooOol00P00>Woo;@0037oo000:Ool01000Oomoo`002goo00@007ooOol003Eoo`L003Qoo`00
2Woo00@007ooOol000Moo`@000=oo`03001oogoo02ioo`H003ioo`002Woo00@007ooOol000Moo`03
001oogoo00Aoo`8002aoo`@004=oo`002goo0P0027oo1@000Woo00<007ooOol0:Goo0`00AWoo000L
Ool00`00Oomoo`0=Ool30004Ool20009Ool30004Ool40002Ool20005Ool30003Ool30004Ool20005
Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol0
0002Ool01000Oomoo`002Goo00<007ooOol00Woo10000Woo00@007ooOol000Eoo`05001oogooOol0
0003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00
Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00@007ooOomoo`<00005Ool007ooOol00002
Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00`00
0Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04
001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool30002Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007oo
Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000
Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0`000goo00@0
07ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007oo
Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000
Oomoo`001Goo000LOol2000=Ool50003Ool20008Ool30005Ool20004Ool20006Ool01000Oomoogoo
1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomo
o`0MOol2001COol001aoo`03001oogoo01]oo`<005Aoo`0077ooJ@0037oo000LOol01@00Oomoogoo
00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo
000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Ioo`<0
00=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02
Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007oo
Ool0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;
Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool0
1000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Mo
o`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool0
0`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(22211\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31853 m
.008 .31784 L
.012 .31747 L
.016 .31745 L
.02 .3178 L
.024 .31793 L
.028 .31778 L
.032 .31769 L
.036 .31776 L
.04 .31782 L
.044 .31781 L
.048 .3178 L
.052 .31782 L
.056 .31784 L
.06 .31784 L
.064 .31785 L
.068 .31786 L
.072 .31788 L
.076 .31788 L
.08 .31788 L
.084 .31789 L
.088 .31791 L
.092 .31793 L
.096 .31795 L
.1 .31794 L
.104 .31793 L
.108 .31793 L
.112 .31796 L
.116 .31799 L
.12 .31802 L
.124 .31801 L
.128 .31799 L
.132 .31797 L
.136 .31797 L
.14 .318 L
.144 .31804 L
.148 .31804 L
.152 .31801 L
.156 .31794 L
.16 .31788 L
.164 .31784 L
.168 .3178 L
.172 .31773 L
.176 .31759 L
.18 .31736 L
.184 .31705 L
.188 .31667 L
.192 .31621 L
.196 .31565 L
.2 .3149 L
Mistroke
.204 .31391 L
.208 .31261 L
.212 .31099 L
.216 .30901 L
.22 .30662 L
.224 .30374 L
.228 .30027 L
.232 .29615 L
.236 .29129 L
.24 .28564 L
.244 .2792 L
.248 .27197 L
.252 .264 L
.256 .25534 L
.26 .24607 L
.264 .23633 L
.268 .22631 L
.272 .21628 L
.276 .20655 L
.28 .19751 L
.284 .18952 L
.288 .18292 L
.292 .17796 L
.296 .17486 L
.3 .17378 L
.304 .17482 L
.308 .17797 L
.312 .183 L
.316 .18954 L
.32 .19701 L
.324 .20476 L
.328 .21205 L
.332 .21824 L
.336 .22284 L
.34 .22548 L
.344 .22598 L
.348 .22426 L
.352 .22053 L
.356 .21526 L
.36 .20922 L
.364 .20333 L
.368 .19855 L
.372 .19574 L
.376 .1955 L
.38 .19801 L
.384 .20303 L
.388 .21005 L
.392 .21838 L
.396 .2273 L
.4 .23605 L
Mistroke
.404 .24392 L
.408 .25038 L
.412 .25525 L
.416 .25873 L
.42 .26144 L
.424 .26428 L
.428 .26829 L
.432 .27431 L
.436 .28265 L
.44 .29294 L
.444 .30414 L
.448 .31491 L
.452 .32388 L
.456 .32988 L
.46 .33214 L
.464 .33042 L
.468 .32513 L
.472 .31718 L
.476 .30785 L
.48 .29857 L
.484 .29077 L
.488 .28561 L
.492 .28377 L
.496 .28515 L
.5 .28892 L
.504 .29381 L
.508 .29864 L
.512 .30261 L
.516 .30549 L
.52 .30753 L
.524 .30926 L
.528 .31121 L
.532 .31353 L
.536 .3158 L
.54 .31713 L
.544 .31664 L
.548 .31395 L
.552 .30949 L
.556 .30437 L
.56 .30009 L
.564 .2981 L
.568 .29943 L
.572 .30429 L
.576 .31191 L
.58 .32063 L
.584 .32839 L
.588 .33333 L
.592 .33444 L
.596 .33177 L
.6 .32634 L
Mistroke
.604 .31983 L
.608 .31416 L
.612 .31102 L
.616 .31129 L
.62 .31473 L
.624 .32 L
.628 .32514 L
.632 .32841 L
.636 .32886 L
.64 .32658 L
.644 .32248 L
.648 .31789 L
.652 .31413 L
.656 .31222 L
.66 .3125 L
.664 .31455 L
.668 .31735 L
.672 .31973 L
.676 .32099 L
.68 .32113 L
.684 .32057 L
.688 .31975 L
.692 .31881 L
.696 .31779 L
.7 .31696 L
.704 .31679 L
.708 .31769 L
.712 .31954 L
.716 .32167 L
.72 .32325 L
.724 .32371 L
.728 .3229 L
.732 .32094 L
.736 .31821 L
.74 .3154 L
.744 .31363 L
.748 .31396 L
.752 .31667 L
.756 .3206 L
.76 .32368 L
.764 .32414 L
.768 .32176 L
.772 .31813 L
.776 .31547 L
.78 .31521 L
.784 .31721 L
.788 .32006 L
.792 .32234 L
.796 .32319 L
.8 .32243 L
Mistroke
.804 .3204 L
.808 .31771 L
.812 .31544 L
.816 .31486 L
.82 .31653 L
.824 .31984 L
.828 .32282 L
.832 .3234 L
.836 .32124 L
.84 .31784 L
.844 .31577 L
.848 .31661 L
.852 .31948 L
.856 .32208 L
.86 .32237 L
.864 .32018 L
.868 .31752 L
.872 .3164 L
.876 .31749 L
.88 .31974 L
.884 .32117 L
.888 .321 L
.892 .31986 L
.896 .31885 L
.9 .31882 L
.904 .31922 L
.908 .31914 L
.912 .31853 L
.916 .31796 L
.92 .31845 L
.924 .32016 L
.928 .32181 L
.932 .32208 L
.936 .32039 L
.94 .31774 L
.944 .31619 L
.948 .31678 L
.952 .31914 L
.956 .32148 L
.96 .3219 L
.964 .32045 L
.968 .31828 L
.972 .31718 L
.976 .31834 L
.98 .32037 L
.984 .32184 L
.988 .3216 L
.992 .31916 L
.996 .31697 L
1 .31641 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15629 m
.008 .15764 L
.012 .15802 L
.016 .15752 L
.02 .15739 L
.024 .15761 L
.028 .15763 L
.032 .15757 L
.036 .15754 L
.04 .15758 L
.044 .15757 L
.048 .15757 L
.052 .15756 L
.056 .15758 L
.06 .15757 L
.064 .15757 L
.068 .15756 L
.072 .15757 L
.076 .15757 L
.08 .15758 L
.084 .15757 L
.088 .15757 L
.092 .15757 L
.096 .15757 L
.1 .15757 L
.104 .15757 L
.108 .15757 L
.112 .15758 L
.116 .15757 L
.12 .15757 L
.124 .15757 L
.128 .15757 L
.132 .15757 L
.136 .15758 L
.14 .15757 L
.144 .15757 L
.148 .15757 L
.152 .15758 L
.156 .15758 L
.16 .15758 L
.164 .15758 L
.168 .15759 L
.172 .1576 L
.176 .15761 L
.18 .15762 L
.184 .15763 L
.188 .15766 L
.192 .15769 L
.196 .15773 L
.2 .15778 L
Mistroke
.204 .15784 L
.208 .15793 L
.212 .15804 L
.216 .15818 L
.22 .15837 L
.224 .15859 L
.228 .15887 L
.232 .15922 L
.236 .15964 L
.24 .16015 L
.244 .16077 L
.248 .1615 L
.252 .16236 L
.256 .16336 L
.26 .1645 L
.264 .16581 L
.268 .16729 L
.272 .16893 L
.276 .17074 L
.28 .1727 L
.284 .17481 L
.288 .17704 L
.292 .17937 L
.296 .18177 L
.3 .18421 L
.304 .18666 L
.308 .18907 L
.312 .19143 L
.316 .1937 L
.32 .19587 L
.324 .19792 L
.328 .19985 L
.332 .20169 L
.336 .20345 L
.34 .20515 L
.344 .20684 L
.348 .20855 L
.352 .21031 L
.356 .21214 L
.36 .21407 L
.364 .2161 L
.368 .21822 L
.372 .22041 L
.376 .22264 L
.38 .22486 L
.384 .22704 L
.388 .22915 L
.392 .23115 L
.396 .23303 L
.4 .23479 L
Mistroke
.404 .23644 L
.408 .23799 L
.412 .23947 L
.416 .24088 L
.42 .24225 L
.424 .24358 L
.428 .24485 L
.432 .24604 L
.436 .24712 L
.44 .24806 L
.444 .24884 L
.448 .24945 L
.452 .24991 L
.456 .25026 L
.46 .25053 L
.464 .2508 L
.468 .25111 L
.472 .25152 L
.476 .25206 L
.48 .25273 L
.484 .25352 L
.488 .25439 L
.492 .25532 L
.496 .25623 L
.5 .25711 L
.504 .25792 L
.508 .25864 L
.512 .25929 L
.516 .25986 L
.52 .26037 L
.524 .26084 L
.528 .26127 L
.532 .26167 L
.536 .26204 L
.54 .26241 L
.544 .26278 L
.548 .26318 L
.552 .26363 L
.556 .26412 L
.56 .26465 L
.564 .26519 L
.568 .26569 L
.572 .26609 L
.576 .26634 L
.58 .26643 L
.584 .26633 L
.588 .26609 L
.592 .26576 L
.596 .26542 L
.6 .26512 L
Mistroke
.604 .2649 L
.608 .26478 L
.612 .26474 L
.616 .26473 L
.62 .26471 L
.624 .26463 L
.628 .26449 L
.632 .2643 L
.636 .26409 L
.64 .26392 L
.644 .2638 L
.648 .26375 L
.652 .26377 L
.656 .26384 L
.66 .26394 L
.664 .26404 L
.668 .26412 L
.672 .26418 L
.676 .26422 L
.68 .26425 L
.684 .26428 L
.688 .2643 L
.692 .26432 L
.696 .26433 L
.7 .26432 L
.704 .26429 L
.708 .26423 L
.712 .26414 L
.716 .264 L
.72 .26384 L
.724 .26368 L
.728 .26354 L
.732 .26345 L
.736 .26343 L
.74 .26348 L
.744 .26358 L
.748 .26371 L
.752 .26383 L
.756 .2639 L
.76 .2639 L
.764 .26386 L
.768 .26379 L
.772 .26373 L
.776 .26367 L
.78 .26361 L
.784 .26355 L
.788 .26346 L
.792 .26338 L
.796 .2633 L
.8 .26325 L
Mistroke
.804 .26324 L
.808 .26327 L
.812 .26334 L
.816 .26341 L
.82 .26345 L
.824 .26344 L
.828 .26337 L
.832 .26329 L
.836 .26321 L
.84 .26318 L
.844 .26318 L
.848 .26319 L
.852 .26318 L
.856 .26313 L
.86 .26305 L
.864 .26297 L
.868 .26292 L
.872 .26291 L
.876 .26293 L
.88 .26297 L
.884 .263 L
.888 .26302 L
.892 .26302 L
.896 .26299 L
.9 .26293 L
.904 .26284 L
.908 .26275 L
.912 .26268 L
.916 .26264 L
.92 .26263 L
.924 .26266 L
.928 .26268 L
.932 .26271 L
.936 .26272 L
.94 .26273 L
.944 .2627 L
.948 .26265 L
.952 .26256 L
.956 .26246 L
.96 .26237 L
.964 .26233 L
.968 .26235 L
.972 .26242 L
.976 .26248 L
.98 .26252 L
.984 .2625 L
.988 .26244 L
.992 .26233 L
.996 .26226 L
1 .26219 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16291 L
.012 .16127 L
.016 .16063 L
.02 .16118 L
.024 .16138 L
.028 .16123 L
.032 .16113 L
.036 .1612 L
.04 .16121 L
.044 .16121 L
.048 .16118 L
.052 .1612 L
.056 .16119 L
.06 .1612 L
.064 .16119 L
.068 .1612 L
.072 .16119 L
.076 .1612 L
.08 .16119 L
.084 .1612 L
.088 .16119 L
.092 .16119 L
.096 .16119 L
.1 .16119 L
.104 .16118 L
.108 .16119 L
.112 .16118 L
.116 .16119 L
.12 .16118 L
.124 .16118 L
.128 .16118 L
.132 .16118 L
.136 .16118 L
.14 .16118 L
.144 .16118 L
.148 .16117 L
.152 .16117 L
.156 .16117 L
.16 .16116 L
.164 .16116 L
.168 .16115 L
.172 .16115 L
.176 .16113 L
.18 .16111 L
.184 .16109 L
.188 .16107 L
.192 .16103 L
.196 .16098 L
.2 .16091 L
Mistroke
.204 .16083 L
.208 .16072 L
.212 .16058 L
.216 .1604 L
.22 .16018 L
.224 .15989 L
.228 .15954 L
.232 .15911 L
.236 .15858 L
.24 .15794 L
.244 .15718 L
.248 .15627 L
.252 .1552 L
.256 .15395 L
.26 .15252 L
.264 .15089 L
.268 .14904 L
.272 .14699 L
.276 .14474 L
.28 .14229 L
.284 .13966 L
.288 .13688 L
.292 .13397 L
.296 .13097 L
.3 .12792 L
.304 .12487 L
.308 .12185 L
.312 .11891 L
.316 .11608 L
.32 .11337 L
.324 .1108 L
.328 .10837 L
.332 .10607 L
.336 .10387 L
.34 .10174 L
.344 .09963 L
.348 .09749 L
.352 .09529 L
.356 .09299 L
.36 .09057 L
.364 .08803 L
.368 .08538 L
.372 .08264 L
.376 .07985 L
.38 .07707 L
.384 .07433 L
.388 .07169 L
.392 .06917 L
.396 .06681 L
.4 .0646 L
Mistroke
.404 .06254 L
.408 .06059 L
.412 .05874 L
.416 .05695 L
.42 .05522 L
.424 .05354 L
.428 .05194 L
.432 .05044 L
.436 .04908 L
.44 .0479 L
.444 .0469 L
.448 .04611 L
.452 .04551 L
.456 .04506 L
.46 .0447 L
.464 .04435 L
.468 .04395 L
.472 .04342 L
.476 .04273 L
.48 .04187 L
.484 .04086 L
.488 .03975 L
.492 .03858 L
.496 .03742 L
.5 .03631 L
.504 .03529 L
.508 .03436 L
.512 .03353 L
.516 .03279 L
.52 .03213 L
.524 .03152 L
.528 .03097 L
.532 .03045 L
.536 .02997 L
.54 .02949 L
.544 .029 L
.548 .02848 L
.552 .0279 L
.556 .02726 L
.56 .02658 L
.564 .02588 L
.568 .02524 L
.572 .02472 L
.576 .02438 L
.58 .02426 L
.584 .02436 L
.588 .02463 L
.592 .02501 L
.596 .02541 L
.6 .02576 L
Mistroke
.604 .026 L
.608 .02613 L
.612 .02617 L
.616 .02617 L
.62 .02618 L
.624 .02625 L
.628 .02639 L
.632 .02659 L
.636 .02682 L
.64 .02703 L
.644 .02716 L
.648 .02721 L
.652 .02717 L
.656 .02705 L
.66 .0269 L
.664 .02674 L
.668 .02661 L
.672 .0265 L
.676 .02643 L
.68 .02638 L
.684 .02635 L
.688 .02631 L
.692 .02627 L
.696 .02622 L
.7 .02619 L
.704 .02619 L
.708 .02623 L
.712 .02633 L
.716 .02648 L
.72 .02667 L
.724 .02688 L
.728 .02704 L
.732 .02713 L
.736 .02712 L
.74 .02701 L
.744 .02683 L
.748 .02665 L
.752 .02649 L
.756 .02641 L
.76 .02639 L
.764 .02643 L
.768 .0265 L
.772 .02656 L
.776 .0266 L
.78 .02663 L
.784 .02665 L
.788 .02671 L
.792 .0268 L
.796 .02691 L
.8 .02699 L
Mistroke
.804 .02701 L
.808 .02695 L
.812 .02683 L
.816 .02671 L
.82 .02662 L
.824 .02658 L
.828 .0266 L
.832 .02666 L
.836 .02673 L
.84 .0268 L
.844 .02685 L
.848 .02688 L
.852 .02689 L
.856 .0269 L
.86 .02689 L
.864 .02689 L
.868 .02689 L
.872 .02687 L
.876 .02684 L
.88 .02682 L
.884 .02681 L
.888 .02684 L
.892 .02689 L
.896 .02694 L
.9 .02696 L
.904 .02692 L
.908 .02686 L
.912 .02683 L
.916 .02684 L
.92 .02691 L
.924 .02701 L
.928 .02708 L
.932 .02711 L
.936 .02708 L
.94 .02702 L
.944 .02696 L
.948 .0269 L
.952 .02686 L
.956 .02684 L
.96 .02686 L
.964 .02693 L
.968 .02703 L
.972 .02715 L
.976 .02724 L
.98 .02727 L
.984 .02722 L
.988 .02712 L
.992 .02698 L
.996 .0269 L
1 .02685 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02000KOol2001@Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008001Yoo`@004moo`002goo0P002Woo0P000goo0`000goo00<007ooOol06Goo00@007oo
Ool000Aoo`8004Uoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P006Goo00@007oo
Oomoo`8000=oo`<004Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2
000=Ool30004Ool20003Ool01000Oomoogoo0`0000Aoo`00Oomoo`8000Aoo`8000Eoo`<000=oo`<0
00Aoo`8000=oo`D000=oo`8000Aoo`8000Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo0000
0Woo00H007ooOol007oo0005Ool30002Ool200001Goo001oogoo00000Woo00<007ooOol00goo00D0
07ooOomoo`0000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0
009oo`03001oo`0000Eoo`03001oogoo009oo`04001oo`000002Ool01000Oomoo`001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo0P001Woo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`03001oogoo00]oo`@000=oo`03001oogoo008000Ioo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool0
00]oo`8000Yoo`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`03001oogoo008000Eo
o`8000Aoo`03001oogoo00800005Ool007ooOol00004Ool20003Ool00`00Oomoo`04Ool01000Oomo
o`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00L007ooOomoo`00
Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool50003Ool30007Ool00`00Oomoo`03Ool20002
Ool01000Ool000001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009o
o`D000=oo`8000Ioo`008Woo00<007ooOol05Goo00<007ooOol047oo00<007ooOol00Woo00<007oo
Ool0?7oo000ROol2000EOol00`00Oomoo`0AOol01P00Oomoogoo001oo`8000Aoo`03001oogoo03Eo
o`008WooH`0037oo000ROolF0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo
Ool200000goo00000003Ool60002Ool800001Goo00000000Ool02@0000Aoo`00001oo`H00003Ool0
000000800003Ool0000000aoo`008Woo0P00:Woo00<007oo00002Woo00@007oo001oo`<0009oo`80
009oo`80009oo`800004Ool00000Ool500000goo00000002Ool200001Goo000007oo00003Woo000R
Ool00`00Oomoo`0ZOol00`00Oomoo`09Ool2000dOol0029oo`8006eoo`008Woo0P00KGoo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P00
17oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo
0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo
06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]
Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2
001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06ao
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`00
00=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo
00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003
Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0
17oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004
Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001o
ogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOolG001BOol0
02Qoo`03001oogoo01=oo`@004moo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`00
0goo00<007ooOol05goo0P00CGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`000goo00@007ooOol001]oo`8004]oo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOol001aoo`<004Uoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo1@000Woo0P0017oo
0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09
Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo00<0009oo`04001oogoo0002Ool0
1@00Oomoogoo00000goo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomo
o`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo10000Woo00@007ooOol000=o
o`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001o
ogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004
Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol0
0Woo00<007oo000010000Woo00D007ooOomoo`0000Moo`04001oogoo0002Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo
0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomo
o`02Ool01@00Oomoo`00Ool02@000goo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol0
0`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001o
ogoo0002Ool^0003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00
Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo
0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@00
37oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00
Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00
Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00D007ooOol007oo00@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo
1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P00
17oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1V
Ool0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05
001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomo
o`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]o
o`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
00]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02
000gOol`000<Ool000Yoo`04001oogoo000;Ool01000Oomoo`00<Woo1`00>goo000:Ool01000Oomo
o`001goo10000goo00<007ooOol0:goo1P00@Goo000:Ool01000Oomoo`001goo00<007ooOol017oo
0P00:Woo0`00AWoo000;Ool20008Ool50002Ool00`00Oomoo`0WOol20019Ool001aoo`03001oogoo
00eoo`<000Aoo`8000Uoo`<000=oo`<000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`80
00Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001o
ogoo0009Ool00`00Oomoo`030002Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`00
00=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001o
ogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool01P00Ool00000Ool0009oo`04001oogoo0002
Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo0P000goo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D0
07ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`00
0Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`001goo0`0017oo00@007ooOol0
009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eo
o`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Ioo`@000Aoo`04001oogoo0002
Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eo
o`0077oo0P003Goo1@000goo0P001Goo0`000Woo00<007ooOol00goo0P0017oo0P001Woo00@007oo
Oomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<0
07ooOol06Woo0P00EWoo000LOol00`00Oomoo`0HOol3001GOol001aoofT000aoo`0077oo00D007oo
Oomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo0080
07=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0
009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000F
Ool30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007oo
Ool00Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03
001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=o
o`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol0
2goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomo
o`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`00
2goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(22378\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31727 m
.008 .31733 L
.012 .31786 L
.016 .31793 L
.02 .31759 L
.024 .31759 L
.028 .31781 L
.032 .31784 L
.036 .31772 L
.04 .3177 L
.044 .31775 L
.048 .31778 L
.052 .3178 L
.056 .31783 L
.06 .31783 L
.064 .31781 L
.068 .3178 L
.072 .31781 L
.076 .31785 L
.08 .31788 L
.084 .31789 L
.088 .31789 L
.092 .31787 L
.096 .31787 L
.1 .31788 L
.104 .3179 L
.108 .31792 L
.112 .31793 L
.116 .31792 L
.12 .3179 L
.124 .31787 L
.128 .31785 L
.132 .31782 L
.136 .31779 L
.14 .31773 L
.144 .31763 L
.148 .31747 L
.152 .31726 L
.156 .31699 L
.16 .31666 L
.164 .31624 L
.168 .31568 L
.172 .31493 L
.176 .31395 L
.18 .31271 L
.184 .31118 L
.188 .30931 L
.192 .30703 L
.196 .30425 L
.2 .30089 L
Mistroke
.204 .29686 L
.208 .29212 L
.212 .28663 L
.216 .2804 L
.22 .27339 L
.224 .26559 L
.228 .25701 L
.232 .24776 L
.236 .23799 L
.24 .22792 L
.244 .21781 L
.248 .20794 L
.252 .19863 L
.256 .19019 L
.26 .18296 L
.264 .17726 L
.268 .17341 L
.272 .17164 L
.276 .17204 L
.28 .17458 L
.284 .17904 L
.288 .1851 L
.292 .19224 L
.296 .1999 L
.3 .20745 L
.304 .21427 L
.308 .21977 L
.312 .2234 L
.316 .22478 L
.32 .2238 L
.324 .22064 L
.328 .21578 L
.332 .20994 L
.336 .20399 L
.34 .19883 L
.344 .19524 L
.348 .19382 L
.352 .19491 L
.356 .19865 L
.36 .20484 L
.364 .21297 L
.368 .22222 L
.372 .23162 L
.376 .24028 L
.38 .2475 L
.384 .25299 L
.388 .25693 L
.392 .25995 L
.396 .26293 L
.4 .26677 L
Mistroke
.404 .27212 L
.408 .2793 L
.412 .28826 L
.416 .29853 L
.42 .30924 L
.424 .31917 L
.428 .32701 L
.432 .33156 L
.436 .33206 L
.44 .32833 L
.444 .32096 L
.448 .31129 L
.452 .30115 L
.456 .29233 L
.46 .28618 L
.464 .28329 L
.468 .28354 L
.472 .28628 L
.476 .29054 L
.48 .29529 L
.484 .29977 L
.488 .3036 L
.492 .30672 L
.496 .30928 L
.5 .31136 L
.504 .31305 L
.508 .31432 L
.512 .31506 L
.516 .31499 L
.52 .31375 L
.524 .31113 L
.528 .30739 L
.532 .30331 L
.536 .30008 L
.54 .29898 L
.544 .30099 L
.548 .30639 L
.552 .3145 L
.556 .32362 L
.56 .33144 L
.564 .33582 L
.568 .3356 L
.572 .33106 L
.576 .32388 L
.58 .31646 L
.584 .31115 L
.588 .30951 L
.592 .31183 L
.596 .31704 L
.6 .32309 L
Mistroke
.604 .32778 L
.608 .32954 L
.612 .32805 L
.616 .32417 L
.62 .31945 L
.624 .31539 L
.628 .313 L
.632 .31257 L
.636 .31379 L
.64 .31593 L
.644 .31812 L
.648 .31969 L
.652 .32036 L
.656 .32034 L
.66 .32 L
.664 .31958 L
.668 .31907 L
.672 .31835 L
.676 .31757 L
.68 .3172 L
.684 .31775 L
.688 .31933 L
.692 .32144 L
.696 .32321 L
.7 .32382 L
.704 .32289 L
.708 .32057 L
.712 .31748 L
.716 .31462 L
.72 .31317 L
.724 .31398 L
.728 .31698 L
.732 .32091 L
.736 .32379 L
.74 .32409 L
.744 .32172 L
.748 .31819 L
.752 .31557 L
.756 .31525 L
.76 .31716 L
.764 .32006 L
.768 .32243 L
.772 .32325 L
.776 .32219 L
.78 .31973 L
.784 .31683 L
.788 .31485 L
.792 .315 L
.796 .31741 L
.8 .32088 L
Mistroke
.804 .32329 L
.808 .32299 L
.812 .32024 L
.816 .31695 L
.82 .31549 L
.824 .31684 L
.828 .31979 L
.832 .32213 L
.836 .32229 L
.84 .32043 L
.844 .31819 L
.848 .31702 L
.852 .31726 L
.856 .31831 L
.86 .31922 L
.864 .31985 L
.868 .32042 L
.872 .32085 L
.876 .32082 L
.88 .3198 L
.884 .31803 L
.888 .31676 L
.892 .317 L
.896 .31886 L
.9 .32111 L
.904 .32196 L
.908 .32087 L
.912 .31874 L
.916 .31732 L
.92 .3178 L
.924 .31955 L
.928 .32092 L
.932 .32064 L
.936 .3188 L
.94 .31714 L
.944 .31715 L
.948 .319 L
.952 .32149 L
.956 .32248 L
.96 .32134 L
.964 .31897 L
.968 .31682 L
.972 .3167 L
.976 .31828 L
.98 .31998 L
.984 .32106 L
.988 .32049 L
.992 .31902 L
.996 .31857 L
1 .31885 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15538 m
.008 .1579 L
.012 .15873 L
.016 .15795 L
.02 .15763 L
.024 .15791 L
.028 .158 L
.032 .15794 L
.036 .15788 L
.04 .15792 L
.044 .15792 L
.048 .15792 L
.052 .15791 L
.056 .15792 L
.06 .15792 L
.064 .15792 L
.068 .15791 L
.072 .15792 L
.076 .15791 L
.08 .15792 L
.084 .15792 L
.088 .15792 L
.092 .15791 L
.096 .15792 L
.1 .15791 L
.104 .15792 L
.108 .15792 L
.112 .15792 L
.116 .15792 L
.12 .15792 L
.124 .15792 L
.128 .15792 L
.132 .15793 L
.136 .15793 L
.14 .15793 L
.144 .15794 L
.148 .15794 L
.152 .15796 L
.156 .15798 L
.16 .158 L
.164 .15803 L
.168 .15806 L
.172 .15811 L
.176 .15817 L
.18 .15826 L
.184 .15836 L
.188 .1585 L
.192 .15867 L
.196 .15888 L
.2 .15915 L
Mistroke
.204 .15947 L
.208 .15988 L
.212 .16036 L
.216 .16095 L
.22 .16164 L
.224 .16246 L
.228 .16342 L
.232 .16452 L
.236 .16578 L
.24 .1672 L
.244 .16879 L
.248 .17055 L
.252 .17246 L
.256 .17452 L
.26 .17671 L
.264 .17901 L
.268 .18139 L
.272 .18381 L
.276 .18626 L
.28 .18869 L
.284 .19106 L
.288 .19336 L
.292 .19556 L
.296 .19766 L
.3 .19963 L
.304 .20151 L
.308 .2033 L
.312 .20502 L
.316 .20671 L
.32 .2084 L
.324 .21013 L
.328 .21193 L
.332 .21381 L
.336 .2158 L
.34 .21788 L
.344 .22004 L
.348 .22225 L
.352 .22447 L
.356 .22667 L
.36 .2288 L
.364 .23085 L
.368 .23278 L
.372 .23458 L
.376 .23627 L
.38 .23784 L
.384 .23933 L
.388 .24075 L
.392 .24212 L
.396 .24345 L
.4 .24472 L
Mistroke
.404 .24593 L
.408 .24704 L
.412 .24803 L
.416 .24886 L
.42 .24954 L
.424 .25007 L
.428 .25047 L
.432 .25077 L
.436 .25103 L
.44 .25131 L
.444 .25167 L
.448 .25214 L
.452 .25275 L
.456 .25349 L
.46 .25434 L
.464 .25525 L
.468 .25618 L
.472 .25708 L
.476 .25791 L
.48 .25867 L
.484 .25935 L
.488 .25995 L
.492 .26048 L
.496 .26096 L
.5 .26139 L
.504 .2618 L
.508 .26218 L
.512 .26255 L
.516 .26292 L
.52 .26331 L
.524 .26373 L
.528 .26419 L
.532 .2647 L
.536 .26522 L
.54 .26572 L
.544 .26615 L
.548 .26647 L
.552 .26663 L
.556 .26662 L
.56 .26645 L
.564 .26616 L
.568 .26581 L
.572 .26547 L
.576 .26519 L
.58 .26501 L
.584 .26492 L
.588 .2649 L
.592 .26489 L
.596 .26486 L
.6 .26477 L
Mistroke
.604 .26462 L
.608 .26443 L
.612 .26423 L
.616 .26407 L
.62 .26397 L
.624 .26395 L
.628 .264 L
.632 .2641 L
.636 .26422 L
.64 .26433 L
.644 .26441 L
.648 .26446 L
.652 .26448 L
.656 .26449 L
.66 .2645 L
.664 .26452 L
.668 .26453 L
.672 .26454 L
.676 .26453 L
.68 .26449 L
.684 .26441 L
.688 .26429 L
.692 .26413 L
.696 .26396 L
.7 .26381 L
.704 .2637 L
.708 .26365 L
.712 .26367 L
.716 .26375 L
.72 .26387 L
.724 .264 L
.728 .26409 L
.732 .26413 L
.736 .26411 L
.74 .26405 L
.744 .26397 L
.748 .2639 L
.752 .26385 L
.756 .2638 L
.76 .26373 L
.764 .26366 L
.768 .26357 L
.772 .26349 L
.776 .26344 L
.78 .26344 L
.784 .26349 L
.788 .26357 L
.792 .26365 L
.796 .26369 L
.8 .26367 L
Mistroke
.804 .2636 L
.808 .2635 L
.812 .26341 L
.816 .26336 L
.82 .26334 L
.824 .26334 L
.828 .26334 L
.832 .26331 L
.836 .26327 L
.84 .26322 L
.844 .26319 L
.848 .26317 L
.852 .26317 L
.856 .26317 L
.86 .26318 L
.864 .26318 L
.868 .26318 L
.872 .26316 L
.876 .26312 L
.88 .26306 L
.884 .26301 L
.888 .26295 L
.892 .2629 L
.896 .26286 L
.9 .26283 L
.904 .26282 L
.908 .26284 L
.912 .26288 L
.916 .26293 L
.92 .26295 L
.924 .26292 L
.928 .26283 L
.932 .26271 L
.936 .2626 L
.94 .26254 L
.944 .26253 L
.948 .26256 L
.952 .26261 L
.956 .26265 L
.96 .26266 L
.964 .26267 L
.968 .26263 L
.972 .26258 L
.976 .26249 L
.98 .26239 L
.984 .26229 L
.988 .26225 L
.992 .26225 L
.996 .26233 L
1 .26239 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .1604 L
.012 .1613 L
.016 .16148 L
.02 .16117 L
.024 .16109 L
.028 .16124 L
.032 .16123 L
.036 .1612 L
.04 .16118 L
.044 .16121 L
.048 .1612 L
.052 .16121 L
.056 .16119 L
.06 .1612 L
.064 .16119 L
.068 .1612 L
.072 .16119 L
.076 .1612 L
.08 .16119 L
.084 .16119 L
.088 .16119 L
.092 .16119 L
.096 .16118 L
.1 .16119 L
.104 .16118 L
.108 .16119 L
.112 .16118 L
.116 .16118 L
.12 .16118 L
.124 .16118 L
.128 .16117 L
.132 .16117 L
.136 .16116 L
.14 .16116 L
.144 .16115 L
.148 .16114 L
.152 .16112 L
.156 .1611 L
.16 .16108 L
.164 .16104 L
.168 .16099 L
.172 .16093 L
.176 .16085 L
.18 .16075 L
.184 .16062 L
.188 .16045 L
.192 .16024 L
.196 .15997 L
.2 .15964 L
Mistroke
.204 .15922 L
.208 .15872 L
.212 .15812 L
.216 .15739 L
.22 .15652 L
.224 .1555 L
.228 .15431 L
.232 .15293 L
.236 .15136 L
.24 .14958 L
.244 .1476 L
.248 .14541 L
.252 .14302 L
.256 .14045 L
.26 .13772 L
.264 .13485 L
.268 .13188 L
.272 .12885 L
.276 .12581 L
.28 .12278 L
.284 .11981 L
.288 .11693 L
.292 .11418 L
.296 .11156 L
.3 .10908 L
.304 .10674 L
.308 .10451 L
.312 .10235 L
.316 .10024 L
.32 .09811 L
.324 .09594 L
.328 .09369 L
.332 .09133 L
.336 .08884 L
.34 .08624 L
.344 .08354 L
.348 .08077 L
.352 .07799 L
.356 .07523 L
.36 .07255 L
.364 .06999 L
.368 .06757 L
.372 .06531 L
.376 .06319 L
.38 .06121 L
.384 .05933 L
.388 .05754 L
.392 .05582 L
.396 .05415 L
.4 .05255 L
Mistroke
.404 .05103 L
.408 .04962 L
.412 .04837 L
.416 .04729 L
.42 .04643 L
.424 .04575 L
.428 .04525 L
.432 .04486 L
.436 .04451 L
.44 .04413 L
.444 .04366 L
.448 .04305 L
.452 .04227 L
.456 .04134 L
.46 .04027 L
.464 .03912 L
.468 .03794 L
.472 .03679 L
.476 .03572 L
.48 .03474 L
.484 .03388 L
.488 .03312 L
.492 .03244 L
.496 .03183 L
.5 .03126 L
.504 .03073 L
.508 .03023 L
.512 .02974 L
.516 .02926 L
.52 .02875 L
.524 .02821 L
.528 .02761 L
.532 .02697 L
.536 .0263 L
.54 .02564 L
.544 .02507 L
.548 .02465 L
.552 .02443 L
.556 .02442 L
.56 .02461 L
.564 .02496 L
.568 .02537 L
.572 .02577 L
.576 .02609 L
.58 .02629 L
.584 .02637 L
.588 .02638 L
.592 .02637 L
.596 .02639 L
.6 .02648 L
Mistroke
.604 .02665 L
.608 .02686 L
.612 .02708 L
.616 .02726 L
.62 .02735 L
.624 .02735 L
.628 .02726 L
.632 .02713 L
.636 .02697 L
.64 .02682 L
.644 .0267 L
.648 .02661 L
.652 .02654 L
.656 .02649 L
.66 .02645 L
.664 .02642 L
.668 .02639 L
.672 .02637 L
.676 .02637 L
.68 .0264 L
.684 .02647 L
.688 .02658 L
.692 .02673 L
.696 .02691 L
.7 .02708 L
.704 .02722 L
.708 .02728 L
.712 .02724 L
.716 .02711 L
.72 .02693 L
.724 .02674 L
.728 .02659 L
.732 .02651 L
.736 .02651 L
.74 .02657 L
.744 .02666 L
.748 .02674 L
.752 .0268 L
.756 .02684 L
.76 .02688 L
.764 .02693 L
.768 .027 L
.772 .02707 L
.776 .02711 L
.78 .0271 L
.784 .02703 L
.788 .02693 L
.792 .02683 L
.796 .02677 L
.8 .02676 L
Mistroke
.804 .02679 L
.808 .02685 L
.812 .02692 L
.816 .02696 L
.82 .02699 L
.824 .027 L
.828 .02701 L
.832 .02703 L
.836 .02707 L
.84 .0271 L
.844 .0271 L
.848 .02707 L
.852 .027 L
.856 .02694 L
.86 .02691 L
.864 .02693 L
.868 .02699 L
.872 .02706 L
.876 .02711 L
.88 .02712 L
.884 .02711 L
.888 .02709 L
.892 .02709 L
.896 .02709 L
.9 .0271 L
.904 .02711 L
.908 .02713 L
.912 .02714 L
.916 .02715 L
.92 .02715 L
.924 .02714 L
.928 .02711 L
.932 .02708 L
.936 .02708 L
.94 .02711 L
.944 .02716 L
.948 .02723 L
.952 .02727 L
.956 .02729 L
.96 .02729 L
.964 .02727 L
.968 .02724 L
.972 .0272 L
.976 .02714 L
.98 .0271 L
.984 .02709 L
.988 .02714 L
.992 .02723 L
.996 .02737 L
1 .02743 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02000HOol2001COol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008001Moo`800003Ool007oo055oo`002goo0P002Woo0P000goo0`000goo00<007ooOol0
5Woo00D007ooOomoo`0000Aoo`03001oogoo04Yoo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo0P005goo00D007ooOomoo`0000=oo`03001oo`0004]oo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2000=Ool30004Ool30004Ool50002Ool01000Ool0000017oo
0P001Goo0`000goo0`0017oo0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo
0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]o
o`05001oogooOol00002Ool01000Oomoo`001Goo0`000goo0P000Woo00@007ooOol0009oo`03001o
ogoo00=oo`05001oogooOol00003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`000Woo00<007ooOol00Woo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011o
o`04001oogoo0002Ool00`00Oomoo`05Ool01000Oomoogoo0P000Woo00@007ooOol0009oo`03001o
ogoo00=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00D007ooOol007oo
008000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0
17oo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool20004Ool00`00Oomoo`0;Ool40003Ool40007Ool00`00Oomoo`02Ool200001Goo
001oogoo00000Woo00<007ooOol00goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001o
ogoo0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`800003
Ool007oo00Eoo`8000Aoo`@0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomo
o`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00L007ooOomoo`00
Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool30003
Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo
0P001Woo000ROol00`00Oomoo`0BOol00`00Oomoo`0@Ool00`00Oomoo`02Ool20010Ool0029oo`80
019oo`03001oogoo019oo`07001oogooOol007oo0000?goo000ROomS000<Ool0029ooa<00003Ool0
07oo009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007oo001oo`80009oo`D0009oo`80
0005Ool00000001oo`03000017oo000000000Woo0P0000=oo`0000000Woo0P0000=oo`00Ool00`00
00Aoo`00001oo`@00004Ool00000Ool2000<Ool0029oo`8002Qoo`8000Yoo`03001oo`00009oo`<0
0005Ool00000001oo`0300001Goo00000000Ool00P0000Aoo`00001oo`800005Ool00000001oo`04
00001Goo000007oo00003Woo000ROol00`00Oomoo`0WOol2000;Ool2000fOol0029oo`8006eoo`00
8Woo0P00KGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eo
o`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]
Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:
Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0
029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00
0Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0
IWoo000XOolD001EOol002Qoo`03001oogoo015oo`@0055oo`002goo0P0017oo00<007ooOol00goo
0P0017oo0P000goo0`000goo00<007ooOol057oo0`00Cgoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`000goo00@007ooOol001Qoo`8004ioo`000goo1@000Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol001Uoo`<004aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P00
1goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@00
0Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`04
0003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`<0009oo`04001oogoo
0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00
Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`030002Ool0
1000Oomoo`000Woo00D007ooOomoo`0000Moo`04001oogoo0002Ool01@00Oomoogoo000017oo00@0
07ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo
000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol00Woo10000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001o
ogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001o
ogoo0007Ool00`00Oomoo`02Ool00`00Oomoo`070003Ool01000Oomoogoo10000goo00H007ooOol0
07oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003
Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P00
17oo00@007ooOol0009oo`03001oogoo034000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uo
o`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool3
0004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00mo
o`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2
000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=o
o`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007oo
Ool000]oo`03001oogoo008003Eooc8000aoo`002Woo00@007ooOol000]oo`04001oogoo000`Ool6
000nOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0YOol60013Ool000Yoo`04001oogoo
0007Ool00`00Oomoo`04Ool2000WOol30019Ool000]oo`8000Qoo`D0009oo`03001oogoo02Aoo`80
04aoo`0077oo00<007ooOol03Goo0`0017oo0P002Goo1@000Woo0P0017oo0P001Goo0`000goo0`00
17oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00
Oomoogoo00000Woo00@007ooOol000Uoo`<0009oo`04001oogoo0002Ool01000Oomoo`001Goo00D0
07ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool0
01aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`06Ool20004Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`04Ool40004Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002
Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0004Ool30002Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool0
1000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`000goo0P000goo
0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool0
0006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool20003Ool20005Ool00`00Oomoo`03Ool2
0004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@00
0goo0P001Woo000LOol00`00Oomoo`0GOol3001HOol001aoo`03001oogoo01Eoo`<005Yoo`0077oo
J@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomo
o`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@0
07ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80
07=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007oo
Ool0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`00
5goo00<007ooOol00Woo00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009o
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007oo
Ool00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02
001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol0
17oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(22545\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31677 m
.008 .31747 L
.012 .31791 L
.016 .31795 L
.02 .31758 L
.024 .3175 L
.028 .31774 L
.032 .31784 L
.036 .31773 L
.04 .31766 L
.044 .31769 L
.048 .31775 L
.052 .31778 L
.056 .3178 L
.06 .31779 L
.064 .31777 L
.068 .31775 L
.072 .31776 L
.076 .31781 L
.08 .31784 L
.084 .31784 L
.088 .31781 L
.092 .31777 L
.096 .31775 L
.1 .31775 L
.104 .31776 L
.108 .31773 L
.112 .31765 L
.116 .31752 L
.12 .31735 L
.124 .31717 L
.128 .31696 L
.132 .31666 L
.136 .31625 L
.14 .31567 L
.144 .31493 L
.148 .31399 L
.152 .31283 L
.156 .31141 L
.16 .30962 L
.164 .30741 L
.168 .3047 L
.172 .30142 L
.176 .29753 L
.18 .29297 L
.184 .28769 L
.188 .28163 L
.192 .27476 L
.196 .26706 L
.2 .25858 L
Mistroke
.204 .24943 L
.208 .23973 L
.212 .22968 L
.216 .2195 L
.22 .20944 L
.224 .1998 L
.228 .19091 L
.232 .18313 L
.236 .17685 L
.24 .17236 L
.244 .1699 L
.248 .16956 L
.252 .17135 L
.256 .17513 L
.26 .18063 L
.264 .18746 L
.268 .1951 L
.272 .20293 L
.276 .21025 L
.28 .21637 L
.284 .22073 L
.288 .22295 L
.292 .22286 L
.296 .22056 L
.3 .21639 L
.304 .21095 L
.308 .20497 L
.312 .19931 L
.316 .1948 L
.32 .19224 L
.324 .1922 L
.328 .19496 L
.332 .20039 L
.336 .208 L
.34 .21704 L
.344 .22657 L
.348 .23569 L
.352 .24369 L
.356 .2502 L
.36 .2552 L
.364 .259 L
.368 .26219 L
.372 .26551 L
.376 .2698 L
.38 .27575 L
.384 .28369 L
.388 .29341 L
.392 .30418 L
.396 .31481 L
.4 .32383 L
Mistroke
.404 .32986 L
.408 .33192 L
.412 .32974 L
.416 .32381 L
.42 .3152 L
.424 .30535 L
.428 .29582 L
.432 .28804 L
.436 .28305 L
.44 .28132 L
.444 .28272 L
.448 .2866 L
.452 .29195 L
.456 .29763 L
.46 .30263 L
.464 .30634 L
.468 .30871 L
.472 .31017 L
.476 .31134 L
.48 .31258 L
.484 .31384 L
.488 .31468 L
.492 .31444 L
.496 .31264 L
.5 .30923 L
.504 .30485 L
.508 .30079 L
.512 .29859 L
.516 .29946 L
.52 .30379 L
.524 .31098 L
.528 .31957 L
.532 .32769 L
.536 .33347 L
.54 .33558 L
.544 .33363 L
.548 .32839 L
.552 .32153 L
.556 .31512 L
.56 .31098 L
.564 .3102 L
.568 .31281 L
.572 .31788 L
.576 .32367 L
.58 .32819 L
.584 .32989 L
.588 .32824 L
.592 .32391 L
.596 .31847 L
.6 .31372 L
Mistroke
.604 .31103 L
.608 .31093 L
.612 .31305 L
.616 .31636 L
.62 .31955 L
.624 .32154 L
.628 .32188 L
.632 .32086 L
.636 .31928 L
.64 .31795 L
.644 .31731 L
.648 .31734 L
.652 .31783 L
.656 .31861 L
.66 .31964 L
.664 .32086 L
.668 .32198 L
.672 .32261 L
.676 .32236 L
.68 .32111 L
.684 .31908 L
.688 .31675 L
.692 .31486 L
.696 .31416 L
.7 .31517 L
.704 .31772 L
.708 .32084 L
.712 .32303 L
.716 .32315 L
.72 .32114 L
.724 .31821 L
.728 .31607 L
.732 .31588 L
.736 .31765 L
.74 .32027 L
.744 .32233 L
.748 .32281 L
.752 .32147 L
.756 .3189 L
.76 .31621 L
.764 .31474 L
.768 .31542 L
.772 .31807 L
.776 .32134 L
.78 .32331 L
.784 .32268 L
.788 .31992 L
.792 .31687 L
.796 .31558 L
.8 .31678 L
Mistroke
.804 .3194 L
.808 .32156 L
.812 .32197 L
.816 .32068 L
.82 .31887 L
.824 .31759 L
.828 .31723 L
.832 .31763 L
.836 .31843 L
.84 .31949 L
.844 .3206 L
.848 .32116 L
.852 .32072 L
.856 .31927 L
.86 .31768 L
.864 .31719 L
.868 .31819 L
.872 .31993 L
.876 .32097 L
.88 .32035 L
.884 .31868 L
.888 .3175 L
.892 .31791 L
.896 .31971 L
.9 .32127 L
.904 .3212 L
.908 .3195 L
.912 .31747 L
.916 .31682 L
.92 .31796 L
.924 .31982 L
.928 .32101 L
.932 .32067 L
.936 .31954 L
.94 .31885 L
.944 .31899 L
.948 .3197 L
.952 .31981 L
.956 .31879 L
.96 .3177 L
.964 .31738 L
.968 .31848 L
.972 .32066 L
.976 .3219 L
.98 .32147 L
.984 .31995 L
.988 .31788 L
.992 .31718 L
.996 .31826 L
1 .31924 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15905 m
.008 .15821 L
.012 .15794 L
.016 .15833 L
.02 .15837 L
.024 .15824 L
.028 .15821 L
.032 .15828 L
.036 .15827 L
.04 .15826 L
.044 .15825 L
.048 .15827 L
.052 .15826 L
.056 .15827 L
.06 .15826 L
.064 .15827 L
.068 .15826 L
.072 .15826 L
.076 .15826 L
.08 .15827 L
.084 .15826 L
.088 .15827 L
.092 .15826 L
.096 .15827 L
.1 .15827 L
.104 .15827 L
.108 .15827 L
.112 .15828 L
.116 .15828 L
.12 .15829 L
.124 .1583 L
.128 .15832 L
.132 .15834 L
.136 .15837 L
.14 .1584 L
.144 .15844 L
.148 .1585 L
.152 .15858 L
.156 .15868 L
.16 .15881 L
.164 .15897 L
.168 .15917 L
.172 .15942 L
.176 .15973 L
.18 .16012 L
.184 .16058 L
.188 .16114 L
.192 .1618 L
.196 .16258 L
.2 .16349 L
Mistroke
.204 .16455 L
.208 .16577 L
.212 .16714 L
.216 .16868 L
.22 .17038 L
.224 .17224 L
.228 .17425 L
.232 .1764 L
.236 .17866 L
.24 .18101 L
.244 .18342 L
.248 .18586 L
.252 .18829 L
.256 .19068 L
.26 .19301 L
.264 .19525 L
.268 .19738 L
.272 .1994 L
.276 .20131 L
.28 .20313 L
.284 .20487 L
.288 .20657 L
.292 .20825 L
.296 .20996 L
.3 .21173 L
.304 .21358 L
.308 .21552 L
.312 .21756 L
.316 .21968 L
.32 .22186 L
.324 .22408 L
.328 .22629 L
.332 .22845 L
.336 .23053 L
.34 .2325 L
.344 .23435 L
.348 .23607 L
.352 .23768 L
.356 .2392 L
.36 .24063 L
.364 .242 L
.368 .24333 L
.372 .2446 L
.376 .24581 L
.38 .24695 L
.384 .24797 L
.388 .24887 L
.392 .24962 L
.396 .25021 L
.4 .25065 L
Mistroke
.404 .25099 L
.408 .25126 L
.412 .25152 L
.416 .25185 L
.42 .25226 L
.424 .25281 L
.428 .25349 L
.432 .25429 L
.436 .25517 L
.44 .2561 L
.444 .25702 L
.448 .25789 L
.452 .2587 L
.456 .25941 L
.46 .26004 L
.464 .26058 L
.468 .26107 L
.472 .26151 L
.476 .26192 L
.48 .26231 L
.484 .26269 L
.488 .26306 L
.492 .26344 L
.496 .26385 L
.5 .26428 L
.504 .26475 L
.508 .26525 L
.512 .26575 L
.516 .26621 L
.52 .26658 L
.524 .26681 L
.528 .26687 L
.532 .26677 L
.536 .26653 L
.54 .2662 L
.544 .26584 L
.548 .26552 L
.552 .26528 L
.556 .26513 L
.56 .26508 L
.564 .26507 L
.568 .26506 L
.572 .26501 L
.576 .2649 L
.58 .26474 L
.584 .26455 L
.588 .26437 L
.592 .26423 L
.596 .26417 L
.6 .26419 L
Mistroke
.604 .26426 L
.608 .26437 L
.612 .26449 L
.616 .26459 L
.62 .26467 L
.624 .26471 L
.628 .26473 L
.632 .26474 L
.636 .26474 L
.64 .26475 L
.644 .26475 L
.648 .26473 L
.652 .2647 L
.656 .26464 L
.66 .26455 L
.664 .26443 L
.668 .26428 L
.672 .26412 L
.676 .26398 L
.68 .26389 L
.684 .26386 L
.688 .26391 L
.692 .26401 L
.696 .26415 L
.7 .26427 L
.704 .26436 L
.708 .26437 L
.712 .26433 L
.716 .26424 L
.72 .26414 L
.724 .26406 L
.728 .264 L
.732 .26396 L
.736 .26391 L
.74 .26385 L
.744 .26378 L
.748 .26371 L
.752 .26367 L
.756 .26367 L
.76 .26372 L
.764 .26379 L
.768 .26386 L
.772 .2639 L
.776 .26388 L
.78 .26381 L
.784 .26371 L
.788 .26362 L
.792 .26356 L
.796 .26354 L
.8 .26353 L
Mistroke
.804 .26351 L
.808 .26349 L
.812 .26346 L
.816 .26343 L
.82 .26342 L
.824 .26341 L
.828 .26341 L
.832 .26341 L
.836 .26341 L
.84 .26339 L
.844 .26335 L
.848 .26331 L
.852 .26327 L
.856 .26323 L
.86 .26321 L
.864 .26319 L
.868 .26316 L
.872 .26311 L
.876 .26307 L
.88 .26303 L
.884 .26303 L
.888 .26305 L
.892 .26309 L
.896 .26311 L
.9 .2631 L
.904 .26304 L
.908 .26297 L
.912 .26288 L
.916 .26282 L
.92 .26276 L
.924 .26274 L
.928 .26274 L
.932 .26277 L
.936 .26282 L
.94 .26286 L
.944 .26286 L
.948 .26283 L
.952 .26275 L
.956 .26265 L
.96 .26255 L
.964 .26248 L
.968 .26246 L
.972 .26248 L
.976 .26251 L
.98 .26257 L
.984 .26261 L
.988 .26262 L
.992 .26259 L
.996 .26251 L
1 .2624 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15933 L
.012 .16119 L
.016 .1618 L
.02 .16124 L
.024 .16099 L
.028 .1612 L
.032 .16126 L
.036 .16121 L
.04 .16117 L
.044 .16121 L
.048 .1612 L
.052 .16121 L
.056 .16119 L
.06 .1612 L
.064 .16119 L
.068 .1612 L
.072 .16119 L
.076 .1612 L
.08 .16119 L
.084 .16119 L
.088 .16118 L
.092 .16119 L
.096 .16118 L
.1 .16119 L
.104 .16118 L
.108 .16117 L
.112 .16116 L
.116 .16116 L
.12 .16114 L
.124 .16113 L
.128 .16111 L
.132 .16109 L
.136 .16105 L
.14 .16101 L
.144 .16095 L
.148 .16088 L
.152 .16078 L
.156 .16066 L
.16 .16049 L
.164 .16029 L
.168 .16004 L
.172 .15972 L
.176 .15934 L
.18 .15886 L
.184 .15828 L
.188 .15759 L
.192 .15676 L
.196 .15578 L
.2 .15464 L
Mistroke
.204 .15332 L
.208 .15181 L
.212 .1501 L
.216 .14818 L
.22 .14606 L
.224 .14374 L
.228 .14123 L
.232 .13855 L
.236 .13572 L
.24 .13279 L
.244 .12978 L
.248 .12674 L
.252 .1237 L
.256 .12071 L
.26 .1178 L
.264 .115 L
.268 .11234 L
.272 .10981 L
.276 .10742 L
.28 .10515 L
.284 .10297 L
.288 .10084 L
.292 .09873 L
.296 .09658 L
.3 .09437 L
.304 .09206 L
.308 .08963 L
.312 .08708 L
.316 .08442 L
.32 .08168 L
.324 .07891 L
.328 .07614 L
.332 .07344 L
.336 .07083 L
.34 .06835 L
.344 .06603 L
.348 .06386 L
.352 .06184 L
.356 .05994 L
.36 .05814 L
.364 .05641 L
.368 .05474 L
.372 .05313 L
.376 .0516 L
.38 .05016 L
.384 .04886 L
.388 .04773 L
.392 .04679 L
.396 .04603 L
.4 .04546 L
Mistroke
.404 .04502 L
.408 .04465 L
.412 .04429 L
.416 .04388 L
.42 .04334 L
.424 .04265 L
.428 .04178 L
.432 .04077 L
.436 .03964 L
.44 .03846 L
.444 .03729 L
.448 .03618 L
.452 .03516 L
.456 .03426 L
.46 .03346 L
.464 .03275 L
.468 .03212 L
.472 .03154 L
.476 .03101 L
.48 .0305 L
.484 .03002 L
.488 .02953 L
.492 .02903 L
.496 .0285 L
.5 .02793 L
.504 .02732 L
.508 .02668 L
.512 .02604 L
.516 .02545 L
.52 .02497 L
.524 .02466 L
.528 .02455 L
.532 .02464 L
.536 .02492 L
.54 .02531 L
.544 .02574 L
.548 .02612 L
.552 .0264 L
.556 .02656 L
.56 .02661 L
.564 .02659 L
.568 .02658 L
.572 .02661 L
.576 .02672 L
.58 .0269 L
.584 .02712 L
.588 .02732 L
.592 .02747 L
.596 .02753 L
.6 .02749 L
Mistroke
.604 .02737 L
.608 .0272 L
.612 .02703 L
.616 .02688 L
.62 .02677 L
.624 .0267 L
.628 .02665 L
.632 .02662 L
.636 .02659 L
.64 .02656 L
.644 .02653 L
.648 .02652 L
.652 .02653 L
.656 .02659 L
.66 .02669 L
.664 .02683 L
.668 .027 L
.672 .02717 L
.676 .02731 L
.68 .02739 L
.684 .0274 L
.688 .02732 L
.692 .02717 L
.696 .02699 L
.7 .02683 L
.704 .02671 L
.708 .02666 L
.712 .02667 L
.716 .02674 L
.72 .02683 L
.724 .02691 L
.728 .02698 L
.732 .02703 L
.736 .02708 L
.74 .02714 L
.744 .0272 L
.748 .02725 L
.752 .02726 L
.756 .02722 L
.76 .02713 L
.764 .02702 L
.768 .02694 L
.772 .02689 L
.776 .02691 L
.78 .02697 L
.784 .02705 L
.788 .02712 L
.792 .02716 L
.796 .02716 L
.8 .02715 L
Mistroke
.804 .02715 L
.808 .02716 L
.812 .0272 L
.816 .02724 L
.82 .02726 L
.824 .02723 L
.828 .02717 L
.832 .02711 L
.836 .02708 L
.84 .02708 L
.844 .02712 L
.848 .02717 L
.852 .02722 L
.856 .02726 L
.86 .02729 L
.864 .0273 L
.868 .02731 L
.872 .0273 L
.876 .02728 L
.88 .02725 L
.884 .02723 L
.888 .02722 L
.892 .02723 L
.896 .02725 L
.9 .02727 L
.904 .0273 L
.908 .02733 L
.912 .02736 L
.916 .02737 L
.92 .02736 L
.924 .02734 L
.928 .02731 L
.932 .02731 L
.936 .02734 L
.94 .02739 L
.944 .02741 L
.948 .02742 L
.952 .02738 L
.956 .02735 L
.96 .02733 L
.964 .02735 L
.968 .02738 L
.972 .02744 L
.976 .02746 L
.98 .02749 L
.984 .02748 L
.988 .0275 L
.992 .0275 L
.996 .02749 L
1 .02744 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02000FOol2001EOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008001Eoo`03001oo`0005Eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol04goo
00D007ooOomoo`0000Aoo`8004ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00
57oo00<007ooOol00Woo00<007ooOol00`00CWoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8000eoo`<000Aoo`8000=oo`03001oo`0000@000Aoo`8000Aoo`8000Eoo`<0
00=oo`<000Aoo`8000=oo`D000=oo`8000Aoo`8000Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@00
0Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomo
ogoo00000Woo00@007ooOol000=oo`80009oo`<0009oo`04001oogoo0002Ool01000Oomoo`001Goo
00D007ooOomoo`0000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04
001oogoo0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007oo
Ool0009oo`03001oogoo00Eoo`03001oo`00009oo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Ool000000Woo00<007ooOol0
1Goo00<007oo00000Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000Aoo`03001oogoo00]oo`@0009oo`80009oo`03001oogoo00Eoo`06001oogoo001o
o`000Woo00@007ooOol0009oo`03001oogoo00=oo`04001oogooOol40003Ool01000Oomoo`000Woo
00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003
Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`02
Ool30002Ool00`00Oomoo`04Ool20003Ool20002Ool01000Oomoo`000Woo00<007ooOol00Woo0P00
0goo00<007ooOol017oo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@0
07ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`008Woo0P0037oo1P000Woo
0P0027oo00<007ooOol00Woo0`0017oo0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`80
00Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol03goo00<007ooOol04Goo00@0
07ooOomoo`<0049oo`008Woo0P003goo0P004goo00H007ooOomoo`00Ool20004Ool00`00Oomoo`0j
Ool0029oof<000aoo`008Woo4@000goo00D007ooOomoo`00009oo`05001oogooOol00003Ool02@00
Oomoogoo001oo`00Ool00002Ool4000017oo001oogoo0`0000Eoo`00000007oo00<00003Ool00000
00D00004Ool00000Ool200001Goo00000000Ool0100000Aoo`00001oo`<00004Ool00000000<Ool0
029oo`8002Eoo`03001oo`0000Yoo`04001oo`00Ool30002Ool2000017oo000000000Woo0P0000=o
o`0000000Woo1@0000Aoo`00001oo`T00003Ool0000000ioo`008Woo00<007ooOol09Goo00<007oo
Ool02Goo0P000goo00<007ooOol0<goo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001o
ogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`00
27oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@0
07ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001o
ogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04
001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000R
Ool2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00
Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<0
07ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001o
ogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0
015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo4P00Egoo000XOol00`00
Oomoo`0>Ool4001DOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001o
ogoo019oo`80059oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=o
o`04001oogoo000EOol3001@Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogoo000GOol3001>Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Aoo`H000Aoo`8000Aoo`8000=oo`<0
00=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007oo
Oomoo`00009oo`04001oogoo0005Ool30004Ool01000Oomoo`000Woo00@007ooOol000=oo`05001o
ogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
0Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000
Oomoo`000Woo00<007ooOol01Goo0`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo
1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oo`0000<0009oo`04
001oogoo0002Ool01@00Oomoogoo00001goo00@007ooOol0009oo`03001oogoo009oo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03
001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`L0
009oo`05001oogooOol00003Ool40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001o
ogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo=0000goo00@0
07ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P00
17oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol0
3goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol0
2Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P00
0goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001o
o`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Mo
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03
001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@0
07ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0
JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000
Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomo
o`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00<Woo=@0037oo000:Ool0
1000Oomoo`002goo00@007ooOol002eoo`L0041oo`002Woo00@007ooOol000Moo`@000=oo`03001o
ogoo02Ioo`H004Ioo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8002Aoo`<004aoo`002goo
0P0027oo1@000Woo00<007ooOol08Goo0P00Cgoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool3
0004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool3
0004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`001goo0`0017oo00@0
07ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo
00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo
00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001o
ogoo00=oo`80009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo
00@007ooOol0009oo`04001oogooOol30003Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03
Ool001aoo`8000eoo`@000=oo`04001oogoo0002Ool20005Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`030006Ool20004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool001aoo`8000eoo`D000=oo`@000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo
01Aoo`<005]oo`0077oo00<007ooOol04Woo0`00GGoo000LOomY000<Ool001aoo`05001oogooOol0
0003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
00]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol0
00Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`005Woo0`00
0goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009o
o`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomo
o`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]o
o`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04
001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo
10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03
001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(22712\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31789 m
.008 .31796 L
.012 .31749 L
.016 .31741 L
.02 .31771 L
.024 .31776 L
.028 .31763 L
.032 .31764 L
.036 .31771 L
.04 .31769 L
.044 .31766 L
.048 .31768 L
.052 .31773 L
.056 .31774 L
.06 .31772 L
.064 .31769 L
.068 .31766 L
.072 .31765 L
.076 .31765 L
.08 .31763 L
.084 .31756 L
.088 .31744 L
.092 .31728 L
.096 .31711 L
.1 .3169 L
.104 .31662 L
.108 .31622 L
.112 .31567 L
.116 .31495 L
.12 .31405 L
.124 .31296 L
.128 .3116 L
.132 .30989 L
.136 .30775 L
.14 .30512 L
.144 .30195 L
.148 .2982 L
.152 .29382 L
.156 .28872 L
.16 .28281 L
.164 .27606 L
.168 .26849 L
.172 .26015 L
.176 .25113 L
.18 .24154 L
.184 .23152 L
.188 .22124 L
.192 .21098 L
.196 .20104 L
.2 .19178 L
Mistroke
.204 .18358 L
.208 .17676 L
.212 .17162 L
.216 .1684 L
.22 .16727 L
.224 .16828 L
.228 .17139 L
.232 .17637 L
.236 .18288 L
.24 .1904 L
.244 .19829 L
.248 .2059 L
.252 .21254 L
.256 .21766 L
.26 .2208 L
.264 .22169 L
.268 .2203 L
.272 .21686 L
.276 .21181 L
.28 .20585 L
.284 .19984 L
.288 .1947 L
.292 .19128 L
.296 .19023 L
.3 .19188 L
.304 .19626 L
.308 .20304 L
.312 .2116 L
.316 .22113 L
.32 .23075 L
.324 .23967 L
.328 .24726 L
.332 .25323 L
.336 .25765 L
.34 .26101 L
.344 .26411 L
.348 .26785 L
.352 .27301 L
.356 .28007 L
.36 .28903 L
.364 .29932 L
.368 .30991 L
.372 .31951 L
.376 .32682 L
.38 .3308 L
.384 .3308 L
.388 .32678 L
.392 .31933 L
.396 .30965 L
.4 .29934 L
Mistroke
.404 .29008 L
.408 .28333 L
.412 .27999 L
.416 .28026 L
.42 .28358 L
.424 .28881 L
.428 .29467 L
.432 .30008 L
.436 .30441 L
.44 .30753 L
.444 .30964 L
.448 .31112 L
.452 .31228 L
.456 .31323 L
.46 .31378 L
.464 .31355 L
.468 .31224 L
.472 .30981 L
.476 .30656 L
.48 .30314 L
.484 .30049 L
.488 .29968 L
.492 .30159 L
.496 .30657 L
.5 .31406 L
.504 .32266 L
.508 .33045 L
.512 .3355 L
.516 .33647 L
.52 .3331 L
.524 .32642 L
.528 .31858 L
.532 .31209 L
.536 .30899 L
.54 .31007 L
.544 .31463 L
.548 .32086 L
.552 .32652 L
.556 .32971 L
.56 .32948 L
.564 .3261 L
.568 .32093 L
.572 .31579 L
.576 .31225 L
.58 .31106 L
.584 .31206 L
.588 .31444 L
.592 .3172 L
.596 .31951 L
.6 .32087 L
Mistroke
.604 .32118 L
.608 .32065 L
.612 .31968 L
.616 .31867 L
.62 .31788 L
.624 .31743 L
.628 .31743 L
.632 .31801 L
.636 .31926 L
.64 .321 L
.644 .32268 L
.648 .32351 L
.652 .32291 L
.656 .3208 L
.66 .3178 L
.664 .31493 L
.668 .31327 L
.672 .31355 L
.676 .31577 L
.68 .31918 L
.684 .3224 L
.688 .32399 L
.692 .32317 L
.696 .32034 L
.7 .31702 L
.704 .31502 L
.708 .31541 L
.712 .31794 L
.716 .32115 L
.72 .32332 L
.724 .32332 L
.728 .32115 L
.732 .31784 L
.736 .31496 L
.74 .31392 L
.744 .31535 L
.748 .31862 L
.752 .3221 L
.756 .32386 L
.76 .3229 L
.764 .31984 L
.768 .31662 L
.772 .3152 L
.776 .31631 L
.78 .31896 L
.784 .32135 L
.788 .3221 L
.792 .32104 L
.796 .31913 L
.8 .31749 L
Mistroke
.804 .3168 L
.808 .31722 L
.812 .3184 L
.816 .31989 L
.82 .32104 L
.824 .32116 L
.828 .3201 L
.832 .3184 L
.836 .31719 L
.84 .31746 L
.844 .319 L
.848 .32062 L
.852 .321 L
.856 .31978 L
.86 .31802 L
.864 .31722 L
.868 .31799 L
.872 .31968 L
.876 .3208 L
.88 .32054 L
.884 .31936 L
.888 .31835 L
.892 .31833 L
.896 .31899 L
.9 .31938 L
.904 .31911 L
.908 .31855 L
.912 .31864 L
.916 .31969 L
.92 .32079 L
.924 .32091 L
.928 .31957 L
.932 .31763 L
.936 .31684 L
.94 .31775 L
.944 .31972 L
.948 .32123 L
.952 .32086 L
.956 .31922 L
.96 .31801 L
.964 .3181 L
.968 .31969 L
.972 .32119 L
.976 .32063 L
.98 .3187 L
.984 .31673 L
.988 .31611 L
.992 .31838 L
.996 .32139 L
1 .32267 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16126 m
.008 .15863 L
.012 .15771 L
.016 .1586 L
.02 .15889 L
.024 .15863 L
.028 .1585 L
.032 .15861 L
.036 .15863 L
.04 .15862 L
.044 .15859 L
.048 .15861 L
.052 .1586 L
.056 .15861 L
.06 .1586 L
.064 .15861 L
.068 .15861 L
.072 .15862 L
.076 .15861 L
.08 .15862 L
.084 .15862 L
.088 .15863 L
.092 .15863 L
.096 .15865 L
.1 .15866 L
.104 .15868 L
.108 .1587 L
.112 .15873 L
.116 .15878 L
.12 .15884 L
.124 .15891 L
.128 .159 L
.132 .15912 L
.136 .15927 L
.14 .15946 L
.144 .1597 L
.148 .16 L
.152 .16036 L
.156 .1608 L
.16 .16133 L
.164 .16196 L
.168 .16271 L
.172 .16358 L
.176 .1646 L
.18 .16577 L
.184 .16709 L
.188 .16857 L
.192 .17022 L
.196 .17203 L
.2 .17399 L
Mistroke
.204 .1761 L
.208 .17832 L
.212 .18064 L
.216 .18303 L
.22 .18546 L
.224 .18789 L
.228 .1903 L
.232 .19265 L
.236 .19492 L
.24 .19709 L
.244 .19915 L
.248 .2011 L
.252 .20295 L
.256 .20471 L
.26 .20643 L
.264 .20811 L
.268 .20981 L
.272 .21155 L
.276 .21336 L
.28 .21526 L
.284 .21725 L
.288 .21933 L
.292 .22149 L
.296 .22369 L
.3 .2259 L
.304 .22808 L
.308 .23019 L
.312 .2322 L
.316 .2341 L
.32 .23587 L
.324 .23752 L
.328 .23906 L
.332 .24051 L
.336 .24189 L
.34 .24321 L
.344 .24448 L
.348 .2457 L
.352 .24685 L
.356 .24791 L
.36 .24886 L
.364 .24966 L
.368 .2503 L
.372 .25081 L
.376 .25119 L
.38 .25149 L
.384 .25175 L
.388 .25205 L
.392 .25241 L
.396 .25289 L
.4 .25351 L
Mistroke
.404 .25425 L
.408 .2551 L
.412 .25602 L
.416 .25695 L
.42 .25786 L
.424 .2587 L
.428 .25945 L
.432 .26011 L
.436 .26068 L
.44 .26118 L
.444 .26163 L
.448 .26205 L
.452 .26244 L
.456 .26282 L
.46 .26319 L
.464 .26357 L
.468 .26396 L
.472 .26438 L
.476 .26483 L
.48 .26531 L
.484 .26579 L
.488 .26625 L
.492 .26665 L
.496 .26694 L
.5 .26708 L
.504 .26706 L
.508 .26689 L
.512 .26659 L
.516 .26623 L
.52 .26588 L
.524 .26558 L
.528 .26537 L
.532 .26526 L
.536 .26523 L
.54 .26524 L
.544 .26523 L
.548 .26517 L
.552 .26504 L
.556 .26487 L
.56 .26468 L
.564 .26452 L
.568 .26441 L
.572 .26438 L
.576 .26443 L
.58 .26453 L
.584 .26466 L
.588 .26478 L
.592 .26487 L
.596 .26493 L
.6 .26496 L
Mistroke
.604 .26497 L
.608 .26496 L
.612 .26496 L
.616 .26496 L
.62 .26496 L
.624 .26493 L
.628 .26488 L
.632 .2648 L
.636 .26469 L
.64 .26455 L
.644 .2644 L
.648 .26426 L
.652 .26416 L
.656 .2641 L
.66 .26411 L
.664 .26418 L
.668 .26429 L
.672 .26441 L
.676 .26452 L
.68 .26459 L
.684 .26459 L
.688 .26453 L
.692 .26444 L
.696 .26433 L
.7 .26424 L
.704 .26417 L
.708 .26412 L
.712 .26407 L
.716 .26402 L
.72 .26397 L
.724 .26393 L
.728 .26391 L
.732 .26393 L
.736 .26397 L
.74 .26403 L
.744 .26408 L
.748 .26409 L
.752 .26406 L
.756 .26399 L
.76 .2639 L
.764 .26382 L
.768 .26377 L
.772 .26375 L
.776 .26373 L
.78 .26372 L
.784 .26369 L
.788 .26366 L
.792 .26363 L
.796 .26362 L
.8 .26362 L
Mistroke
.804 .26364 L
.808 .26365 L
.812 .26364 L
.816 .26361 L
.82 .26356 L
.824 .2635 L
.828 .26344 L
.832 .26341 L
.836 .26339 L
.84 .26338 L
.844 .26337 L
.848 .26334 L
.852 .26331 L
.856 .26328 L
.86 .26327 L
.864 .26327 L
.868 .26328 L
.872 .26327 L
.876 .26325 L
.88 .26321 L
.884 .26316 L
.888 .26311 L
.892 .26306 L
.896 .26302 L
.9 .26299 L
.904 .26297 L
.908 .26298 L
.912 .263 L
.916 .26301 L
.92 .26301 L
.924 .26299 L
.928 .26295 L
.932 .2629 L
.936 .26283 L
.94 .26277 L
.944 .26271 L
.948 .26268 L
.952 .26267 L
.956 .2627 L
.96 .26275 L
.964 .26279 L
.968 .26279 L
.972 .26274 L
.976 .26265 L
.98 .26255 L
.984 .26247 L
.988 .26243 L
.992 .26241 L
.996 .26244 L
1 .26246 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16164 L
.012 .16113 L
.016 .16101 L
.02 .16128 L
.024 .16127 L
.028 .16119 L
.032 .16116 L
.036 .16122 L
.04 .1612 L
.044 .1612 L
.048 .16119 L
.052 .16121 L
.056 .16119 L
.06 .1612 L
.064 .16118 L
.068 .16119 L
.072 .16118 L
.076 .16119 L
.08 .16118 L
.084 .16117 L
.088 .16116 L
.092 .16116 L
.096 .16114 L
.1 .16113 L
.104 .1611 L
.108 .16107 L
.112 .16102 L
.116 .16097 L
.12 .1609 L
.124 .16081 L
.128 .16069 L
.132 .16054 L
.136 .16034 L
.14 .16011 L
.144 .15981 L
.148 .15944 L
.152 .15899 L
.156 .15844 L
.16 .15778 L
.164 .15699 L
.168 .15606 L
.172 .15497 L
.176 .1537 L
.18 .15225 L
.184 .1506 L
.188 .14874 L
.192 .14669 L
.196 .14443 L
.2 .14198 L
Mistroke
.204 .13936 L
.208 .13658 L
.212 .13369 L
.216 .1307 L
.22 .12767 L
.224 .12463 L
.228 .12162 L
.232 .11868 L
.236 .11585 L
.24 .11314 L
.244 .11056 L
.248 .10812 L
.252 .1058 L
.256 .10359 L
.26 .10145 L
.264 .09934 L
.268 .09722 L
.272 .09504 L
.276 .09277 L
.28 .09039 L
.284 .08789 L
.288 .08528 L
.292 .08258 L
.296 .07983 L
.3 .07706 L
.304 .07433 L
.308 .07168 L
.312 .06916 L
.316 .06678 L
.32 .06455 L
.324 .06248 L
.328 .06055 L
.332 .05873 L
.336 .05699 L
.34 .05532 L
.344 .05371 L
.348 .05217 L
.352 .05072 L
.356 .04938 L
.36 .04819 L
.364 .04717 L
.368 .04634 L
.372 .04569 L
.376 .04519 L
.38 .0448 L
.384 .04446 L
.388 .04408 L
.392 .0436 L
.396 .04298 L
.4 .04219 L
Mistroke
.404 .04124 L
.408 .04016 L
.412 .039 L
.416 .03782 L
.42 .03667 L
.424 .0356 L
.428 .03464 L
.432 .03379 L
.436 .03306 L
.44 .03241 L
.444 .03183 L
.448 .0313 L
.452 .03079 L
.456 .03029 L
.46 .0298 L
.464 .0293 L
.468 .02878 L
.472 .02824 L
.476 .02766 L
.48 .02705 L
.484 .02643 L
.488 .02583 L
.492 .0253 L
.496 .02492 L
.5 .02472 L
.504 .02472 L
.508 .02492 L
.512 .02527 L
.516 .02569 L
.52 .02611 L
.524 .02646 L
.528 .02669 L
.532 .0268 L
.536 .02682 L
.54 .02679 L
.544 .02679 L
.548 .02684 L
.552 .02697 L
.556 .02715 L
.56 .02736 L
.564 .02755 L
.568 .02766 L
.572 .02767 L
.576 .0276 L
.58 .02745 L
.584 .02727 L
.588 .02709 L
.592 .02695 L
.596 .02685 L
.6 .02679 L
Mistroke
.604 .02676 L
.608 .02674 L
.612 .02672 L
.616 .02671 L
.62 .02669 L
.624 .0267 L
.628 .02673 L
.632 .02681 L
.636 .02692 L
.64 .02707 L
.644 .02723 L
.648 .02739 L
.652 .02751 L
.656 .02756 L
.66 .02753 L
.664 .02742 L
.668 .02724 L
.672 .02705 L
.676 .02689 L
.68 .0268 L
.684 .02679 L
.688 .02685 L
.692 .02694 L
.696 .02704 L
.7 .02713 L
.704 .02718 L
.708 .02722 L
.712 .02725 L
.716 .0273 L
.72 .02735 L
.724 .0274 L
.728 .02741 L
.732 .02736 L
.736 .02726 L
.74 .02715 L
.744 .02705 L
.748 .02702 L
.752 .02705 L
.756 .02713 L
.76 .02723 L
.764 .02731 L
.768 .02735 L
.772 .02735 L
.776 .02733 L
.78 .0273 L
.784 .0273 L
.788 .02733 L
.792 .02736 L
.796 .02738 L
.8 .02737 L
Mistroke
.804 .02733 L
.808 .02728 L
.812 .02725 L
.816 .02725 L
.82 .02728 L
.824 .02732 L
.828 .02737 L
.832 .0274 L
.836 .02743 L
.84 .02745 L
.844 .02746 L
.848 .02746 L
.852 .02745 L
.856 .02743 L
.86 .0274 L
.864 .02737 L
.868 .02735 L
.872 .02735 L
.876 .02737 L
.88 .02743 L
.884 .0275 L
.888 .02756 L
.892 .02759 L
.896 .02757 L
.9 .02752 L
.904 .02747 L
.908 .02743 L
.912 .02743 L
.916 .02746 L
.92 .02749 L
.924 .02753 L
.928 .02756 L
.932 .02759 L
.936 .0276 L
.94 .02761 L
.944 .02758 L
.948 .02756 L
.952 .02752 L
.956 .02752 L
.96 .02754 L
.964 .0276 L
.968 .02765 L
.972 .02768 L
.976 .02768 L
.98 .02765 L
.984 .02761 L
.988 .02759 L
.992 .02758 L
.996 .0276 L
1 .02762 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02000COol2001HOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo0080019oo`04001oogoo001GOol000]oo`8000Yoo`8000=oo`<000=oo`03001oogoo015o
o`05001oogooOol00003Ool2001AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`80
015oo`03001oogoo009oo`03001oogoo00800003Ool007oo04moo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2000=Ool3000017oo001oogoo0P0000Aoo`00Ool000=oo`<0
00Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000=oo`D000=oo`8000Aoo`8000Aoo`D0009oo`<0
00Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`0;Ool01@00Oomoogoo00000Woo00<007ooOol010000goo0P0017oo00@007ooOol0009o
o`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`05001oogooOol00002Ool0
1000Oomoo`000Woo00@007ooOol0009oo`03001oogoo009oo`06001oogoo001oo`000goo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool2000@Ool01000Oomoo`000Woo00<007ooOol017oo0P0017oo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001o
ogoo00Aoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo0P0017oo00<007ooOol02goo10000goo00@007ooOol000Moo`8000=oo`04
001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001o
ogoo0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`8000aoo`04001oogoo0003Ool01000
Oomoo`001Woo10000Woo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00L007oo
Oomoo`00Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool50003Ool20008Ool00`00Ool00003
Ool20004Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo
1@000goo0P001Woo000ROol00`00Oomoo`0=Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool20015Ool0
029oo`8000eoo`03001oogoo015oo`03001oogoo009oo`<004Aoo`008WooH`0037oo000ROol>0002
Ool01@00Oomoogoo00000goo00@007ooOol000=oo`04001oogooOol20002Ool01000Oomoogoo1@00
00=oo`00Ool00`0000=oo`0000001P0000Eoo`00000007oo00T00004Ool00000Ool200000goo0000
0009000017oo0000000037oo000ROol2000ROol3000:Ool00`00Ool00002Ool20002Ool3000017oo
000000000Woo0P0000Aoo`00001oo`<00004Ool007ooOol200000goo0000000200000goo00000006
00000goo0000000<Ool0029oo`03001oogoo029oo`8000]oo`80009oo`03001oogoo03Ioo`008Woo
0P00KGoo000ROol2001]Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo
06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P00
17oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Ao
o`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<0
00=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003
Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00
Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool0
00]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029o
o`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001o
ogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Io
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uo
o`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol002Qoo`l005Yoo`00:7oo00<007ooOol02goo1@00EWoo000;Ool20004Ool00`00
Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0?Ool2001EOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`004goo0P00Dgoo0003Ool50002
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`005Goo0P00DGoo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool3
0004Ool20002Ool20003Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool2
0004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`000goo
0`0000=oo`00Ool00goo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol0
0002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001o
ogoo00=oo`<000Aoo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0
009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo
00eoo`04001oogoo0002Ool00`00Oomoo`05Ool30002Ool01000Oomoo`000Woo00@007ooOol000=o
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qo
o`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`0700001Goo001oogoo00000goo
00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<0
07ooOol017oo00@007ooOol000Ioo`8000Aoo`03001oogoo03L000=oo`04001oogoo0005Ool002Qo
o`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol5
0003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011o
o`03001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001o
ogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo
001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo0080
06Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007oo
Ool0IWoo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo
1@000Woo00@007ooOol000]oo`03001oogoo008002moocP000aoo`002Woo00@007ooOol000]oo`04
001oogoo000[Ool60013Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0SOol60019Ool0
00Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2000QOol3001?Ool000]oo`8000Qoo`D0009oo`03
001oogoo01ioo`<0055oo`0077oo00<007ooOol03Goo0`0017oo0P001goo1@0017oo0P0017oo0P00
1Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000L
Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Aoo`8000=oo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomo
o`030004Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Io
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001o
ogoo0002Ool01000Ool000001Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo
0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2
000=Ool40003Ool00`00Oomoo`020008Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002
Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomo
o`0<Ool00`00Oomoo`04Ool40008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=o
o`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D0009oo`<0
00Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004
Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo019oo`8005ioo`0077oo00<007oo
Ool03goo0`00H7oo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo
00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo009o
o`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000
Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol0
0`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol0
0Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`8007=o
o`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001o
ogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:
Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(22879\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31852 m
.008 .31785 L
.012 .31731 L
.016 .31723 L
.02 .31767 L
.024 .31781 L
.028 .31759 L
.032 .31751 L
.036 .31761 L
.04 .31764 L
.044 .31757 L
.048 .31753 L
.052 .3175 L
.056 .31746 L
.06 .31736 L
.064 .31722 L
.068 .31706 L
.072 .31685 L
.076 .31656 L
.08 .31617 L
.084 .31566 L
.088 .31499 L
.092 .31414 L
.096 .31309 L
.1 .31177 L
.104 .31012 L
.108 .30806 L
.112 .30554 L
.116 .3025 L
.12 .29889 L
.124 .29464 L
.128 .28967 L
.132 .28392 L
.136 .27734 L
.14 .26993 L
.144 .26175 L
.148 .25286 L
.152 .24335 L
.156 .23334 L
.16 .223 L
.164 .21259 L
.168 .20243 L
.172 .19286 L
.176 .18423 L
.18 .17687 L
.184 .17108 L
.188 .16713 L
.192 .16522 L
.196 .16548 L
.2 .16792 L
Mistroke
.204 .17234 L
.208 .17842 L
.212 .18567 L
.216 .19351 L
.22 .20133 L
.224 .20847 L
.228 .21432 L
.232 .21836 L
.236 .2202 L
.24 .2197 L
.244 .21699 L
.248 .21244 L
.252 .20672 L
.256 .20063 L
.26 .19506 L
.264 .19085 L
.268 .18873 L
.272 .18919 L
.276 .19242 L
.28 .19827 L
.284 .20628 L
.288 .21571 L
.292 .22568 L
.296 .23526 L
.3 .24371 L
.304 .25056 L
.308 .25578 L
.312 .2597 L
.316 .26298 L
.32 .26646 L
.324 .27093 L
.328 .27702 L
.332 .28492 L
.336 .29439 L
.34 .30473 L
.344 .31484 L
.348 .32341 L
.352 .32914 L
.356 .33107 L
.36 .32881 L
.364 .32266 L
.368 .31361 L
.372 .30318 L
.376 .29311 L
.38 .28501 L
.384 .28002 L
.388 .27858 L
.392 .28045 L
.396 .28487 L
.4 .29075 L
Mistroke
.404 .29694 L
.408 .30244 L
.412 .30667 L
.416 .30947 L
.42 .31105 L
.424 .31182 L
.428 .31219 L
.432 .31243 L
.436 .3125 L
.44 .31209 L
.444 .31077 L
.448 .30832 L
.452 .30503 L
.456 .30176 L
.46 .29972 L
.464 .30008 L
.468 .30357 L
.472 .31008 L
.476 .31852 L
.48 .32705 L
.484 .33359 L
.488 .33653 L
.492 .33523 L
.496 .33028 L
.5 .32322 L
.504 .31613 L
.508 .31104 L
.512 .30934 L
.516 .31136 L
.52 .31621 L
.524 .32217 L
.528 .32725 L
.532 .32982 L
.536 .32911 L
.54 .32538 L
.544 .31986 L
.548 .31433 L
.552 .31053 L
.556 .3095 L
.56 .31122 L
.564 .31471 L
.568 .31853 L
.572 .32135 L
.576 .32245 L
.58 .32184 L
.584 .32012 L
.588 .31823 L
.592 .317 L
.596 .31683 L
.6 .31756 L
Mistroke
.604 .31874 L
.608 .31989 L
.612 .32079 L
.616 .32145 L
.62 .32186 L
.624 .32184 L
.628 .32115 L
.632 .31964 L
.636 .31754 L
.64 .31545 L
.644 .31412 L
.648 .31421 L
.652 .3159 L
.656 .31875 L
.66 .32171 L
.664 .32348 L
.668 .32321 L
.672 .32098 L
.676 .31791 L
.68 .31564 L
.684 .31539 L
.688 .31726 L
.692 .32016 L
.696 .32247 L
.7 .32293 L
.704 .32126 L
.708 .31828 L
.712 .31548 L
.716 .31426 L
.72 .31533 L
.724 .3182 L
.728 .32143 L
.732 .32328 L
.736 .32275 L
.74 .32024 L
.744 .31733 L
.748 .31576 L
.752 .31637 L
.756 .31849 L
.76 .32064 L
.764 .32151 L
.768 .32077 L
.772 .31911 L
.776 .31758 L
.78 .31694 L
.784 .31741 L
.788 .31865 L
.792 .32008 L
.796 .32097 L
.8 .32078 L
Mistroke
.804 .31955 L
.808 .318 L
.812 .31716 L
.816 .31772 L
.82 .31925 L
.824 .3206 L
.828 .32073 L
.832 .31954 L
.836 .31808 L
.84 .31752 L
.844 .31818 L
.848 .3194 L
.852 .32009 L
.856 .31985 L
.86 .3192 L
.864 .31884 L
.868 .31905 L
.872 .31934 L
.876 .31914 L
.88 .31857 L
.884 .31826 L
.888 .31877 L
.892 .31985 L
.896 .32045 L
.9 .31995 L
.904 .31864 L
.908 .31766 L
.912 .31808 L
.916 .31952 L
.92 .32069 L
.924 .32049 L
.928 .31885 L
.932 .31734 L
.936 .31745 L
.94 .3191 L
.944 .32115 L
.948 .32173 L
.952 .32006 L
.956 .31775 L
.96 .31652 L
.964 .31724 L
.968 .31968 L
.972 .3214 L
.976 .32103 L
.98 .31955 L
.984 .31775 L
.988 .3175 L
.992 .31938 L
.996 .32079 L
1 .32086 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15862 m
.008 .15902 L
.012 .15909 L
.016 .1589 L
.02 .15888 L
.024 .15899 L
.028 .15897 L
.032 .15894 L
.036 .15893 L
.04 .15897 L
.044 .15895 L
.048 .15896 L
.052 .15895 L
.056 .15897 L
.06 .15896 L
.064 .15898 L
.068 .15898 L
.072 .159 L
.076 .15901 L
.08 .15904 L
.084 .15907 L
.088 .15911 L
.092 .15916 L
.096 .15924 L
.1 .15932 L
.104 .15944 L
.108 .15958 L
.112 .15976 L
.116 .15999 L
.12 .16027 L
.124 .16061 L
.128 .16103 L
.132 .16153 L
.136 .16213 L
.14 .16285 L
.144 .16369 L
.148 .16466 L
.152 .16578 L
.156 .16705 L
.16 .16848 L
.164 .17008 L
.168 .17184 L
.172 .17375 L
.176 .17581 L
.18 .17799 L
.184 .18028 L
.188 .18265 L
.192 .18506 L
.196 .18749 L
.2 .18991 L
Mistroke
.204 .19228 L
.208 .19458 L
.212 .19679 L
.216 .19889 L
.22 .20087 L
.224 .20276 L
.228 .20455 L
.232 .20628 L
.236 .20797 L
.24 .20966 L
.244 .21137 L
.248 .21315 L
.252 .21501 L
.256 .21696 L
.26 .21901 L
.264 .22113 L
.268 .22331 L
.272 .22551 L
.276 .2277 L
.28 .22984 L
.284 .23189 L
.288 .23383 L
.292 .23565 L
.296 .23734 L
.3 .23891 L
.304 .24038 L
.308 .24177 L
.312 .2431 L
.316 .24437 L
.32 .2456 L
.324 .24676 L
.328 .24784 L
.332 .24882 L
.336 .24967 L
.34 .25038 L
.344 .25094 L
.348 .25137 L
.352 .25171 L
.356 .25198 L
.36 .25226 L
.364 .25258 L
.368 .25301 L
.372 .25356 L
.376 .25425 L
.38 .25505 L
.384 .25595 L
.388 .25688 L
.392 .2578 L
.396 .25867 L
.4 .25947 L
Mistroke
.404 .26017 L
.408 .26077 L
.412 .2613 L
.416 .26176 L
.42 .26218 L
.424 .26257 L
.428 .26294 L
.432 .26332 L
.436 .2637 L
.44 .26409 L
.444 .2645 L
.448 .26493 L
.452 .26538 L
.456 .26584 L
.46 .2663 L
.464 .26672 L
.468 .26705 L
.472 .26726 L
.476 .26731 L
.48 .26721 L
.484 .26696 L
.488 .26662 L
.492 .26625 L
.496 .26591 L
.5 .26565 L
.504 .26549 L
.508 .26542 L
.512 .2654 L
.516 .26541 L
.52 .26539 L
.524 .26531 L
.528 .26518 L
.532 .265 L
.536 .26483 L
.54 .26468 L
.544 .26461 L
.548 .26461 L
.552 .26468 L
.556 .2648 L
.56 .26494 L
.564 .26506 L
.568 .26514 L
.572 .26519 L
.576 .2652 L
.58 .2652 L
.584 .26519 L
.588 .26518 L
.592 .26517 L
.596 .26515 L
.6 .26511 L
Mistroke
.604 .26505 L
.608 .26496 L
.612 .26483 L
.616 .26469 L
.62 .26455 L
.624 .26442 L
.628 .26434 L
.632 .26431 L
.636 .26435 L
.64 .26445 L
.644 .26457 L
.648 .26469 L
.652 .26478 L
.656 .26482 L
.66 .26479 L
.664 .26471 L
.668 .2646 L
.672 .2645 L
.676 .26441 L
.68 .26435 L
.684 .26431 L
.688 .26426 L
.692 .26421 L
.696 .26417 L
.7 .26413 L
.704 .26413 L
.708 .26416 L
.712 .26422 L
.716 .26428 L
.72 .26432 L
.724 .26431 L
.728 .26426 L
.732 .26416 L
.736 .26407 L
.74 .26399 L
.744 .26395 L
.748 .26394 L
.752 .26395 L
.756 .26394 L
.76 .26392 L
.764 .26388 L
.768 .26384 L
.772 .26382 L
.776 .26382 L
.78 .26384 L
.784 .26385 L
.788 .26386 L
.792 .26383 L
.796 .26377 L
.8 .26371 L
Mistroke
.804 .26364 L
.808 .2636 L
.812 .26358 L
.816 .26357 L
.82 .26356 L
.824 .26354 L
.828 .26353 L
.832 .26352 L
.836 .26351 L
.84 .2635 L
.844 .26349 L
.848 .26347 L
.852 .26343 L
.856 .26338 L
.86 .26333 L
.864 .26329 L
.868 .26326 L
.872 .26324 L
.876 .26323 L
.88 .26323 L
.884 .26323 L
.888 .26322 L
.892 .2632 L
.896 .26317 L
.9 .26314 L
.904 .26311 L
.908 .26308 L
.912 .26305 L
.916 .26301 L
.92 .26296 L
.924 .26293 L
.928 .26291 L
.932 .26292 L
.936 .26293 L
.94 .26294 L
.944 .26292 L
.948 .26289 L
.952 .26284 L
.956 .2628 L
.96 .26275 L
.964 .26272 L
.968 .26267 L
.972 .26265 L
.976 .26262 L
.98 .26264 L
.984 .26266 L
.988 .26269 L
.992 .26268 L
.996 .26265 L
1 .26257 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16313 L
.012 .16124 L
.016 .16055 L
.02 .16121 L
.024 .16141 L
.028 .16122 L
.032 .16112 L
.036 .1612 L
.04 .16121 L
.044 .1612 L
.048 .16118 L
.052 .16119 L
.056 .16118 L
.06 .16118 L
.064 .16116 L
.068 .16115 L
.072 .16113 L
.076 .16111 L
.08 .16108 L
.084 .16104 L
.088 .16098 L
.092 .16092 L
.096 .16083 L
.1 .16073 L
.104 .16058 L
.108 .1604 L
.112 .16017 L
.116 .15989 L
.12 .15954 L
.124 .15912 L
.128 .15859 L
.132 .15796 L
.136 .15721 L
.14 .15632 L
.144 .15527 L
.148 .15406 L
.152 .15267 L
.156 .15108 L
.16 .14928 L
.164 .14729 L
.168 .1451 L
.172 .14272 L
.176 .14015 L
.18 .13743 L
.184 .13457 L
.188 .13161 L
.192 .1286 L
.196 .12556 L
.2 .12254 L
Mistroke
.204 .11958 L
.208 .11671 L
.212 .11395 L
.216 .11132 L
.22 .10883 L
.224 .10648 L
.228 .10423 L
.232 .10207 L
.236 .09995 L
.24 .09784 L
.244 .09568 L
.248 .09346 L
.252 .09113 L
.256 .08869 L
.26 .08613 L
.264 .08347 L
.268 .08074 L
.272 .07798 L
.276 .07523 L
.28 .07256 L
.284 .06998 L
.288 .06755 L
.292 .06527 L
.296 .06314 L
.3 .06117 L
.304 .05931 L
.308 .05756 L
.312 .05589 L
.316 .05429 L
.32 .05275 L
.324 .05128 L
.328 .04991 L
.332 .04867 L
.336 .04759 L
.34 .04668 L
.344 .04596 L
.348 .0454 L
.352 .04497 L
.356 .04461 L
.36 .04425 L
.364 .04382 L
.368 .04327 L
.372 .04256 L
.376 .04168 L
.38 .04066 L
.384 .03953 L
.388 .03835 L
.392 .03717 L
.396 .03606 L
.4 .03505 L
Mistroke
.404 .03416 L
.408 .03338 L
.412 .03271 L
.416 .03211 L
.42 .03157 L
.424 .03106 L
.428 .03056 L
.432 .03007 L
.436 .02958 L
.44 .02907 L
.444 .02855 L
.448 .02799 L
.452 .0274 L
.456 .02679 L
.46 .02619 L
.464 .02565 L
.468 .02522 L
.472 .02494 L
.476 .02486 L
.48 .02496 L
.484 .02524 L
.488 .02563 L
.492 .02607 L
.496 .02647 L
.5 .02678 L
.504 .02697 L
.508 .02703 L
.512 .02702 L
.516 .02699 L
.52 .02699 L
.524 .02706 L
.528 .02721 L
.532 .0274 L
.536 .02761 L
.54 .02776 L
.544 .02783 L
.548 .0278 L
.552 .02768 L
.556 .02751 L
.56 .02732 L
.564 .02715 L
.568 .02703 L
.572 .02695 L
.576 .02691 L
.58 .02689 L
.584 .02688 L
.588 .02686 L
.592 .02686 L
.596 .02686 L
.6 .02688 L
Mistroke
.604 .02694 L
.608 .02703 L
.612 .02716 L
.616 .02732 L
.62 .02747 L
.624 .0276 L
.628 .02768 L
.632 .02769 L
.636 .02762 L
.64 .02749 L
.644 .02732 L
.648 .02714 L
.652 .027 L
.656 .02693 L
.66 .02694 L
.664 .02701 L
.668 .02712 L
.672 .02724 L
.676 .02733 L
.68 .02739 L
.684 .02743 L
.688 .02745 L
.692 .02747 L
.696 .0275 L
.7 .02752 L
.704 .02751 L
.708 .02746 L
.712 .02738 L
.716 .02728 L
.72 .02721 L
.724 .02719 L
.728 .02722 L
.732 .0273 L
.736 .02739 L
.74 .02747 L
.744 .02752 L
.748 .02752 L
.752 .0275 L
.756 .02748 L
.76 .02748 L
.764 .02748 L
.768 .0275 L
.772 .0275 L
.776 .02748 L
.78 .02745 L
.784 .02743 L
.788 .02742 L
.792 .02743 L
.796 .02747 L
.8 .02751 L
Mistroke
.804 .02754 L
.808 .02756 L
.812 .02758 L
.816 .02759 L
.82 .02759 L
.824 .0276 L
.828 .0276 L
.832 .02759 L
.836 .02757 L
.84 .02754 L
.844 .02751 L
.848 .0275 L
.852 .02752 L
.856 .02757 L
.86 .02764 L
.864 .02771 L
.868 .02774 L
.872 .02773 L
.876 .0277 L
.88 .02765 L
.884 .02761 L
.888 .02759 L
.892 .02758 L
.896 .0276 L
.9 .02764 L
.904 .02769 L
.908 .02775 L
.912 .02779 L
.916 .02781 L
.92 .02779 L
.924 .02775 L
.928 .02769 L
.932 .02766 L
.936 .02765 L
.94 .02768 L
.944 .02772 L
.948 .02778 L
.952 .02784 L
.956 .02788 L
.96 .02787 L
.964 .02785 L
.968 .02778 L
.972 .02774 L
.976 .0277 L
.98 .02773 L
.984 .02778 L
.988 .02786 L
.992 .02792 L
.996 .02796 L
1 .02794 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo00004Woo00<007ooOol0FGoo000:Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool00`00Oomoo`02000@Ool3001JOol000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`03001oogoo008000moo`800003Ool0000005Uoo`002goo0P002Woo0P000goo0`00
0goo00<007ooOol03Woo00D007ooOomoo`0000=oo`<005=oo`002goo0P0017oo00<007ooOol00goo
0P000goo0`000goo0P003goo00<007ooOol00Woo00D007ooOol007oo0080059oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000=Ool30004Ool40002Ool00`00Oomoo`03
0004Ool20004Ool20005Ool30003Ool30004Ool20003Ool50003Ool20004Ool20004Ool50002Ool3
0004Ool20006Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol02goo00D007oo001oo`00009oo`04001oo`000004Ool01000Oomoo`0017oo00@007oo
Ool0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo009oo`06001oogoo001oo`000goo
00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2000=Ool01000Oomoo`000Woo00@007ooOol000Aoo`04001oogoo0004Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo
00@007ooOol0009oo`04001oogoo0004Ool01000Oomoo`0017oo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00]oo`@000=oo`04001o
ogoo0005Ool00`00Ool00004Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003
Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00H0
07ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool2
000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0004
Ool20003Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002
Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000ROol2000;Ool6
0003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`00
17oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`0:Ool00`00Oomoo`0@
Ool00`00Oomoo`02Ool30017Ool0029oo`8000Yoo`8001=oo`06001oogooOol007oo0P00AWoo000R
OomS000<Ool0029oo`/00003Ool007oo009oo`05001oogooOol00003Ool01000Oomoo`000goo00<0
07ooOol00`000Woo00<007oo00000P000Woo0P0000Aoo`000000009oo`800004Ool000000002Ool3
000017oo000007oo0`0000=oo`0000001P0000=oo`00Ool02`0000Aoo`00Ool000aoo`008Woo0P00
87oo0`002Woo00@007oo001oo`<0009oo`800003Ool0000000800005Ool00000001oo`02000017oo
000007oo0P0000Aoo`00001oo`800005Ool00000001oo`0400000goo00000005000<Ool0029oo`03
001oogoo021oo`03001oogoo00Uoo`8000=oo`03001oogoo03Qoo`008Woo0P00KGoo000ROol2001]
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2
000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80
009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06ao
o`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo
00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`80
00=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=o
o`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<0
07ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00
Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007oo
Oomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool0
0`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P00
17oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qo
o``005eoo`00:7oo00<007ooOol027oo1@00FGoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool2
0003Ool30003Ool00`00Oomoo`0<Ool3001GOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0003Ool01000Oomoo`0047oo0`00EGoo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`004Woo0`00Dgoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool40005Ool30004
Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004
Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03
001oogoo00Uoo`05001oogooOol00002Ool01@00Oomoo`00Ool00P0017oo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001o
ogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00<0009oo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001o
ogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001o
ogoo0002Ool00`00Oomoo`02Ool40004Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03
001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo
00Uoo`@000=oo`04001oogoo0007Ool700001Goo001oogoo00000Woo00D007ooOomoo`0000=oo`@0
00=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@0
07ooOol000Ioo`8000Aoo`03001oo`0003L000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uo
o`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool3
0004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00mo
o`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2
000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=o
o`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007oo
Ool000]oo`03001oogoo008002eoocP000ioo`002Woo00@007ooOol000]oo`04001oogoo000XOol7
000gOol2000<Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0POol6001<Ool000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool2000NOol4001AOol000]oo`8000Qoo`D0009oo`03001oogoo
01]oo`<005Aoo`0077oo00<007ooOol03Goo0`0017oo0P0017oo0P000goo0`0017oo0P0017oo0P00
1Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000L
Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool0
00=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool3
0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`05001oogoo
001oo`020009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001o
ogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=o
o`800003Ool007oo00Qoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Oomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001o
ogoo00=oo`80009oo`03001oogoo00Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P00
0goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1P000Woo
0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`80
00Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol03goo0P00HGoo000LOol00`00
Oomoo`0=Ool3001ROol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol0
0Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04
001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Mo
o`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomo
o`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00
Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1b
Ool000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007oo
Oomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<0
07ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol0
00Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(23046\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31739 m
.008 .31722 L
.012 .31759 L
.016 .31763 L
.02 .31738 L
.024 .31733 L
.028 .31739 L
.032 .31729 L
.036 .31713 L
.04 .31699 L
.044 .31681 L
.048 .31651 L
.052 .31612 L
.056 .31563 L
.06 .31501 L
.064 .31422 L
.068 .31321 L
.072 .31193 L
.076 .31032 L
.08 .30834 L
.084 .30593 L
.088 .30303 L
.092 .29955 L
.096 .29543 L
.1 .29059 L
.104 .28499 L
.108 .27858 L
.112 .27136 L
.116 .26335 L
.12 .25459 L
.124 .24515 L
.128 .23516 L
.132 .22479 L
.136 .2143 L
.14 .20396 L
.144 .19411 L
.148 .18507 L
.152 .17717 L
.156 .17075 L
.16 .1661 L
.164 .16346 L
.168 .16299 L
.172 .16471 L
.176 .1685 L
.18 .17405 L
.184 .18096 L
.188 .18869 L
.192 .19666 L
.196 .20422 L
.2 .21072 L
Mistroke
.204 .21556 L
.208 .21829 L
.212 .2187 L
.216 .2168 L
.22 .21292 L
.224 .2076 L
.228 .20158 L
.232 .19568 L
.236 .19076 L
.24 .18764 L
.244 .18695 L
.248 .18903 L
.252 .19391 L
.256 .20123 L
.26 .21033 L
.264 .22034 L
.268 .23035 L
.272 .23955 L
.276 .24738 L
.28 .25357 L
.284 .25826 L
.288 .26192 L
.292 .26528 L
.296 .26917 L
.3 .27433 L
.304 .28122 L
.308 .28989 L
.312 .29984 L
.316 .31013 L
.32 .31947 L
.324 .32654 L
.328 .3302 L
.332 .32981 L
.336 .32534 L
.34 .31748 L
.344 .30749 L
.348 .29698 L
.352 .2876 L
.356 .28076 L
.36 .27736 L
.364 .27763 L
.368 .28114 L
.372 .28687 L
.376 .29355 L
.38 .29995 L
.384 .30513 L
.388 .30866 L
.392 .31062 L
.396 .31146 L
.4 .31176 L
Mistroke
.404 .31192 L
.408 .31198 L
.412 .31171 L
.416 .31074 L
.42 .30884 L
.424 .30611 L
.428 .3031 L
.432 .30076 L
.436 .30017 L
.44 .30215 L
.444 .30695 L
.448 .31406 L
.452 .32227 L
.456 .3299 L
.46 .33519 L
.464 .33679 L
.468 .33428 L
.472 .32836 L
.476 .32076 L
.48 .31371 L
.484 .3093 L
.488 .30878 L
.492 .31217 L
.496 .3182 L
.5 .32467 L
.504 .32929 L
.508 .3305 L
.512 .32802 L
.516 .32287 L
.52 .31686 L
.524 .31194 L
.528 .30948 L
.532 .30989 L
.536 .31256 L
.54 .31623 L
.544 .31951 L
.548 .32148 L
.552 .32192 L
.556 .32117 L
.56 .31984 L
.564 .3185 L
.568 .31755 L
.572 .31722 L
.576 .31751 L
.58 .31834 L
.584 .31951 L
.588 .32081 L
.592 .32196 L
.596 .32261 L
.6 .32233 L
Mistroke
.604 .32089 L
.608 .31846 L
.612 .31575 L
.616 .31375 L
.62 .31331 L
.624 .31472 L
.628 .31753 L
.632 .3207 L
.636 .32301 L
.64 .32353 L
.644 .32206 L
.648 .3193 L
.652 .3166 L
.656 .31533 L
.66 .31616 L
.664 .31863 L
.668 .32137 L
.672 .32282 L
.676 .32215 L
.68 .31964 L
.684 .31658 L
.688 .31452 L
.692 .31453 L
.696 .31663 L
.7 .31981 L
.704 .32249 L
.708 .32329 L
.712 .3218 L
.716 .31889 L
.72 .31622 L
.724 .31535 L
.728 .31671 L
.732 .31934 L
.736 .32156 L
.74 .32205 L
.744 .32061 L
.748 .31825 L
.752 .31639 L
.756 .31601 L
.76 .31722 L
.764 .31927 L
.768 .3211 L
.772 .32179 L
.776 .32096 L
.78 .31909 L
.784 .31721 L
.788 .31646 L
.792 .31731 L
.796 .31917 L
.8 .32075 L
Mistroke
.804 .32102 L
.808 .3199 L
.812 .31835 L
.816 .31753 L
.82 .31785 L
.824 .31883 L
.828 .31961 L
.832 .31974 L
.836 .31946 L
.84 .3192 L
.844 .31913 L
.848 .31902 L
.852 .3187 L
.856 .31841 L
.86 .31857 L
.864 .31927 L
.868 .32 L
.872 .31999 L
.876 .31908 L
.88 .31797 L
.884 .31769 L
.888 .31867 L
.892 .32012 L
.896 .32079 L
.9 .32008 L
.904 .3185 L
.908 .31747 L
.912 .31786 L
.916 .31921 L
.92 .32037 L
.924 .3203 L
.928 .3191 L
.932 .31812 L
.936 .31819 L
.94 .31917 L
.944 .32028 L
.948 .32017 L
.952 .31895 L
.956 .31798 L
.96 .3178 L
.964 .31886 L
.968 .32041 L
.972 .32065 L
.976 .3198 L
.98 .31865 L
.984 .31771 L
.988 .31829 L
.992 .31964 L
.996 .32 L
1 .31977 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15656 m
.008 .1593 L
.012 .16019 L
.016 .15932 L
.02 .15899 L
.024 .1593 L
.028 .1594 L
.032 .15932 L
.036 .15927 L
.04 .15933 L
.044 .15935 L
.048 .15936 L
.052 .15937 L
.056 .15941 L
.06 .15944 L
.064 .1595 L
.068 .15956 L
.072 .15965 L
.076 .15975 L
.08 .15989 L
.084 .16005 L
.088 .16028 L
.092 .16054 L
.096 .16087 L
.1 .16126 L
.104 .16174 L
.108 .16231 L
.112 .163 L
.116 .1638 L
.12 .16473 L
.124 .1658 L
.128 .16703 L
.132 .16841 L
.136 .16996 L
.14 .17166 L
.144 .17353 L
.148 .17554 L
.152 .17768 L
.156 .17993 L
.16 .18227 L
.164 .18467 L
.168 .1871 L
.172 .18952 L
.176 .19191 L
.18 .19423 L
.184 .19647 L
.188 .1986 L
.192 .20063 L
.196 .20255 L
.2 .20438 L
Mistroke
.204 .20613 L
.208 .20783 L
.212 .20951 L
.216 .21121 L
.22 .21296 L
.224 .21478 L
.228 .21669 L
.232 .21869 L
.236 .22078 L
.24 .22294 L
.244 .22513 L
.248 .22732 L
.252 .22948 L
.256 .23156 L
.26 .23355 L
.264 .23541 L
.268 .23714 L
.272 .23875 L
.276 .24025 L
.28 .24166 L
.284 .243 L
.288 .24427 L
.292 .24549 L
.296 .24666 L
.3 .24776 L
.304 .24877 L
.308 .24966 L
.312 .25043 L
.316 .25105 L
.32 .25154 L
.324 .25191 L
.328 .2522 L
.332 .25247 L
.336 .25277 L
.34 .25315 L
.344 .25364 L
.348 .25427 L
.352 .25502 L
.356 .25587 L
.36 .25679 L
.364 .25773 L
.368 .25863 L
.372 .25947 L
.376 .26021 L
.38 .26085 L
.384 .26141 L
.388 .26188 L
.392 .2623 L
.396 .2627 L
.4 .26308 L
Mistroke
.404 .26345 L
.408 .26383 L
.412 .26421 L
.416 .26461 L
.42 .26502 L
.424 .26546 L
.428 .26591 L
.432 .26636 L
.436 .26679 L
.44 .26715 L
.444 .2674 L
.448 .26752 L
.452 .26748 L
.456 .2673 L
.46 .26701 L
.464 .26665 L
.468 .26628 L
.472 .26597 L
.476 .26574 L
.48 .26561 L
.484 .26557 L
.488 .26558 L
.492 .26559 L
.496 .26556 L
.5 .26547 L
.504 .26532 L
.508 .26514 L
.512 .26497 L
.516 .26486 L
.52 .26481 L
.524 .26485 L
.528 .26496 L
.532 .26509 L
.536 .26523 L
.54 .26534 L
.544 .26541 L
.548 .26543 L
.552 .26544 L
.556 .26542 L
.56 .2654 L
.564 .26539 L
.568 .26537 L
.572 .26534 L
.576 .26528 L
.58 .26521 L
.584 .2651 L
.588 .26497 L
.592 .26483 L
.596 .2647 L
.6 .2646 L
Mistroke
.604 .26455 L
.608 .26455 L
.612 .26461 L
.616 .26472 L
.62 .26484 L
.624 .26496 L
.628 .26503 L
.632 .26504 L
.636 .26499 L
.64 .26489 L
.644 .26477 L
.648 .26466 L
.652 .26457 L
.656 .26452 L
.66 .26448 L
.664 .26445 L
.668 .26442 L
.672 .26439 L
.676 .26437 L
.68 .26437 L
.684 .26439 L
.688 .26444 L
.692 .2645 L
.696 .26452 L
.7 .26451 L
.704 .26445 L
.708 .26436 L
.712 .26426 L
.716 .26418 L
.72 .26414 L
.724 .26413 L
.728 .26414 L
.732 .26414 L
.736 .26413 L
.74 .2641 L
.744 .26407 L
.748 .26405 L
.752 .26404 L
.756 .26404 L
.76 .26405 L
.764 .26404 L
.768 .26402 L
.772 .26397 L
.776 .26391 L
.78 .26386 L
.784 .26381 L
.788 .26378 L
.792 .26377 L
.796 .26375 L
.8 .26374 L
Mistroke
.804 .26373 L
.808 .26373 L
.812 .26373 L
.816 .26373 L
.82 .26371 L
.824 .26368 L
.828 .26363 L
.832 .26357 L
.836 .26352 L
.84 .26347 L
.844 .26344 L
.848 .26344 L
.852 .26345 L
.856 .26346 L
.86 .26347 L
.864 .26345 L
.868 .26342 L
.872 .26337 L
.876 .26333 L
.88 .26329 L
.884 .26325 L
.888 .26323 L
.892 .2632 L
.896 .26318 L
.9 .26317 L
.904 .26317 L
.908 .26317 L
.912 .26315 L
.916 .26313 L
.92 .26309 L
.924 .26304 L
.928 .26301 L
.932 .26298 L
.936 .26297 L
.94 .26296 L
.944 .26293 L
.948 .26291 L
.952 .26288 L
.956 .26286 L
.96 .26284 L
.964 .26282 L
.968 .2628 L
.972 .26278 L
.976 .26276 L
.98 .26274 L
.984 .26271 L
.988 .26269 L
.992 .26263 L
.996 .2626 L
1 .26256 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .1611 L
.012 .16131 L
.016 .16125 L
.02 .16115 L
.024 .16115 L
.028 .16123 L
.032 .16119 L
.036 .16117 L
.04 .16115 L
.044 .16116 L
.048 .16112 L
.052 .1611 L
.056 .16105 L
.06 .16101 L
.064 .16094 L
.068 .16086 L
.072 .16075 L
.076 .16062 L
.08 .16044 L
.084 .16024 L
.088 .15996 L
.092 .15964 L
.096 .15923 L
.1 .15873 L
.104 .15813 L
.108 .15742 L
.112 .15656 L
.116 .15557 L
.12 .1544 L
.124 .15307 L
.128 .15153 L
.132 .14981 L
.136 .14788 L
.14 .14575 L
.144 .14343 L
.148 .14092 L
.152 .13825 L
.156 .13544 L
.16 .13251 L
.164 .12952 L
.168 .12649 L
.172 .12347 L
.176 .12048 L
.18 .11758 L
.184 .11478 L
.188 .11211 L
.192 .10957 L
.196 .10717 L
.2 .10489 L
Mistroke
.204 .1027 L
.208 .10056 L
.212 .09845 L
.216 .09632 L
.22 .09413 L
.224 .09185 L
.228 .08946 L
.232 .08695 L
.236 .08434 L
.24 .08164 L
.244 .07889 L
.248 .07615 L
.252 .07344 L
.256 .07083 L
.26 .06834 L
.264 .066 L
.268 .06382 L
.272 .0618 L
.276 .05991 L
.28 .05814 L
.284 .05646 L
.288 .05485 L
.292 .05331 L
.296 .05183 L
.3 .05045 L
.304 .04917 L
.308 .04803 L
.312 .04706 L
.316 .04627 L
.32 .04564 L
.324 .04516 L
.328 .04476 L
.332 .04441 L
.336 .04401 L
.34 .04353 L
.344 .04289 L
.348 .0421 L
.352 .04114 L
.356 .04005 L
.36 .03888 L
.364 .0377 L
.368 .03655 L
.372 .03549 L
.376 .03454 L
.38 .03372 L
.384 .03301 L
.388 .03239 L
.392 .03184 L
.396 .03133 L
.4 .03084 L
Mistroke
.404 .03035 L
.408 .02986 L
.412 .02936 L
.416 .02884 L
.42 .02829 L
.424 .02772 L
.428 .02714 L
.432 .02656 L
.436 .02601 L
.44 .02554 L
.444 .0252 L
.448 .02502 L
.452 .02504 L
.456 .02524 L
.46 .02559 L
.464 .02602 L
.468 .02646 L
.472 .02683 L
.476 .02708 L
.48 .02721 L
.484 .02724 L
.488 .02721 L
.492 .02718 L
.496 .0272 L
.5 .02729 L
.504 .02745 L
.508 .02764 L
.512 .02783 L
.516 .02795 L
.52 .02798 L
.524 .02791 L
.528 .02777 L
.532 .02757 L
.536 .02738 L
.54 .02722 L
.544 .0271 L
.548 .02704 L
.552 .02702 L
.556 .02702 L
.56 .02703 L
.564 .02703 L
.568 .02703 L
.572 .02704 L
.576 .02708 L
.58 .02715 L
.584 .02726 L
.588 .0274 L
.592 .02755 L
.596 .02769 L
.6 .0278 L
Mistroke
.604 .02784 L
.608 .02781 L
.612 .02771 L
.616 .02756 L
.62 .02738 L
.624 .02722 L
.628 .02711 L
.632 .02707 L
.636 .02711 L
.64 .02721 L
.644 .02733 L
.648 .02744 L
.652 .02753 L
.656 .02758 L
.66 .0276 L
.664 .02762 L
.668 .02764 L
.672 .02766 L
.676 .02766 L
.68 .02764 L
.684 .02757 L
.688 .02748 L
.692 .0274 L
.696 .02734 L
.7 .02735 L
.704 .02741 L
.708 .0275 L
.712 .02759 L
.716 .02766 L
.72 .02768 L
.724 .02767 L
.728 .02764 L
.732 .02762 L
.736 .02763 L
.74 .02764 L
.744 .02766 L
.748 .02766 L
.752 .02763 L
.756 .02759 L
.76 .02756 L
.764 .02755 L
.768 .02758 L
.772 .02763 L
.776 .02769 L
.78 .02773 L
.784 .02775 L
.788 .02775 L
.792 .02774 L
.796 .02773 L
.8 .02772 L
Mistroke
.804 .02772 L
.808 .02772 L
.812 .02772 L
.816 .0277 L
.82 .02769 L
.824 .02768 L
.828 .0277 L
.832 .02774 L
.836 .0278 L
.84 .02785 L
.844 .02787 L
.848 .02787 L
.852 .02784 L
.856 .02781 L
.86 .02778 L
.864 .02775 L
.868 .02775 L
.872 .02776 L
.876 .02779 L
.88 .02783 L
.884 .02788 L
.888 .02792 L
.892 .02795 L
.896 .02794 L
.9 .02792 L
.904 .02788 L
.908 .02785 L
.912 .02782 L
.916 .02781 L
.92 .02784 L
.924 .02789 L
.928 .02795 L
.932 .02801 L
.936 .02804 L
.94 .02803 L
.944 .02798 L
.948 .02794 L
.952 .0279 L
.956 .02789 L
.96 .0279 L
.964 .02794 L
.968 .02799 L
.972 .02804 L
.976 .02808 L
.98 .02812 L
.984 .0281 L
.988 .02807 L
.992 .02799 L
.996 .02794 L
1 .02792 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo00003goo0P00GGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`02000=Ool4001LOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0
00=oo`03001oogoo008000eoo`04001oogoo001LOol000]oo`8000Yoo`8000=oo`<000=oo`03001o
ogoo00]oo`05001oogooOol00004Ool3001EOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`8000aoo`03001oogoo009oo`04001oogoo0002Ool00`00Oomoo`1COol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P002goo00<007oo00000P000Woo00H007oo0000
07oo0005Ool30004Ool20004Ool20005Ool30003Ool30004Ool20003Ool50003Ool20004Ool20004
Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol02Woo0P000goo00@007oo0000009oo`03001oo`0000Eoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P002goo00<007ooOol00Woo00@007ooOol0009oo`03001oo`0000Eo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2000:Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol000Aoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo00<007oo
Ool017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool00`00Oomoo`09Ool00`00Ool000030003Ool01000Oomoo`000Woo00<007ooOol00Woo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007oo
Ool0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogooOol0
07oo10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo0P002Goo00@0
07ooOol000Ioo`04001oogoo0003Ool200000goo00000004Ool01000Oomoo`000Woo00@007ooOol0
00Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0029oo`8000Uo
o`03001oogoo00D000=oo`8000Eoo`04001oogoo0002Ool200000goo00000004Ool20006Ool01000
Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol0
0`00Oomoo`07Ool2000BOol01000Oomoogoo0`00BWoo000ROol20008Ool00`00Oomoo`0AOol01@00
Oomoogoo00000Woo00<007ooOol0Agoo000ROomS000<Ool0029oo`T000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000Woo00T007ooOomoo`00Ool007oo00000Woo100000=oo`0000000Woo0P00
0Woo0`0000Eoo`00000007oo00X00004Ool00000Ool800000goo0000000;000017oo001oo`0037oo
000ROol2000MOol3000:Ool01@00Ool00000Ool00P000Woo0`0000Aoo`000000009oo`800004Ool0
0000Ool6000017oo000007oo0P0000=oo`0000000Woo00T007oo000007oo001oo`00Ool00P0000=o
o`00000037oo000ROol00`00Oomoo`0MOol00`00Oomoo`0:Ool20003Ool00`00Oomoo`0jOol0029o
o`8006eoo`008Woo0P00KGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomo
o`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004
Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`80
06eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool3
0003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<0
07ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo
000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000R
Ool2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000
Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009
Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo
00<007ooOol0IWoo000XOol9001POol002Qoo`03001oogoo00Eoo`H005]oo`002goo0P0017oo00<0
07ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol02Woo0`00FGoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol000ioo`8005Qoo`000goo1@00
0Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0011oo`8005Io
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo
0`000Woo10001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo
0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001o
ogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007oo000000Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<0
07oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool30005Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00
Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000
Oomoo`000Woo00<007ooOol0100000=oo`00Ool00goo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo
0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol0
0`00Oomoo`09Ool40003Ool01000Oomoo`001Goo20000Woo00@007ooOol0009oo`05001oogooOol0
0003Ool40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo
00Aoo`04001oogoo0006Ool20003Oolk0003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool5
0003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`00
17oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool0
0`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo06Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo0P00
2Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool2
0004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo
00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool0
0`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo
000;Ool00`00Oomoo`02000ZOol:00000goo0000000T000017oo000000000Woo00<007ooOol03goo
000:Ool01000Oomoo`002goo00@007ooOol002Eoo`L000Uoo`03001oogoo02=oo`80009oo`<00003
Ool0000000<000aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo01eoo`L004ioo`002Woo
00@007ooOol000Moo`03001oogoo00Aoo`8001aoo`<005Aoo`002goo0P0027oo1@000Woo00<007oo
Ool06Goo0P00Egoo000LOol00`00Oomoo`0=Ool30004Ool200000goo00000006Ool30004Ool20004
Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006
Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=o
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@0
07ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00<007ooOol010002Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool00`00Ool0000200000goo001o
o`08Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eo
o`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`H00005Ool007oo
Ool00009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003
Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H0
07ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`020002
Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomo
o`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00
Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo
0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`0<Ool2001TOol001aoo`03001oogoo00Yoo`<0
06Eoo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo
00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:
Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Ao
o`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol0
0Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo009oo`03001o
ogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03
001oogoo009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`00
17oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool0
0`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo
00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(23213\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31608 m
.008 .31666 L
.012 .31717 L
.016 .31708 L
.02 .31634 L
.024 .31584 L
.028 .31563 L
.032 .31512 L
.036 .31426 L
.04 .31326 L
.044 .31208 L
.048 .31056 L
.052 .30863 L
.056 .3063 L
.06 .30352 L
.064 .30018 L
.068 .29619 L
.072 .2915 L
.076 .28604 L
.08 .2798 L
.084 .27276 L
.088 .26492 L
.092 .25629 L
.096 .24695 L
.1 .23701 L
.104 .22664 L
.108 .21608 L
.112 .20559 L
.116 .19548 L
.12 .18606 L
.124 .17767 L
.128 .17065 L
.132 .16533 L
.136 .16198 L
.14 .16078 L
.144 .16176 L
.148 .16485 L
.152 .16982 L
.156 .17632 L
.16 .18388 L
.164 .19193 L
.168 .19981 L
.172 .20684 L
.176 .21239 L
.18 .21598 L
.184 .21731 L
.188 .21633 L
.192 .21322 L
.196 .20841 L
.2 .20255 L
Mistroke
.204 .19644 L
.208 .19097 L
.212 .18699 L
.216 .18523 L
.22 .18618 L
.224 .18999 L
.228 .19643 L
.232 .20496 L
.236 .21481 L
.24 .22511 L
.244 .23499 L
.248 .24375 L
.252 .25095 L
.256 .25649 L
.26 .26068 L
.264 .26413 L
.268 .26767 L
.272 .27213 L
.276 .27815 L
.28 .28593 L
.284 .29523 L
.288 .3053 L
.292 .31504 L
.296 .32316 L
.3 .32843 L
.304 .32996 L
.308 .32739 L
.312 .32101 L
.316 .31177 L
.32 .30111 L
.324 .29076 L
.328 .28236 L
.332 .27715 L
.336 .27571 L
.34 .27791 L
.344 .28296 L
.348 .28963 L
.352 .2966 L
.356 .30272 L
.36 .30731 L
.364 .31017 L
.368 .31155 L
.372 .31191 L
.376 .31174 L
.38 .31139 L
.384 .31093 L
.388 .3102 L
.392 .30892 L
.396 .30698 L
.4 .30456 L
Mistroke
.404 .30221 L
.408 .3008 L
.412 .30126 L
.416 .30431 L
.42 .31006 L
.424 .31781 L
.428 .32607 L
.432 .33299 L
.436 .33684 L
.44 .33659 L
.444 .33232 L
.448 .32526 L
.452 .3175 L
.456 .31135 L
.46 .30855 L
.464 .30974 L
.468 .31427 L
.472 .32049 L
.476 .32627 L
.48 .32974 L
.484 .3298 L
.488 .32652 L
.492 .32104 L
.496 .31515 L
.5 .31062 L
.504 .30866 L
.508 .30957 L
.512 .31275 L
.516 .31693 L
.52 .32066 L
.524 .32278 L
.528 .32289 L
.532 .32138 L
.536 .31918 L
.54 .31729 L
.544 .3164 L
.548 .31671 L
.552 .31794 L
.556 .31956 L
.56 .32099 L
.564 .32184 L
.568 .32199 L
.572 .32153 L
.576 .32061 L
.58 .31927 L
.584 .31758 L
.588 .31579 L
.592 .31442 L
.596 .31408 L
.6 .31516 L
Mistroke
.604 .31749 L
.608 .32036 L
.612 .3227 L
.616 .32354 L
.62 .32247 L
.624 .3199 L
.628 .317 L
.632 .31521 L
.636 .31547 L
.64 .31767 L
.644 .32061 L
.648 .32264 L
.652 .32256 L
.656 .32031 L
.66 .31703 L
.664 .31444 L
.668 .31393 L
.672 .31583 L
.676 .31923 L
.68 .32244 L
.684 .32383 L
.688 .32269 L
.692 .31968 L
.696 .31647 L
.7 .31482 L
.704 .31558 L
.708 .31813 L
.712 .32088 L
.716 .3222 L
.72 .32146 L
.724 .31926 L
.728 .31699 L
.732 .31591 L
.736 .31651 L
.74 .31834 L
.744 .32037 L
.748 .32152 L
.752 .32123 L
.756 .31975 L
.76 .31795 L
.764 .31689 L
.768 .31715 L
.772 .31843 L
.776 .31977 L
.78 .32029 L
.784 .31977 L
.788 .31879 L
.792 .31819 L
.796 .31833 L
.8 .31892 L
Mistroke
.804 .31937 L
.808 .31936 L
.812 .31907 L
.816 .31885 L
.82 .31883 L
.824 .31888 L
.828 .31882 L
.832 .31879 L
.836 .31898 L
.84 .3194 L
.844 .31968 L
.848 .31937 L
.852 .31858 L
.856 .31791 L
.86 .31802 L
.864 .31899 L
.868 .32006 L
.872 .32035 L
.876 .31963 L
.88 .3185 L
.884 .31796 L
.888 .31839 L
.892 .31922 L
.896 .3197 L
.9 .31938 L
.904 .31866 L
.908 .31842 L
.912 .31887 L
.916 .31957 L
.92 .31994 L
.924 .31951 L
.928 .31876 L
.932 .31849 L
.936 .31863 L
.94 .31905 L
.944 .31928 L
.948 .31889 L
.952 .31872 L
.956 .31913 L
.96 .31969 L
.964 .32026 L
.968 .31995 L
.972 .31859 L
.976 .31767 L
.98 .31769 L
.984 .31851 L
.988 .32011 L
.992 .32078 L
.996 .3199 L
1 .31907 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15947 m
.008 .15962 L
.012 .15968 L
.016 .15976 L
.02 .1597 L
.024 .15969 L
.028 .15973 L
.032 .1598 L
.036 .15982 L
.04 .15989 L
.044 .15996 L
.048 .16008 L
.052 .16019 L
.056 .16036 L
.06 .16056 L
.064 .16082 L
.068 .16112 L
.072 .1615 L
.076 .16195 L
.08 .1625 L
.084 .16315 L
.088 .16392 L
.092 .16481 L
.096 .16585 L
.1 .16702 L
.104 .16836 L
.108 .16985 L
.112 .17151 L
.116 .17332 L
.12 .17528 L
.124 .17738 L
.128 .17959 L
.132 .1819 L
.136 .18428 L
.14 .1867 L
.144 .18913 L
.148 .19152 L
.152 .19387 L
.156 .19614 L
.16 .19831 L
.164 .20038 L
.168 .20234 L
.172 .20419 L
.176 .20597 L
.18 .20768 L
.184 .20937 L
.188 .21106 L
.192 .21278 L
.196 .21457 L
.2 .21644 L
Mistroke
.204 .2184 L
.208 .22045 L
.212 .22257 L
.216 .22475 L
.22 .22694 L
.224 .22911 L
.228 .23122 L
.232 .23324 L
.236 .23515 L
.24 .23693 L
.244 .23858 L
.248 .24012 L
.252 .24155 L
.256 .24289 L
.26 .24417 L
.264 .2454 L
.268 .24657 L
.272 .24768 L
.276 .24871 L
.28 .24964 L
.284 .25045 L
.288 .25113 L
.292 .25167 L
.296 .25209 L
.3 .25242 L
.304 .2527 L
.308 .25298 L
.312 .25332 L
.316 .25375 L
.32 .25431 L
.324 .25501 L
.328 .25582 L
.332 .25672 L
.336 .25765 L
.34 .25857 L
.344 .25945 L
.348 .26023 L
.352 .26092 L
.356 .2615 L
.36 .262 L
.364 .26244 L
.368 .26284 L
.372 .26321 L
.376 .26358 L
.38 .26395 L
.384 .26433 L
.388 .26472 L
.392 .26513 L
.396 .26556 L
.4 .26599 L
Mistroke
.404 .26643 L
.408 .26685 L
.412 .26723 L
.416 .26752 L
.42 .2677 L
.424 .26773 L
.428 .26762 L
.432 .26738 L
.436 .26704 L
.44 .26666 L
.444 .26631 L
.448 .26603 L
.452 .26584 L
.456 .26576 L
.46 .26575 L
.464 .26576 L
.468 .26576 L
.472 .26571 L
.476 .26561 L
.48 .26545 L
.484 .26528 L
.488 .26514 L
.492 .26505 L
.496 .26505 L
.5 .26511 L
.504 .26523 L
.508 .26538 L
.512 .26551 L
.516 .26561 L
.52 .26567 L
.524 .26568 L
.528 .26566 L
.532 .26563 L
.536 .26561 L
.54 .26558 L
.544 .26555 L
.548 .26551 L
.552 .26545 L
.556 .26536 L
.56 .26525 L
.564 .26511 L
.568 .26498 L
.572 .26486 L
.576 .26479 L
.58 .26476 L
.584 .2648 L
.588 .26488 L
.592 .265 L
.596 .26512 L
.6 .26521 L
Mistroke
.604 .26526 L
.608 .26524 L
.612 .26517 L
.616 .26506 L
.62 .26494 L
.624 .26483 L
.628 .26475 L
.632 .2647 L
.636 .26467 L
.64 .26464 L
.644 .26462 L
.648 .2646 L
.652 .26459 L
.656 .2646 L
.66 .26464 L
.664 .26468 L
.668 .26472 L
.672 .26473 L
.676 .2647 L
.68 .26463 L
.684 .26454 L
.688 .26444 L
.692 .26438 L
.696 .26435 L
.7 .26434 L
.704 .26435 L
.708 .26435 L
.712 .26433 L
.716 .26431 L
.72 .26428 L
.724 .26426 L
.728 .26426 L
.732 .26427 L
.736 .26427 L
.74 .26425 L
.744 .26421 L
.748 .26415 L
.752 .26409 L
.756 .26404 L
.76 .26401 L
.764 .264 L
.768 .26399 L
.772 .26398 L
.776 .26396 L
.78 .26394 L
.784 .26393 L
.788 .26392 L
.792 .26392 L
.796 .26391 L
.8 .26389 L
Mistroke
.804 .26384 L
.808 .26379 L
.812 .26372 L
.816 .26367 L
.82 .26364 L
.824 .26363 L
.828 .26365 L
.832 .26367 L
.836 .26368 L
.84 .26367 L
.844 .26364 L
.848 .26359 L
.852 .26353 L
.856 .26348 L
.86 .26344 L
.864 .26341 L
.868 .26339 L
.872 .26338 L
.876 .26339 L
.88 .2634 L
.884 .2634 L
.888 .26338 L
.892 .26334 L
.896 .26329 L
.9 .26324 L
.904 .26319 L
.908 .26316 L
.912 .26315 L
.916 .26315 L
.92 .26315 L
.924 .26315 L
.928 .26313 L
.932 .2631 L
.936 .26306 L
.94 .26302 L
.944 .26297 L
.948 .26294 L
.952 .26292 L
.956 .26292 L
.96 .26292 L
.964 .26291 L
.968 .26289 L
.972 .26286 L
.976 .26282 L
.98 .26278 L
.984 .26274 L
.988 .26271 L
.992 .26269 L
.996 .2627 L
1 .26269 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15923 L
.012 .1612 L
.016 .1618 L
.02 .16115 L
.024 .16087 L
.028 .16108 L
.032 .16109 L
.036 .16098 L
.04 .16085 L
.044 .16079 L
.048 .16066 L
.052 .1605 L
.056 .16028 L
.06 .16005 L
.064 .15972 L
.068 .15934 L
.072 .15886 L
.076 .1583 L
.08 .15761 L
.084 .15681 L
.088 .15585 L
.092 .15474 L
.096 .15345 L
.1 .15198 L
.104 .15031 L
.108 .14845 L
.112 .14638 L
.116 .14413 L
.12 .14167 L
.124 .13906 L
.128 .13629 L
.132 .13341 L
.136 .13044 L
.14 .12742 L
.144 .12439 L
.148 .12139 L
.152 .11846 L
.156 .11563 L
.16 .11291 L
.164 .11033 L
.168 .10787 L
.172 .10555 L
.176 .10333 L
.18 .10118 L
.184 .09906 L
.188 .09695 L
.192 .09479 L
.196 .09255 L
.2 .09021 L
Mistroke
.204 .08775 L
.208 .08518 L
.212 .08252 L
.216 .0798 L
.22 .07706 L
.224 .07434 L
.228 .0717 L
.232 .06916 L
.236 .06676 L
.24 .06453 L
.244 .06245 L
.248 .06052 L
.252 .05872 L
.256 .05702 L
.26 .05541 L
.264 .05386 L
.268 .05238 L
.272 .05098 L
.276 .04968 L
.28 .0485 L
.284 .04747 L
.288 .0466 L
.292 .0459 L
.296 .04536 L
.3 .04494 L
.304 .04457 L
.308 .0442 L
.312 .04376 L
.316 .04319 L
.32 .04247 L
.324 .04159 L
.328 .04055 L
.332 .03942 L
.336 .03823 L
.34 .03706 L
.344 .03595 L
.348 .03495 L
.352 .03407 L
.356 .03332 L
.36 .03267 L
.364 .03211 L
.368 .0316 L
.372 .03111 L
.376 .03063 L
.38 .03014 L
.384 .02964 L
.388 .02913 L
.392 .0286 L
.396 .02805 L
.4 .02748 L
Mistroke
.404 .02691 L
.408 .02636 L
.412 .02587 L
.416 .02548 L
.42 .02524 L
.424 .02517 L
.428 .02529 L
.432 .02557 L
.436 .02597 L
.44 .02641 L
.444 .02682 L
.448 .02715 L
.452 .02736 L
.456 .02745 L
.46 .02745 L
.464 .0274 L
.468 .02738 L
.472 .02741 L
.476 .02752 L
.48 .02769 L
.484 .02788 L
.488 .02804 L
.492 .02813 L
.496 .02811 L
.5 .028 L
.504 .02782 L
.508 .02762 L
.512 .02743 L
.516 .02729 L
.52 .0272 L
.524 .02716 L
.528 .02716 L
.532 .02717 L
.536 .02718 L
.54 .02718 L
.544 .0272 L
.548 .02723 L
.552 .02729 L
.556 .02738 L
.56 .0275 L
.564 .02764 L
.568 .02778 L
.572 .0279 L
.576 .02797 L
.58 .02798 L
.584 .02792 L
.588 .02779 L
.592 .02763 L
.596 .02745 L
.6 .02731 L
Mistroke
.604 .02723 L
.608 .02722 L
.612 .02729 L
.616 .02741 L
.62 .02754 L
.624 .02766 L
.628 .02773 L
.632 .02777 L
.636 .02778 L
.64 .02779 L
.644 .02779 L
.648 .0278 L
.652 .02779 L
.656 .02776 L
.66 .02769 L
.664 .02761 L
.668 .02754 L
.672 .0275 L
.676 .02751 L
.68 .02758 L
.684 .02767 L
.688 .02777 L
.692 .02784 L
.696 .02786 L
.7 .02784 L
.704 .0278 L
.708 .02777 L
.712 .02776 L
.716 .02777 L
.72 .02779 L
.724 .0278 L
.728 .02779 L
.732 .02776 L
.736 .02773 L
.74 .02772 L
.744 .02774 L
.748 .02778 L
.752 .02784 L
.756 .02789 L
.76 .02792 L
.764 .02792 L
.768 .02791 L
.772 .02789 L
.776 .02787 L
.78 .02786 L
.784 .02785 L
.788 .02784 L
.792 .02784 L
.796 .02784 L
.8 .02786 L
Mistroke
.804 .02789 L
.808 .02793 L
.812 .02798 L
.816 .028 L
.82 .02801 L
.824 .02799 L
.828 .02796 L
.832 .02794 L
.836 .02792 L
.84 .02791 L
.844 .02792 L
.848 .02794 L
.852 .02797 L
.856 .028 L
.86 .02804 L
.864 .02806 L
.868 .02807 L
.872 .02807 L
.876 .02806 L
.88 .02804 L
.884 .02801 L
.888 .02799 L
.892 .02799 L
.896 .02801 L
.9 .02805 L
.904 .0281 L
.908 .02814 L
.912 .02816 L
.916 .02815 L
.92 .02813 L
.924 .02811 L
.928 .02809 L
.932 .02808 L
.936 .02808 L
.94 .02809 L
.944 .02811 L
.948 .02815 L
.952 .02819 L
.956 .02823 L
.96 .02824 L
.964 .02823 L
.968 .02819 L
.972 .02816 L
.976 .02813 L
.98 .02814 L
.984 .02816 L
.988 .02821 L
.992 .02824 L
.996 .02828 L
1 .0283 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo000037oo0`00Ggoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`02000;Ool00`00Ool0001OOol000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`03001oogoo008000Yoo`03001oogoo008000Aoo`03001oogoo05Moo`002goo0P00
2Woo0P000goo0`000goo00<007ooOol027oo0P000goo00@007ooOomoo`<005Qoo`002goo0P0017oo
00<007ooOol00goo0P000goo0`000goo0P002Goo00<007ooOol00goo00D007ooOol007oo008005Mo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20009Ool01000Oomoogoo
1@000Woo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo1@000goo0P0017oo
0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo00Moo`05001oogooOol00003Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20008Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`8000Qoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001o
ogoo00Aoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo0P0017oo00<007ooOol01Woo00<007ooOol00Woo10000goo00<007ooOol0
0P001Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`06001o
ogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo0P00
1goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00`0017oo0P0017oo00@007ooOol0009o
o`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo
000ROol20006Ool00`00Oomoo`03Ool50003Ool20003Ool00`00Oomoo`02Ool20004Ool20004Ool2
0006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P00
1Woo000ROol00`00Oomoo`05Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool00`00Ool0001<Ool0029o
o`8000Eoo`03001oogoo019oo`07001oogooOol007oo0000C7oo000ROomS000<Ool0029oo`H0009o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00P007ooOol007oo001oo`000goo1@0000=o
o`00Ool03@0000Eoo`00000007oo00800005Ool00000001oo`05000017oo000007oo200000=oo`00
00002@0000=oo`00Ool02goo000ROol2000KOol3000:Ool01000Ool007oo0`000Woo0P0000Aoo`00
0000009oo`<00004Ool00000Ool3000017oo001oogoo0P0000=oo`0000000P000Woo0P0000=oo`00
Ool010000goo00@007oo000000eoo`008Woo00<007ooOol06goo00<007ooOol02Goo0P000goo00<0
07ooOol0?Goo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo
06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Ao
o`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo
0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<0
07ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03
001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0
009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P00
2Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2
001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Ao
o`03001oogoo009oo`03001oogoo06Ioo`00:7oo1P00Hgoo000XOol00`00Oomoo`03Ool5001NOol0
00]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo00Moo`<005aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000<Ool2
001JOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001o
ogoo000=Ool2001IOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo008000]oo`H00003Ool0000000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80
009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00H007ooOomoo`00Ool30000
0goo001oo`06Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol0
0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D0
07ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool00`00Oomoo`04
0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001o
ogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00
Oomoo`0=Ool01000Oomoo`000Woo100017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo
000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`000Woo1`000goo00@007ooOol0009oo`04001o
ogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomo
o`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0000=oo`000000>`000goo00@007ooOol000Eo
o`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007oo
Oomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007oo
Ool047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo
00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo
00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool0
0`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool0
0`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Io
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00
Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo
0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00:7oo2@0000=oo`0000001P0000=oo`00
0000400000=oo`0000000P008Goo000:Ool01000Oomoo`002goo00@007ooOol0029oo`L000Uoo`80
00Moo`80015oo`8000=ooaD000aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo01]oo`H0
055oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8001Uoo`@005Ioo`002goo0P0027oo1@00
0Woo00<007ooOol05Woo0`00FGoo000LOol00`00Oomoo`0=Ool30004Ool30008Ool30004Ool20004
Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006
Ool001aoo`8000eoo`05001oogooOol00002Ool200000goo001oo`08Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol0
0goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool40002Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo00moo`<00005Ool007ooOol0
0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eo
o`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001o
ogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003
Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H0
07ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool20005Ool01000Oomo
o`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000
Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomo
o`00Ool00006Ool01000Oomoo`001Goo000LOol2000<Ool60003Ool2000:Ool00`00Oomoo`03Ool2
0004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@00
0goo0P001Woo000LOol00`00Oomoo`0:Ool00`00Oomoo`1UOol001aoo`03001oogoo00Moo`<006Qo
o`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yo
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool0
1000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`00
2Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo
00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo
00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo009oo`03001oogoo
079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001o
ogoo009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo
00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00
Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<0
07ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001o
ogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(23380\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31398 m
.008 .31379 L
.012 .31281 L
.016 .31174 L
.02 .31051 L
.024 .30873 L
.028 .30648 L
.032 .30385 L
.036 .30069 L
.04 .29686 L
.044 .29232 L
.048 .28705 L
.052 .281 L
.056 .27412 L
.06 .26643 L
.064 .25796 L
.068 .24874 L
.072 .23888 L
.076 .22853 L
.08 .21792 L
.084 .2073 L
.088 .19696 L
.092 .1872 L
.096 .17836 L
.1 .17079 L
.104 .16483 L
.108 .16077 L
.112 .15881 L
.116 .15904 L
.12 .16142 L
.124 .16577 L
.128 .17181 L
.132 .17911 L
.136 .18713 L
.14 .19522 L
.144 .2027 L
.148 .20891 L
.152 .21332 L
.156 .21558 L
.16 .21553 L
.164 .21325 L
.168 .20905 L
.172 .20349 L
.176 .19733 L
.18 .19145 L
.184 .18674 L
.188 .18402 L
.192 .18385 L
.196 .1865 L
.2 .19192 L
Mistroke
.204 .19971 L
.208 .20924 L
.212 .21966 L
.216 .23007 L
.22 .23966 L
.224 .24781 L
.228 .25427 L
.232 .25914 L
.236 .26294 L
.24 .26642 L
.244 .27041 L
.248 .27562 L
.252 .28245 L
.256 .29091 L
.26 .30052 L
.264 .31037 L
.268 .31926 L
.272 .32593 L
.276 .32927 L
.28 .3286 L
.284 .32386 L
.288 .3157 L
.292 .30538 L
.296 .29456 L
.3 .28495 L
.304 .27802 L
.308 .27469 L
.312 .2752 L
.316 .27909 L
.32 .28535 L
.324 .29265 L
.328 .29971 L
.332 .30551 L
.336 .30946 L
.34 .31153 L
.344 .3121 L
.348 .31176 L
.352 .31108 L
.356 .31038 L
.36 .30968 L
.364 .30878 L
.368 .30742 L
.372 .3055 L
.376 .30331 L
.38 .30153 L
.384 .3011 L
.388 .30286 L
.392 .30724 L
.396 .31394 L
.4 .32193 L
Mistroke
.404 .3296 L
.408 .33517 L
.412 .33724 L
.416 .33528 L
.42 .32981 L
.424 .32237 L
.428 .31502 L
.432 .30982 L
.436 .30823 L
.44 .31057 L
.444 .31593 L
.448 .32245 L
.452 .32791 L
.456 .33051 L
.46 .32938 L
.464 .32493 L
.468 .31864 L
.472 .31259 L
.476 .30867 L
.48 .30791 L
.484 .31018 L
.488 .31432 L
.492 .31872 L
.496 .32193 L
.5 .32315 L
.504 .32244 L
.508 .32052 L
.512 .31842 L
.516 .31702 L
.52 .31669 L
.524 .31731 L
.528 .31847 L
.532 .31976 L
.536 .32089 L
.54 .32166 L
.544 .32193 L
.548 .32155 L
.552 .32044 L
.556 .31867 L
.56 .31653 L
.564 .31457 L
.568 .31351 L
.572 .31394 L
.576 .31596 L
.58 .31898 L
.584 .32189 L
.588 .32353 L
.592 .32325 L
.596 .32122 L
.6 .31839 L
Mistroke
.604 .31605 L
.608 .31528 L
.612 .31643 L
.616 .31887 L
.62 .3213 L
.624 .32234 L
.628 .32134 L
.632 .31874 L
.636 .3159 L
.64 .31433 L
.644 .3149 L
.648 .31735 L
.652 .32048 L
.656 .32272 L
.66 .32301 L
.664 .32125 L
.668 .31841 L
.672 .31603 L
.676 .31535 L
.68 .31667 L
.684 .31911 L
.688 .32116 L
.692 .32162 L
.696 .32028 L
.7 .31807 L
.704 .31636 L
.708 .31616 L
.712 .31752 L
.716 .31957 L
.72 .32112 L
.724 .32135 L
.728 .3202 L
.732 .3184 L
.736 .31698 L
.74 .31675 L
.744 .31781 L
.748 .31944 L
.752 .32058 L
.756 .32051 L
.76 .3193 L
.764 .31785 L
.768 .31717 L
.772 .31769 L
.776 .31896 L
.78 .32008 L
.784 .32038 L
.788 .31981 L
.792 .31885 L
.796 .31807 L
.8 .31776 L
Mistroke
.804 .31797 L
.808 .31858 L
.812 .31939 L
.816 .32004 L
.82 .32015 L
.824 .3195 L
.828 .31842 L
.832 .31761 L
.836 .31767 L
.84 .3186 L
.844 .31969 L
.848 .32016 L
.852 .31977 L
.856 .31893 L
.86 .31839 L
.864 .31845 L
.868 .31881 L
.872 .31905 L
.876 .31896 L
.88 .31877 L
.884 .31886 L
.888 .31916 L
.892 .31936 L
.896 .3193 L
.9 .31899 L
.904 .31885 L
.908 .31909 L
.912 .31924 L
.916 .31907 L
.92 .31855 L
.924 .31804 L
.928 .31838 L
.932 .31943 L
.936 .32029 L
.94 .3204 L
.944 .31939 L
.948 .31801 L
.952 .31769 L
.956 .31844 L
.96 .31952 L
.964 .32016 L
.968 .31945 L
.972 .31817 L
.976 .31802 L
.98 .31887 L
.984 .32021 L
.988 .32114 L
.992 .31997 L
.996 .3179 L
1 .31695 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16291 m
.008 .16026 L
.012 .15938 L
.016 .16036 L
.02 .16072 L
.024 .16054 L
.028 .16057 L
.032 .16088 L
.036 .16113 L
.04 .1614 L
.044 .16173 L
.048 .16219 L
.052 .1627 L
.056 .16333 L
.06 .16405 L
.064 .16491 L
.068 .16589 L
.072 .16703 L
.076 .16831 L
.08 .16976 L
.084 .17136 L
.088 .17313 L
.092 .17504 L
.096 .17709 L
.1 .17926 L
.104 .18155 L
.108 .1839 L
.112 .18631 L
.116 .18873 L
.12 .19114 L
.124 .1935 L
.128 .1958 L
.132 .198 L
.136 .20011 L
.14 .2021 L
.144 .204 L
.148 .2058 L
.152 .20753 L
.156 .20922 L
.16 .21091 L
.164 .21262 L
.168 .21437 L
.172 .2162 L
.176 .21812 L
.18 .22013 L
.184 .22222 L
.188 .22437 L
.192 .22656 L
.196 .22873 L
.2 .23086 L
Mistroke
.204 .23292 L
.208 .23487 L
.212 .2367 L
.216 .2384 L
.22 .23997 L
.224 .24143 L
.228 .24279 L
.232 .24408 L
.236 .24531 L
.24 .24648 L
.244 .2476 L
.248 .24865 L
.252 .24961 L
.256 .25046 L
.26 .25119 L
.264 .25178 L
.268 .25225 L
.272 .25262 L
.276 .25292 L
.28 .25319 L
.284 .2535 L
.288 .25389 L
.292 .25439 L
.296 .25503 L
.3 .25578 L
.304 .25665 L
.308 .25757 L
.312 .2585 L
.316 .2594 L
.32 .26023 L
.324 .26096 L
.328 .26159 L
.332 .26212 L
.336 .26258 L
.34 .26298 L
.344 .26335 L
.348 .26371 L
.352 .26407 L
.356 .26445 L
.36 .26484 L
.364 .26524 L
.368 .26566 L
.372 .26608 L
.376 .26651 L
.38 .26693 L
.384 .26731 L
.388 .26763 L
.392 .26785 L
.396 .26795 L
.4 .2679 L
Mistroke
.404 .26771 L
.408 .26741 L
.412 .26705 L
.416 .26668 L
.42 .26635 L
.424 .26611 L
.428 .26597 L
.432 .26592 L
.436 .26592 L
.44 .26594 L
.444 .26594 L
.448 .26588 L
.452 .26576 L
.456 .2656 L
.46 .26544 L
.464 .26531 L
.468 .26526 L
.472 .26528 L
.476 .26538 L
.48 .26552 L
.484 .26567 L
.488 .2658 L
.492 .26588 L
.496 .26591 L
.5 .2659 L
.504 .26588 L
.508 .26584 L
.512 .26581 L
.516 .26578 L
.52 .26574 L
.524 .26569 L
.528 .26561 L
.532 .26551 L
.536 .26539 L
.54 .26526 L
.544 .26514 L
.548 .26505 L
.552 .26499 L
.556 .265 L
.56 .26505 L
.564 .26515 L
.568 .26527 L
.572 .26538 L
.576 .26546 L
.58 .26548 L
.584 .26544 L
.588 .26534 L
.592 .26522 L
.596 .26509 L
.6 .26499 L
Mistroke
.604 .26492 L
.608 .26488 L
.612 .26486 L
.616 .26485 L
.62 .26484 L
.624 .26483 L
.628 .26482 L
.632 .26484 L
.636 .26487 L
.64 .26491 L
.644 .26494 L
.648 .26494 L
.652 .2649 L
.656 .26482 L
.66 .26472 L
.664 .26462 L
.668 .26456 L
.672 .26454 L
.676 .26454 L
.68 .26456 L
.684 .26457 L
.688 .26456 L
.692 .26453 L
.696 .2645 L
.7 .26447 L
.704 .26446 L
.708 .26447 L
.712 .26447 L
.716 .26445 L
.72 .26441 L
.724 .26436 L
.728 .26429 L
.732 .26424 L
.736 .2642 L
.74 .26419 L
.744 .26419 L
.748 .26419 L
.752 .26419 L
.756 .26418 L
.76 .26416 L
.764 .26414 L
.768 .26412 L
.772 .2641 L
.776 .26407 L
.78 .26403 L
.784 .26398 L
.788 .26393 L
.792 .26389 L
.796 .26386 L
.8 .26386 L
Mistroke
.804 .26386 L
.808 .26387 L
.812 .26388 L
.816 .26386 L
.82 .26383 L
.824 .26379 L
.828 .26374 L
.832 .26369 L
.836 .26365 L
.84 .26361 L
.844 .26359 L
.848 .26358 L
.852 .26359 L
.856 .2636 L
.86 .2636 L
.864 .26359 L
.868 .26356 L
.872 .2635 L
.876 .26345 L
.88 .26339 L
.884 .26336 L
.888 .26334 L
.892 .26334 L
.896 .26335 L
.9 .26335 L
.904 .26335 L
.908 .26332 L
.912 .26328 L
.916 .26323 L
.92 .26318 L
.924 .26315 L
.928 .26312 L
.932 .2631 L
.936 .2631 L
.94 .2631 L
.944 .2631 L
.948 .26309 L
.952 .26306 L
.956 .26302 L
.96 .26297 L
.964 .26292 L
.968 .26287 L
.972 .26287 L
.976 .26286 L
.98 .26288 L
.984 .26287 L
.988 .26286 L
.992 .26282 L
.996 .26279 L
1 .26273 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16083 L
.012 .16093 L
.016 .16093 L
.02 .16082 L
.024 .16055 L
.028 .16036 L
.032 .16012 L
.036 .15985 L
.04 .15945 L
.044 .159 L
.048 .15845 L
.052 .15782 L
.056 .15703 L
.06 .15613 L
.064 .15505 L
.068 .15382 L
.072 .1524 L
.076 .1508 L
.08 .14899 L
.084 .147 L
.088 .14479 L
.092 .14241 L
.096 .13984 L
.1 .13713 L
.104 .13428 L
.108 .13135 L
.112 .12834 L
.116 .12532 L
.12 .12231 L
.124 .11935 L
.128 .11648 L
.132 .11373 L
.136 .1111 L
.14 .1086 L
.144 .10623 L
.148 .10397 L
.152 .1018 L
.156 .09968 L
.16 .09757 L
.164 .09544 L
.168 .09323 L
.172 .09094 L
.176 .08853 L
.18 .08601 L
.184 .0834 L
.188 .0807 L
.192 .07797 L
.196 .07525 L
.2 .07257 L
Mistroke
.204 .06999 L
.208 .06755 L
.212 .06525 L
.216 .06312 L
.22 .06114 L
.224 .05931 L
.228 .05759 L
.232 .05596 L
.236 .05441 L
.24 .05293 L
.244 .05152 L
.248 .0502 L
.252 .04898 L
.256 .04789 L
.26 .04696 L
.264 .0462 L
.268 .0456 L
.272 .04512 L
.276 .04473 L
.28 .04437 L
.284 .04396 L
.288 .04345 L
.292 .04281 L
.296 .042 L
.3 .04104 L
.304 .03994 L
.308 .03877 L
.312 .03759 L
.316 .03644 L
.32 .03539 L
.324 .03445 L
.328 .03365 L
.332 .03297 L
.336 .03238 L
.34 .03185 L
.344 .03137 L
.348 .0309 L
.352 .03042 L
.356 .02993 L
.36 .02942 L
.364 .0289 L
.368 .02836 L
.372 .02781 L
.376 .02725 L
.38 .0267 L
.384 .0262 L
.388 .02578 L
.392 .02549 L
.396 .02534 L
.4 .02538 L
Mistroke
.404 .02558 L
.408 .02593 L
.412 .02636 L
.416 .0268 L
.42 .02719 L
.424 .02747 L
.428 .02762 L
.432 .02766 L
.436 .02763 L
.44 .02758 L
.444 .02757 L
.448 .02762 L
.452 .02775 L
.456 .02792 L
.46 .0281 L
.464 .02823 L
.468 .02827 L
.472 .02822 L
.476 .02808 L
.48 .02788 L
.484 .02768 L
.488 .0275 L
.492 .02737 L
.496 .0273 L
.5 .02728 L
.504 .0273 L
.508 .02732 L
.512 .02735 L
.516 .02737 L
.52 .02739 L
.524 .02743 L
.528 .02749 L
.532 .02759 L
.536 .02772 L
.54 .02787 L
.544 .028 L
.548 .02809 L
.552 .02813 L
.556 .0281 L
.56 .02801 L
.564 .02786 L
.568 .02769 L
.572 .02753 L
.576 .02742 L
.58 .02737 L
.584 .0274 L
.588 .02749 L
.592 .02762 L
.596 .02775 L
.6 .02786 L
Mistroke
.604 .02793 L
.608 .02795 L
.612 .02796 L
.616 .02795 L
.62 .02794 L
.624 .02793 L
.628 .02791 L
.632 .02787 L
.636 .02781 L
.64 .02774 L
.644 .02768 L
.648 .02766 L
.652 .02769 L
.656 .02776 L
.66 .02786 L
.664 .02795 L
.668 .028 L
.672 .02801 L
.676 .02799 L
.68 .02795 L
.684 .02792 L
.688 .02791 L
.692 .02792 L
.696 .02793 L
.7 .02794 L
.704 .02792 L
.708 .0279 L
.712 .02788 L
.716 .02789 L
.72 .02792 L
.724 .02797 L
.728 .02802 L
.732 .02805 L
.736 .02807 L
.74 .02806 L
.744 .02805 L
.748 .02803 L
.752 .02802 L
.756 .02802 L
.76 .02801 L
.764 .028 L
.768 .02799 L
.772 .02799 L
.776 .02801 L
.78 .02804 L
.784 .0281 L
.788 .02815 L
.792 .02818 L
.796 .02818 L
.8 .02815 L
Mistroke
.804 .0281 L
.808 .02806 L
.812 .02804 L
.816 .02805 L
.82 .02808 L
.824 .02812 L
.828 .02816 L
.832 .0282 L
.836 .02821 L
.84 .02822 L
.844 .02821 L
.848 .02819 L
.852 .02818 L
.856 .02817 L
.86 .02816 L
.864 .02816 L
.868 .02817 L
.872 .0282 L
.876 .02823 L
.88 .02827 L
.884 .02829 L
.888 .02829 L
.892 .02828 L
.896 .02826 L
.9 .02825 L
.904 .02825 L
.908 .02825 L
.912 .02826 L
.916 .02828 L
.92 .02829 L
.924 .02831 L
.928 .02833 L
.932 .02835 L
.936 .02835 L
.94 .02835 L
.944 .02834 L
.948 .02833 L
.952 .02833 L
.956 .02834 L
.96 .02835 L
.964 .02836 L
.968 .02837 L
.972 .02839 L
.976 .0284 L
.98 .02843 L
.984 .02843 L
.988 .02844 L
.992 .02843 L
.996 .02842 L
1 .0284 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo00002Goo0`00HWoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`020008Ool01000Ool00000HGoo000:Ool01000Oomoo`0027oo00H007oo
Ool007oo0003Ool00`00Oomoo`020008Ool01000Oomoo`0017oo0P00Fgoo000;Ool2000:Ool20003
Ool30003Ool00`00Oomoo`06Ool01000Oomoogoo0P000goo0`00FWoo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool20007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007ooOol0F7oo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Ioo`03001oogoo00Ao
o`<0009oo`04001oo`000007Ool30004Ool20004Ool20005Ool30003Ool30004Ool20003Ool50003
Ool20004Ool20004Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00goo00D007ooOomoo`00009o
o`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogoo
Ool00003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
0Woo00<007ooOol00Woo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Ioo`03001oogoo00Moo`04
001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P001Goo00<007ooOol027oo00<007oo
Ool00P0000=oo`00Ool01Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`00009oo`04001oogoo0002
Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00Aoo`03001oogoo00Aoo`@000=oo`80
0003Ool007oo00Ioo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomo
o`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003
Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo
009oo`8000Aoo`03001oogoo00Eoo`03001oogoo00Aoo`04001oo`000006Ool20004Ool01000Oomo
o`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo
0005Ool0029oo`8000Aoo`03001oogoo00Eoo`D000=oo`<000Eoo`<000Eoo`8000Aoo`8000Ioo`04
001oogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029o
o`03001oogoo009oo`03001oogoo015oo`07001oogooOol007oo0000Cgoo000ROol20002Ool00`00
Oomoo`0BOol01@00Oomoogoo00000Woo00<007ooOol0C7oo000ROomS000<Ool0029oo`<00003Ool0
07oo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo00000P000Woo00<007oo
00000P000goo00<007ooOol00P000Woo0`0000Eoo`00000007oo00@00004Ool00000Ool200000goo
0000000=000017oo000007oo3`0037oo000ROol2000IOol2000:Ool00`00Ool00002Ool20002Ool3
000017oo000000000Woo0P000Woo00<007ooOol00P0000Aoo`00001oo`800004Ool00000Ool20000
17oo000007oo0P000goo00@007ooOomoo`800003Ool007oo008000eoo`008Woo00<007ooOol09Goo
0P000goo00<007ooOol0?goo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2
001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009o
o`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@0
07ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=o
o`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol0
06ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001o
o`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo
001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo
001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]
Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00
K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1Y
Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0
JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Mo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Io
o`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo
0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`80
00Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo0`00IWoo000XOol00`00Ool00006
001POol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo00Eoo`<0
05ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo
0009Ool2001MOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eo
o`04001oogoo000:Ool3001KOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Ao
o`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00@007ooOomoo`800005
Ool007ooOol00007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogoo
Ool00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo
00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Ool0
00000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`00
17oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P00
0Woo1@000Woo00<007ooOol03Goo00<007ooOol010001goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000XOol00`00Oomoo`09Ool40003Ool00`00Oomoo`090004Ool01000Oomoo`000Woo
00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03
001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Oom00003Ool01000Oomoo`001Goo000XOol0
0`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@00
0goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool0
0`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomo
o`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomo
o`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00
J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001W
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo
06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo
06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007oo
Ool0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Io
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0
009oo`04001oogoo000;Ool00`00Oomoo`02000UOol90002Ool70002Ool40003Ool30004Ool2000Z
Ool000Yoo`04001oogoo000;Ool01000Oomoo`0087oo1P0027oo0`001Woo0`0017oo0`000goo1@00
00=oo`000000700037oo000:Ool01000Oomoo`001goo10000goo00<007ooOol067oo1P00E7oo000:
Ool01000Oomoo`001goo00<007ooOol017oo0P005Woo1000FGoo000;Ool20008Ool50002Ool00`00
Oomoo`0COol3001LOol001aoo`03001oogoo00eoo`<00003Ool0000000<000Uoo`<000Aoo`8000Ao
o`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Io
o`0077oo0P003Goo00@007ooOomoo`800005Ool007ooOol00009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000
Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0>Ool30002Ool01000Oomoo`002Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0=Ool200001Goo001oogoo0000
0Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000<Ool5
0003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000
Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol02Woo00<0
07oo00001Woo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo
00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P002Goo0P000Woo1@00
0goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Ao
o`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol01goo0P00JGoo000LOol0
0`00Oomoo`05Ool2001[Ool001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomo
o`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007oo
Ool00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]o
o`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol0
01Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00
Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo
0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo
00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1b
Ool000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(23547\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30019 m
.008 .29754 L
.012 .29404 L
.016 .29028 L
.02 .28624 L
.024 .28091 L
.028 .2743 L
.032 .26696 L
.036 .25897 L
.04 .25008 L
.044 .24039 L
.048 .23017 L
.052 .21963 L
.056 .20895 L
.06 .19843 L
.064 .18839 L
.068 .17917 L
.072 .17111 L
.076 .16455 L
.08 .1598 L
.084 .1571 L
.088 .15657 L
.092 .15821 L
.096 .16193 L
.1 .16745 L
.104 .17442 L
.108 .18231 L
.112 .19051 L
.116 .19834 L
.12 .20514 L
.124 .21034 L
.128 .2135 L
.132 .21438 L
.136 .21296 L
.14 .20946 L
.144 .20434 L
.148 .19829 L
.152 .19216 L
.156 .18687 L
.16 .18326 L
.164 .18199 L
.168 .18347 L
.172 .18779 L
.176 .19472 L
.18 .20374 L
.184 .21408 L
.188 .22483 L
.192 .2351 L
.196 .24415 L
.2 .25156 L
Mistroke
.204 .25728 L
.208 .26164 L
.212 .26529 L
.216 .269 L
.22 .27353 L
.224 .27945 L
.228 .287 L
.232 .29597 L
.236 .30567 L
.24 .31503 L
.244 .32279 L
.248 .3277 L
.252 .32885 L
.256 .32591 L
.26 .31918 L
.264 .30966 L
.268 .2988 L
.272 .28832 L
.276 .27983 L
.28 .27457 L
.284 .27319 L
.288 .2756 L
.292 .28108 L
.296 .28839 L
.3 .29612 L
.304 .30298 L
.308 .30809 L
.312 .31113 L
.316 .31228 L
.32 .3121 L
.324 .31124 L
.328 .31022 L
.332 .30929 L
.336 .30839 L
.34 .3073 L
.344 .30585 L
.348 .3041 L
.352 .30245 L
.356 .30158 L
.36 .30231 L
.364 .30527 L
.368 .31061 L
.372 .3178 L
.376 .32561 L
.38 .33244 L
.384 .33665 L
.388 .33713 L
.392 .33367 L
.396 .32713 L
.4 .3193 L
Mistroke
.404 .3124 L
.408 .30838 L
.412 .30831 L
.416 .31205 L
.42 .31822 L
.424 .32472 L
.428 .32932 L
.432 .33051 L
.436 .32795 L
.44 .32255 L
.444 .31611 L
.448 .31064 L
.452 .30772 L
.456 .30799 L
.46 .311 L
.464 .31548 L
.468 .31984 L
.472 .32275 L
.476 .3236 L
.48 .32253 L
.484 .32032 L
.488 .31798 L
.492 .31643 L
.496 .31616 L
.5 .31712 L
.504 .31882 L
.508 .32058 L
.512 .32183 L
.516 .32225 L
.52 .3218 L
.524 .32062 L
.528 .31894 L
.532 .31712 L
.536 .3155 L
.54 .31442 L
.544 .3142 L
.548 .31502 L
.552 .31688 L
.556 .31937 L
.56 .32176 L
.564 .32316 L
.568 .32296 L
.572 .32118 L
.576 .31854 L
.58 .3162 L
.584 .31521 L
.588 .31604 L
.592 .31827 L
.596 .32076 L
.6 .32215 L
Mistroke
.604 .32155 L
.608 .31915 L
.612 .31615 L
.616 .31419 L
.62 .31441 L
.624 .31684 L
.628 .32029 L
.632 .32303 L
.636 .32367 L
.64 .3219 L
.644 .31866 L
.648 .31564 L
.652 .31442 L
.656 .31559 L
.66 .3184 L
.664 .32119 L
.668 .32237 L
.672 .32132 L
.676 .31876 L
.68 .31628 L
.684 .31531 L
.688 .31637 L
.692 .31874 L
.696 .32105 L
.7 .32203 L
.704 .32123 L
.708 .31919 L
.712 .31709 L
.716 .31607 L
.72 .31662 L
.724 .3183 L
.728 .32005 L
.732 .32085 L
.736 .32032 L
.74 .31897 L
.744 .31774 L
.748 .31737 L
.752 .31794 L
.756 .31891 L
.76 .31965 L
.764 .31981 L
.768 .31946 L
.772 .3189 L
.776 .31841 L
.78 .31814 L
.784 .3182 L
.788 .31857 L
.792 .3191 L
.796 .31948 L
.8 .31945 L
Mistroke
.804 .31903 L
.808 .31855 L
.812 .31839 L
.816 .31866 L
.82 .31906 L
.824 .3192 L
.828 .319 L
.832 .31868 L
.836 .31863 L
.84 .31889 L
.844 .31919 L
.848 .31922 L
.852 .31896 L
.856 .31865 L
.86 .31859 L
.864 .31874 L
.868 .31891 L
.872 .31901 L
.876 .31907 L
.88 .31925 L
.884 .31948 L
.888 .31933 L
.892 .31875 L
.896 .31804 L
.9 .31778 L
.904 .3185 L
.908 .31971 L
.912 .32039 L
.916 .32005 L
.92 .3188 L
.924 .31771 L
.928 .3179 L
.932 .31898 L
.936 .31997 L
.94 .32001 L
.944 .31883 L
.948 .31768 L
.952 .3179 L
.956 .31911 L
.96 .32043 L
.964 .32074 L
.968 .3193 L
.972 .31768 L
.976 .3174 L
.98 .31825 L
.984 .31986 L
.988 .32069 L
.992 .31952 L
.996 .31811 L
1 .31774 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16263 m
.008 .16209 L
.012 .16195 L
.016 .16232 L
.02 .16274 L
.024 .16317 L
.028 .16364 L
.032 .16431 L
.036 .1651 L
.04 .16604 L
.044 .16709 L
.048 .16833 L
.052 .16971 L
.056 .17126 L
.06 .17296 L
.064 .17482 L
.068 .17682 L
.072 .17896 L
.076 .1812 L
.08 .18354 L
.084 .18592 L
.088 .18834 L
.092 .19074 L
.096 .19313 L
.1 .19544 L
.104 .19769 L
.108 .19982 L
.112 .20186 L
.116 .20378 L
.12 .20562 L
.124 .20737 L
.128 .20908 L
.132 .21076 L
.136 .21246 L
.14 .21419 L
.144 .21598 L
.148 .21786 L
.152 .21983 L
.156 .22189 L
.16 .22401 L
.164 .22618 L
.168 .22835 L
.172 .2305 L
.176 .23258 L
.18 .23457 L
.184 .23645 L
.188 .23819 L
.192 .2398 L
.196 .2413 L
.2 .24268 L
Mistroke
.204 .24399 L
.208 .24522 L
.212 .2464 L
.216 .24752 L
.22 .24858 L
.224 .24956 L
.228 .25045 L
.232 .25122 L
.236 .25187 L
.24 .25239 L
.244 .2528 L
.248 .25312 L
.252 .25341 L
.256 .2537 L
.26 .25405 L
.264 .2545 L
.268 .25507 L
.272 .25577 L
.276 .25659 L
.28 .25748 L
.284 .25842 L
.288 .25934 L
.292 .26021 L
.296 .26099 L
.3 .26166 L
.304 .26223 L
.308 .26271 L
.312 .26312 L
.316 .26349 L
.32 .26385 L
.324 .2642 L
.328 .26457 L
.332 .26495 L
.336 .26535 L
.34 .26576 L
.344 .26617 L
.348 .2666 L
.352 .26701 L
.356 .2674 L
.36 .26773 L
.364 .26799 L
.368 .26813 L
.372 .26814 L
.376 .26802 L
.38 .26777 L
.384 .26744 L
.388 .26706 L
.392 .2667 L
.396 .26641 L
.4 .26621 L
Mistroke
.404 .26611 L
.408 .26609 L
.412 .26611 L
.416 .26613 L
.42 .26611 L
.424 .26603 L
.428 .2659 L
.432 .26574 L
.436 .2656 L
.44 .2655 L
.444 .26548 L
.448 .26554 L
.452 .26566 L
.456 .26581 L
.46 .26596 L
.464 .26607 L
.468 .26613 L
.472 .26615 L
.476 .26613 L
.48 .26609 L
.484 .26604 L
.488 .266 L
.492 .26595 L
.496 .26591 L
.5 .26585 L
.504 .26577 L
.508 .26566 L
.512 .26554 L
.516 .26541 L
.52 .2653 L
.524 .26523 L
.528 .26521 L
.532 .26524 L
.536 .26532 L
.54 .26543 L
.544 .26555 L
.548 .26564 L
.552 .26569 L
.556 .26568 L
.56 .26562 L
.564 .26551 L
.568 .26538 L
.572 .26526 L
.576 .26516 L
.58 .2651 L
.584 .26507 L
.588 .26506 L
.592 .26506 L
.596 .26506 L
.6 .26506 L
Mistroke
.604 .26506 L
.608 .26507 L
.612 .2651 L
.616 .26513 L
.62 .26515 L
.624 .26513 L
.628 .26508 L
.632 .26499 L
.636 .2649 L
.64 .26481 L
.644 .26476 L
.648 .26474 L
.652 .26475 L
.656 .26477 L
.66 .26478 L
.664 .26477 L
.668 .26474 L
.672 .26471 L
.676 .26469 L
.68 .26468 L
.684 .26468 L
.688 .26467 L
.692 .26464 L
.696 .2646 L
.7 .26454 L
.704 .26449 L
.708 .26444 L
.712 .26441 L
.716 .2644 L
.72 .2644 L
.724 .2644 L
.728 .26439 L
.732 .26438 L
.736 .26437 L
.74 .26435 L
.744 .26433 L
.748 .26431 L
.752 .26427 L
.756 .26422 L
.76 .26416 L
.764 .26411 L
.768 .26408 L
.772 .26407 L
.776 .26408 L
.78 .2641 L
.784 .26411 L
.788 .2641 L
.792 .26407 L
.796 .26402 L
.8 .26397 L
Mistroke
.804 .26392 L
.808 .26388 L
.812 .26386 L
.816 .26384 L
.82 .26382 L
.824 .26381 L
.828 .26381 L
.832 .2638 L
.836 .26379 L
.84 .26378 L
.844 .26375 L
.848 .26371 L
.852 .26366 L
.856 .26361 L
.86 .26357 L
.864 .26355 L
.868 .26354 L
.872 .26355 L
.876 .26355 L
.88 .26354 L
.884 .26352 L
.888 .26349 L
.892 .26344 L
.896 .2634 L
.9 .26336 L
.904 .26333 L
.908 .26331 L
.912 .26329 L
.916 .26329 L
.92 .26329 L
.924 .26329 L
.928 .26327 L
.932 .26323 L
.936 .26318 L
.94 .26314 L
.944 .2631 L
.948 .26308 L
.952 .26306 L
.956 .26306 L
.96 .26305 L
.964 .26304 L
.968 .26302 L
.972 .263 L
.976 .26297 L
.98 .26293 L
.984 .26288 L
.988 .26285 L
.992 .26281 L
.996 .26281 L
1 .2628 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16258 L
.012 .16017 L
.016 .15894 L
.02 .15899 L
.024 .15847 L
.028 .15746 L
.032 .15645 L
.036 .15548 L
.04 .15427 L
.044 .15288 L
.048 .15129 L
.052 .14956 L
.056 .14761 L
.06 .14547 L
.064 .14313 L
.068 .14063 L
.072 .13795 L
.076 .13516 L
.08 .13224 L
.084 .12927 L
.088 .12625 L
.092 .12323 L
.096 .12025 L
.1 .11736 L
.104 .11456 L
.108 .11189 L
.112 .10934 L
.116 .10693 L
.12 .10463 L
.124 .10243 L
.128 .10029 L
.132 .09819 L
.136 .09607 L
.14 .0939 L
.144 .09164 L
.148 .08929 L
.152 .08682 L
.156 .08425 L
.16 .08159 L
.164 .07888 L
.168 .07615 L
.172 .07346 L
.176 .07085 L
.18 .06835 L
.184 .066 L
.188 .06381 L
.192 .06178 L
.196 .0599 L
.2 .05815 L
Mistroke
.204 .05651 L
.208 .05495 L
.212 .05347 L
.216 .05205 L
.22 .05071 L
.224 .04947 L
.228 .04834 L
.232 .04736 L
.236 .04653 L
.24 .04586 L
.244 .04533 L
.248 .04491 L
.252 .04453 L
.256 .04415 L
.26 .04369 L
.264 .04311 L
.268 .04238 L
.272 .04149 L
.276 .04045 L
.28 .03931 L
.284 .03812 L
.288 .03695 L
.292 .03585 L
.296 .03486 L
.3 .034 L
.304 .03327 L
.308 .03265 L
.312 .03211 L
.316 .03162 L
.32 .03116 L
.324 .0307 L
.328 .03022 L
.332 .02972 L
.336 .0292 L
.34 .02867 L
.344 .02812 L
.348 .02757 L
.352 .02704 L
.356 .02653 L
.36 .02609 L
.364 .02575 L
.368 .02555 L
.372 .02551 L
.376 .02564 L
.38 .02592 L
.384 .02632 L
.388 .02676 L
.392 .02719 L
.396 .02753 L
.4 .02776 L
Mistroke
.404 .02786 L
.408 .02786 L
.412 .02781 L
.416 .02776 L
.42 .02776 L
.424 .02784 L
.428 .02798 L
.432 .02815 L
.436 .0283 L
.44 .0284 L
.444 .02841 L
.448 .02832 L
.452 .02814 L
.456 .02793 L
.46 .02772 L
.464 .02756 L
.468 .02746 L
.472 .02742 L
.476 .02743 L
.48 .02746 L
.484 .02749 L
.488 .02752 L
.492 .02754 L
.496 .02758 L
.5 .02763 L
.504 .02771 L
.508 .02783 L
.512 .02796 L
.516 .02809 L
.52 .0282 L
.524 .02826 L
.528 .02827 L
.532 .02821 L
.536 .02809 L
.54 .02793 L
.544 .02777 L
.548 .02762 L
.552 .02753 L
.556 .02752 L
.56 .02758 L
.564 .0277 L
.568 .02784 L
.572 .02797 L
.576 .02807 L
.58 .02812 L
.584 .02813 L
.588 .02811 L
.592 .02809 L
.596 .02808 L
.6 .02806 L
Mistroke
.604 .02803 L
.608 .02799 L
.612 .02793 L
.616 .02787 L
.62 .02783 L
.624 .02782 L
.628 .02787 L
.632 .02795 L
.636 .02805 L
.64 .02814 L
.644 .02818 L
.648 .02817 L
.652 .02814 L
.656 .02809 L
.66 .02806 L
.664 .02805 L
.668 .02806 L
.672 .02808 L
.676 .02809 L
.68 .02808 L
.684 .02806 L
.688 .02804 L
.692 .02804 L
.696 .02808 L
.7 .02813 L
.704 .02818 L
.708 .02822 L
.712 .02823 L
.716 .02822 L
.72 .02819 L
.724 .02817 L
.728 .02815 L
.732 .02815 L
.736 .02815 L
.74 .02815 L
.744 .02816 L
.748 .02817 L
.752 .02819 L
.756 .02822 L
.76 .02825 L
.764 .02829 L
.768 .02832 L
.772 .02832 L
.776 .0283 L
.78 .02826 L
.784 .02822 L
.788 .0282 L
.792 .0282 L
.796 .02822 L
.8 .02827 L
Mistroke
.804 .02831 L
.808 .02836 L
.812 .02838 L
.816 .02839 L
.82 .02838 L
.824 .02835 L
.828 .02832 L
.832 .0283 L
.836 .02829 L
.84 .02829 L
.844 .02832 L
.848 .02837 L
.852 .02842 L
.856 .02845 L
.86 .02846 L
.864 .02844 L
.868 .02841 L
.872 .02838 L
.876 .02837 L
.88 .02838 L
.884 .0284 L
.888 .02843 L
.892 .02846 L
.896 .02848 L
.9 .02849 L
.904 .02849 L
.908 .02849 L
.912 .02848 L
.916 .02847 L
.92 .02847 L
.924 .02848 L
.928 .02849 L
.932 .02851 L
.936 .02853 L
.94 .02855 L
.944 .02855 L
.948 .02855 L
.952 .02854 L
.956 .02854 L
.96 .02854 L
.964 .02856 L
.968 .02857 L
.972 .02859 L
.976 .0286 L
.98 .02861 L
.984 .0286 L
.988 .0286 L
.992 .02858 L
.996 .0286 L
1 .02861 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo00001goo0`00I7oo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`020005Ool01000Oomoo`00I7oo000:Ool01000Oomoo`0027oo00H007oo
Ool007oo0003Ool00`00Oomoo`020005Ool01@00Oomoogoo000017oo0P00GGoo000;Ool2000:Ool2
0003Ool30003Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0005eoo`002goo
0P0017oo00<007ooOol00goo0P000goo0`000goo0P0017oo00<007ooOol00Woo0P0000=oo`000000
0Woo00<007ooOol0FWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
00Aoo`03001oogoo00=oo`L000=oo`8000Moo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`80
00=oo`D000=oo`8000Aoo`8000Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01@00Oomo
ogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00D007ooOomoo`0000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04
001oogoo0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P000goo00<007oo
Ool02Woo0P0000Eoo`00Oomoo`0000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20002Ool00`00Oomoo`0;Ool20000
1Goo001oogoo00001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`00009oo`04001oogoo0002Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000Aoo`05001oogooOol00009Ool40002Ool20002Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool0
1000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00H007oo
Oomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool20000
0goo00000009Ool00`00Oomoo`03Ool20002Ool00`00Oomoo`04Ool20004Ool01000Oomoo`000Woo
00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0
029oo`800003Ool007oo00Uoo`D0009oo`<000=oo`8000=oo`03001oogoo00=oo`8000Aoo`8000Io
o`04001oogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0
029oo`03001oo`0001=oo`03001oogoo009oo`03001oo`00055oo`008Woo0`0057oo00L007ooOomo
o`00Ool0001AOol0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo10000goo0P000Woo0P000Woo0`0000Eoo`00000007oo00<00003Ool00000
00`00003Ool0000001D00003Ool0000000L000aoo`008Woo0P005Woo0P002goo00@007oo001oo`<0
009oo`80009oo`80009oo`<00004Ool00000Ool20002Ool2000017oo000007oo0P0000=oo`000000
0Woo00<007ooOol01Goo0P0000=oo`00Ool00P0000=oo`00Ool00P003Goo000ROol00`00Oomoo`0R
Ool20003Ool00`00Oomoo`12Ool0029oo`8006eoo`008Woo0P00KGoo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol0
0Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`00
0goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomo
o`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007oo
Ool006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007oo
Ool007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`80
06eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3
001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo
06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00
Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1V
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0
IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03
Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo
0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`H0
06=oo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol00goo0P00
HGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol0
00Ioo`<005moo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOol000Qoo`<005eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol00P002Goo1@0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo
0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool50002Ool01000Oomoo`00
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol0
0002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol037oo0`0000Eoo`00Oomoo`0000Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0
009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo
00eoo`D00003Ool007oo00Ioo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`00
0Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<0
07ooOol02Goo10000goo20000goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool0
1000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00
Oomoo`04Ool01000Oomoo`000goo@`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@00
0goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Ao
o`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<0
07ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
2goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1VOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yo
o`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P00
17oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<0
07ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`00
2goo00<007ooOol00P008Woo2@000goo1P000Woo100017oo0P00<goo000:Ool01000Oomoo`002goo
00@007ooOol001eoo`L000Moo`@000Eoo`@0009oo`D0009oobL000aoo`002Woo00@007ooOol000Mo
o`@000=oo`03001oogoo01Ioo`H005Ioo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8001=o
o`@005aoo`002goo0P0027oo1@000Woo00<007ooOol047oo0`00Ggoo000LOol00`00Oomoo`0=Ool4
0003Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool2
0005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`<00005Ool007ooOol00002Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool0
1000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0<
Ool20002Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
0goo000LOol00`00Oomoo`0:Ool20004Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol20009Ool20002Ool40003Ool01000Oomoo`002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol0
07oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol01goo0P000goo00<007ooOol017oo00@0
07ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo
00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001o
ogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P001Woo0P001Goo1@000goo0P002Woo00<0
07ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Io
o`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol017oo0P00K7oo000LOol00`00Oomoo`02Ool2
001^Ool001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomo
o`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001d
Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00
Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo
009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00
Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol0
0`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<0
00Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009o
o`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo
00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uo
o`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(23714\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .25042 m
.008 .24493 L
.012 .2388 L
.016 .23152 L
.02 .22328 L
.024 .21441 L
.028 .20506 L
.032 .19548 L
.036 .1861 L
.04 .1773 L
.044 .16941 L
.048 .16277 L
.052 .15776 L
.056 .15463 L
.06 .15358 L
.064 .15467 L
.068 .15785 L
.072 .16293 L
.076 .16958 L
.08 .17732 L
.084 .18558 L
.088 .19371 L
.092 .20104 L
.096 .20698 L
.1 .21103 L
.104 .21285 L
.108 .21233 L
.112 .2096 L
.116 .20504 L
.12 .19925 L
.124 .19304 L
.128 .1873 L
.132 .18291 L
.136 .1806 L
.14 .18092 L
.144 .1841 L
.148 .19006 L
.152 .19841 L
.156 .20846 L
.16 .21934 L
.164 .23013 L
.168 .23999 L
.172 .24836 L
.176 .25502 L
.18 .26012 L
.184 .26414 L
.188 .26777 L
.192 .27181 L
.196 .27693 L
.2 .28358 L
Mistroke
.204 .29178 L
.208 .30109 L
.212 .3106 L
.216 .3191 L
.22 .32532 L
.224 .3282 L
.228 .32712 L
.232 .32207 L
.236 .31369 L
.24 .30321 L
.244 .29224 L
.248 .28247 L
.252 .27541 L
.256 .27207 L
.26 .27277 L
.264 .27708 L
.268 .28394 L
.272 .29194 L
.276 .29967 L
.28 .30598 L
.284 .31023 L
.288 .31232 L
.292 .31263 L
.296 .31179 L
.3 .31044 L
.304 .30909 L
.308 .30792 L
.312 .30689 L
.316 .30582 L
.32 .30457 L
.324 .30323 L
.328 .30223 L
.332 .30227 L
.336 .30405 L
.34 .30805 L
.344 .31417 L
.348 .32165 L
.352 .32911 L
.356 .33487 L
.36 .33749 L
.364 .33621 L
.368 .33128 L
.372 .32397 L
.376 .31626 L
.38 .31029 L
.384 .30771 L
.388 .30913 L
.392 .31393 L
.396 .32045 L
.4 .32649 L
Mistroke
.404 .33008 L
.408 .33003 L
.412 .32637 L
.416 .32029 L
.42 .31376 L
.424 .30878 L
.428 .30677 L
.432 .3081 L
.436 .31202 L
.44 .31704 L
.444 .32143 L
.448 .32389 L
.452 .32396 L
.456 .3221 L
.46 .31939 L
.464 .31705 L
.468 .31593 L
.472 .31628 L
.476 .31775 L
.48 .31964 L
.484 .32122 L
.488 .32201 L
.492 .3219 L
.496 .32107 L
.5 .31975 L
.504 .31817 L
.508 .3165 L
.512 .31501 L
.516 .31406 L
.52 .31409 L
.524 .31531 L
.528 .3176 L
.532 .32035 L
.536 .32266 L
.54 .32361 L
.544 .32273 L
.548 .32033 L
.552 .31743 L
.556 .31535 L
.56 .31503 L
.564 .31657 L
.568 .31911 L
.572 .3213 L
.576 .32195 L
.58 .32065 L
.584 .31799 L
.588 .31535 L
.592 .31418 L
.596 .31522 L
.6 .31805 L
Mistroke
.604 .32126 L
.608 .32322 L
.612 .32295 L
.616 .32066 L
.62 .31758 L
.624 .3153 L
.628 .31492 L
.632 .31652 L
.636 .31912 L
.64 .32122 L
.644 .32166 L
.648 .32027 L
.652 .31795 L
.656 .31614 L
.66 .31592 L
.664 .31736 L
.668 .31955 L
.672 .32117 L
.676 .32135 L
.68 .32007 L
.684 .31818 L
.688 .31676 L
.692 .31657 L
.696 .31761 L
.7 .31915 L
.704 .32023 L
.708 .32024 L
.712 .31924 L
.716 .31799 L
.72 .31736 L
.724 .31775 L
.728 .31886 L
.732 .31988 L
.736 .32012 L
.74 .31946 L
.744 .3184 L
.748 .31763 L
.752 .31759 L
.756 .31822 L
.76 .3191 L
.764 .31974 L
.768 .31983 L
.772 .31936 L
.776 .31857 L
.78 .31788 L
.784 .3177 L
.788 .3182 L
.792 .31912 L
.796 .31987 L
.8 .31997 L
Mistroke
.804 .31934 L
.808 .31841 L
.812 .3178 L
.816 .31786 L
.82 .31843 L
.824 .31912 L
.828 .31955 L
.832 .31958 L
.836 .31931 L
.84 .31885 L
.844 .31838 L
.848 .31814 L
.852 .31831 L
.856 .31889 L
.86 .31954 L
.864 .31969 L
.868 .31919 L
.872 .31838 L
.876 .31794 L
.88 .31837 L
.884 .31927 L
.888 .31982 L
.892 .31956 L
.896 .31865 L
.9 .31798 L
.904 .31829 L
.908 .3192 L
.912 .31985 L
.916 .31962 L
.92 .31854 L
.924 .31776 L
.928 .31813 L
.932 .31921 L
.936 .32016 L
.94 .32008 L
.944 .31882 L
.948 .31778 L
.952 .3179 L
.956 .31882 L
.96 .31997 L
.964 .32012 L
.968 .31894 L
.972 .31798 L
.976 .31797 L
.98 .31876 L
.984 .32003 L
.988 .32026 L
.992 .31906 L
.996 .31812 L
1 .31797 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16546 m
.008 .16817 L
.012 .16933 L
.016 .16905 L
.02 .16955 L
.024 .1709 L
.028 .17221 L
.032 .17357 L
.036 .17517 L
.04 .17704 L
.044 .17902 L
.048 .18115 L
.052 .18337 L
.056 .1857 L
.06 .18805 L
.064 .19044 L
.068 .1928 L
.072 .19514 L
.076 .19738 L
.08 .19956 L
.084 .20161 L
.088 .20358 L
.092 .20543 L
.096 .20722 L
.1 .20893 L
.104 .21062 L
.108 .2123 L
.112 .21401 L
.116 .21578 L
.12 .21762 L
.124 .21955 L
.128 .22157 L
.132 .22366 L
.136 .22581 L
.14 .22797 L
.144 .23013 L
.148 .23223 L
.152 .23426 L
.156 .23618 L
.16 .23797 L
.164 .23962 L
.168 .24116 L
.172 .24257 L
.176 .2439 L
.18 .24514 L
.184 .24632 L
.188 .24745 L
.192 .24851 L
.196 .24951 L
.2 .25043 L
Mistroke
.204 .25124 L
.208 .25194 L
.212 .25251 L
.216 .25296 L
.22 .25332 L
.224 .25362 L
.228 .25391 L
.232 .25423 L
.236 .25463 L
.24 .25515 L
.244 .25579 L
.248 .25655 L
.252 .25741 L
.256 .25833 L
.26 .25927 L
.264 .26016 L
.268 .26099 L
.272 .26171 L
.276 .26232 L
.28 .26283 L
.284 .26326 L
.288 .26364 L
.292 .26399 L
.296 .26434 L
.3 .26469 L
.304 .26506 L
.308 .26545 L
.312 .26586 L
.316 .26627 L
.32 .26669 L
.324 .2671 L
.328 .26749 L
.332 .26783 L
.336 .26811 L
.34 .26829 L
.344 .26836 L
.348 .2683 L
.352 .26811 L
.356 .26781 L
.36 .26745 L
.364 .26707 L
.368 .26674 L
.372 .26648 L
.376 .26633 L
.38 .26627 L
.384 .26627 L
.388 .2663 L
.392 .26632 L
.396 .26628 L
.4 .26619 L
Mistroke
.404 .26605 L
.408 .2659 L
.412 .26578 L
.416 .26571 L
.42 .26572 L
.424 .26581 L
.428 .26595 L
.432 .2661 L
.436 .26624 L
.44 .26634 L
.444 .26638 L
.448 .26638 L
.452 .26634 L
.456 .26628 L
.46 .26623 L
.464 .26618 L
.468 .26613 L
.472 .26608 L
.476 .26601 L
.48 .26592 L
.484 .2658 L
.488 .26568 L
.492 .26557 L
.496 .26548 L
.5 .26544 L
.504 .26544 L
.508 .2655 L
.512 .26559 L
.516 .2657 L
.52 .26581 L
.524 .26588 L
.528 .26591 L
.532 .26588 L
.536 .26579 L
.54 .26566 L
.544 .26553 L
.548 .26541 L
.552 .26533 L
.556 .26528 L
.56 .26527 L
.564 .26527 L
.568 .26528 L
.572 .26528 L
.576 .26528 L
.58 .26529 L
.584 .2653 L
.588 .26533 L
.592 .26535 L
.596 .26535 L
.6 .26532 L
Mistroke
.604 .26526 L
.608 .26517 L
.612 .26507 L
.616 .265 L
.62 .26496 L
.624 .26495 L
.628 .26497 L
.632 .26499 L
.636 .265 L
.64 .26498 L
.644 .26495 L
.648 .26492 L
.652 .2649 L
.656 .26488 L
.66 .26488 L
.664 .26487 L
.668 .26484 L
.672 .2648 L
.676 .26474 L
.68 .26468 L
.684 .26463 L
.688 .26461 L
.692 .26461 L
.696 .26462 L
.7 .26462 L
.704 .26461 L
.708 .2646 L
.712 .26457 L
.716 .26455 L
.72 .26452 L
.724 .2645 L
.728 .26446 L
.732 .26442 L
.736 .26437 L
.74 .26433 L
.744 .26429 L
.748 .26428 L
.752 .26429 L
.756 .2643 L
.76 .26431 L
.764 .26431 L
.768 .26428 L
.772 .26423 L
.776 .26417 L
.78 .26412 L
.784 .26407 L
.788 .26404 L
.792 .26403 L
.796 .26403 L
.8 .26403 L
Mistroke
.804 .26403 L
.808 .26403 L
.812 .26401 L
.816 .26398 L
.82 .26393 L
.824 .26388 L
.828 .26384 L
.832 .2638 L
.836 .26378 L
.84 .26377 L
.844 .26377 L
.848 .26377 L
.852 .26376 L
.856 .26374 L
.86 .26371 L
.864 .26367 L
.868 .26363 L
.872 .2636 L
.876 .26358 L
.88 .26355 L
.884 .26353 L
.888 .26351 L
.892 .2635 L
.896 .26349 L
.9 .26347 L
.904 .26345 L
.908 .26342 L
.912 .26339 L
.916 .26335 L
.92 .26332 L
.924 .2633 L
.928 .26328 L
.932 .26326 L
.936 .26325 L
.94 .26323 L
.944 .26321 L
.948 .26319 L
.952 .26317 L
.956 .26314 L
.96 .2631 L
.964 .26308 L
.968 .26304 L
.972 .26303 L
.976 .263 L
.98 .26299 L
.984 .26297 L
.988 .26296 L
.992 .26294 L
.996 .26292 L
1 .26289 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15999 L
.012 .15766 L
.016 .15547 L
.02 .15364 L
.024 .15163 L
.028 .14944 L
.032 .14703 L
.036 .14457 L
.04 .14195 L
.044 .13922 L
.048 .13634 L
.052 .1334 L
.056 .13037 L
.06 .12733 L
.064 .12426 L
.068 .12125 L
.072 .1183 L
.076 .11546 L
.08 .11272 L
.084 .11013 L
.088 .10765 L
.092 .10532 L
.096 .10308 L
.1 .10093 L
.104 .09881 L
.108 .0967 L
.112 .09455 L
.116 .09234 L
.12 .09002 L
.124 .08761 L
.128 .08508 L
.132 .08247 L
.136 .07978 L
.14 .07706 L
.144 .07436 L
.148 .07172 L
.152 .06918 L
.156 .06677 L
.16 .06452 L
.164 .06244 L
.168 .06051 L
.172 .05872 L
.176 .05706 L
.18 .05549 L
.184 .054 L
.188 .05258 L
.192 .05123 L
.196 .04996 L
.2 .0488 L
Mistroke
.204 .04777 L
.208 .04689 L
.212 .04615 L
.216 .04557 L
.22 .0451 L
.224 .0447 L
.228 .04432 L
.232 .0439 L
.236 .04339 L
.24 .04272 L
.244 .0419 L
.248 .04093 L
.252 .03983 L
.256 .03866 L
.26 .03748 L
.264 .03634 L
.268 .0353 L
.272 .03438 L
.276 .03359 L
.28 .03293 L
.284 .03237 L
.288 .03187 L
.292 .03142 L
.296 .03096 L
.3 .0305 L
.304 .03001 L
.308 .0295 L
.312 .02898 L
.316 .02844 L
.32 .0279 L
.324 .02736 L
.328 .02686 L
.332 .0264 L
.336 .02603 L
.34 .02578 L
.344 .02567 L
.348 .02573 L
.352 .02594 L
.356 .02629 L
.36 .02671 L
.364 .02716 L
.368 .02755 L
.372 .02785 L
.376 .02802 L
.38 .02807 L
.384 .02804 L
.388 .02798 L
.392 .02794 L
.396 .02796 L
.4 .02805 L
Mistroke
.404 .0282 L
.408 .02837 L
.412 .0285 L
.416 .02856 L
.42 .02852 L
.424 .02839 L
.428 .02819 L
.432 .02798 L
.436 .02778 L
.44 .02764 L
.444 .02756 L
.448 .02755 L
.452 .02757 L
.456 .02762 L
.46 .02766 L
.464 .0277 L
.468 .02774 L
.472 .02778 L
.476 .02785 L
.48 .02794 L
.484 .02805 L
.488 .02818 L
.492 .0283 L
.496 .02839 L
.5 .02842 L
.504 .02839 L
.508 .0283 L
.512 .02816 L
.516 .028 L
.52 .02784 L
.524 .02772 L
.528 .02767 L
.532 .0277 L
.536 .02778 L
.54 .02791 L
.544 .02805 L
.548 .02818 L
.552 .02826 L
.556 .0283 L
.56 .02829 L
.564 .02827 L
.568 .02824 L
.572 .02821 L
.576 .02818 L
.58 .02815 L
.584 .02811 L
.588 .02806 L
.592 .02801 L
.596 .02799 L
.6 .028 L
Mistroke
.604 .02805 L
.608 .02814 L
.612 .02823 L
.616 .02831 L
.62 .02834 L
.624 .02833 L
.628 .02829 L
.632 .02824 L
.636 .0282 L
.64 .02819 L
.644 .02821 L
.648 .02822 L
.652 .02823 L
.656 .02823 L
.66 .02821 L
.664 .02821 L
.668 .02821 L
.672 .02825 L
.676 .0283 L
.68 .02834 L
.684 .02838 L
.688 .02838 L
.692 .02837 L
.696 .02834 L
.7 .02832 L
.704 .0283 L
.708 .02829 L
.712 .0283 L
.716 .0283 L
.72 .02831 L
.724 .02833 L
.728 .02836 L
.732 .02839 L
.736 .02843 L
.74 .02846 L
.744 .02847 L
.748 .02846 L
.752 .02842 L
.756 .02838 L
.76 .02836 L
.764 .02835 L
.768 .02837 L
.772 .02841 L
.776 .02845 L
.78 .02849 L
.784 .02851 L
.788 .02852 L
.792 .02852 L
.796 .02851 L
.8 .0285 L
Mistroke
.804 .02848 L
.808 .02846 L
.812 .02845 L
.816 .02846 L
.82 .02848 L
.824 .02851 L
.828 .02856 L
.832 .0286 L
.836 .02862 L
.84 .02861 L
.844 .02858 L
.848 .02855 L
.852 .02852 L
.856 .02852 L
.86 .02853 L
.864 .02857 L
.868 .02861 L
.872 .02864 L
.876 .02866 L
.88 .02867 L
.884 .02865 L
.888 .02863 L
.892 .02861 L
.896 .0286 L
.9 .02861 L
.904 .02863 L
.908 .02866 L
.912 .02869 L
.916 .02872 L
.92 .02872 L
.924 .02872 L
.928 .0287 L
.932 .02869 L
.936 .02868 L
.94 .02869 L
.944 .0287 L
.948 .02873 L
.952 .02876 L
.956 .02878 L
.96 .02878 L
.964 .02878 L
.968 .02877 L
.972 .02876 L
.976 .02875 L
.98 .02876 L
.984 .02877 L
.988 .0288 L
.992 .02882 L
.996 .02885 L
1 .02885 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Aoo`03001oogoo06Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0004Ool01@00Oomoogoo000017oo00<007oo0000Igoo000:Ool01000
Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`020002Ool01@00Oomoogoo0000IWoo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`020002Ool01@00Oomoogoo0000
17oo0P00H7oo000;Ool2000:Ool20003Ool30003Ool00`00Oomoo`020004Ool00`00Oomoo`020000
0goo001oo`1NOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`800003Ool007oo00Ao
o`04001oo`000002Ool00`00Oomoo`1MOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0`001goo0P000goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`00
17oo0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oo`0000]oo`05001oo`00Ool00002
Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomo
ogoo00000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool3000=Ool00`00Ool00002Ool0
1000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8000moo`80009oo`04001oogoo0007Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
0P0037oo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`80
00Aoo`03001oogoo009oo`8000aoo`05001oogooOol00002Ool01000Oomoo`001Woo0P0017oo00@0
07ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D007oo
Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006Ool01000
Oomoo`001Goo000ROol2000<Ool60002Ool200000goo00000005Ool00`00Oomoo`03Ool20004Ool2
0006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P00
1Woo000ROol00`00Oomoo`0AOol01`00Oomoogoo001oo`0005Aoo`008Woo0P004Woo00D007ooOomo
o`00009oo`03001oogoo055oo`008WooH`0037oo000ROol01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`04001oogooOol200000goo00000002Ool50002Ool200002Goo00000000Ool007oo001o
o`0300000goo00000002000017oo000007oo0`0000Aoo`00001oo`D00004Ool00000Ool200000goo
0000000300000goo0000000?000<Ool0029oo`8001Aoo`8000Yoo`03001oo`00009oo`<00005Ool0
0000001oo`030002Ool3000017oo000007oo0P0000Aoo`00001oo`80009oo`04001oo`000002Ool0
1000Oomoo`000Woo0P0000Qoo`00Oomoo`00Ool007oo0P0000Aoo`00Ool000ioo`008Woo00<007oo
Ool087oo0P000goo00<007ooOol0A7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001o
ogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`00
27oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@0
07ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001o
ogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04
001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000R
Ool2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00
Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<0
07ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001o
ogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0
015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool3001VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo0080
06Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo
0004Ool2001ROol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eo
o`04001oogoo0006Ool2001POol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo008000Ioo`<0009oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=o
o`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol027oo0`000Woo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00Yo
o`800005Ool007ooOol00002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0
009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2
000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0<Ool300001Goo001oogoo00001goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40002Ool70005Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00
Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=o
o`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`05001oogoo001oo`150003
Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004
Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo
0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00
Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00
Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004
Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04
001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007oo
Ool007oo00@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00
Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Io
o`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yo
o`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00
0goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003
Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03
001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00
Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Ao
o`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03
001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02000OOol70005Ool5
0004Ool3000lOol000Yoo`04001oogoo000;Ool01000Oomoo`006Woo1`001Goo1`0017oo1@0000=o
o`000000;`0037oo000:Ool01000Oomoo`001goo10000goo00<007ooOol04goo1P00FGoo000:Ool0
1000Oomoo`001goo00<007ooOol017oo0P004Goo0`00Ggoo000;Ool20008Ool50002Ool00`00Oomo
o`0>Ool2001ROol001aoo`03001oogoo00aoo`@000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<0
00=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P00
2goo0`000goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool001aoo`03001oogoo00Uoo`8000Eoo`04001oogoo0002Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo00Moo`8000Moo`04001o
ogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`80
00Ioo`8000Eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00
Oomoo`04Ool20006Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04
001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000L
Ool20004Ool00`00Oomoo`06Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000
Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol0
1000Oomoogoo0P00Kgoo000LOol00`00Ool00002001`Ool001aoofT000aoo`0077oo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=o
o`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009o
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol3
0003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol0
0Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001o
ogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`00
2goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo
00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07
Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo
00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(23881\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15446 m
.008 .14919 L
.012 .14451 L
.016 .14013 L
.02 .13613 L
.024 .13392 L
.028 .13359 L
.032 .13484 L
.036 .13771 L
.04 .14252 L
.044 .1491 L
.048 .15706 L
.052 .166 L
.056 .17546 L
.06 .18483 L
.064 .19346 L
.068 .20075 L
.072 .20618 L
.076 .20938 L
.08 .21015 L
.084 .20855 L
.088 .20486 L
.092 .19963 L
.096 .19362 L
.1 .18767 L
.104 .1827 L
.108 .17951 L
.112 .17874 L
.116 .18078 L
.12 .18571 L
.124 .19326 L
.128 .20284 L
.132 .21366 L
.136 .2248 L
.14 .23536 L
.144 .24467 L
.148 .25232 L
.152 .25827 L
.156 .26284 L
.16 .26662 L
.164 .27037 L
.168 .27486 L
.172 .28067 L
.176 .28804 L
.18 .29674 L
.184 .30609 L
.188 .31502 L
.192 .32228 L
.196 .32671 L
.2 .32747 L
Mistroke
.204 .32422 L
.208 .31727 L
.212 .30755 L
.216 .29651 L
.22 .28584 L
.224 .27723 L
.228 .27198 L
.232 .27077 L
.236 .27353 L
.24 .27949 L
.244 .28737 L
.248 .2957 L
.252 .30313 L
.256 .30871 L
.26 .312 L
.264 .3131 L
.268 .31253 L
.272 .311 L
.276 .30923 L
.28 .30767 L
.284 .30648 L
.288 .30554 L
.292 .30463 L
.296 .30365 L
.3 .30277 L
.304 .30248 L
.308 .30347 L
.312 .30634 L
.316 .31132 L
.32 .31802 L
.324 .32544 L
.328 .3321 L
.332 .33648 L
.336 .33742 L
.34 .33455 L
.344 .32851 L
.348 .32082 L
.352 .31355 L
.356 .30867 L
.36 .30751 L
.364 .31027 L
.368 .31596 L
.372 .32267 L
.376 .32815 L
.38 .33057 L
.384 .32914 L
.388 .32431 L
.392 .31766 L
.396 .31129 L
.4 .30715 L
Mistroke
.404 .30636 L
.408 .30888 L
.412 .31359 L
.416 .31877 L
.42 .32276 L
.424 .3245 L
.428 .32386 L
.432 .32153 L
.436 .31868 L
.44 .3165 L
.444 .31572 L
.448 .31641 L
.452 .31812 L
.456 .32009 L
.46 .32162 L
.464 .32226 L
.468 .32187 L
.472 .32063 L
.476 .31887 L
.48 .31699 L
.484 .31534 L
.488 .31424 L
.492 .31397 L
.496 .3147 L
.5 .31643 L
.504 .31879 L
.508 .32116 L
.512 .32279 L
.516 .32311 L
.52 .32194 L
.524 .31968 L
.528 .31717 L
.532 .31545 L
.536 .31526 L
.54 .31666 L
.544 .31892 L
.548 .32087 L
.552 .32147 L
.556 .32035 L
.56 .318 L
.564 .31561 L
.568 .31448 L
.572 .31535 L
.576 .31796 L
.58 .32109 L
.584 .32317 L
.588 .32308 L
.592 .32085 L
.596 .31761 L
.6 .31501 L
Mistroke
.604 .31436 L
.608 .3159 L
.612 .31871 L
.616 .32124 L
.62 .32212 L
.624 .32091 L
.628 .31838 L
.632 .31604 L
.636 .31528 L
.64 .31652 L
.644 .31901 L
.648 .32125 L
.652 .32199 L
.656 .32086 L
.66 .31859 L
.664 .3165 L
.668 .31571 L
.672 .31656 L
.676 .31845 L
.68 .32025 L
.684 .32096 L
.688 .32026 L
.692 .31872 L
.696 .31732 L
.7 .31692 L
.704 .31766 L
.708 .31897 L
.712 .31999 L
.716 .32013 L
.72 .31942 L
.724 .31838 L
.728 .31762 L
.732 .31751 L
.736 .31801 L
.74 .3188 L
.744 .31949 L
.748 .31976 L
.752 .31948 L
.756 .31882 L
.76 .31816 L
.764 .31787 L
.768 .3181 L
.772 .31867 L
.776 .3192 L
.78 .3194 L
.784 .31921 L
.788 .31885 L
.792 .31853 L
.796 .31838 L
.8 .3184 L
Mistroke
.804 .31852 L
.808 .31874 L
.812 .319 L
.816 .31916 L
.82 .31913 L
.824 .31894 L
.828 .31872 L
.832 .31866 L
.836 .31872 L
.84 .31869 L
.844 .3185 L
.848 .31834 L
.852 .3185 L
.856 .31913 L
.86 .31978 L
.864 .31986 L
.868 .31916 L
.872 .31805 L
.876 .31743 L
.88 .31789 L
.884 .31902 L
.888 .31996 L
.892 .31997 L
.896 .31907 L
.9 .31819 L
.904 .31809 L
.908 .31866 L
.912 .31934 L
.916 .31943 L
.92 .3188 L
.924 .31831 L
.928 .31844 L
.932 .31899 L
.936 .31959 L
.94 .3195 L
.944 .31875 L
.948 .3183 L
.952 .3184 L
.956 .31889 L
.96 .31949 L
.964 .31935 L
.968 .31867 L
.972 .31844 L
.976 .31866 L
.98 .31917 L
.984 .31974 L
.988 .31935 L
.992 .31841 L
.996 .31818 L
1 .31841 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .18313 m
.008 .18438 L
.012 .18522 L
.016 .1857 L
.02 .18654 L
.024 .1879 L
.028 .18941 L
.032 .19106 L
.036 .19279 L
.04 .19467 L
.044 .19657 L
.048 .19851 L
.052 .20039 L
.056 .20226 L
.06 .20405 L
.064 .2058 L
.068 .20747 L
.072 .20912 L
.076 .21073 L
.08 .21235 L
.084 .21399 L
.088 .2157 L
.092 .21747 L
.096 .21935 L
.1 .22131 L
.104 .22336 L
.108 .22546 L
.112 .22761 L
.116 .22976 L
.12 .23189 L
.124 .23394 L
.128 .23589 L
.132 .23773 L
.136 .23943 L
.14 .241 L
.144 .24246 L
.148 .2438 L
.152 .24506 L
.156 .24625 L
.16 .24738 L
.164 .24845 L
.168 .24946 L
.172 .2504 L
.176 .25124 L
.18 .25198 L
.184 .2526 L
.188 .2531 L
.192 .2535 L
.196 .25382 L
.2 .25412 L
Mistroke
.204 .25442 L
.208 .25478 L
.212 .25524 L
.216 .25583 L
.22 .25653 L
.224 .25736 L
.228 .25825 L
.232 .25919 L
.236 .2601 L
.24 .26096 L
.244 .26173 L
.248 .26239 L
.252 .26294 L
.256 .2634 L
.26 .26379 L
.264 .26415 L
.268 .26448 L
.272 .26482 L
.276 .26518 L
.28 .26556 L
.284 .26596 L
.288 .26637 L
.292 .26678 L
.296 .26719 L
.3 .26758 L
.304 .26793 L
.308 .26823 L
.312 .26845 L
.316 .26856 L
.32 .26855 L
.324 .26841 L
.328 .26816 L
.332 .26782 L
.336 .26745 L
.34 .26709 L
.344 .26679 L
.348 .26658 L
.352 .26647 L
.356 .26644 L
.36 .26647 L
.364 .2665 L
.368 .2665 L
.372 .26645 L
.376 .26635 L
.38 .26621 L
.384 .26607 L
.388 .26597 L
.392 .26593 L
.396 .26598 L
.4 .26609 L
Mistroke
.404 .26624 L
.408 .2664 L
.412 .26652 L
.416 .2666 L
.42 .26662 L
.424 .26659 L
.428 .26653 L
.432 .26647 L
.436 .26641 L
.44 .26636 L
.444 .2663 L
.448 .26624 L
.452 .26617 L
.456 .26607 L
.46 .26596 L
.464 .26584 L
.468 .26574 L
.472 .26568 L
.476 .26566 L
.48 .26568 L
.484 .26576 L
.488 .26586 L
.492 .26598 L
.496 .26607 L
.5 .26612 L
.504 .26612 L
.508 .26605 L
.512 .26595 L
.516 .26581 L
.52 .26568 L
.524 .26558 L
.528 .26551 L
.532 .26548 L
.536 .26547 L
.54 .26548 L
.544 .2655 L
.548 .26551 L
.552 .26551 L
.556 .26552 L
.56 .26553 L
.564 .26555 L
.568 .26556 L
.572 .26555 L
.576 .26551 L
.58 .26544 L
.584 .26535 L
.588 .26526 L
.592 .26519 L
.596 .26516 L
.6 .26516 L
Mistroke
.604 .26518 L
.608 .2652 L
.612 .26521 L
.616 .2652 L
.62 .26517 L
.624 .26513 L
.628 .2651 L
.632 .26509 L
.636 .26508 L
.64 .26506 L
.644 .26504 L
.648 .26499 L
.652 .26493 L
.656 .26488 L
.66 .26484 L
.664 .26482 L
.668 .26482 L
.672 .26483 L
.676 .26483 L
.68 .26483 L
.684 .26481 L
.688 .26478 L
.692 .26475 L
.696 .26472 L
.7 .26469 L
.704 .26465 L
.708 .26461 L
.712 .26456 L
.716 .26453 L
.72 .26451 L
.724 .2645 L
.728 .26451 L
.732 .26452 L
.736 .26452 L
.74 .26451 L
.744 .26447 L
.748 .26442 L
.752 .26436 L
.756 .26432 L
.76 .26428 L
.764 .26426 L
.768 .26425 L
.772 .26424 L
.776 .26424 L
.78 .26424 L
.784 .26423 L
.788 .26421 L
.792 .26418 L
.796 .26414 L
.8 .26409 L
Mistroke
.804 .26404 L
.808 .264 L
.812 .26398 L
.816 .26397 L
.82 .26398 L
.824 .26399 L
.828 .26398 L
.832 .26396 L
.836 .26392 L
.84 .26387 L
.844 .26382 L
.848 .26378 L
.852 .26376 L
.856 .26375 L
.86 .26374 L
.864 .26374 L
.868 .26373 L
.872 .26371 L
.876 .26368 L
.88 .26365 L
.884 .26361 L
.888 .26357 L
.892 .26354 L
.896 .26353 L
.9 .26352 L
.904 .2635 L
.908 .26349 L
.912 .26346 L
.916 .26344 L
.92 .26341 L
.924 .26338 L
.928 .26335 L
.932 .26333 L
.936 .26331 L
.94 .26329 L
.944 .26327 L
.948 .26325 L
.952 .26322 L
.956 .2632 L
.96 .26317 L
.964 .26315 L
.968 .26312 L
.972 .26311 L
.976 .26308 L
.98 .26307 L
.984 .26304 L
.988 .26302 L
.992 .26299 L
.996 .26297 L
1 .26293 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15521 L
.012 .15284 L
.016 .14921 L
.02 .14446 L
.024 .14016 L
.028 .13638 L
.032 .1325 L
.036 .12864 L
.04 .12493 L
.044 .12147 L
.048 .11813 L
.052 .115 L
.056 .11203 L
.06 .10929 L
.064 .1067 L
.068 .10428 L
.072 .10197 L
.076 .09975 L
.08 .09756 L
.084 .09538 L
.088 .09315 L
.092 .09085 L
.096 .08845 L
.1 .08596 L
.104 .08336 L
.108 .0807 L
.112 .07798 L
.116 .07528 L
.12 .07261 L
.124 .07003 L
.128 .06757 L
.132 .06527 L
.136 .06312 L
.14 .06114 L
.144 .05931 L
.148 .05761 L
.152 .05603 L
.156 .05453 L
.16 .0531 L
.164 .05174 L
.168 .05046 L
.172 .04927 L
.176 .0482 L
.18 .04727 L
.184 .04647 L
.188 .04583 L
.192 .04531 L
.196 .04488 L
.2 .0445 L
Mistroke
.204 .0441 L
.208 .04363 L
.212 .04303 L
.216 .04229 L
.22 .04138 L
.224 .04034 L
.228 .0392 L
.232 .03802 L
.236 .03686 L
.24 .03576 L
.244 .03478 L
.248 .03394 L
.252 .03323 L
.256 .03263 L
.26 .03212 L
.264 .03166 L
.268 .03122 L
.272 .03077 L
.276 .0303 L
.28 .0298 L
.284 .02929 L
.288 .02875 L
.292 .02822 L
.296 .02768 L
.3 .02718 L
.304 .02671 L
.308 .02632 L
.312 .02603 L
.316 .02586 L
.32 .02585 L
.324 .026 L
.328 .02629 L
.332 .02668 L
.336 .02712 L
.34 .02755 L
.344 .0279 L
.348 .02814 L
.352 .02826 L
.356 .02827 L
.36 .02821 L
.364 .02815 L
.368 .02812 L
.372 .02816 L
.376 .02827 L
.38 .02842 L
.384 .02857 L
.388 .02867 L
.392 .02869 L
.396 .02862 L
.4 .02845 L
Mistroke
.404 .02824 L
.408 .02803 L
.412 .02784 L
.416 .02773 L
.42 .02768 L
.424 .02769 L
.428 .02774 L
.432 .0278 L
.436 .02785 L
.44 .02789 L
.444 .02793 L
.448 .02799 L
.452 .02806 L
.456 .02816 L
.46 .02827 L
.464 .0284 L
.468 .0285 L
.472 .02856 L
.476 .02856 L
.48 .0285 L
.484 .02838 L
.488 .02823 L
.492 .02807 L
.496 .02794 L
.5 .02785 L
.504 .02783 L
.508 .02788 L
.512 .02799 L
.516 .02813 L
.52 .02827 L
.524 .02839 L
.528 .02845 L
.532 .02847 L
.536 .02845 L
.54 .02841 L
.544 .02837 L
.548 .02833 L
.552 .02831 L
.556 .02828 L
.56 .02824 L
.564 .0282 L
.568 .02816 L
.572 .02815 L
.576 .02817 L
.58 .02824 L
.584 .02833 L
.588 .02842 L
.592 .02848 L
.596 .0285 L
.6 .02847 L
Mistroke
.604 .02842 L
.608 .02837 L
.612 .02834 L
.616 .02834 L
.62 .02836 L
.624 .02838 L
.628 .02839 L
.632 .02838 L
.636 .02837 L
.64 .02837 L
.644 .02838 L
.648 .02842 L
.652 .02847 L
.656 .02851 L
.66 .02854 L
.664 .02854 L
.668 .02851 L
.672 .02848 L
.676 .02845 L
.68 .02844 L
.684 .02844 L
.688 .02845 L
.692 .02847 L
.696 .02848 L
.7 .0285 L
.704 .02852 L
.708 .02855 L
.712 .02859 L
.716 .02861 L
.72 .02862 L
.724 .02861 L
.728 .02857 L
.732 .02853 L
.736 .0285 L
.74 .0285 L
.744 .02852 L
.748 .02856 L
.752 .02861 L
.756 .02866 L
.76 .02868 L
.764 .02869 L
.768 .02867 L
.772 .02865 L
.776 .02862 L
.78 .02861 L
.784 .0286 L
.788 .02861 L
.792 .02863 L
.796 .02866 L
.8 .0287 L
Mistroke
.804 .02873 L
.808 .02875 L
.812 .02875 L
.816 .02873 L
.82 .02871 L
.824 .02869 L
.828 .02869 L
.832 .02869 L
.836 .02871 L
.84 .02873 L
.844 .02876 L
.848 .02878 L
.852 .0288 L
.856 .02881 L
.86 .0288 L
.864 .02879 L
.868 .02878 L
.872 .02877 L
.876 .02877 L
.88 .02878 L
.884 .0288 L
.888 .02883 L
.892 .02886 L
.896 .02888 L
.9 .02888 L
.904 .02887 L
.908 .02885 L
.912 .02884 L
.916 .02884 L
.92 .02885 L
.924 .02887 L
.928 .02889 L
.932 .02892 L
.936 .02893 L
.94 .02894 L
.944 .02894 L
.948 .02893 L
.952 .02892 L
.956 .02891 L
.96 .02891 L
.964 .02893 L
.968 .02895 L
.972 .02898 L
.976 .02899 L
.98 .02901 L
.984 .029 L
.988 .029 L
.992 .02899 L
.996 .02899 L
1 .02898 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`04001oo`00001[Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`D006Yoo`000goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20002Ool00`00Oomoo`1XOol000Yoo`04
001oogoo0008Ool01000Oomoo`0017oo00D007ooOomoo`0000Aoo`03001oogoo06Moo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P000goo0P00J7oo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool00`00Oomoo`020004Ool01000Oomoogoo0`00HWoo000;Ool2
000:Ool20003Ool30003Ool00`00Oomoo`03Ool01`00Oomoogoo001oo`00069oo`002goo0P0017oo
00<007ooOol00goo0P000goo0`000goo0P001Goo00<007oo00000goo00<007ooOol0Ggoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Ioo`03001oogoo009oo`03001o
o`00008000Aoo`8000Moo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000=oo`D000=oo`80
00Aoo`8000Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool20003Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007oo
Ool0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo009o
o`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2000<Ool01@00Oomoogoo00000Woo00@007ooOol000Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2000<Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol017oo00@0
07ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool0
0`00Oomoo`0;Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool01000Oomoogoo10000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomo
o`000Woo00@007ooOol000=oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P00
2Woo0P0017oo00<007ooOol00Woo0P0037oo0`0017oo00@007ooOol000Ioo`8000Aoo`04001oogoo
0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol0
00Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomo
o`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007oo
Ool03Woo00<007ooOol00Woo00<007oo0000EWoo000ROol2000@Ool01000Oomoo`000Woo00<007oo
Ool0E7oo000ROomS000<Ool0029oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
001oo`0000=oo`@000=oo`03001oogoo00<00003Ool0000000800003Ool00000009oo`<00005Ool0
0000001oo`0200000goo0000000700000goo0000000300000goo0000000G000<Ool0029oo`80015o
o`8000]oo`04001oo`00Ool30002Ool20002Ool20003Ool20002Ool00`00Oomoo`02000017oo0000
07oo0P0000=oo`0000000Woo00@007ooOol0009oo`03001oogoo00Eoo`07001oogoo001oo`00Ool0
0P0000Aoo`00Ool000ioo`008Woo00<007ooOol07Goo0P000goo00<007ooOol0Agoo000ROol2001]
Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0K7oo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2
001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<0
07ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04
001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool0
00Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007oo
Ool000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo
0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`80
06eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo
008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo
0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00
KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo
0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomo
o`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@00
0Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo
00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01P00Oomoo`00Ool000=oo`03001oogoo00@006Eoo`000goo1@000Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol000=oo`<0069oo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P0017oo0`0017oo0`0017oo0P00
1goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@00
0Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`04
0003Ool00`00Oomoo`05Ool300000goo001oo`02Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool0
0`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`001Woo00<007ooOol01goo0`000goo00@007ooOol0009oo`03001o
ogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@0
07ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03
001oogoo00Uoo`D0009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03
Ool002Qoo`03001oogoo00Uoo`/000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo
00<007ooOol017oo00<007oo0000A`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@00
0goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Ao
o`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<0
07ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
2goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1VOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yo
o`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P00
17oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<0
07ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`00
2goo00<007ooOol00P007Goo1P001Woo10001Goo0P00?goo000:Ool01000Oomoo`002goo00@007oo
Ool001Qoo`H000Eoo`L000=oo`H00003Ool00000038000aoo`002Woo00@007ooOol000Moo`@000=o
o`03001oogoo011oo`H005aoo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8000ioo`@0065o
o`002goo0P0027oo1@000Woo00<007ooOol02goo0`00I7oo000LOol00`00Oomoo`09Ool20002Ool3
0004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool2
0005Ool50002Ool30004Ool20006Ool001aoo`8000Uoo`80009oo`05001oogooOol00002Ool01000
Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo0000
0goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007oo
Ool01Woo0P0027oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00=oo`0077oo00<007ooOol017oo0P002Woo00@007ooOol0009oo`03001oogoo00Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol0
17oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P0017oo0P001goo10000goo00@007ooOol0
00Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomo
ogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo009oo`03001oogoo00Moo`03001o
ogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03
001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`80009oo`03001oogoo00Qo
o`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool3
0004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`04001oogoo001aOol001aoo`<0
079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo
00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:
Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Ao
o`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol0
0Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo009oo`03001o
ogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03
001oogoo009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`00
17oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool0
0`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo
00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(24048\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .08228 m
.008 .08394 L
.012 .08805 L
.016 .095 L
.02 .10421 L
.024 .11539 L
.028 .12779 L
.032 .14079 L
.036 .15337 L
.04 .16494 L
.044 .17477 L
.048 .18242 L
.052 .18743 L
.056 .18978 L
.06 .1896 L
.064 .18738 L
.068 .18374 L
.072 .17954 L
.076 .17568 L
.08 .17305 L
.084 .17238 L
.088 .17423 L
.092 .17882 L
.096 .18606 L
.1 .19552 L
.104 .2065 L
.108 .21813 L
.112 .22951 L
.116 .23986 L
.12 .24865 L
.124 .25566 L
.128 .26104 L
.132 .26524 L
.136 .26899 L
.14 .27306 L
.144 .27816 L
.148 .2847 L
.152 .29268 L
.156 .30165 L
.16 .31071 L
.164 .31872 L
.168 .32447 L
.172 .32695 L
.176 .32554 L
.18 .32022 L
.184 .31161 L
.188 .30092 L
.192 .28977 L
.196 .27992 L
.2 .27289 L
Mistroke
.204 .26969 L
.208 .27064 L
.212 .27529 L
.216 .28262 L
.22 .2912 L
.224 .29956 L
.228 .30645 L
.232 .31108 L
.236 .31326 L
.24 .31329 L
.244 .31186 L
.248 .3098 L
.252 .30779 L
.256 .30622 L
.26 .30513 L
.264 .30434 L
.268 .30365 L
.272 .30304 L
.276 .30276 L
.28 .30334 L
.284 .30535 L
.288 .30921 L
.292 .31489 L
.296 .32179 L
.3 .32879 L
.304 .33444 L
.308 .33736 L
.312 .33668 L
.316 .3324 L
.32 .32547 L
.324 .31765 L
.328 .31105 L
.332 .30748 L
.336 .30786 L
.34 .31194 L
.344 .31831 L
.348 .32484 L
.352 .32938 L
.356 .33043 L
.36 .32763 L
.364 .32189 L
.368 .31502 L
.372 .30917 L
.376 .30605 L
.38 .30643 L
.384 .30994 L
.388 .3152 L
.392 .32042 L
.396 .324 L
.4 .32507 L
Mistroke
.404 .32372 L
.408 .32087 L
.412 .31784 L
.416 .3158 L
.42 .3154 L
.424 .31659 L
.428 .31871 L
.432 .32083 L
.436 .32217 L
.44 .32234 L
.444 .32138 L
.448 .31967 L
.452 .3177 L
.456 .31591 L
.46 .31464 L
.464 .31407 L
.468 .31431 L
.472 .31538 L
.476 .31721 L
.48 .3195 L
.484 .32167 L
.488 .32303 L
.492 .32302 L
.496 .32153 L
.5 .31904 L
.504 .3165 L
.508 .31495 L
.512 .31507 L
.516 .31678 L
.52 .31924 L
.524 .32115 L
.528 .32147 L
.532 .31995 L
.536 .31736 L
.54 .31507 L
.544 .31439 L
.548 .31582 L
.552 .31876 L
.556 .32181 L
.56 .32341 L
.564 .32268 L
.568 .31996 L
.572 .31664 L
.576 .31443 L
.58 .31442 L
.584 .31649 L
.588 .31941 L
.592 .32156 L
.596 .32183 L
.6 .32019 L
Mistroke
.604 .31766 L
.608 .31576 L
.612 .31557 L
.616 .31719 L
.62 .31962 L
.624 .32143 L
.628 .32157 L
.632 .32003 L
.636 .31778 L
.64 .31615 L
.644 .31599 L
.648 .31726 L
.652 .31908 L
.656 .32038 L
.66 .32046 L
.664 .31942 L
.668 .31802 L
.672 .31717 L
.676 .31737 L
.68 .31843 L
.684 .31958 L
.688 .32003 L
.692 .31952 L
.696 .31842 L
.7 .31751 L
.704 .31735 L
.708 .31799 L
.712 .31896 L
.716 .31965 L
.72 .31967 L
.724 .31911 L
.728 .31834 L
.732 .31784 L
.736 .31786 L
.74 .31838 L
.744 .31907 L
.748 .31951 L
.752 .31942 L
.756 .31884 L
.76 .31815 L
.764 .31779 L
.768 .31801 L
.772 .31865 L
.776 .3193 L
.78 .31956 L
.784 .31931 L
.788 .31874 L
.792 .31818 L
.796 .31793 L
.8 .31813 L
Mistroke
.804 .31868 L
.808 .31932 L
.812 .31966 L
.816 .31941 L
.82 .31866 L
.824 .31785 L
.828 .31759 L
.832 .31816 L
.836 .3192 L
.84 .31995 L
.844 .31988 L
.848 .31902 L
.852 .31807 L
.856 .31777 L
.86 .31817 L
.864 .31886 L
.868 .31923 L
.872 .31906 L
.876 .31879 L
.88 .3188 L
.884 .31906 L
.888 .31927 L
.892 .31903 L
.896 .31839 L
.9 .31799 L
.904 .31814 L
.908 .31875 L
.912 .31946 L
.916 .31964 L
.92 .31926 L
.924 .31882 L
.928 .3185 L
.932 .31843 L
.936 .31862 L
.94 .31865 L
.944 .31868 L
.948 .31899 L
.952 .31922 L
.956 .3193 L
.96 .3192 L
.964 .31867 L
.968 .31832 L
.972 .3186 L
.976 .31893 L
.98 .31919 L
.984 .31925 L
.988 .31866 L
.992 .31833 L
.996 .31878 L
1 .31919 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .21532 m
.008 .21298 L
.012 .21229 L
.016 .21325 L
.02 .21368 L
.024 .21363 L
.028 .21381 L
.032 .21424 L
.036 .21463 L
.04 .21504 L
.044 .21552 L
.048 .21615 L
.052 .21686 L
.056 .21772 L
.06 .21871 L
.064 .21989 L
.068 .22122 L
.072 .22274 L
.076 .2244 L
.08 .22621 L
.084 .2281 L
.088 .23007 L
.092 .23205 L
.096 .23401 L
.1 .2359 L
.104 .23771 L
.108 .2394 L
.112 .24097 L
.116 .24243 L
.12 .24378 L
.124 .24504 L
.128 .24622 L
.132 .24734 L
.136 .24841 L
.14 .24943 L
.144 .25038 L
.148 .25124 L
.152 .25202 L
.156 .25268 L
.16 .25322 L
.164 .25366 L
.168 .25402 L
.172 .25432 L
.176 .25462 L
.18 .25496 L
.184 .25537 L
.188 .25589 L
.192 .25655 L
.196 .25732 L
.2 .25818 L
Mistroke
.204 .2591 L
.208 .26003 L
.212 .26092 L
.216 .26173 L
.22 .26244 L
.224 .26304 L
.228 .26353 L
.232 .26394 L
.236 .2643 L
.24 .26463 L
.244 .26496 L
.248 .26531 L
.252 .26567 L
.256 .26606 L
.26 .26646 L
.264 .26687 L
.268 .26728 L
.272 .26767 L
.276 .26803 L
.28 .26834 L
.284 .26859 L
.288 .26873 L
.292 .26877 L
.296 .26869 L
.3 .26849 L
.304 .26819 L
.308 .26783 L
.312 .26746 L
.316 .26712 L
.32 .26686 L
.324 .26669 L
.328 .26662 L
.332 .26663 L
.336 .26667 L
.34 .2667 L
.344 .26669 L
.348 .26662 L
.352 .26651 L
.356 .26637 L
.36 .26624 L
.364 .26617 L
.368 .26617 L
.372 .26624 L
.376 .26638 L
.38 .26653 L
.384 .26668 L
.388 .26679 L
.392 .26685 L
.396 .26684 L
.4 .2668 L
Mistroke
.404 .26672 L
.408 .26665 L
.412 .26658 L
.416 .26653 L
.42 .26647 L
.424 .2664 L
.428 .26632 L
.432 .26622 L
.436 .26611 L
.44 .26601 L
.444 .26592 L
.448 .26588 L
.452 .26589 L
.456 .26594 L
.46 .26603 L
.464 .26614 L
.468 .26624 L
.472 .26631 L
.476 .26634 L
.48 .26631 L
.484 .26622 L
.488 .2661 L
.492 .26597 L
.496 .26584 L
.5 .26574 L
.504 .26569 L
.508 .26567 L
.512 .26568 L
.516 .26571 L
.52 .26573 L
.524 .26574 L
.528 .26574 L
.532 .26575 L
.536 .26575 L
.54 .26576 L
.544 .26576 L
.548 .26574 L
.552 .26569 L
.556 .26562 L
.56 .26553 L
.564 .26544 L
.568 .26538 L
.572 .26536 L
.576 .26537 L
.58 .2654 L
.584 .26542 L
.588 .26543 L
.592 .26541 L
.596 .26537 L
.6 .26534 L
Mistroke
.604 .26531 L
.608 .26529 L
.612 .26528 L
.616 .26526 L
.62 .26523 L
.624 .26518 L
.628 .26513 L
.632 .26508 L
.636 .26504 L
.64 .26503 L
.644 .26503 L
.648 .26504 L
.652 .26505 L
.656 .26504 L
.66 .26502 L
.664 .26498 L
.668 .26495 L
.672 .26492 L
.676 .26488 L
.68 .26485 L
.684 .26481 L
.688 .26477 L
.692 .26473 L
.696 .26471 L
.7 .26471 L
.704 .26472 L
.708 .26473 L
.712 .26473 L
.716 .26471 L
.72 .26467 L
.724 .26461 L
.728 .26455 L
.732 .26451 L
.736 .26447 L
.74 .26446 L
.744 .26446 L
.748 .26446 L
.752 .26446 L
.756 .26445 L
.76 .26444 L
.764 .26441 L
.768 .26437 L
.772 .26433 L
.776 .26428 L
.78 .26424 L
.784 .26421 L
.788 .2642 L
.792 .26419 L
.796 .26419 L
.8 .26419 L
Mistroke
.804 .26418 L
.808 .26415 L
.812 .26412 L
.816 .26407 L
.82 .26403 L
.824 .264 L
.828 .26397 L
.832 .26395 L
.836 .26394 L
.84 .26393 L
.844 .26393 L
.848 .26392 L
.852 .2639 L
.856 .26386 L
.86 .26382 L
.864 .26378 L
.868 .26374 L
.872 .26372 L
.876 .2637 L
.88 .2637 L
.884 .2637 L
.888 .26368 L
.892 .26366 L
.896 .26363 L
.9 .26359 L
.904 .26355 L
.908 .26352 L
.912 .26349 L
.916 .26348 L
.92 .26347 L
.924 .26346 L
.928 .26344 L
.932 .26342 L
.936 .26339 L
.94 .26336 L
.944 .26332 L
.948 .2633 L
.952 .26327 L
.956 .26326 L
.96 .26324 L
.964 .26323 L
.968 .26321 L
.972 .26319 L
.976 .26315 L
.98 .26312 L
.984 .26309 L
.988 .26307 L
.992 .26305 L
.996 .26304 L
1 .26301 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15432 L
.012 .14928 L
.016 .14388 L
.02 .1381 L
.024 .13265 L
.028 .12771 L
.032 .12305 L
.036 .11868 L
.04 .11458 L
.044 .11083 L
.048 .1073 L
.052 .10401 L
.056 .10084 L
.06 .0978 L
.064 .09481 L
.068 .09186 L
.072 .08889 L
.076 .08592 L
.08 .08293 L
.084 .07996 L
.088 .07702 L
.092 .07416 L
.096 .0714 L
.1 .06878 L
.104 .06632 L
.108 .06405 L
.112 .06196 L
.116 .06004 L
.12 .05827 L
.124 .05664 L
.128 .0551 L
.132 .05365 L
.136 .05228 L
.14 .05098 L
.144 .04977 L
.148 .04866 L
.152 .04767 L
.156 .04682 L
.16 .04611 L
.164 .04554 L
.168 .04508 L
.172 .04468 L
.176 .04429 L
.18 .04385 L
.184 .04331 L
.188 .04263 L
.192 .0418 L
.196 .04082 L
.2 .03973 L
Mistroke
.204 .03856 L
.208 .03738 L
.212 .03625 L
.216 .03522 L
.22 .03431 L
.224 .03354 L
.228 .03291 L
.232 .03237 L
.236 .0319 L
.24 .03146 L
.244 .03103 L
.248 .03058 L
.252 .0301 L
.256 .0296 L
.26 .02907 L
.264 .02853 L
.268 .028 L
.272 .02749 L
.276 .02702 L
.28 .02661 L
.284 .02629 L
.288 .02608 L
.292 .02601 L
.296 .02609 L
.3 .02631 L
.304 .02666 L
.308 .02708 L
.312 .02752 L
.316 .02792 L
.32 .02822 L
.324 .02841 L
.328 .02847 L
.332 .02845 L
.336 .02838 L
.34 .02832 L
.344 .0283 L
.348 .02836 L
.352 .02848 L
.356 .02863 L
.36 .02876 L
.364 .02883 L
.368 .02881 L
.372 .0287 L
.376 .02851 L
.38 .02829 L
.384 .02808 L
.388 .02792 L
.392 .02783 L
.396 .02781 L
.4 .02785 L
Mistroke
.404 .02791 L
.408 .02798 L
.412 .02804 L
.416 .02809 L
.42 .02814 L
.424 .0282 L
.428 .02828 L
.432 .02838 L
.436 .02849 L
.44 .0286 L
.444 .02868 L
.448 .02871 L
.452 .02868 L
.456 .02859 L
.46 .02846 L
.464 .0283 L
.468 .02815 L
.472 .02804 L
.476 .02798 L
.48 .028 L
.484 .02808 L
.488 .02821 L
.492 .02836 L
.496 .02849 L
.5 .02859 L
.504 .02863 L
.508 .02863 L
.512 .02859 L
.516 .02854 L
.52 .0285 L
.524 .02846 L
.528 .02843 L
.532 .0284 L
.536 .02837 L
.54 .02834 L
.544 .02832 L
.548 .02832 L
.552 .02836 L
.556 .02843 L
.56 .02852 L
.564 .0286 L
.568 .02865 L
.572 .02865 L
.576 .02862 L
.58 .02857 L
.584 .02852 L
.588 .02849 L
.592 .02848 L
.596 .0285 L
.6 .02852 L
Mistroke
.604 .02854 L
.608 .02854 L
.612 .02854 L
.616 .02854 L
.62 .02855 L
.624 .02858 L
.628 .02863 L
.632 .02867 L
.636 .02869 L
.64 .02869 L
.644 .02866 L
.648 .02863 L
.652 .0286 L
.656 .02858 L
.66 .02859 L
.664 .0286 L
.668 .02862 L
.672 .02865 L
.676 .02867 L
.68 .0287 L
.684 .02872 L
.688 .02875 L
.692 .02876 L
.696 .02876 L
.7 .02874 L
.704 .02871 L
.708 .02868 L
.712 .02866 L
.716 .02866 L
.72 .02869 L
.724 .02873 L
.728 .02878 L
.732 .02882 L
.736 .02884 L
.74 .02884 L
.744 .02882 L
.748 .0288 L
.752 .02877 L
.756 .02876 L
.76 .02875 L
.764 .02876 L
.768 .02878 L
.772 .02882 L
.776 .02886 L
.78 .02889 L
.784 .02891 L
.788 .02891 L
.792 .02889 L
.796 .02885 L
.8 .02883 L
Mistroke
.804 .02882 L
.808 .02883 L
.812 .02887 L
.816 .02891 L
.82 .02894 L
.824 .02896 L
.828 .02896 L
.832 .02895 L
.836 .02893 L
.84 .02892 L
.844 .02892 L
.848 .02892 L
.852 .02894 L
.856 .02896 L
.86 .02898 L
.864 .02899 L
.868 .02901 L
.872 .02901 L
.876 .02901 L
.88 .029 L
.884 .029 L
.888 .029 L
.892 .02901 L
.896 .02902 L
.9 .02904 L
.904 .02904 L
.908 .02905 L
.912 .02906 L
.916 .02908 L
.92 .02908 L
.924 .02909 L
.928 .02909 L
.932 .02909 L
.936 .02908 L
.94 .02909 L
.944 .0291 L
.948 .02912 L
.952 .02913 L
.956 .02914 L
.96 .02915 L
.964 .02916 L
.968 .02916 L
.972 .02916 L
.976 .02915 L
.98 .02916 L
.984 .02916 L
.988 .02918 L
.992 .02919 L
.996 .02921 L
1 .02922 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=o
o`03001oogoo00<006aoo`002goo0P002Woo0P000goo0`000goo00<007oo0000K7oo000ROol3001/
Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`04001oogoo001[Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`800003Ool007oo06Yoo`000goo1@000Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20002Ool00`00Oomoo`1XOol000Yo
o`04001oogoo0008Ool01000Oomoo`0017oo00D007ooOomoo`0000=oo`03001oogoo06Qoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P000Woo00@007ooOomoo`8006Eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P000goo00<007oo0000
0P00IGoo000;Ool2000:Ool20003Ool30003Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`1ROol0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8000Qoo`03001oogoo069oo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20008Ool00`00Oomoo`02Ool30004Ool2
0007Ool30004Ool20004Ool20005Ool30003Ool30004Ool20003Ool50003Ool20004Ool20004Ool5
0002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol027oo00@007ooOol000=oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`00
0Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8000Uoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P002Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00Eo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool20004Ool00`00Oomoo`09Ool00`00Ool000030003Ool01000Oomoo`001goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol0009oo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogooOol007oo10000goo
00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo0P002goo0P001Woo00@007oo
Ool000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@0
07ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogoo
Ool007oo00001Woo00@007ooOol000Eoo`008Woo0P002goo1P0000=oo`0000000P0027oo00<007oo
Ool00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0
009oo`D000=oo`8000Ioo`008Woo00<007ooOol037oo00L007ooOomoo`00Ool0001IOol0029oo`80
00eoo`05001oogooOol00002Ool00`00Oomoo`1FOol0029oof<000aoo`008Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Ool007oo00000Woo0P000Woo0`0000=oo`000000100000=o
o`000000200000=oo`0000001`0000Aoo`00001oo`D00003Ool0000000T00003Ool00000014000ao
o`008Woo0P003goo0P002Woo00<007oo00000Woo0`0000Eoo`00000007oo00<0009oo`80009oo`80
0004Ool00000Ool3000017oo000007oo0P0000Eoo`00001oo`00009oo`03001oogoo00800005Ool0
0000Ool00006Ool00`00Oomoo`0COol0029oo`03001oogoo01]oo`8000=oo`03001oogoo04Uoo`00
8Woo0P00KGoo000ROol2001]Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001o
ogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`80
00Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo
0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=o
o`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eo
o`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool0
0`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^
Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0
029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04
001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo
06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
00Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool0
0`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`050008Ool30004Ool20007Ool30004
Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004
Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`04
001oogooOol40004Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@0
07ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000Ioo`03001oogoo00Aoo`<000Ioo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00
Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`07Ool30003
Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo
000XOol00`00Oomoo`09Ool80002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03
001oogoo00Uoo`03001oogoo00AoodX000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D0
00=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004
Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03
001oogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
00]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:
Ool20004Ool20002Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03
001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol0
00]oo`03001oogoo008001Yoo`D000Qoo`8004Yoo`002Woo00@007ooOol000]oo`04001oogoo000E
Ool70004Ool800000goo0000000m000<Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0=
Ool6001OOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2000;Ool4001TOol000]oo`8000Qo
o`D0009oo`03001oogoo00Qoo`<006Moo`0077oo00<007ooOol01goo0P0017oo0`0017oo0P002Goo
0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo
0`0017oo0P001Woo000LOol20006Ool20005Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00
Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo00Aoo`8000Yo
o`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001ao
o`03001oogoo00=oo`03001oogoo00Yoo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04
001oogoo0002Ool00`00Oomoo`03Ool001aoo`80009oo`8000Uoo`@000=oo`04001oogoo0009Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomo
o`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00
Ool40003Ool01000Oomoo`001Goo000LOol01@00Oomoogoo00002Woo00<007ooOol017oo00@007oo
Ool000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@0
07ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogoo
Ool007oo00001Woo00@007ooOol000Eoo`0077oo0P0000=oo`00Ool02Woo1@000goo0P002Woo00<0
07ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Io
o`<0009oo`D000=oo`8000Ioo`0077oo00<007oo0000LWoo000LOol2001cOol001aoofT000aoo`00
77oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03
001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007
Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]o
o`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`00
5goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001o
ogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<0
00=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo
00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;
Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001o
ogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03
001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(24215\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12221 m
.008 .12732 L
.012 .13191 L
.016 .1361 L
.02 .13984 L
.024 .14168 L
.028 .1417 L
.032 .14047 L
.036 .13828 L
.04 .1354 L
.044 .1324 L
.048 .13025 L
.052 .12958 L
.056 .13109 L
.06 .13517 L
.064 .14216 L
.068 .15191 L
.072 .16408 L
.076 .17794 L
.08 .19267 L
.084 .2073 L
.088 .22097 L
.092 .23299 L
.096 .24301 L
.1 .25098 L
.104 .25725 L
.108 .26243 L
.112 .26732 L
.116 .27269 L
.12 .27914 L
.124 .2869 L
.128 .29577 L
.132 .30508 L
.136 .31383 L
.14 .32085 L
.144 .32504 L
.148 .32556 L
.152 .3221 L
.156 .31496 L
.16 .30509 L
.164 .29394 L
.168 .28325 L
.172 .27468 L
.176 .26955 L
.18 .26853 L
.184 .27158 L
.188 .27794 L
.192 .28636 L
.196 .29533 L
.2 .30338 L
Mistroke
.204 .30943 L
.208 .31291 L
.212 .31388 L
.216 .31289 L
.22 .31077 L
.224 .30836 L
.228 .30627 L
.232 .30477 L
.236 .30385 L
.24 .30331 L
.244 .30299 L
.248 .30291 L
.252 .30337 L
.256 .30483 L
.26 .30775 L
.264 .31238 L
.268 .3185 L
.272 .32536 L
.276 .33172 L
.28 .33618 L
.284 .33754 L
.288 .33525 L
.292 .32968 L
.296 .32215 L
.3 .3146 L
.304 .30904 L
.308 .30696 L
.312 .30884 L
.316 .31396 L
.32 .32064 L
.324 .32667 L
.328 .3301 L
.332 .32978 L
.336 .32578 L
.34 .31934 L
.344 .31246 L
.348 .30726 L
.352 .30525 L
.356 .30688 L
.36 .31137 L
.364 .31711 L
.368 .32219 L
.372 .32514 L
.376 .32534 L
.38 .32321 L
.384 .31993 L
.388 .31691 L
.392 .31526 L
.396 .31541 L
.4 .31705 L
Mistroke
.404 .31936 L
.408 .32139 L
.412 .3224 L
.416 .32212 L
.42 .32074 L
.424 .31874 L
.428 .31669 L
.432 .31503 L
.436 .31404 L
.44 .31389 L
.444 .31461 L
.448 .31614 L
.452 .31823 L
.456 .32047 L
.46 .32229 L
.464 .3231 L
.468 .32253 L
.472 .32068 L
.476 .31816 L
.48 .31591 L
.484 .31483 L
.488 .31535 L
.492 .31718 L
.496 .31941 L
.5 .32095 L
.504 .32097 L
.508 .31942 L
.512 .31707 L
.516 .31518 L
.52 .31484 L
.524 .31637 L
.528 .31914 L
.532 .32182 L
.536 .32306 L
.54 .32219 L
.544 .31957 L
.548 .31647 L
.552 .3144 L
.556 .31439 L
.56 .31638 L
.564 .31925 L
.568 .32144 L
.572 .32184 L
.576 .32034 L
.58 .31787 L
.584 .31587 L
.588 .31545 L
.592 .31684 L
.596 .31922 L
.6 .32121 L
Mistroke
.604 .32168 L
.608 .32037 L
.612 .31806 L
.616 .31609 L
.62 .31554 L
.624 .31661 L
.628 .31859 L
.632 .32031 L
.636 .32086 L
.64 .32005 L
.644 .3185 L
.648 .31718 L
.652 .31683 L
.656 .31759 L
.66 .31889 L
.664 .3199 L
.668 .31999 L
.672 .31917 L
.676 .31802 L
.68 .31726 L
.684 .31731 L
.688 .31806 L
.692 .31902 L
.696 .31965 L
.7 .31967 L
.704 .31915 L
.708 .31841 L
.712 .31784 L
.716 .31771 L
.72 .31806 L
.724 .31868 L
.728 .31921 L
.732 .31936 L
.736 .31908 L
.74 .31856 L
.744 .31813 L
.748 .31802 L
.752 .31824 L
.756 .31864 L
.76 .31901 L
.764 .31918 L
.768 .31908 L
.772 .31877 L
.776 .31842 L
.78 .31821 L
.784 .31827 L
.788 .31855 L
.792 .31882 L
.796 .31891 L
.8 .3188 L
Mistroke
.804 .31866 L
.808 .31871 L
.812 .31888 L
.816 .31895 L
.82 .31873 L
.824 .31831 L
.828 .31808 L
.832 .31835 L
.836 .31898 L
.84 .3195 L
.844 .31942 L
.848 .31875 L
.852 .31804 L
.856 .31786 L
.86 .31835 L
.864 .31914 L
.868 .31958 L
.872 .31938 L
.876 .31879 L
.88 .31823 L
.884 .31806 L
.888 .31834 L
.892 .31876 L
.896 .31908 L
.9 .31928 L
.904 .31919 L
.908 .31892 L
.912 .31864 L
.916 .31835 L
.92 .31833 L
.924 .31865 L
.928 .3189 L
.932 .31903 L
.936 .319 L
.94 .31878 L
.944 .31881 L
.948 .31907 L
.952 .31905 L
.956 .31881 L
.96 .31844 L
.964 .31808 L
.968 .31841 L
.972 .31921 L
.976 .31961 L
.98 .31954 L
.984 .31896 L
.988 .3181 L
.992 .3181 L
.996 .31884 L
1 .31929 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .24549 m
.008 .24389 L
.012 .24304 L
.016 .24301 L
.02 .2426 L
.024 .24178 L
.028 .24098 L
.032 .24032 L
.036 .23973 L
.04 .23925 L
.044 .23893 L
.048 .23883 L
.052 .23893 L
.056 .23923 L
.06 .23969 L
.064 .24032 L
.068 .24105 L
.072 .24188 L
.076 .24273 L
.08 .24361 L
.084 .24447 L
.088 .24532 L
.092 .24615 L
.096 .24697 L
.1 .24777 L
.104 .24859 L
.108 .24939 L
.112 .2502 L
.116 .25098 L
.12 .25173 L
.124 .25242 L
.128 .25303 L
.132 .25355 L
.136 .25398 L
.14 .25433 L
.144 .25462 L
.148 .2549 L
.152 .2552 L
.156 .25556 L
.16 .25602 L
.164 .2566 L
.168 .25732 L
.172 .25814 L
.176 .25903 L
.18 .25996 L
.184 .26086 L
.188 .26171 L
.192 .26247 L
.196 .26311 L
.2 .26365 L
Mistroke
.204 .26409 L
.208 .26446 L
.212 .26479 L
.216 .26511 L
.22 .26544 L
.224 .26579 L
.228 .26617 L
.232 .26656 L
.236 .26697 L
.24 .26737 L
.244 .26777 L
.248 .26814 L
.252 .26846 L
.256 .26872 L
.26 .2689 L
.264 .26898 L
.268 .26894 L
.272 .26879 L
.276 .26854 L
.28 .2682 L
.284 .26783 L
.288 .26748 L
.292 .26717 L
.296 .26695 L
.3 .26683 L
.304 .2668 L
.308 .26683 L
.312 .26687 L
.316 .26689 L
.32 .26687 L
.324 .26679 L
.328 .26667 L
.332 .26654 L
.336 .26644 L
.34 .26639 L
.344 .26642 L
.348 .26652 L
.352 .26667 L
.356 .26683 L
.36 .26697 L
.364 .26705 L
.368 .26708 L
.372 .26705 L
.376 .26699 L
.38 .2669 L
.384 .26682 L
.388 .26675 L
.392 .26669 L
.396 .26663 L
.4 .26656 L
Mistroke
.404 .26648 L
.408 .26638 L
.412 .26627 L
.416 .26618 L
.42 .26612 L
.424 .2661 L
.428 .26613 L
.432 .2662 L
.436 .2663 L
.44 .2664 L
.444 .26649 L
.448 .26655 L
.452 .26654 L
.456 .26649 L
.46 .26638 L
.464 .26625 L
.468 .26611 L
.472 .266 L
.476 .26592 L
.48 .26588 L
.484 .26588 L
.488 .2659 L
.492 .26593 L
.496 .26595 L
.5 .26597 L
.504 .26597 L
.508 .26597 L
.512 .26597 L
.516 .26597 L
.52 .26596 L
.524 .26592 L
.528 .26587 L
.532 .26579 L
.536 .2657 L
.54 .26563 L
.544 .26559 L
.548 .26557 L
.552 .26559 L
.556 .26562 L
.56 .26564 L
.564 .26564 L
.568 .26562 L
.572 .26558 L
.576 .26554 L
.58 .26551 L
.584 .26549 L
.588 .26547 L
.592 .26545 L
.596 .26542 L
.6 .26538 L
Mistroke
.604 .26533 L
.608 .26528 L
.612 .26525 L
.616 .26524 L
.62 .26524 L
.624 .26525 L
.628 .26526 L
.632 .26525 L
.636 .26522 L
.64 .26519 L
.644 .26515 L
.648 .26511 L
.652 .26507 L
.656 .26504 L
.66 .265 L
.664 .26497 L
.668 .26494 L
.672 .26493 L
.676 .26493 L
.68 .26494 L
.684 .26494 L
.688 .26493 L
.692 .26491 L
.696 .26486 L
.7 .26481 L
.704 .26475 L
.708 .26471 L
.712 .26468 L
.716 .26467 L
.72 .26467 L
.724 .26467 L
.728 .26467 L
.732 .26466 L
.736 .26464 L
.74 .26461 L
.744 .26457 L
.748 .26452 L
.752 .26448 L
.756 .26444 L
.76 .26441 L
.764 .2644 L
.768 .2644 L
.772 .26441 L
.776 .26441 L
.78 .26439 L
.784 .26436 L
.788 .26431 L
.792 .26426 L
.796 .26422 L
.8 .26419 L
Mistroke
.804 .26418 L
.808 .26417 L
.812 .26416 L
.816 .26415 L
.82 .26413 L
.824 .26411 L
.828 .26408 L
.832 .26405 L
.836 .26402 L
.84 .26398 L
.844 .26396 L
.848 .26394 L
.852 .26392 L
.856 .2639 L
.86 .26389 L
.864 .26387 L
.868 .26385 L
.872 .26383 L
.876 .2638 L
.88 .26377 L
.884 .26374 L
.888 .26371 L
.892 .26369 L
.896 .26367 L
.9 .26365 L
.904 .26364 L
.908 .26362 L
.912 .2636 L
.916 .26358 L
.92 .26354 L
.924 .26351 L
.928 .26347 L
.932 .26345 L
.936 .26343 L
.94 .26342 L
.944 .26341 L
.948 .2634 L
.952 .26337 L
.956 .26334 L
.96 .26331 L
.964 .26328 L
.968 .26325 L
.972 .26323 L
.976 .2632 L
.98 .2632 L
.984 .26318 L
.988 .26317 L
.992 .26314 L
.996 .26312 L
1 .26307 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15776 L
.012 .15105 L
.016 .14548 L
.02 .14099 L
.024 .13606 L
.028 .13075 L
.032 .12557 L
.036 .1205 L
.04 .11537 L
.044 .11022 L
.048 .10511 L
.052 .10009 L
.056 .09517 L
.06 .0904 L
.064 .08582 L
.068 .0815 L
.072 .07745 L
.076 .07372 L
.08 .0703 L
.084 .06722 L
.088 .06443 L
.092 .06194 L
.096 .05968 L
.1 .05765 L
.104 .05578 L
.108 .05407 L
.112 .05249 L
.116 .05105 L
.12 .04974 L
.124 .04857 L
.128 .04756 L
.132 .04671 L
.136 .04601 L
.14 .04545 L
.144 .04498 L
.148 .04456 L
.152 .04412 L
.156 .04361 L
.16 .04299 L
.164 .04222 L
.168 .0413 L
.172 .04025 L
.176 .0391 L
.18 .03792 L
.184 .03676 L
.188 .03568 L
.192 .03471 L
.196 .03389 L
.2 .0332 L
Mistroke
.204 .03263 L
.208 .03214 L
.212 .0317 L
.216 .03128 L
.22 .03085 L
.224 .03039 L
.228 .0299 L
.232 .02938 L
.236 .02885 L
.24 .02832 L
.244 .02781 L
.248 .02733 L
.252 .0269 L
.256 .02656 L
.26 .02631 L
.264 .02619 L
.268 .0262 L
.272 .02637 L
.276 .02666 L
.28 .02706 L
.284 .02749 L
.288 .02791 L
.292 .02827 L
.296 .02852 L
.3 .02865 L
.304 .02867 L
.308 .02861 L
.312 .02853 L
.316 .02848 L
.32 .02849 L
.324 .02856 L
.328 .02869 L
.332 .02883 L
.336 .02894 L
.34 .02897 L
.344 .02891 L
.348 .02876 L
.352 .02855 L
.356 .02833 L
.36 .02814 L
.364 .02801 L
.368 .02795 L
.372 .02796 L
.376 .02802 L
.38 .0281 L
.384 .02817 L
.388 .02824 L
.392 .02829 L
.396 .02835 L
.4 .02841 L
Mistroke
.404 .02849 L
.408 .02859 L
.412 .0287 L
.416 .02879 L
.42 .02885 L
.424 .02885 L
.428 .02879 L
.432 .02868 L
.436 .02853 L
.44 .02838 L
.444 .02824 L
.448 .02816 L
.452 .02814 L
.456 .02818 L
.46 .02829 L
.464 .02843 L
.468 .02858 L
.472 .0287 L
.476 .02878 L
.48 .0288 L
.484 .02878 L
.488 .02873 L
.492 .02867 L
.496 .02862 L
.5 .02858 L
.504 .02855 L
.508 .02853 L
.512 .02851 L
.516 .02849 L
.52 .02848 L
.524 .0285 L
.528 .02855 L
.532 .02862 L
.536 .0287 L
.54 .02877 L
.544 .02881 L
.548 .0288 L
.552 .02876 L
.556 .0287 L
.56 .02865 L
.564 .02863 L
.568 .02863 L
.572 .02866 L
.576 .02868 L
.58 .0287 L
.584 .0287 L
.588 .0287 L
.592 .0287 L
.596 .02872 L
.6 .02875 L
Mistroke
.604 .0288 L
.608 .02883 L
.612 .02885 L
.616 .02883 L
.62 .0288 L
.624 .02877 L
.628 .02874 L
.632 .02873 L
.636 .02874 L
.64 .02877 L
.644 .02879 L
.648 .02881 L
.652 .02884 L
.656 .02886 L
.66 .02888 L
.664 .0289 L
.668 .02891 L
.672 .02891 L
.676 .02888 L
.68 .02885 L
.684 .02882 L
.688 .02881 L
.692 .02882 L
.696 .02885 L
.7 .0289 L
.704 .02895 L
.708 .02899 L
.712 .029 L
.716 .02898 L
.72 .02896 L
.724 .02893 L
.728 .02891 L
.732 .0289 L
.736 .02891 L
.74 .02893 L
.744 .02896 L
.748 .02899 L
.752 .02902 L
.756 .02904 L
.76 .02905 L
.764 .02905 L
.768 .02903 L
.772 .029 L
.776 .02899 L
.78 .02898 L
.784 .02899 L
.788 .02902 L
.792 .02906 L
.796 .02909 L
.8 .02911 L
Mistroke
.804 .02912 L
.808 .02911 L
.812 .02909 L
.816 .02908 L
.82 .02907 L
.824 .02907 L
.828 .02908 L
.832 .0291 L
.836 .02913 L
.84 .02916 L
.844 .02918 L
.848 .02918 L
.852 .02917 L
.856 .02915 L
.86 .02914 L
.864 .02914 L
.868 .02915 L
.872 .02918 L
.876 .0292 L
.88 .02922 L
.884 .02923 L
.888 .02923 L
.892 .02922 L
.896 .02921 L
.9 .02921 L
.904 .02922 L
.908 .02924 L
.912 .02925 L
.916 .02927 L
.92 .02928 L
.924 .02928 L
.928 .02928 L
.932 .02928 L
.936 .02928 L
.94 .02929 L
.944 .0293 L
.948 .02932 L
.952 .02932 L
.956 .02933 L
.96 .02933 L
.964 .02934 L
.968 .02934 L
.972 .02935 L
.976 .02935 L
.98 .02937 L
.984 .02937 L
.988 .02939 L
.992 .02939 L
.996 .0294 L
1 .02939 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`80009oo`<006Qoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo1@0000=oo`00Ool0Igoo0003Ool5
0002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Eoo`03001oogoo06Eo
o`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01@00Oomoogoo00001Woo00<007ooOol0IGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`020005Ool00`00Oomoo`1U
Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008000Ioo`03001oogoo
06Aoo`002goo0P002Woo0P000goo0`000goo00<007ooOol01Goo00<007ooOol0I7oo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool20006Ool00`00Oomoo`1TOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P001Woo00<007ooOol017oo0`0017oo0P001goo0`00
17oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`00
17oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo009oo`06001oogoo
001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool20007Ool00`00Oomoo`06Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8000Qoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`03Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo
00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
0P0017oo00<007ooOol01goo00@007ooOomoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`000Woo00D007oo
Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000
Oomoo`001Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool20009Ool01000Oomoo`001Woo00@0
07ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001o
ogooOol007oo00001Woo00@007ooOol000Eoo`008Woo0P002Goo00<007ooOol01@000goo0P0027oo
00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`80
00Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol02Goo00<007ooOol00Woo00<007oo0000
Fgoo000ROol2000;Ool01000Oomoo`000Woo00<007ooOol0FGoo000ROomS000<Ool0029oo`05001o
ogooOol00003Ool01000Oomoogoo0P0000=oo`0000000goo0`0000=oo`00Ool00P0000Aoo`000000
009oo`<00004Ool00000Ool40002Ool200001Goo00000000Ool00P0000=oo`0000001P0000=oo`00
00007`0037oo000ROol2000<Ool2000;Ool01000Ool007oo0`000Woo0`0000=oo`0000000goo0P00
00Eoo`00000007oo00800003Ool00000009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007oo
Ool027oo00@007ooOol000Uoo`8000ioo`008Woo00<007ooOol067oo0`000Woo00<007ooOol0C7oo
000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<0
07ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo
0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogoo
Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P00
0goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eo
o`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol0
06ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06ao
o`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo
00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007oo
Ool0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Io
o`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo
009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Ao
o`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<0
00Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<0
00Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo
00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`00
00Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo2P001Woo00@007ooOol0009oo`03001o
ogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0
0goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol01goo1`00
0Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007oo
Oomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00@007ooOomo
odd000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=o
o`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool5
0003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qo
o`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo011o
o`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=o
o`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool20002Ool50002Ool0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00
Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo
0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003
Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomo
o`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
1Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eo
o`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo
0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P00
17oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008001Moo`H0
05Ioo`002Woo00@007ooOol000]oo`04001oogoo000BOol70004Oom;000<Ool000Yoo`04001oogoo
0007Ool40003Ool00`00Oomoo`0;Ool6001QOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2
0009Ool3001WOol000]oo`8000Qoo`D0009oo`03001oogoo00Ioo`<006Uoo`0077oo00<007ooOol0
1Goo0P001Woo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@00
0goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol20005Ool20006Ool01@00Oomoogoo
00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D0
07ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool0
01aoo`03001oogoo00=oo`03001oogoo00Yoo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo009oo`8000aoo`04001oogoo0002Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001o
ogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000=oo`03001o
ogoo00Moo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002
Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol01@00Oomo
ogoo00002Woo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomo
o`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomo
o`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P00
00=oo`0000002Woo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D0
00=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00@007oo0000
075oo`0077oo0`00LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
17oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol0
0Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo
009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool0
1000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000G
Ool00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007oo
Ool00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`80
07=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03
001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo
000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`80
07=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(24382\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .1572 m
.008 .15422 L
.012 .149 L
.016 .14218 L
.02 .13463 L
.024 .12719 L
.028 .12094 L
.032 .11682 L
.036 .11582 L
.04 .11805 L
.044 .12365 L
.048 .13216 L
.052 .14306 L
.056 .15541 L
.06 .1683 L
.064 .1809 L
.068 .19255 L
.072 .20298 L
.076 .21215 L
.08 .22044 L
.084 .22838 L
.088 .23667 L
.092 .24581 L
.096 .25618 L
.1 .26765 L
.104 .27976 L
.108 .29159 L
.112 .30203 L
.116 .30991 L
.12 .31424 L
.124 .31443 L
.128 .3105 L
.132 .3031 L
.136 .29348 L
.14 .28328 L
.144 .27427 L
.148 .26798 L
.152 .26547 L
.156 .26708 L
.16 .27244 L
.164 .28053 L
.168 .28992 L
.172 .29905 L
.176 .30657 L
.18 .31161 L
.184 .31388 L
.188 .31373 L
.192 .31188 L
.196 .30926 L
.2 .30666 L
Mistroke
.204 .30462 L
.208 .30334 L
.212 .30273 L
.216 .30259 L
.22 .30278 L
.224 .30333 L
.228 .30454 L
.232 .30682 L
.236 .31053 L
.24 .31576 L
.244 .32211 L
.248 .32867 L
.252 .33414 L
.256 .33719 L
.26 .3369 L
.264 .3331 L
.268 .32657 L
.272 .31885 L
.276 .31192 L
.28 .30761 L
.284 .30703 L
.288 .31024 L
.292 .31616 L
.296 .32286 L
.3 .32819 L
.304 .33039 L
.308 .32867 L
.312 .32354 L
.316 .31657 L
.32 .30995 L
.324 .30568 L
.328 .30499 L
.332 .30788 L
.336 .31321 L
.34 .31913 L
.344 .32379 L
.348 .32593 L
.352 .32526 L
.356 .32251 L
.36 .31899 L
.364 .31611 L
.368 .31485 L
.372 .31547 L
.376 .3175 L
.38 .31996 L
.384 .32188 L
.388 .32256 L
.392 .32183 L
.396 .31999 L
.4 .31768 L
Mistroke
.404 .31556 L
.408 .31412 L
.412 .31362 L
.416 .31405 L
.42 .3153 L
.424 .31714 L
.428 .31925 L
.432 .32122 L
.436 .32257 L
.44 .32287 L
.444 .32193 L
.448 .31994 L
.452 .3175 L
.456 .31549 L
.46 .31468 L
.464 .31541 L
.468 .31733 L
.472 .31953 L
.476 .32091 L
.48 .32078 L
.484 .31915 L
.488 .31685 L
.492 .31511 L
.496 .31496 L
.5 .31668 L
.504 .31954 L
.508 .32213 L
.512 .3231 L
.516 .32187 L
.52 .31896 L
.524 .31579 L
.528 .31393 L
.532 .31429 L
.536 .31663 L
.54 .31969 L
.544 .32183 L
.548 .32193 L
.552 .32006 L
.556 .31737 L
.56 .31543 L
.564 .31534 L
.568 .3171 L
.572 .31965 L
.576 .32151 L
.58 .32161 L
.584 .31992 L
.588 .31744 L
.592 .31559 L
.596 .3154 L
.6 .31689 L
Mistroke
.604 .31909 L
.608 .32069 L
.612 .32084 L
.616 .31962 L
.62 .3179 L
.624 .31678 L
.628 .31686 L
.632 .31798 L
.636 .31934 L
.64 .32006 L
.644 .31971 L
.648 .31855 L
.652 .31737 L
.656 .31694 L
.66 .3175 L
.664 .31865 L
.668 .31964 L
.672 .31986 L
.676 .31928 L
.68 .31834 L
.684 .31763 L
.688 .31755 L
.692 .31806 L
.696 .31879 L
.7 .31929 L
.704 .31927 L
.708 .31879 L
.712 .31817 L
.716 .31781 L
.72 .31795 L
.724 .31849 L
.728 .31908 L
.732 .31934 L
.736 .31911 L
.74 .31856 L
.744 .31804 L
.748 .31787 L
.752 .31814 L
.756 .31869 L
.76 .31918 L
.764 .31933 L
.768 .31901 L
.772 .31838 L
.776 .31783 L
.78 .31775 L
.784 .31828 L
.788 .31912 L
.792 .31972 L
.796 .3196 L
.8 .31879 L
Mistroke
.804 .31783 L
.808 .31741 L
.812 .3178 L
.816 .31873 L
.82 .31951 L
.824 .31965 L
.828 .31918 L
.832 .31852 L
.836 .31812 L
.84 .31815 L
.844 .31839 L
.848 .31862 L
.852 .31876 L
.856 .31883 L
.86 .3189 L
.864 .31898 L
.868 .31893 L
.872 .31874 L
.876 .31851 L
.88 .31831 L
.884 .31829 L
.888 .31852 L
.892 .31885 L
.896 .31919 L
.9 .31934 L
.904 .31904 L
.908 .3185 L
.912 .31804 L
.916 .31796 L
.92 .31851 L
.924 .31929 L
.928 .31961 L
.932 .31934 L
.936 .31863 L
.94 .318 L
.944 .31813 L
.948 .31874 L
.952 .31916 L
.956 .31919 L
.96 .31878 L
.964 .31835 L
.968 .31864 L
.972 .3192 L
.976 .31932 L
.98 .31901 L
.984 .31829 L
.988 .31775 L
.992 .31834 L
.996 .31935 L
1 .31978 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .26606 m
.008 .2682 L
.012 .26896 L
.016 .2684 L
.02 .26838 L
.024 .26887 L
.028 .26911 L
.032 .26915 L
.036 .26915 L
.04 .2691 L
.044 .26886 L
.048 .26846 L
.052 .2679 L
.056 .26721 L
.06 .2664 L
.064 .26551 L
.068 .26458 L
.072 .26364 L
.076 .26275 L
.08 .26192 L
.084 .26117 L
.088 .26053 L
.092 .25997 L
.096 .25949 L
.1 .25906 L
.104 .25868 L
.108 .25832 L
.112 .25799 L
.116 .25769 L
.12 .25745 L
.124 .25729 L
.128 .25726 L
.132 .25737 L
.136 .25765 L
.14 .25809 L
.144 .2587 L
.148 .25943 L
.152 .26024 L
.156 .26107 L
.16 .26188 L
.164 .26263 L
.168 .26329 L
.172 .26384 L
.176 .26429 L
.18 .26467 L
.184 .26499 L
.188 .26529 L
.192 .2656 L
.196 .26593 L
.2 .26629 L
Mistroke
.204 .26667 L
.208 .26706 L
.212 .26747 L
.216 .26787 L
.22 .26824 L
.224 .26857 L
.228 .26885 L
.232 .26905 L
.236 .26916 L
.24 .26917 L
.244 .26907 L
.248 .26886 L
.252 .26856 L
.256 .26821 L
.26 .26784 L
.264 .2675 L
.268 .26724 L
.272 .26707 L
.276 .26699 L
.28 .26699 L
.284 .26703 L
.288 .26708 L
.292 .26709 L
.296 .26705 L
.3 .26696 L
.304 .26683 L
.308 .26672 L
.312 .26664 L
.316 .26662 L
.32 .26668 L
.324 .2668 L
.328 .26696 L
.332 .26712 L
.336 .26724 L
.34 .2673 L
.344 .2673 L
.348 .26725 L
.352 .26717 L
.356 .26708 L
.36 .26699 L
.364 .26692 L
.368 .26686 L
.372 .26679 L
.376 .26672 L
.38 .26664 L
.384 .26654 L
.388 .26645 L
.392 .26637 L
.396 .26633 L
.4 .26633 L
Mistroke
.404 .26638 L
.408 .26646 L
.412 .26657 L
.416 .26667 L
.42 .26674 L
.424 .26677 L
.428 .26674 L
.432 .26665 L
.436 .26654 L
.44 .2664 L
.444 .26627 L
.448 .26617 L
.452 .2661 L
.456 .26608 L
.46 .2661 L
.464 .26613 L
.468 .26616 L
.472 .26619 L
.476 .2662 L
.48 .2662 L
.484 .26619 L
.488 .26618 L
.492 .26617 L
.496 .26615 L
.5 .26611 L
.504 .26604 L
.508 .26597 L
.512 .26589 L
.516 .26582 L
.52 .26579 L
.524 .26578 L
.528 .26581 L
.532 .26584 L
.536 .26586 L
.54 .26585 L
.544 .26583 L
.548 .26579 L
.552 .26574 L
.556 .26571 L
.56 .26569 L
.564 .26567 L
.568 .26565 L
.572 .26562 L
.576 .26557 L
.58 .26552 L
.584 .26548 L
.588 .26545 L
.592 .26545 L
.596 .26546 L
.6 .26547 L
Mistroke
.604 .26547 L
.608 .26546 L
.612 .26542 L
.616 .26538 L
.62 .26534 L
.624 .2653 L
.628 .26527 L
.632 .26523 L
.636 .2652 L
.64 .26517 L
.644 .26515 L
.648 .26514 L
.652 .26514 L
.656 .26515 L
.66 .26515 L
.664 .26514 L
.668 .26511 L
.672 .26506 L
.676 .265 L
.68 .26494 L
.684 .2649 L
.688 .26488 L
.692 .26488 L
.696 .26488 L
.7 .26489 L
.704 .26488 L
.708 .26487 L
.712 .26484 L
.716 .2648 L
.72 .26476 L
.724 .26472 L
.728 .26468 L
.732 .26464 L
.736 .26462 L
.74 .26461 L
.744 .26461 L
.748 .26461 L
.752 .26461 L
.756 .26459 L
.76 .26456 L
.764 .26451 L
.768 .26447 L
.772 .26442 L
.776 .26439 L
.78 .26438 L
.784 .26437 L
.788 .26437 L
.792 .26436 L
.796 .26435 L
.8 .26432 L
Mistroke
.804 .26429 L
.808 .26425 L
.812 .26421 L
.816 .26418 L
.82 .26415 L
.824 .26414 L
.828 .26413 L
.832 .26412 L
.836 .26411 L
.84 .26409 L
.844 .26406 L
.848 .26402 L
.852 .26398 L
.856 .26395 L
.86 .26393 L
.864 .26392 L
.868 .26391 L
.872 .26389 L
.876 .26387 L
.88 .26384 L
.884 .26381 L
.888 .26379 L
.892 .26376 L
.896 .26374 L
.9 .26372 L
.904 .2637 L
.908 .26367 L
.912 .26365 L
.916 .26363 L
.92 .2636 L
.924 .26358 L
.928 .26356 L
.932 .26354 L
.936 .26352 L
.94 .2635 L
.944 .26347 L
.948 .26344 L
.952 .26341 L
.956 .26339 L
.96 .26337 L
.964 .26336 L
.968 .26333 L
.972 .26332 L
.976 .26329 L
.98 .26327 L
.984 .26323 L
.988 .26321 L
.992 .26318 L
.996 .26316 L
1 .26314 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15815 L
.012 .15268 L
.016 .14773 L
.02 .14347 L
.024 .13882 L
.028 .13374 L
.032 .12849 L
.036 .12321 L
.04 .11783 L
.044 .11239 L
.048 .10699 L
.052 .10169 L
.056 .09654 L
.06 .09158 L
.064 .08683 L
.068 .08232 L
.072 .07805 L
.076 .07404 L
.08 .07026 L
.084 .06675 L
.088 .06349 L
.092 .06052 L
.096 .05782 L
.1 .05543 L
.104 .05334 L
.108 .05156 L
.112 .05005 L
.116 .04878 L
.12 .04768 L
.124 .0467 L
.128 .04576 L
.132 .04481 L
.136 .04379 L
.14 .04268 L
.144 .04148 L
.148 .04022 L
.152 .03891 L
.156 .03764 L
.16 .03643 L
.164 .03535 L
.168 .03441 L
.172 .03363 L
.176 .03298 L
.18 .03244 L
.184 .03198 L
.188 .03155 L
.192 .03113 L
.196 .03069 L
.2 .03021 L
Mistroke
.204 .0297 L
.208 .02918 L
.212 .02865 L
.216 .02813 L
.22 .02764 L
.224 .0272 L
.228 .02683 L
.232 .02655 L
.236 .02638 L
.24 .02635 L
.244 .02646 L
.248 .0267 L
.252 .02704 L
.256 .02746 L
.26 .02789 L
.264 .02829 L
.268 .0286 L
.272 .02879 L
.276 .02886 L
.28 .02884 L
.284 .02876 L
.288 .02868 L
.292 .02865 L
.296 .02867 L
.3 .02877 L
.304 .0289 L
.308 .02902 L
.312 .0291 L
.316 .02909 L
.32 .02899 L
.324 .02882 L
.328 .0286 L
.332 .02838 L
.336 .02821 L
.34 .02811 L
.344 .02808 L
.348 .02812 L
.352 .0282 L
.356 .02829 L
.36 .02838 L
.364 .02844 L
.368 .0285 L
.372 .02855 L
.376 .02862 L
.38 .02871 L
.384 .0288 L
.388 .0289 L
.392 .02897 L
.396 .029 L
.4 .02897 L
Mistroke
.404 .02889 L
.408 .02876 L
.412 .02861 L
.416 .02846 L
.42 .02835 L
.424 .02829 L
.428 .02831 L
.432 .02838 L
.436 .02851 L
.44 .02866 L
.444 .0288 L
.448 .02891 L
.452 .02896 L
.456 .02896 L
.46 .02892 L
.464 .02886 L
.468 .0288 L
.472 .02874 L
.476 .02871 L
.48 .02868 L
.484 .02867 L
.488 .02865 L
.492 .02864 L
.496 .02865 L
.5 .02868 L
.504 .02874 L
.508 .02881 L
.512 .02889 L
.516 .02894 L
.52 .02896 L
.524 .02894 L
.528 .0289 L
.532 .02884 L
.536 .02879 L
.54 .02877 L
.544 .02878 L
.548 .02881 L
.552 .02884 L
.556 .02886 L
.56 .02886 L
.564 .02886 L
.568 .02887 L
.572 .02889 L
.576 .02892 L
.58 .02896 L
.584 .02898 L
.588 .02899 L
.592 .02898 L
.596 .02895 L
.6 .02891 L
Mistroke
.604 .02889 L
.608 .02888 L
.612 .0289 L
.616 .02892 L
.62 .02895 L
.624 .02898 L
.628 .02901 L
.632 .02903 L
.636 .02904 L
.64 .02905 L
.644 .02905 L
.648 .02904 L
.652 .02902 L
.656 .02899 L
.66 .02897 L
.664 .02897 L
.668 .02898 L
.672 .02902 L
.676 .02907 L
.68 .02912 L
.684 .02914 L
.688 .02915 L
.692 .02913 L
.696 .02911 L
.7 .02908 L
.704 .02906 L
.708 .02905 L
.712 .02906 L
.716 .02909 L
.72 .02912 L
.724 .02916 L
.728 .02919 L
.732 .0292 L
.736 .02921 L
.74 .02919 L
.744 .02917 L
.748 .02914 L
.752 .02913 L
.756 .02913 L
.76 .02916 L
.764 .02919 L
.768 .02923 L
.772 .02925 L
.776 .02926 L
.78 .02926 L
.784 .02925 L
.788 .02923 L
.792 .02922 L
.796 .02922 L
.8 .02923 L
Mistroke
.804 .02925 L
.808 .02927 L
.812 .02929 L
.816 .02931 L
.82 .02932 L
.824 .02932 L
.828 .02932 L
.832 .02931 L
.836 .0293 L
.84 .0293 L
.844 .02931 L
.848 .02932 L
.852 .02934 L
.856 .02936 L
.86 .02938 L
.864 .02939 L
.868 .02939 L
.872 .02938 L
.876 .02938 L
.88 .02937 L
.884 .02937 L
.888 .02939 L
.892 .02941 L
.896 .02943 L
.9 .02944 L
.904 .02945 L
.908 .02945 L
.912 .02944 L
.916 .02944 L
.92 .02944 L
.924 .02944 L
.928 .02946 L
.932 .02948 L
.936 .0295 L
.94 .02951 L
.944 .02951 L
.948 .02951 L
.952 .0295 L
.956 .0295 L
.96 .0295 L
.964 .02952 L
.968 .02953 L
.972 .02955 L
.976 .02956 L
.98 .02957 L
.984 .02957 L
.988 .02958 L
.992 .02956 L
.996 .02957 L
1 .02957 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool200000goo0000001ZOol000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oo`00
009oo`03001oogoo06Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo
0`000Woo00<007ooOol0Igoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`8000=oo`03001oogoo06Moo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000
Oomoogoo0P0017oo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
0`00Oomoo`020004Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=o
o`03001oogoo008000Aoo`03001oogoo06Ioo`002goo0P002Woo0P000goo0`000goo00<007ooOol0
17oo00<007ooOol0IGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool20005Ool00`00
Oomoo`1UOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P001Woo00<0
07ooOol017oo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo1@00
0goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00=oo`05001oogooOol00002
Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomo
ogoo00000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20006Ool20008Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Moo`03001oogoo00Ioo`04001oogoo0002
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03
001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol01goo00@007ooOomoo`@000=oo`04001oogoo
0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool0
1000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00H007oo
Oomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool20008
Ool01000Oomoogoo0P001Goo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`00
17oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`00
0Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`008Woo0P0027oo
00@007ooOomoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003
Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo00Mo
o`07001oogooOol007oo0000GWoo000ROol20009Ool00`00Ool00003Ool00`00Oomoo`1KOol0029o
of<000aoo`008Woo00D007ooOomoo`0000=oo`03001oogoo00<0009oo`03001oo`000080009oo`80
009oo`<00005Ool007oo001oo`0300000goo00000009000017oo000007oo0P0000Eoo`00000007oo
02H000aoo`008Woo0P005Woo00<007oo00000Woo0`000Woo0P0000Aoo`000000009oo`<00004Ool0
0000Ool20002Ool2000017oo000007oo0P0000Aoo`00001oo`8000Aoo`06001oogooOol007oo0P00
00=oo`00Ool01Woo00@007ooOol000=oo`04001oo`00000<Ool0029oo`03001oogoo01Ioo`8000=o
o`03001oogoo04ioo`008Woo0P00KGoo000ROol2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00
Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo
0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00
Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool0
00]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00
Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=o
o`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0
00=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000R
Ool00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003
Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]o
o`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool2
0004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo0003
Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool3
0004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool2
0003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007oo
Ool007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00
Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009o
o`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eo
o`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool0
02Qoo`03001oogoo00Moo`H000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`X0
009oo`03001oo`0004h000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qo
o`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool2
0004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
OomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00mo
o`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Ao
o`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool2
0002Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000A
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001o
ogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03
Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000
Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eo
o`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001o
ogoo008001Eoo`D005Uoo`002Woo00@007ooOol000]oo`04001oogoo000@Ool70004Oom=000<Ool0
00Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0:Ool4001TOol000Yoo`04001oogoo0007Ool0
0`00Oomoo`04Ool20009Ool3001WOol000]oo`8000Qoo`D0009oo`03001oogoo00Ioo`8006Yoo`00
77oo00<007ooOol01Goo0P001Woo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`00
17oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol20005Ool20006
Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool001aoo`03001oogoo00=oo`8000]oo`04001oogoo0002Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo00=oo`03001oogoo00Yoo`04
001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001ao
o`8000=oo`03001oogoo00Moo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000LOol01@00Oomoogoo00002Woo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo
0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol0
00Eoo`0077oo0P0000=oo`0000002Woo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo
00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`00
77oo00@007oo0000075oo`0077oo0`00LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol000]oo`80
00Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04
001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<0
07ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=o
o`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol0
01Ioo`8000Aoo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001o
ogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo
001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo
00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo
00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(24549\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .10908 m
.008 .11123 L
.012 .11738 L
.016 .12654 L
.02 .13763 L
.024 .15105 L
.028 .16517 L
.032 .17872 L
.036 .19042 L
.04 .20004 L
.044 .2071 L
.048 .21166 L
.052 .21424 L
.056 .21565 L
.06 .21699 L
.064 .21907 L
.068 .22275 L
.072 .22831 L
.076 .23572 L
.08 .24433 L
.084 .25321 L
.088 .26116 L
.092 .26702 L
.096 .2699 L
.1 .26936 L
.104 .26563 L
.108 .25949 L
.112 .25231 L
.116 .24564 L
.12 .24108 L
.124 .23984 L
.128 .24259 L
.132 .24924 L
.136 .25905 L
.14 .27071 L
.144 .28264 L
.148 .29332 L
.152 .30156 L
.156 .30677 L
.16 .30898 L
.164 .30877 L
.168 .30704 L
.172 .30474 L
.176 .30268 L
.18 .30132 L
.184 .30077 L
.188 .30091 L
.192 .30152 L
.196 .30246 L
.2 .30381 L
Mistroke
.204 .30586 L
.208 .30898 L
.212 .31343 L
.216 .31913 L
.22 .3255 L
.224 .33148 L
.228 .33581 L
.232 .33734 L
.236 .33548 L
.24 .33043 L
.244 .32327 L
.248 .3157 L
.252 .30966 L
.256 .30671 L
.26 .30762 L
.264 .31202 L
.268 .31851 L
.272 .32498 L
.276 .32934 L
.28 .33013 L
.284 .32701 L
.288 .32093 L
.292 .31376 L
.296 .30772 L
.3 .30463 L
.304 .3053 L
.308 .3093 L
.312 .31522 L
.316 .3211 L
.32 .3252 L
.324 .32649 L
.328 .32499 L
.332 .32166 L
.336 .31794 L
.34 .31527 L
.344 .31449 L
.348 .31566 L
.352 .31808 L
.356 .32066 L
.36 .32235 L
.364 .32254 L
.368 .32124 L
.372 .31898 L
.376 .31651 L
.38 .31454 L
.384 .31351 L
.388 .31352 L
.392 .31447 L
.396 .3161 L
.4 .3181 L
Mistroke
.404 .32014 L
.408 .32183 L
.412 .32277 L
.416 .3226 L
.42 .32127 L
.424 .31908 L
.428 .3167 L
.432 .31499 L
.436 .31458 L
.44 .31564 L
.444 .31768 L
.448 .31977 L
.452 .32088 L
.456 .32046 L
.46 .3187 L
.464 .31653 L
.468 .31513 L
.472 .31535 L
.476 .31724 L
.48 .31999 L
.484 .32223 L
.488 .32277 L
.492 .32123 L
.496 .31827 L
.5 .31533 L
.504 .31384 L
.508 .31451 L
.512 .31696 L
.516 .31989 L
.52 .32178 L
.524 .32172 L
.528 .31984 L
.532 .31726 L
.536 .31547 L
.54 .31545 L
.544 .31717 L
.548 .31958 L
.552 .3213 L
.556 .32135 L
.56 .31974 L
.564 .3174 L
.568 .31564 L
.572 .31541 L
.576 .31676 L
.58 .31886 L
.584 .32052 L
.588 .32085 L
.592 .3198 L
.596 .31814 L
.6 .31688 L
Mistroke
.604 .31671 L
.608 .3176 L
.612 .31888 L
.616 .31975 L
.62 .3197 L
.624 .31884 L
.628 .31774 L
.632 .3171 L
.636 .31729 L
.64 .31816 L
.644 .31914 L
.648 .31967 L
.652 .31948 L
.656 .31877 L
.66 .318 L
.664 .3176 L
.668 .31769 L
.672 .31815 L
.676 .3187 L
.68 .31904 L
.684 .31905 L
.688 .31876 L
.692 .31835 L
.696 .31806 L
.7 .31804 L
.704 .31829 L
.708 .31864 L
.712 .31889 L
.716 .31892 L
.72 .31872 L
.724 .31843 L
.728 .3182 L
.732 .31815 L
.736 .31829 L
.74 .31856 L
.744 .31879 L
.748 .31885 L
.752 .31871 L
.756 .3185 L
.76 .31839 L
.764 .31846 L
.768 .31861 L
.772 .31867 L
.776 .31855 L
.78 .31837 L
.784 .31835 L
.788 .31856 L
.792 .31887 L
.796 .31896 L
.8 .31871 L
Mistroke
.804 .31831 L
.808 .3181 L
.812 .31831 L
.816 .31883 L
.82 .31921 L
.824 .31913 L
.828 .31862 L
.832 .31804 L
.836 .31782 L
.84 .31817 L
.844 .31884 L
.848 .31941 L
.852 .31952 L
.856 .31905 L
.86 .31832 L
.864 .31778 L
.868 .31775 L
.872 .3183 L
.876 .31905 L
.88 .31947 L
.884 .31935 L
.888 .31883 L
.892 .31829 L
.896 .31819 L
.9 .31844 L
.904 .31867 L
.908 .31873 L
.912 .31859 L
.916 .31854 L
.92 .31889 L
.924 .31928 L
.928 .31924 L
.932 .31875 L
.936 .31803 L
.94 .31771 L
.944 .31829 L
.948 .3192 L
.952 .31967 L
.956 .31946 L
.96 .31862 L
.964 .31793 L
.968 .31816 L
.972 .31879 L
.976 .31917 L
.98 .31915 L
.984 .31857 L
.988 .31818 L
.992 .31865 L
.996 .31924 L
1 .31936 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29228 m
.008 .29417 L
.012 .29489 L
.016 .2944 L
.02 .29423 L
.024 .29446 L
.028 .29453 L
.032 .29441 L
.036 .29418 L
.04 .2939 L
.044 .29345 L
.048 .29286 L
.052 .2921 L
.056 .29121 L
.06 .29015 L
.064 .28893 L
.068 .28754 L
.072 .286 L
.076 .2843 L
.08 .28247 L
.084 .28054 L
.088 .27856 L
.092 .27657 L
.096 .27464 L
.1 .27284 L
.104 .27122 L
.108 .26984 L
.112 .26872 L
.116 .26787 L
.12 .26728 L
.124 .26691 L
.128 .26671 L
.132 .26663 L
.136 .26662 L
.14 .26664 L
.144 .26665 L
.148 .26664 L
.152 .26662 L
.156 .26661 L
.16 .26662 L
.164 .26668 L
.168 .26679 L
.172 .26697 L
.176 .26721 L
.18 .2675 L
.184 .26782 L
.188 .26816 L
.192 .26849 L
.196 .2688 L
.2 .26906 L
Mistroke
.204 .26927 L
.208 .26939 L
.212 .26942 L
.216 .26935 L
.22 .26918 L
.224 .26892 L
.228 .26858 L
.232 .26821 L
.236 .26786 L
.24 .26755 L
.244 .26733 L
.248 .26721 L
.252 .26717 L
.256 .26719 L
.26 .26724 L
.264 .26728 L
.268 .26728 L
.272 .26723 L
.276 .26713 L
.28 .26701 L
.284 .2669 L
.288 .26685 L
.292 .26687 L
.296 .26696 L
.3 .2671 L
.304 .26726 L
.308 .2674 L
.312 .2675 L
.316 .26753 L
.32 .26751 L
.324 .26744 L
.328 .26734 L
.332 .26724 L
.336 .26715 L
.34 .26708 L
.344 .26702 L
.348 .26696 L
.352 .26688 L
.356 .2668 L
.36 .26671 L
.364 .26662 L
.368 .26657 L
.372 .26655 L
.376 .26657 L
.38 .26664 L
.384 .26673 L
.388 .26683 L
.392 .26692 L
.396 .26697 L
.4 .26697 L
Mistroke
.404 .26692 L
.408 .26681 L
.412 .26668 L
.416 .26655 L
.42 .26642 L
.424 .26634 L
.428 .26629 L
.432 .26629 L
.436 .26632 L
.44 .26636 L
.444 .26639 L
.448 .26642 L
.452 .26642 L
.456 .26642 L
.46 .26641 L
.464 .26639 L
.468 .26637 L
.472 .26634 L
.476 .26629 L
.48 .26622 L
.484 .26615 L
.488 .26607 L
.492 .26602 L
.496 .266 L
.5 .266 L
.504 .26603 L
.508 .26606 L
.512 .26607 L
.516 .26606 L
.52 .26603 L
.524 .26599 L
.528 .26594 L
.532 .26591 L
.536 .26589 L
.54 .26587 L
.544 .26584 L
.548 .26581 L
.552 .26577 L
.556 .26572 L
.56 .26569 L
.564 .26567 L
.568 .26566 L
.572 .26567 L
.576 .26568 L
.58 .26568 L
.584 .26566 L
.588 .26563 L
.592 .26558 L
.596 .26554 L
.6 .2655 L
Mistroke
.604 .26546 L
.608 .26543 L
.612 .2654 L
.616 .26538 L
.62 .26537 L
.624 .26536 L
.628 .26536 L
.632 .26536 L
.636 .26535 L
.64 .26533 L
.644 .2653 L
.648 .26525 L
.652 .26519 L
.656 .26514 L
.66 .26511 L
.664 .26509 L
.668 .26509 L
.672 .2651 L
.676 .2651 L
.68 .26509 L
.684 .26508 L
.688 .26504 L
.692 .265 L
.696 .26495 L
.7 .26491 L
.704 .26487 L
.708 .26485 L
.712 .26483 L
.716 .26483 L
.72 .26483 L
.724 .26483 L
.728 .26482 L
.732 .26479 L
.736 .26475 L
.74 .2647 L
.744 .26466 L
.748 .26462 L
.752 .2646 L
.756 .26459 L
.76 .26458 L
.764 .26458 L
.768 .26457 L
.772 .26455 L
.776 .26452 L
.78 .26449 L
.784 .26445 L
.788 .26442 L
.792 .26438 L
.796 .26436 L
.8 .26434 L
Mistroke
.804 .26433 L
.808 .26432 L
.812 .26431 L
.816 .26429 L
.82 .26426 L
.824 .26423 L
.828 .26419 L
.832 .26416 L
.836 .26413 L
.84 .26411 L
.844 .2641 L
.848 .26409 L
.852 .26407 L
.856 .26406 L
.86 .26403 L
.864 .264 L
.868 .26397 L
.872 .26393 L
.876 .26391 L
.88 .26389 L
.884 .26387 L
.888 .26386 L
.892 .26385 L
.896 .26382 L
.9 .2638 L
.904 .26376 L
.908 .26373 L
.912 .2637 L
.916 .26369 L
.92 .26367 L
.924 .26365 L
.928 .26363 L
.932 .26361 L
.936 .26359 L
.94 .26356 L
.944 .26353 L
.948 .2635 L
.952 .26348 L
.956 .26347 L
.96 .26345 L
.964 .26343 L
.968 .2634 L
.972 .26338 L
.976 .26335 L
.98 .26332 L
.984 .2633 L
.988 .26328 L
.992 .26325 L
.996 .26324 L
1 .26321 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15455 L
.012 .15074 L
.016 .14607 L
.02 .14065 L
.024 .13586 L
.028 .13164 L
.032 .12749 L
.036 .12346 L
.04 .11961 L
.044 .11592 L
.048 .11222 L
.052 .10853 L
.056 .10478 L
.06 .101 L
.064 .09715 L
.068 .09328 L
.072 .08942 L
.076 .0856 L
.08 .08188 L
.084 .07827 L
.088 .07481 L
.092 .07149 L
.096 .06829 L
.1 .0652 L
.104 .06218 L
.108 .05922 L
.112 .05629 L
.116 .05341 L
.12 .05059 L
.124 .04787 L
.128 .0453 L
.132 .04294 L
.136 .04081 L
.14 .03895 L
.144 .03737 L
.148 .03604 L
.152 .03494 L
.156 .03402 L
.16 .03323 L
.164 .03252 L
.168 .03186 L
.172 .03121 L
.176 .03056 L
.18 .02992 L
.184 .0293 L
.188 .0287 L
.192 .02814 L
.196 .02764 L
.2 .02721 L
Mistroke
.204 .02688 L
.208 .02666 L
.212 .02656 L
.216 .0266 L
.22 .02678 L
.224 .02707 L
.228 .02745 L
.232 .02788 L
.236 .02829 L
.24 .02865 L
.244 .0289 L
.248 .02903 L
.252 .02906 L
.256 .029 L
.26 .02891 L
.264 .02884 L
.268 .02882 L
.272 .02887 L
.276 .02897 L
.28 .02909 L
.284 .02919 L
.288 .02924 L
.292 .02919 L
.296 .02906 L
.3 .02887 L
.304 .02865 L
.308 .02844 L
.312 .02829 L
.316 .02822 L
.32 .02823 L
.324 .0283 L
.328 .0284 L
.332 .0285 L
.336 .02858 L
.34 .02865 L
.344 .02871 L
.348 .02876 L
.352 .02883 L
.356 .02892 L
.36 .029 L
.364 .02908 L
.368 .02913 L
.372 .02913 L
.376 .02908 L
.38 .02898 L
.384 .02884 L
.388 .02869 L
.392 .02855 L
.396 .02847 L
.4 .02845 L
Mistroke
.404 .02849 L
.408 .0286 L
.412 .02874 L
.416 .02889 L
.42 .02901 L
.424 .0291 L
.428 .02913 L
.432 .02911 L
.436 .02906 L
.44 .02899 L
.444 .02892 L
.448 .02887 L
.452 .02883 L
.456 .02882 L
.46 .02881 L
.464 .02881 L
.468 .02881 L
.472 .02883 L
.476 .02887 L
.48 .02893 L
.484 .029 L
.488 .02906 L
.492 .02911 L
.496 .02911 L
.5 .02909 L
.504 .02903 L
.508 .02897 L
.512 .02893 L
.516 .02892 L
.52 .02893 L
.524 .02897 L
.528 .029 L
.532 .02902 L
.536 .02903 L
.54 .02903 L
.544 .02903 L
.548 .02905 L
.552 .02908 L
.556 .02912 L
.56 .02914 L
.564 .02914 L
.568 .02913 L
.572 .02909 L
.576 .02906 L
.58 .02903 L
.584 .02904 L
.588 .02906 L
.592 .02909 L
.596 .02912 L
.6 .02915 L
Mistroke
.604 .02917 L
.608 .02919 L
.612 .0292 L
.616 .0292 L
.62 .0292 L
.624 .02919 L
.628 .02917 L
.632 .02914 L
.636 .02912 L
.64 .02912 L
.644 .02915 L
.648 .02919 L
.652 .02924 L
.656 .02928 L
.66 .0293 L
.664 .0293 L
.668 .02927 L
.672 .02924 L
.676 .02922 L
.68 .0292 L
.684 .02921 L
.688 .02923 L
.692 .02926 L
.696 .02929 L
.7 .02932 L
.704 .02934 L
.708 .02935 L
.712 .02935 L
.716 .02934 L
.72 .02932 L
.724 .02929 L
.728 .02928 L
.732 .02929 L
.736 .02931 L
.74 .02935 L
.744 .02939 L
.748 .02941 L
.752 .02942 L
.756 .02941 L
.76 .0294 L
.764 .02938 L
.768 .02937 L
.772 .02937 L
.776 .02938 L
.78 .0294 L
.784 .02943 L
.788 .02945 L
.792 .02947 L
.796 .02948 L
.8 .02947 L
Mistroke
.804 .02946 L
.808 .02945 L
.812 .02944 L
.816 .02945 L
.82 .02947 L
.824 .02949 L
.828 .02951 L
.832 .02952 L
.836 .02953 L
.84 .02952 L
.844 .02952 L
.848 .02952 L
.852 .02953 L
.856 .02953 L
.86 .02954 L
.864 .02955 L
.868 .02956 L
.872 .02957 L
.876 .02958 L
.88 .02959 L
.884 .02959 L
.888 .0296 L
.892 .02961 L
.896 .02961 L
.9 .02961 L
.904 .02961 L
.908 .02962 L
.912 .02963 L
.916 .02965 L
.92 .02966 L
.924 .02967 L
.928 .02967 L
.932 .02967 L
.936 .02967 L
.94 .02967 L
.944 .02967 L
.948 .02968 L
.952 .02969 L
.956 .02972 L
.96 .02973 L
.964 .02974 L
.968 .02974 L
.972 .02974 L
.976 .02973 L
.98 .02973 L
.984 .02974 L
.988 .02976 L
.992 .02977 L
.996 .02979 L
1 .02979 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]
Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oo`0006aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0`00K7oo0003Ool50002Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo
0004Ool01@00Oomoogoo00000Woo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`0200000goo001oo`1ZOol000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo00800003Ool007oo06Yoo`002goo0P002Woo0P000goo0`000goo00D007oo
Oomoo`0006Yoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P000Woo00<007ooOol0
J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80009oo`<000Qoo`<0
00Aoo`8000Moo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000=oo`D000=oo`8000Aoo`80
00Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool20006Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo
0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P001Goo0P002Goo00@007ooOol0009oo`03001oogoo00Eo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool20006Ool00`00Oomoo`030004Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000Aoo`03001oogoo00Eoo`05001oogoo001oo`050003Ool01000Oomoo`001goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol0009o
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogooOol007oo1000
0goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo0P001goo0`0000=oo`00
00001Woo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<0
07ooOol017oo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0
00=oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`008Woo0P0027oo00@007ooOomoo`D0
00=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20004Ool30004
Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo00]oo`03001oogoo05io
o`008Woo0P003Goo00<007ooOol0GGoo000ROomS000<Ool0029oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00@007ooOomoo`80009oo`@00005Ool00000001oo`0700001Goo00000000Ool0
2@0000=oo`0000006P0000=oo`0000001`0000=oo`0000000`0037oo000ROol2000DOol00`00Ool0
0002Ool20002Ool20002Ool20003Ool20002Ool2000017oo000007oo0`0000Aoo`00001oo`800004
Ool00000Ool2000BOol01000Oomoo`001Woo00<007ooOol00Woo00<007ooOol02Woo000ROol00`00
Oomoo`0COol30002Ool00`00Oomoo`1AOol0029oo`8006eoo`008Woo0P00KGoo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<0
07ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo
0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo
001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
1000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`00
2goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo
00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yo
o`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0
029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03
001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool0
0`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007oo
Ool00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00
Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<0
07ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00
Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Io
o`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<0
07ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@0
07ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo
1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007oo
Ool000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=o
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eo
o`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002
Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007oo
Oomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo
00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomo
o`001Goo000XOol00`00Oomoo`07OomC0003Ool01000Oomoo`001Goo000XOol00`00Oomoo`05Ool3
00000goo000000030003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@00
0goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`02
Ool3001QOol002Qoo`H006=oo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool0
0`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomo
o`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomo
o`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00
J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001W
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo
06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo
06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007oo
Ool0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Io
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0
009oo`04001oogoo000;Ool00`00Oomoo`02000BOol5001LOol000Yoo`04001oogoo000;Ool01000
Oomoo`003Woo1P0017ooD00037oo000:Ool01000Oomoo`001goo10000goo00<007ooOol02Woo0`00
IGoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P002Woo0P00Igoo000;Ool20008Ool50002
Ool00`00Oomoo`08Ool00`00Oomoo`1WOol001aoo`03001oogoo00Ioo`8000Eoo`<000Aoo`8000Uo
o`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009o
o`<000Aoo`8000Ioo`0077oo0P001Woo0P001Goo00D007ooOomoo`00009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomo
o`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`04Ool2000:
Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000L
Ool00`00Oomoo`03Ool2000;Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo
00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomo
o`000Woo00<007ooOol00goo000LOol20003Ool20008Ool40003Ool01000Oomoo`002Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Ao
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo1000
0goo00@007ooOol000Eoo`0077oo00@007ooOomoo`8000Uoo`03001oogoo00Aoo`04001oogoo0008
Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo
0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001o
o`0000Ioo`04001oogoo0005Ool001aoo`800003Ool0000000Yoo`D000=oo`8000Yoo`03001oogoo
00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002
Ool50003Ool20006Ool001aoo`04001oo`00001aOol001aoo`<0079oo`0077ooJ@0037oo000LOol0
1@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001ao
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007oo
Ool00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@0
00=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P00
27oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol0
0`00Oomoo`02Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol0
0Woo00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000L
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo
0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00
Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03
001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0
LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(24716\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .17344 m
.008 .18147 L
.012 .1885 L
.016 .19406 L
.02 .19866 L
.024 .20262 L
.028 .20687 L
.032 .21161 L
.036 .21735 L
.04 .22471 L
.044 .23359 L
.048 .24384 L
.052 .25443 L
.056 .26455 L
.06 .27273 L
.064 .27791 L
.068 .279 L
.072 .2756 L
.076 .26786 L
.08 .25659 L
.084 .24328 L
.088 .2297 L
.092 .21785 L
.096 .20935 L
.1 .20545 L
.104 .20655 L
.108 .21235 L
.112 .22178 L
.116 .23331 L
.12 .24524 L
.124 .25604 L
.128 .26465 L
.132 .27059 L
.136 .27406 L
.14 .27565 L
.144 .27629 L
.148 .27681 L
.152 .27786 L
.156 .27972 L
.16 .28236 L
.164 .28553 L
.168 .28896 L
.172 .29251 L
.176 .29629 L
.18 .30058 L
.184 .30572 L
.188 .31182 L
.192 .31865 L
.196 .32548 L
.2 .33125 L
Mistroke
.204 .33478 L
.208 .33521 L
.212 .33226 L
.216 .32649 L
.22 .31922 L
.224 .31226 L
.228 .30745 L
.232 .30609 L
.236 .30853 L
.24 .314 L
.244 .32078 L
.248 .32672 L
.252 .32989 L
.256 .32922 L
.26 .32485 L
.264 .31811 L
.268 .31107 L
.272 .30589 L
.276 .30407 L
.28 .30605 L
.284 .31105 L
.288 .31738 L
.292 .32305 L
.296 .32644 L
.3 .32678 L
.304 .32442 L
.308 .32056 L
.312 .3168 L
.316 .3145 L
.32 .31434 L
.324 .31608 L
.328 .31879 L
.332 .32129 L
.336 .32259 L
.34 .32224 L
.344 .32046 L
.348 .31792 L
.352 .31543 L
.356 .3137 L
.36 .31308 L
.364 .3136 L
.368 .31502 L
.372 .317 L
.376 .31915 L
.38 .32106 L
.384 .32236 L
.388 .32275 L
.392 .32206 L
.396 .32039 L
.4 .31815 L
Mistroke
.404 .31601 L
.408 .31468 L
.412 .31466 L
.416 .31594 L
.42 .31798 L
.424 .31986 L
.428 .32073 L
.432 .32015 L
.436 .31841 L
.44 .31641 L
.444 .31525 L
.448 .31568 L
.452 .31763 L
.456 .32024 L
.46 .32221 L
.464 .32245 L
.468 .32072 L
.472 .31773 L
.476 .31491 L
.48 .31365 L
.484 .31457 L
.488 .3172 L
.492 .32017 L
.496 .32197 L
.5 .32173 L
.504 .31968 L
.508 .31701 L
.512 .31523 L
.516 .31531 L
.52 .31716 L
.524 .31969 L
.528 .32143 L
.532 .32136 L
.536 .31955 L
.54 .31705 L
.544 .31526 L
.548 .31517 L
.552 .31676 L
.556 .31909 L
.56 .32082 L
.564 .32105 L
.568 .31977 L
.572 .31784 L
.576 .31645 L
.58 .31638 L
.584 .31753 L
.588 .31907 L
.592 .32001 L
.596 .31979 L
.6 .31864 L
Mistroke
.604 .31734 L
.608 .31671 L
.612 .31713 L
.616 .31831 L
.62 .3195 L
.624 .31999 L
.628 .31951 L
.632 .31842 L
.636 .31742 L
.64 .31711 L
.644 .31758 L
.648 .31846 L
.652 .31917 L
.656 .31933 L
.66 .31891 L
.664 .31825 L
.668 .31776 L
.672 .31774 L
.676 .31816 L
.68 .31875 L
.684 .31913 L
.688 .31906 L
.692 .3186 L
.696 .31804 L
.7 .31775 L
.704 .3179 L
.708 .3184 L
.712 .31892 L
.716 .31913 L
.72 .31893 L
.724 .31842 L
.728 .31794 L
.732 .3178 L
.736 .31812 L
.74 .31874 L
.744 .31924 L
.748 .31925 L
.752 .31872 L
.756 .31796 L
.76 .31752 L
.764 .31774 L
.768 .31851 L
.772 .31929 L
.776 .31955 L
.78 .31912 L
.784 .31834 L
.788 .31775 L
.792 .31773 L
.796 .3182 L
.8 .31878 L
Mistroke
.804 .3191 L
.808 .31902 L
.812 .31869 L
.816 .3184 L
.82 .31829 L
.824 .31838 L
.828 .31852 L
.832 .31858 L
.836 .31858 L
.84 .31858 L
.844 .31864 L
.848 .31877 L
.852 .31882 L
.856 .31864 L
.86 .31834 L
.864 .31811 L
.868 .31822 L
.872 .31873 L
.876 .31926 L
.88 .31936 L
.884 .31889 L
.888 .3181 L
.892 .31763 L
.896 .31794 L
.9 .31875 L
.904 .31943 L
.908 .31952 L
.912 .31894 L
.916 .31825 L
.92 .31808 L
.924 .31832 L
.928 .31865 L
.932 .31878 L
.936 .31859 L
.94 .31852 L
.944 .31888 L
.948 .31923 L
.952 .31921 L
.956 .31876 L
.96 .31798 L
.964 .3177 L
.968 .31829 L
.972 .31907 L
.976 .31954 L
.98 .3194 L
.984 .31866 L
.988 .31817 L
.992 .3184 L
.996 .31875 L
1 .31885 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3223 m
.008 .32044 L
.012 .31951 L
.016 .31951 L
.02 .31886 L
.024 .31764 L
.028 .31652 L
.032 .31546 L
.036 .31432 L
.04 .31312 L
.044 .31195 L
.048 .31079 L
.052 .30959 L
.056 .30837 L
.06 .3071 L
.064 .30579 L
.068 .30442 L
.072 .30302 L
.076 .30159 L
.08 .30016 L
.084 .29874 L
.088 .29734 L
.092 .29594 L
.096 .29454 L
.1 .29312 L
.104 .29165 L
.108 .29012 L
.112 .28852 L
.116 .28684 L
.12 .28512 L
.124 .28337 L
.128 .28166 L
.132 .28001 L
.136 .27849 L
.14 .27711 L
.144 .27591 L
.148 .27489 L
.152 .27405 L
.156 .27337 L
.16 .27283 L
.164 .2724 L
.168 .27206 L
.172 .27177 L
.176 .27152 L
.18 .27127 L
.184 .271 L
.188 .27069 L
.192 .27033 L
.196 .26992 L
.2 .26947 L
Mistroke
.204 .269 L
.208 .26854 L
.212 .26813 L
.216 .26781 L
.22 .26759 L
.224 .26747 L
.228 .26744 L
.232 .26746 L
.236 .2675 L
.24 .26752 L
.244 .2675 L
.248 .26742 L
.252 .26731 L
.256 .26719 L
.26 .26711 L
.264 .26709 L
.268 .26713 L
.272 .26724 L
.276 .26739 L
.28 .26754 L
.284 .26767 L
.288 .26775 L
.292 .26775 L
.296 .26771 L
.3 .26761 L
.304 .26751 L
.308 .2674 L
.312 .26731 L
.316 .26724 L
.32 .26718 L
.324 .26712 L
.328 .26705 L
.332 .26696 L
.336 .26688 L
.34 .26681 L
.344 .26677 L
.348 .26678 L
.352 .26682 L
.356 .2669 L
.36 .267 L
.364 .26709 L
.368 .26716 L
.372 .26719 L
.376 .26716 L
.38 .26708 L
.384 .26696 L
.388 .26683 L
.392 .26669 L
.396 .26659 L
.4 .26652 L
Mistroke
.404 .2665 L
.408 .26651 L
.412 .26655 L
.416 .26659 L
.42 .26662 L
.424 .26664 L
.428 .26665 L
.432 .26663 L
.436 .26662 L
.44 .26659 L
.444 .26656 L
.448 .26652 L
.452 .26646 L
.456 .2664 L
.46 .26633 L
.464 .26626 L
.468 .26622 L
.472 .26621 L
.476 .26622 L
.48 .26625 L
.484 .26627 L
.488 .26628 L
.492 .26627 L
.496 .26623 L
.5 .26619 L
.504 .26614 L
.508 .2661 L
.512 .26608 L
.516 .26606 L
.52 .26604 L
.524 .26601 L
.528 .26597 L
.532 .26592 L
.536 .26589 L
.54 .26587 L
.544 .26587 L
.548 .26588 L
.552 .26589 L
.556 .26589 L
.56 .26586 L
.564 .26582 L
.568 .26578 L
.572 .26573 L
.576 .26569 L
.58 .26565 L
.584 .26563 L
.588 .26561 L
.592 .26559 L
.596 .26558 L
.6 .26557 L
Mistroke
.604 .26557 L
.608 .26557 L
.612 .26556 L
.616 .26553 L
.62 .26549 L
.624 .26544 L
.628 .26538 L
.632 .26533 L
.636 .26531 L
.64 .2653 L
.644 .2653 L
.648 .26531 L
.652 .26531 L
.656 .2653 L
.66 .26527 L
.664 .26524 L
.668 .26519 L
.672 .26515 L
.676 .26511 L
.68 .26508 L
.684 .26505 L
.688 .26504 L
.692 .26504 L
.696 .26504 L
.7 .26503 L
.704 .26502 L
.708 .26499 L
.712 .26495 L
.716 .2649 L
.72 .26486 L
.724 .26482 L
.728 .2648 L
.732 .26479 L
.736 .26479 L
.74 .26479 L
.744 .26478 L
.748 .26475 L
.752 .26472 L
.756 .26468 L
.76 .26465 L
.764 .26461 L
.768 .26458 L
.772 .26456 L
.776 .26455 L
.78 .26454 L
.784 .26453 L
.788 .26452 L
.792 .26449 L
.796 .26446 L
.8 .26442 L
Mistroke
.804 .26439 L
.808 .26436 L
.812 .26434 L
.816 .26433 L
.82 .26431 L
.824 .26429 L
.828 .26427 L
.832 .26425 L
.836 .26422 L
.84 .2642 L
.844 .26417 L
.848 .26415 L
.852 .26412 L
.856 .2641 L
.86 .26408 L
.864 .26406 L
.868 .26404 L
.872 .26402 L
.876 .264 L
.88 .26397 L
.884 .26395 L
.888 .26392 L
.892 .26389 L
.896 .26386 L
.9 .26384 L
.904 .26382 L
.908 .26381 L
.912 .26379 L
.916 .26377 L
.92 .26375 L
.924 .26372 L
.928 .26368 L
.932 .26366 L
.936 .26363 L
.94 .26362 L
.944 .2636 L
.948 .26359 L
.952 .26357 L
.956 .26355 L
.96 .26351 L
.964 .26348 L
.968 .26345 L
.972 .26343 L
.976 .2634 L
.98 .2634 L
.984 .26338 L
.988 .26337 L
.992 .26333 L
.996 .26331 L
1 .26327 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15573 L
.012 .15311 L
.016 .14962 L
.02 .14514 L
.024 .14094 L
.028 .13708 L
.032 .13325 L
.036 .12941 L
.04 .12574 L
.044 .12229 L
.048 .11905 L
.052 .11602 L
.056 .11318 L
.06 .11053 L
.064 .10796 L
.068 .10545 L
.072 .10286 L
.076 .10016 L
.08 .09723 L
.084 .09406 L
.088 .09061 L
.092 .0869 L
.096 .08297 L
.1 .0789 L
.104 .07477 L
.108 .07067 L
.112 .06668 L
.116 .06287 L
.12 .05928 L
.124 .05593 L
.128 .05283 L
.132 .04995 L
.136 .04728 L
.14 .0448 L
.144 .04247 L
.148 .0403 L
.152 .03828 L
.156 .03642 L
.16 .03473 L
.164 .03321 L
.168 .03187 L
.172 .03072 L
.176 .02977 L
.18 .02901 L
.184 .02845 L
.188 .0281 L
.192 .02794 L
.196 .02796 L
.2 .02812 L
Mistroke
.204 .02838 L
.208 .02868 L
.212 .02898 L
.216 .02921 L
.22 .02935 L
.224 .02938 L
.228 .02933 L
.232 .02922 L
.236 .02911 L
.24 .02904 L
.244 .02903 L
.248 .02908 L
.252 .02918 L
.256 .02929 L
.26 .02936 L
.264 .02937 L
.268 .02929 L
.272 .02913 L
.276 .02891 L
.28 .02869 L
.284 .02851 L
.288 .0284 L
.292 .02836 L
.296 .0284 L
.3 .02849 L
.304 .0286 L
.308 .02871 L
.312 .02879 L
.316 .02886 L
.32 .02892 L
.324 .02897 L
.328 .02904 L
.332 .02912 L
.336 .02919 L
.34 .02926 L
.344 .02928 L
.348 .02926 L
.352 .02918 L
.356 .02906 L
.36 .02891 L
.364 .02877 L
.368 .02866 L
.372 .02861 L
.376 .02862 L
.38 .02869 L
.384 .02882 L
.388 .02897 L
.392 .02911 L
.396 .02922 L
.4 .02928 L
Mistroke
.404 .02929 L
.408 .02925 L
.412 .02918 L
.416 .0291 L
.42 .02904 L
.424 .02899 L
.428 .02896 L
.432 .02896 L
.436 .02896 L
.44 .02897 L
.444 .02898 L
.448 .02901 L
.452 .02905 L
.456 .02911 L
.46 .02918 L
.464 .02924 L
.468 .02927 L
.472 .02926 L
.476 .02922 L
.48 .02916 L
.484 .02911 L
.488 .02907 L
.492 .02907 L
.496 .02909 L
.5 .02913 L
.504 .02916 L
.508 .02918 L
.512 .02919 L
.516 .0292 L
.52 .0292 L
.524 .02922 L
.528 .02925 L
.532 .02927 L
.536 .02929 L
.54 .02929 L
.544 .02927 L
.548 .02923 L
.552 .0292 L
.556 .02919 L
.56 .02919 L
.564 .02922 L
.568 .02925 L
.572 .02929 L
.576 .02932 L
.58 .02934 L
.584 .02935 L
.588 .02936 L
.592 .02935 L
.596 .02934 L
.6 .02933 L
Mistroke
.604 .02931 L
.608 .02929 L
.612 .02928 L
.616 .02929 L
.62 .02932 L
.624 .02936 L
.628 .02941 L
.632 .02944 L
.636 .02946 L
.64 .02945 L
.644 .02942 L
.648 .02939 L
.652 .02936 L
.656 .02935 L
.66 .02936 L
.664 .02939 L
.668 .02942 L
.672 .02946 L
.676 .02949 L
.68 .0295 L
.684 .02951 L
.688 .0295 L
.692 .02948 L
.696 .02946 L
.7 .02944 L
.704 .02944 L
.708 .02945 L
.712 .02948 L
.716 .02952 L
.72 .02955 L
.724 .02957 L
.728 .02957 L
.732 .02956 L
.736 .02954 L
.74 .02953 L
.744 .02952 L
.748 .02953 L
.752 .02954 L
.756 .02956 L
.76 .02959 L
.764 .02961 L
.768 .02962 L
.772 .02963 L
.776 .02962 L
.78 .02961 L
.784 .0296 L
.788 .0296 L
.792 .0296 L
.796 .02962 L
.8 .02964 L
Mistroke
.804 .02966 L
.808 .02968 L
.812 .02969 L
.816 .02969 L
.82 .02968 L
.824 .02967 L
.828 .02967 L
.832 .02968 L
.836 .02969 L
.84 .02971 L
.844 .02973 L
.848 .02974 L
.852 .02975 L
.856 .02974 L
.86 .02974 L
.864 .02974 L
.868 .02974 L
.872 .02975 L
.876 .02976 L
.88 .02978 L
.884 .02979 L
.888 .0298 L
.892 .0298 L
.896 .0298 L
.9 .0298 L
.904 .0298 L
.908 .02981 L
.912 .02983 L
.916 .02984 L
.92 .02985 L
.924 .02985 L
.928 .02985 L
.932 .02986 L
.936 .02986 L
.94 .02987 L
.944 .02988 L
.948 .02989 L
.952 .0299 L
.956 .02991 L
.96 .02991 L
.964 .02991 L
.968 .02991 L
.972 .02992 L
.976 .02993 L
.98 .02995 L
.984 .02995 L
.988 .02997 L
.992 .02996 L
.996 .02997 L
1 .02996 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo0`00K7oo000;Ool20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool30007Ool00`00Oomoo`1ROol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P0000=oo`00Ool01Goo0P000goo0`0017oo0P001goo0`0017oo0P0017oo0P00
1Goo0`000goo0`0017oo0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003
Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Ool00002Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P000Woo00<007ooOol00Woo00<007oo00001Woo00@007ooOol0009oo`03001oogoo
00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool20003Ool01000Oomoo`000goo00<007ooOol00goo00@007ooOol0009o
o`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`000Woo00<0
07ooOol017oo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007oo00000`00
0goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Oomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03001o
ogoo009oo`8000Aoo`03001oo`0000Aoo`8000Ioo`04001oogoo0006Ool20004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool0029oo`8000Aoo`8000Eoo`H000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo00Aoo`03001oogoo00Eoo`8005ioo`008Woo0P003goo00<007ooOol0Fgoo000ROomS000<
Ool0029oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo00000P0000Eoo`00Ool0
07oo00<0009oo`800003Ool0000000800005Ool00000001oo`0200001Goo00000000Ool00P0000=o
o`0000000`0000Aoo`00001oobD000aoo`008Woo0P004Goo00<007oo00000Woo0P000goo0P0000Ao
o`000000009oo`<00003Ool00000009oo`800004Ool00000Ool20002Ool01000Oomoo`000Woo00@0
07ooOol000]oo`03001oogoo00Moo`04001oo`000005Ool2000>Ool0029oo`03001oogoo015oo`80
00=oo`03001oogoo05=oo`008Woo0P00KGoo000ROol2001]Ool000]oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool0
0`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
0`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^
Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0
00=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00
KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo
000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006ao
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo
0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol0
00]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:
Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo
0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00
J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;
Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004
Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D0
07ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool0
0`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0
009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo
00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03
Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qo
o`03001oogoo00Uoo`03001oogoo00=ood/000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uo
o`L00003Ool0000000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003
Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo00Moo`<005ao
o`00:7oo00<007ooOol017oo1000GWoo000XOomM000<Ool002Qoo`@000ioo`03001oogoo011oo`03
001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo
06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo
001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001X
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Mo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0
IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0
IWoo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomo
o`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@00
0Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo000?
OomI000<Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0<Ool2001TOol000Yoo`04001o
ogoo0007Ool00`00Oomoo`04Ool2000;Ool2001VOol000]oo`8000Qoo`D0009oo`03001oogoo00Uo
o`8006Moo`0077oo00<007ooOol027oo0P000goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo
0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2
0008Ool20003Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo00Ioo`8000Qoo`04001oogoo0002Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Io
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo00Eoo`03001o
ogoo00Qoo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`8000Aoo`8000Moo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`00
1Goo000LOol00`00Oomoo`02Ool20008Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@0
07ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007oo
Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000
Oomoo`001Goo000LOol20002Ool00`00Oomoo`08Ool50003Ool2000:Ool00`00Oomoo`03Ool20004
Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo
0P001Woo000LOol01000Oomoo`00LGoo000LOol3001bOol001aoofT000aoo`0077oo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=o
o`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009o
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol3
0003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol0
0Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001o
ogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`00
2goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo
00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07
Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo
00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(24883\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .24433 m
.008 .24796 L
.012 .24974 L
.016 .25286 L
.02 .25696 L
.024 .26124 L
.028 .26512 L
.032 .26833 L
.036 .27019 L
.04 .2695 L
.044 .26613 L
.048 .25985 L
.052 .25135 L
.056 .24138 L
.06 .23133 L
.064 .22271 L
.068 .2168 L
.072 .21472 L
.076 .21671 L
.08 .22265 L
.084 .23143 L
.088 .24173 L
.092 .25178 L
.096 .26008 L
.1 .26545 L
.104 .26736 L
.108 .26598 L
.112 .26205 L
.116 .25672 L
.12 .25121 L
.124 .24663 L
.128 .24367 L
.132 .24264 L
.136 .24343 L
.14 .24574 L
.144 .24924 L
.148 .25372 L
.152 .25922 L
.156 .26584 L
.16 .2737 L
.164 .28264 L
.168 .29213 L
.172 .30124 L
.176 .30882 L
.18 .31376 L
.184 .31539 L
.188 .3137 L
.192 .30951 L
.196 .30433 L
.2 .29997 L
Mistroke
.204 .29811 L
.208 .2997 L
.212 .30468 L
.216 .31191 L
.22 .31947 L
.224 .32527 L
.228 .32766 L
.232 .32604 L
.236 .32099 L
.24 .31418 L
.244 .30779 L
.248 .30383 L
.252 .30353 L
.256 .30692 L
.26 .31286 L
.264 .31947 L
.268 .32475 L
.272 .32727 L
.276 .32661 L
.28 .32345 L
.284 .31925 L
.288 .31566 L
.292 .3139 L
.296 .31437 L
.3 .31659 L
.304 .31947 L
.308 .32179 L
.312 .32265 L
.316 .3218 L
.32 .31959 L
.324 .31682 L
.328 .31438 L
.332 .31294 L
.336 .31282 L
.34 .31392 L
.344 .31584 L
.348 .3181 L
.352 .32021 L
.356 .3218 L
.36 .3226 L
.364 .32245 L
.368 .32134 L
.372 .31949 L
.376 .31732 L
.38 .31543 L
.384 .31445 L
.388 .31474 L
.392 .31621 L
.396 .31827 L
.4 .32002 L
Mistroke
.404 .32068 L
.408 .31991 L
.412 .31812 L
.416 .31624 L
.42 .31532 L
.424 .31598 L
.428 .31804 L
.432 .32055 L
.436 .32221 L
.44 .32208 L
.444 .32007 L
.448 .31705 L
.452 .31446 L
.456 .31357 L
.46 .31484 L
.464 .31762 L
.468 .32052 L
.472 .32207 L
.476 .32155 L
.48 .31933 L
.484 .31669 L
.488 .3151 L
.492 .31539 L
.496 .31733 L
.5 .31979 L
.504 .32135 L
.508 .32111 L
.512 .31923 L
.516 .31677 L
.52 .31514 L
.524 .31522 L
.528 .31691 L
.532 .31921 L
.536 .32083 L
.54 .32095 L
.544 .31963 L
.548 .31774 L
.552 .31641 L
.556 .31634 L
.56 .31744 L
.564 .31892 L
.568 .31982 L
.572 .31963 L
.576 .31857 L
.58 .31738 L
.584 .31682 L
.588 .31721 L
.592 .31827 L
.596 .31931 L
.6 .31974 L
Mistroke
.604 .31934 L
.608 .31841 L
.612 .31753 L
.616 .3172 L
.62 .31754 L
.624 .31824 L
.628 .31886 L
.632 .31906 L
.636 .31882 L
.64 .31838 L
.644 .31804 L
.648 .31796 L
.652 .31812 L
.656 .3184 L
.66 .31863 L
.664 .31868 L
.668 .31855 L
.672 .31832 L
.676 .31815 L
.68 .31812 L
.684 .31824 L
.688 .31843 L
.692 .31857 L
.696 .31861 L
.7 .31853 L
.704 .3184 L
.708 .3183 L
.712 .3183 L
.716 .31839 L
.72 .3185 L
.724 .31855 L
.728 .31845 L
.732 .31829 L
.736 .31821 L
.74 .31832 L
.744 .31859 L
.748 .31879 L
.752 .31875 L
.756 .31845 L
.76 .31813 L
.764 .31807 L
.768 .31835 L
.772 .31874 L
.776 .31892 L
.78 .31871 L
.784 .31826 L
.788 .31794 L
.792 .31805 L
.796 .31854 L
.8 .31907 L
Mistroke
.804 .31924 L
.808 .31886 L
.812 .31819 L
.816 .31768 L
.82 .3177 L
.824 .31829 L
.828 .31906 L
.832 .31946 L
.836 .31924 L
.84 .31854 L
.844 .31787 L
.848 .31773 L
.852 .31813 L
.856 .31872 L
.86 .31908 L
.864 .31897 L
.868 .31864 L
.872 .31845 L
.876 .31846 L
.88 .31854 L
.884 .31849 L
.888 .31828 L
.892 .31824 L
.896 .31857 L
.9 .31904 L
.904 .31927 L
.908 .31898 L
.912 .31826 L
.916 .31776 L
.92 .31793 L
.924 .31857 L
.928 .31923 L
.932 .31941 L
.936 .31893 L
.94 .31838 L
.944 .31819 L
.948 .31826 L
.952 .31851 L
.956 .31866 L
.96 .31859 L
.964 .31871 L
.968 .31903 L
.972 .31913 L
.976 .31892 L
.98 .31843 L
.984 .31788 L
.988 .31793 L
.992 .31865 L
.996 .31923 L
1 .31939 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35155 m
.008 .34232 L
.012 .33752 L
.016 .33715 L
.02 .33659 L
.024 .33568 L
.028 .33467 L
.032 .33362 L
.036 .33232 L
.04 .33079 L
.044 .32915 L
.048 .32745 L
.052 .32577 L
.056 .32414 L
.06 .32265 L
.064 .32131 L
.068 .32014 L
.072 .31911 L
.076 .31818 L
.08 .31731 L
.084 .31642 L
.088 .31548 L
.092 .31442 L
.096 .31323 L
.1 .31189 L
.104 .31041 L
.108 .3088 L
.112 .30708 L
.116 .30528 L
.12 .3034 L
.124 .30147 L
.128 .29951 L
.132 .29752 L
.136 .29551 L
.14 .2935 L
.144 .29149 L
.148 .28949 L
.152 .28751 L
.156 .28557 L
.16 .28366 L
.164 .2818 L
.168 .27999 L
.172 .27824 L
.176 .27659 L
.18 .27506 L
.184 .27368 L
.188 .27248 L
.192 .27148 L
.196 .27068 L
.2 .27008 L
Mistroke
.204 .26962 L
.208 .26928 L
.212 .26901 L
.216 .26875 L
.22 .2685 L
.224 .26824 L
.228 .26799 L
.232 .26778 L
.236 .26763 L
.24 .26756 L
.244 .26758 L
.248 .26766 L
.252 .26778 L
.256 .2679 L
.26 .26799 L
.264 .26802 L
.268 .26799 L
.272 .26791 L
.276 .2678 L
.28 .26768 L
.284 .26757 L
.288 .26748 L
.292 .26741 L
.296 .26735 L
.3 .26728 L
.304 .26721 L
.308 .26714 L
.312 .26707 L
.316 .26702 L
.32 .267 L
.324 .26702 L
.328 .26708 L
.332 .26716 L
.336 .26726 L
.34 .26735 L
.344 .26739 L
.348 .26739 L
.352 .26734 L
.356 .26724 L
.36 .26711 L
.364 .26697 L
.368 .26685 L
.372 .26676 L
.376 .26671 L
.38 .2667 L
.384 .26673 L
.388 .26678 L
.392 .26682 L
.396 .26686 L
.4 .26687 L
Mistroke
.404 .26686 L
.408 .26684 L
.412 .26682 L
.416 .26678 L
.42 .26675 L
.424 .2667 L
.428 .26664 L
.432 .26658 L
.436 .26651 L
.44 .26646 L
.444 .26643 L
.448 .26642 L
.452 .26644 L
.456 .26647 L
.46 .26649 L
.464 .26649 L
.468 .26647 L
.472 .26643 L
.476 .26638 L
.48 .26634 L
.484 .2663 L
.488 .26627 L
.492 .26625 L
.496 .26623 L
.5 .2662 L
.504 .26616 L
.508 .26613 L
.512 .2661 L
.516 .26609 L
.52 .26609 L
.524 .2661 L
.528 .2661 L
.532 .26609 L
.536 .26606 L
.54 .26602 L
.544 .26597 L
.548 .26592 L
.552 .26588 L
.556 .26585 L
.56 .26583 L
.564 .26581 L
.568 .2658 L
.572 .26579 L
.576 .26579 L
.58 .26578 L
.584 .26578 L
.588 .26576 L
.592 .26573 L
.596 .26568 L
.6 .26563 L
Mistroke
.604 .26558 L
.608 .26554 L
.612 .26551 L
.616 .26551 L
.62 .26551 L
.624 .26552 L
.628 .26552 L
.632 .26551 L
.636 .26548 L
.64 .26543 L
.644 .26539 L
.648 .26534 L
.652 .2653 L
.656 .26527 L
.66 .26526 L
.664 .26525 L
.668 .26525 L
.672 .26525 L
.676 .26524 L
.68 .26522 L
.684 .26519 L
.688 .26514 L
.692 .2651 L
.696 .26505 L
.7 .26503 L
.704 .26501 L
.708 .265 L
.712 .265 L
.716 .265 L
.72 .26498 L
.724 .26495 L
.728 .26492 L
.732 .26488 L
.736 .26485 L
.74 .26481 L
.744 .26479 L
.748 .26477 L
.752 .26476 L
.756 .26475 L
.76 .26474 L
.764 .26472 L
.768 .26469 L
.772 .26466 L
.776 .26463 L
.78 .26459 L
.784 .26456 L
.788 .26454 L
.792 .26453 L
.796 .26452 L
.8 .2645 L
Mistroke
.804 .26448 L
.808 .26446 L
.812 .26443 L
.816 .2644 L
.82 .26437 L
.824 .26434 L
.828 .26432 L
.832 .2643 L
.836 .26429 L
.84 .26427 L
.844 .26425 L
.848 .26422 L
.852 .2642 L
.856 .26417 L
.86 .26414 L
.864 .26412 L
.868 .2641 L
.872 .26408 L
.876 .26406 L
.88 .26403 L
.884 .26401 L
.888 .26399 L
.892 .26396 L
.896 .26394 L
.9 .26392 L
.904 .2639 L
.908 .26388 L
.912 .26385 L
.916 .26383 L
.92 .2638 L
.924 .26378 L
.928 .26375 L
.932 .26374 L
.936 .26372 L
.94 .2637 L
.944 .26367 L
.948 .26364 L
.952 .26361 L
.956 .26359 L
.96 .26357 L
.964 .26355 L
.968 .26353 L
.972 .26352 L
.976 .26349 L
.98 .26347 L
.984 .26344 L
.988 .26341 L
.992 .26338 L
.996 .26336 L
1 .26334 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .17466 m
.008 .1652 L
.012 .15826 L
.016 .15378 L
.02 .15156 L
.024 .14908 L
.028 .1464 L
.032 .14379 L
.036 .1412 L
.04 .13846 L
.044 .13556 L
.048 .13256 L
.052 .12939 L
.056 .1261 L
.06 .12266 L
.064 .11915 L
.068 .11559 L
.072 .11205 L
.076 .10858 L
.08 .10523 L
.084 .10204 L
.088 .09901 L
.092 .09613 L
.096 .09335 L
.1 .09065 L
.104 .08793 L
.108 .08515 L
.112 .08226 L
.116 .07923 L
.12 .07603 L
.124 .0727 L
.128 .06926 L
.132 .06576 L
.136 .06225 L
.14 .0588 L
.144 .05546 L
.148 .05227 L
.152 .0493 L
.156 .04659 L
.16 .04415 L
.164 .04202 L
.168 .04019 L
.172 .03866 L
.176 .03739 L
.18 .03635 L
.184 .03547 L
.188 .03469 L
.192 .03397 L
.196 .03327 L
.2 .03259 L
Mistroke
.204 .03195 L
.208 .03136 L
.212 .03086 L
.216 .03048 L
.22 .03022 L
.224 .03007 L
.228 .02999 L
.232 .02995 L
.236 .02989 L
.24 .02977 L
.244 .02959 L
.248 .02935 L
.252 .02909 L
.256 .02885 L
.26 .02867 L
.264 .02857 L
.268 .02856 L
.272 .02861 L
.276 .02871 L
.28 .02883 L
.284 .02893 L
.288 .02901 L
.292 .02908 L
.296 .02913 L
.3 .02918 L
.304 .02924 L
.308 .02931 L
.312 .02938 L
.316 .02942 L
.32 .02942 L
.324 .02937 L
.328 .02927 L
.332 .02914 L
.336 .02899 L
.34 .02887 L
.344 .02878 L
.348 .02876 L
.352 .0288 L
.356 .02891 L
.36 .02904 L
.364 .02919 L
.368 .02933 L
.372 .02942 L
.376 .02945 L
.38 .02944 L
.384 .02938 L
.388 .0293 L
.392 .02922 L
.396 .02916 L
.4 .02912 L
Mistroke
.404 .0291 L
.408 .0291 L
.412 .02911 L
.416 .02913 L
.42 .02916 L
.424 .02919 L
.428 .02924 L
.432 .0293 L
.436 .02936 L
.44 .0294 L
.444 .02942 L
.448 .0294 L
.452 .02936 L
.456 .0293 L
.46 .02925 L
.464 .02922 L
.468 .02922 L
.472 .02925 L
.476 .02929 L
.48 .02933 L
.484 .02935 L
.488 .02936 L
.492 .02936 L
.496 .02937 L
.5 .02938 L
.504 .0294 L
.508 .02943 L
.512 .02944 L
.516 .02943 L
.52 .02941 L
.524 .02938 L
.528 .02935 L
.532 .02934 L
.536 .02935 L
.54 .02938 L
.544 .02942 L
.548 .02946 L
.552 .02949 L
.556 .0295 L
.56 .02951 L
.564 .0295 L
.568 .0295 L
.572 .02948 L
.576 .02947 L
.58 .02945 L
.584 .02944 L
.588 .02944 L
.592 .02945 L
.596 .02949 L
.6 .02953 L
Mistroke
.604 .02957 L
.608 .0296 L
.612 .02961 L
.616 .02959 L
.62 .02956 L
.624 .02953 L
.628 .0295 L
.632 .0295 L
.636 .02952 L
.64 .02955 L
.644 .02959 L
.648 .02962 L
.652 .02965 L
.656 .02966 L
.66 .02965 L
.664 .02964 L
.668 .02962 L
.672 .02961 L
.676 .02959 L
.68 .02959 L
.684 .02961 L
.688 .02964 L
.692 .02968 L
.696 .02971 L
.7 .02973 L
.704 .02972 L
.708 .02971 L
.712 .02969 L
.716 .02967 L
.72 .02967 L
.724 .02968 L
.728 .0297 L
.732 .02973 L
.736 .02975 L
.74 .02977 L
.744 .02978 L
.748 .02978 L
.752 .02977 L
.756 .02976 L
.76 .02975 L
.764 .02975 L
.768 .02976 L
.772 .02978 L
.776 .0298 L
.78 .02982 L
.784 .02983 L
.788 .02983 L
.792 .02983 L
.796 .02983 L
.8 .02983 L
Mistroke
.804 .02983 L
.808 .02984 L
.812 .02985 L
.816 .02986 L
.82 .02987 L
.824 .02988 L
.828 .02989 L
.832 .0299 L
.836 .0299 L
.84 .0299 L
.844 .0299 L
.848 .0299 L
.852 .02991 L
.856 .02992 L
.86 .02993 L
.864 .02995 L
.868 .02996 L
.872 .02997 L
.876 .02997 L
.88 .02997 L
.884 .02996 L
.888 .02997 L
.892 .02998 L
.896 .02999 L
.9 .03 L
.904 .03001 L
.908 .03003 L
.912 .03003 L
.916 .03003 L
.92 .03002 L
.924 .03003 L
.928 .03003 L
.932 .03005 L
.936 .03006 L
.94 .03008 L
.944 .03008 L
.948 .03009 L
.952 .03009 L
.956 .03009 L
.96 .03008 L
.964 .03009 L
.968 .0301 L
.972 .03012 L
.976 .03013 L
.98 .03015 L
.984 .03015 L
.988 .03015 L
.992 .03014 L
.996 .03015 L
1 .03015 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P001Goo00<007ooOol01Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo
0`0017oo0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00=oo`<000Eoo`05001o
ogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool01@00Oomoogoo00000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol0009oo`03001oogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20004Ool00`00
Ool00009Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
0goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Aoo`04001oogoo
0002Ool30003Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`<0009oo`06001oogoo
Ool007oo0P0000=oo`0000000P000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool0
00]oo`8000Yoo`8000Aoo`03001oogoo009oo`H000Aoo`80009oo`8000Eoo`04001oogoo0006Ool2
0004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`00
00Ioo`04001oogoo0005Ool0029oo`800003Ool0000000Uoo`D000=oo`8000Qoo`03001oogoo00=o
o`8000Aoo`8000Ioo`04001oogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool5
0003Ool20006Ool0029oo`03001oogoo00eoo`03001oogoo05aoo`008Woo0P003goo00@007ooOol0
05Yoo`008WooH`0037oo000ROol01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oo`00
00<0009oo`800005Ool00000001oo`0500000goo00000007000017oo000007oo0`0000=oo`000000
:`0037oo000ROol2000DOol20002Ool20002Ool20002Ool30002Ool200000goo00000002Ool20000
17oo000007oo0P0000Aoo`00001oo`8001Eoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo
00Yoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo
009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo
00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0
00=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007oo
Ool006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo
001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001o
ogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000
Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001o
ogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2
001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo
0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomo
o`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007oo
Ool0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo0080
06Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0
IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo
06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015o
o`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo
06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo
001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001o
ogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo
008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=o
o`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00
009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<0
07ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001o
ogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eo
o`00:7oo00<007ooOol02Goo00<007ooOol017ooBP000goo00@007ooOol000Eoo`00:7oo00<007oo
Ool02Goo1`0000=oo`00000027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=o
o`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol02Woo
0`00FGoo000XOol00`00Oomoo`08Ool3001KOol002Qooed000aoo`00:7oo00<007ooOol00Woo1000
2Goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol0
2Woo000XOol00`00Oomoo`03001SOol002Qoo`<006Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo
0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`04
0003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007oo
Ool006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02
001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomo
ogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02
Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`00
2goo00@007ooOol0015ooeL000aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo00eoo`<0
069oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8000eoo`8006Aoo`002goo0P0027oo1@00
0Woo00<007ooOol02goo0P00IGoo000LOol00`00Oomoo`0:Ool00`00Oomoo`030004Ool20009Ool3
0004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool3
0004Ool20006Ool001aoo`8000Uoo`80009oo`05001oogooOol00002Ool01000Oomoo`002Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0
009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001o
ogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol01goo0P001goo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo
00<007ooOol01Goo0`0027oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0
009oo`03001oogoo00=oo`0077oo0P001Woo00<007ooOol017oo10000goo00@007ooOol000Uoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo
0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001o
o`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00=oo`8000Moo`03001oogoo00Aoo`04001o
ogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomo
ogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000=oo`8000Qoo`D000=oo`8000Yoo`03001o
ogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool3
0002Ool50003Ool20006Ool001aoo`04001oogooOol2001_Ool001aoo`04001oo`00001aOol001ao
ofT000aoo`0077oo0P000Woo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`8007=o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000L
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001o
ogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool4
0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`80
00Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo
00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo
009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1b
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=o
o`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<0
07ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool0
0`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo
079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(25050\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29908 m
.008 .30234 L
.012 .30313 L
.016 .30255 L
.02 .30084 L
.024 .29484 L
.028 .28484 L
.032 .27216 L
.036 .25825 L
.04 .24576 L
.044 .23582 L
.048 .22969 L
.052 .22763 L
.056 .2293 L
.06 .23394 L
.064 .24019 L
.068 .24687 L
.072 .25258 L
.076 .25662 L
.08 .25854 L
.084 .25862 L
.088 .25744 L
.092 .25581 L
.096 .25457 L
.1 .25416 L
.104 .25488 L
.108 .25645 L
.112 .25854 L
.116 .26065 L
.12 .26252 L
.124 .26409 L
.128 .26561 L
.132 .26744 L
.136 .26989 L
.14 .27301 L
.144 .27642 L
.148 .27944 L
.152 .28115 L
.156 .28081 L
.16 .27809 L
.164 .27336 L
.168 .26766 L
.172 .26258 L
.176 .25981 L
.18 .26064 L
.184 .26552 L
.188 .27382 L
.192 .28396 L
.196 .29379 L
.2 .30126 L
Mistroke
.204 .30497 L
.208 .30467 L
.212 .30129 L
.216 .29672 L
.22 .29313 L
.224 .29233 L
.228 .29517 L
.232 .30127 L
.236 .30917 L
.24 .31683 L
.244 .32236 L
.248 .32462 L
.252 .32358 L
.256 .32028 L
.26 .31635 L
.264 .31341 L
.268 .31251 L
.272 .31381 L
.276 .31661 L
.28 .3197 L
.284 .32187 L
.288 .32234 L
.292 .32101 L
.296 .31843 L
.3 .31554 L
.304 .31329 L
.308 .31233 L
.312 .31283 L
.316 .31451 L
.32 .31684 L
.324 .3192 L
.328 .32113 L
.332 .32232 L
.336 .32261 L
.34 .322 L
.344 .32056 L
.348 .31857 L
.352 .31648 L
.356 .31487 L
.36 .31428 L
.364 .31493 L
.368 .31661 L
.372 .31865 L
.376 .3202 L
.38 .32056 L
.384 .31959 L
.388 .31779 L
.392 .31611 L
.396 .3155 L
.4 .31639 L
Mistroke
.404 .31846 L
.408 .32073 L
.412 .32202 L
.416 .32155 L
.42 .31939 L
.424 .31647 L
.428 .31417 L
.432 .31363 L
.436 .31514 L
.44 .31798 L
.444 .32076 L
.448 .3221 L
.452 .3214 L
.456 .31909 L
.46 .31647 L
.464 .31497 L
.468 .31536 L
.472 .31737 L
.476 .31982 L
.48 .3213 L
.484 .32097 L
.488 .31903 L
.492 .31656 L
.496 .31497 L
.5 .31512 L
.504 .31692 L
.508 .31931 L
.512 .32098 L
.516 .32105 L
.52 .31961 L
.524 .31759 L
.528 .31615 L
.532 .31607 L
.536 .31723 L
.54 .31884 L
.544 .31988 L
.548 .31975 L
.552 .31863 L
.556 .31729 L
.56 .3166 L
.564 .31699 L
.568 .31816 L
.572 .31937 L
.576 .31989 L
.58 .31945 L
.584 .31836 L
.588 .31729 L
.592 .31685 L
.596 .31723 L
.6 .31815 L
Mistroke
.604 .31901 L
.608 .31933 L
.612 .319 L
.616 .31831 L
.62 .31772 L
.624 .31757 L
.628 .3179 L
.632 .31843 L
.636 .31884 L
.64 .31889 L
.644 .31857 L
.648 .31809 L
.652 .31775 L
.656 .31775 L
.66 .31811 L
.664 .31861 L
.668 .31893 L
.672 .31888 L
.676 .31849 L
.68 .31803 L
.684 .31778 L
.688 .3179 L
.692 .31833 L
.696 .31878 L
.7 .31895 L
.704 .31871 L
.708 .3182 L
.712 .31777 L
.716 .31774 L
.72 .31818 L
.724 .31881 L
.728 .31917 L
.732 .319 L
.736 .3184 L
.74 .3178 L
.744 .31763 L
.748 .31798 L
.752 .31857 L
.756 .31898 L
.76 .31897 L
.764 .3186 L
.768 .3182 L
.772 .31804 L
.776 .31818 L
.78 .31844 L
.784 .3186 L
.788 .31858 L
.792 .31845 L
.796 .31836 L
.8 .31842 L
Mistroke
.804 .31854 L
.808 .31857 L
.812 .31845 L
.816 .31827 L
.82 .31822 L
.824 .31844 L
.828 .31877 L
.832 .31893 L
.836 .3187 L
.84 .31819 L
.844 .31782 L
.848 .31796 L
.852 .31856 L
.856 .31919 L
.86 .31934 L
.864 .31883 L
.868 .31809 L
.872 .31769 L
.876 .31788 L
.88 .3185 L
.884 .31902 L
.888 .31908 L
.892 .31882 L
.896 .31853 L
.9 .31836 L
.904 .31837 L
.908 .31836 L
.912 .31826 L
.916 .31833 L
.92 .31862 L
.924 .31895 L
.928 .31913 L
.932 .3189 L
.936 .31835 L
.94 .318 L
.944 .31807 L
.948 .31842 L
.952 .31886 L
.956 .31902 L
.96 .31884 L
.964 .31867 L
.968 .31861 L
.972 .31848 L
.976 .3184 L
.98 .31836 L
.984 .3183 L
.988 .31861 L
.992 .31907 L
.996 .31909 L
1 .3189 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .39549 m
.008 .38859 L
.012 .38264 L
.016 .37766 L
.02 .37198 L
.024 .36537 L
.028 .35884 L
.032 .35281 L
.036 .34866 L
.04 .34629 L
.044 .34484 L
.048 .34404 L
.052 .34338 L
.056 .34269 L
.06 .34181 L
.064 .34071 L
.068 .33938 L
.072 .33783 L
.076 .33612 L
.08 .33431 L
.084 .33248 L
.088 .33068 L
.092 .32895 L
.096 .32733 L
.1 .32581 L
.104 .3244 L
.108 .32305 L
.112 .32174 L
.116 .32041 L
.12 .31902 L
.124 .31753 L
.128 .3159 L
.132 .3141 L
.136 .31211 L
.14 .30992 L
.144 .30754 L
.148 .305 L
.152 .30235 L
.156 .29963 L
.16 .29692 L
.164 .29426 L
.168 .29172 L
.172 .28932 L
.176 .28708 L
.18 .285 L
.184 .28305 L
.188 .28122 L
.192 .27949 L
.196 .27786 L
.2 .27635 L
Mistroke
.204 .27497 L
.208 .27376 L
.212 .27274 L
.216 .2719 L
.22 .27125 L
.224 .27076 L
.228 .27037 L
.232 .27005 L
.236 .26975 L
.24 .26946 L
.244 .26915 L
.248 .26885 L
.252 .26856 L
.256 .2683 L
.26 .26809 L
.264 .26792 L
.268 .26779 L
.272 .26768 L
.276 .26758 L
.28 .26748 L
.284 .26739 L
.288 .26732 L
.292 .26727 L
.296 .26725 L
.3 .26728 L
.304 .26735 L
.308 .26744 L
.312 .26753 L
.316 .26759 L
.32 .26762 L
.324 .26759 L
.328 .26751 L
.332 .26739 L
.336 .26725 L
.34 .26712 L
.344 .26701 L
.348 .26694 L
.352 .26691 L
.356 .26692 L
.36 .26696 L
.364 .26701 L
.368 .26706 L
.372 .26709 L
.376 .26709 L
.38 .26707 L
.384 .26705 L
.388 .26701 L
.392 .26697 L
.396 .26693 L
.4 .26688 L
Mistroke
.404 .26682 L
.408 .26676 L
.412 .2667 L
.416 .26666 L
.42 .26664 L
.424 .26664 L
.428 .26666 L
.432 .26669 L
.436 .2667 L
.44 .2667 L
.444 .26667 L
.448 .26663 L
.452 .26658 L
.456 .26653 L
.46 .26649 L
.464 .26647 L
.468 .26645 L
.472 .26643 L
.476 .2664 L
.48 .26637 L
.484 .26633 L
.488 .26631 L
.492 .2663 L
.496 .2663 L
.5 .26631 L
.504 .26631 L
.508 .26629 L
.512 .26626 L
.516 .26621 L
.52 .26616 L
.524 .26611 L
.528 .26607 L
.532 .26605 L
.536 .26603 L
.54 .26602 L
.544 .26601 L
.548 .26601 L
.552 .266 L
.556 .26599 L
.56 .26598 L
.564 .26595 L
.568 .26592 L
.572 .26587 L
.576 .26582 L
.58 .26577 L
.584 .26574 L
.588 .26572 L
.592 .26572 L
.596 .26573 L
.6 .26574 L
Mistroke
.604 .26573 L
.608 .26571 L
.612 .26567 L
.616 .26562 L
.62 .26558 L
.624 .26553 L
.628 .2655 L
.632 .26548 L
.636 .26547 L
.64 .26546 L
.644 .26546 L
.648 .26546 L
.652 .26544 L
.656 .26542 L
.66 .26538 L
.664 .26534 L
.668 .26529 L
.672 .26525 L
.676 .26523 L
.68 .26521 L
.684 .26521 L
.688 .26521 L
.692 .2652 L
.696 .26519 L
.7 .26516 L
.704 .26512 L
.708 .26508 L
.712 .26504 L
.716 .26501 L
.72 .26499 L
.724 .26498 L
.728 .26497 L
.732 .26496 L
.736 .26494 L
.74 .26492 L
.744 .26489 L
.748 .26486 L
.752 .26482 L
.756 .26479 L
.76 .26477 L
.764 .26475 L
.768 .26473 L
.772 .26472 L
.776 .2647 L
.78 .26468 L
.784 .26466 L
.788 .26463 L
.792 .2646 L
.796 .26457 L
.8 .26455 L
Mistroke
.804 .26452 L
.808 .2645 L
.812 .26449 L
.816 .26447 L
.82 .26445 L
.824 .26443 L
.828 .2644 L
.832 .26437 L
.836 .26435 L
.84 .26432 L
.844 .2643 L
.848 .26427 L
.852 .26426 L
.856 .26424 L
.86 .26422 L
.864 .2642 L
.868 .26417 L
.872 .26414 L
.876 .26412 L
.88 .26409 L
.884 .26407 L
.888 .26405 L
.892 .26403 L
.896 .26401 L
.9 .26399 L
.904 .26397 L
.908 .26394 L
.912 .26391 L
.916 .26389 L
.92 .26386 L
.924 .26384 L
.928 .26382 L
.932 .26381 L
.936 .26379 L
.94 .26376 L
.944 .26373 L
.948 .2637 L
.952 .26368 L
.956 .26366 L
.96 .26364 L
.964 .26362 L
.968 .2636 L
.972 .26358 L
.976 .26355 L
.98 .26353 L
.984 .2635 L
.988 .26348 L
.992 .26345 L
.996 .26344 L
1 .26341 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .21954 m
.008 .21477 L
.012 .20376 L
.016 .19498 L
.02 .18825 L
.024 .1797 L
.028 .1694 L
.032 .16073 L
.036 .154 L
.04 .14884 L
.044 .14499 L
.048 .1416 L
.052 .13853 L
.056 .13548 L
.06 .13243 L
.064 .12935 L
.068 .12628 L
.072 .12321 L
.076 .12015 L
.08 .11711 L
.084 .11408 L
.088 .11109 L
.092 .10813 L
.096 .10521 L
.1 .10237 L
.104 .09959 L
.108 .0969 L
.112 .09429 L
.116 .09176 L
.12 .08928 L
.124 .08685 L
.128 .08445 L
.132 .08206 L
.136 .07967 L
.14 .07728 L
.144 .07487 L
.148 .07243 L
.152 .06995 L
.156 .06741 L
.16 .0648 L
.164 .06211 L
.168 .05935 L
.172 .05654 L
.176 .05374 L
.18 .051 L
.184 .04839 L
.188 .04597 L
.192 .04379 L
.196 .04185 L
.2 .04015 L
Mistroke
.204 .03866 L
.208 .03733 L
.212 .03611 L
.216 .03496 L
.22 .03389 L
.224 .0329 L
.228 .03201 L
.232 .03125 L
.236 .03066 L
.24 .03022 L
.244 .02994 L
.248 .02977 L
.252 .02968 L
.256 .02964 L
.26 .02961 L
.264 .02958 L
.268 .02956 L
.272 .02954 L
.276 .02954 L
.28 .02955 L
.284 .02958 L
.288 .02961 L
.292 .02962 L
.296 .02958 L
.3 .0295 L
.304 .02938 L
.308 .02924 L
.312 .0291 L
.316 .02899 L
.32 .02893 L
.324 .02894 L
.328 .02901 L
.332 .02913 L
.336 .02928 L
.34 .02942 L
.344 .02954 L
.348 .0296 L
.352 .02961 L
.356 .02957 L
.36 .0295 L
.364 .02941 L
.368 .02934 L
.372 .02928 L
.376 .02925 L
.38 .02925 L
.384 .02926 L
.388 .02928 L
.392 .02931 L
.396 .02934 L
.4 .02938 L
Mistroke
.404 .02943 L
.408 .02948 L
.412 .02953 L
.416 .02956 L
.42 .02956 L
.424 .02954 L
.428 .02949 L
.432 .02943 L
.436 .02939 L
.44 .02937 L
.444 .02938 L
.448 .02941 L
.452 .02946 L
.456 .02949 L
.46 .02952 L
.464 .02952 L
.468 .02953 L
.472 .02953 L
.476 .02954 L
.48 .02956 L
.484 .02958 L
.488 .02959 L
.492 .02958 L
.496 .02955 L
.5 .02952 L
.504 .0295 L
.508 .0295 L
.512 .02951 L
.516 .02955 L
.52 .02959 L
.524 .02963 L
.528 .02965 L
.532 .02966 L
.536 .02966 L
.54 .02965 L
.544 .02964 L
.548 .02963 L
.552 .02961 L
.556 .0296 L
.56 .02959 L
.564 .0296 L
.568 .02962 L
.572 .02966 L
.576 .0297 L
.58 .02974 L
.584 .02976 L
.588 .02976 L
.592 .02974 L
.596 .0297 L
.6 .02967 L
Mistroke
.604 .02966 L
.608 .02966 L
.612 .02968 L
.616 .02972 L
.62 .02976 L
.624 .02979 L
.628 .02981 L
.632 .02981 L
.636 .0298 L
.64 .02979 L
.644 .02977 L
.648 .02975 L
.652 .02974 L
.656 .02975 L
.66 .02978 L
.664 .02981 L
.668 .02984 L
.672 .02987 L
.676 .02988 L
.68 .02987 L
.684 .02985 L
.688 .02983 L
.692 .02982 L
.696 .02982 L
.7 .02984 L
.704 .02986 L
.708 .02989 L
.712 .02991 L
.716 .02992 L
.72 .02993 L
.724 .02993 L
.728 .02992 L
.732 .02991 L
.736 .0299 L
.74 .0299 L
.744 .02992 L
.748 .02994 L
.752 .02996 L
.756 .02998 L
.76 .02999 L
.764 .02999 L
.768 .02998 L
.772 .02998 L
.776 .02997 L
.78 .02998 L
.784 .02999 L
.788 .03 L
.792 .03002 L
.796 .03003 L
.8 .03004 L
Mistroke
.804 .03005 L
.808 .03005 L
.812 .03004 L
.816 .03004 L
.82 .03005 L
.824 .03006 L
.828 .03007 L
.832 .03008 L
.836 .03009 L
.84 .0301 L
.844 .0301 L
.848 .03011 L
.852 .03011 L
.856 .03012 L
.86 .03012 L
.864 .03013 L
.868 .03014 L
.872 .03014 L
.876 .03015 L
.88 .03016 L
.884 .03017 L
.888 .03017 L
.892 .03018 L
.896 .03019 L
.9 .03019 L
.904 .03019 L
.908 .0302 L
.912 .0302 L
.916 .03021 L
.92 .03022 L
.924 .03024 L
.928 .03025 L
.932 .03026 L
.936 .03025 L
.94 .03025 L
.944 .03025 L
.948 .03026 L
.952 .03027 L
.956 .03029 L
.96 .0303 L
.964 .03031 L
.968 .03031 L
.972 .03032 L
.976 .03031 L
.98 .03031 L
.984 .03031 L
.988 .03033 L
.992 .03034 L
.996 .03037 L
1 .03037 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20002Ool3000;Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`80009oo`04001oo`00000:Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000Aoo`05001oogooOol00002Ool50002Ool40003Ool01000Oomoo`001goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol0
009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogooOol007oo
10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo0P000Woo00D007oo
Oomoo`00009oo`@0009oo`80009oo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0029oo`80
0003Ool007oo00Qoo`H000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`04001oogoo
000;Ool01@00Oomoogoo0000Fgoo000ROol3000@Ool01000Ool00000F7oo000ROomS000<Ool0029o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`D00003Ool00000
00800005Ool00000001oo`0600000goo0000000300000goo0000000300000goo0000000X000<Ool0
029oo`8001Ioo`800004Ool000000002Ool30002Ool2000017oo000007oo0P000Woo00<007ooOol0
0P0000Aoo`00001oo`800003Ool007oo01Moo`03001oogoo01Qoo`008Woo00<007ooOol0K7oo000R
Ool2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007oo
Ool0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool2
0004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P00
17oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2
001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo
0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03
001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006io
o`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`00
8Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@0
07ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
2Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03
001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Ao
o`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Ao
o`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<0
07ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Ao
o`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo
10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@0
07ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007oo
Ool017oo00<007ooOol0A`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@0000=oo`00
00000P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Ao
o`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol03Goo0P00Egoo000XOol0
0`00Oomoo`0;Ool2001IOol002Qooed000aoo`00:7oo00<007ooOol01goo0`001Goo00<007ooOol0
47oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00
Oomoo`04Ool3001OOol002Qoo`04001oogooOol4001QOol002Qoo`03001oogoo008006Aoo`00:7oo
00@007oo000006Eoo`00:7oo00<007oo0000IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool2
0003Ool30003Ool2001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005
Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool0
0`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool0
00Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo
0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03
001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomo
o`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo0080
06Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogoo
Ool5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009o
o`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;
Ool01000Oomoo`005GooD`0037oo000:Ool01000Oomoo`001goo10000goo00<007ooOol04Goo0P00
Ggoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P0047oo0P00HGoo000;Ool20008Ool50002
Ool00`00Oomoo`0>Ool2001ROol001aoo`03001oogoo00aoo`@000Aoo`8000Uoo`<000Aoo`8000Ao
o`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Io
o`0077oo0P002goo0`000goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo00Uoo`8000Eoo`04001oogoo0002Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo00Moo`80
00Moo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03
Ool001aoo`8000Moo`8000Aoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000LOol00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo
00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool0
1000Oomoo`001Goo000LOol20004Ool20007Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool2
0006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P00
1Woo000LOol00`00Oomoo`02Ool2001^Ool001aoo`04001oogooOol2001_Ool001aoofT000aoo`00
77oo00<007ooOol00P000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00@007ooOol0
075oo`0077oo0`00LWoo000LOol00`00Ool0001bOol001aoo`8007=oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo
008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qo
o`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<0
07ooOol00Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009o
o`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`80
07=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007oo
Ool02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00
Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079o
o`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo
079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(25217\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .27811 m
.008 .27133 L
.012 .26451 L
.016 .25939 L
.02 .25659 L
.024 .25678 L
.028 .25976 L
.032 .2649 L
.036 .27229 L
.04 .28199 L
.044 .29251 L
.048 .29984 L
.052 .30282 L
.056 .30137 L
.06 .2961 L
.064 .28894 L
.068 .28096 L
.072 .27343 L
.076 .26691 L
.08 .26175 L
.084 .258 L
.088 .25548 L
.092 .25416 L
.096 .25392 L
.1 .255 L
.104 .25755 L
.108 .26177 L
.112 .26757 L
.116 .27446 L
.12 .28159 L
.124 .28771 L
.128 .29168 L
.132 .29252 L
.136 .28999 L
.14 .28454 L
.144 .27744 L
.148 .27038 L
.152 .26509 L
.156 .26276 L
.16 .26373 L
.164 .26729 L
.168 .27191 L
.172 .27571 L
.176 .27706 L
.18 .27514 L
.184 .27025 L
.188 .26378 L
.192 .25779 L
.196 .25439 L
.2 .25504 L
Mistroke
.204 .26009 L
.208 .26863 L
.212 .27877 L
.216 .28832 L
.22 .29541 L
.224 .29916 L
.228 .2998 L
.232 .29856 L
.236 .29712 L
.24 .29696 L
.244 .29889 L
.248 .30278 L
.252 .30771 L
.256 .31236 L
.26 .31554 L
.264 .31664 L
.268 .31576 L
.272 .31368 L
.276 .31149 L
.28 .31016 L
.284 .31024 L
.288 .31175 L
.292 .31424 L
.296 .31707 L
.3 .3196 L
.304 .32142 L
.308 .32229 L
.312 .32217 L
.316 .32116 L
.32 .31947 L
.324 .31745 L
.328 .31557 L
.332 .31437 L
.336 .31423 L
.34 .31524 L
.344 .31705 L
.348 .31898 L
.352 .32026 L
.356 .32036 L
.36 .31927 L
.364 .31755 L
.368 .31609 L
.372 .31571 L
.376 .31672 L
.38 .31874 L
.384 .32078 L
.388 .32176 L
.392 .32104 L
.396 .31878 L
.4 .31596 L
Mistroke
.404 .31391 L
.408 .31368 L
.412 .31545 L
.416 .31839 L
.42 .32107 L
.424 .32219 L
.428 .32122 L
.432 .31876 L
.436 .31613 L
.44 .31476 L
.444 .31535 L
.448 .31749 L
.452 .31995 L
.456 .3213 L
.46 .32079 L
.464 .31871 L
.468 .31625 L
.472 .3148 L
.476 .31515 L
.48 .31709 L
.484 .31952 L
.488 .3211 L
.492 .32102 L
.496 .31943 L
.5 .31733 L
.504 .31592 L
.508 .31593 L
.512 .3172 L
.516 .31886 L
.52 .31986 L
.524 .31968 L
.528 .31852 L
.532 .31719 L
.536 .31655 L
.54 .31699 L
.544 .3182 L
.548 .31939 L
.552 .31984 L
.556 .31929 L
.56 .31814 L
.564 .3171 L
.568 .31676 L
.572 .31724 L
.576 .31819 L
.58 .319 L
.584 .31925 L
.588 .31887 L
.592 .31819 L
.596 .31766 L
.6 .31759 L
Mistroke
.604 .31794 L
.608 .31842 L
.612 .3187 L
.616 .31863 L
.62 .31831 L
.624 .31798 L
.628 .31783 L
.632 .31795 L
.636 .31824 L
.64 .31854 L
.644 .31866 L
.648 .31855 L
.652 .31828 L
.656 .31803 L
.66 .31796 L
.664 .31811 L
.668 .31836 L
.672 .31854 L
.676 .31853 L
.68 .31834 L
.684 .31811 L
.688 .31799 L
.692 .31811 L
.696 .3184 L
.7 .31868 L
.704 .31873 L
.708 .31848 L
.712 .31808 L
.716 .31782 L
.72 .31793 L
.724 .31835 L
.728 .31876 L
.732 .31885 L
.736 .31853 L
.74 .31807 L
.744 .31784 L
.748 .31805 L
.752 .31853 L
.756 .3189 L
.76 .31885 L
.764 .3184 L
.768 .31787 L
.772 .31769 L
.776 .31802 L
.78 .31865 L
.784 .31912 L
.788 .31909 L
.792 .31855 L
.796 .3179 L
.8 .31763 L
Mistroke
.804 .3179 L
.808 .31851 L
.812 .31899 L
.816 .319 L
.82 .31862 L
.824 .31819 L
.828 .31804 L
.832 .3182 L
.836 .31844 L
.84 .31854 L
.844 .3185 L
.848 .31847 L
.852 .31855 L
.856 .31867 L
.86 .31861 L
.864 .31831 L
.868 .31803 L
.872 .31804 L
.876 .31842 L
.88 .31894 L
.884 .31915 L
.888 .31884 L
.892 .31827 L
.896 .31784 L
.9 .31785 L
.904 .31832 L
.908 .31883 L
.912 .31906 L
.916 .31901 L
.92 .3187 L
.924 .31833 L
.928 .31811 L
.932 .31803 L
.936 .31814 L
.94 .31851 L
.944 .31893 L
.948 .31913 L
.952 .31905 L
.956 .31865 L
.96 .31813 L
.964 .31795 L
.968 .31811 L
.972 .31838 L
.976 .3188 L
.98 .31903 L
.984 .31898 L
.988 .31895 L
.992 .31868 L
.996 .31822 L
1 .31798 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .43124 m
.008 .43023 L
.012 .42663 L
.016 .42039 L
.02 .41511 L
.024 .41062 L
.028 .40579 L
.032 .40069 L
.036 .39591 L
.04 .39118 L
.044 .38535 L
.048 .3784 L
.052 .37152 L
.056 .36518 L
.06 .36015 L
.064 .35649 L
.068 .35388 L
.072 .35208 L
.076 .35065 L
.08 .3494 L
.084 .34814 L
.088 .34678 L
.092 .34526 L
.096 .34357 L
.1 .34171 L
.104 .3397 L
.108 .33758 L
.112 .33536 L
.116 .33309 L
.12 .33081 L
.124 .32855 L
.128 .32635 L
.132 .32424 L
.136 .32224 L
.14 .32035 L
.144 .31856 L
.148 .31683 L
.152 .31514 L
.156 .3134 L
.16 .31159 L
.164 .30965 L
.168 .30756 L
.172 .30532 L
.176 .30297 L
.18 .30055 L
.184 .29811 L
.188 .29571 L
.192 .29338 L
.196 .29115 L
.2 .28901 L
Mistroke
.204 .28695 L
.208 .28497 L
.212 .28306 L
.216 .28122 L
.22 .27946 L
.224 .27782 L
.228 .27631 L
.232 .27496 L
.236 .27377 L
.24 .27273 L
.244 .27184 L
.248 .27108 L
.252 .27042 L
.256 .26984 L
.26 .26936 L
.264 .26895 L
.268 .26863 L
.272 .26841 L
.276 .26826 L
.28 .26818 L
.284 .26815 L
.288 .26812 L
.292 .26809 L
.296 .26802 L
.3 .26792 L
.304 .26779 L
.308 .26763 L
.312 .26747 L
.316 .26732 L
.32 .26721 L
.324 .26715 L
.328 .26714 L
.332 .26716 L
.336 .26721 L
.34 .26726 L
.344 .2673 L
.348 .26731 L
.352 .26731 L
.356 .26728 L
.36 .26725 L
.364 .26721 L
.368 .26716 L
.372 .26711 L
.376 .26706 L
.38 .267 L
.384 .26694 L
.388 .2669 L
.392 .26686 L
.396 .26685 L
.4 .26686 L
Mistroke
.404 .26688 L
.408 .26691 L
.412 .26692 L
.416 .26691 L
.42 .26687 L
.424 .26682 L
.428 .26677 L
.432 .26672 L
.436 .26669 L
.44 .26666 L
.444 .26665 L
.448 .26662 L
.452 .2666 L
.456 .26657 L
.46 .26654 L
.464 .26652 L
.468 .26651 L
.472 .26651 L
.476 .26651 L
.48 .26651 L
.484 .26649 L
.488 .26645 L
.492 .26641 L
.496 .26635 L
.5 .26631 L
.504 .26627 L
.508 .26625 L
.512 .26624 L
.516 .26623 L
.52 .26622 L
.524 .26622 L
.528 .26621 L
.532 .2662 L
.536 .26618 L
.54 .26615 L
.544 .26611 L
.548 .26606 L
.552 .26601 L
.556 .26597 L
.56 .26594 L
.564 .26593 L
.568 .26593 L
.572 .26594 L
.576 .26594 L
.58 .26594 L
.584 .26591 L
.588 .26587 L
.592 .26582 L
.596 .26577 L
.6 .26573 L
Mistroke
.604 .2657 L
.608 .26568 L
.612 .26568 L
.616 .26567 L
.62 .26567 L
.624 .26566 L
.628 .26565 L
.632 .26562 L
.636 .26558 L
.64 .26553 L
.644 .26549 L
.648 .26545 L
.652 .26543 L
.656 .26542 L
.66 .26542 L
.664 .26542 L
.668 .26541 L
.672 .26539 L
.676 .26535 L
.68 .26531 L
.684 .26527 L
.688 .26524 L
.692 .26521 L
.696 .2652 L
.7 .26518 L
.704 .26517 L
.708 .26516 L
.712 .26515 L
.716 .26512 L
.72 .26509 L
.724 .26506 L
.728 .26502 L
.732 .26499 L
.736 .26497 L
.74 .26495 L
.744 .26494 L
.748 .26493 L
.752 .26491 L
.756 .26489 L
.76 .26486 L
.764 .26483 L
.768 .2648 L
.772 .26477 L
.776 .26475 L
.78 .26473 L
.784 .26471 L
.788 .26469 L
.792 .26468 L
.796 .26465 L
.8 .26463 L
Mistroke
.804 .2646 L
.808 .26457 L
.812 .26455 L
.816 .26452 L
.82 .2645 L
.824 .26448 L
.828 .26446 L
.832 .26444 L
.836 .26442 L
.84 .2644 L
.844 .26437 L
.848 .26435 L
.852 .26432 L
.856 .2643 L
.86 .26428 L
.864 .26425 L
.868 .26423 L
.872 .26421 L
.876 .26419 L
.88 .26417 L
.884 .26415 L
.888 .26412 L
.892 .2641 L
.896 .26407 L
.9 .26404 L
.904 .26402 L
.908 .264 L
.912 .26398 L
.916 .26397 L
.92 .26394 L
.924 .26392 L
.928 .26389 L
.932 .26386 L
.936 .26384 L
.94 .26381 L
.944 .26379 L
.948 .26378 L
.952 .26376 L
.956 .26374 L
.96 .26372 L
.964 .26369 L
.968 .26365 L
.972 .26363 L
.976 .2636 L
.98 .26359 L
.984 .26357 L
.988 .26356 L
.992 .26353 L
.996 .26351 L
1 .26348 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .26441 m
.008 .25763 L
.012 .24817 L
.016 .23948 L
.02 .23174 L
.024 .22351 L
.028 .21464 L
.032 .20643 L
.036 .19903 L
.04 .19125 L
.044 .18265 L
.048 .17329 L
.052 .16359 L
.056 .15508 L
.06 .14809 L
.064 .1427 L
.068 .13869 L
.072 .13545 L
.076 .13273 L
.08 .13014 L
.084 .12759 L
.088 .12497 L
.092 .12228 L
.096 .11954 L
.1 .11678 L
.104 .11405 L
.108 .11141 L
.112 .10889 L
.116 .10652 L
.12 .10433 L
.124 .1023 L
.128 .10039 L
.132 .09856 L
.136 .09675 L
.14 .0949 L
.144 .09295 L
.148 .09088 L
.152 .08867 L
.156 .08634 L
.16 .08389 L
.164 .08135 L
.168 .07874 L
.172 .07608 L
.176 .07334 L
.18 .07052 L
.184 .0676 L
.188 .0646 L
.192 .06152 L
.196 .05842 L
.2 .05535 L
Mistroke
.204 .0524 L
.208 .04963 L
.212 .04708 L
.216 .04479 L
.22 .04276 L
.224 .04097 L
.228 .03938 L
.232 .03797 L
.236 .03672 L
.24 .0356 L
.244 .03461 L
.248 .03377 L
.252 .03305 L
.256 .03246 L
.26 .03197 L
.264 .03155 L
.268 .03118 L
.272 .03083 L
.276 .0305 L
.28 .03018 L
.284 .02988 L
.288 .02963 L
.292 .02944 L
.296 .02934 L
.3 .02932 L
.304 .02937 L
.308 .02947 L
.312 .02959 L
.316 .02971 L
.32 .02978 L
.324 .02981 L
.328 .02978 L
.332 .02972 L
.336 .02963 L
.34 .02954 L
.344 .02946 L
.348 .02941 L
.352 .02939 L
.356 .0294 L
.36 .02942 L
.364 .02945 L
.368 .02949 L
.372 .02952 L
.376 .02956 L
.38 .02961 L
.384 .02966 L
.388 .0297 L
.392 .02972 L
.396 .02971 L
.4 .02967 L
Mistroke
.404 .02962 L
.408 .02957 L
.412 .02953 L
.416 .02952 L
.42 .02954 L
.424 .02958 L
.428 .02962 L
.432 .02966 L
.436 .02968 L
.44 .02969 L
.444 .02969 L
.448 .02969 L
.452 .0297 L
.456 .02972 L
.46 .02973 L
.464 .02973 L
.468 .02972 L
.472 .0297 L
.476 .02967 L
.48 .02966 L
.484 .02966 L
.488 .02968 L
.492 .02972 L
.496 .02976 L
.5 .0298 L
.504 .02982 L
.508 .02982 L
.512 .02982 L
.516 .0298 L
.52 .02978 L
.524 .02977 L
.528 .02976 L
.532 .02975 L
.536 .02975 L
.54 .02977 L
.544 .02979 L
.548 .02983 L
.552 .02987 L
.556 .0299 L
.56 .02991 L
.564 .02991 L
.568 .02988 L
.572 .02985 L
.576 .02982 L
.58 .0298 L
.584 .02981 L
.588 .02984 L
.592 .02989 L
.596 .02993 L
.6 .02995 L
Mistroke
.604 .02997 L
.608 .02996 L
.612 .02995 L
.616 .02993 L
.62 .02991 L
.624 .0299 L
.628 .0299 L
.632 .02991 L
.636 .02994 L
.64 .02997 L
.644 .03 L
.648 .03003 L
.652 .03003 L
.656 .03002 L
.66 .03 L
.664 .02998 L
.668 .02997 L
.672 .02997 L
.676 .02999 L
.68 .03002 L
.684 .03005 L
.688 .03007 L
.692 .03008 L
.696 .03008 L
.7 .03007 L
.704 .03006 L
.708 .03005 L
.712 .03005 L
.716 .03006 L
.72 .03008 L
.724 .0301 L
.728 .03012 L
.732 .03013 L
.736 .03014 L
.74 .03014 L
.744 .03013 L
.748 .03013 L
.752 .03013 L
.756 .03013 L
.76 .03014 L
.764 .03016 L
.768 .03017 L
.772 .03019 L
.776 .0302 L
.78 .0302 L
.784 .0302 L
.788 .0302 L
.792 .0302 L
.796 .0302 L
.8 .03021 L
Mistroke
.804 .03022 L
.808 .03023 L
.812 .03024 L
.816 .03025 L
.82 .03026 L
.824 .03026 L
.828 .03027 L
.832 .03027 L
.836 .03027 L
.84 .03027 L
.844 .03029 L
.848 .0303 L
.852 .03031 L
.856 .03032 L
.86 .03032 L
.864 .03033 L
.868 .03033 L
.872 .03033 L
.876 .03034 L
.88 .03034 L
.884 .03036 L
.888 .03037 L
.892 .03038 L
.896 .03038 L
.9 .03038 L
.904 .03039 L
.908 .03039 L
.912 .0304 L
.916 .03041 L
.92 .03041 L
.924 .03043 L
.928 .03043 L
.932 .03044 L
.936 .03044 L
.94 .03044 L
.944 .03045 L
.948 .03046 L
.952 .03047 L
.956 .03048 L
.96 .03048 L
.964 .03049 L
.968 .03049 L
.972 .0305 L
.976 .0305 L
.98 .03052 L
.984 .03052 L
.988 .03053 L
.992 .03054 L
.996 .03055 L
1 .03054 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07oo00001Woo0P000goo100000Aoo`000000009oo`03001oogoo00Eoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo
0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`@000Aoo`04001oogoo0002Ool300000goo
000000020002Ool00`00Oomoo`04Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=o
o`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0029oo`80009oo`04001oogoo
0003Ool00`00Oomoo`0500000goo001oo`020008Ool00`00Oomoo`03Ool20004Ool20006Ool01000
Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol0
1@00Oomoogoo00000Woo00<007ooOol00Woo00<007oo00001Woo00<007ooOol0Egoo000ROol20002
Ool00`00Ool00006Ool00`00Oomoo`06Ool3001FOol0029oof<000aoo`008Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo1P0000=oo`0000001@0000=oo`000000
1`0000=oo`000000<00037oo000ROol2000KOol30002Ool20002Ool00`00Oomoo`02000017oo0000
07oo0P000Woo00@007ooOol003Qoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`8006eo
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`80
00Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P00
0Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2
001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo
000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001o
ogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol0
0`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P00
0goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo
0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00
Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001o
ogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomo
ogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03
001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
4Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004
Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`80
00=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo
00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=o
o`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomo
o`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05
001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool0
1000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000
Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P00
17oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo
00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001o
ogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo0000
0`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00D007ooOol007oo
04D000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`D000Eoo`03001oogoo00=o
o`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool5
0003Ool20006Ool002Qoo`03001oogoo00moo`<005Aoo`00:7oo00<007ooOol03Woo0P00EWoo000X
OomM000<Ool002Qoo`03001oogoo00Uoo`<000=oo`03001oogoo011oo`03001oogoo00moo`03001o
ogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol027oo0P00G7oo000XOol0
0`00Oomoo`05Ool3001NOol002Qoo`03001oogoo00=oo`<0061oo`00:7oo00<007ooOol00Woo0P00
HWoo000XOol01000Oomoogoo0P00Hgoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool3
0003Ool01@00Oomoogoo0000I7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`000goo00@007ooOol0009oo`8006Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`001Goo00D007ooOol007oo008006Eoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol00`00IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`05001oogoo001oo`040003Ool2001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:
Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo0000
0goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool0
0`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<0
07ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004
Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool0
0`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool0
1000Oomoo`002goo00@007ooOol001Qooe0000aoo`002Woo00@007ooOol000Moo`@000=oo`03001o
ogoo01=oo`<005aoo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8001=oo`8005ioo`002goo
0P0027oo1@000Woo00<007ooOol04Goo00<007ooOol0GWoo000LOol00`00Oomoo`0=Ool40003Ool2
0009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool5
0002Ool30004Ool20006Ool001aoo`8000eoo`03001oo`000080009oo`04001oogoo0009Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`00
0Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0<Ool20002Ool0
1000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol0
0`00Oomoo`0:Ool20004Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D0
07ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`00
0Woo00<007ooOol00goo000LOol20009Ool20002Ool40003Ool01000Oomoo`002Goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo
00@007ooOol000Eoo`0077oo00<007ooOol01goo0P000goo00<007ooOol017oo00@007ooOol000Qo
o`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo
00001Woo00@007ooOol000Eoo`0077oo0P001Woo0P001Goo1@000goo0P002Woo00<007ooOol00goo
0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D0
00=oo`8000Ioo`0077oo00<007ooOol017oo0P00K7oo000LOol00`00Oomoo`03Ool00`00Oomoo`1/
Ool001aoofT000aoo`0077oo00T007ooOomoo`00Ool007oo000017oo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`00
77oo00<007ooOol00Woo00<007ooOol0KGoo000LOol20002Ool00`00Oomoo`1^Ool001aoo`05001o
ogooOol0001`Ool001aoo`05001oogooOol0001`Ool001aoo`800003Ool007oo071oo`0077oo00@0
07ooOol0075oo`0077oo00<007oo0000LWoo000LOol2001cOol001aoo`8007=oo`0077oo0P00Lgoo
000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo
000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Ioo`<0
00=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02
Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007oo
Ool0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;
Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool0
1000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Mo
o`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool0
0`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(25384\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23487 m
.008 .24326 L
.012 .25566 L
.016 .26823 L
.02 .27978 L
.024 .29045 L
.028 .29866 L
.032 .30305 L
.036 .30355 L
.04 .30345 L
.044 .3028 L
.048 .30018 L
.052 .29617 L
.056 .29344 L
.06 .29328 L
.064 .29571 L
.068 .29999 L
.072 .30373 L
.076 .30636 L
.08 .30782 L
.084 .30848 L
.088 .30912 L
.092 .30953 L
.096 .30931 L
.1 .30751 L
.104 .30333 L
.108 .2964 L
.112 .28701 L
.116 .2763 L
.12 .26589 L
.124 .25775 L
.128 .2534 L
.132 .25365 L
.136 .2582 L
.14 .26569 L
.144 .27405 L
.148 .28098 L
.152 .28473 L
.156 .28448 L
.16 .28067 L
.164 .27476 L
.168 .26885 L
.172 .26488 L
.176 .26409 L
.18 .26656 L
.184 .27123 L
.188 .27632 L
.192 .27991 L
.196 .28068 L
.2 .27834 L
Mistroke
.204 .27369 L
.208 .26833 L
.212 .2641 L
.216 .26241 L
.22 .26381 L
.224 .26787 L
.228 .27337 L
.232 .27883 L
.236 .28302 L
.24 .2854 L
.244 .28622 L
.248 .28632 L
.252 .28676 L
.256 .28839 L
.26 .29154 L
.264 .29598 L
.268 .30108 L
.272 .30608 L
.276 .31033 L
.28 .31341 L
.284 .31521 L
.288 .31581 L
.292 .31544 L
.296 .31444 L
.3 .31324 L
.304 .31231 L
.308 .31207 L
.312 .31277 L
.316 .31439 L
.32 .31651 L
.324 .31851 L
.328 .31972 L
.332 .31974 L
.336 .31867 L
.34 .31709 L
.344 .31587 L
.348 .31573 L
.352 .31689 L
.356 .31889 L
.36 .32075 L
.364 .32146 L
.368 .32048 L
.372 .31811 L
.376 .31541 L
.38 .31368 L
.384 .31384 L
.388 .31588 L
.392 .31887 L
.396 .32137 L
.4 .32217 L
Mistroke
.404 .32092 L
.408 .31834 L
.412 .31581 L
.416 .31465 L
.42 .31543 L
.424 .31764 L
.428 .32 L
.432 .32119 L
.436 .32053 L
.44 .31842 L
.444 .31604 L
.448 .31474 L
.452 .31523 L
.456 .31724 L
.46 .31964 L
.464 .32113 L
.468 .32095 L
.472 .3193 L
.476 .31716 L
.48 .31574 L
.484 .31575 L
.488 .31706 L
.492 .31877 L
.496 .31985 L
.5 .31971 L
.504 .31855 L
.508 .31719 L
.512 .31649 L
.516 .31688 L
.52 .31808 L
.524 .3193 L
.528 .3198 L
.532 .31929 L
.536 .31811 L
.54 .31699 L
.544 .31658 L
.548 .31706 L
.552 .31807 L
.556 .319 L
.56 .31933 L
.564 .31897 L
.568 .31822 L
.572 .31758 L
.576 .31739 L
.58 .3177 L
.584 .31824 L
.588 .31865 L
.592 .31869 L
.596 .31839 L
.6 .31798 L
Mistroke
.604 .31772 L
.608 .31776 L
.612 .31806 L
.616 .31843 L
.62 .31867 L
.624 .31864 L
.628 .31837 L
.632 .318 L
.636 .31777 L
.64 .31781 L
.644 .3181 L
.648 .31845 L
.652 .31865 L
.656 .31856 L
.66 .31825 L
.664 .31793 L
.668 .31783 L
.672 .31803 L
.676 .3184 L
.68 .3187 L
.684 .31869 L
.688 .31837 L
.692 .31794 L
.696 .31772 L
.7 .31788 L
.704 .31831 L
.708 .3187 L
.712 .31877 L
.716 .3185 L
.72 .31813 L
.724 .31794 L
.728 .31804 L
.732 .3183 L
.736 .31848 L
.74 .31846 L
.744 .31829 L
.748 .31817 L
.752 .31823 L
.756 .3184 L
.76 .31853 L
.764 .31847 L
.768 .31825 L
.772 .31806 L
.776 .31809 L
.78 .31836 L
.784 .31866 L
.788 .31871 L
.792 .31842 L
.796 .31803 L
.8 .31787 L
Mistroke
.804 .31813 L
.808 .31865 L
.812 .31899 L
.816 .31883 L
.82 .31829 L
.824 .31778 L
.828 .31772 L
.832 .31817 L
.836 .31877 L
.84 .31905 L
.844 .31886 L
.848 .31838 L
.852 .318 L
.856 .31797 L
.86 .3182 L
.864 .31846 L
.868 .31862 L
.872 .31863 L
.876 .31859 L
.88 .31856 L
.884 .31845 L
.888 .31827 L
.892 .31815 L
.896 .31817 L
.9 .31838 L
.904 .3187 L
.908 .31884 L
.912 .31874 L
.916 .31847 L
.92 .31818 L
.924 .31807 L
.928 .31823 L
.932 .3185 L
.936 .31875 L
.94 .31888 L
.944 .31876 L
.948 .31844 L
.952 .3182 L
.956 .31809 L
.96 .31821 L
.964 .31861 L
.968 .31886 L
.972 .31885 L
.976 .3187 L
.98 .3184 L
.984 .31824 L
.988 .31835 L
.992 .31846 L
.996 .3185 L
1 .31856 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .47989 m
.008 .47677 L
.012 .47209 L
.016 .4657 L
.02 .45962 L
.024 .45391 L
.028 .44823 L
.032 .44249 L
.036 .43707 L
.04 .43187 L
.044 .42633 L
.048 .42046 L
.052 .41504 L
.056 .41019 L
.06 .4054 L
.064 .4002 L
.068 .39404 L
.072 .38698 L
.076 .37978 L
.08 .37294 L
.084 .36707 L
.088 .36229 L
.092 .35851 L
.096 .35554 L
.1 .35307 L
.104 .35091 L
.108 .34889 L
.112 .34693 L
.116 .34498 L
.12 .34302 L
.124 .34105 L
.128 .33905 L
.132 .33702 L
.136 .33497 L
.14 .3329 L
.144 .33083 L
.148 .32879 L
.152 .32681 L
.156 .32492 L
.16 .32314 L
.164 .32146 L
.168 .31988 L
.172 .31835 L
.176 .31681 L
.18 .3152 L
.184 .31347 L
.188 .31158 L
.192 .30953 L
.196 .30732 L
.2 .30499 L
Mistroke
.204 .30257 L
.208 .3001 L
.212 .29762 L
.216 .29516 L
.22 .29273 L
.224 .29035 L
.228 .28804 L
.232 .28582 L
.236 .28373 L
.24 .28177 L
.244 .27999 L
.248 .27838 L
.252 .27696 L
.256 .27571 L
.26 .27461 L
.264 .27363 L
.268 .27274 L
.272 .27192 L
.276 .27116 L
.28 .27047 L
.284 .26984 L
.288 .26929 L
.292 .26884 L
.296 .26848 L
.3 .26822 L
.304 .26804 L
.308 .26794 L
.312 .26787 L
.316 .26782 L
.32 .26778 L
.324 .26773 L
.328 .26767 L
.332 .2676 L
.336 .26753 L
.34 .26745 L
.344 .26739 L
.348 .26732 L
.352 .26726 L
.356 .2672 L
.36 .26715 L
.364 .2671 L
.368 .26708 L
.372 .26707 L
.376 .26708 L
.38 .26711 L
.384 .26713 L
.388 .26713 L
.392 .26711 L
.396 .26707 L
.4 .26702 L
Mistroke
.404 .26696 L
.408 .26691 L
.412 .26688 L
.416 .26686 L
.42 .26684 L
.424 .26682 L
.428 .2668 L
.432 .26677 L
.436 .26675 L
.44 .26673 L
.444 .26672 L
.448 .26672 L
.452 .26672 L
.456 .26671 L
.46 .26669 L
.464 .26665 L
.468 .2666 L
.472 .26655 L
.476 .2665 L
.48 .26647 L
.484 .26645 L
.488 .26644 L
.492 .26644 L
.496 .26644 L
.5 .26643 L
.504 .26642 L
.508 .2664 L
.512 .26637 L
.516 .26634 L
.52 .2663 L
.524 .26625 L
.528 .26621 L
.532 .26617 L
.536 .26615 L
.54 .26614 L
.544 .26614 L
.548 .26615 L
.552 .26615 L
.556 .26614 L
.56 .26611 L
.564 .26606 L
.568 .26601 L
.572 .26596 L
.576 .26592 L
.58 .2659 L
.584 .26589 L
.588 .26589 L
.592 .26589 L
.596 .26588 L
.6 .26587 L
Mistroke
.604 .26584 L
.608 .26581 L
.612 .26577 L
.616 .26573 L
.62 .26569 L
.624 .26566 L
.628 .26564 L
.632 .26563 L
.636 .26563 L
.64 .26563 L
.644 .26561 L
.648 .26559 L
.652 .26555 L
.656 .26551 L
.66 .26547 L
.664 .26544 L
.668 .26541 L
.672 .2654 L
.676 .26539 L
.68 .26538 L
.684 .26537 L
.688 .26535 L
.692 .26532 L
.696 .26529 L
.7 .26525 L
.704 .26522 L
.708 .26519 L
.712 .26517 L
.716 .26516 L
.72 .26515 L
.724 .26513 L
.728 .26511 L
.732 .26509 L
.736 .26506 L
.74 .26503 L
.744 .265 L
.748 .26497 L
.752 .26495 L
.756 .26493 L
.76 .26491 L
.764 .2649 L
.768 .26488 L
.772 .26486 L
.776 .26483 L
.78 .2648 L
.784 .26477 L
.788 .26475 L
.792 .26472 L
.796 .2647 L
.8 .26468 L
Mistroke
.804 .26467 L
.808 .26465 L
.812 .26462 L
.816 .2646 L
.82 .26458 L
.824 .26455 L
.828 .26452 L
.832 .2645 L
.836 .26448 L
.84 .26446 L
.844 .26444 L
.848 .26442 L
.852 .26439 L
.856 .26437 L
.86 .26434 L
.864 .26432 L
.868 .2643 L
.872 .26427 L
.876 .26425 L
.88 .26423 L
.884 .26421 L
.888 .26419 L
.892 .26416 L
.896 .26414 L
.9 .26411 L
.904 .26409 L
.908 .26407 L
.912 .26405 L
.916 .26403 L
.92 .264 L
.924 .26398 L
.928 .26395 L
.932 .26393 L
.936 .26391 L
.94 .26389 L
.944 .26387 L
.948 .26385 L
.952 .26382 L
.956 .2638 L
.96 .26377 L
.964 .26375 L
.968 .26372 L
.972 .26371 L
.976 .26368 L
.98 .26367 L
.984 .26364 L
.988 .26362 L
.992 .26358 L
.996 .26357 L
1 .26354 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30929 m
.008 .29767 L
.012 .29192 L
.016 .28442 L
.02 .27511 L
.024 .26662 L
.028 .25874 L
.032 .25112 L
.036 .24373 L
.04 .23624 L
.044 .22838 L
.048 .22035 L
.052 .21248 L
.056 .2053 L
.06 .19857 L
.064 .19115 L
.068 .18271 L
.072 .17353 L
.076 .16412 L
.08 .1556 L
.084 .14841 L
.088 .14282 L
.092 .13871 L
.096 .1357 L
.1 .13345 L
.104 .13156 L
.108 .12979 L
.112 .12793 L
.116 .12589 L
.12 .12362 L
.124 .12113 L
.128 .11849 L
.132 .11576 L
.136 .11302 L
.14 .11036 L
.144 .10782 L
.148 .10541 L
.152 .10312 L
.156 .10092 L
.16 .09875 L
.164 .09659 L
.168 .09437 L
.172 .09211 L
.176 .08979 L
.18 .08742 L
.184 .08501 L
.188 .08256 L
.192 .08008 L
.196 .07753 L
.2 .07491 L
Mistroke
.204 .0722 L
.208 .0694 L
.212 .06651 L
.216 .06359 L
.22 .06066 L
.224 .05779 L
.228 .055 L
.232 .05234 L
.236 .04981 L
.24 .04743 L
.244 .04518 L
.248 .04308 L
.252 .04113 L
.256 .03933 L
.26 .03772 L
.264 .03631 L
.268 .03511 L
.272 .03413 L
.276 .03335 L
.28 .03275 L
.284 .03228 L
.288 .03192 L
.292 .03161 L
.296 .03132 L
.3 .03105 L
.304 .03078 L
.308 .03051 L
.312 .03027 L
.316 .03006 L
.32 .0299 L
.324 .02979 L
.328 .02973 L
.332 .0297 L
.336 .0297 L
.34 .02971 L
.344 .02972 L
.348 .02975 L
.352 .02978 L
.356 .02982 L
.36 .02985 L
.364 .02987 L
.368 .02987 L
.372 .02985 L
.376 .02981 L
.38 .02976 L
.384 .02971 L
.388 .02968 L
.392 .02968 L
.396 .02971 L
.4 .02975 L
Mistroke
.404 .02979 L
.408 .02983 L
.412 .02985 L
.416 .02985 L
.42 .02985 L
.424 .02985 L
.428 .02986 L
.432 .02987 L
.436 .02988 L
.44 .02988 L
.444 .02987 L
.448 .02984 L
.452 .02982 L
.456 .02981 L
.46 .02982 L
.464 .02985 L
.468 .02989 L
.472 .02993 L
.476 .02996 L
.48 .02998 L
.484 .02998 L
.488 .02997 L
.492 .02995 L
.496 .02993 L
.5 .02991 L
.504 .02991 L
.508 .0299 L
.512 .02991 L
.516 .02993 L
.52 .02996 L
.524 .03 L
.528 .03003 L
.532 .03006 L
.536 .03006 L
.54 .03005 L
.544 .03002 L
.548 .02999 L
.552 .02997 L
.556 .02996 L
.56 .02998 L
.564 .03001 L
.568 .03005 L
.572 .03009 L
.576 .03011 L
.58 .03012 L
.584 .03011 L
.588 .03009 L
.592 .03007 L
.596 .03006 L
.6 .03005 L
Mistroke
.604 .03006 L
.608 .03007 L
.612 .0301 L
.616 .03014 L
.62 .03017 L
.624 .03018 L
.628 .03018 L
.632 .03017 L
.636 .03015 L
.64 .03013 L
.644 .03012 L
.648 .03013 L
.652 .03016 L
.656 .03018 L
.66 .03021 L
.664 .03023 L
.668 .03023 L
.672 .03023 L
.676 .03022 L
.68 .03021 L
.684 .03021 L
.688 .03021 L
.692 .03022 L
.696 .03023 L
.7 .03026 L
.704 .03028 L
.708 .03029 L
.712 .03029 L
.716 .03029 L
.72 .03028 L
.724 .03028 L
.728 .03028 L
.732 .03028 L
.736 .0303 L
.74 .03032 L
.744 .03033 L
.748 .03034 L
.752 .03035 L
.756 .03035 L
.76 .03035 L
.764 .03035 L
.768 .03035 L
.772 .03036 L
.776 .03037 L
.78 .03038 L
.784 .03039 L
.788 .0304 L
.792 .0304 L
.796 .03041 L
.8 .03041 L
Mistroke
.804 .03042 L
.808 .03042 L
.812 .03043 L
.816 .03043 L
.82 .03044 L
.824 .03045 L
.828 .03046 L
.832 .03047 L
.836 .03047 L
.84 .03048 L
.844 .03048 L
.848 .03049 L
.852 .03049 L
.856 .0305 L
.86 .0305 L
.864 .03051 L
.868 .03052 L
.872 .03053 L
.876 .03054 L
.88 .03055 L
.884 .03055 L
.888 .03055 L
.892 .03055 L
.896 .03056 L
.9 .03057 L
.904 .03058 L
.908 .0306 L
.912 .0306 L
.916 .03061 L
.92 .03061 L
.924 .03061 L
.928 .03061 L
.932 .03062 L
.936 .03063 L
.94 .03064 L
.944 .03065 L
.948 .03067 L
.952 .03067 L
.956 .03067 L
.96 .03066 L
.964 .03067 L
.968 .03067 L
.972 .03069 L
.976 .0307 L
.98 .03072 L
.984 .03072 L
.988 .03073 L
.992 .03072 L
.996 .03073 L
1 .03072 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00
2goo1@000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04
001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Ao
o`03001oogoo009oo`8000Yoo`<0009oo`80009oo`800003Ool007oo00Eoo`8000Aoo`04001oogoo
0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol0
00Eoo`008Woo0`0027oo00<007ooOol01@0000=oo`00Ool00P0027oo00<007ooOol00goo0P0017oo
0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`80
00Ioo`008Woo00<007oo000027oo00@007ooOomoo`80009oo`80009oo`<005Eoo`008Woo100000=o
o`00000017oo00<007ooOol02goo0P00E7oo000ROomS000<Ool0029oo`05001oogooOol00003Ool3
00000goo001oo`02Ool01@00Oomoogoo00000goo00<007ooOol03`0000=oo`000000=P0037oo000R
Ool2000NOol00`00Oomoo`020002Ool2000017oo000007oo0P0000=oo`0000000Woo00@007ooOol0
03Moo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo
009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo
00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0
00=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007oo
Ool006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo
001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001o
ogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000
Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001o
ogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2
001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo
0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomo
o`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007oo
Ool0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo0080
06Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0
IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo
06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015o
o`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo
06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo
001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001o
ogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo
008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=o
o`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00
009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<0
07ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001o
ogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eo
o`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000=ood<000=oo`04001oogoo0005
Ool002Qoo`03001oogoo00Uoo`D000=oo`L000=oo`03001oogoo00=oo`8000Aoo`8000Aoo`04001o
ogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03
001oogoo019oo`80059oo`00:7oo00<007ooOol047oo0P00E7oo000XOomM000<Ool002Qoo`03001o
ogoo00aoo`@0019oo`03001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yo
o`00:7oo00<007ooOol02Woo0P00FWoo000XOol00`00Oomoo`08Ool2001LOol002Qoo`03001oogoo
00Ioo`8005ioo`00:7oo00<007ooOol01Goo00<007ooOol0GWoo000XOol00`00Oomoo`04Ool00`00
Oomoo`1OOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo00Ao
o`03001oogoo05moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=o
o`04001oogoo0005Ool00`00Oomoo`1POol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogoo0004Ool2001ROol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo0080009oo`8006=oo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01@00Oomoo`00Ool010000goo00D007ooOomoo`0006Aoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000Ioo`04001oogoo001UOol000]oo`8000Yoo`8000Aoo`80
009oo`D0009oo`04001oo`00001UOol002Qoo`03001oo`0006Ioo`00:7oo0P00Igoo000AOol20004
Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Io
o`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003
Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D0
07ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo
1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo
0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
2goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo0080
07=oo`002Woo00@007ooOol000]oo`04001oogoo000KOom=000<Ool000Yoo`04001oogoo0007Ool4
0003Ool00`00Oomoo`0FOol3001IOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2000FOol2
001KOol000]oo`8000Qoo`D0009oo`03001oogoo01=oo`8005eoo`0077oo00<007ooOol03Goo0`00
0Woo10002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P00
1Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01000Oomoogoo0P0000Eoo`00Oomoo`0000Uo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo00moo`80
009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo
00eoo`800005Ool007ooOol00002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00
Oomoo`03Ool001aoo`8000aoo`D000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000LOol00`00Oomoo`0:Ool30006Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001o
ogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2
0009Ool20002Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@00
0goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`06
Ool2001ZOol001aoo`03001oogoo00Ioo`03001oogoo06Uoo`0077ooJ@0037oo000LOol01@00Oomo
ogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol017oo0P00K7oo
000LOol20005Ool00`00Oomoo`1[Ool001aoo`03001oogoo00=oo`03001oogoo06aoo`0077oo00<0
07ooOol00goo00<007ooOol0K7oo000LOol20003Ool2001^Ool001aoo`03001oogoo009oo`03001o
ogoo06eoo`0077oo00D007ooOomoo`00071oo`0077oo0P000Woo00<007ooOol0KWoo000LOol00`00
Oomoo`02001`Ool001aoo`800003Ool007oo071oo`002goo0P0017oo00<007ooOol00Woo0`000goo
00<007oo0000LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oo`00079oo`00
2Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`03001oogoo0080
07=oo`002Woo00@007ooOol000Moo`@000=oo`8007=oo`002Woo00@007ooOol000Moo`03001oogoo
00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo
00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo009oo`03001oogoo
079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001o
ogoo009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo
00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00
Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<0
07ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001o
ogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(25551\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29874 m
.008 .29852 L
.012 .29402 L
.016 .28753 L
.02 .2803 L
.024 .27425 L
.028 .27099 L
.032 .26939 L
.036 .27043 L
.04 .27487 L
.044 .28249 L
.048 .29037 L
.052 .29778 L
.056 .30666 L
.06 .31679 L
.064 .32703 L
.068 .33501 L
.072 .33873 L
.076 .33793 L
.08 .33466 L
.084 .33017 L
.088 .32508 L
.092 .31992 L
.096 .31435 L
.1 .30928 L
.104 .30557 L
.108 .30389 L
.112 .30437 L
.116 .30589 L
.12 .30692 L
.124 .3056 L
.128 .3008 L
.132 .29241 L
.136 .28151 L
.14 .27019 L
.144 .26077 L
.148 .25526 L
.152 .25458 L
.156 .25842 L
.16 .26523 L
.164 .27284 L
.168 .27912 L
.172 .28262 L
.176 .283 L
.18 .28098 L
.184 .27803 L
.188 .27568 L
.192 .27504 L
.196 .27629 L
.2 .27878 L
Mistroke
.204 .28125 L
.208 .28238 L
.212 .28134 L
.216 .27807 L
.22 .27335 L
.224 .26841 L
.228 .26457 L
.232 .26275 L
.236 .26326 L
.24 .26575 L
.244 .26951 L
.248 .27366 L
.252 .27751 L
.256 .28065 L
.26 .28297 L
.264 .2846 L
.268 .2858 L
.272 .28689 L
.276 .28819 L
.28 .29001 L
.284 .29258 L
.288 .29596 L
.292 .29996 L
.296 .30412 L
.3 .30782 L
.304 .31046 L
.308 .31176 L
.312 .3119 L
.316 .31151 L
.32 .31144 L
.324 .31234 L
.328 .31431 L
.332 .31682 L
.336 .31891 L
.34 .31967 L
.344 .31874 L
.348 .31658 L
.352 .31429 L
.356 .31309 L
.36 .31374 L
.364 .31608 L
.368 .31909 L
.372 .32139 L
.376 .32192 L
.38 .32049 L
.384 .31789 L
.388 .31549 L
.392 .31452 L
.396 .31545 L
.4 .31771 L
Mistroke
.404 .32002 L
.408 .32109 L
.412 .32033 L
.416 .31818 L
.42 .31585 L
.424 .31464 L
.428 .31525 L
.432 .31736 L
.436 .31979 L
.44 .32123 L
.444 .32093 L
.448 .31913 L
.452 .31689 L
.456 .31545 L
.46 .31555 L
.464 .31698 L
.468 .3188 L
.472 .31993 L
.476 .31976 L
.48 .31852 L
.484 .31707 L
.488 .31635 L
.492 .31679 L
.496 .31806 L
.5 .31933 L
.504 .3198 L
.508 .31921 L
.512 .31794 L
.516 .31677 L
.52 .31639 L
.524 .31697 L
.528 .31811 L
.532 .3191 L
.536 .3194 L
.54 .31894 L
.544 .31809 L
.548 .31739 L
.552 .31724 L
.556 .31762 L
.56 .31823 L
.564 .31865 L
.568 .31865 L
.572 .31828 L
.576 .31782 L
.58 .3176 L
.584 .31773 L
.588 .31812 L
.592 .3185 L
.596 .31865 L
.6 .3185 L
Mistroke
.604 .31814 L
.608 .31781 L
.612 .31768 L
.616 .31783 L
.62 .31817 L
.624 .31848 L
.628 .31857 L
.632 .31839 L
.636 .31806 L
.64 .31781 L
.644 .31783 L
.648 .31812 L
.652 .31846 L
.656 .31863 L
.66 .31849 L
.664 .31811 L
.668 .31775 L
.672 .31769 L
.676 .31798 L
.68 .31845 L
.684 .31877 L
.688 .31869 L
.692 .31826 L
.696 .31781 L
.7 .31768 L
.704 .31798 L
.708 .31846 L
.712 .31874 L
.716 .3186 L
.72 .31816 L
.724 .31779 L
.728 .31779 L
.732 .31817 L
.736 .31864 L
.74 .31883 L
.744 .31859 L
.748 .3181 L
.752 .31773 L
.756 .31776 L
.76 .31817 L
.764 .31863 L
.768 .31881 L
.772 .3186 L
.776 .31819 L
.78 .31793 L
.784 .31799 L
.788 .31826 L
.792 .31847 L
.796 .31848 L
.8 .31835 L
Mistroke
.804 .31825 L
.808 .31831 L
.812 .31841 L
.816 .3184 L
.82 .31825 L
.824 .3181 L
.828 .31815 L
.832 .31843 L
.836 .31871 L
.84 .31872 L
.844 .3184 L
.848 .31798 L
.852 .31781 L
.856 .31807 L
.86 .31856 L
.864 .31893 L
.868 .31892 L
.872 .31853 L
.876 .31805 L
.88 .31782 L
.884 .31792 L
.888 .31829 L
.892 .31871 L
.896 .3189 L
.9 .31883 L
.904 .31856 L
.908 .3182 L
.912 .31797 L
.916 .31799 L
.92 .31818 L
.924 .31849 L
.928 .3188 L
.932 .3189 L
.936 .31879 L
.94 .31854 L
.944 .31814 L
.948 .31786 L
.952 .31793 L
.956 .31825 L
.96 .31877 L
.964 .31918 L
.968 .31909 L
.972 .31862 L
.976 .31808 L
.98 .31777 L
.984 .31791 L
.988 .31841 L
.992 .31885 L
.996 .31895 L
1 .31889 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .52847 m
.008 .5193 L
.012 .51272 L
.016 .50864 L
.02 .50358 L
.024 .49753 L
.028 .49172 L
.032 .48603 L
.036 .48031 L
.04 .47442 L
.044 .46831 L
.048 .46196 L
.052 .45591 L
.056 .45021 L
.06 .44446 L
.064 .43838 L
.068 .43194 L
.072 .42545 L
.076 .4195 L
.08 .41413 L
.084 .40881 L
.088 .4031 L
.092 .39663 L
.096 .38946 L
.1 .38215 L
.104 .37514 L
.108 .36897 L
.112 .36382 L
.116 .3597 L
.12 .35646 L
.124 .35386 L
.128 .3517 L
.132 .3498 L
.136 .34803 L
.14 .34631 L
.144 .34457 L
.148 .34279 L
.152 .34093 L
.156 .33898 L
.16 .33694 L
.164 .33483 L
.168 .33269 L
.172 .33057 L
.176 .32849 L
.18 .3265 L
.184 .3246 L
.188 .32279 L
.192 .32106 L
.196 .31935 L
.2 .31765 L
Mistroke
.204 .3159 L
.208 .3141 L
.212 .31221 L
.216 .31025 L
.22 .30822 L
.224 .30612 L
.228 .30396 L
.232 .30173 L
.236 .29945 L
.24 .2971 L
.244 .29471 L
.248 .2923 L
.252 .2899 L
.256 .28754 L
.26 .28527 L
.264 .28313 L
.268 .28116 L
.272 .27937 L
.276 .27778 L
.28 .27637 L
.284 .27513 L
.288 .27404 L
.292 .27308 L
.296 .27223 L
.3 .27147 L
.304 .27079 L
.308 .27019 L
.312 .26967 L
.316 .26923 L
.32 .26885 L
.324 .26853 L
.328 .26826 L
.332 .26804 L
.336 .26785 L
.34 .2677 L
.344 .2676 L
.348 .26753 L
.352 .26749 L
.356 .26747 L
.36 .26744 L
.364 .26741 L
.368 .26737 L
.372 .2673 L
.376 .26724 L
.38 .26718 L
.384 .26713 L
.388 .26709 L
.392 .26707 L
.396 .26705 L
.4 .26703 L
Mistroke
.404 .267 L
.408 .26698 L
.412 .26696 L
.416 .26694 L
.42 .26693 L
.424 .26693 L
.428 .26692 L
.432 .26691 L
.436 .26688 L
.44 .26684 L
.444 .26679 L
.448 .26674 L
.452 .2667 L
.456 .26667 L
.46 .26665 L
.464 .26665 L
.468 .26665 L
.472 .26665 L
.476 .26664 L
.48 .26662 L
.484 .2666 L
.488 .26657 L
.492 .26653 L
.496 .26649 L
.5 .26645 L
.504 .2664 L
.508 .26637 L
.512 .26635 L
.516 .26635 L
.52 .26636 L
.524 .26636 L
.528 .26636 L
.532 .26634 L
.536 .2663 L
.54 .26625 L
.544 .2662 L
.548 .26615 L
.552 .26612 L
.556 .2661 L
.56 .2661 L
.564 .2661 L
.568 .2661 L
.572 .26609 L
.576 .26607 L
.58 .26604 L
.584 .26601 L
.588 .26596 L
.592 .26592 L
.596 .26588 L
.6 .26586 L
Mistroke
.604 .26584 L
.608 .26584 L
.612 .26584 L
.616 .26583 L
.62 .26582 L
.624 .26579 L
.628 .26575 L
.632 .26571 L
.636 .26567 L
.64 .26564 L
.644 .26562 L
.648 .26561 L
.652 .2656 L
.656 .26559 L
.66 .26557 L
.664 .26555 L
.668 .26552 L
.672 .26549 L
.676 .26545 L
.68 .26542 L
.684 .26539 L
.688 .26538 L
.692 .26536 L
.696 .26535 L
.7 .26534 L
.704 .26532 L
.708 .26529 L
.712 .26526 L
.716 .26523 L
.72 .2652 L
.724 .26517 L
.728 .26515 L
.732 .26513 L
.736 .26512 L
.74 .2651 L
.744 .26508 L
.748 .26506 L
.752 .26503 L
.756 .265 L
.76 .26497 L
.764 .26495 L
.768 .26493 L
.772 .26491 L
.776 .26489 L
.78 .26487 L
.784 .26485 L
.788 .26482 L
.792 .2648 L
.796 .26478 L
.8 .26475 L
Mistroke
.804 .26473 L
.808 .2647 L
.812 .26468 L
.816 .26466 L
.82 .26464 L
.824 .26462 L
.828 .2646 L
.832 .26457 L
.836 .26455 L
.84 .26452 L
.844 .2645 L
.848 .26447 L
.852 .26445 L
.856 .26443 L
.86 .26441 L
.864 .26439 L
.868 .26437 L
.872 .26435 L
.876 .26432 L
.88 .26429 L
.884 .26427 L
.888 .26424 L
.892 .26422 L
.896 .2642 L
.9 .26419 L
.904 .26417 L
.908 .26414 L
.912 .26411 L
.916 .26409 L
.92 .26406 L
.924 .26404 L
.928 .26402 L
.932 .264 L
.936 .26398 L
.94 .26396 L
.944 .26394 L
.948 .26391 L
.952 .26388 L
.956 .26386 L
.96 .26383 L
.964 .26382 L
.968 .2638 L
.972 .26378 L
.976 .26376 L
.98 .26373 L
.984 .2637 L
.988 .26367 L
.992 .26365 L
.996 .26364 L
1 .26361 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .35416 m
.008 .34479 L
.012 .33912 L
.016 .33233 L
.02 .32411 L
.024 .31589 L
.028 .30778 L
.032 .29973 L
.036 .29163 L
.04 .2835 L
.044 .2752 L
.048 .26708 L
.052 .25929 L
.056 .25215 L
.06 .24539 L
.064 .23829 L
.068 .2308 L
.072 .22357 L
.076 .21695 L
.08 .21093 L
.084 .20504 L
.088 .19836 L
.092 .19053 L
.096 .18172 L
.1 .17242 L
.104 .16354 L
.108 .15561 L
.112 .14904 L
.116 .14386 L
.12 .13986 L
.124 .13678 L
.128 .13425 L
.132 .13199 L
.136 .12978 L
.14 .12749 L
.144 .12503 L
.148 .12243 L
.152 .11972 L
.156 .11696 L
.16 .11423 L
.164 .11158 L
.168 .10906 L
.172 .10666 L
.176 .10438 L
.18 .1022 L
.184 .10008 L
.188 .09801 L
.192 .09597 L
.196 .09393 L
.2 .09187 L
Mistroke
.204 .08976 L
.208 .08758 L
.212 .08529 L
.216 .08285 L
.22 .08025 L
.224 .0775 L
.228 .07459 L
.232 .07158 L
.236 .06852 L
.24 .06545 L
.244 .06244 L
.248 .05953 L
.252 .05675 L
.256 .0541 L
.26 .05159 L
.264 .04922 L
.268 .04697 L
.272 .04485 L
.276 .04285 L
.28 .041 L
.284 .0393 L
.288 .03778 L
.292 .03644 L
.296 .03529 L
.3 .03432 L
.304 .03352 L
.308 .03286 L
.312 .03232 L
.316 .03187 L
.32 .03151 L
.324 .03122 L
.328 .03098 L
.332 .0308 L
.336 .03065 L
.34 .03052 L
.344 .0304 L
.348 .03028 L
.352 .03017 L
.356 .03007 L
.36 .02998 L
.364 .02993 L
.368 .02992 L
.372 .02993 L
.376 .02996 L
.38 .03 L
.384 .03002 L
.388 .03003 L
.392 .03003 L
.396 .03002 L
.4 .03002 L
Mistroke
.404 .03002 L
.408 .03003 L
.412 .03003 L
.416 .03003 L
.42 .03001 L
.424 .02999 L
.428 .02998 L
.432 .02997 L
.436 .02998 L
.44 .03001 L
.444 .03006 L
.448 .03009 L
.452 .03012 L
.456 .03014 L
.46 .03013 L
.464 .03011 L
.468 .03009 L
.472 .03007 L
.476 .03006 L
.48 .03005 L
.484 .03006 L
.488 .03008 L
.492 .0301 L
.496 .03013 L
.5 .03017 L
.504 .03019 L
.508 .03021 L
.512 .03021 L
.516 .03019 L
.52 .03016 L
.524 .03014 L
.528 .03012 L
.532 .03012 L
.536 .03014 L
.54 .03018 L
.544 .03022 L
.548 .03026 L
.552 .03028 L
.556 .03028 L
.56 .03026 L
.564 .03024 L
.568 .03022 L
.572 .0302 L
.576 .0302 L
.58 .03022 L
.584 .03024 L
.588 .03027 L
.592 .0303 L
.596 .03032 L
.6 .03033 L
Mistroke
.604 .03033 L
.608 .03031 L
.612 .03029 L
.616 .03028 L
.62 .03028 L
.624 .03029 L
.628 .03031 L
.632 .03034 L
.636 .03037 L
.64 .03039 L
.644 .03039 L
.648 .03038 L
.652 .03037 L
.656 .03036 L
.66 .03035 L
.664 .03036 L
.668 .03037 L
.672 .03039 L
.676 .03042 L
.68 .03043 L
.684 .03044 L
.688 .03044 L
.692 .03044 L
.696 .03043 L
.7 .03043 L
.704 .03043 L
.708 .03044 L
.712 .03046 L
.716 .03047 L
.72 .03049 L
.724 .0305 L
.728 .0305 L
.732 .0305 L
.736 .0305 L
.74 .0305 L
.744 .0305 L
.748 .03051 L
.752 .03052 L
.756 .03053 L
.76 .03055 L
.764 .03055 L
.768 .03056 L
.772 .03056 L
.776 .03056 L
.78 .03057 L
.784 .03057 L
.788 .03058 L
.792 .03058 L
.796 .03059 L
.8 .03061 L
Mistroke
.804 .03062 L
.808 .03062 L
.812 .03063 L
.816 .03063 L
.82 .03063 L
.824 .03063 L
.828 .03064 L
.832 .03065 L
.836 .03066 L
.84 .03067 L
.844 .03068 L
.848 .03068 L
.852 .03069 L
.856 .03069 L
.86 .0307 L
.864 .0307 L
.868 .03071 L
.872 .03072 L
.876 .03073 L
.88 .03073 L
.884 .03074 L
.888 .03075 L
.892 .03075 L
.896 .03076 L
.9 .03076 L
.904 .03077 L
.908 .03078 L
.912 .03078 L
.916 .03079 L
.92 .03079 L
.924 .0308 L
.928 .03081 L
.932 .03082 L
.936 .03083 L
.94 .03083 L
.944 .03083 L
.948 .03084 L
.952 .03084 L
.956 .03086 L
.96 .03086 L
.964 .03087 L
.968 .03088 L
.972 .03089 L
.976 .03089 L
.98 .0309 L
.984 .03089 L
.988 .0309 L
.992 .03091 L
.996 .03093 L
1 .03093 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`<000Aoo`@000Ioo`8000Aoo`04001oogoo0002Ool01000
Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`008Woo
1@002Goo1P0000=oo`0000000`001Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D0
00=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00D007oo001o
o`0000Qoo`04001oogooOol200000goo00000003Ool3001COol0029oo`8000=oo`03001oogoo00Eo
o`03001oogoo00]oo`80059oo`008WooH`0037oo000ROol03@00Oomoogoo001oo`00Ool007oo001o
o`0000=oo`05001oogooOol00003Ool01000Oomoo`000Woo1`0000Aoo`00001oo`P00003Ool00000
02l000aoo`008Woo0P0017oo00@007ooOol001Moo`03001oogoo0080009oo`04001oogoo0002Ool2
00001Goo001oogoo0000>Woo000ROol00`00Oomoo`04Ool2001VOol0029oo`8006eoo`008Woo0P00
KGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo
0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool2
0002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009o
o`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/
Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007oo
Ool000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029o
o`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool2
0003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003
Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03
001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00
Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D0
07ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001o
ogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo
00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo
0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001o
ogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`00
0goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomo
ogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eo
o`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04
001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool2
0004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`00
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool0
00030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`00
1Woo@0000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P000goo100000=oo`00
Ool017oo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0
009oo`D000=oo`8000Ioo`00:7oo00<007ooOol057oo0`00Cgoo000XOol00`00Oomoo`0BOol3001A
Ool002Qooed000aoo`00:7oo00<007ooOol03Woo0`004Goo00<007ooOol03goo00<007ooOol03goo
00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`0<Ool3001GOol002Qoo`03001oogoo
00Yoo`<005Uoo`00:7oo00<007ooOol027oo0`00Fgoo000XOol00`00Oomoo`07Ool2001MOol002Qo
o`03001oogoo00Moo`03001oogoo05aoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo
0`000goo00<007ooOol01Woo00<007ooOol0GGoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`000goo00@007ooOol000Moo`03001oogoo05ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol000Moo`03001oogoo05ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P001Goo00<007ooOol0
Ggoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomo
o`03Ool2001QOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool0
0`00Oomoo`03Ool00`00Oomoo`1POol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo
009oo`03001oogoo065oo`00:7oo00@007ooOomoo`8006=oo`00:7oo00D007ooOomoo`0006Aoo`00
4Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00@007ooOol006Eoo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool01000Ool00000IGoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oo`0006Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03
001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo
06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03
001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo000MOom;000<Ool000Yoo`04001o
ogoo0007Ool40003Ool00`00Oomoo`0IOol3001FOol000Yoo`04001oogoo0007Ool00`00Oomoo`04
Ool2000HOol3001HOol000]oo`8000Qoo`D0009oo`03001oogoo01Ioo`8005Yoo`0077oo00<007oo
Ool03Goo0`0017oo0`0027oo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo
0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo0P00
00=oo`00Ool027oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<0
07ooOol047oo10000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000L
Ool00`00Oomoo`0?Ool300001Goo001oogoo00002Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00
009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007oo
Ool00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`00
77oo00<007ooOol037oo0P001Goo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomo
o`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomo
o`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P00
2goo1`000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Io
o`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol02Goo0P00Igoo
000LOol00`00Oomoo`09Ool00`00Oomoo`1VOol001aoofT000aoo`0077oo00D007ooOomoo`0000=o
o`06001oogoo001oo`000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03
001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol01goo00<007ooOol0J7oo000LOol20008
Ool00`00Oomoo`1XOol001aoo`03001oogoo00Ioo`03001oogoo06Uoo`0077oo00<007ooOol01Goo
0P00Jgoo000LOol20006Ool00`00Oomoo`1ZOol001aoo`03001oogoo00Aoo`8006aoo`0077oo00<0
07ooOol017oo00<007ooOol0Jgoo000LOol20004Ool00`00Oomoo`1/Ool001aoo`03001oogoo00=o
o`03001oogoo06aoo`0077oo0P000goo00<007ooOol0KGoo000;Ool20004Ool00`00Oomoo`02Ool3
0003Ool00`00Oomoo`02Ool00`00Oomoo`1]Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00D007ooOomoo`00071oo`002Woo00@007ooOol000]oo`03001oogoo0080009oo`03001oogoo
06ioo`002Woo00@007ooOol000]oo`04001oogoo0002Ool2001`Ool000Yoo`04001oogoo0007Ool4
0003Ool01000Oomoo`00LGoo000:Ool01000Oomoo`001goo00<007ooOol017oo0`00LWoo000;Ool2
0008Ool50002Ool00`00Ool0001bOol001aoo`8007=oo`0077oo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
5Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001o
ogoo009oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool0
0`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001c
Ool000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo
00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007oo
Ool01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol0
00]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1b
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(25718\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .27157 m
.008 .27364 L
.012 .27755 L
.016 .28355 L
.02 .29098 L
.024 .29837 L
.028 .30476 L
.032 .31027 L
.036 .31413 L
.04 .31744 L
.044 .31961 L
.048 .31874 L
.052 .31481 L
.056 .30943 L
.06 .30433 L
.064 .29925 L
.068 .29473 L
.072 .29126 L
.076 .29083 L
.08 .29616 L
.084 .30654 L
.088 .31873 L
.092 .32894 L
.096 .33457 L
.1 .33489 L
.104 .33163 L
.108 .32649 L
.112 .32101 L
.116 .31653 L
.12 .31348 L
.124 .31244 L
.128 .31333 L
.132 .31554 L
.136 .31794 L
.14 .31891 L
.144 .31718 L
.148 .31204 L
.152 .30389 L
.156 .29401 L
.16 .28424 L
.164 .27636 L
.168 .27146 L
.172 .26971 L
.176 .27033 L
.18 .272 L
.184 .27338 L
.188 .27365 L
.192 .27271 L
.196 .27116 L
.2 .26999 L
Mistroke
.204 .27008 L
.208 .27187 L
.212 .27517 L
.216 .27926 L
.22 .28316 L
.224 .28594 L
.228 .28702 L
.232 .28624 L
.236 .28387 L
.24 .28043 L
.244 .27656 L
.248 .27285 L
.252 .26983 L
.256 .26792 L
.26 .26737 L
.264 .26822 L
.268 .27028 L
.272 .27307 L
.276 .27598 L
.28 .27844 L
.284 .28021 L
.288 .28147 L
.292 .28279 L
.296 .28485 L
.3 .28808 L
.304 .29237 L
.308 .29703 L
.312 .30107 L
.316 .30368 L
.32 .3046 L
.324 .30437 L
.328 .30406 L
.332 .30477 L
.336 .30709 L
.34 .31075 L
.344 .3147 L
.348 .31764 L
.352 .31863 L
.356 .31761 L
.36 .31546 L
.364 .31357 L
.368 .31312 L
.372 .3145 L
.376 .31706 L
.38 .31951 L
.384 .32059 L
.388 .31979 L
.392 .31764 L
.396 .31541 L
.4 .3144 L
Mistroke
.404 .31524 L
.408 .31749 L
.412 .31993 L
.416 .32126 L
.42 .32078 L
.424 .31884 L
.428 .31656 L
.432 .3152 L
.436 .31543 L
.44 .31698 L
.444 .31885 L
.448 .31995 L
.452 .31973 L
.456 .31846 L
.46 .31701 L
.464 .31631 L
.468 .31676 L
.472 .31802 L
.476 .31926 L
.48 .3197 L
.484 .31908 L
.488 .31781 L
.492 .31667 L
.496 .31632 L
.5 .31692 L
.504 .31808 L
.508 .31909 L
.512 .31941 L
.516 .31894 L
.52 .31805 L
.524 .3173 L
.528 .31711 L
.532 .31748 L
.536 .3181 L
.54 .31856 L
.544 .3186 L
.548 .31827 L
.552 .31783 L
.556 .31758 L
.56 .31767 L
.564 .31802 L
.568 .31839 L
.572 .31855 L
.576 .31842 L
.58 .3181 L
.584 .31778 L
.588 .31764 L
.592 .31775 L
.596 .31804 L
.6 .31833 L
Mistroke
.604 .31847 L
.608 .31838 L
.612 .31812 L
.616 .31787 L
.62 .31779 L
.624 .31794 L
.628 .31822 L
.632 .31843 L
.636 .31841 L
.64 .31818 L
.644 .31789 L
.648 .31776 L
.652 .31789 L
.656 .3182 L
.66 .31849 L
.664 .31855 L
.668 .31832 L
.672 .31799 L
.676 .3178 L
.68 .31789 L
.684 .31818 L
.688 .31842 L
.692 .31842 L
.696 .31819 L
.7 .31797 L
.704 .31796 L
.708 .31818 L
.712 .31844 L
.716 .3185 L
.72 .31828 L
.724 .31796 L
.728 .31781 L
.732 .31797 L
.736 .31835 L
.74 .31864 L
.744 .31859 L
.748 .31824 L
.752 .31786 L
.756 .31777 L
.76 .31808 L
.764 .31853 L
.768 .31875 L
.772 .31854 L
.776 .31807 L
.78 .31773 L
.784 .31781 L
.788 .31825 L
.792 .3187 L
.796 .31879 L
.8 .31848 L
Mistroke
.804 .31804 L
.808 .31783 L
.812 .31795 L
.816 .31827 L
.82 .31853 L
.824 .31855 L
.828 .31842 L
.832 .31829 L
.836 .31823 L
.84 .31823 L
.844 .31823 L
.848 .3182 L
.852 .31823 L
.856 .31835 L
.86 .31849 L
.864 .31855 L
.868 .31845 L
.872 .31822 L
.876 .31805 L
.88 .31809 L
.884 .31831 L
.888 .31859 L
.892 .31871 L
.896 .31856 L
.9 .31825 L
.904 .31801 L
.908 .318 L
.912 .31827 L
.916 .31863 L
.92 .31878 L
.924 .31866 L
.928 .31837 L
.932 .31807 L
.936 .31804 L
.94 .31823 L
.944 .31843 L
.948 .3186 L
.952 .31865 L
.956 .31858 L
.96 .31851 L
.964 .3184 L
.968 .3182 L
.972 .31804 L
.976 .31813 L
.98 .31842 L
.984 .31878 L
.988 .31904 L
.992 .3188 L
.996 .31826 L
1 .31796 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .56822 m
.008 .55973 L
.012 .55327 L
.016 .54866 L
.02 .54359 L
.024 .53775 L
.028 .53197 L
.032 .52625 L
.036 .52056 L
.04 .51472 L
.044 .50861 L
.048 .50221 L
.052 .49591 L
.056 .48972 L
.06 .48346 L
.064 .47694 L
.068 .47037 L
.072 .46396 L
.076 .45809 L
.08 .45257 L
.084 .44688 L
.088 .44077 L
.092 .43447 L
.096 .42833 L
.1 .42276 L
.104 .41771 L
.108 .41271 L
.112 .40733 L
.116 .40121 L
.12 .39436 L
.124 .38719 L
.128 .38009 L
.132 .37357 L
.136 .36788 L
.14 .36314 L
.144 .35929 L
.148 .35619 L
.152 .35364 L
.156 .35146 L
.16 .3495 L
.164 .34762 L
.168 .34575 L
.172 .34383 L
.176 .34183 L
.18 .33976 L
.184 .33765 L
.188 .33553 L
.192 .33344 L
.196 .33143 L
.2 .3295 L
Mistroke
.204 .32767 L
.208 .32592 L
.212 .32423 L
.216 .32256 L
.22 .32088 L
.224 .31915 L
.228 .31736 L
.232 .31551 L
.236 .31358 L
.24 .31158 L
.244 .30953 L
.248 .30742 L
.252 .30525 L
.256 .30304 L
.26 .30077 L
.264 .29845 L
.268 .2961 L
.272 .29373 L
.276 .29137 L
.28 .28905 L
.284 .2868 L
.288 .28465 L
.292 .28263 L
.296 .28074 L
.3 .279 L
.304 .27742 L
.308 .27598 L
.312 .2747 L
.316 .27358 L
.32 .2726 L
.324 .27177 L
.328 .27106 L
.332 .27045 L
.336 .26993 L
.34 .26947 L
.344 .26907 L
.348 .26871 L
.352 .2684 L
.356 .26814 L
.36 .26793 L
.364 .26777 L
.368 .26764 L
.372 .26754 L
.376 .26745 L
.38 .26738 L
.384 .26732 L
.388 .26726 L
.392 .26722 L
.396 .2672 L
.4 .26718 L
Mistroke
.404 .26716 L
.408 .26713 L
.412 .26709 L
.416 .26704 L
.42 .26699 L
.424 .26694 L
.428 .2669 L
.432 .26687 L
.436 .26686 L
.44 .26686 L
.444 .26686 L
.448 .26686 L
.452 .26685 L
.456 .26683 L
.46 .2668 L
.464 .26676 L
.468 .26672 L
.472 .26668 L
.476 .26664 L
.48 .2666 L
.484 .26658 L
.488 .26656 L
.492 .26656 L
.496 .26657 L
.5 .26657 L
.504 .26656 L
.508 .26654 L
.512 .2665 L
.516 .26645 L
.52 .26639 L
.524 .26635 L
.528 .26632 L
.532 .26631 L
.536 .26631 L
.54 .26631 L
.544 .26631 L
.548 .2663 L
.552 .26627 L
.556 .26624 L
.56 .2662 L
.564 .26616 L
.568 .26612 L
.572 .26608 L
.576 .26606 L
.58 .26605 L
.584 .26605 L
.588 .26605 L
.592 .26604 L
.596 .26602 L
.6 .26598 L
Mistroke
.604 .26594 L
.608 .2659 L
.612 .26586 L
.616 .26584 L
.62 .26582 L
.624 .26581 L
.628 .2658 L
.632 .26579 L
.636 .26578 L
.64 .26575 L
.644 .26572 L
.648 .26569 L
.652 .26565 L
.656 .26562 L
.66 .2656 L
.664 .26558 L
.668 .26557 L
.672 .26556 L
.676 .26554 L
.68 .26552 L
.684 .26549 L
.688 .26546 L
.692 .26543 L
.696 .2654 L
.7 .26538 L
.704 .26536 L
.708 .26534 L
.712 .26532 L
.716 .2653 L
.72 .26528 L
.724 .26526 L
.728 .26523 L
.732 .2652 L
.736 .26518 L
.74 .26515 L
.744 .26513 L
.748 .26511 L
.752 .26509 L
.756 .26507 L
.76 .26505 L
.764 .26503 L
.768 .265 L
.772 .26498 L
.776 .26495 L
.78 .26493 L
.784 .2649 L
.788 .26488 L
.792 .26486 L
.796 .26484 L
.8 .26482 L
Mistroke
.804 .2648 L
.808 .26477 L
.812 .26475 L
.816 .26472 L
.82 .2647 L
.824 .26468 L
.828 .26466 L
.832 .26463 L
.836 .26461 L
.84 .26459 L
.844 .26457 L
.848 .26455 L
.852 .26452 L
.856 .2645 L
.86 .26447 L
.864 .26445 L
.868 .26443 L
.872 .26441 L
.876 .26439 L
.88 .26436 L
.884 .26434 L
.888 .26432 L
.892 .26429 L
.896 .26427 L
.9 .26425 L
.904 .26422 L
.908 .2642 L
.912 .26418 L
.916 .26416 L
.92 .26414 L
.924 .26412 L
.928 .26409 L
.932 .26407 L
.936 .26404 L
.94 .26402 L
.944 .26399 L
.948 .26397 L
.952 .26395 L
.956 .26394 L
.96 .26391 L
.964 .26389 L
.968 .26386 L
.972 .26384 L
.976 .26381 L
.98 .26379 L
.984 .26376 L
.988 .26375 L
.992 .26373 L
.996 .26371 L
1 .26368 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .39903 m
.008 .39394 L
.012 .38365 L
.016 .37545 L
.02 .36903 L
.024 .36209 L
.028 .3546 L
.032 .3476 L
.036 .34096 L
.04 .33424 L
.044 .32727 L
.048 .32018 L
.052 .31302 L
.056 .30595 L
.06 .29872 L
.064 .29101 L
.068 .28281 L
.072 .27487 L
.076 .26738 L
.08 .26019 L
.084 .2529 L
.088 .2452 L
.092 .23724 L
.096 .2297 L
.1 .22289 L
.104 .21668 L
.108 .21055 L
.112 .20374 L
.116 .19588 L
.12 .18705 L
.124 .17767 L
.128 .16849 L
.132 .16007 L
.136 .15287 L
.14 .14701 L
.144 .1424 L
.148 .13883 L
.152 .13597 L
.156 .13355 L
.16 .13132 L
.164 .12914 L
.168 .1269 L
.172 .12455 L
.176 .12211 L
.18 .11958 L
.184 .11699 L
.188 .11436 L
.192 .11173 L
.196 .10911 L
.2 .10654 L
Mistroke
.204 .10404 L
.208 .10164 L
.212 .09934 L
.216 .09716 L
.22 .09509 L
.224 .09308 L
.228 .0911 L
.232 .08909 L
.236 .08699 L
.24 .08476 L
.244 .08236 L
.248 .07978 L
.252 .07702 L
.256 .07412 L
.26 .07111 L
.264 .06806 L
.268 .065 L
.272 .06199 L
.276 .05905 L
.28 .05623 L
.284 .05352 L
.288 .05096 L
.292 .04855 L
.296 .0463 L
.3 .04424 L
.304 .04235 L
.308 .04065 L
.312 .03911 L
.316 .03774 L
.32 .03652 L
.324 .03543 L
.328 .03448 L
.332 .03366 L
.336 .03297 L
.34 .03241 L
.344 .03196 L
.348 .03162 L
.352 .03135 L
.356 .03113 L
.36 .03095 L
.364 .03079 L
.368 .03065 L
.372 .03054 L
.376 .03045 L
.38 .03039 L
.384 .03034 L
.388 .0303 L
.392 .03027 L
.396 .03023 L
.4 .0302 L
Mistroke
.404 .03017 L
.408 .03016 L
.412 .03017 L
.416 .0302 L
.42 .03023 L
.424 .03027 L
.428 .03029 L
.432 .0303 L
.436 .03029 L
.44 .03026 L
.444 .03024 L
.448 .03022 L
.452 .03021 L
.456 .03021 L
.46 .03022 L
.464 .03024 L
.468 .03027 L
.472 .0303 L
.476 .03033 L
.48 .03035 L
.484 .03036 L
.488 .03036 L
.492 .03034 L
.496 .03031 L
.5 .03028 L
.504 .03027 L
.508 .03028 L
.512 .0303 L
.516 .03035 L
.52 .03039 L
.524 .03042 L
.528 .03043 L
.532 .03043 L
.536 .03041 L
.54 .03038 L
.544 .03036 L
.548 .03035 L
.552 .03036 L
.556 .03038 L
.56 .03041 L
.564 .03044 L
.568 .03046 L
.572 .03048 L
.576 .03049 L
.58 .03048 L
.584 .03046 L
.588 .03044 L
.592 .03043 L
.596 .03043 L
.6 .03045 L
Mistroke
.604 .03048 L
.608 .03051 L
.612 .03053 L
.616 .03054 L
.62 .03054 L
.624 .03053 L
.628 .03052 L
.632 .03051 L
.636 .03051 L
.64 .03052 L
.644 .03053 L
.648 .03055 L
.652 .03057 L
.656 .03059 L
.66 .0306 L
.664 .0306 L
.668 .03059 L
.672 .03058 L
.676 .03058 L
.68 .03058 L
.684 .0306 L
.688 .03061 L
.692 .03063 L
.696 .03064 L
.7 .03065 L
.704 .03065 L
.708 .03065 L
.712 .03065 L
.716 .03065 L
.72 .03065 L
.724 .03066 L
.728 .03068 L
.732 .03069 L
.736 .0307 L
.74 .03071 L
.744 .03071 L
.748 .03071 L
.752 .03071 L
.756 .03072 L
.76 .03073 L
.764 .03073 L
.768 .03074 L
.772 .03075 L
.776 .03076 L
.78 .03077 L
.784 .03077 L
.788 .03078 L
.792 .03078 L
.796 .03079 L
.8 .03079 L
Mistroke
.804 .03079 L
.808 .0308 L
.812 .03081 L
.816 .03082 L
.82 .03083 L
.824 .03084 L
.828 .03084 L
.832 .03085 L
.836 .03085 L
.84 .03085 L
.844 .03086 L
.848 .03086 L
.852 .03088 L
.856 .03089 L
.86 .0309 L
.864 .0309 L
.868 .03091 L
.872 .03091 L
.876 .03091 L
.88 .03091 L
.884 .03093 L
.888 .03094 L
.892 .03095 L
.896 .03095 L
.9 .03096 L
.904 .03096 L
.908 .03097 L
.912 .03097 L
.916 .03097 L
.92 .03098 L
.924 .031 L
.928 .03101 L
.932 .03102 L
.936 .03102 L
.94 .03102 L
.944 .03102 L
.948 .03103 L
.952 .03103 L
.956 .03105 L
.96 .03106 L
.964 .03107 L
.968 .03107 L
.972 .03108 L
.976 .03107 L
.98 .03108 L
.984 .03108 L
.988 .0311 L
.992 .03111 L
.996 .03113 L
1 .03112 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`03001oogoo008000Eoo`8000Aoo`04
001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@0
07ooOol000Eoo`008Woo0P0037oo3P0017oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomo
o`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007oo
00003Goo00<007ooOol00Woo10000Woo0`00DGoo000ROol30004Ool20006Ool00`00Oomoo`0<Ool0
0`00Oomoo`1>Ool0029oof<000aoo`008Woo00<007ooOol0100000Aoo`00001oo`H000=oo`05001o
ogooOol00002Ool01P00Oomoogoo001oo`/00003Ool0000003@000aoo`008Woo0P000Woo00<007oo
Ool00Woo00<007oo00006Goo0P0000=oo`0000000Woo00@007ooOol0009oo`03001oogoo03Yoo`00
8Woo00<007ooOol01goo00<007ooOol0HWoo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo
00<007ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03
001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomo
o`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eo
o`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qo
o`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo
000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool0
0`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo
00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001o
ogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<0
07ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03
001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1V
Ool0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03
001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04
001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eo
o`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009o
o`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001o
ogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007oo
Oomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@00
0Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001o
ogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009o
o`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007oo
Ool000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Iood0000=oo`04001o
ogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Ioo`@000Aoo`8000Aoo`8000Aoo`04001o
ogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03
001oogoo01Ioo`<004eoo`00:7oo00<007ooOol05Goo0P00Cgoo000XOomM000<Ool002Qoo`03001o
ogoo00moo`D000ioo`03001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yo
o`00:7oo00<007ooOol03goo0P00EGoo000XOol00`00Oomoo`0<Ool3001GOol002Qoo`03001oogoo
00]oo`8005Uoo`00:7oo00<007ooOol02Woo00<007ooOol0FGoo000XOol00`00Oomoo`09Ool00`00
Oomoo`1JOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo00Qo
o`8005aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001o
ogoo000:Ool00`00Oomoo`1KOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`04001oogoo0009Ool2001MOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo008000Moo`8005ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1@00Oomoo`00Ool010000goo00<007ooOol01Woo00<007ooOol0GGoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol01Goo00<007ooOol0GWoo000;Ool2
000:Ool20004Ool20002Ool50002Ool00`00Oomoo`04Ool2001POol002Qoo`03001oogoo00Aoo`03
001oogoo05moo`00:7oo00<007ooOol00goo00<007ooOol0H7oo000AOol20004Ool00`00Oomoo`03
Ool20003Ool30003Ool00`00Oomoo`03Ool00`00Oomoo`1POol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0HGoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`05001oogooOol0001TOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P0000=oo`000000I7oo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`04001oogoo001UOol0011oo`04001oogoo0008Ool01000
Oomoo`000Woo0P0017oo00<007oo0000IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool3001V
Ool002Qoo`8006Moo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<0
07ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`00
2goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol0021oodP000aoo`002Woo
00@007ooOol000Moo`@000=oo`03001oogoo01aoo`<005=oo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`8001]oo`8005Ioo`002goo0P0027oo1@000Woo00<007ooOol06Goo0P00Egoo000LOol0
0`00Oomoo`0=Ool30004Ool20002Ool20005Ool30004Ool20004Ool20005Ool30003Ool30004Ool2
0005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogoo
Ool00002Ool00`00Oomoo`020008Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol0
0goo000LOol00`00Oomoo`0@Ool00`00Oomoo`040009Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`03001oogoo011oo`03001oo`0000800003Ool007oo00Qoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eo
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo0P003Goo100000Aoo`000000009oo`03001oogoo00Moo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo
0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001o
o`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo0080009oo`04001oogoo
0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001o
ogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo
001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`80
00Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003
Ool20006Ool001aoo`03001oogoo00aoo`8006Aoo`0077oo00<007ooOol02goo0P00IGoo000LOomY
000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol0
0`00Oomoo`0:Ool00`00Oomoo`1UOol001aoo`8000]oo`03001oogoo06Eoo`0077oo00<007ooOol0
2Goo00<007ooOol0IWoo000LOol00`00Oomoo`08Ool2001XOol001aoo`8000Uoo`03001oogoo06Mo
o`0077oo00<007ooOol01goo0P00JGoo000LOol00`00Oomoo`07Ool00`00Oomoo`1XOol001aoo`80
00Moo`03001oogoo06Uoo`0077oo00<007ooOol01Woo00<007ooOol0JGoo000LOol20006Ool00`00
Oomoo`1ZOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo00Eoo`03001oogoo06Yo
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`04Ool00`00Oomoo`1[Ool0
00Yoo`04001oogoo000;Ool00`00Oomoo`020004Ool2001]Ool000Yoo`04001oogoo000;Ool01000
Oomoo`001Goo00<007ooOol0K7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol00goo00<0
07ooOol0K7oo000:Ool01000Oomoo`001goo00<007ooOol017oo0P000goo00<007ooOol0KGoo000;
Ool20008Ool50002Ool01@00Oomoogoo0000L7oo000LOol01@00Oomoogoo0000L7oo000LOol20000
0goo0000001`Ool001aoo`04001oogoo001aOol001aoo`<0079oo`0077oo0P00Lgoo000LOol2001c
Ool001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomo
o`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000G
Ool00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol00Woo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomo
o`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo0080
07=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04
Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo
000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(25885\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30286 m
.008 .30405 L
.012 .30738 L
.016 .3103 L
.02 .3124 L
.024 .31327 L
.028 .31253 L
.032 .30943 L
.036 .30488 L
.04 .30061 L
.044 .29781 L
.048 .29627 L
.052 .29627 L
.056 .29947 L
.06 .30532 L
.064 .31201 L
.068 .31662 L
.072 .31712 L
.076 .31377 L
.08 .30854 L
.084 .30277 L
.088 .29608 L
.092 .29006 L
.096 .28728 L
.1 .29029 L
.104 .30017 L
.108 .31449 L
.112 .32856 L
.116 .33816 L
.12 .34137 L
.124 .3388 L
.128 .33343 L
.132 .32822 L
.136 .32529 L
.14 .32544 L
.144 .3278 L
.148 .331 L
.152 .3332 L
.156 .33302 L
.16 .32972 L
.164 .32332 L
.168 .31474 L
.172 .30528 L
.176 .29644 L
.18 .28933 L
.184 .2845 L
.188 .28182 L
.192 .28064 L
.196 .28012 L
.2 .27948 L
Mistroke
.204 .27834 L
.208 .2767 L
.212 .27485 L
.216 .27325 L
.22 .27228 L
.224 .27218 L
.228 .27303 L
.232 .27478 L
.236 .27721 L
.24 .28004 L
.244 .28282 L
.248 .28499 L
.252 .28601 L
.256 .28555 L
.26 .28364 L
.264 .28076 L
.268 .27773 L
.272 .27539 L
.276 .27428 L
.28 .27438 L
.284 .27515 L
.288 .27579 L
.292 .27569 L
.296 .27477 L
.3 .27363 L
.304 .27327 L
.308 .27463 L
.312 .27808 L
.316 .28313 L
.32 .28863 L
.324 .2932 L
.328 .29594 L
.332 .29684 L
.336 .29679 L
.34 .29713 L
.344 .29892 L
.348 .30239 L
.352 .30677 L
.356 .3107 L
.36 .313 L
.364 .31327 L
.368 .31215 L
.372 .31095 L
.376 .31092 L
.38 .3126 L
.384 .31547 L
.388 .31829 L
.392 .31982 L
.396 .31948 L
.4 .3177 L
Mistroke
.404 .31563 L
.408 .3145 L
.412 .31494 L
.416 .31664 L
.42 .31863 L
.424 .3198 L
.428 .31962 L
.432 .31837 L
.436 .31691 L
.44 .31619 L
.444 .31661 L
.448 .31787 L
.452 .31914 L
.456 .31962 L
.46 .31902 L
.464 .31773 L
.468 .31654 L
.472 .31617 L
.476 .31681 L
.48 .31804 L
.484 .31914 L
.488 .31949 L
.492 .31898 L
.496 .31798 L
.5 .31712 L
.504 .31687 L
.508 .31729 L
.512 .31802 L
.516 .31858 L
.52 .31865 L
.524 .31827 L
.528 .31776 L
.532 .31746 L
.536 .31755 L
.54 .31795 L
.544 .31838 L
.548 .31856 L
.552 .31839 L
.556 .31799 L
.56 .31762 L
.564 .31748 L
.568 .31766 L
.572 .31803 L
.576 .31837 L
.58 .31849 L
.584 .31834 L
.588 .31803 L
.592 .31774 L
.596 .31766 L
.6 .31785 L
Mistroke
.604 .31817 L
.608 .31841 L
.612 .3184 L
.616 .31813 L
.62 .31779 L
.624 .31763 L
.628 .31778 L
.632 .31816 L
.636 .3185 L
.64 .31856 L
.644 .3183 L
.648 .31789 L
.652 .31761 L
.656 .31768 L
.66 .31805 L
.664 .31843 L
.668 .31855 L
.672 .31832 L
.676 .31794 L
.68 .31773 L
.684 .31785 L
.688 .3182 L
.692 .31849 L
.696 .31847 L
.7 .31817 L
.704 .31784 L
.708 .31775 L
.712 .31797 L
.716 .31832 L
.72 .31853 L
.724 .31844 L
.728 .31815 L
.732 .3179 L
.736 .31789 L
.74 .3181 L
.744 .31833 L
.748 .31839 L
.752 .31824 L
.756 .31805 L
.76 .31804 L
.764 .3182 L
.768 .31837 L
.772 .31837 L
.776 .31817 L
.78 .31797 L
.784 .31799 L
.788 .31823 L
.792 .31849 L
.796 .31852 L
.8 .31826 L
Mistroke
.804 .31794 L
.808 .31785 L
.812 .31809 L
.816 .31848 L
.82 .3187 L
.824 .31856 L
.828 .31817 L
.832 .31783 L
.836 .31779 L
.84 .31809 L
.844 .31849 L
.848 .31872 L
.852 .31865 L
.856 .31836 L
.86 .31804 L
.864 .31791 L
.868 .31798 L
.872 .31818 L
.876 .31842 L
.88 .31858 L
.884 .31861 L
.888 .31853 L
.892 .31833 L
.896 .31806 L
.9 .31789 L
.904 .31794 L
.908 .31821 L
.912 .31863 L
.916 .31891 L
.92 .31879 L
.924 .31839 L
.928 .31791 L
.932 .3177 L
.936 .31794 L
.94 .31843 L
.944 .3188 L
.948 .31887 L
.952 .31864 L
.956 .31828 L
.96 .31806 L
.964 .31804 L
.968 .31809 L
.972 .31824 L
.976 .31851 L
.98 .31871 L
.984 .31884 L
.988 .31876 L
.992 .31828 L
.996 .31787 L
1 .3178 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .5873 m
.008 .59229 L
.012 .5918 L
.016 .58568 L
.02 .57995 L
.024 .57445 L
.028 .56859 L
.032 .56236 L
.036 .55646 L
.04 .55075 L
.044 .54505 L
.048 .53926 L
.052 .5337 L
.056 .52831 L
.06 .52288 L
.064 .5172 L
.068 .51132 L
.072 .50538 L
.076 .49957 L
.08 .49376 L
.084 .48764 L
.088 .48115 L
.092 .47473 L
.096 .46864 L
.1 .46297 L
.104 .45742 L
.108 .45156 L
.112 .44526 L
.116 .43882 L
.12 .43263 L
.124 .42702 L
.128 .42191 L
.132 .4169 L
.136 .41155 L
.14 .40549 L
.144 .3987 L
.148 .39144 L
.152 .3841 L
.156 .37717 L
.16 .37097 L
.164 .36571 L
.168 .36142 L
.172 .358 L
.176 .35527 L
.18 .35303 L
.184 .35107 L
.188 .34924 L
.192 .3474 L
.196 .34549 L
.2 .34346 L
Mistroke
.204 .34134 L
.208 .33914 L
.212 .33692 L
.216 .33473 L
.22 .33261 L
.224 .33058 L
.228 .32867 L
.232 .32685 L
.236 .32512 L
.24 .32345 L
.244 .3218 L
.248 .32015 L
.252 .31847 L
.256 .31673 L
.26 .31493 L
.264 .31305 L
.268 .31108 L
.272 .30902 L
.276 .30686 L
.28 .30461 L
.284 .30229 L
.288 .29992 L
.292 .29753 L
.296 .29514 L
.3 .29278 L
.304 .29047 L
.308 .28822 L
.312 .28606 L
.316 .28398 L
.32 .28202 L
.324 .28018 L
.328 .27848 L
.332 .27694 L
.336 .27555 L
.34 .27433 L
.344 .27325 L
.348 .27231 L
.352 .27149 L
.356 .27077 L
.36 .27016 L
.364 .26963 L
.368 .26919 L
.372 .26883 L
.376 .26853 L
.38 .26828 L
.384 .26805 L
.388 .26786 L
.392 .26768 L
.396 .26753 L
.4 .26741 L
Mistroke
.404 .26731 L
.408 .26724 L
.412 .26719 L
.416 .26716 L
.42 .26714 L
.424 .26712 L
.428 .26709 L
.432 .26706 L
.436 .26702 L
.44 .26697 L
.444 .26692 L
.448 .26688 L
.452 .26684 L
.456 .26681 L
.46 .26679 L
.464 .26678 L
.468 .26677 L
.472 .26678 L
.476 .26677 L
.48 .26676 L
.484 .26673 L
.488 .26669 L
.492 .26664 L
.496 .26659 L
.5 .26655 L
.504 .26652 L
.508 .26651 L
.512 .26652 L
.516 .26652 L
.52 .26651 L
.524 .2665 L
.528 .26647 L
.532 .26643 L
.536 .26639 L
.54 .26635 L
.544 .26631 L
.548 .26628 L
.552 .26627 L
.556 .26626 L
.56 .26626 L
.564 .26625 L
.568 .26624 L
.572 .26622 L
.576 .26618 L
.58 .26614 L
.584 .2661 L
.588 .26606 L
.592 .26604 L
.596 .26602 L
.6 .26602 L
Mistroke
.604 .26601 L
.608 .266 L
.612 .26598 L
.616 .26595 L
.62 .26592 L
.624 .26588 L
.628 .26585 L
.632 .26582 L
.636 .2658 L
.64 .26578 L
.644 .26577 L
.648 .26576 L
.652 .26574 L
.656 .26572 L
.66 .26569 L
.664 .26566 L
.668 .26563 L
.672 .2656 L
.676 .26558 L
.68 .26556 L
.684 .26554 L
.688 .26552 L
.692 .26551 L
.696 .26549 L
.7 .26546 L
.704 .26543 L
.708 .2654 L
.712 .26537 L
.716 .26535 L
.72 .26533 L
.724 .26531 L
.728 .2653 L
.732 .26527 L
.736 .26525 L
.74 .26523 L
.744 .2652 L
.748 .26518 L
.752 .26515 L
.756 .26513 L
.76 .26511 L
.764 .26508 L
.768 .26506 L
.772 .26504 L
.776 .26502 L
.78 .265 L
.784 .26498 L
.788 .26495 L
.792 .26492 L
.796 .2649 L
.8 .26488 L
Mistroke
.804 .26486 L
.808 .26484 L
.812 .26481 L
.816 .26479 L
.82 .26477 L
.824 .26475 L
.828 .26472 L
.832 .2647 L
.836 .26467 L
.84 .26465 L
.844 .26463 L
.848 .26461 L
.852 .26459 L
.856 .26457 L
.86 .26454 L
.864 .26452 L
.868 .26449 L
.872 .26447 L
.876 .26445 L
.88 .26442 L
.884 .26441 L
.888 .26439 L
.892 .26436 L
.896 .26434 L
.9 .26431 L
.904 .26429 L
.908 .26426 L
.912 .26424 L
.916 .26422 L
.92 .2642 L
.924 .26418 L
.928 .26416 L
.932 .26413 L
.936 .2641 L
.94 .26408 L
.944 .26406 L
.948 .26404 L
.952 .26402 L
.956 .264 L
.96 .26397 L
.964 .26395 L
.968 .26392 L
.972 .2639 L
.976 .26387 L
.98 .26386 L
.984 .26383 L
.988 .26382 L
.992 .26379 L
.996 .26377 L
1 .26374 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43403 L
.012 .42882 L
.016 .42335 L
.02 .41767 L
.024 .41148 L
.028 .40443 L
.032 .39747 L
.036 .39056 L
.04 .38363 L
.044 .37646 L
.048 .36923 L
.052 .36199 L
.056 .35497 L
.06 .34804 L
.064 .34087 L
.068 .33344 L
.072 .32616 L
.076 .31906 L
.08 .31185 L
.084 .30419 L
.088 .29603 L
.092 .28766 L
.096 .27972 L
.1 .27228 L
.104 .26499 L
.108 .25746 L
.112 .24958 L
.116 .24162 L
.12 .23417 L
.124 .22748 L
.128 .22139 L
.132 .21544 L
.136 .20894 L
.14 .20151 L
.144 .19311 L
.148 .18406 L
.152 .17495 L
.156 .16632 L
.16 .15861 L
.164 .15204 L
.168 .14662 L
.172 .14223 L
.176 .13863 L
.18 .13562 L
.184 .13297 L
.188 .13053 L
.192 .1282 L
.196 .12589 L
.2 .12356 L
Mistroke
.204 .12118 L
.208 .11875 L
.212 .11627 L
.216 .11375 L
.22 .1112 L
.224 .10867 L
.228 .10617 L
.232 .10373 L
.236 .10139 L
.24 .09914 L
.244 .09698 L
.248 .09489 L
.252 .09282 L
.256 .09075 L
.26 .08861 L
.264 .08639 L
.268 .08404 L
.272 .08157 L
.276 .07897 L
.28 .07624 L
.284 .07341 L
.288 .07049 L
.292 .06751 L
.296 .06451 L
.3 .06151 L
.304 .05856 L
.308 .05571 L
.312 .05298 L
.316 .05043 L
.32 .04805 L
.324 .04586 L
.328 .04386 L
.332 .04204 L
.336 .04038 L
.34 .03889 L
.344 .03756 L
.348 .0364 L
.352 .03538 L
.356 .03451 L
.36 .03377 L
.364 .03314 L
.368 .03261 L
.372 .03216 L
.376 .03178 L
.38 .03148 L
.384 .03124 L
.388 .03106 L
.392 .03093 L
.396 .03084 L
.4 .03078 L
Mistroke
.404 .03071 L
.408 .03065 L
.412 .03059 L
.416 .03052 L
.42 .03047 L
.424 .03043 L
.428 .03041 L
.432 .0304 L
.436 .03041 L
.44 .03043 L
.444 .03046 L
.448 .03048 L
.452 .0305 L
.456 .03052 L
.46 .03052 L
.464 .0305 L
.468 .03048 L
.472 .03045 L
.476 .03043 L
.48 .03043 L
.484 .03044 L
.488 .03047 L
.492 .03051 L
.496 .03055 L
.5 .03058 L
.504 .03059 L
.508 .03058 L
.512 .03055 L
.516 .03053 L
.52 .03051 L
.524 .0305 L
.528 .03052 L
.532 .03054 L
.536 .03057 L
.54 .0306 L
.544 .03063 L
.548 .03064 L
.552 .03064 L
.556 .03062 L
.56 .03061 L
.564 .03059 L
.568 .03058 L
.572 .03059 L
.576 .03061 L
.58 .03064 L
.584 .03067 L
.588 .03069 L
.592 .0307 L
.596 .03069 L
.6 .03068 L
Mistroke
.604 .03067 L
.608 .03066 L
.612 .03066 L
.616 .03067 L
.62 .03069 L
.624 .03071 L
.628 .03073 L
.632 .03075 L
.636 .03075 L
.64 .03075 L
.644 .03074 L
.648 .03073 L
.652 .03073 L
.656 .03074 L
.66 .03075 L
.664 .03077 L
.668 .03079 L
.672 .0308 L
.676 .0308 L
.68 .0308 L
.684 .0308 L
.688 .0308 L
.692 .0308 L
.696 .03081 L
.7 .03082 L
.704 .03083 L
.708 .03084 L
.712 .03085 L
.716 .03086 L
.72 .03087 L
.724 .03087 L
.728 .03087 L
.732 .03087 L
.736 .03088 L
.74 .03088 L
.744 .03089 L
.748 .0309 L
.752 .03091 L
.756 .03092 L
.76 .03093 L
.764 .03093 L
.768 .03093 L
.772 .03094 L
.776 .03094 L
.78 .03095 L
.784 .03096 L
.788 .03097 L
.792 .03098 L
.796 .03098 L
.8 .03099 L
Mistroke
.804 .03099 L
.808 .031 L
.812 .031 L
.816 .03101 L
.82 .03101 L
.824 .03102 L
.828 .03103 L
.832 .03104 L
.836 .03105 L
.84 .03105 L
.844 .03106 L
.848 .03106 L
.852 .03106 L
.856 .03107 L
.86 .03108 L
.864 .03109 L
.868 .0311 L
.872 .0311 L
.876 .03111 L
.88 .03112 L
.884 .03112 L
.888 .03113 L
.892 .03113 L
.896 .03113 L
.9 .03114 L
.904 .03115 L
.908 .03116 L
.912 .03117 L
.916 .03118 L
.92 .03118 L
.924 .03118 L
.928 .03119 L
.932 .03119 L
.936 .0312 L
.94 .03121 L
.944 .03122 L
.948 .03123 L
.952 .03124 L
.956 .03124 L
.96 .03124 L
.964 .03125 L
.968 .03125 L
.972 .03126 L
.976 .03127 L
.98 .03129 L
.984 .03129 L
.988 .0313 L
.992 .03129 L
.996 .0313 L
1 .0313 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D00003Ool000000080009oo`L000Eoo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo00Moo`03001oogoo00Eoo`<000=oo`<000Aoo`03001oogoo04eoo`008Woo0P000Woo0P00
0goo0P001Woo0P0037oo0`00CGoo000ROomS000<Ool0029oo`03001oo`0000800004Ool000000002
Ool20003Ool20002Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000=ood0000aoo`008Woo0P00
2Goo00H007oo000007oo000EOol200000goo00000002Ool01000Oomoo`00?Woo000ROol00`00Oomo
o`08Ool300000goo0000001NOol0029oo`8000Yoo`03001oogoo061oo`008Woo0P00KGoo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P00
17oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo
0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo
06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]
Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2
001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06ao
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`00
00=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo
00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003
Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0
17oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004
Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001o
ogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`00
0goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`00
0goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo
0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo
00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomo
o`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool0
1@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo
0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
ogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002
Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo
00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomo
o`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo
0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool0
1000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P000Woo
?0000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo10000Woo0P0017oo
0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`80
00Ioo`00:7oo00<007ooOol06Goo0P00Bgoo000XOol00`00Oomoo`0GOol3001<Ool002Qooed000ao
o`00:7oo00<007ooOol03goo00@007ooOomoo`<000aoo`03001oogoo00moo`03001oogoo00moo`03
001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol04Goo0`00DWoo000XOol00`00Oomoo`0?
Ool2001EOol002Qoo`03001oogoo00eoo`<005Ioo`00:7oo00<007ooOol037oo0P00F7oo000XOol0
0`00Oomoo`0;Ool2001IOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03
001oogoo00]oo`03001oogoo05Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000=oo`04001oogoo000<Ool2001JOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00@007ooOol000Eoo`04001oogoo000<Ool00`00Oomoo`1IOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000Yoo`03001oogoo05Yoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol027oo00<007ooOol0
Fgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0
27oo00<007ooOol0Fgoo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`07Ool00`00
Oomoo`1LOol002Qoo`03001oogoo00Ioo`8005ioo`00:7oo00<007ooOol01Goo0P00Ggoo000AOol2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`05Ool00`00Oomoo`1NOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0Ggoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00Aoo`03001o
ogoo05moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20004Ool00`00
Oomoo`1POol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
0Woo0P00HWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`04001oogooOol2001S
Ool0015oo`8000Yoo`8000Aoo`03001oogoo009oo`05001oogooOol0001TOol002Qoo`04001oogoo
001UOol002Qoo`04001oo`00001UOol002Qoo`03001oo`0006Ioo`002goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo0`000goo0P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05
001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomo
o`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]o
o`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
00]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02
001cOol000Yoo`04001oogoo000;Ool01000Oomoo`008gooA@0037oo000:Ool01000Oomoo`001goo
10000goo00<007ooOol07goo0P00DGoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P007Woo
0P00Dgoo000;Ool20008Ool50002Ool00`00Oomoo`0LOol2001DOol001aoo`03001oogoo00eoo`<0
00Aoo`8000Aoo`8000=oo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`80
00Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001o
ogoo0002Ool20005Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogoo
Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol0
0`00Oomoo`0@Ool01000Oomoo`000Woo10001Woo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo
000LOol00`00Oomoo`0@Ool01@00Oomoo`00Ool00P002Goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000LOol2000=Ool40003Ool40009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol0
0`00Oomoo`0<Ool00`00Oomoo`03Ool20002Ool00`00Oomoo`06Ool20004Ool01000Oomoo`000Woo
00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0
01aoo`8000eoo`H0009oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003
Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo00mo
o`80065oo`0077oo00<007ooOol03Woo0P00HWoo000LOomY000<Ool001aoo`05001oogooOol00003
Ool00`00Oomoo`02Ool00`00Oomoo`020003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo00eoo`03001oogoo069oo`00
77oo0P003Woo00<007ooOol0HWoo000LOol00`00Oomoo`0<Ool00`00Oomoo`1SOol001aoo`03001o
ogoo00]oo`03001oogoo06Aoo`0077oo0P002goo0P00IWoo000LOol00`00Oomoo`0:Ool00`00Oomo
o`1UOol001aoo`03001oogoo00Yoo`03001oogoo06Eoo`0077oo0P002Woo00<007ooOol0IWoo000L
Ool00`00Oomoo`08Ool00`00Oomoo`1WOol001aoo`8000Uoo`03001oogoo06Moo`002goo0P0017oo
00<007ooOol00Woo0`000goo00<007ooOol027oo00<007ooOol0Igoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo00Moo`03001oogoo06Qoo`002Woo00@007ooOol000]oo`03
001oogoo008000Moo`03001oogoo06Uoo`002Woo00@007ooOol000]oo`04001oogoo0008Ool00`00
Oomoo`1YOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`05Ool00`00Oomoo`1ZOol000Yo
o`04001oogoo0007Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`1ZOol000]oo`8000Qoo`D0009o
o`03001oogoo00Aoo`03001oogoo06]oo`0077oo00<007ooOol017oo00<007ooOol0Jgoo000LOol2
0004Ool00`00Oomoo`1/Ool001aoo`03001oogoo00=oo`03001oogoo06aoo`0077oo0P000goo00<0
07ooOol0KGoo000LOol01000Oomoogoo0P00Kgoo000LOol01@00Oomoogoo0000L7oo000LOol20000
0goo0000001`Ool001Ioo`<000=oo`04001oogoo001aOol001Moo`03001oogoo009oo`03001oo`00
079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Mo
o`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo
009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079o
o`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00
Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Ao
o`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(26052\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31616 m
.008 .31372 L
.012 .31027 L
.016 .30304 L
.02 .29374 L
.024 .28795 L
.028 .28715 L
.032 .28988 L
.036 .29525 L
.04 .30198 L
.044 .30825 L
.048 .31124 L
.052 .31003 L
.056 .30586 L
.06 .30084 L
.064 .29648 L
.068 .29406 L
.072 .29428 L
.076 .29816 L
.08 .30652 L
.084 .31683 L
.088 .32474 L
.092 .32737 L
.096 .32511 L
.1 .31987 L
.104 .31376 L
.108 .30803 L
.112 .30263 L
.116 .29901 L
.12 .29925 L
.124 .30451 L
.128 .31403 L
.132 .32475 L
.136 .33269 L
.14 .33544 L
.144 .33322 L
.148 .32834 L
.152 .32431 L
.156 .32356 L
.16 .32684 L
.164 .33305 L
.168 .33983 L
.172 .34491 L
.176 .34657 L
.18 .34434 L
.184 .3387 L
.188 .33076 L
.192 .32183 L
.196 .31296 L
.2 .30491 L
Mistroke
.204 .29801 L
.208 .29241 L
.212 .28804 L
.216 .28473 L
.22 .28224 L
.224 .28021 L
.228 .27832 L
.232 .2764 L
.236 .27454 L
.24 .27312 L
.244 .27267 L
.248 .27361 L
.252 .276 L
.256 .27937 L
.26 .28282 L
.264 .28536 L
.268 .28626 L
.272 .28545 L
.276 .28353 L
.28 .28153 L
.284 .28042 L
.288 .2806 L
.292 .28169 L
.296 .28273 L
.3 .28264 L
.304 .28086 L
.308 .27771 L
.312 .27433 L
.316 .27212 L
.32 .27212 L
.324 .27441 L
.328 .27811 L
.332 .28185 L
.336 .28444 L
.34 .28554 L
.344 .28577 L
.348 .28634 L
.352 .28835 L
.356 .29215 L
.36 .29708 L
.364 .30184 L
.368 .30519 L
.372 .30658 L
.376 .30645 L
.38 .30596 L
.384 .30632 L
.388 .30813 L
.392 .31106 L
.396 .31409 L
.4 .31613 L
Mistroke
.404 .31663 L
.408 .31589 L
.412 .31484 L
.416 .31448 L
.42 .31524 L
.424 .31681 L
.428 .31834 L
.432 .319 L
.436 .3185 L
.44 .31725 L
.444 .31612 L
.448 .31585 L
.452 .31662 L
.456 .31798 L
.46 .31915 L
.464 .31948 L
.468 .31888 L
.472 .3178 L
.476 .3169 L
.48 .31668 L
.484 .31717 L
.488 .31798 L
.492 .31857 L
.496 .31863 L
.5 .31822 L
.504 .31768 L
.508 .31739 L
.512 .31751 L
.516 .31793 L
.52 .31833 L
.524 .31847 L
.528 .31826 L
.532 .31786 L
.536 .31752 L
.54 .31744 L
.544 .31765 L
.548 .31802 L
.552 .31832 L
.556 .3184 L
.56 .31824 L
.564 .31795 L
.568 .3177 L
.572 .31765 L
.576 .3178 L
.58 .31806 L
.584 .31826 L
.588 .31827 L
.592 .31807 L
.596 .3178 L
.6 .31767 L
Mistroke
.604 .31778 L
.608 .31807 L
.612 .31835 L
.616 .3184 L
.62 .31819 L
.624 .31785 L
.628 .31763 L
.632 .31769 L
.636 .31799 L
.64 .31831 L
.644 .31842 L
.648 .31823 L
.652 .31791 L
.656 .31772 L
.66 .31783 L
.664 .31814 L
.668 .31839 L
.672 .31836 L
.676 .31805 L
.68 .31774 L
.684 .31768 L
.688 .31796 L
.692 .31835 L
.696 .31855 L
.7 .31839 L
.704 .31799 L
.708 .31768 L
.712 .3177 L
.716 .31804 L
.72 .31842 L
.724 .31854 L
.728 .31831 L
.732 .31792 L
.736 .31771 L
.74 .31785 L
.744 .31822 L
.748 .31851 L
.752 .31848 L
.756 .31818 L
.76 .31788 L
.764 .31781 L
.768 .31801 L
.772 .31828 L
.776 .31839 L
.78 .31831 L
.784 .31815 L
.788 .31808 L
.792 .31813 L
.796 .3182 L
.8 .31818 L
Mistroke
.804 .3181 L
.808 .31806 L
.812 .31815 L
.816 .31833 L
.82 .31843 L
.824 .31835 L
.828 .31813 L
.832 .31795 L
.836 .31796 L
.84 .31818 L
.844 .31843 L
.848 .31851 L
.852 .31836 L
.856 .31809 L
.86 .31794 L
.864 .31804 L
.868 .3183 L
.872 .3185 L
.876 .31851 L
.88 .31829 L
.884 .31804 L
.888 .31798 L
.892 .31812 L
.896 .31833 L
.9 .31849 L
.904 .31847 L
.908 .31835 L
.912 .31825 L
.916 .31816 L
.92 .31811 L
.924 .31812 L
.928 .31819 L
.932 .31836 L
.936 .31859 L
.94 .31868 L
.944 .31848 L
.948 .31812 L
.952 .31785 L
.956 .31785 L
.96 .31823 L
.964 .31869 L
.968 .31883 L
.972 .31869 L
.976 .31834 L
.98 .318 L
.984 .31798 L
.988 .31811 L
.992 .31826 L
.996 .31846 L
1 .31862 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .58181 m
.008 .58805 L
.012 .59021 L
.016 .58816 L
.02 .58785 L
.024 .58942 L
.028 .5907 L
.032 .59106 L
.036 .58972 L
.04 .58663 L
.044 .5824 L
.048 .57715 L
.052 .57167 L
.056 .56606 L
.06 .56047 L
.064 .55478 L
.068 .5491 L
.072 .54348 L
.076 .53811 L
.08 .53279 L
.084 .52724 L
.088 .52139 L
.092 .51551 L
.096 .50977 L
.1 .50407 L
.104 .49815 L
.108 .49181 L
.112 .48518 L
.116 .47871 L
.12 .47261 L
.124 .46684 L
.128 .46108 L
.132 .455 L
.136 .44858 L
.14 .44215 L
.144 .43606 L
.148 .4306 L
.152 .42568 L
.156 .42092 L
.16 .41586 L
.164 .41012 L
.168 .40358 L
.172 .39642 L
.176 .38899 L
.18 .38174 L
.184 .37505 L
.188 .36919 L
.192 .36427 L
.196 .36027 L
.2 .35706 L
Mistroke
.204 .35446 L
.208 .35227 L
.212 .35032 L
.216 .34847 L
.22 .3466 L
.224 .34468 L
.228 .34266 L
.232 .34058 L
.236 .33844 L
.24 .33628 L
.244 .33414 L
.248 .33205 L
.252 .33002 L
.256 .32807 L
.26 .32621 L
.264 .32443 L
.268 .32272 L
.272 .32107 L
.276 .31943 L
.28 .31778 L
.284 .31609 L
.288 .31431 L
.292 .31243 L
.296 .31044 L
.3 .30834 L
.304 .30614 L
.308 .30386 L
.312 .30152 L
.316 .29914 L
.32 .29674 L
.324 .29435 L
.328 .29198 L
.332 .28966 L
.336 .28741 L
.34 .28526 L
.344 .28324 L
.348 .28135 L
.352 .27959 L
.356 .27798 L
.36 .2765 L
.364 .27516 L
.368 .27396 L
.372 .27289 L
.376 .27196 L
.38 .27115 L
.384 .27047 L
.388 .2699 L
.392 .26942 L
.396 .26902 L
.4 .26868 L
Mistroke
.404 .26838 L
.408 .26812 L
.412 .2679 L
.416 .2677 L
.42 .26754 L
.424 .2674 L
.428 .26729 L
.432 .26721 L
.436 .26715 L
.44 .2671 L
.444 .26707 L
.448 .26705 L
.452 .26703 L
.456 .267 L
.46 .26695 L
.464 .2669 L
.468 .26684 L
.472 .26679 L
.476 .26675 L
.48 .26673 L
.484 .26673 L
.488 .26673 L
.492 .26673 L
.496 .26672 L
.5 .2667 L
.504 .26667 L
.508 .26663 L
.512 .26658 L
.516 .26654 L
.52 .26651 L
.524 .26649 L
.528 .26647 L
.532 .26647 L
.536 .26646 L
.54 .26646 L
.544 .26644 L
.548 .26641 L
.552 .26638 L
.556 .26633 L
.56 .26629 L
.564 .26626 L
.568 .26624 L
.572 .26623 L
.576 .26622 L
.58 .26621 L
.584 .2662 L
.588 .26618 L
.592 .26615 L
.596 .26611 L
.6 .26608 L
Mistroke
.604 .26605 L
.608 .26602 L
.612 .266 L
.616 .26599 L
.62 .26598 L
.624 .26596 L
.628 .26594 L
.632 .26592 L
.636 .26589 L
.64 .26585 L
.644 .26582 L
.648 .2658 L
.652 .26578 L
.656 .26576 L
.66 .26574 L
.664 .26573 L
.668 .26571 L
.672 .26569 L
.676 .26566 L
.68 .26563 L
.684 .2656 L
.688 .26558 L
.692 .26555 L
.696 .26553 L
.7 .26552 L
.704 .2655 L
.708 .26548 L
.712 .26545 L
.716 .26543 L
.72 .2654 L
.724 .26538 L
.728 .26535 L
.732 .26533 L
.736 .26531 L
.74 .26529 L
.744 .26527 L
.748 .26525 L
.752 .26523 L
.756 .2652 L
.76 .26518 L
.764 .26515 L
.768 .26512 L
.772 .2651 L
.776 .26508 L
.78 .26506 L
.784 .26504 L
.788 .26502 L
.792 .26499 L
.796 .26497 L
.8 .26495 L
Mistroke
.804 .26492 L
.808 .2649 L
.812 .26487 L
.816 .26485 L
.82 .26483 L
.824 .26481 L
.828 .26479 L
.832 .26477 L
.836 .26474 L
.84 .26472 L
.844 .26469 L
.848 .26467 L
.852 .26465 L
.856 .26463 L
.86 .26461 L
.864 .26458 L
.868 .26456 L
.872 .26454 L
.876 .26452 L
.88 .26449 L
.884 .26447 L
.888 .26444 L
.892 .26442 L
.896 .2644 L
.9 .26438 L
.904 .26436 L
.908 .26434 L
.912 .26431 L
.916 .26429 L
.92 .26426 L
.924 .26424 L
.928 .26422 L
.932 .2642 L
.936 .26418 L
.94 .26416 L
.944 .26413 L
.948 .26411 L
.952 .26408 L
.956 .26406 L
.96 .26403 L
.964 .26401 L
.968 .26399 L
.972 .26398 L
.976 .26395 L
.98 .26393 L
.984 .2639 L
.988 .26388 L
.992 .26385 L
.996 .26383 L
1 .26381 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42689 L
.012 .43121 L
.016 .43257 L
.02 .4311 L
.024 .43164 L
.028 .43375 L
.032 .43393 L
.036 .43185 L
.04 .42806 L
.044 .42261 L
.048 .41635 L
.052 .40944 L
.056 .40252 L
.06 .39547 L
.064 .3882 L
.068 .38069 L
.072 .37335 L
.076 .36627 L
.08 .35931 L
.084 .35221 L
.088 .34497 L
.092 .33776 L
.096 .33086 L
.1 .32409 L
.104 .31699 L
.108 .30929 L
.112 .30122 L
.116 .29318 L
.12 .28559 L
.124 .2784 L
.128 .27119 L
.132 .26359 L
.136 .25558 L
.14 .24747 L
.144 .23979 L
.148 .23282 L
.152 .22646 L
.156 .22032 L
.16 .21381 L
.164 .20654 L
.168 .19841 L
.172 .1896 L
.176 .18057 L
.18 .17181 L
.184 .16377 L
.188 .15671 L
.192 .15074 L
.196 .14579 L
.2 .14172 L
Mistroke
.204 .13832 L
.208 .1354 L
.212 .13278 L
.216 .13032 L
.22 .12792 L
.224 .12551 L
.228 .12306 L
.232 .12056 L
.236 .11802 L
.24 .11545 L
.244 .11289 L
.248 .11037 L
.252 .10791 L
.256 .10553 L
.26 .10325 L
.264 .10104 L
.268 .0989 L
.272 .09679 L
.276 .09469 L
.28 .09256 L
.284 .0904 L
.288 .08818 L
.292 .08588 L
.296 .08348 L
.3 .08097 L
.304 .07833 L
.308 .07558 L
.312 .07271 L
.316 .06977 L
.32 .06679 L
.324 .0638 L
.328 .06085 L
.332 .05797 L
.336 .05519 L
.34 .05254 L
.344 .05002 L
.348 .04767 L
.352 .04549 L
.356 .0435 L
.36 .0417 L
.364 .0401 L
.368 .03869 L
.372 .03745 L
.376 .03637 L
.38 .03541 L
.384 .03458 L
.388 .03385 L
.392 .03323 L
.396 .0327 L
.4 .03227 L
Mistroke
.404 .03192 L
.408 .03165 L
.412 .03144 L
.416 .03128 L
.42 .03116 L
.424 .03107 L
.428 .03099 L
.432 .03092 L
.436 .03085 L
.44 .03079 L
.444 .03073 L
.448 .03068 L
.452 .03065 L
.456 .03063 L
.46 .03064 L
.464 .03067 L
.468 .0307 L
.472 .03073 L
.476 .03075 L
.48 .03075 L
.484 .03073 L
.488 .0307 L
.492 .03067 L
.496 .03066 L
.5 .03066 L
.504 .03068 L
.508 .03071 L
.512 .03074 L
.516 .03077 L
.52 .03078 L
.524 .03079 L
.528 .03078 L
.532 .03077 L
.536 .03075 L
.54 .03074 L
.544 .03074 L
.548 .03075 L
.552 .03077 L
.556 .0308 L
.56 .03083 L
.564 .03085 L
.568 .03085 L
.572 .03084 L
.576 .03083 L
.58 .03081 L
.584 .03081 L
.588 .03082 L
.592 .03083 L
.596 .03085 L
.6 .03087 L
Mistroke
.604 .03089 L
.608 .0309 L
.612 .0309 L
.616 .0309 L
.62 .03089 L
.624 .03088 L
.628 .03088 L
.632 .03089 L
.636 .03091 L
.64 .03093 L
.644 .03094 L
.648 .03095 L
.652 .03096 L
.656 .03096 L
.66 .03096 L
.664 .03095 L
.668 .03096 L
.672 .03096 L
.676 .03097 L
.68 .03099 L
.684 .031 L
.688 .03101 L
.692 .03102 L
.696 .03102 L
.7 .03102 L
.704 .03102 L
.708 .03102 L
.712 .03103 L
.716 .03104 L
.72 .03105 L
.724 .03106 L
.728 .03106 L
.732 .03107 L
.736 .03108 L
.74 .03108 L
.744 .03109 L
.748 .03109 L
.752 .03109 L
.756 .0311 L
.76 .03111 L
.764 .03112 L
.768 .03113 L
.772 .03114 L
.776 .03114 L
.78 .03115 L
.784 .03115 L
.788 .03115 L
.792 .03116 L
.796 .03116 L
.8 .03117 L
Mistroke
.804 .03118 L
.808 .03119 L
.812 .0312 L
.816 .03121 L
.82 .03121 L
.824 .03121 L
.828 .03121 L
.832 .03122 L
.836 .03123 L
.84 .03124 L
.844 .03125 L
.848 .03126 L
.852 .03126 L
.856 .03126 L
.86 .03127 L
.864 .03127 L
.868 .03128 L
.872 .03129 L
.876 .0313 L
.88 .03131 L
.884 .03132 L
.888 .03132 L
.892 .03132 L
.896 .03132 L
.9 .03133 L
.904 .03134 L
.908 .03135 L
.912 .03136 L
.916 .03137 L
.92 .03137 L
.924 .03138 L
.928 .03138 L
.932 .03139 L
.936 .03139 L
.94 .0314 L
.944 .03141 L
.948 .03142 L
.952 .03142 L
.956 .03143 L
.96 .03143 L
.964 .03144 L
.968 .03144 L
.972 .03146 L
.976 .03146 L
.98 .03148 L
.984 .03147 L
.988 .03148 L
.992 .03148 L
.996 .03149 L
1 .03149 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`@000Aoo`<000Eoo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`04001oo`00
000AOol20002Ool6000017oo00000000C7oo000ROol5000017oo000000002goo00<007ooOol037oo
00<007ooOol0BGoo000ROomS000<Ool0029oo`80009oo`80009oo`04001oo`00Ool20002Ool00`00
Oomoo`020003Ool01000Oomoo`000goo00D007ooOomoo`00009oocd000aoo`008Woo0P001goo0P00
0Woo00@007oo0000009oo`03001oogoo01Moo`03001oogoo03moo`008Woo00<007ooOol02Woo0P00
00Aoo`00000005aoo`008Woo0P003goo0P00G7oo000ROol2001]Ool000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06ao
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02
Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo
001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomo
o`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007oo
Ool000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00
KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<0
06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0
JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001W
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Io
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1V
Ool000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2
000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1V
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00
J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomo
o`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02
000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool2
0004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002
Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo
00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007oo
Ool0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001o
ogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool0
02Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Oolj0003Ool01000Oomo
o`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Ool000050004Ool20004Ool01000
Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol0
0`00Oomoo`0KOol30018Ool002Qoo`03001oogoo01Yoo`8004Yoo`00:7ooG@0037oo000XOol00`00
Oomoo`0?Ool00`00Oomoo`04Ool2000:Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@
Ool00`00Oomoo`0:Ool002Qoo`03001oogoo01=oo`<0051oo`00:7oo00<007ooOol04Woo0P00DWoo
000XOol00`00Oomoo`0?Ool3001DOol002Qoo`03001oogoo00moo`03001oogoo05Aoo`00:7oo00<0
07ooOol03Woo00<007ooOol0EGoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003
Ool00`00Oomoo`0=Ool2001GOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0003Ool01000Oomoo`003goo00<007ooOol0EWoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0005Ool01000Oomoo`003Woo00<007ooOol0Egoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000<Ool2001IOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00]oo`03001oogoo05Qo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00Yo
o`03001oogoo05Uoo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol02Goo0P00Fgoo
000XOol00`00Oomoo`09Ool00`00Oomoo`1JOol002Qoo`03001oogoo00Qoo`03001oogoo05]oo`00
4Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol01goo0P00GGoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00Moo`03001oogoo05aoo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomo
o`1MOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P001Woo00<007oo
Ool0GWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00Eo
o`03001oogoo05ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`04
Ool00`00Oomoo`1OOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo00=oo`80065o
o`00:7oo00<007ooOol00goo00<007ooOol0H7oo000XOol00`00Oomoo`02Ool00`00Oomoo`1QOol0
02Qoo`05001oogooOol0001TOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=o
o`@006Eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007oo
Ool006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02
001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomo
ogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02
Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`00
2goo00@007ooOol002Iood8000aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo029oo`80
04ioo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80025oo`80051oo`002goo0P0027oo1@00
0Woo00<007ooOol07goo0P00DGoo000LOol00`00Oomoo`0=Ool30004Ool20007Ool50004Ool20004
Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006
Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`0017oo0`000Woo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001o
ogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`00
0goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`04
001oogooOol20004Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011o
o`04001oogoo0002Ool01000Ool000001Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo
000LOol2000=Ool40003Ool00`00Oomoo`030007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol0
0`00Oomoo`0<Ool00`00Oomoo`04Ool01000Ool0000027oo0P0017oo00@007ooOol0009oo`04001o
ogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2
000=Ool50002Ool3000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P00
1Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`0BOol2001N
Ool001aoo`03001oogoo015oo`03001oogoo05ioo`0077ooJ@0037oo000LOol01@00Oomoogoo0000
0goo00<007ooOol00Woo00T007ooOomoo`00Ool007oo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`0?Ool00`00Oomoo`1POol001ao
o`80011oo`03001oogoo061oo`0077oo00<007ooOol03goo00<007ooOol0H7oo000LOol00`00Oomo
o`0>Ool00`00Oomoo`1QOol001aoo`8000ioo`8006=oo`0077oo00<007ooOol03Goo00<007ooOol0
HWoo000LOol00`00Oomoo`0<Ool2001TOol001aoo`8000eoo`03001oogoo06=oo`0077oo00<007oo
Ool02goo00<007ooOol0I7oo000LOol2000<Ool00`00Oomoo`1TOol000]oo`8000Aoo`03001oogoo
009oo`<000=oo`03001oogoo00Yoo`03001oogoo06Eoo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`0:Ool00`00Oomoo`1UOol000Yoo`04001oogoo000;Ool00`00Oomoo`02
000:Ool00`00Oomoo`1VOol000Yoo`04001oogoo000;Ool01000Oomoo`002goo00<007ooOol0IWoo
000:Ool01000Oomoo`001goo10000goo00<007ooOol027oo00<007ooOol0Igoo000:Ool01000Oomo
o`001goo00<007ooOol017oo0P002Goo00<007ooOol0Igoo000;Ool20008Ool50002Ool00`00Oomo
o`07Ool00`00Oomoo`1XOol001aoo`03001oogoo00Ioo`8006Yoo`0077oo0P001goo00<007ooOol0
JGoo000LOol00`00Oomoo`05Ool00`00Oomoo`1ZOol001aoo`8000Ioo`03001oogoo06Yoo`0077oo
00<007ooOol017oo00<007ooOol0Jgoo000LOol00`00Oomoo`03Ool2001]Ool001aoo`8000Aoo`03
001oogoo06aoo`005Woo0`000goo00<007ooOol00goo00<007ooOol0K7oo000GOol00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`1]Ool001Moo`03001oogoo009oo`D0071oo`005goo00<007oo
Ool00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`80
07=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03
001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo
000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`80
07=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(26219\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .28008 m
.008 .28559 L
.012 .29365 L
.016 .30162 L
.02 .30693 L
.024 .31037 L
.028 .31085 L
.032 .30793 L
.036 .3018 L
.04 .29397 L
.044 .28726 L
.048 .28478 L
.052 .28718 L
.056 .29384 L
.06 .30308 L
.064 .31169 L
.068 .31689 L
.072 .31688 L
.076 .3129 L
.08 .30818 L
.084 .30485 L
.088 .30292 L
.092 .30301 L
.096 .30635 L
.1 .31293 L
.104 .32095 L
.108 .32686 L
.112 .32768 L
.116 .32345 L
.12 .31733 L
.124 .31224 L
.128 .30937 L
.132 .30834 L
.136 .30788 L
.14 .30816 L
.144 .31037 L
.148 .31535 L
.152 .32262 L
.156 .33024 L
.16 .33563 L
.164 .33735 L
.168 .3357 L
.172 .3324 L
.176 .32988 L
.18 .32982 L
.184 .33275 L
.188 .3379 L
.192 .34363 L
.196 .34822 L
.2 .35024 L
Mistroke
.204 .349 L
.208 .34458 L
.212 .33772 L
.216 .32958 L
.22 .32135 L
.224 .31398 L
.228 .30789 L
.232 .30288 L
.236 .29835 L
.24 .2936 L
.244 .28827 L
.248 .28257 L
.252 .27731 L
.256 .27354 L
.26 .2721 L
.264 .27315 L
.268 .276 L
.272 .2794 L
.276 .28202 L
.28 .28311 L
.284 .28279 L
.288 .28193 L
.292 .28166 L
.296 .28271 L
.3 .28495 L
.304 .28745 L
.308 .2889 L
.312 .28838 L
.316 .28582 L
.32 .28211 L
.324 .27869 L
.328 .27679 L
.332 .27687 L
.336 .27837 L
.34 .28012 L
.344 .28098 L
.348 .28051 L
.352 .27922 L
.356 .27829 L
.36 .27887 L
.364 .28146 L
.368 .28558 L
.372 .29007 L
.376 .29373 L
.38 .29595 L
.384 .29702 L
.388 .29784 L
.392 .29937 L
.396 .302 L
.4 .30533 L
Mistroke
.404 .30845 L
.408 .31053 L
.412 .31128 L
.416 .31118 L
.42 .31108 L
.424 .31174 L
.428 .31331 L
.432 .31533 L
.436 .31701 L
.44 .31774 L
.444 .31744 L
.448 .3166 L
.452 .31591 L
.456 .31588 L
.46 .31654 L
.464 .3175 L
.468 .31823 L
.472 .31841 L
.476 .31807 L
.48 .31756 L
.484 .31725 L
.488 .31735 L
.492 .31775 L
.496 .31818 L
.5 .31836 L
.504 .31819 L
.508 .31781 L
.512 .31746 L
.516 .31736 L
.52 .31756 L
.524 .31793 L
.528 .31827 L
.532 .31839 L
.536 .31823 L
.54 .31791 L
.544 .31762 L
.548 .31752 L
.552 .31766 L
.556 .31795 L
.56 .3182 L
.564 .31825 L
.568 .31808 L
.572 .3178 L
.576 .31762 L
.58 .31766 L
.584 .31793 L
.588 .31823 L
.592 .31835 L
.596 .31819 L
.6 .31785 L
Mistroke
.604 .31757 L
.608 .31757 L
.612 .31784 L
.616 .31819 L
.62 .31838 L
.624 .31828 L
.628 .31797 L
.632 .3177 L
.636 .31767 L
.64 .3179 L
.644 .3182 L
.648 .31831 L
.652 .31815 L
.656 .31785 L
.66 .31769 L
.664 .31781 L
.668 .31811 L
.672 .31835 L
.676 .31832 L
.68 .31805 L
.684 .31777 L
.688 .31772 L
.692 .31792 L
.696 .31821 L
.7 .31834 L
.704 .31821 L
.708 .31795 L
.712 .31779 L
.716 .31789 L
.72 .31815 L
.724 .31835 L
.728 .31829 L
.732 .31802 L
.736 .31779 L
.74 .3178 L
.744 .31807 L
.748 .31836 L
.752 .31841 L
.756 .31818 L
.76 .31788 L
.764 .31778 L
.768 .31798 L
.772 .31829 L
.776 .31844 L
.78 .3183 L
.784 .318 L
.788 .3178 L
.792 .31787 L
.796 .31814 L
.8 .3184 L
Mistroke
.804 .31846 L
.808 .31828 L
.812 .31802 L
.816 .31788 L
.82 .31792 L
.824 .31808 L
.828 .31825 L
.832 .31834 L
.836 .31834 L
.84 .3183 L
.844 .31821 L
.848 .31809 L
.852 .31797 L
.856 .31791 L
.86 .31802 L
.864 .31829 L
.868 .31855 L
.872 .31861 L
.876 .31839 L
.88 .31799 L
.884 .31771 L
.888 .31778 L
.892 .31813 L
.896 .31854 L
.9 .31873 L
.904 .31856 L
.908 .3182 L
.912 .31793 L
.916 .31787 L
.92 .318 L
.924 .31823 L
.928 .31843 L
.932 .31853 L
.936 .31855 L
.94 .31842 L
.944 .31814 L
.948 .31792 L
.952 .31786 L
.956 .31806 L
.96 .31849 L
.964 .31877 L
.968 .3187 L
.972 .31839 L
.976 .31798 L
.98 .31781 L
.984 .318 L
.988 .31831 L
.992 .31856 L
.996 .31862 L
1 .31857 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .59179 m
.008 .58709 L
.012 .58561 L
.016 .58715 L
.02 .58762 L
.024 .58719 L
.028 .58737 L
.032 .58776 L
.036 .58772 L
.04 .58745 L
.044 .58815 L
.048 .58969 L
.052 .59109 L
.056 .59181 L
.06 .5911 L
.064 .58875 L
.068 .58509 L
.072 .5804 L
.076 .5753 L
.08 .56989 L
.084 .56422 L
.088 .55831 L
.092 .55251 L
.096 .54693 L
.1 .54149 L
.104 .53595 L
.108 .53022 L
.112 .5244 L
.116 .5188 L
.12 .51342 L
.124 .508 L
.128 .50223 L
.132 .49602 L
.136 .48956 L
.14 .48326 L
.144 .47726 L
.148 .47144 L
.152 .46551 L
.156 .45922 L
.16 .45262 L
.164 .44601 L
.168 .43978 L
.172 .43418 L
.176 .42917 L
.18 .42443 L
.184 .41951 L
.188 .41402 L
.192 .4078 L
.196 .40091 L
.2 .39362 L
Mistroke
.204 .38633 L
.208 .37941 L
.212 .37316 L
.216 .36775 L
.22 .36321 L
.224 .35948 L
.228 .35641 L
.232 .35385 L
.236 .35163 L
.24 .34961 L
.244 .34768 L
.248 .34577 L
.252 .34383 L
.256 .34183 L
.26 .33978 L
.264 .33767 L
.268 .33555 L
.272 .33343 L
.276 .33135 L
.28 .32935 L
.284 .32743 L
.288 .3256 L
.292 .32385 L
.296 .32216 L
.3 .3205 L
.304 .31884 L
.308 .31715 L
.312 .31541 L
.316 .3136 L
.32 .31171 L
.324 .30971 L
.328 .30761 L
.332 .30542 L
.336 .30313 L
.34 .30076 L
.344 .29835 L
.348 .29592 L
.352 .29351 L
.356 .29114 L
.36 .28885 L
.364 .28666 L
.368 .28457 L
.372 .2826 L
.376 .28075 L
.38 .27903 L
.384 .27745 L
.388 .27601 L
.392 .2747 L
.396 .27355 L
.4 .27253 L
Mistroke
.404 .27164 L
.408 .27088 L
.412 .27023 L
.416 .26969 L
.42 .26923 L
.424 .26884 L
.428 .26851 L
.432 .26822 L
.436 .26796 L
.44 .26774 L
.444 .26755 L
.448 .26739 L
.452 .26727 L
.456 .26718 L
.46 .26712 L
.464 .26708 L
.468 .26705 L
.472 .26701 L
.476 .26696 L
.48 .26691 L
.484 .26685 L
.488 .2668 L
.492 .26675 L
.496 .26672 L
.5 .2667 L
.504 .26669 L
.508 .26668 L
.512 .26667 L
.516 .26666 L
.52 .26664 L
.524 .26661 L
.528 .26657 L
.532 .26653 L
.536 .26649 L
.54 .26646 L
.544 .26644 L
.548 .26643 L
.552 .26643 L
.556 .26642 L
.56 .2664 L
.564 .26638 L
.568 .26635 L
.572 .26631 L
.576 .26627 L
.58 .26624 L
.584 .26622 L
.588 .2662 L
.592 .26619 L
.596 .26618 L
.6 .26617 L
Mistroke
.604 .26614 L
.608 .26612 L
.612 .26609 L
.616 .26605 L
.62 .26602 L
.624 .266 L
.628 .26598 L
.632 .26596 L
.636 .26595 L
.64 .26593 L
.644 .26591 L
.648 .26589 L
.652 .26586 L
.656 .26583 L
.66 .2658 L
.664 .26578 L
.668 .26575 L
.672 .26573 L
.676 .26572 L
.68 .2657 L
.684 .26568 L
.688 .26565 L
.692 .26563 L
.696 .2656 L
.7 .26558 L
.704 .26555 L
.708 .26553 L
.712 .26551 L
.716 .26549 L
.72 .26547 L
.724 .26545 L
.728 .26543 L
.732 .2654 L
.736 .26538 L
.74 .26535 L
.744 .26533 L
.748 .2653 L
.752 .26528 L
.756 .26526 L
.76 .26524 L
.764 .26522 L
.768 .2652 L
.772 .26517 L
.776 .26515 L
.78 .26513 L
.784 .2651 L
.788 .26508 L
.792 .26505 L
.796 .26503 L
.8 .26501 L
Mistroke
.804 .26499 L
.808 .26497 L
.812 .26495 L
.816 .26492 L
.82 .26489 L
.824 .26487 L
.828 .26485 L
.832 .26483 L
.836 .26481 L
.84 .26479 L
.844 .26477 L
.848 .26474 L
.852 .26472 L
.856 .26469 L
.86 .26467 L
.864 .26464 L
.868 .26463 L
.872 .26461 L
.876 .26459 L
.88 .26456 L
.884 .26454 L
.888 .26451 L
.892 .26449 L
.896 .26446 L
.9 .26444 L
.904 .26442 L
.908 .2644 L
.912 .26438 L
.916 .26435 L
.92 .26433 L
.924 .26431 L
.928 .26428 L
.932 .26426 L
.936 .26424 L
.94 .26422 L
.944 .2642 L
.948 .26418 L
.952 .26415 L
.956 .26413 L
.96 .2641 L
.964 .26408 L
.968 .26406 L
.972 .26404 L
.976 .26401 L
.98 .26399 L
.984 .26396 L
.988 .26395 L
.992 .26392 L
.996 .26391 L
1 .26388 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42494 L
.012 .42936 L
.016 .43095 L
.02 .42925 L
.024 .42898 L
.028 .43012 L
.032 .4305 L
.036 .42974 L
.04 .42949 L
.044 .43004 L
.048 .43135 L
.052 .43291 L
.056 .43345 L
.06 .43248 L
.064 .42969 L
.068 .42517 L
.072 .41973 L
.076 .41363 L
.08 .40715 L
.084 .40022 L
.088 .39302 L
.092 .38576 L
.096 .37878 L
.1 .37196 L
.104 .36501 L
.108 .35777 L
.112 .35049 L
.116 .34339 L
.12 .33653 L
.124 .32959 L
.128 .32218 L
.132 .3142 L
.136 .30602 L
.14 .29807 L
.144 .29063 L
.148 .28354 L
.152 .27638 L
.156 .26882 L
.16 .26085 L
.164 .2528 L
.168 .24513 L
.172 .23813 L
.176 .23174 L
.18 .22564 L
.184 .21928 L
.188 .21225 L
.192 .20437 L
.196 .19572 L
.2 .18666 L
Mistroke
.204 .17764 L
.208 .16914 L
.212 .16147 L
.216 .15484 L
.22 .14928 L
.224 .1447 L
.228 .14093 L
.232 .13776 L
.236 .13501 L
.24 .13248 L
.244 .13005 L
.248 .12761 L
.252 .12512 L
.256 .12257 L
.26 .11998 L
.264 .11736 L
.268 .11476 L
.272 .11221 L
.276 .10973 L
.28 .10732 L
.284 .105 L
.288 .10276 L
.292 .10059 L
.296 .09847 L
.3 .09639 L
.304 .09432 L
.308 .09223 L
.312 .09007 L
.316 .08783 L
.32 .08547 L
.324 .08299 L
.328 .08038 L
.332 .07767 L
.336 .07487 L
.34 .07199 L
.344 .06907 L
.348 .06612 L
.352 .06317 L
.356 .06026 L
.36 .0574 L
.364 .05464 L
.368 .05201 L
.372 .04953 L
.376 .04722 L
.38 .04511 L
.384 .0432 L
.388 .04148 L
.392 .03994 L
.396 .03858 L
.4 .03738 L
Mistroke
.404 .03632 L
.408 .0354 L
.412 .03459 L
.416 .03389 L
.42 .0333 L
.424 .03281 L
.428 .0324 L
.432 .03208 L
.436 .03183 L
.44 .03165 L
.444 .03151 L
.448 .0314 L
.452 .0313 L
.456 .0312 L
.46 .03111 L
.464 .03102 L
.468 .03096 L
.472 .03091 L
.476 .0309 L
.48 .0309 L
.484 .03092 L
.488 .03094 L
.492 .03095 L
.496 .03096 L
.5 .03096 L
.504 .03094 L
.508 .03092 L
.512 .0309 L
.516 .03089 L
.52 .03089 L
.524 .03091 L
.528 .03094 L
.532 .03097 L
.536 .03099 L
.54 .031 L
.544 .031 L
.548 .03099 L
.552 .03097 L
.556 .03096 L
.56 .03096 L
.564 .03097 L
.568 .03099 L
.572 .03101 L
.576 .03103 L
.58 .03105 L
.584 .03106 L
.588 .03105 L
.592 .03105 L
.596 .03104 L
.6 .03103 L
Mistroke
.604 .03104 L
.608 .03105 L
.612 .03107 L
.616 .03109 L
.62 .0311 L
.624 .03111 L
.628 .03111 L
.632 .03111 L
.636 .03111 L
.64 .03111 L
.644 .03111 L
.648 .03112 L
.652 .03113 L
.656 .03114 L
.66 .03115 L
.664 .03116 L
.668 .03117 L
.672 .03117 L
.676 .03117 L
.68 .03117 L
.684 .03117 L
.688 .03118 L
.692 .03119 L
.696 .0312 L
.7 .03121 L
.704 .03122 L
.708 .03123 L
.712 .03123 L
.716 .03124 L
.72 .03124 L
.724 .03124 L
.728 .03125 L
.732 .03125 L
.736 .03126 L
.74 .03127 L
.744 .03128 L
.748 .03129 L
.752 .03129 L
.756 .0313 L
.76 .0313 L
.764 .0313 L
.768 .03131 L
.772 .03132 L
.776 .03133 L
.78 .03133 L
.784 .03134 L
.788 .03135 L
.792 .03136 L
.796 .03136 L
.8 .03136 L
Mistroke
.804 .03137 L
.808 .03137 L
.812 .03138 L
.816 .03139 L
.82 .0314 L
.824 .03141 L
.828 .03141 L
.832 .03142 L
.836 .03142 L
.84 .03143 L
.844 .03143 L
.848 .03144 L
.852 .03145 L
.856 .03146 L
.86 .03147 L
.864 .03147 L
.868 .03148 L
.872 .03148 L
.876 .03148 L
.88 .03149 L
.884 .0315 L
.888 .03151 L
.892 .03152 L
.896 .03152 L
.9 .03153 L
.904 .03153 L
.908 .03154 L
.912 .03154 L
.916 .03155 L
.92 .03155 L
.924 .03157 L
.928 .03157 L
.932 .03159 L
.936 .03159 L
.94 .03159 L
.944 .03159 L
.948 .0316 L
.952 .0316 L
.956 .03162 L
.96 .03162 L
.964 .03164 L
.968 .03164 L
.972 .03165 L
.976 .03165 L
.98 .03165 L
.984 .03165 L
.988 .03167 L
.992 .03167 L
.996 .03169 L
1 .03169 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`800003Ool0000000Eoo`03001oogoo00=oo`8000Aoo`80
00Ioo`04001oogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006
Ool0029oo`80009oo`80019oo`03001oogoo00X004Yoo`008Woo0P000Woo00<007oo000047oo0P00
1Goo00<007ooOol00goo0`00B7oo000ROomS000<Ool0029oo`03001oo`0000800007Ool00000001o
o`00Ool01@000goo00D007oo001oo`00009oo`05001oogooOol00003Ool01000Oomoogoo?00037oo
000ROol20008Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1FOol0029oo`03001oogoo00aoo`@0
009oo`03001oogoo05Moo`008Woo0P004Goo0P00FWoo000ROol2000BOol00`00Oomoo`1HOol000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06aoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2
001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool2
0004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0
009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007oo
Ool0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`80
06eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=o
o`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0
K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo
00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05
Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomo
o`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool3
0003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004
Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002
Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomo
ogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009o
o`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007oo
Ool0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<0
07ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol0
00Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80
009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00
Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=o
o`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004
Ool00`00Oomoo`0g0003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool0
0`00Oomoo`02Ool40003Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P00
17oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`0NOol20016Ool002Qoo`03001oogoo01ao
o`8004Qoo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`06Ool30007Ool00`00Oomo
o`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo01Ioo`80
04ioo`00:7oo00<007ooOol057oo0`00Cgoo000XOol00`00Oomoo`0BOol2001BOol002Qoo`03001o
ogoo015oo`8005=oo`00:7oo00<007ooOol047oo00<007ooOol0Dgoo000;Ool20004Ool00`00Oomo
o`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0@Ool00`00Oomoo`1COol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`004Goo00<007ooOol0E7oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`004Goo00<0
07ooOol0E7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`02000?Ool00`00Oomoo`1EOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol0
07oo00@000=oo`03001oogoo00eoo`8005Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1P00Oomoo`00Ool000Ioo`03001oogoo00aoo`8005Qoo`002goo0P002Woo0P0017oo0P000Woo1@00
0Woo00<007ooOol037oo00<007ooOol0Egoo000XOol00`00Oomoo`0;Ool00`00Oomoo`1HOol002Qo
o`03001oogoo00Yoo`8005Yoo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007oo
Ool02Woo00<007ooOol0FGoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo00Uoo`8005]oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`08Ool2001LOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P002Goo00<007ooOol0Fgoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo00Moo`03001oogoo05aoo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool2
0004Ool00`00Oomoo`06Ool2001NOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo
00Eoo`8005moo`00:7oo00<007ooOol01Goo00<007ooOol0GWoo000XOol00`00Oomoo`04Ool00`00
Oomoo`1OOol002Qoo`8000Aoo`80065oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo
0`000goo1`00HWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool0
1000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001o
ogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04
001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001o
ogoo000;Ool01000Oomoo`00:Goo?`0037oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0
97oo0`00Bgoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P0097oo0P00CGoo000;Ool20008
Ool50002Ool00`00Oomoo`0QOol2001?Ool001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Ao
o`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Ao
o`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0007Ool30004Ool01000Oomo
o`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000
Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol0
17oo0P0000=oo`00Ool00goo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomo
o`000Woo00<007ooOol00Woo0P000goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001o
ogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000L
Ool2000=Ool40003Ool01000Oomoo`000Woo0P001Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo
00<007ooOol037oo00<007ooOol017oo00D007ooOol007oo008000Eoo`8000Aoo`04001oogoo0002
Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eo
o`0077oo0P003Goo1@000goo100027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D0
00=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0
5Goo0P00Fgoo000LOol00`00Oomoo`0DOol00`00Oomoo`1KOol001aoofT000aoo`0077oo00D007oo
Oomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool20002Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo019oo`03001oogoo05eo
o`0077oo0P004goo00<007ooOol0GGoo000LOol00`00Oomoo`0AOol00`00Oomoo`1NOol001aoo`03
001oogoo015oo`03001oogoo05ioo`0077oo0P004Goo0P00H7oo000LOol00`00Oomoo`0@Ool00`00
Oomoo`1OOol001aoo`03001oogoo00moo`03001oogoo061oo`0077oo0P0047oo00<007ooOol0H7oo
000LOol00`00Oomoo`0>Ool00`00Oomoo`1QOol001aoo`8000ioo`8006=oo`002goo0P0017oo00<0
07ooOol00Woo0`000goo00<007ooOol03Goo00<007ooOol0HWoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo00eoo`03001oogoo069oo`002Woo00@007ooOol000]oo`03001o
ogoo008000eoo`03001oogoo06=oo`002Woo00@007ooOol000]oo`04001oogoo000=Ool00`00Oomo
o`1TOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0;Ool00`00Oomoo`1TOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool2000;Ool00`00Oomoo`1UOol000]oo`8000Qoo`D0009oo`03
001oogoo00Yoo`03001oogoo06Eoo`0077oo00<007ooOol02Goo00<007ooOol0IWoo000LOol2000:
Ool00`00Oomoo`1VOol001aoo`03001oogoo00Qoo`03001oogoo06Moo`0077oo0P002Goo00<007oo
Ool0Igoo000LOol00`00Oomoo`07Ool00`00Oomoo`1XOol001aoo`03001oogoo00Ioo`03001oogoo
06Uoo`0077oo0P001goo00<007ooOol0JGoo000FOol30003Ool00`00Oomoo`05Ool00`00Oomoo`1Z
Ool001Moo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo06Yoo`005goo00<007ooOol00Woo
2000KGoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo
079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo
00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@0
07ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool4
0003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<0
07ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(26386\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30846 m
.008 .30382 L
.012 .2949 L
.016 .28757 L
.02 .28368 L
.024 .28216 L
.028 .28464 L
.032 .29118 L
.036 .29997 L
.04 .30639 L
.044 .30927 L
.048 .31046 L
.052 .30965 L
.056 .30631 L
.06 .30151 L
.064 .2971 L
.068 .29423 L
.072 .2939 L
.076 .29621 L
.08 .30105 L
.084 .30644 L
.088 .30896 L
.092 .30774 L
.096 .30464 L
.1 .3024 L
.104 .30253 L
.108 .30478 L
.112 .30791 L
.116 .31197 L
.12 .31786 L
.124 .32493 L
.128 .33076 L
.132 .33288 L
.136 .33069 L
.14 .32593 L
.144 .32175 L
.148 .31964 L
.152 .31889 L
.156 .31792 L
.16 .31568 L
.164 .31316 L
.168 .31255 L
.172 .31553 L
.176 .32194 L
.18 .32979 L
.184 .33627 L
.188 .33947 L
.192 .33931 L
.196 .33733 L
.2 .33592 L
Mistroke
.204 .33677 L
.208 .34034 L
.212 .34561 L
.216 .35072 L
.22 .35393 L
.224 .35426 L
.228 .35185 L
.232 .3476 L
.236 .34264 L
.24 .33768 L
.244 .33271 L
.248 .32719 L
.252 .32047 L
.256 .31239 L
.26 .30352 L
.264 .29503 L
.268 .28821 L
.272 .28386 L
.276 .28189 L
.28 .2814 L
.284 .28116 L
.288 .28025 L
.292 .27855 L
.296 .2768 L
.3 .27612 L
.304 .27736 L
.308 .28054 L
.312 .28474 L
.316 .28848 L
.32 .29047 L
.324 .29021 L
.328 .28826 L
.332 .28587 L
.336 .28426 L
.34 .28401 L
.344 .28476 L
.348 .28549 L
.352 .28522 L
.356 .28357 L
.36 .28107 L
.364 .27879 L
.368 .27777 L
.372 .27844 L
.376 .28041 L
.38 .28275 L
.384 .28461 L
.388 .28568 L
.392 .28635 L
.396 .28741 L
.4 .2895 L
Mistroke
.404 .2927 L
.408 .29647 L
.412 .29996 L
.416 .30249 L
.42 .30393 L
.424 .30472 L
.428 .30554 L
.432 .30693 L
.436 .30893 L
.44 .31115 L
.444 .31302 L
.448 .31415 L
.452 .31457 L
.456 .31463 L
.46 .31479 L
.464 .31531 L
.468 .31612 L
.472 .31692 L
.476 .3174 L
.48 .31744 L
.484 .31717 L
.488 .31691 L
.492 .3169 L
.496 .31723 L
.5 .31774 L
.504 .31815 L
.508 .31828 L
.512 .31809 L
.516 .31773 L
.52 .31743 L
.524 .31737 L
.528 .31758 L
.532 .31791 L
.536 .31816 L
.54 .31819 L
.544 .31799 L
.548 .31772 L
.552 .31756 L
.556 .31763 L
.56 .31789 L
.564 .31816 L
.568 .31825 L
.572 .31809 L
.576 .31777 L
.58 .31751 L
.584 .31752 L
.588 .3178 L
.592 .31815 L
.596 .31833 L
.6 .31822 L
Mistroke
.604 .31789 L
.608 .31761 L
.612 .31758 L
.616 .31782 L
.62 .31813 L
.624 .31828 L
.628 .31813 L
.632 .31782 L
.636 .3176 L
.64 .31768 L
.644 .31799 L
.648 .31829 L
.652 .31834 L
.656 .31807 L
.66 .31772 L
.664 .31756 L
.668 .31773 L
.672 .31808 L
.676 .31834 L
.68 .3183 L
.684 .31802 L
.688 .31773 L
.692 .31768 L
.696 .31789 L
.7 .31818 L
.704 .31831 L
.708 .31817 L
.712 .31791 L
.716 .31775 L
.72 .31783 L
.724 .31806 L
.728 .31824 L
.732 .31821 L
.736 .31804 L
.74 .3179 L
.744 .31793 L
.748 .31807 L
.752 .31817 L
.756 .31811 L
.76 .31795 L
.764 .31787 L
.768 .31799 L
.772 .31821 L
.776 .31834 L
.78 .31826 L
.784 .318 L
.788 .31778 L
.792 .3178 L
.796 .31803 L
.8 .31831 L
Mistroke
.804 .31841 L
.808 .31826 L
.812 .31801 L
.816 .31786 L
.82 .31791 L
.824 .31811 L
.828 .31827 L
.832 .31827 L
.836 .31814 L
.84 .31803 L
.844 .31802 L
.848 .31812 L
.852 .31823 L
.856 .31823 L
.86 .31815 L
.864 .31809 L
.868 .31808 L
.872 .31813 L
.876 .31816 L
.88 .31815 L
.884 .31816 L
.888 .31822 L
.892 .31829 L
.896 .3183 L
.9 .31817 L
.904 .31798 L
.908 .3179 L
.912 .31806 L
.916 .31834 L
.92 .31854 L
.924 .31851 L
.928 .31824 L
.932 .31794 L
.936 .31786 L
.94 .31798 L
.944 .31822 L
.948 .31845 L
.952 .31851 L
.956 .31845 L
.96 .31833 L
.964 .31811 L
.968 .31793 L
.972 .31789 L
.976 .31806 L
.98 .31838 L
.984 .31867 L
.988 .31873 L
.992 .31842 L
.996 .31801 L
1 .31782 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .59424 m
.008 .58706 L
.012 .58472 L
.016 .58706 L
.02 .5881 L
.024 .58752 L
.028 .58735 L
.032 .58751 L
.036 .58738 L
.04 .58689 L
.044 .58693 L
.048 .58737 L
.052 .5875 L
.056 .5871 L
.06 .58667 L
.064 .5865 L
.068 .58716 L
.072 .58854 L
.076 .59006 L
.08 .59112 L
.084 .59093 L
.088 .58929 L
.092 .58649 L
.096 .58279 L
.1 .57843 L
.104 .57343 L
.108 .56797 L
.112 .56226 L
.116 .55665 L
.12 .55116 L
.124 .54558 L
.128 .53977 L
.132 .53383 L
.136 .52799 L
.14 .52246 L
.144 .51714 L
.148 .5117 L
.152 .50588 L
.156 .49968 L
.16 .49334 L
.164 .48718 L
.168 .48133 L
.172 .4756 L
.176 .46972 L
.18 .46346 L
.184 .45686 L
.188 .45022 L
.192 .4439 L
.196 .43815 L
.2 .43298 L
Mistroke
.204 .42813 L
.208 .42323 L
.212 .41789 L
.216 .4119 L
.22 .40524 L
.224 .39811 L
.228 .39084 L
.232 .38377 L
.236 .37722 L
.24 .37138 L
.244 .36635 L
.248 .36212 L
.252 .35861 L
.256 .35569 L
.26 .35321 L
.264 .35102 L
.268 .349 L
.272 .34704 L
.276 .34508 L
.28 .34308 L
.284 .34103 L
.288 .33894 L
.292 .33683 L
.296 .33473 L
.3 .33266 L
.304 .33065 L
.308 .3287 L
.312 .32682 L
.316 .32501 L
.32 .32326 L
.324 .32156 L
.328 .31989 L
.332 .31822 L
.336 .31653 L
.34 .31478 L
.344 .31296 L
.348 .31105 L
.352 .30902 L
.356 .30688 L
.36 .30464 L
.364 .30231 L
.368 .29993 L
.372 .29751 L
.376 .29509 L
.38 .29271 L
.384 .29037 L
.388 .28811 L
.392 .28595 L
.396 .28389 L
.4 .28196 L
Mistroke
.404 .28014 L
.408 .27846 L
.412 .27692 L
.416 .27552 L
.42 .27426 L
.424 .27314 L
.428 .27217 L
.432 .27134 L
.436 .27063 L
.44 .27003 L
.444 .26951 L
.448 .26906 L
.452 .26866 L
.456 .26832 L
.46 .26802 L
.464 .26777 L
.468 .26757 L
.472 .26741 L
.476 .26729 L
.48 .26719 L
.484 .26712 L
.488 .26706 L
.492 .267 L
.496 .26694 L
.5 .26688 L
.504 .26682 L
.508 .26677 L
.512 .26672 L
.516 .26669 L
.52 .26666 L
.524 .26665 L
.528 .26664 L
.532 .26663 L
.536 .26661 L
.54 .26658 L
.544 .26654 L
.548 .26651 L
.552 .26647 L
.556 .26644 L
.56 .26642 L
.564 .26641 L
.568 .2664 L
.572 .26638 L
.576 .26637 L
.58 .26635 L
.584 .26632 L
.588 .26628 L
.592 .26625 L
.596 .26622 L
.6 .2662 L
Mistroke
.604 .26618 L
.608 .26617 L
.612 .26615 L
.616 .26613 L
.62 .26611 L
.624 .26608 L
.628 .26606 L
.632 .26603 L
.636 .266 L
.64 .26598 L
.644 .26596 L
.648 .26594 L
.652 .26592 L
.656 .2659 L
.66 .26588 L
.664 .26585 L
.668 .26583 L
.672 .2658 L
.676 .26578 L
.68 .26575 L
.684 .26573 L
.688 .26571 L
.692 .26569 L
.696 .26567 L
.7 .26565 L
.704 .26563 L
.708 .2656 L
.712 .26558 L
.716 .26555 L
.72 .26553 L
.724 .2655 L
.728 .26548 L
.732 .26546 L
.736 .26544 L
.74 .26542 L
.744 .2654 L
.748 .26537 L
.752 .26535 L
.756 .26532 L
.76 .2653 L
.764 .26528 L
.768 .26526 L
.772 .26523 L
.776 .26521 L
.78 .26519 L
.784 .26517 L
.788 .26515 L
.792 .26512 L
.796 .2651 L
.8 .26507 L
Mistroke
.804 .26505 L
.808 .26503 L
.812 .26501 L
.816 .26499 L
.82 .26497 L
.824 .26494 L
.828 .26492 L
.832 .26489 L
.836 .26487 L
.84 .26485 L
.844 .26482 L
.848 .2648 L
.852 .26479 L
.856 .26476 L
.86 .26474 L
.864 .26471 L
.868 .26469 L
.872 .26466 L
.876 .26464 L
.88 .26462 L
.884 .2646 L
.888 .26458 L
.892 .26456 L
.896 .26453 L
.9 .26451 L
.904 .26448 L
.908 .26446 L
.912 .26444 L
.916 .26442 L
.92 .2644 L
.924 .26438 L
.928 .26435 L
.932 .26433 L
.936 .2643 L
.94 .26428 L
.944 .26426 L
.948 .26424 L
.952 .26422 L
.956 .2642 L
.96 .26417 L
.964 .26415 L
.968 .26412 L
.972 .2641 L
.976 .26407 L
.98 .26406 L
.984 .26403 L
.988 .26402 L
.992 .26399 L
.996 .26397 L
1 .26394 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43284 L
.012 .42966 L
.016 .4287 L
.02 .42952 L
.024 .42962 L
.028 .42914 L
.032 .42884 L
.036 .42838 L
.04 .42826 L
.044 .42857 L
.048 .42922 L
.052 .42971 L
.056 .42959 L
.06 .429 L
.064 .42896 L
.068 .42974 L
.072 .43132 L
.076 .43325 L
.08 .43439 L
.084 .43407 L
.088 .43199 L
.092 .42829 L
.096 .42353 L
.1 .41786 L
.104 .41144 L
.108 .40438 L
.112 .39718 L
.116 .39014 L
.12 .38336 L
.124 .37659 L
.128 .3696 L
.132 .36243 L
.136 .35538 L
.14 .34862 L
.144 .34199 L
.148 .33513 L
.152 .32769 L
.156 .31971 L
.16 .31159 L
.164 .30373 L
.168 .29631 L
.172 .28914 L
.176 .28184 L
.18 .27412 L
.184 .26602 L
.188 .25785 L
.192 .25006 L
.196 .24297 L
.2 .23656 L
Mistroke
.204 .23055 L
.208 .22443 L
.212 .21776 L
.216 .21025 L
.22 .2019 L
.224 .19295 L
.228 .18381 L
.232 .17495 L
.236 .16676 L
.24 .1595 L
.244 .15329 L
.248 .14811 L
.252 .14384 L
.256 .14029 L
.26 .13725 L
.264 .13454 L
.268 .13201 L
.272 .12955 L
.276 .12709 L
.28 .12459 L
.284 .12203 L
.288 .11943 L
.292 .11681 L
.296 .1142 L
.3 .11163 L
.304 .10914 L
.308 .10674 L
.312 .10445 L
.316 .10226 L
.32 .10016 L
.324 .0981 L
.328 .09606 L
.332 .09399 L
.336 .09187 L
.34 .08967 L
.344 .08736 L
.348 .08495 L
.352 .08242 L
.356 .07979 L
.36 .07706 L
.364 .07424 L
.368 .07136 L
.372 .06842 L
.376 .06546 L
.38 .06251 L
.384 .05961 L
.388 .05678 L
.392 .05406 L
.396 .05148 L
.4 .04906 L
Mistroke
.404 .04683 L
.408 .04478 L
.412 .04294 L
.416 .04128 L
.42 .0398 L
.424 .03849 L
.428 .03732 L
.432 .03628 L
.436 .03537 L
.44 .03458 L
.444 .03392 L
.448 .03337 L
.452 .03293 L
.456 .03257 L
.46 .0323 L
.464 .03207 L
.468 .03188 L
.472 .03172 L
.476 .03158 L
.48 .03146 L
.484 .03135 L
.488 .03127 L
.492 .03122 L
.496 .03118 L
.5 .03117 L
.504 .03117 L
.508 .03118 L
.512 .03119 L
.516 .03119 L
.52 .03118 L
.524 .03116 L
.528 .03114 L
.532 .03112 L
.536 .03112 L
.54 .03113 L
.544 .03115 L
.548 .03117 L
.552 .03119 L
.556 .03121 L
.56 .03121 L
.564 .03121 L
.568 .0312 L
.572 .03119 L
.576 .03119 L
.58 .03119 L
.584 .03121 L
.588 .03123 L
.592 .03124 L
.596 .03126 L
.6 .03126 L
Mistroke
.604 .03126 L
.608 .03126 L
.612 .03126 L
.616 .03126 L
.62 .03126 L
.624 .03127 L
.628 .03128 L
.632 .0313 L
.636 .03131 L
.64 .03132 L
.644 .03132 L
.648 .03132 L
.652 .03132 L
.656 .03132 L
.66 .03133 L
.664 .03134 L
.668 .03135 L
.672 .03136 L
.676 .03137 L
.68 .03137 L
.684 .03138 L
.688 .03138 L
.692 .03139 L
.696 .03139 L
.7 .0314 L
.704 .0314 L
.708 .03141 L
.712 .03142 L
.716 .03143 L
.72 .03144 L
.724 .03144 L
.728 .03145 L
.732 .03145 L
.736 .03145 L
.74 .03146 L
.744 .03146 L
.748 .03147 L
.752 .03148 L
.756 .03149 L
.76 .0315 L
.764 .0315 L
.768 .03151 L
.772 .03151 L
.776 .03152 L
.78 .03152 L
.784 .03152 L
.788 .03153 L
.792 .03155 L
.796 .03156 L
.8 .03156 L
Mistroke
.804 .03157 L
.808 .03157 L
.812 .03157 L
.816 .03158 L
.82 .03158 L
.824 .03159 L
.828 .0316 L
.832 .03161 L
.836 .03162 L
.84 .03162 L
.844 .03163 L
.848 .03163 L
.852 .03163 L
.856 .03164 L
.86 .03165 L
.864 .03166 L
.868 .03167 L
.872 .03167 L
.876 .03168 L
.88 .03168 L
.884 .03169 L
.888 .03169 L
.892 .0317 L
.896 .03171 L
.9 .03172 L
.904 .03172 L
.908 .03173 L
.912 .03173 L
.916 .03174 L
.92 .03174 L
.924 .03175 L
.928 .03176 L
.932 .03177 L
.936 .03178 L
.94 .03178 L
.944 .03178 L
.948 .03179 L
.952 .0318 L
.956 .03181 L
.96 .03181 L
.964 .03182 L
.968 .03183 L
.972 .03184 L
.976 .03183 L
.98 .03185 L
.984 .03185 L
.988 .03186 L
.992 .03186 L
.996 .03188 L
1 .03188 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Eoo`800003Ool007oo009oo`04001oo`000004Ool2
0006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P00
1Woo000ROol01000Ool000005Woo3P00Agoo000ROol2000017oo001oogoo0`004Goo00<007ooOol0
0Woo0P001Woo0P00AWoo000ROomS000<Ool0029oo`04001oogooOol20002Ool00`00Oomoo`020002
Ool30002Ool01000Oomoogoo0P0000=oo`00Ool00Woo00D007ooOomoo`0000=oo`04001oogooOolh
000<Ool0029oo`8000Yoo`06001oo`00001oo`001Woo0P00EGoo000ROol00`00Oomoo`0:Ool00`00
Oomoo`02Ool30003Ool00`00Oomoo`1DOol0029oo`80019oo`800003Ool007oo05Ioo`008Woo0P00
4goo0P00F7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eo
o`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]
Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:
Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0
029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00
0Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo
0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P00
0goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool0
1@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001o
ogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0
009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2
000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000
Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo1000
0goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000
Oomoo`001Woo0P0017oo00@007ooOol0009ooc@000=oo`04001oogoo0005Ool002Qoo`03001oogoo
00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`D00003Ool0000000Aoo`04001oogooOol50003Ool2
0003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo021oo`<0
04=oo`00:7oo00<007ooOol07Woo0`00AGoo000XOomM000<Ool002Qoo`03001oogoo00moo`03001o
ogoo00Qoo`<000Eoo`03001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yo
o`00:7oo00<007ooOol067oo0`00Bgoo000XOol00`00Oomoo`0FOol3001=Ool002Qoo`03001oogoo
01Eoo`8004moo`00:7oo00<007ooOol04goo0P00DGoo000XOol00`00Oomoo`0COol00`00Oomoo`1@
Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo019oo`03001o
ogoo055oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001o
ogoo000DOol00`00Oomoo`1AOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`04001oogoo000COol00`00Oomoo`1BOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo0080015oo`8005Aoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01@00Oomoo`00Ool010000goo00<007ooOol03goo0P00EGoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03goo00<007ooOol0E7oo000;Ool2
000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0>Ool00`00Oomoo`1EOol002Qoo`03001oogoo
00ioo`03001oogoo05Eoo`00:7oo00<007ooOol03Goo00<007ooOol0EWoo000AOol20004Ool00`00
Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0<Ool00`00Oomoo`1GOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol0Egoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`03001oogoo05Qoo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000;Ool2001JOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol0FGoo
000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00Uoo`03001oogoo05Yo
o`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0Fgoo000XOol0
0`00Oomoo`07Ool2001MOol002Qoo`03001oogoo00Moo`03001oogoo05aoo`00:7oo0P0017oo00@0
07oo000005moo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo2@00H7oo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=o
o`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomo
o`00:goo?@0037oo000:Ool01000Oomoo`001goo10000goo00<007ooOol09goo0`00B7oo000:Ool0
1000Oomoo`001goo00<007ooOol017oo0P009Woo0`00BWoo000;Ool20008Ool50002Ool00`00Oomo
o`0TOol2001<Ool001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<00004Ool00000Ool20004Ool2
0005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool0
01aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo0`000Woo00@007ooOol0009oo`04
001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009o
o`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`8000=o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Ao
o`@000Aoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol0
17oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Eoo`80
009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomo
ogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001o
ogoo0003Ool20003Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo
00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool0
1`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000=oo`8000Eo
o`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool2
0006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo01Moo`<005Qoo`0077oo00<007ooOol0
5Woo0P00FWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<0
07ooOol02Woo000LOol00`00Oomoo`0EOol00`00Oomoo`1JOol001aoo`8001Ioo`03001oogoo05Yo
o`0077oo00<007ooOol057oo00<007ooOol0Fgoo000LOol00`00Oomoo`0DOol00`00Oomoo`1KOol0
01aoo`8001Aoo`03001oogoo05aoo`0077oo00<007ooOol04Woo0P00GWoo000LOol00`00Oomoo`0B
Ool00`00Oomoo`1MOol001aoo`80019oo`03001oogoo05ioo`0077oo00<007ooOol04Goo00<007oo
Ool0GWoo000LOol2000AOol00`00Oomoo`1OOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03
001oogoo011oo`03001oogoo05moo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`0?Ool00`00Oomoo`1POol000Yoo`04001oogoo000;Ool00`00Oomoo`02000@Ool00`00Oomo
o`1POol000Yoo`04001oogoo000;Ool01000Oomoo`0047oo00<007ooOol0HGoo000:Ool01000Oomo
o`001goo10000goo00<007ooOol03Woo00<007ooOol0HGoo000:Ool01000Oomoo`001goo00<007oo
Ool017oo0P003Woo00<007ooOol0HWoo000;Ool20008Ool50002Ool00`00Oomoo`0=Ool00`00Oomo
o`1ROol001aoo`03001oogoo00aoo`03001oogoo06=oo`0077oo0P0037oo0P00IGoo000LOol00`00
Oomoo`0;Ool00`00Oomoo`1TOol001aoo`8000]oo`03001oogoo06Eoo`0077oo00<007ooOol02Woo
00<007ooOol0IGoo000LOol00`00Oomoo`09Ool00`00Oomoo`1VOol001aoo`8000Uoo`8006Qoo`00
5Woo0`000goo00<007ooOol027oo00<007ooOol0Igoo000GOol00`00Oomoo`02Ool00`00Oomoo`07
Ool2001YOol001Moo`03001oogoo009oo`/006Yoo`005goo00<007ooOol00Woo00<007ooOol01Goo
00<007ooOol0JWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`00
5goo00<007ooOol00Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000:
Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo
00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool2
0009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`00
77oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(26553\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .2917 m
.008 .29453 L
.012 .29963 L
.016 .30455 L
.02 .30868 L
.024 .3089 L
.028 .30497 L
.032 .30089 L
.036 .29717 L
.04 .29367 L
.044 .29115 L
.048 .29202 L
.052 .2958 L
.056 .29834 L
.06 .29862 L
.064 .29723 L
.068 .29539 L
.072 .29449 L
.076 .29507 L
.08 .29709 L
.084 .29971 L
.088 .3013 L
.092 .30132 L
.096 .3015 L
.1 .30289 L
.104 .30529 L
.108 .30717 L
.112 .30698 L
.116 .30562 L
.12 .30526 L
.124 .30682 L
.128 .30907 L
.132 .31075 L
.136 .31189 L
.14 .31411 L
.144 .31885 L
.148 .32534 L
.152 .33083 L
.156 .3331 L
.16 .33207 L
.164 .32963 L
.168 .3282 L
.172 .32848 L
.176 .32921 L
.18 .32863 L
.184 .32585 L
.188 .32186 L
.192 .31887 L
.196 .31876 L
.2 .32207 L
Mistroke
.204 .32786 L
.208 .33421 L
.212 .33947 L
.216 .3428 L
.22 .34426 L
.224 .34463 L
.228 .34477 L
.232 .34547 L
.236 .34718 L
.24 .35002 L
.244 .35371 L
.248 .35749 L
.252 .36024 L
.256 .36066 L
.26 .35777 L
.264 .35136 L
.268 .34217 L
.272 .33178 L
.276 .32196 L
.28 .31404 L
.284 .30832 L
.288 .30412 L
.292 .30019 L
.296 .29551 L
.3 .28985 L
.304 .28397 L
.308 .27917 L
.312 .27664 L
.316 .27674 L
.32 .27885 L
.324 .28168 L
.328 .28397 L
.332 .28506 L
.336 .28521 L
.34 .28522 L
.344 .2859 L
.348 .28749 L
.352 .28949 L
.356 .29098 L
.36 .29114 L
.364 .28977 L
.368 .28743 L
.372 .28508 L
.376 .28356 L
.38 .28317 L
.384 .28352 L
.388 .2839 L
.392 .2837 L
.396 .28289 L
.4 .28195 L
Mistroke
.404 .28165 L
.408 .28252 L
.412 .2846 L
.416 .28739 L
.42 .29019 L
.424 .2925 L
.428 .29427 L
.432 .29581 L
.436 .29759 L
.44 .29981 L
.444 .30235 L
.448 .30482 L
.452 .30685 L
.456 .3083 L
.46 .30932 L
.464 .31025 L
.468 .31133 L
.472 .31263 L
.476 .31396 L
.48 .31504 L
.484 .3157 L
.488 .31595 L
.492 .31598 L
.496 .31605 L
.5 .3163 L
.504 .31674 L
.508 .31723 L
.512 .3176 L
.516 .31774 L
.52 .31766 L
.524 .31749 L
.528 .3174 L
.532 .31747 L
.536 .3177 L
.54 .31795 L
.544 .31806 L
.548 .31797 L
.552 .31773 L
.556 .31752 L
.56 .3175 L
.564 .3177 L
.568 .31801 L
.572 .3182 L
.576 .31815 L
.58 .31789 L
.584 .31761 L
.588 .31753 L
.592 .31769 L
.596 .31797 L
.6 .31815 L
Mistroke
.604 .31809 L
.608 .31785 L
.612 .31764 L
.616 .31764 L
.62 .31786 L
.624 .31812 L
.628 .31821 L
.632 .31803 L
.636 .31773 L
.64 .31756 L
.644 .31767 L
.648 .31798 L
.652 .31823 L
.656 .31823 L
.66 .31797 L
.664 .31769 L
.668 .31762 L
.672 .31782 L
.676 .31811 L
.68 .31825 L
.684 .31812 L
.688 .31784 L
.692 .31764 L
.696 .31771 L
.7 .31799 L
.704 .31824 L
.708 .31825 L
.712 .31803 L
.716 .31776 L
.72 .3177 L
.724 .31787 L
.728 .31812 L
.732 .31823 L
.736 .3181 L
.74 .31788 L
.744 .31779 L
.748 .3179 L
.752 .31811 L
.756 .31822 L
.76 .31814 L
.764 .31795 L
.768 .31782 L
.772 .31785 L
.776 .31801 L
.78 .31815 L
.784 .31818 L
.788 .31811 L
.792 .31803 L
.796 .318 L
.8 .31803 L
Mistroke
.804 .31803 L
.808 .31798 L
.812 .31794 L
.816 .31799 L
.82 .31815 L
.824 .31831 L
.828 .31832 L
.832 .31812 L
.836 .31784 L
.84 .3177 L
.844 .31782 L
.848 .31816 L
.852 .31845 L
.856 .31849 L
.86 .31826 L
.864 .31795 L
.868 .31776 L
.872 .31781 L
.876 .31802 L
.88 .31824 L
.884 .31837 L
.888 .31838 L
.892 .31827 L
.896 .3181 L
.9 .31793 L
.904 .31783 L
.908 .3179 L
.912 .31817 L
.916 .31843 L
.92 .31854 L
.924 .31839 L
.928 .31805 L
.932 .31779 L
.936 .31781 L
.94 .31804 L
.944 .31835 L
.948 .31852 L
.952 .31846 L
.956 .31826 L
.96 .31805 L
.964 .31793 L
.968 .31792 L
.972 .31806 L
.976 .31831 L
.98 .31848 L
.984 .31856 L
.988 .31841 L
.992 .31804 L
.996 .31784 L
1 .31786 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .58466 m
.008 .58782 L
.012 .5887 L
.016 .58709 L
.02 .58662 L
.024 .58687 L
.028 .58685 L
.032 .58659 L
.036 .58649 L
.04 .58639 L
.044 .58653 L
.048 .5868 L
.052 .5868 L
.056 .58637 L
.06 .58606 L
.064 .58606 L
.068 .58646 L
.072 .58696 L
.076 .58711 L
.08 .58676 L
.084 .58632 L
.088 .58612 L
.092 .58672 L
.096 .58809 L
.1 .58966 L
.104 .59079 L
.108 .5909 L
.112 .58986 L
.116 .5878 L
.12 .5848 L
.124 .5809 L
.128 .57617 L
.132 .57095 L
.136 .56556 L
.14 .56022 L
.144 .55485 L
.148 .54927 L
.152 .54342 L
.156 .53753 L
.16 .53184 L
.164 .52645 L
.168 .52118 L
.172 .51569 L
.176 .50978 L
.18 .50353 L
.184 .4972 L
.188 .49109 L
.192 .48527 L
.196 .47959 L
.2 .47375 L
Mistroke
.204 .46754 L
.208 .46098 L
.212 .45434 L
.216 .44793 L
.22 .44205 L
.224 .43675 L
.228 .43183 L
.232 .42698 L
.236 .42181 L
.24 .41607 L
.244 .40966 L
.248 .4027 L
.252 .39545 L
.256 .38824 L
.26 .38138 L
.264 .37514 L
.268 .36966 L
.272 .36497 L
.276 .36105 L
.28 .35778 L
.284 .35501 L
.288 .3526 L
.292 .35042 L
.296 .34836 L
.3 .34635 L
.304 .34433 L
.308 .3423 L
.312 .34023 L
.316 .33814 L
.32 .33605 L
.324 .33398 L
.328 .33193 L
.332 .32994 L
.336 .32801 L
.34 .32616 L
.344 .32437 L
.348 .32265 L
.352 .32097 L
.356 .31931 L
.36 .31765 L
.364 .31595 L
.368 .31418 L
.372 .31232 L
.376 .31036 L
.38 .30829 L
.384 .30611 L
.388 .30383 L
.392 .30149 L
.396 .29909 L
.4 .29668 L
Mistroke
.404 .29428 L
.408 .29192 L
.412 .28962 L
.416 .2874 L
.42 .28527 L
.424 .28324 L
.428 .28132 L
.432 .27952 L
.436 .27787 L
.44 .27638 L
.444 .27503 L
.448 .27384 L
.452 .2728 L
.456 .27189 L
.46 .27109 L
.464 .2704 L
.468 .2698 L
.472 .26928 L
.476 .26883 L
.48 .26844 L
.484 .26811 L
.488 .26784 L
.492 .26762 L
.496 .26745 L
.5 .26732 L
.504 .26721 L
.508 .26711 L
.512 .26703 L
.516 .26694 L
.52 .26687 L
.524 .2668 L
.528 .26674 L
.532 .2667 L
.536 .26667 L
.54 .26664 L
.544 .26662 L
.548 .2666 L
.552 .26658 L
.556 .26655 L
.56 .26652 L
.564 .26648 L
.568 .26645 L
.572 .26642 L
.576 .2664 L
.58 .26639 L
.584 .26637 L
.588 .26635 L
.592 .26633 L
.596 .26631 L
.6 .26628 L
Mistroke
.604 .26626 L
.608 .26623 L
.612 .2662 L
.616 .26618 L
.62 .26616 L
.624 .26614 L
.628 .26612 L
.632 .2661 L
.636 .26608 L
.64 .26606 L
.644 .26603 L
.648 .266 L
.652 .26598 L
.656 .26595 L
.66 .26593 L
.664 .26591 L
.668 .26589 L
.672 .26587 L
.676 .26585 L
.68 .26583 L
.684 .2658 L
.688 .26578 L
.692 .26575 L
.696 .26573 L
.7 .2657 L
.704 .26568 L
.708 .26566 L
.712 .26564 L
.716 .26562 L
.72 .2656 L
.724 .26557 L
.728 .26555 L
.732 .26553 L
.736 .2655 L
.74 .26548 L
.744 .26546 L
.748 .26543 L
.752 .26541 L
.756 .2654 L
.76 .26537 L
.764 .26535 L
.768 .26532 L
.772 .26529 L
.776 .26527 L
.78 .26525 L
.784 .26523 L
.788 .26521 L
.792 .26519 L
.796 .26517 L
.8 .26514 L
Mistroke
.804 .26512 L
.808 .26509 L
.812 .26507 L
.816 .26505 L
.82 .26503 L
.824 .26501 L
.828 .26499 L
.832 .26496 L
.836 .26494 L
.84 .26491 L
.844 .26489 L
.848 .26486 L
.852 .26485 L
.856 .26483 L
.86 .26481 L
.864 .26478 L
.868 .26476 L
.872 .26473 L
.876 .26471 L
.88 .26469 L
.884 .26466 L
.888 .26464 L
.892 .26462 L
.896 .2646 L
.9 .26458 L
.904 .26455 L
.908 .26453 L
.912 .2645 L
.916 .26448 L
.92 .26446 L
.924 .26444 L
.928 .26442 L
.932 .2644 L
.936 .26437 L
.94 .26435 L
.944 .26432 L
.948 .2643 L
.952 .26428 L
.956 .26426 L
.96 .26423 L
.964 .26421 L
.968 .26419 L
.972 .26417 L
.976 .26414 L
.98 .26412 L
.984 .2641 L
.988 .26408 L
.992 .26405 L
.996 .26404 L
1 .264 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43525 L
.012 .42976 L
.016 .42781 L
.02 .42932 L
.024 .4301 L
.028 .42975 L
.032 .42963 L
.036 .42962 L
.04 .42968 L
.044 .42976 L
.048 .42989 L
.052 .42978 L
.056 .42932 L
.06 .42866 L
.064 .42857 L
.068 .42897 L
.072 .42936 L
.076 .42932 L
.08 .42876 L
.084 .42792 L
.088 .42768 L
.092 .42842 L
.096 .43018 L
.1 .43241 L
.104 .43402 L
.108 .43437 L
.112 .43326 L
.116 .43074 L
.12 .42696 L
.124 .42193 L
.128 .41583 L
.132 .40903 L
.136 .40209 L
.14 .39526 L
.144 .38847 L
.148 .38149 L
.152 .37427 L
.156 .36701 L
.16 .36003 L
.164 .3534 L
.168 .34689 L
.172 .34009 L
.176 .33275 L
.18 .32493 L
.184 .31701 L
.188 .30935 L
.192 .30204 L
.196 .29488 L
.2 .28751 L
Mistroke
.204 .27969 L
.208 .27147 L
.212 .26316 L
.216 .25521 L
.22 .24794 L
.224 .2414 L
.228 .23536 L
.232 .22936 L
.236 .22295 L
.24 .21578 L
.244 .20777 L
.248 .19907 L
.252 .19 L
.256 .18099 L
.26 .17244 L
.264 .16466 L
.268 .15783 L
.272 .15201 L
.276 .14713 L
.28 .14306 L
.284 .13965 L
.288 .1367 L
.292 .13404 L
.296 .13153 L
.3 .12907 L
.304 .12659 L
.308 .12405 L
.312 .12145 L
.316 .11882 L
.32 .11617 L
.324 .11356 L
.328 .11102 L
.332 .10858 L
.336 .10625 L
.34 .10401 L
.344 .10187 L
.348 .09978 L
.352 .09773 L
.356 .09568 L
.36 .09359 L
.364 .09144 L
.368 .08921 L
.372 .08687 L
.376 .08443 L
.38 .08188 L
.384 .07922 L
.388 .07646 L
.392 .07362 L
.396 .07072 L
.4 .06777 L
Mistroke
.404 .0648 L
.408 .06185 L
.412 .05895 L
.416 .05615 L
.42 .05348 L
.424 .05096 L
.428 .04863 L
.432 .04648 L
.436 .04452 L
.44 .04273 L
.444 .04111 L
.448 .03965 L
.452 .03835 L
.456 .0372 L
.46 .0362 L
.464 .03534 L
.468 .03462 L
.472 .03401 L
.476 .03352 L
.48 .03311 L
.484 .03277 L
.488 .0325 L
.492 .03226 L
.496 .03205 L
.5 .03188 L
.504 .03173 L
.508 .03162 L
.512 .03155 L
.516 .0315 L
.52 .03147 L
.524 .03146 L
.528 .03145 L
.532 .03143 L
.536 .03141 L
.54 .03139 L
.544 .03138 L
.548 .03136 L
.552 .03136 L
.556 .03136 L
.56 .03137 L
.564 .03139 L
.568 .03141 L
.572 .03142 L
.576 .03142 L
.58 .03142 L
.584 .03141 L
.588 .03141 L
.592 .03141 L
.596 .03142 L
.6 .03143 L
Mistroke
.604 .03144 L
.608 .03145 L
.612 .03146 L
.616 .03147 L
.62 .03148 L
.624 .03148 L
.628 .03147 L
.632 .03148 L
.636 .03148 L
.64 .03149 L
.644 .0315 L
.648 .03151 L
.652 .03152 L
.656 .03153 L
.66 .03153 L
.664 .03153 L
.668 .03154 L
.672 .03154 L
.676 .03155 L
.68 .03155 L
.684 .03156 L
.688 .03157 L
.692 .03158 L
.696 .03159 L
.7 .0316 L
.704 .0316 L
.708 .0316 L
.712 .0316 L
.716 .03161 L
.72 .03162 L
.724 .03163 L
.728 .03164 L
.732 .03164 L
.736 .03165 L
.74 .03165 L
.744 .03166 L
.748 .03166 L
.752 .03167 L
.756 .03167 L
.76 .03168 L
.764 .03169 L
.768 .0317 L
.772 .03171 L
.776 .03171 L
.78 .03172 L
.784 .03172 L
.788 .03172 L
.792 .03173 L
.796 .03174 L
.8 .03175 L
Mistroke
.804 .03175 L
.808 .03176 L
.812 .03177 L
.816 .03177 L
.82 .03178 L
.824 .03178 L
.828 .03179 L
.832 .03179 L
.836 .0318 L
.84 .03181 L
.844 .03182 L
.848 .03183 L
.852 .03183 L
.856 .03183 L
.86 .03184 L
.864 .03184 L
.868 .03185 L
.872 .03186 L
.876 .03187 L
.88 .03188 L
.884 .03188 L
.888 .03189 L
.892 .03189 L
.896 .0319 L
.9 .0319 L
.904 .03191 L
.908 .03192 L
.912 .03193 L
.916 .03194 L
.92 .03194 L
.924 .03195 L
.928 .03195 L
.932 .03195 L
.936 .03196 L
.94 .03197 L
.944 .03198 L
.948 .03199 L
.952 .03199 L
.956 .032 L
.96 .032 L
.964 .03201 L
.968 .03201 L
.972 .03202 L
.976 .03203 L
.98 .03204 L
.984 .03204 L
.988 .03206 L
.992 .03205 L
.996 .03206 L
1 .03206 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Moo`8000Eoo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo
01]oo`D00003Ool0000000@004Eoo`008Woo0P000Woo1@0057oo00<007ooOol00Woo0`0017oo0`00
@goo000ROomS000<Ool0029oo`05001oogooOol00003Ool01000Oomoogoo0`0000Aoo`00Oomoo`80
00=oo`04001oogoo0003Ool01@00Oomoogoo00000goo00H007ooOomoo`00Oolf000<Ool0029oo`80
00eoo`06001oo`00001oo`001Woo00<007ooOol0DGoo000ROol00`00Oomoo`0<Ool20003Ool20005
Ool00`00Oomoo`1AOol0029oo`8001=oo`@00003Ool007oo05=oo`008Woo0P005Woo0`00E7oo000;
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0FOol00`00Oomoo`1COol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eo
o`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]
Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:
Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0
029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00
0Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo
0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P00
0goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool0
1@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001o
ogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0
009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2
000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000
Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo1000
0goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000
Oomoo`001Woo0P0017oo00@007ooOol0009oo`03001oo`00034000=oo`04001oogoo0005Ool002Qo
o`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`80009oo`@000Aoo`04001oogooOol5
0003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo
02=oo`80045oo`00:7oo00<007ooOol08Goo0P00@goo000XOomM000<Ool002Qoo`03001oogoo00mo
o`03001oogoo00]oo`<0009oo`03001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001o
ogoo00Yoo`00:7oo00<007ooOol06goo0P00BGoo000XOol00`00Oomoo`0IOol2001;Ool002Qoo`03
001oogoo01Moo`<004aoo`00:7oo00<007ooOol05Woo0P00CWoo000XOol00`00Oomoo`0EOol2001?
Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo01Eoo`03001o
ogoo04ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001o
ogoo000FOol00`00Oomoo`1?Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`04001oogoo000EOol2001AOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo008001Aoo`03001oogoo051oo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01@00Oomoo`00Ool010000goo00<007ooOol04Woo00<007ooOol0DGoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol04Goo0P00Dgoo000;Ool2
000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0@Ool2001DOol002Qoo`03001oogoo011oo`03
001oogoo05=oo`00:7oo00<007ooOol03goo0P00EGoo000AOol20004Ool00`00Oomoo`03Ool20003
Ool30003Ool00`00Oomoo`0?Ool00`00Oomoo`1DOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol0EGoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo00eoo`8005Moo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2000>Ool00`00Oomoo`1FOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol0Egoo000@Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00]oo`03001oogoo05Qoo`004Goo0P002Woo
0P0017oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol0F7oo000XOol00`00Oomoo`0:Ool0
0`00Oomoo`1IOol002Qoo`03001oogoo00Uoo`8005]oo`00:7oo00<007oo0000100000Aoo`00Oomo
o`8005aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo1P0000=oo`00Ool0
0`00GGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomo
o`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo0080
06Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogoo
Ool5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009o
o`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;
Ool01000Oomoo`00;Woo>P0037oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0:Woo0`00
AGoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00:Goo0P00B7oo000;Ool20008Ool50002
Ool00`00Oomoo`0WOol20019Ool001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Ao
o`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Io
o`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool01000Oomoogoo0P000Woo00@0
07ooOol0009oo`03001oogoo00=oo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol0
0goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007oo00000`000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Io
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001o
ogoo0002Ool00`00Oomoo`07Ool30002Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@0
00=oo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol4
0003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04
Ool01000Oomoo`001Woo100017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomo
o`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool20005Ool30002
Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo
0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`0JOol2001FOol001aoo`03001oogoo
01Uoo`8005Moo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007oo
Oomoo`0000=oo`06001oogooOol007oo0`000goo00D007ooOomoo`0000Aoo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:
Ool001aoo`03001oogoo01Qoo`03001oogoo05Moo`0077oo0P0067oo00<007ooOol0F7oo000LOol0
0`00Oomoo`0GOol00`00Oomoo`1HOol001aoo`03001oogoo01Ioo`03001oogoo05Uoo`0077oo0P00
5goo00<007ooOol0FGoo000LOol00`00Oomoo`0EOol2001KOol001aoo`03001oogoo01Eoo`03001o
ogoo05Yoo`0077oo0P005Goo00<007ooOol0Fgoo000LOol00`00Oomoo`0DOol00`00Oomoo`1KOol0
01aoo`8001Aoo`03001oogoo05aoo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0
4goo00<007ooOol0G7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo019o
o`03001oogoo05eoo`002Woo00@007ooOol000]oo`03001oogoo0080019oo`03001oogoo05ioo`00
2Woo00@007ooOol000]oo`04001oogoo000COol00`00Oomoo`1NOol000Yoo`04001oogoo0007Ool4
0003Ool00`00Oomoo`0@Ool2001POol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2000AOol0
0`00Oomoo`1OOol000]oo`8000Qoo`D0009oo`03001oogoo00moo`03001oogoo061oo`0077oo00<0
07ooOol03goo00<007ooOol0H7oo000LOol2000?Ool00`00Oomoo`1QOol001aoo`03001oogoo00io
o`03001oogoo065oo`0077oo0P003Woo00<007ooOol0HWoo000LOol00`00Oomoo`0=Ool00`00Oomo
o`1ROol001aoo`03001oogoo00aoo`03001oogoo06=oo`0077oo0P0037oo00<007ooOol0I7oo000F
Ool30003Ool00`00Oomoo`0;Ool00`00Oomoo`1TOol001Moo`03001oogoo009oo`03001oogoo00Yo
o`03001oogoo06Eoo`005goo00<007ooOol00Woo3P00Igoo000GOol00`00Oomoo`02Ool20009Ool0
0`00Oomoo`1WOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000G
Ool00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yo
o`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00
009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol0
2goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`80
00Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000L
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(26720\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30213 m
.008 .29855 L
.012 .2966 L
.016 .29584 L
.02 .29524 L
.024 .29612 L
.028 .29752 L
.032 .298 L
.036 .29805 L
.04 .29592 L
.044 .29295 L
.048 .29171 L
.052 .29283 L
.056 .29487 L
.06 .29648 L
.064 .29877 L
.068 .30145 L
.072 .3037 L
.076 .30441 L
.08 .30226 L
.084 .29827 L
.088 .29398 L
.092 .29117 L
.096 .2916 L
.1 .29522 L
.104 .29973 L
.108 .30235 L
.112 .30163 L
.116 .29884 L
.12 .29728 L
.124 .29821 L
.128 .30045 L
.132 .30241 L
.136 .3037 L
.14 .30549 L
.144 .30876 L
.148 .31282 L
.152 .31578 L
.156 .31698 L
.16 .31763 L
.164 .31955 L
.168 .32342 L
.172 .32789 L
.176 .33072 L
.18 .3311 L
.184 .33042 L
.188 .33095 L
.192 .33402 L
.196 .33843 L
.2 .34121 L
Mistroke
.204 .33978 L
.208 .33377 L
.212 .32567 L
.216 .3195 L
.22 .31854 L
.224 .32362 L
.228 .33277 L
.232 .34227 L
.236 .34862 L
.24 .35014 L
.244 .34759 L
.248 .34363 L
.252 .34136 L
.256 .34292 L
.26 .34851 L
.264 .35646 L
.268 .3641 L
.272 .36897 L
.276 .36979 L
.28 .36678 L
.284 .36126 L
.288 .35479 L
.292 .34841 L
.296 .34222 L
.3 .33568 L
.304 .32816 L
.308 .31956 L
.312 .31053 L
.316 .30221 L
.32 .2956 L
.324 .29112 L
.328 .28839 L
.332 .28652 L
.336 .28471 L
.34 .28268 L
.344 .28085 L
.348 .27997 L
.352 .28065 L
.356 .28285 L
.36 .28589 L
.364 .2887 L
.368 .29043 L
.372 .29086 L
.376 .29039 L
.38 .28975 L
.384 .28954 L
.388 .28982 L
.392 .29018 L
.396 .29004 L
.4 .28905 L
Mistroke
.404 .28737 L
.408 .28553 L
.412 .28413 L
.416 .28356 L
.42 .28375 L
.424 .28439 L
.428 .28512 L
.432 .28579 L
.436 .28655 L
.44 .28766 L
.444 .28934 L
.448 .29156 L
.452 .29406 L
.456 .29652 L
.46 .29868 L
.464 .30051 L
.468 .30214 L
.472 .30377 L
.476 .30551 L
.48 .30735 L
.484 .30916 L
.488 .31074 L
.492 .31198 L
.496 .31286 L
.5 .31349 L
.504 .31406 L
.508 .31469 L
.512 .3154 L
.516 .31609 L
.52 .31661 L
.524 .31685 L
.528 .31686 L
.532 .31681 L
.536 .3169 L
.54 .31719 L
.544 .3176 L
.548 .31791 L
.552 .31796 L
.556 .31775 L
.56 .31746 L
.564 .31734 L
.568 .31748 L
.572 .31781 L
.576 .31808 L
.58 .3181 L
.584 .31787 L
.588 .3176 L
.592 .31751 L
.596 .31768 L
.6 .31797 L
Mistroke
.604 .31815 L
.608 .31806 L
.612 .31778 L
.616 .31753 L
.62 .31753 L
.624 .31779 L
.628 .3181 L
.632 .3182 L
.636 .31803 L
.64 .31773 L
.644 .31755 L
.648 .31764 L
.652 .31792 L
.656 .31813 L
.66 .31812 L
.664 .3179 L
.668 .31768 L
.672 .31765 L
.676 .31783 L
.68 .31806 L
.684 .31814 L
.688 .31801 L
.692 .3178 L
.696 .3177 L
.7 .3178 L
.704 .318 L
.708 .31811 L
.712 .31802 L
.716 .31784 L
.72 .31774 L
.724 .31784 L
.728 .31806 L
.732 .31819 L
.736 .31809 L
.74 .31785 L
.744 .31766 L
.748 .31771 L
.752 .31796 L
.756 .31821 L
.76 .31827 L
.764 .3181 L
.768 .31786 L
.772 .31773 L
.776 .31779 L
.78 .31797 L
.784 .31811 L
.788 .31813 L
.792 .31806 L
.796 .31799 L
.8 .31798 L
Mistroke
.804 .318 L
.808 .318 L
.812 .31796 L
.816 .31793 L
.82 .31797 L
.824 .31808 L
.828 .31817 L
.832 .31814 L
.836 .31803 L
.84 .31792 L
.844 .31791 L
.848 .31802 L
.852 .31813 L
.856 .31814 L
.86 .31805 L
.864 .31797 L
.868 .31799 L
.872 .31811 L
.876 .31821 L
.88 .31817 L
.884 .31803 L
.888 .31792 L
.892 .31791 L
.896 .31805 L
.9 .31821 L
.904 .31827 L
.908 .31823 L
.912 .31812 L
.916 .318 L
.92 .31795 L
.924 .31796 L
.928 .31803 L
.932 .31818 L
.936 .31832 L
.94 .31838 L
.944 .31827 L
.948 .31804 L
.952 .31785 L
.956 .31782 L
.96 .31804 L
.964 .31831 L
.968 .31845 L
.972 .31845 L
.976 .31824 L
.98 .31799 L
.984 .3179 L
.988 .31789 L
.992 .31803 L
.996 .31829 L
1 .31845 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57842 m
.008 .58617 L
.012 .58894 L
.016 .58655 L
.02 .58578 L
.024 .58662 L
.028 .58704 L
.032 .5868 L
.036 .5866 L
.04 .58642 L
.044 .58646 L
.048 .58657 L
.052 .58659 L
.056 .5864 L
.06 .58635 L
.064 .58649 L
.068 .58673 L
.072 .5868 L
.076 .58648 L
.08 .58587 L
.084 .5855 L
.088 .58554 L
.092 .58594 L
.096 .58639 L
.1 .58644 L
.104 .58597 L
.108 .58539 L
.112 .58517 L
.116 .5858 L
.12 .5872 L
.124 .58883 L
.128 .59013 L
.132 .59071 L
.136 .59042 L
.14 .58915 L
.144 .58678 L
.148 .58329 L
.152 .57886 L
.156 .57393 L
.16 .56882 L
.164 .56366 L
.168 .55832 L
.172 .55271 L
.176 .54687 L
.18 .54107 L
.184 .53554 L
.188 .53027 L
.192 .52506 L
.196 .51957 L
.2 .51365 L
Mistroke
.204 .50743 L
.208 .50116 L
.212 .49512 L
.216 .48935 L
.22 .48369 L
.224 .47786 L
.228 .47165 L
.232 .46508 L
.236 .45838 L
.24 .45188 L
.244 .44588 L
.248 .44046 L
.252 .4355 L
.256 .43069 L
.26 .42568 L
.264 .42016 L
.268 .41401 L
.272 .40724 L
.276 .40008 L
.28 .39281 L
.284 .38575 L
.288 .37918 L
.292 .37327 L
.296 .36813 L
.3 .36375 L
.304 .36007 L
.308 .35695 L
.312 .35428 L
.316 .35191 L
.32 .34974 L
.324 .34767 L
.328 .34564 L
.332 .34361 L
.336 .34156 L
.34 .33948 L
.344 .33738 L
.348 .33529 L
.352 .33321 L
.356 .33119 L
.36 .32922 L
.364 .32732 L
.368 .3255 L
.372 .32375 L
.376 .32205 L
.38 .3204 L
.384 .31875 L
.388 .31709 L
.392 .31537 L
.396 .31357 L
.4 .31166 L
Mistroke
.404 .30964 L
.408 .30752 L
.412 .30529 L
.416 .303 L
.42 .30065 L
.424 .29827 L
.428 .29589 L
.432 .29352 L
.436 .29117 L
.44 .28888 L
.444 .28667 L
.448 .28454 L
.452 .28253 L
.456 .28065 L
.46 .27891 L
.464 .27733 L
.468 .2759 L
.472 .27462 L
.476 .27348 L
.48 .27248 L
.484 .27159 L
.488 .27081 L
.492 .27013 L
.496 .26954 L
.5 .26903 L
.504 .2686 L
.508 .26825 L
.512 .26796 L
.516 .26772 L
.52 .26752 L
.524 .26736 L
.528 .26721 L
.532 .26709 L
.536 .26698 L
.54 .26689 L
.544 .26681 L
.548 .26674 L
.552 .2667 L
.556 .26666 L
.56 .26663 L
.564 .26659 L
.568 .26656 L
.572 .26653 L
.576 .2665 L
.58 .26647 L
.584 .26643 L
.588 .26641 L
.592 .26638 L
.596 .26636 L
.6 .26634 L
Mistroke
.604 .26632 L
.608 .2663 L
.612 .26628 L
.616 .26625 L
.62 .26623 L
.624 .2662 L
.628 .26617 L
.632 .26615 L
.636 .26613 L
.64 .26611 L
.644 .26609 L
.648 .26607 L
.652 .26605 L
.656 .26602 L
.66 .266 L
.664 .26598 L
.668 .26595 L
.672 .26593 L
.676 .2659 L
.68 .26588 L
.684 .26586 L
.688 .26585 L
.692 .26582 L
.696 .2658 L
.7 .26577 L
.704 .26575 L
.708 .26572 L
.712 .2657 L
.716 .26568 L
.72 .26566 L
.724 .26564 L
.728 .26562 L
.732 .26559 L
.736 .26557 L
.74 .26555 L
.744 .26552 L
.748 .2655 L
.752 .26547 L
.756 .26545 L
.76 .26543 L
.764 .26541 L
.768 .26539 L
.772 .26537 L
.776 .26534 L
.78 .26532 L
.784 .26529 L
.788 .26527 L
.792 .26525 L
.796 .26523 L
.8 .26521 L
Mistroke
.804 .26519 L
.808 .26516 L
.812 .26514 L
.816 .26511 L
.82 .26509 L
.824 .26507 L
.828 .26504 L
.832 .26503 L
.836 .26501 L
.84 .26498 L
.844 .26496 L
.848 .26493 L
.852 .26491 L
.856 .26489 L
.86 .26486 L
.864 .26484 L
.868 .26482 L
.872 .2648 L
.876 .26478 L
.88 .26476 L
.884 .26473 L
.888 .26471 L
.892 .26468 L
.896 .26466 L
.9 .26464 L
.904 .26462 L
.908 .2646 L
.912 .26457 L
.916 .26455 L
.92 .26452 L
.924 .2645 L
.928 .26448 L
.932 .26446 L
.936 .26444 L
.94 .26442 L
.944 .26439 L
.948 .26437 L
.952 .26434 L
.956 .26432 L
.96 .2643 L
.964 .26428 L
.968 .26425 L
.972 .26424 L
.976 .26421 L
.98 .26419 L
.984 .26416 L
.988 .26414 L
.992 .26411 L
.996 .2641 L
1 .26407 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42837 L
.012 .43061 L
.016 .4312 L
.02 .43032 L
.024 .43028 L
.028 .43061 L
.032 .43053 L
.036 .43003 L
.04 .42975 L
.044 .42958 L
.048 .42951 L
.052 .42932 L
.056 .42903 L
.06 .42872 L
.064 .42885 L
.068 .42928 L
.072 .4295 L
.076 .42925 L
.08 .42883 L
.084 .4285 L
.088 .42868 L
.092 .42922 L
.096 .42963 L
.1 .42949 L
.104 .42871 L
.108 .42764 L
.112 .4272 L
.116 .42783 L
.12 .42948 L
.124 .43155 L
.128 .43324 L
.132 .43406 L
.136 .43379 L
.14 .43228 L
.144 .42936 L
.148 .425 L
.152 .41949 L
.156 .41328 L
.16 .40686 L
.164 .40035 L
.168 .39361 L
.172 .38651 L
.176 .37915 L
.18 .37183 L
.184 .36488 L
.188 .35831 L
.192 .35183 L
.196 .34504 L
.2 .33774 L
Mistroke
.204 .33002 L
.208 .32225 L
.212 .31471 L
.216 .30749 L
.22 .30039 L
.224 .29307 L
.228 .28529 L
.232 .27707 L
.236 .26869 L
.24 .26059 L
.244 .25309 L
.248 .24633 L
.252 .24015 L
.256 .23417 L
.26 .22795 L
.264 .22111 L
.268 .21348 L
.272 .2051 L
.276 .1962 L
.28 .18714 L
.284 .17833 L
.288 .1701 L
.292 .1627 L
.296 .15625 L
.3 .15078 L
.304 .1462 L
.308 .14236 L
.312 .1391 L
.316 .13623 L
.32 .13359 L
.324 .13107 L
.328 .12856 L
.332 .12602 L
.336 .12343 L
.34 .1208 L
.344 .11816 L
.348 .11554 L
.352 .11297 L
.356 .11048 L
.36 .10808 L
.364 .10579 L
.368 .1036 L
.372 .10148 L
.376 .09941 L
.38 .09735 L
.384 .09528 L
.388 .09316 L
.392 .09098 L
.396 .08873 L
.4 .08638 L
Mistroke
.404 .08392 L
.408 .08136 L
.412 .07868 L
.416 .07589 L
.42 .073 L
.424 .07004 L
.428 .06706 L
.432 .06408 L
.436 .06115 L
.44 .0583 L
.444 .05557 L
.448 .05298 L
.452 .05054 L
.456 .04827 L
.46 .04617 L
.464 .04424 L
.468 .04248 L
.472 .04089 L
.476 .03946 L
.48 .03821 L
.484 .03711 L
.488 .03618 L
.492 .03539 L
.496 .03472 L
.5 .03415 L
.504 .03367 L
.508 .03327 L
.512 .03292 L
.516 .03263 L
.52 .03239 L
.524 .0322 L
.528 .03205 L
.532 .03194 L
.536 .03186 L
.54 .0318 L
.544 .03176 L
.548 .03172 L
.552 .03169 L
.556 .03165 L
.56 .03163 L
.564 .03161 L
.568 .0316 L
.572 .0316 L
.576 .03161 L
.58 .03161 L
.584 .03162 L
.588 .03163 L
.592 .03163 L
.596 .03163 L
.6 .03163 L
Mistroke
.604 .03163 L
.608 .03163 L
.612 .03164 L
.616 .03165 L
.62 .03166 L
.624 .03167 L
.628 .03168 L
.632 .03168 L
.636 .03168 L
.64 .03169 L
.644 .03169 L
.648 .0317 L
.652 .0317 L
.656 .03171 L
.66 .03172 L
.664 .03172 L
.668 .03173 L
.672 .03174 L
.676 .03175 L
.68 .03175 L
.684 .03175 L
.688 .03176 L
.692 .03176 L
.696 .03177 L
.7 .03178 L
.704 .03179 L
.708 .0318 L
.712 .0318 L
.716 .03181 L
.72 .03181 L
.724 .03182 L
.728 .03182 L
.732 .03183 L
.736 .03183 L
.74 .03184 L
.744 .03185 L
.748 .03186 L
.752 .03187 L
.756 .03187 L
.76 .03187 L
.764 .03187 L
.768 .03188 L
.772 .03189 L
.776 .0319 L
.78 .03191 L
.784 .03191 L
.788 .03192 L
.792 .03193 L
.796 .03193 L
.8 .03193 L
Mistroke
.804 .03194 L
.808 .03194 L
.812 .03195 L
.816 .03196 L
.82 .03197 L
.824 .03198 L
.828 .03198 L
.832 .03198 L
.836 .03199 L
.84 .03199 L
.844 .032 L
.848 .03201 L
.852 .03202 L
.856 .03203 L
.86 .03203 L
.864 .03204 L
.868 .03204 L
.872 .03205 L
.876 .03205 L
.88 .03206 L
.884 .03207 L
.888 .03208 L
.892 .03209 L
.896 .03209 L
.9 .03209 L
.904 .0321 L
.908 .03211 L
.912 .03211 L
.916 .03212 L
.92 .03213 L
.924 .03214 L
.928 .03214 L
.932 .03215 L
.936 .03215 L
.94 .03216 L
.944 .03216 L
.948 .03218 L
.952 .03218 L
.956 .03219 L
.96 .03219 L
.964 .0322 L
.968 .0322 L
.972 .03221 L
.976 .03222 L
.98 .03223 L
.984 .03223 L
.988 .03224 L
.992 .03224 L
.996 .03225 L
1 .03225 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo01eoo`@000Aoo`@004=oo`008Woo1`0000Ioo`00000007oo000BOol20003Ool40003Ool3
0011Ool0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol00002Ool20003Ool0
1@00Ool007oo00000Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoogoo=000
37oo000ROol2000>Ool20003Ool20007Ool00`00Oomoo`1>Ool0029oo`03001oogoo00ioo`@00003
Ool007oo00Eoo`03001oogoo04moo`008Woo0P004Woo00<007ooOol00`000goo00<007ooOol0Cgoo
000ROol2000FOol01@00Ool007oo0000DWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003
Ool00`00Oomoo`0GOol3001BOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007oo
Ool0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
17oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007oo
Ool00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;
Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
0`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo
00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo
1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2
000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P00
17oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo
1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`00
17oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P00
0goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo
001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo
00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool0
1@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool0
1000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001o
ogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000X
Ool00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00
Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`03001oogoo
034000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=o
o`8000Aoo`@0009oo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool5
0003Ool20006Ool002Qoo`03001oogoo02Eoo`8003moo`00:7oo00<007ooOol097oo0P00@7oo000X
OomM000<Ool002Qoo`03001oogoo00moo`03001oogoo00eoo`@0015oo`03001oogoo00moo`03001o
ogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol07Goo0`00AWoo000XOol00`00Oomoo`0KOol3
0018Ool002Qoo`03001oogoo01Uoo`<004Yoo`00:7oo00<007ooOol067oo0P00C7oo000XOol00`00
Oomoo`0HOol00`00Oomoo`1;Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=o
o`03001oogoo01Moo`03001oogoo04aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00
Oomoo`00Ool000=oo`04001oogoo000HOol2001>Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogoo000HOol00`00Oomoo`1=Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008001Ioo`8004moo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol05Goo00<007ooOol0CWoo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol057oo
00<007ooOol0Cgoo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0COol00`00Oomo
o`1@Ool002Qoo`03001oogoo019oo`80059oo`00:7oo00<007ooOol04Woo00<007ooOol0DGoo000A
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0AOol2001COol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol047oo0P00E7oo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo011oo`03001oogoo05=oo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool00`00Oomoo`1DOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol03Woo0P00EWoo
000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00ioo`03001oogoo05Eo
o`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol0EWoo000XOol0
0`00Oomoo`0<Ool00`00Oomoo`1GOol002Qoo`03001oogoo00]oo`8005Uoo`00:7oo30000Woo00<0
07ooOol0F7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool200000goo001o
o`02Ool01000Oomoogoo0`00Fgoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogoo
Ool00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05
Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006ao
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yo
o`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`80
00Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol0
00Yoo`04001oogoo000;Ool01000Oomoo`00<Goo=`0037oo000:Ool01000Oomoo`001goo10000goo
00<007ooOol0;Goo0`00@Woo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00;7oo0P00AGoo
000;Ool20008Ool50002Ool00`00Oomoo`0ZOol20016Ool001aoo`03001oogoo00eoo`<000Aoo`80
00Uoo`<000Aoo`@0009oo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0
009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00
Oomoo`02Ool01000Ool000000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`00
0Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomo
o`000Woo00<007ooOol01goo00<007ooOol00Woo10000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04
001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`030002Ool01000Oomoo`000Woo00<007ooOol0
0goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00
77oo0P003Goo10000goo00@007ooOol000Uoo`06001oo`00001oo`000Woo00@007ooOol0009oo`03
001oogoo00=oo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol0
0`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0`000goo00@007ooOol0009oo`04001o
ogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2
000=Ool50003Ool20008Ool30005Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`00
17oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`0MOol2001COol001ao
o`03001oogoo01aoo`8005Aoo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol0
0Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool20002Ool01@00Oomoogoo000017oo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Ao
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009o
o`03001oogoo00Yoo`0077oo00<007ooOol06goo00<007ooOol0E7oo000LOol2000KOol00`00Oomo
o`1EOol001aoo`03001oogoo01Yoo`03001oogoo05Eoo`0077oo00<007ooOol06Goo00<007ooOol0
EWoo000LOol2000JOol00`00Oomoo`1FOol001aoo`03001oogoo01Qoo`03001oogoo05Moo`0077oo
00<007ooOol05goo0P00FGoo000LOol2000HOol00`00Oomoo`1HOol001aoo`03001oogoo01Ioo`03
001oogoo05Uoo`0077oo0P005goo00<007ooOol0FGoo000;Ool20004Ool00`00Oomoo`02Ool30003
Ool00`00Oomoo`0EOol00`00Oomoo`1JOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol05Goo00<007ooOol0FWoo000:Ool01000Oomoo`002goo00<007ooOol00P005Goo00<0
07ooOol0Fgoo000:Ool01000Oomoo`002goo00@007ooOol001Ioo`03001oogoo05]oo`002Woo00@0
07ooOol000Moo`@000=oo`03001oogoo01=oo`03001oogoo05aoo`002Woo00@007ooOol000Moo`03
001oogoo00Aoo`8001Aoo`03001oogoo05aoo`002goo0P0027oo1@000Woo00<007ooOol04Woo00<0
07ooOol0GGoo000LOol00`00Oomoo`0AOol2001OOol001aoo`80019oo`03001oogoo05ioo`0077oo
00<007ooOol047oo0P00H7oo000LOol2000AOol00`00Oomoo`1OOol001aoo`03001oogoo00moo`03
001oogoo061oo`0077oo00<007ooOol03goo00<007ooOol0H7oo000LOol2000?Ool00`00Oomoo`1Q
Ool001Ioo`<000=oo`03001oogoo00eoo`8006=oo`005goo00<007ooOol00Woo00<007ooOol03Goo
00<007ooOol0HWoo000GOol00`00Oomoo`02OolA001TOol001Moo`03001oogoo009oo`03001oogoo
079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001o
ogoo009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo
00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00
Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<0
07ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001o
ogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(26887\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29837 m
.008 .30126 L
.012 .30125 L
.016 .29801 L
.02 .29388 L
.024 .29106 L
.028 .29127 L
.032 .29449 L
.036 .29914 L
.04 .30367 L
.044 .30591 L
.048 .30671 L
.052 .30588 L
.056 .30213 L
.06 .29671 L
.064 .29173 L
.068 .28967 L
.072 .29067 L
.076 .29333 L
.08 .29583 L
.084 .29736 L
.088 .29893 L
.092 .30035 L
.096 .30126 L
.1 .30126 L
.104 .29938 L
.108 .29588 L
.112 .29218 L
.116 .29065 L
.12 .29322 L
.124 .2989 L
.128 .30393 L
.132 .30545 L
.136 .30338 L
.14 .29976 L
.144 .297 L
.148 .29552 L
.152 .29462 L
.156 .29457 L
.16 .29693 L
.164 .3028 L
.168 .31105 L
.172 .31864 L
.176 .32254 L
.18 .32241 L
.184 .32066 L
.188 .32034 L
.192 .32296 L
.196 .3277 L
.2 .33248 L
Mistroke
.204 .33591 L
.208 .33807 L
.212 .3398 L
.216 .34165 L
.22 .34302 L
.224 .34269 L
.228 .34 L
.232 .33556 L
.236 .3312 L
.24 .32893 L
.244 .32984 L
.248 .33355 L
.252 .33862 L
.256 .34329 L
.26 .34649 L
.264 .34806 L
.268 .34857 L
.272 .34889 L
.276 .34972 L
.28 .35145 L
.284 .35423 L
.288 .35806 L
.292 .36274 L
.296 .36773 L
.3 .37207 L
.304 .37448 L
.308 .37379 L
.312 .36945 L
.316 .36183 L
.32 .35216 L
.324 .34204 L
.328 .33278 L
.332 .32495 L
.336 .31826 L
.34 .31199 L
.344 .30557 L
.348 .29897 L
.352 .29278 L
.356 .28785 L
.36 .28478 L
.364 .28359 L
.368 .28372 L
.372 .2844 L
.376 .28505 L
.38 .28551 L
.384 .28606 L
.388 .28703 L
.392 .28855 L
.396 .29037 L
.4 .292 L
Mistroke
.404 .29298 L
.408 .29311 L
.412 .29254 L
.416 .29163 L
.42 .29075 L
.424 .29004 L
.428 .28943 L
.432 .28875 L
.436 .28788 L
.44 .2869 L
.444 .28605 L
.448 .28563 L
.452 .28585 L
.456 .2867 L
.46 .28802 L
.464 .28956 L
.468 .29113 L
.472 .29265 L
.476 .29421 L
.48 .29595 L
.484 .29794 L
.488 .30012 L
.492 .30231 L
.496 .30431 L
.5 .30598 L
.504 .30736 L
.508 .3086 L
.512 .30987 L
.516 .31123 L
.52 .31258 L
.524 .3137 L
.528 .31445 L
.532 .31485 L
.536 .3151 L
.54 .31543 L
.544 .31595 L
.548 .31658 L
.552 .3171 L
.556 .31733 L
.56 .31727 L
.564 .31711 L
.568 .3171 L
.572 .31734 L
.576 .31769 L
.58 .31793 L
.584 .3179 L
.588 .31766 L
.592 .31742 L
.596 .31742 L
.6 .31767 L
Mistroke
.604 .318 L
.608 .31814 L
.612 .31799 L
.616 .31768 L
.62 .31746 L
.624 .31751 L
.628 .3178 L
.632 .31809 L
.636 .31813 L
.64 .31791 L
.644 .31762 L
.648 .31751 L
.652 .31767 L
.656 .31796 L
.66 .31813 L
.664 .31805 L
.668 .3178 L
.672 .3176 L
.676 .31762 L
.68 .31782 L
.684 .31803 L
.688 .31806 L
.692 .31792 L
.696 .31775 L
.7 .31771 L
.704 .31785 L
.708 .31801 L
.712 .31804 L
.716 .3179 L
.72 .31773 L
.724 .3177 L
.728 .31784 L
.732 .31804 L
.736 .31812 L
.74 .31802 L
.744 .31784 L
.748 .31773 L
.752 .31778 L
.756 .31793 L
.76 .31802 L
.764 .31801 L
.768 .31792 L
.772 .31788 L
.776 .31793 L
.78 .31803 L
.784 .31805 L
.788 .31795 L
.792 .3178 L
.796 .31775 L
.8 .31787 L
Mistroke
.804 .31809 L
.808 .31823 L
.812 .31819 L
.816 .31798 L
.82 .31777 L
.824 .31771 L
.828 .31782 L
.832 .31802 L
.836 .31817 L
.84 .3182 L
.844 .31813 L
.848 .31802 L
.852 .31791 L
.856 .31782 L
.86 .31781 L
.864 .31791 L
.868 .3181 L
.872 .31828 L
.876 .31832 L
.88 .31814 L
.884 .31788 L
.888 .3177 L
.892 .31774 L
.896 .318 L
.9 .31827 L
.904 .31838 L
.908 .31828 L
.912 .31804 L
.916 .31784 L
.92 .31778 L
.924 .31788 L
.928 .31808 L
.932 .31827 L
.936 .31836 L
.94 .31829 L
.944 .31808 L
.948 .31787 L
.952 .31778 L
.956 .31789 L
.96 .31817 L
.964 .31838 L
.968 .31841 L
.972 .31827 L
.976 .31799 L
.98 .31783 L
.984 .31786 L
.988 .318 L
.992 .31824 L
.996 .3184 L
1 .31841 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .58744 m
.008 .58556 L
.012 .58513 L
.016 .58597 L
.02 .58612 L
.024 .58575 L
.028 .58592 L
.032 .58624 L
.036 .58638 L
.04 .58633 L
.044 .58644 L
.048 .58659 L
.052 .58655 L
.056 .58625 L
.06 .58602 L
.064 .58591 L
.068 .58596 L
.072 .58595 L
.076 .58581 L
.08 .58562 L
.084 .58572 L
.088 .58608 L
.092 .5864 L
.096 .58642 L
.1 .58607 L
.104 .58551 L
.108 .58522 L
.112 .58537 L
.116 .58584 L
.12 .58623 L
.124 .5861 L
.128 .58541 L
.132 .58464 L
.136 .58434 L
.14 .58485 L
.144 .58607 L
.148 .5876 L
.152 .58905 L
.156 .59013 L
.16 .59054 L
.164 .58999 L
.168 .58822 L
.172 .58523 L
.176 .58129 L
.18 .57682 L
.184 .57208 L
.188 .56712 L
.192 .56183 L
.196 .55619 L
.2 .55034 L
Mistroke
.204 .54459 L
.208 .53913 L
.212 .53393 L
.216 .52875 L
.22 .52329 L
.224 .51744 L
.228 .5113 L
.232 .50513 L
.236 .49915 L
.24 .49342 L
.244 .48777 L
.248 .48196 L
.252 .47577 L
.256 .46922 L
.26 .4625 L
.264 .45592 L
.268 .44977 L
.272 .4442 L
.276 .43913 L
.28 .43431 L
.284 .4294 L
.288 .4241 L
.292 .41821 L
.296 .41171 L
.3 .40471 L
.304 .39748 L
.308 .3903 L
.312 .38345 L
.316 .37716 L
.32 .37157 L
.324 .36672 L
.328 .36259 L
.332 .3591 L
.336 .35612 L
.34 .35353 L
.344 .35121 L
.348 .34906 L
.352 .34699 L
.356 .34494 L
.36 .34289 L
.364 .34082 L
.368 .33873 L
.372 .33662 L
.376 .33452 L
.38 .33245 L
.384 .33043 L
.388 .32848 L
.392 .32663 L
.396 .32486 L
.4 .32316 L
Mistroke
.404 .32151 L
.408 .31987 L
.412 .31822 L
.416 .31652 L
.42 .31475 L
.424 .31289 L
.428 .31094 L
.432 .30888 L
.436 .30674 L
.44 .30451 L
.444 .30222 L
.448 .29987 L
.452 .2975 L
.456 .29511 L
.46 .29273 L
.464 .29039 L
.468 .2881 L
.472 .2859 L
.476 .28381 L
.48 .28186 L
.484 .28004 L
.488 .27837 L
.492 .27685 L
.496 .27547 L
.5 .27423 L
.504 .27311 L
.508 .27213 L
.512 .27126 L
.516 .2705 L
.52 .26985 L
.524 .26929 L
.528 .26882 L
.532 .26843 L
.536 .2681 L
.54 .26783 L
.544 .26759 L
.548 .26739 L
.552 .26721 L
.556 .26707 L
.56 .26695 L
.564 .26686 L
.568 .26678 L
.572 .26671 L
.576 .26666 L
.58 .26661 L
.584 .26657 L
.588 .26653 L
.592 .26649 L
.596 .26645 L
.6 .26642 L
Mistroke
.604 .26639 L
.608 .26636 L
.612 .26634 L
.616 .26632 L
.62 .2663 L
.624 .26627 L
.628 .26625 L
.632 .26623 L
.636 .2662 L
.64 .26618 L
.644 .26615 L
.648 .26613 L
.652 .2661 L
.656 .26608 L
.66 .26607 L
.664 .26605 L
.668 .26602 L
.672 .266 L
.676 .26597 L
.68 .26595 L
.684 .26592 L
.688 .2659 L
.692 .26588 L
.696 .26586 L
.7 .26584 L
.704 .26582 L
.708 .26579 L
.712 .26577 L
.716 .26575 L
.72 .26572 L
.724 .2657 L
.728 .26567 L
.732 .26565 L
.736 .26563 L
.74 .26561 L
.744 .26559 L
.748 .26557 L
.752 .26554 L
.756 .26552 L
.76 .26549 L
.764 .26547 L
.768 .26545 L
.772 .26543 L
.776 .26541 L
.78 .26539 L
.784 .26536 L
.788 .26534 L
.792 .26531 L
.796 .26529 L
.8 .26527 L
Mistroke
.804 .26525 L
.808 .26523 L
.812 .26521 L
.816 .26518 L
.82 .26516 L
.824 .26513 L
.828 .26511 L
.832 .26509 L
.836 .26507 L
.84 .26505 L
.844 .26502 L
.848 .265 L
.852 .26498 L
.856 .26495 L
.86 .26493 L
.864 .26491 L
.868 .26488 L
.872 .26486 L
.876 .26484 L
.88 .26482 L
.884 .2648 L
.888 .26477 L
.892 .26475 L
.896 .26472 L
.9 .2647 L
.904 .26468 L
.908 .26466 L
.912 .26464 L
.916 .26462 L
.92 .26459 L
.924 .26457 L
.928 .26455 L
.932 .26452 L
.936 .2645 L
.94 .26448 L
.944 .26446 L
.948 .26444 L
.952 .26441 L
.956 .26439 L
.96 .26436 L
.964 .26435 L
.968 .26432 L
.972 .2643 L
.976 .26428 L
.98 .26426 L
.984 .26423 L
.988 .26421 L
.992 .26418 L
.996 .26417 L
1 .26414 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42416 L
.012 .42962 L
.016 .43149 L
.02 .42946 L
.024 .42874 L
.028 .4293 L
.032 .42962 L
.036 .42946 L
.04 .42951 L
.044 .42976 L
.048 .43008 L
.052 .43025 L
.056 .4302 L
.06 .42995 L
.064 .42992 L
.068 .42996 L
.072 .42981 L
.076 .42932 L
.08 .4289 L
.084 .42875 L
.088 .42897 L
.092 .42929 L
.096 .4293 L
.1 .42886 L
.104 .42833 L
.108 .42803 L
.112 .42831 L
.116 .42898 L
.12 .42947 L
.124 .42928 L
.128 .42841 L
.132 .42735 L
.136 .42692 L
.14 .42747 L
.144 .42888 L
.148 .4307 L
.152 .43241 L
.156 .43367 L
.16 .43413 L
.164 .43343 L
.168 .43125 L
.172 .42756 L
.176 .42271 L
.18 .41716 L
.184 .41126 L
.188 .40504 L
.192 .3984 L
.196 .39129 L
.2 .38394 L
Mistroke
.204 .37671 L
.208 .36985 L
.212 .36334 L
.216 .35686 L
.22 .35004 L
.224 .34274 L
.228 .33507 L
.232 .32738 L
.236 .31995 L
.24 .31283 L
.244 .30582 L
.248 .29858 L
.252 .29088 L
.256 .28269 L
.26 .27427 L
.264 .26601 L
.268 .2583 L
.272 .25131 L
.276 .24496 L
.28 .23897 L
.284 .23289 L
.288 .22635 L
.292 .21907 L
.296 .21101 L
.3 .20233 L
.304 .19331 L
.308 .18433 L
.312 .17575 L
.316 .16787 L
.32 .16087 L
.324 .15482 L
.328 .1497 L
.332 .14539 L
.336 .14174 L
.34 .13858 L
.344 .13575 L
.348 .13311 L
.352 .13055 L
.356 .128 L
.36 .12541 L
.364 .12279 L
.368 .12014 L
.372 .11751 L
.376 .11492 L
.38 .11241 L
.384 .10998 L
.388 .10764 L
.392 .10538 L
.396 .10319 L
.4 .10107 L
Mistroke
.404 .09898 L
.408 .09691 L
.412 .09484 L
.416 .09273 L
.42 .09056 L
.424 .0883 L
.428 .08593 L
.432 .08344 L
.436 .08082 L
.44 .07808 L
.444 .07523 L
.448 .0723 L
.452 .06933 L
.456 .06635 L
.46 .0634 L
.464 .06052 L
.468 .05773 L
.472 .05506 L
.476 .05252 L
.48 .05012 L
.484 .04788 L
.488 .04581 L
.492 .04392 L
.496 .0422 L
.5 .04067 L
.504 .03932 L
.508 .03814 L
.512 .03711 L
.516 .03623 L
.52 .03546 L
.524 .03481 L
.528 .03425 L
.532 .03377 L
.536 .03337 L
.54 .03305 L
.544 .03278 L
.548 .03258 L
.552 .03241 L
.556 .03228 L
.56 .03218 L
.564 .03209 L
.568 .03202 L
.572 .03197 L
.576 .03193 L
.58 .03189 L
.584 .03187 L
.588 .03185 L
.592 .03185 L
.596 .03185 L
.6 .03185 L
Mistroke
.604 .03185 L
.608 .03185 L
.612 .03185 L
.616 .03185 L
.62 .03185 L
.624 .03185 L
.628 .03186 L
.632 .03187 L
.636 .03187 L
.64 .03188 L
.644 .03189 L
.648 .0319 L
.652 .0319 L
.656 .03191 L
.66 .03191 L
.664 .03191 L
.668 .03191 L
.672 .03192 L
.676 .03193 L
.68 .03194 L
.684 .03195 L
.688 .03195 L
.692 .03196 L
.696 .03196 L
.7 .03197 L
.704 .03197 L
.708 .03198 L
.712 .03198 L
.716 .03199 L
.72 .032 L
.724 .03201 L
.728 .03202 L
.732 .03202 L
.736 .03202 L
.74 .03203 L
.744 .03203 L
.748 .03204 L
.752 .03205 L
.756 .03206 L
.76 .03207 L
.764 .03207 L
.768 .03208 L
.772 .03208 L
.776 .03209 L
.78 .03209 L
.784 .0321 L
.788 .0321 L
.792 .03211 L
.796 .03212 L
.8 .03213 L
Mistroke
.804 .03213 L
.808 .03214 L
.812 .03214 L
.816 .03215 L
.82 .03215 L
.824 .03216 L
.828 .03217 L
.832 .03218 L
.836 .03219 L
.84 .03219 L
.844 .03219 L
.848 .0322 L
.852 .0322 L
.856 .03221 L
.86 .03222 L
.864 .03223 L
.868 .03224 L
.872 .03224 L
.876 .03225 L
.88 .03225 L
.884 .03225 L
.888 .03226 L
.892 .03227 L
.896 .03228 L
.9 .03229 L
.904 .03229 L
.908 .0323 L
.912 .0323 L
.916 .03231 L
.92 .03231 L
.924 .03232 L
.928 .03233 L
.932 .03234 L
.936 .03234 L
.94 .03235 L
.944 .03235 L
.948 .03236 L
.952 .03236 L
.956 .03237 L
.96 .03238 L
.964 .03239 L
.968 .0324 L
.972 .03241 L
.976 .0324 L
.98 .03241 L
.984 .03241 L
.988 .03243 L
.992 .03243 L
.996 .03245 L
1 .03244 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo021oo`@000Aoo`<0045oo`008Woo10000Woo0`000Woo0P0000Aoo`000000015oo`04001o
ogooOol50002Ool3000oOol0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool20002Ool01@00Oomoogoo00000Woo00T007ooOomoo`00Ool007oo00000goo00D007ooOomo
o`0000=oo`03001oogoo034000aoo`008Woo0P003goo0`0017oo00<007ooOol01Goo00<007ooOol0
C7oo000ROol00`00Oomoo`0AOol2000017oo000000001Woo00<007ooOol0C7oo000ROol2000COol2
0002Ool30004Ool00`00Oomoo`1<Ool0029oo`8001Uoo`80009oo`03001oogoo04eoo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo00<007ooOol06Woo00<007oo0000Cgoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8001]oo`80051oo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]
Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007oo
Ool00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol0
00Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00
KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000
Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo0080
06eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P00
2Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo
000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0
009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=o
o`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`80
00=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo
00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00
Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo
0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo
0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@0
07ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@0
00=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@0
07ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo;P000goo00@007ooOol000Eo
o`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo1`000goo1@000goo
0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`0XOol2
000lOol002Qoo`03001oogoo02Ioo`8003ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00
Oomoo`0@Ool3000?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001o
ogoo01moo`<004Aoo`00:7oo00<007ooOol07Woo0P00AWoo000XOol00`00Oomoo`0LOol20018Ool0
02Qoo`03001oogoo01]oo`03001oogoo04Qoo`00:7oo00<007ooOol06Woo00<007ooOol0BGoo000;
Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0JOol00`00Oomoo`19
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00
6goo00<007ooOol0BWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool0
1000Oomoo`006Woo0P00C7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`02000IOol00`00Oomoo`1;Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00D007ooOol007oo00@000=oo`03001oogoo01Moo`03001oogoo04aoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo01Ioo`8004ioo`002goo0P002Woo
0P0017oo0P000Woo1@000Woo00<007ooOol05Woo00<007ooOol0CGoo000XOol00`00Oomoo`0EOol0
0`00Oomoo`1>Ool002Qoo`03001oogoo01Aoo`80051oo`004Goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo00<007ooOol04goo0P00DGoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo01=oo`03001oogoo051oo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`1AOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P004goo00<007ooOol0DGoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo015oo`03001oogoo059oo`0047oo00@007oo
Ool000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0@Ool00`00Oomoo`1COol0015oo`8000Yo
o`8000Aoo`03001oogoo009oo`03001oogoo00moo`8005Eoo`00:7oo00<007ooOol03goo00<007oo
Ool0E7oo000XOol00`00Oomoo`0>Ool00`00Oomoo`1EOol002Qoo`h0009oo`8005Moo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol02goo0P00FGoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009o
o`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00=7oo
=00037oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0<7oo0`00?goo000:Ool01000Oomo
o`001goo00<007ooOol017oo0P00;goo0P00@Woo000;Ool20008Ool50002Ool00`00Oomoo`0/Ool3
0013Ool001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000=oo`<000Eoo`<000=oo`<0
00Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D0
07ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`040002Ool00`00Oomo
o`03Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001o
ogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009o
o`03001oogoo00800005Ool007ooOol00005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol0
1goo00<007ooOol00Woo10000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool0
1000Oomoogoo0`0000Eoo`00Oomoo`00009oo`03001oogoo00=oo`04001oogooOol40003Ool01000
Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomo
o`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomo
o`0027oo0P000Woo0`000Woo00@007ooOol0009oo`03001oogoo009oo`8000=oo`03001oogoo00Ao
o`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00
Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`<000=oo`80
00Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003
Ool20006Ool001aoo`03001oogoo021oo`80051oo`0077oo00<007ooOol07goo0P00DGoo000LOomY
000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol0
0`00Oomoo`0MOol00`00Oomoo`1BOol001aoo`8001ioo`03001oogoo059oo`0077oo00<007ooOol0
7Goo00<007ooOol0DWoo000LOol00`00Oomoo`0LOol00`00Oomoo`1COol001aoo`8001aoo`03001o
ogoo05Aoo`0077oo00<007ooOol06goo00<007ooOol0E7oo000LOol00`00Oomoo`0JOol2001FOol0
01aoo`8001]oo`03001oogoo05Eoo`0077oo00<007ooOol06Goo00<007ooOol0EWoo000LOol2000J
Ool00`00Oomoo`1FOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo01Qoo`03001o
ogoo05Moo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0HOol00`00Oomo
o`1GOol000Yoo`04001oogoo000;Ool00`00Oomoo`02000HOol00`00Oomoo`1HOol000Yoo`04001o
ogoo000;Ool01000Oomoo`0067oo00<007ooOol0FGoo000:Ool01000Oomoo`001goo10000goo00<0
07ooOol05Woo00<007ooOol0FGoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P005Woo0P00
Fgoo000;Ool20008Ool50002Ool00`00Oomoo`0EOol00`00Oomoo`1JOol001aoo`03001oogoo01Ao
o`03001oogoo05]oo`0077oo0P005Goo00<007ooOol0Fgoo000LOol00`00Oomoo`0COol00`00Oomo
o`1LOol001aoo`8001Aoo`03001oogoo05aoo`0077oo00<007ooOol04Woo00<007ooOol0GGoo000L
Ool00`00Oomoo`0AOol00`00Oomoo`1NOol001aoo`80019oo`03001oogoo05ioo`005Woo0`000goo
00<007ooOol047oo00<007ooOol0Ggoo000GOol00`00Oomoo`02Ool2000@Ool2001QOol001Moo`03
001oogoo009ooa<0069oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02
Ool00`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001ao
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2
001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001o
ogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<0
07ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1b
Ool000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(27054\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .28928 m
.008 .29099 L
.012 .29388 L
.016 .29956 L
.02 .30538 L
.024 .30808 L
.028 .30641 L
.032 .30301 L
.036 .29896 L
.04 .29391 L
.044 .29003 L
.048 .28921 L
.052 .29204 L
.056 .29626 L
.06 .29975 L
.064 .30242 L
.068 .30387 L
.072 .30428 L
.076 .30286 L
.08 .29904 L
.084 .29469 L
.088 .29211 L
.092 .29235 L
.096 .29415 L
.1 .29639 L
.104 .29827 L
.108 .29935 L
.112 .30022 L
.116 .30096 L
.12 .30129 L
.124 .30022 L
.128 .2964 L
.132 .29093 L
.136 .28726 L
.14 .28855 L
.144 .29508 L
.148 .30335 L
.152 .30834 L
.156 .30781 L
.16 .30323 L
.164 .29765 L
.168 .29347 L
.172 .29133 L
.176 .2912 L
.18 .2935 L
.184 .29876 L
.188 .3061 L
.192 .31303 L
.196 .31708 L
.2 .31768 L
Mistroke
.204 .31702 L
.208 .3184 L
.212 .32356 L
.216 .33121 L
.22 .33805 L
.224 .34117 L
.228 .34026 L
.232 .33782 L
.236 .33716 L
.24 .3401 L
.244 .34562 L
.248 .35055 L
.252 .3517 L
.256 .34784 L
.26 .34057 L
.264 .33347 L
.268 .3301 L
.272 .33222 L
.276 .33902 L
.28 .34756 L
.284 .35444 L
.288 .35738 L
.292 .35621 L
.296 .35277 L
.3 .34983 L
.304 .34977 L
.308 .35351 L
.312 .36028 L
.316 .36815 L
.32 .37497 L
.324 .37923 L
.328 .38043 L
.332 .3789 L
.336 .37525 L
.34 .36997 L
.344 .36324 L
.348 .3551 L
.352 .34575 L
.356 .33575 L
.36 .32591 L
.364 .31703 L
.368 .3096 L
.372 .3036 L
.376 .29871 L
.38 .29452 L
.384 .29086 L
.388 .28784 L
.392 .28577 L
.396 .28488 L
.4 .28517 L
Mistroke
.404 .28629 L
.408 .28776 L
.412 .28918 L
.416 .29033 L
.42 .29125 L
.424 .2921 L
.428 .29297 L
.432 .29378 L
.436 .29432 L
.44 .29437 L
.444 .29383 L
.448 .29281 L
.452 .29155 L
.456 .29037 L
.46 .28948 L
.464 .28892 L
.468 .28864 L
.472 .28851 L
.476 .28851 L
.48 .28869 L
.484 .28921 L
.488 .29019 L
.492 .29161 L
.496 .29336 L
.5 .2952 L
.504 .29695 L
.508 .29858 L
.512 .30017 L
.516 .30187 L
.52 .30375 L
.524 .30569 L
.528 .30751 L
.532 .30901 L
.536 .31017 L
.54 .31109 L
.544 .31199 L
.548 .31298 L
.552 .314 L
.556 .31487 L
.56 .31545 L
.564 .31574 L
.568 .31591 L
.572 .31617 L
.576 .3166 L
.58 .31708 L
.584 .31741 L
.588 .31747 L
.592 .31733 L
.596 .3172 L
.6 .31726 L
Mistroke
.604 .31753 L
.608 .31783 L
.612 .31795 L
.616 .31782 L
.62 .31758 L
.624 .31746 L
.628 .31757 L
.632 .31783 L
.636 .31802 L
.64 .31798 L
.644 .31776 L
.648 .31756 L
.652 .31755 L
.656 .31774 L
.66 .31795 L
.664 .31801 L
.668 .31788 L
.672 .31769 L
.676 .31761 L
.68 .31773 L
.684 .31793 L
.688 .31802 L
.692 .31791 L
.696 .3177 L
.7 .31758 L
.704 .31768 L
.708 .31792 L
.712 .3181 L
.716 .31807 L
.72 .31785 L
.724 .31765 L
.728 .31761 L
.732 .31775 L
.736 .31794 L
.74 .31803 L
.744 .31799 L
.748 .31789 L
.752 .31783 L
.756 .31783 L
.76 .31786 L
.764 .31785 L
.768 .31781 L
.772 .31782 L
.776 .3179 L
.78 .31803 L
.784 .31809 L
.788 .31801 L
.792 .31783 L
.796 .31769 L
.8 .31771 L
Mistroke
.804 .31788 L
.808 .31808 L
.812 .31814 L
.816 .31804 L
.82 .31788 L
.824 .31779 L
.828 .31783 L
.832 .31793 L
.836 .31799 L
.84 .31799 L
.844 .31796 L
.848 .31796 L
.852 .31799 L
.856 .318 L
.86 .31798 L
.864 .31793 L
.868 .3179 L
.872 .31794 L
.876 .31799 L
.88 .31802 L
.884 .31802 L
.888 .31801 L
.892 .31801 L
.896 .31803 L
.9 .31801 L
.904 .31796 L
.908 .31791 L
.912 .31793 L
.916 .31802 L
.92 .31813 L
.924 .31818 L
.928 .31812 L
.932 .31799 L
.936 .31789 L
.94 .31786 L
.944 .31795 L
.948 .3181 L
.952 .31819 L
.956 .31824 L
.96 .31818 L
.964 .31801 L
.968 .31789 L
.972 .31784 L
.976 .31793 L
.98 .31814 L
.984 .3183 L
.988 .31834 L
.992 .3182 L
.996 .31799 L
1 .31787 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .59407 m
.008 .58595 L
.012 .58324 L
.016 .58577 L
.02 .58661 L
.024 .58554 L
.028 .58512 L
.032 .58529 L
.036 .58532 L
.04 .58506 L
.044 .58504 L
.048 .58519 L
.052 .58538 L
.056 .58544 L
.06 .58558 L
.064 .5858 L
.068 .58608 L
.072 .58622 L
.076 .58613 L
.08 .5859 L
.084 .58582 L
.088 .58586 L
.092 .58584 L
.096 .58559 L
.1 .58528 L
.104 .58507 L
.108 .58519 L
.112 .58556 L
.116 .58587 L
.12 .58584 L
.124 .58546 L
.128 .58495 L
.132 .58478 L
.136 .58511 L
.14 .58568 L
.144 .58602 L
.148 .58576 L
.152 .58498 L
.156 .58417 L
.16 .5838 L
.164 .58411 L
.168 .58502 L
.172 .58635 L
.176 .58787 L
.18 .5893 L
.184 .59024 L
.188 .59026 L
.192 .58908 L
.196 .58669 L
.2 .58337 L
Mistroke
.204 .57947 L
.208 .57517 L
.212 .57045 L
.216 .56525 L
.22 .55963 L
.224 .5538 L
.228 .5481 L
.232 .5427 L
.236 .53755 L
.24 .5324 L
.244 .52698 L
.248 .52118 L
.252 .51511 L
.256 .50901 L
.26 .50309 L
.264 .49741 L
.268 .4918 L
.272 .48604 L
.276 .47993 L
.28 .47342 L
.284 .46669 L
.288 .46003 L
.292 .45373 L
.296 .44797 L
.3 .44274 L
.304 .43786 L
.308 .43303 L
.312 .42792 L
.316 .42229 L
.32 .41607 L
.324 .4093 L
.328 .40217 L
.332 .39494 L
.336 .3879 L
.34 .38129 L
.344 .37528 L
.348 .36998 L
.352 .3654 L
.356 .36148 L
.36 .35815 L
.364 .35529 L
.368 .35278 L
.372 .35051 L
.376 .34839 L
.38 .34632 L
.384 .34426 L
.388 .34218 L
.392 .34007 L
.396 .33794 L
.4 .33581 L
Mistroke
.404 .33371 L
.408 .33167 L
.412 .3297 L
.416 .32781 L
.42 .32601 L
.424 .32428 L
.428 .32261 L
.432 .32096 L
.436 .31931 L
.44 .31762 L
.444 .31589 L
.448 .31408 L
.452 .31219 L
.456 .31022 L
.46 .30816 L
.464 .306 L
.468 .30376 L
.472 .30145 L
.476 .29909 L
.48 .29669 L
.484 .29429 L
.488 .29191 L
.492 .28958 L
.496 .28733 L
.5 .28518 L
.504 .28315 L
.508 .28125 L
.512 .27948 L
.516 .27785 L
.52 .27636 L
.524 .27501 L
.528 .27379 L
.532 .27272 L
.536 .27177 L
.54 .27095 L
.544 .27023 L
.548 .26962 L
.552 .26909 L
.556 .26864 L
.56 .26826 L
.564 .26794 L
.568 .26766 L
.572 .26743 L
.576 .26724 L
.58 .26708 L
.584 .26695 L
.588 .26685 L
.592 .26676 L
.596 .26668 L
.6 .26661 L
Mistroke
.604 .26656 L
.608 .2665 L
.612 .26646 L
.616 .26642 L
.62 .26639 L
.624 .26635 L
.628 .26632 L
.632 .2663 L
.636 .26627 L
.64 .26625 L
.644 .26623 L
.648 .2662 L
.652 .26617 L
.656 .26615 L
.66 .26612 L
.664 .2661 L
.668 .26608 L
.672 .26606 L
.676 .26604 L
.68 .26602 L
.684 .26599 L
.688 .26597 L
.692 .26595 L
.696 .26592 L
.7 .2659 L
.704 .26587 L
.708 .26585 L
.712 .26583 L
.716 .26581 L
.72 .26579 L
.724 .26577 L
.728 .26574 L
.732 .26572 L
.736 .26569 L
.74 .26567 L
.744 .26565 L
.748 .26563 L
.752 .26561 L
.756 .26559 L
.76 .26556 L
.764 .26554 L
.768 .26551 L
.772 .26549 L
.776 .26547 L
.78 .26545 L
.784 .26543 L
.788 .26541 L
.792 .26538 L
.796 .26536 L
.8 .26533 L
Mistroke
.804 .26531 L
.808 .26529 L
.812 .26527 L
.816 .26525 L
.82 .26522 L
.824 .2652 L
.828 .26518 L
.832 .26515 L
.836 .26513 L
.84 .26511 L
.844 .26508 L
.848 .26506 L
.852 .26504 L
.856 .26502 L
.86 .265 L
.864 .26498 L
.868 .26495 L
.872 .26493 L
.876 .2649 L
.88 .26488 L
.884 .26486 L
.888 .26484 L
.892 .26482 L
.896 .26479 L
.9 .26477 L
.904 .26475 L
.908 .26472 L
.912 .2647 L
.916 .26468 L
.92 .26466 L
.924 .26464 L
.928 .26461 L
.932 .26459 L
.936 .26457 L
.94 .26454 L
.944 .26452 L
.948 .2645 L
.952 .26448 L
.956 .26446 L
.96 .26443 L
.964 .26441 L
.968 .26439 L
.972 .26437 L
.976 .26434 L
.98 .26432 L
.984 .26429 L
.988 .26428 L
.992 .26425 L
.996 .26424 L
1 .2642 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43067 L
.012 .42945 L
.016 .42935 L
.02 .42982 L
.024 .42986 L
.028 .42964 L
.032 .42975 L
.036 .4298 L
.04 .42971 L
.044 .4295 L
.048 .42948 L
.052 .42945 L
.056 .42935 L
.06 .42919 L
.064 .42932 L
.068 .42964 L
.072 .42983 L
.076 .42974 L
.08 .42963 L
.084 .42962 L
.088 .42974 L
.092 .42975 L
.096 .42948 L
.1 .429 L
.104 .42872 L
.108 .42879 L
.112 .42915 L
.116 .42945 L
.12 .42933 L
.124 .42871 L
.128 .42804 L
.132 .42775 L
.136 .42813 L
.14 .42887 L
.144 .4293 L
.148 .42901 L
.152 .4281 L
.156 .42709 L
.16 .42662 L
.164 .42695 L
.168 .42802 L
.172 .4296 L
.176 .43142 L
.18 .43313 L
.184 .43425 L
.188 .43424 L
.192 .43273 L
.196 .42971 L
.2 .42556 L
Mistroke
.204 .42068 L
.208 .41531 L
.212 .40944 L
.216 .40297 L
.22 .39595 L
.224 .38869 L
.228 .38155 L
.232 .37478 L
.236 .3683 L
.24 .36182 L
.244 .355 L
.248 .34772 L
.252 .34012 L
.256 .33252 L
.26 .32517 L
.264 .31813 L
.268 .3112 L
.272 .30405 L
.276 .29642 L
.28 .28829 L
.284 .27984 L
.288 .27147 L
.292 .26356 L
.296 .25635 L
.3 .24983 L
.304 .24376 L
.308 .23777 L
.312 .23146 L
.316 .2245 L
.32 .21678 L
.324 .20836 L
.328 .19947 L
.332 .19043 L
.336 .18162 L
.34 .17333 L
.344 .16582 L
.348 .15921 L
.352 .15353 L
.356 .14872 L
.36 .14465 L
.364 .14116 L
.368 .13807 L
.372 .13525 L
.376 .13258 L
.38 .12997 L
.384 .12737 L
.388 .12476 L
.392 .12215 L
.396 .11953 L
.4 .11694 L
Mistroke
.404 .11439 L
.408 .11189 L
.412 .10948 L
.416 .10715 L
.42 .1049 L
.424 .10273 L
.428 .10063 L
.432 .09857 L
.436 .09653 L
.44 .09447 L
.444 .09236 L
.448 .09018 L
.452 .08788 L
.456 .08545 L
.46 .08289 L
.464 .08021 L
.468 .07741 L
.472 .07453 L
.476 .0716 L
.48 .06865 L
.484 .0657 L
.488 .06279 L
.492 .05994 L
.496 .05718 L
.5 .05453 L
.504 .05202 L
.508 .04965 L
.512 .04746 L
.516 .04545 L
.52 .04363 L
.524 .04199 L
.528 .04053 L
.532 .03924 L
.536 .0381 L
.54 .0371 L
.544 .03624 L
.548 .03549 L
.552 .03486 L
.556 .03433 L
.56 .03388 L
.564 .03352 L
.568 .03322 L
.572 .03298 L
.576 .03278 L
.58 .03262 L
.584 .03249 L
.588 .03238 L
.592 .03229 L
.596 .03223 L
.6 .03218 L
Mistroke
.604 .03215 L
.608 .03212 L
.612 .0321 L
.616 .03209 L
.62 .03208 L
.624 .03208 L
.628 .03208 L
.632 .03208 L
.636 .03207 L
.64 .03207 L
.644 .03207 L
.648 .03208 L
.652 .03209 L
.656 .0321 L
.66 .03211 L
.664 .03211 L
.668 .03211 L
.672 .03212 L
.676 .03212 L
.68 .03213 L
.684 .03213 L
.688 .03214 L
.692 .03215 L
.696 .03215 L
.7 .03216 L
.704 .03217 L
.708 .03218 L
.712 .03218 L
.716 .03218 L
.72 .03218 L
.724 .03219 L
.728 .0322 L
.732 .03221 L
.736 .03222 L
.74 .03222 L
.744 .03223 L
.748 .03223 L
.752 .03224 L
.756 .03224 L
.76 .03225 L
.764 .03226 L
.768 .03227 L
.772 .03228 L
.776 .03228 L
.78 .03229 L
.784 .03229 L
.788 .03229 L
.792 .0323 L
.796 .03231 L
.8 .03232 L
Mistroke
.804 .03233 L
.808 .03233 L
.812 .03234 L
.816 .03234 L
.82 .03234 L
.824 .03235 L
.828 .03236 L
.832 .03237 L
.836 .03237 L
.84 .03238 L
.844 .03239 L
.848 .03239 L
.852 .0324 L
.856 .0324 L
.86 .03241 L
.864 .03241 L
.868 .03242 L
.872 .03243 L
.876 .03244 L
.88 .03244 L
.884 .03245 L
.888 .03245 L
.892 .03246 L
.896 .03247 L
.9 .03248 L
.904 .03248 L
.908 .03249 L
.912 .03249 L
.916 .0325 L
.92 .0325 L
.924 .03251 L
.928 .03252 L
.932 .03253 L
.936 .03253 L
.94 .03254 L
.944 .03254 L
.948 .03255 L
.952 .03255 L
.956 .03256 L
.96 .03257 L
.964 .03258 L
.968 .03258 L
.972 .03259 L
.976 .03259 L
.98 .0326 L
.984 .0326 L
.988 .03262 L
.992 .03262 L
.996 .03263 L
1 .03263 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo00Yoo`03001oogoo01Ioo`<004Ioo`008Woo0P000Woo0`0000Aoo`000000009oo`800004
Ool00000000BOol200000goo00000009000lOol0029oof<000aoo`008Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool00`00Oomoo`020003Ool01000Oomoo`000goo00@007ooOomoo`80009o
o`05001oogooOol00003Ool01000Oomoogoo<00037oo000ROol2000COol00`00Oomoo`0;Ool00`00
Oomoo`19Ool0029oo`03001oogoo019oo`<0009oo`8000Moo`03001oogoo04Uoo`008Woo0P0057oo
00L007oo000007oo001oo`020003Ool00`00Oomoo`1:Ool0029oo`8001Ioo`80009oo`@0009oo`03
001oogoo04Yoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol077oo00@0
07oo000004aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000MOol3
001=Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/
Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool0
1000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`80
00Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03
Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001o
ogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04
001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00
Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yo
o`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;
Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool50002
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool2
0007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool5
0002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo
00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06
001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001o
ogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001o
ogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03
001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomo
o`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo
00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009o
o`800003Ool0000002T000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qo
o`03001oogoo00=oo`8000Aoo`8000=oo`@00003Ool0000000<000=oo`8000=oo`<000Aoo`8000Ao
o`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0:Woo0`00>Goo000XOol00`00Oomo
o`0XOol3000kOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007oo0000
0P003Goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`0ROol3
0011Ool002Qoo`03001oogoo021oo`<004=oo`00:7oo00<007ooOol07Woo0`00AGoo000XOol00`00
Oomoo`0MOol20017Ool002Qoo`03001oogoo01eoo`03001oogoo04Ioo`002goo0P0017oo00<007oo
Ool00goo0P0017oo0P000goo0`000goo00<007ooOol077oo00<007ooOol0Agoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol001eoo`03001oogoo04Qo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol001eoo`03
001oogoo04Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool00P006goo00<007ooOol0BGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo
001oo`040003Ool00`00Oomoo`0IOol2001;Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0006Ool00`00Oomoo`0IOol00`00Oomoo`1:Ool000]oo`8000Yoo`8000Aoo`80
009oo`D0009oo`03001oogoo01Qoo`03001oogoo04]oo`00:7oo00<007ooOol05goo00<007ooOol0
C7oo000XOol00`00Oomoo`0GOol00`00Oomoo`1<Ool0015oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`03001oogoo01Ioo`03001oogoo04eoo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`0EOol2001?Ool0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol05Goo00<007ooOol0CWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8001Eoo`03001oogoo04moo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0COol2001AOol0011oo`04001oogoo0008Ool0
1000Oomoo`000Woo0P0017oo00<007ooOol04Woo0P00DWoo000AOol2000:Ool20004Ool00`00Oomo
o`02Ool00`00Oomoo`0BOol00`00Oomoo`1AOol002Qoo`03001oogoo015oo`03001oogoo059oo`00
:7oo00<007ooOol047oo0P00E7oo000XOolA00000goo0000001EOol000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`<000=oo`03001oogoo00eoo`<005Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<0
07ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`00
2goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol003Mooc4000aoo`002Woo
00@007ooOol000Moo`@000=oo`03001oogoo03=oo`<003aoo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`80039oo`8003moo`002goo0P0027oo1@000Woo00<007ooOol0;goo0P00@Goo000LOol0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool40003Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002
Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`@000Eoo`05001oogooOol00003
Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomo
o`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`800003
Ool007oo00Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Oomoo`040002Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo
00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomo
o`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo
00@007oo0000009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@0
07ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`@0
009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`00
1Goo000LOol2000=Ool50003Ool2000:Ool01000Oomoogoo100017oo0P001Woo00@007ooOomoo`D0
00=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0
8goo0P00CGoo000LOol00`00Oomoo`0ROol00`00Oomoo`1=Ool001aoofT000aoo`0077oo00D007oo
Oomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`00009oo`8000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo021oo`03001oogoo04mo
o`0077oo0P008Goo00<007ooOol0Cgoo000LOol00`00Oomoo`0OOol00`00Oomoo`1@Ool001aoo`03
001oogoo01moo`03001oogoo051oo`0077oo0P007goo00<007ooOol0DGoo000LOol00`00Oomoo`0N
Ool00`00Oomoo`1AOol001aoo`03001oogoo01eoo`03001oogoo059oo`0077oo0P007Goo0P00E7oo
000LOol00`00Oomoo`0LOol00`00Oomoo`1COol001aoo`8001aoo`03001oogoo05Aoo`002goo0P00
17oo00<007ooOol00Woo0`000goo00<007ooOol06goo00<007ooOol0E7oo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo01Yoo`8005Ioo`002Woo00@007ooOol000]oo`03001o
ogoo008001]oo`03001oogoo05Eoo`002Woo00@007ooOol000]oo`04001oogoo000KOol00`00Oomo
o`1FOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0IOol00`00Oomoo`1FOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool2000IOol00`00Oomoo`1GOol000]oo`8000Qoo`D0009oo`03
001oogoo01Qoo`03001oogoo05Moo`0077oo00<007ooOol05goo00<007ooOol0F7oo000LOol2000G
Ool2001JOol001aoo`03001oogoo01Ioo`03001oogoo05Uoo`0077oo0P005Woo0P00Fgoo000LOol0
0`00Oomoo`0EOol00`00Oomoo`1JOol001aoo`03001oogoo01Aoo`03001oogoo05]oo`0077oo0P00
5Goo00<007ooOol0Fgoo000FOol30003Ool00`00Oomoo`0COol00`00Oomoo`1LOol001Moo`03001o
ogoo009oo`03001oogoo019oo`8005ioo`005goo00<007ooOol00Woo5P00Ggoo000GOol00`00Oomo
o`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00
Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1b
Ool000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007oo
Oomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<0
07ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol0
00Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(27221\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3111 m
.008 .30681 L
.012 .30038 L
.016 .29523 L
.02 .29281 L
.024 .29067 L
.028 .28974 L
.032 .29145 L
.036 .29566 L
.04 .29957 L
.044 .30161 L
.048 .30274 L
.052 .30267 L
.056 .30114 L
.06 .29815 L
.064 .29469 L
.068 .29288 L
.072 .29345 L
.076 .29591 L
.08 .29837 L
.084 .30031 L
.088 .30262 L
.092 .30424 L
.096 .30354 L
.1 .29999 L
.104 .29506 L
.108 .29123 L
.112 .2903 L
.116 .29269 L
.12 .29674 L
.124 .30031 L
.128 .30159 L
.132 .30038 L
.136 .29877 L
.14 .29839 L
.144 .29904 L
.148 .29897 L
.152 .29653 L
.156 .2928 L
.16 .29083 L
.164 .29244 L
.168 .29656 L
.172 .30039 L
.176 .30177 L
.18 .30112 L
.184 .30029 L
.188 .30009 L
.192 .29955 L
.196 .29734 L
.2 .29378 L
Mistroke
.204 .29123 L
.208 .29239 L
.212 .29796 L
.216 .30601 L
.22 .31365 L
.224 .31902 L
.228 .32237 L
.232 .32527 L
.236 .32888 L
.24 .33297 L
.244 .33648 L
.248 .33861 L
.252 .3398 L
.256 .34144 L
.26 .34462 L
.264 .34917 L
.268 .35351 L
.272 .35558 L
.276 .3542 L
.28 .34977 L
.284 .34418 L
.288 .33982 L
.292 .33845 L
.296 .3405 L
.3 .34511 L
.304 .3506 L
.308 .35534 L
.312 .35821 L
.316 .35896 L
.32 .35811 L
.324 .35673 L
.328 .35611 L
.332 .35739 L
.336 .36116 L
.34 .36723 L
.344 .37457 L
.348 .38159 L
.352 .38658 L
.356 .38828 L
.36 .38623 L
.364 .38085 L
.368 .37308 L
.372 .36404 L
.376 .35456 L
.38 .3451 L
.384 .33581 L
.388 .32677 L
.392 .31818 L
.396 .31037 L
.4 .30373 L
Mistroke
.404 .29845 L
.408 .29453 L
.412 .29173 L
.416 .28976 L
.42 .28843 L
.424 .28768 L
.428 .28755 L
.432 .2881 L
.436 .28924 L
.44 .29076 L
.444 .29237 L
.448 .29375 L
.452 .29474 L
.456 .29527 L
.46 .29545 L
.464 .29538 L
.468 .29516 L
.472 .29477 L
.476 .29417 L
.48 .29332 L
.484 .29228 L
.488 .29127 L
.492 .29051 L
.496 .29019 L
.5 .29033 L
.504 .2908 L
.508 .29142 L
.512 .2921 L
.516 .2929 L
.52 .29397 L
.524 .29544 L
.528 .29724 L
.532 .29916 L
.536 .30097 L
.54 .30256 L
.544 .304 L
.548 .30546 L
.552 .30705 L
.556 .30871 L
.56 .31022 L
.564 .31139 L
.568 .31221 L
.572 .31286 L
.576 .31356 L
.58 .31439 L
.584 .31524 L
.588 .31591 L
.592 .31626 L
.596 .31636 L
.6 .31642 L
Mistroke
.604 .31664 L
.608 .31702 L
.612 .3174 L
.616 .31759 L
.62 .31753 L
.624 .31737 L
.628 .31732 L
.632 .31746 L
.636 .3177 L
.64 .31786 L
.644 .31784 L
.648 .31769 L
.652 .31757 L
.656 .31761 L
.66 .31776 L
.664 .31787 L
.668 .31785 L
.672 .31771 L
.676 .3176 L
.68 .31764 L
.684 .31781 L
.688 .31798 L
.692 .31798 L
.696 .3178 L
.7 .3176 L
.704 .31755 L
.708 .31768 L
.712 .31789 L
.716 .318 L
.72 .31794 L
.724 .31779 L
.728 .31769 L
.732 .31772 L
.736 .31781 L
.74 .31787 L
.744 .31784 L
.748 .31777 L
.752 .31776 L
.756 .31785 L
.76 .31795 L
.764 .31798 L
.768 .31789 L
.772 .31774 L
.776 .31766 L
.78 .31772 L
.784 .31788 L
.788 .31802 L
.792 .31804 L
.796 .31795 L
.8 .31783 L
Mistroke
.804 .31777 L
.808 .31778 L
.812 .31781 L
.816 .31785 L
.82 .3179 L
.824 .31797 L
.828 .31804 L
.832 .31804 L
.836 .31793 L
.84 .31776 L
.844 .31767 L
.848 .31774 L
.852 .31795 L
.856 .31814 L
.86 .31819 L
.864 .31805 L
.868 .31784 L
.872 .3177 L
.876 .31771 L
.88 .31785 L
.884 .31803 L
.888 .31815 L
.892 .31817 L
.896 .31806 L
.9 .31789 L
.904 .31775 L
.908 .31773 L
.912 .31786 L
.916 .31806 L
.92 .31823 L
.924 .31823 L
.928 .31806 L
.932 .31785 L
.936 .31773 L
.94 .31776 L
.944 .31796 L
.948 .31817 L
.952 .31827 L
.956 .31822 L
.96 .31803 L
.964 .31782 L
.968 .31774 L
.972 .31782 L
.976 .31805 L
.98 .31826 L
.984 .31834 L
.988 .31822 L
.992 .31795 L
.996 .31778 L
1 .31777 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .58473 m
.008 .58508 L
.012 .58517 L
.016 .58486 L
.02 .58507 L
.024 .58532 L
.028 .58538 L
.032 .58534 L
.036 .58542 L
.04 .58537 L
.044 .58532 L
.048 .58526 L
.052 .58522 L
.056 .58506 L
.06 .58491 L
.064 .5848 L
.068 .58483 L
.072 .58484 L
.076 .5848 L
.08 .58474 L
.084 .5849 L
.088 .58521 L
.092 .58547 L
.096 .58551 L
.1 .58547 L
.104 .58546 L
.108 .58557 L
.112 .58568 L
.116 .58558 L
.12 .58523 L
.124 .58484 L
.128 .58464 L
.132 .58481 L
.136 .58522 L
.14 .5855 L
.144 .58536 L
.148 .58486 L
.152 .58436 L
.156 .5843 L
.16 .58475 L
.164 .58534 L
.168 .58563 L
.172 .58536 L
.176 .58465 L
.18 .58389 L
.184 .58342 L
.188 .58344 L
.192 .58401 L
.196 .58511 L
.2 .58665 L
Mistroke
.204 .58832 L
.208 .58966 L
.212 .59016 L
.216 .58952 L
.22 .58775 L
.224 .58509 L
.228 .58179 L
.232 .57795 L
.236 .57353 L
.24 .5685 L
.244 .56298 L
.248 .55724 L
.252 .55162 L
.256 .54628 L
.26 .54117 L
.264 .53604 L
.268 .53065 L
.272 .52489 L
.276 .51887 L
.28 .51282 L
.284 .50696 L
.288 .50132 L
.292 .49578 L
.296 .49011 L
.3 .48408 L
.304 .47765 L
.308 .47093 L
.312 .4642 L
.316 .45775 L
.32 .4518 L
.324 .4464 L
.328 .44141 L
.332 .43659 L
.336 .43161 L
.34 .42623 L
.344 .42029 L
.348 .41379 L
.352 .40684 L
.356 .39965 L
.36 .39249 L
.364 .38562 L
.368 .37923 L
.372 .37349 L
.376 .36845 L
.38 .36411 L
.384 .36041 L
.388 .35726 L
.392 .35453 L
.396 .3521 L
.4 .34986 L
Mistroke
.404 .34773 L
.408 .34563 L
.412 .34353 L
.416 .3414 L
.42 .33926 L
.424 .33712 L
.428 .33501 L
.432 .33294 L
.436 .33095 L
.44 .32903 L
.444 .32719 L
.448 .32542 L
.452 .3237 L
.456 .32202 L
.46 .32036 L
.464 .31869 L
.468 .317 L
.472 .31525 L
.476 .31344 L
.48 .31154 L
.484 .30955 L
.488 .30745 L
.492 .30526 L
.496 .30298 L
.5 .30064 L
.504 .29825 L
.508 .29585 L
.512 .29346 L
.516 .29111 L
.52 .28881 L
.524 .2866 L
.528 .2845 L
.532 .2825 L
.536 .28064 L
.54 .2789 L
.544 .27731 L
.548 .27586 L
.552 .27455 L
.556 .27339 L
.56 .27236 L
.564 .27146 L
.568 .27067 L
.572 .26998 L
.576 .26939 L
.58 .26887 L
.584 .26844 L
.588 .26808 L
.592 .26777 L
.596 .26751 L
.6 .26729 L
Mistroke
.604 .26711 L
.608 .26696 L
.612 .26684 L
.616 .26674 L
.62 .26665 L
.624 .26657 L
.628 .26651 L
.632 .26645 L
.636 .2664 L
.64 .26636 L
.644 .26633 L
.648 .2663 L
.652 .26626 L
.656 .26623 L
.66 .26621 L
.664 .26618 L
.668 .26615 L
.672 .26613 L
.676 .2661 L
.68 .26608 L
.684 .26605 L
.688 .26603 L
.692 .26601 L
.696 .26599 L
.7 .26597 L
.704 .26594 L
.708 .26591 L
.712 .26589 L
.716 .26587 L
.72 .26585 L
.724 .26583 L
.728 .26581 L
.732 .26579 L
.736 .26576 L
.74 .26574 L
.744 .26571 L
.748 .26569 L
.752 .26567 L
.756 .26565 L
.76 .26563 L
.764 .26561 L
.768 .26558 L
.772 .26556 L
.776 .26553 L
.78 .26551 L
.784 .26549 L
.788 .26547 L
.792 .26545 L
.796 .26543 L
.8 .2654 L
Mistroke
.804 .26538 L
.808 .26535 L
.812 .26533 L
.816 .26531 L
.82 .26528 L
.824 .26526 L
.828 .26524 L
.832 .26522 L
.836 .2652 L
.84 .26518 L
.844 .26515 L
.848 .26513 L
.852 .2651 L
.856 .26508 L
.86 .26506 L
.864 .26504 L
.868 .26502 L
.872 .26499 L
.876 .26497 L
.88 .26495 L
.884 .26492 L
.888 .2649 L
.892 .26488 L
.896 .26486 L
.9 .26484 L
.904 .26481 L
.908 .26479 L
.912 .26477 L
.916 .26474 L
.92 .26472 L
.924 .2647 L
.928 .26468 L
.932 .26466 L
.936 .26463 L
.94 .26461 L
.944 .26459 L
.948 .26457 L
.952 .26454 L
.956 .26452 L
.96 .2645 L
.964 .26448 L
.968 .26445 L
.972 .26443 L
.976 .2644 L
.98 .26439 L
.984 .26436 L
.988 .26434 L
.992 .26432 L
.996 .2643 L
1 .26427 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43601 L
.012 .43028 L
.016 .42842 L
.02 .43028 L
.024 .43089 L
.028 .43003 L
.032 .42966 L
.036 .42968 L
.04 .42963 L
.044 .42939 L
.048 .42938 L
.052 .42945 L
.056 .42944 L
.06 .42926 L
.064 .42924 L
.068 .4293 L
.072 .42931 L
.076 .42914 L
.08 .42905 L
.084 .42914 L
.088 .42942 L
.092 .42964 L
.096 .42964 L
.1 .42946 L
.104 .4294 L
.108 .4295 L
.112 .42961 L
.116 .4295 L
.12 .42913 L
.124 .42865 L
.128 .42845 L
.132 .42867 L
.136 .42913 L
.14 .42943 L
.144 .42918 L
.148 .42846 L
.152 .42778 L
.156 .42765 L
.16 .42815 L
.164 .42886 L
.168 .42919 L
.172 .42881 L
.176 .42792 L
.18 .42696 L
.184 .42638 L
.188 .4264 L
.192 .4271 L
.196 .42846 L
.2 .43034 L
Mistroke
.204 .43239 L
.208 .43399 L
.212 .43454 L
.216 .43367 L
.22 .43139 L
.224 .42802 L
.228 .42387 L
.232 .41909 L
.236 .4136 L
.24 .40736 L
.244 .4005 L
.248 .39336 L
.252 .38633 L
.256 .37962 L
.26 .37317 L
.264 .36669 L
.268 .3599 L
.272 .35267 L
.276 .34516 L
.28 .33764 L
.284 .33037 L
.288 .32338 L
.292 .31651 L
.296 .30944 L
.3 .30193 L
.304 .29387 L
.308 .28545 L
.312 .277 L
.316 .26891 L
.32 .26146 L
.324 .25473 L
.328 .24854 L
.332 .24258 L
.336 .23645 L
.34 .22979 L
.344 .22241 L
.348 .21428 L
.352 .20557 L
.356 .19657 L
.36 .18761 L
.364 .17902 L
.368 .17109 L
.372 .16397 L
.376 .15775 L
.38 .1524 L
.384 .14784 L
.388 .14393 L
.392 .14053 L
.396 .13749 L
.4 .13468 L
Mistroke
.404 .132 L
.408 .12939 L
.412 .12678 L
.416 .12418 L
.42 .12157 L
.424 .11896 L
.428 .11637 L
.432 .11382 L
.436 .11133 L
.44 .10893 L
.444 .10663 L
.448 .10442 L
.452 .1023 L
.456 .10024 L
.46 .09822 L
.464 .09619 L
.468 .09412 L
.472 .09198 L
.476 .08974 L
.48 .08738 L
.484 .08489 L
.488 .08229 L
.492 .07958 L
.496 .07677 L
.5 .07389 L
.504 .07096 L
.508 .06801 L
.512 .06507 L
.516 .06216 L
.52 .05933 L
.524 .05659 L
.528 .05398 L
.532 .05152 L
.536 .04923 L
.54 .0471 L
.544 .04516 L
.548 .0434 L
.552 .04181 L
.556 .04039 L
.56 .03914 L
.564 .03803 L
.568 .03707 L
.572 .03624 L
.576 .03554 L
.58 .03495 L
.584 .03445 L
.588 .03403 L
.592 .03368 L
.596 .03339 L
.6 .03315 L
Mistroke
.604 .03296 L
.608 .03281 L
.612 .03268 L
.616 .03258 L
.62 .03251 L
.624 .03245 L
.628 .03241 L
.632 .03238 L
.636 .03236 L
.64 .03234 L
.644 .03232 L
.648 .03231 L
.652 .0323 L
.656 .0323 L
.66 .0323 L
.664 .03231 L
.668 .03231 L
.672 .03231 L
.676 .03232 L
.68 .03233 L
.684 .03233 L
.688 .03233 L
.692 .03233 L
.696 .03234 L
.7 .03235 L
.704 .03236 L
.708 .03237 L
.712 .03237 L
.716 .03238 L
.72 .03238 L
.724 .03238 L
.728 .03239 L
.732 .0324 L
.736 .0324 L
.74 .03241 L
.744 .03242 L
.748 .03243 L
.752 .03243 L
.756 .03244 L
.76 .03244 L
.764 .03244 L
.768 .03245 L
.772 .03246 L
.776 .03247 L
.78 .03248 L
.784 .03248 L
.788 .03249 L
.792 .03249 L
.796 .03249 L
.8 .0325 L
Mistroke
.804 .03251 L
.808 .03252 L
.812 .03252 L
.816 .03253 L
.82 .03254 L
.824 .03254 L
.828 .03255 L
.832 .03255 L
.836 .03256 L
.84 .03256 L
.844 .03257 L
.848 .03258 L
.852 .03259 L
.856 .03259 L
.86 .0326 L
.864 .0326 L
.868 .03261 L
.872 .03262 L
.876 .03262 L
.88 .03263 L
.884 .03264 L
.888 .03264 L
.892 .03265 L
.896 .03265 L
.9 .03266 L
.904 .03267 L
.908 .03267 L
.912 .03268 L
.916 .03269 L
.92 .0327 L
.924 .0327 L
.928 .03271 L
.932 .03271 L
.936 .03272 L
.94 .03273 L
.944 .03273 L
.948 .03274 L
.952 .03275 L
.956 .03276 L
.96 .03276 L
.964 .03277 L
.968 .03277 L
.972 .03278 L
.976 .03278 L
.98 .0328 L
.984 .0328 L
.988 .03281 L
.992 .03281 L
.996 .03282 L
1 .03282 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo02Ioo`8004Aoo`008Woo1@0000Eoo`00000007oo00<00003Ool0000000800004Ool00000
000BOol200000goo00000008000jOol0029oof<000aoo`008Woo0P000Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Ool007oo00000Woo00D007ooOomoo`0000=oo`03001oogoo0080
00=oo`05001oogooOol00003Ool01000Oomoogoo;00037oo000ROol2000DOol2000>Ool00`00Oomo
o`16Ool0029oo`03001oogoo01Eoo`80009oo`8000Qoo`03001oogoo04Ioo`008Woo0P005goo1@00
1goo00<007ooOol0Agoo000ROol2000HOol20002Ool30004Ool00`00Oomoo`17Ool000]oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo01ioo`04001oogoo001:Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0087oo00<007oo0000BWoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80021oo`8004]oo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool2
0004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomo
o`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003
Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]
Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo
00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00
KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo
000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool0
1000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomo
o`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo
0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`00
27oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol0
0Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo
00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`00
17oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`00
17oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool0
0`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00
Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo0000
17oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09
Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool0
1000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00
Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003OolY
0003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool2
0004Ool20004Ool90003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool0
02Qoo`03001oogoo02aoo`<003Moo`00:7oo00<007ooOol0:goo0P00>Goo000XOomM000<Ool002Qo
o`03001oogoo00moo`03001oogoo011oo`04001oogooOol3000;Ool00`00Oomoo`0?Ool00`00Oomo
o`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo02Aoo`<003moo`00:7oo00<007ooOol08Woo0`00
@Goo000XOol00`00Oomoo`0QOol20013Ool002Qoo`03001oogoo021oo`8004Aoo`00:7oo00<007oo
Ool07goo00<007ooOol0A7oo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool0
0`00Oomoo`0NOol20016Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0003Ool01000Oomoo`0087oo00<007ooOol0AGoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0005Ool01000Oomoo`007goo00<007ooOol0AWoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000NOol00`00Oomoo`16Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo01aoo`03001oogoo
04Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo
01]oo`03001oogoo04Qoo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol06Woo0P00
BWoo000XOol00`00Oomoo`0JOol00`00Oomoo`19Ool002Qoo`03001oogoo01Uoo`03001oogoo04Yo
o`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol06Goo00<007ooOol0BWoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo01Qoo`03001o
ogoo04]oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0G
Ool00`00Oomoo`1<Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
5goo0P00CWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
01Ioo`03001oogoo04eoo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomo
o`0EOol00`00Oomoo`1>Ool0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo01Aoo`80
051oo`00:7oo00<007ooOol04goo0P00DGoo000XOol00`00Oomoo`0COol00`00Oomoo`1@Ool002Qo
oa<0009oo`03001oogoo055oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo
00<007ooOol047oo0P00E7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol0
0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eo
o`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool0
0`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`80
00Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Ao
o`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol0
0002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yo
o`04001oogoo000;Ool01000Oomoo`00>Woo;P0037oo000:Ool01000Oomoo`001goo10000goo00<0
07ooOol0=Goo1000>Goo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00=7oo0`00?7oo000;
Ool20008Ool50002Ool00`00Oomoo`0bOol2000nOol001aoo`03001oogoo00eoo`<000Aoo`8000Uo
o`<000Aoo`8000Aoo`8000=oo`D000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009o
o`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00<007ooOol00`000goo00D007ooOomoo`0000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo
0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007ooOol00P0017oo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007oo
Ool047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool40005
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001o
ogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000L
Ool2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00D007ooOol007oo0080009oo`03
001oogoo00=oo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol0
0`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00<007ooOol00P0000Eoo`00
Oomoo`0000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001ao
o`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`<000=oo`8000Ioo`04001oogooOol50003Ool2
0006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo02Eoo`<0
04Yoo`0077oo00<007ooOol097oo0P00C7oo000LOomY000<Ool001aoo`05001oogooOol00003Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool3
0002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`0SOol00`00Oomoo`1<Ool001aoo`8002=o
o`03001oogoo04eoo`0077oo00<007ooOol08Woo00<007ooOol0CGoo000LOol00`00Oomoo`0ROol0
0`00Oomoo`1=Ool001aoo`80029oo`03001oogoo04ioo`0077oo00<007ooOol087oo0P00D7oo000L
Ool00`00Oomoo`0POol00`00Oomoo`1?Ool001aoo`80021oo`80055oo`0077oo00<007ooOol07goo
00<007ooOol0D7oo000LOol2000OOol00`00Oomoo`1AOol000]oo`8000Aoo`03001oogoo009oo`<0
00=oo`03001oogoo01eoo`03001oogoo059oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`0MOol00`00Oomoo`1BOol000Yoo`04001oogoo000;Ool00`00Oomoo`02000NOol0
0`00Oomoo`1BOol000Yoo`04001oogoo000;Ool01000Oomoo`007Woo00<007ooOol0Dgoo000:Ool0
1000Oomoo`001goo10000goo00<007ooOol06goo0P00EGoo000:Ool01000Oomoo`001goo00<007oo
Ool017oo0P0077oo00<007ooOol0E7oo000;Ool20008Ool50002Ool00`00Oomoo`0KOol00`00Oomo
o`1DOol001aoo`03001oogoo01Yoo`03001oogoo05Eoo`0077oo0P006Woo00<007ooOol0EWoo000L
Ool00`00Oomoo`0IOol00`00Oomoo`1FOol001aoo`8001Uoo`8005Qoo`0077oo00<007ooOol067oo
00<007ooOol0Egoo000LOol00`00Oomoo`0GOol00`00Oomoo`1HOol001aoo`8001Moo`03001oogoo
05Uoo`005Woo0`000goo00<007ooOol05Woo00<007ooOol0FGoo000GOol00`00Oomoo`02Ool00`00
Oomoo`0EOol00`00Oomoo`1JOol001Moo`03001oogoo009ooaP005eoo`005goo00<007ooOol00Woo
0P0057oo00<007ooOol0G7oo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`80
07=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03
001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo
000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`80
07=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(27388\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29114 m
.008 .29201 L
.012 .2956 L
.016 .29856 L
.02 .30082 L
.024 .30279 L
.028 .30348 L
.032 .30308 L
.036 .30155 L
.04 .29944 L
.044 .29686 L
.048 .29462 L
.052 .29415 L
.056 .29511 L
.06 .29692 L
.064 .29845 L
.068 .29941 L
.072 .30026 L
.076 .29988 L
.08 .29756 L
.084 .29443 L
.088 .2931 L
.092 .29457 L
.096 .29704 L
.1 .29917 L
.104 .30048 L
.108 .30119 L
.112 .3017 L
.116 .30142 L
.12 .29999 L
.124 .2977 L
.128 .29557 L
.132 .29462 L
.136 .2953 L
.14 .29709 L
.144 .29808 L
.148 .297 L
.152 .29439 L
.156 .29283 L
.16 .29522 L
.164 .30108 L
.168 .3064 L
.172 .30682 L
.176 .30116 L
.18 .29272 L
.184 .28677 L
.188 .28637 L
.192 .29082 L
.196 .29722 L
.2 .3028 L
Mistroke
.204 .30619 L
.208 .30689 L
.212 .30444 L
.216 .29887 L
.22 .29173 L
.224 .28628 L
.228 .28573 L
.232 .29107 L
.236 .30009 L
.24 .30874 L
.244 .31407 L
.248 .3161 L
.252 .31746 L
.256 .32115 L
.26 .32804 L
.264 .33625 L
.268 .34266 L
.272 .34521 L
.276 .34447 L
.28 .34319 L
.284 .34434 L
.288 .34909 L
.292 .35594 L
.296 .36163 L
.3 .36315 L
.304 .3595 L
.308 .35231 L
.312 .34499 L
.316 .34097 L
.32 .34201 L
.324 .34752 L
.328 .35506 L
.332 .36163 L
.336 .36508 L
.34 .36492 L
.344 .36231 L
.348 .3593 L
.352 .35788 L
.356 .35925 L
.36 .36354 L
.364 .37002 L
.368 .37745 L
.372 .38452 L
.376 .39006 L
.38 .3932 L
.384 .39338 L
.388 .39039 L
.392 .38442 L
.396 .37604 L
.4 .36606 L
Mistroke
.404 .35539 L
.408 .34484 L
.412 .33497 L
.416 .32604 L
.42 .31809 L
.424 .31107 L
.428 .30495 L
.432 .29976 L
.436 .29561 L
.44 .2926 L
.444 .29073 L
.448 .28987 L
.452 .28978 L
.456 .29016 L
.46 .29083 L
.464 .29172 L
.468 .29281 L
.472 .2941 L
.476 .29544 L
.48 .29658 L
.484 .29725 L
.488 .29735 L
.492 .29697 L
.496 .29634 L
.5 .29572 L
.504 .29519 L
.508 .29468 L
.512 .29407 L
.516 .29333 L
.52 .29263 L
.524 .29223 L
.528 .29232 L
.532 .29289 L
.536 .29374 L
.54 .29464 L
.544 .29553 L
.548 .29651 L
.552 .29779 L
.556 .29944 L
.56 .30131 L
.564 .30312 L
.568 .30467 L
.572 .30594 L
.576 .30713 L
.58 .30843 L
.584 .30987 L
.588 .31128 L
.592 .31243 L
.596 .3132 L
.6 .31372 L
Mistroke
.604 .31422 L
.608 .31486 L
.612 .31559 L
.616 .31621 L
.62 .31657 L
.624 .31667 L
.628 .3167 L
.632 .31683 L
.636 .31711 L
.64 .31741 L
.644 .31757 L
.648 .31754 L
.652 .31743 L
.656 .31741 L
.66 .31755 L
.664 .31776 L
.668 .31787 L
.672 .3178 L
.676 .31761 L
.68 .31748 L
.684 .31754 L
.688 .31773 L
.692 .3179 L
.696 .31793 L
.7 .31781 L
.704 .31767 L
.708 .31762 L
.712 .31768 L
.716 .31775 L
.72 .31778 L
.724 .31775 L
.728 .31774 L
.732 .3178 L
.736 .31788 L
.74 .31789 L
.744 .3178 L
.748 .31765 L
.752 .31758 L
.756 .31765 L
.76 .31784 L
.764 .31801 L
.768 .31802 L
.772 .31788 L
.776 .31769 L
.78 .3176 L
.784 .31766 L
.788 .3178 L
.792 .31792 L
.796 .31795 L
.8 .31791 L
Mistroke
.804 .31786 L
.808 .31782 L
.812 .31778 L
.816 .31775 L
.82 .31775 L
.824 .31781 L
.828 .31791 L
.832 .31799 L
.836 .31798 L
.84 .31788 L
.844 .31776 L
.848 .31773 L
.852 .31779 L
.856 .31791 L
.86 .31798 L
.864 .31796 L
.868 .3179 L
.872 .31786 L
.876 .31785 L
.88 .31788 L
.884 .3179 L
.888 .3179 L
.892 .3179 L
.896 .31791 L
.9 .31793 L
.904 .31794 L
.908 .31795 L
.912 .31794 L
.916 .31792 L
.92 .31791 L
.924 .31789 L
.928 .31789 L
.932 .31794 L
.936 .31798 L
.94 .31802 L
.944 .31803 L
.948 .31797 L
.952 .31791 L
.956 .31786 L
.96 .31788 L
.964 .31796 L
.968 .31803 L
.972 .3181 L
.976 .31809 L
.98 .318 L
.984 .31792 L
.988 .31783 L
.992 .31785 L
.996 .31799 L
1 .31811 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57668 m
.008 .58472 L
.012 .58745 L
.016 .58465 L
.02 .58373 L
.024 .58456 L
.028 .5849 L
.032 .58462 L
.036 .58458 L
.04 .58469 L
.044 .58479 L
.048 .58479 L
.052 .58485 L
.056 .58483 L
.06 .58479 L
.064 .58473 L
.068 .58478 L
.072 .58481 L
.076 .58476 L
.08 .58461 L
.084 .58457 L
.088 .58461 L
.092 .58459 L
.096 .58442 L
.1 .58427 L
.104 .58427 L
.108 .58447 L
.112 .58473 L
.116 .58487 L
.12 .58486 L
.124 .58487 L
.128 .58498 L
.132 .58519 L
.136 .58532 L
.14 .58518 L
.144 .58477 L
.148 .58437 L
.152 .58425 L
.156 .58453 L
.16 .58497 L
.164 .58515 L
.168 .58486 L
.172 .58428 L
.176 .58383 L
.18 .58388 L
.184 .58437 L
.188 .58493 L
.192 .58519 L
.196 .58497 L
.2 .58439 L
Mistroke
.204 .58368 L
.208 .58308 L
.212 .58281 L
.216 .58304 L
.22 .58393 L
.224 .58543 L
.228 .58724 L
.232 .58885 L
.236 .58973 L
.24 .58959 L
.244 .58843 L
.248 .58643 L
.252 .58374 L
.256 .58039 L
.26 .57633 L
.264 .57155 L
.268 .56621 L
.272 .56062 L
.276 .55511 L
.28 .54984 L
.284 .54475 L
.288 .53964 L
.292 .53427 L
.296 .52855 L
.3 .52259 L
.304 .51659 L
.308 .51077 L
.312 .50517 L
.316 .49969 L
.32 .49411 L
.324 .4882 L
.328 .48187 L
.332 .47521 L
.336 .46843 L
.34 .46184 L
.344 .45569 L
.348 .45007 L
.352 .44495 L
.356 .44009 L
.36 .43523 L
.364 .43007 L
.368 .42442 L
.372 .41819 L
.376 .41145 L
.38 .40435 L
.384 .39714 L
.388 .39008 L
.392 .38339 L
.396 .37726 L
.4 .37179 L
Mistroke
.404 .36703 L
.408 .36294 L
.412 .35945 L
.416 .35644 L
.42 .3538 L
.424 .35141 L
.428 .34917 L
.432 .347 L
.436 .34487 L
.44 .34273 L
.444 .3406 L
.448 .33846 L
.452 .33635 L
.456 .33426 L
.46 .33223 L
.464 .33027 L
.468 .32837 L
.472 .32654 L
.476 .32478 L
.48 .32308 L
.484 .32142 L
.488 .31977 L
.492 .31811 L
.496 .31641 L
.5 .31465 L
.504 .31281 L
.508 .31087 L
.512 .30883 L
.516 .3067 L
.52 .30447 L
.524 .30217 L
.528 .29982 L
.532 .29743 L
.536 .29504 L
.54 .29267 L
.544 .29034 L
.548 .28807 L
.552 .28588 L
.556 .2838 L
.56 .28185 L
.564 .28002 L
.568 .27833 L
.572 .27679 L
.576 .27539 L
.58 .27413 L
.584 .27301 L
.588 .27202 L
.592 .27114 L
.596 .27038 L
.6 .26972 L
Mistroke
.604 .26915 L
.608 .26866 L
.612 .26825 L
.616 .2679 L
.62 .26761 L
.624 .26737 L
.628 .26716 L
.632 .26699 L
.636 .26684 L
.64 .26672 L
.644 .26662 L
.648 .26654 L
.652 .26646 L
.656 .2664 L
.66 .26635 L
.664 .26631 L
.668 .26627 L
.672 .26623 L
.676 .2662 L
.68 .26616 L
.684 .26613 L
.688 .2661 L
.692 .26608 L
.696 .26606 L
.7 .26604 L
.704 .26601 L
.708 .26599 L
.712 .26596 L
.716 .26594 L
.72 .26591 L
.724 .26589 L
.728 .26587 L
.732 .26585 L
.736 .26583 L
.74 .26581 L
.744 .26578 L
.748 .26576 L
.752 .26573 L
.756 .26571 L
.76 .26569 L
.764 .26566 L
.768 .26565 L
.772 .26563 L
.776 .2656 L
.78 .26558 L
.784 .26555 L
.788 .26553 L
.792 .26551 L
.796 .26549 L
.8 .26546 L
Mistroke
.804 .26544 L
.808 .26542 L
.812 .2654 L
.816 .26538 L
.82 .26535 L
.824 .26533 L
.828 .2653 L
.832 .26528 L
.836 .26526 L
.84 .26524 L
.844 .26522 L
.848 .26519 L
.852 .26517 L
.856 .26515 L
.86 .26512 L
.864 .2651 L
.868 .26508 L
.872 .26506 L
.876 .26504 L
.88 .26501 L
.884 .26499 L
.888 .26497 L
.892 .26494 L
.896 .26492 L
.9 .2649 L
.904 .26488 L
.908 .26486 L
.912 .26483 L
.916 .26481 L
.92 .26479 L
.924 .26477 L
.928 .26474 L
.932 .26472 L
.936 .2647 L
.94 .26468 L
.944 .26465 L
.948 .26463 L
.952 .26461 L
.956 .26459 L
.96 .26456 L
.964 .26454 L
.968 .26452 L
.972 .2645 L
.976 .26447 L
.98 .26445 L
.984 .26443 L
.988 .26441 L
.992 .26438 L
.996 .26436 L
1 .26433 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43003 L
.012 .42975 L
.016 .4294 L
.02 .42913 L
.024 .42937 L
.028 .42955 L
.032 .42968 L
.036 .42977 L
.04 .42993 L
.044 .42995 L
.048 .42998 L
.052 .42997 L
.056 .42989 L
.06 .42967 L
.064 .42956 L
.068 .42952 L
.072 .42947 L
.076 .42928 L
.08 .4291 L
.084 .42901 L
.088 .42905 L
.092 .42904 L
.096 .42892 L
.1 .42872 L
.104 .42876 L
.108 .429 L
.112 .42927 L
.116 .42937 L
.12 .4293 L
.124 .4292 L
.128 .42929 L
.132 .4295 L
.136 .42961 L
.14 .4294 L
.144 .42888 L
.148 .42833 L
.152 .42818 L
.156 .42853 L
.16 .42907 L
.164 .4293 L
.168 .42893 L
.172 .42817 L
.176 .42759 L
.18 .42759 L
.184 .42812 L
.188 .42876 L
.192 .42901 L
.196 .42867 L
.2 .42791 L
Mistroke
.204 .427 L
.208 .42626 L
.212 .42593 L
.216 .42624 L
.22 .42736 L
.224 .42923 L
.228 .43145 L
.232 .43337 L
.236 .43438 L
.24 .43411 L
.244 .43258 L
.248 .43004 L
.252 .42667 L
.256 .42252 L
.26 .41748 L
.264 .41154 L
.268 .40489 L
.272 .39791 L
.276 .391 L
.28 .38437 L
.284 .37797 L
.288 .37153 L
.292 .36477 L
.296 .3576 L
.3 .35016 L
.304 .34271 L
.308 .3355 L
.312 .32856 L
.316 .32176 L
.32 .3148 L
.324 .30739 L
.328 .29944 L
.332 .29106 L
.336 .28257 L
.34 .27433 L
.344 .26668 L
.348 .25972 L
.352 .25337 L
.356 .24737 L
.36 .24132 L
.364 .2349 L
.368 .22783 L
.372 .22004 L
.376 .2116 L
.38 .20273 L
.384 .19374 L
.388 .18495 L
.392 .17665 L
.396 .16906 L
.4 .1623 L
Mistroke
.404 .1564 L
.408 .15131 L
.412 .14695 L
.416 .14319 L
.42 .13988 L
.424 .1369 L
.428 .13412 L
.432 .13146 L
.436 .12885 L
.44 .12623 L
.444 .1236 L
.448 .12097 L
.452 .11834 L
.456 .11574 L
.46 .11321 L
.464 .11076 L
.468 .10841 L
.472 .10617 L
.476 .10402 L
.48 .10194 L
.484 .0999 L
.488 .09787 L
.492 .09582 L
.496 .09371 L
.5 .09153 L
.504 .08925 L
.508 .08686 L
.512 .08435 L
.516 .08172 L
.52 .07898 L
.524 .07615 L
.528 .07325 L
.532 .0703 L
.536 .06734 L
.54 .0644 L
.544 .06152 L
.548 .05872 L
.552 .05603 L
.556 .05348 L
.56 .05108 L
.564 .04884 L
.568 .04677 L
.572 .04487 L
.576 .04316 L
.58 .04162 L
.584 .04025 L
.588 .03904 L
.592 .03798 L
.596 .03707 L
.6 .03628 L
Mistroke
.604 .03561 L
.608 .03505 L
.612 .03457 L
.616 .03416 L
.62 .03383 L
.624 .03355 L
.628 .03332 L
.632 .03315 L
.636 .033 L
.64 .03289 L
.644 .0328 L
.648 .03273 L
.652 .03267 L
.656 .03263 L
.66 .0326 L
.664 .03258 L
.668 .03256 L
.672 .03254 L
.676 .03254 L
.68 .03254 L
.684 .03254 L
.688 .03254 L
.692 .03254 L
.696 .03254 L
.7 .03254 L
.704 .03254 L
.708 .03255 L
.712 .03256 L
.716 .03257 L
.72 .03257 L
.724 .03258 L
.728 .03258 L
.732 .03259 L
.736 .03259 L
.74 .0326 L
.744 .0326 L
.748 .03261 L
.752 .03262 L
.756 .03263 L
.76 .03264 L
.764 .03264 L
.768 .03264 L
.772 .03264 L
.776 .03265 L
.78 .03266 L
.784 .03267 L
.788 .03268 L
.792 .03268 L
.796 .03269 L
.8 .03269 L
Mistroke
.804 .0327 L
.808 .0327 L
.812 .03271 L
.816 .03272 L
.82 .03273 L
.824 .03273 L
.828 .03274 L
.832 .03275 L
.836 .03275 L
.84 .03275 L
.844 .03276 L
.848 .03277 L
.852 .03278 L
.856 .03278 L
.86 .03279 L
.864 .03279 L
.868 .0328 L
.872 .0328 L
.876 .03281 L
.88 .03282 L
.884 .03283 L
.888 .03283 L
.892 .03284 L
.896 .03285 L
.9 .03285 L
.904 .03286 L
.908 .03286 L
.912 .03287 L
.916 .03288 L
.92 .03288 L
.924 .03289 L
.928 .0329 L
.932 .0329 L
.936 .03291 L
.94 .03292 L
.944 .03292 L
.948 .03293 L
.952 .03293 L
.956 .03294 L
.96 .03294 L
.964 .03296 L
.968 .03296 L
.972 .03297 L
.976 .03297 L
.98 .03298 L
.984 .03298 L
.988 .033 L
.992 .03299 L
.996 .03301 L
1 .03301 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo00moo`05001oogooOol0001HOol0029oo`<00005Ool00000001oo`0300000goo00000003
00000goo00000002Ool2000COol<000hOol0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo0P0000=oo`00Ool00Woo00D007ooOomoo`0000=o
o`05001oo`00Ool00003Ool01@00Oomoogoo00000goo00<007oo0000:@0037oo000ROol2000GOol0
0`00Oomoo`0=Ool00`00Oomoo`13Ool0029oo`03001oogoo01Moo`03001oogoo00]oo`03001oogoo
04Aoo`008Woo0P0067oo0`000Woo0P001goo00<007ooOol0A7oo000ROol2000KOol200000goo001o
o`020004Ool00`00Oomoo`14Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001o
ogoo01Yoo`03001oogoo00D0009oo`03001oogoo04Eoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool2000ROol01000Oomoo`00Agoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`80029oo`<004Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`0ROol20018Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`80
06eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00
Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2
001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04
001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol0
0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2
000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]
Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo
1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol0
0goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo
0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09
Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03
001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007oo
Ool0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;
Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool0
1000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo
10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003
Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool0
1000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`0V
0003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool2
0004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@00
0goo0P001Woo000XOol00`00Oomoo`0_Ool2000eOol002Qoo`03001oogoo02eoo`8003Moo`00:7oo
G@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool30008Ool00`00Oomo
o`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo02Moo`<003aoo`00:7oo00<0
07ooOol09Goo0P00?goo000XOol00`00Oomoo`0SOol30010Ool002Qoo`03001oogoo029oo`80049o
o`00:7oo00<007ooOol08Goo0P00@goo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool3
0003Ool00`00Oomoo`0QOol00`00Oomoo`12Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0003Ool01000Oomoo`008Woo0P00A7oo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`04001oogoo0005Ool01000Oomoo`008Goo0P00AGoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000POol00`00Oomoo`14Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo01ioo`8004Ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo01ioo`03
001oogoo04Eoo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol07Goo00<007ooOol0
AWoo000XOol00`00Oomoo`0LOol20018Ool002Qoo`03001oogoo01]oo`8004Uoo`004Goo0P0017oo
00<007ooOol00goo0P000goo0`000goo00<007ooOol06goo00<007ooOol0B7oo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo01Yoo`03001oogoo04Uoo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0JOol00`00Oomoo`19
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P006Woo00<007ooOol0
BWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo01Qoo`80
04aoo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0GOol2001=Ool0
015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo01Moo`03001oogoo04aoo`00:7oo00<0
07ooOol05Woo00<007ooOol0CGoo000XOol00`00Oomoo`0EOol2001?Ool002QooaH00003Ool00000
051oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo0P004goo0P00DWoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=o
o`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomo
o`00?Goo:`0037oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0>7oo0`00=goo000:Ool0
1000Oomoo`001goo00<007ooOol017oo0P00=goo0`00>Goo000;Ool20008Ool50002Ool00`00Oomo
o`0eOol2000kOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<0
00=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P00
3Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`<000=oo`05001oogooOol00002Ool01000Oomoo`001Goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007oo
Ool00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo
00@007ooOol0009oo`05001oogoo001oo`0300000goo001oo`06Ool01000Oomoo`000Woo00<007oo
Ool017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol0
1goo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo00<000=oo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eo
o`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001o
ogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo000000Eoo`04001oogooOol40003
Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H0
07ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool0
1000Oomoo`0027oo0P0017oo00@007ooOol0009oo`800003Ool007oo00=oo`8000=oo`03001oogoo
00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool0
1`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001o
ogoo00=oo`800003Ool0000000<000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool2
0006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo02Qoo`8004Qoo`0077oo00<007ooOol0
9goo0P00BGoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoogoo0P000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<0
07ooOol02Woo000LOol00`00Oomoo`0VOol00`00Oomoo`19Ool001aoo`8002Ioo`03001oogoo04Yo
o`0077oo00<007ooOol09Goo00<007ooOol0BWoo000LOol00`00Oomoo`0TOol00`00Oomoo`1;Ool0
01aoo`8002Eoo`03001oogoo04]oo`0077oo00<007ooOol08goo00<007ooOol0C7oo000LOol00`00
Oomoo`0SOol00`00Oomoo`1<Ool001aoo`8002=oo`03001oogoo04eoo`0077oo00<007ooOol08Goo
0P00Cgoo000LOol2000ROol00`00Oomoo`1>Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`03
001oogoo021oo`03001oogoo04moo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`0POol00`00Oomoo`1?Ool000Yoo`04001oogoo000;Ool00`00Oomoo`02000QOol00`00Oomo
o`1?Ool000Yoo`04001oogoo000;Ool01000Oomoo`008Goo00<007ooOol0D7oo000:Ool01000Oomo
o`001goo10000goo00<007ooOol07Woo00<007ooOol0DGoo000:Ool01000Oomoo`001goo00<007oo
Ool017oo0P007goo00<007ooOol0DGoo000;Ool20008Ool50002Ool00`00Oomoo`0MOol00`00Oomo
o`1BOol001aoo`03001oogoo01eoo`03001oogoo059oo`0077oo0P007Goo00<007ooOol0Dgoo000L
Ool00`00Oomoo`0KOol2001EOol001aoo`8001aoo`03001oogoo05Aoo`0077oo00<007ooOol06Woo
0P00EWoo000LOol00`00Oomoo`0JOol00`00Oomoo`1EOol001aoo`8001Yoo`03001oogoo05Ioo`00
5Woo0`000goo00<007ooOol06Goo00<007ooOol0EWoo000GOol00`00Oomoo`02Ool00`00Oomoo`0H
Ool00`00Oomoo`1GOol001Moo`03001oogoo009ooa/005Yoo`005goo00<007ooOol00Woo00<007oo
Ool05Woo00<007ooOol0FGoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`80
07=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03
001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo
000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`80
07=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(27555\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .2991 m
.008 .30006 L
.012 .30061 L
.016 .29951 L
.02 .29671 L
.024 .29522 L
.028 .29533 L
.032 .2954 L
.036 .29582 L
.04 .29677 L
.044 .298 L
.048 .29874 L
.052 .29898 L
.056 .29944 L
.06 .29951 L
.064 .299 L
.068 .29841 L
.072 .29868 L
.076 .29945 L
.08 .29884 L
.084 .29717 L
.088 .29609 L
.092 .29635 L
.096 .29711 L
.1 .29735 L
.104 .29743 L
.108 .29782 L
.112 .29847 L
.116 .29849 L
.12 .29689 L
.124 .29468 L
.128 .29377 L
.132 .29545 L
.136 .29947 L
.14 .30385 L
.144 .30601 L
.148 .30435 L
.152 .29965 L
.156 .29457 L
.16 .29187 L
.164 .29227 L
.168 .29383 L
.172 .29473 L
.176 .2951 L
.18 .29656 L
.184 .30019 L
.188 .30428 L
.192 .30551 L
.196 .30219 L
.2 .29603 L
Mistroke
.204 .29078 L
.208 .2893 L
.212 .29145 L
.216 .29492 L
.22 .29781 L
.224 .29991 L
.228 .30193 L
.232 .30377 L
.236 .30394 L
.24 .30091 L
.244 .29498 L
.248 .28882 L
.252 .28582 L
.256 .28786 L
.26 .29413 L
.264 .30192 L
.268 .30877 L
.272 .314 L
.276 .31863 L
.28 .32407 L
.284 .33061 L
.288 .33711 L
.292 .34197 L
.296 .34442 L
.3 .34524 L
.304 .34632 L
.308 .34935 L
.312 .35464 L
.316 .36082 L
.32 .36553 L
.324 .36677 L
.328 .36392 L
.332 .35818 L
.336 .35201 L
.34 .34802 L
.344 .34785 L
.348 .35159 L
.352 .35781 L
.356 .36424 L
.36 .36874 L
.364 .37012 L
.368 .36854 L
.372 .36533 L
.376 .36247 L
.38 .36179 L
.384 .36435 L
.388 .37014 L
.392 .37815 L
.396 .38675 L
.4 .39419 L
Mistroke
.404 .39907 L
.408 .40062 L
.412 .39871 L
.416 .39372 L
.42 .38629 L
.424 .37713 L
.428 .36689 L
.432 .35613 L
.436 .34538 L
.44 .33515 L
.444 .32586 L
.448 .31781 L
.452 .31104 L
.456 .30545 L
.46 .30083 L
.464 .29707 L
.468 .29419 L
.472 .2923 L
.476 .29146 L
.48 .29155 L
.484 .29228 L
.488 .29328 L
.492 .2943 L
.496 .29525 L
.5 .29619 L
.504 .29715 L
.508 .29805 L
.512 .29868 L
.516 .29884 L
.52 .2985 L
.524 .29783 L
.528 .29711 L
.532 .29652 L
.536 .2961 L
.54 .2957 L
.544 .29523 L
.548 .29472 L
.552 .29441 L
.556 .29451 L
.56 .29509 L
.564 .29602 L
.568 .29706 L
.572 .29807 L
.576 .29908 L
.58 .30024 L
.584 .30169 L
.588 .30336 L
.592 .30503 L
.596 .3065 L
.6 .30771 L
Mistroke
.604 .30879 L
.608 .30991 L
.612 .31111 L
.616 .31229 L
.62 .31325 L
.624 .31394 L
.628 .31442 L
.632 .3149 L
.636 .31547 L
.64 .31607 L
.644 .31654 L
.648 .31675 L
.652 .31677 L
.656 .31679 L
.66 .31695 L
.664 .31727 L
.668 .31758 L
.672 .31772 L
.676 .31764 L
.68 .31748 L
.684 .31739 L
.688 .31747 L
.692 .31764 L
.696 .31776 L
.7 .31777 L
.704 .31771 L
.708 .31767 L
.712 .3177 L
.716 .31775 L
.72 .31775 L
.724 .31767 L
.728 .3176 L
.732 .31761 L
.736 .31773 L
.74 .31787 L
.744 .31791 L
.748 .31783 L
.752 .31768 L
.756 .31758 L
.76 .31761 L
.764 .31772 L
.768 .31783 L
.772 .31786 L
.776 .31783 L
.78 .31778 L
.784 .31777 L
.788 .31776 L
.792 .31774 L
.796 .3177 L
.8 .31769 L
Mistroke
.804 .31776 L
.808 .31788 L
.812 .31796 L
.816 .31792 L
.82 .31779 L
.824 .31766 L
.828 .31763 L
.832 .31771 L
.836 .31785 L
.84 .31795 L
.844 .31797 L
.848 .31791 L
.852 .31781 L
.856 .31773 L
.86 .31769 L
.864 .31773 L
.868 .31782 L
.872 .31795 L
.876 .31803 L
.88 .318 L
.884 .31788 L
.888 .31773 L
.892 .31765 L
.896 .31772 L
.9 .31788 L
.904 .31804 L
.908 .3181 L
.912 .31801 L
.916 .31784 L
.92 .3177 L
.924 .31767 L
.928 .31779 L
.932 .31797 L
.936 .31811 L
.94 .31812 L
.944 .31799 L
.948 .31781 L
.952 .3177 L
.956 .31771 L
.96 .31788 L
.964 .31805 L
.968 .31815 L
.972 .31813 L
.976 .31796 L
.98 .31779 L
.984 .31771 L
.988 .31775 L
.992 .31795 L
.996 .31815 L
1 .31822 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .58301 m
.008 .5841 L
.012 .58465 L
.016 .5845 L
.02 .58428 L
.024 .58418 L
.028 .58428 L
.032 .58423 L
.036 .58415 L
.04 .58404 L
.044 .58405 L
.048 .58405 L
.052 .58413 L
.056 .5842 L
.06 .58427 L
.064 .5843 L
.068 .5844 L
.072 .58446 L
.076 .58444 L
.08 .58432 L
.084 .5843 L
.088 .58435 L
.092 .58438 L
.096 .5843 L
.1 .5842 L
.104 .58416 L
.108 .58422 L
.112 .58424 L
.116 .58413 L
.12 .58392 L
.124 .58382 L
.128 .58391 L
.132 .58411 L
.136 .58427 L
.14 .5843 L
.144 .58425 L
.148 .58429 L
.152 .58452 L
.156 .58482 L
.16 .58496 L
.164 .58475 L
.168 .58427 L
.172 .58388 L
.176 .58388 L
.18 .58425 L
.184 .58467 L
.188 .58474 L
.192 .58434 L
.196 .58376 L
.2 .58339 L
Mistroke
.204 .58349 L
.208 .58395 L
.212 .58446 L
.216 .58473 L
.22 .58463 L
.224 .58419 L
.228 .58351 L
.232 .58276 L
.236 .58221 L
.24 .58215 L
.244 .58284 L
.248 .58426 L
.252 .5861 L
.256 .58785 L
.26 .58902 L
.264 .58932 L
.268 .58874 L
.272 .58738 L
.276 .58531 L
.28 .5825 L
.284 .57886 L
.288 .57439 L
.292 .56929 L
.296 .56389 L
.3 .55852 L
.304 .55334 L
.308 .5483 L
.312 .54321 L
.316 .53786 L
.32 .53218 L
.324 .52625 L
.328 .5203 L
.332 .51452 L
.336 .50897 L
.34 .50357 L
.344 .49809 L
.348 .4923 L
.352 .48608 L
.356 .47947 L
.36 .47267 L
.364 .46597 L
.368 .45963 L
.372 .45382 L
.376 .44853 L
.38 .44361 L
.384 .4388 L
.388 .43381 L
.392 .42841 L
.396 .42246 L
.4 .41595 L
Mistroke
.404 .409 L
.408 .40182 L
.412 .39464 L
.416 .38772 L
.42 .38127 L
.424 .37542 L
.428 .37024 L
.432 .36574 L
.436 .36187 L
.44 .35854 L
.444 .35563 L
.448 .35304 L
.452 .35067 L
.456 .34842 L
.46 .34625 L
.464 .34411 L
.468 .34197 L
.472 .33984 L
.476 .3377 L
.48 .33559 L
.484 .33352 L
.488 .3315 L
.492 .32956 L
.496 .32769 L
.5 .3259 L
.504 .32417 L
.508 .32249 L
.512 .32085 L
.516 .3192 L
.52 .31754 L
.524 .31582 L
.528 .31403 L
.532 .31215 L
.536 .31017 L
.54 .3081 L
.544 .30594 L
.548 .30369 L
.552 .30138 L
.556 .29901 L
.56 .29662 L
.564 .29423 L
.568 .29187 L
.572 .28956 L
.576 .28732 L
.58 .28517 L
.584 .28312 L
.588 .28121 L
.592 .27943 L
.596 .27779 L
.6 .2763 L
Mistroke
.604 .27494 L
.608 .27372 L
.612 .27263 L
.616 .27167 L
.62 .27083 L
.624 .2701 L
.628 .26947 L
.632 .26893 L
.636 .26846 L
.64 .26807 L
.644 .26774 L
.648 .26746 L
.652 .26722 L
.656 .26702 L
.66 .26686 L
.664 .26672 L
.668 .2666 L
.672 .26651 L
.676 .26643 L
.68 .26637 L
.684 .26631 L
.688 .26625 L
.692 .2662 L
.696 .26616 L
.7 .26613 L
.704 .2661 L
.708 .26607 L
.712 .26604 L
.716 .26602 L
.72 .26599 L
.724 .26597 L
.728 .26594 L
.732 .26591 L
.736 .26589 L
.74 .26587 L
.744 .26585 L
.748 .26583 L
.752 .2658 L
.756 .26578 L
.76 .26575 L
.764 .26573 L
.768 .26571 L
.772 .26568 L
.776 .26566 L
.78 .26564 L
.784 .26562 L
.788 .2656 L
.792 .26557 L
.796 .26555 L
.8 .26553 L
Mistroke
.804 .2655 L
.808 .26548 L
.812 .26546 L
.816 .26544 L
.82 .26542 L
.824 .26539 L
.828 .26537 L
.832 .26535 L
.836 .26532 L
.84 .2653 L
.844 .26528 L
.848 .26526 L
.852 .26524 L
.856 .26521 L
.86 .26519 L
.864 .26517 L
.868 .26514 L
.872 .26512 L
.876 .2651 L
.88 .26508 L
.884 .26506 L
.888 .26503 L
.892 .26501 L
.896 .26499 L
.9 .26496 L
.904 .26494 L
.908 .26492 L
.912 .2649 L
.916 .26488 L
.92 .26485 L
.924 .26483 L
.928 .26481 L
.932 .26479 L
.936 .26476 L
.94 .26474 L
.944 .26472 L
.948 .2647 L
.952 .26467 L
.956 .26465 L
.96 .26463 L
.964 .26461 L
.968 .26458 L
.972 .26456 L
.976 .26454 L
.98 .26452 L
.984 .26449 L
.988 .26447 L
.992 .26444 L
.996 .26443 L
1 .2644 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42433 L
.012 .43019 L
.016 .43219 L
.02 .43017 L
.024 .42947 L
.028 .42992 L
.032 .43001 L
.036 .42959 L
.04 .42938 L
.044 .42927 L
.048 .42927 L
.052 .42928 L
.056 .42935 L
.06 .42937 L
.064 .42947 L
.068 .42961 L
.072 .42974 L
.076 .4297 L
.08 .42961 L
.084 .42952 L
.088 .42953 L
.092 .42949 L
.096 .42933 L
.1 .42909 L
.104 .42899 L
.108 .42902 L
.112 .42901 L
.116 .42883 L
.12 .42858 L
.124 .42842 L
.128 .42852 L
.132 .42877 L
.136 .42897 L
.14 .42899 L
.144 .42892 L
.148 .42894 L
.152 .42917 L
.156 .42949 L
.16 .42959 L
.164 .42925 L
.168 .42861 L
.172 .42806 L
.176 .42802 L
.18 .42849 L
.184 .42901 L
.188 .42911 L
.192 .42864 L
.196 .42791 L
.2 .42744 L
Mistroke
.204 .4275 L
.208 .42799 L
.212 .42853 L
.216 .42878 L
.22 .42859 L
.224 .428 L
.228 .42715 L
.232 .42625 L
.236 .42558 L
.24 .42553 L
.244 .42637 L
.248 .42811 L
.252 .43035 L
.256 .43246 L
.26 .43383 L
.264 .43413 L
.268 .43334 L
.272 .43161 L
.276 .42902 L
.28 .42553 L
.284 .42101 L
.288 .41546 L
.292 .40911 L
.296 .40235 L
.3 .39559 L
.304 .38905 L
.308 .38269 L
.312 .37628 L
.316 .36959 L
.32 .36251 L
.324 .35516 L
.328 .34777 L
.332 .34058 L
.336 .33367 L
.34 .32691 L
.344 .32004 L
.348 .31277 L
.352 .30498 L
.356 .2967 L
.36 .28822 L
.364 .27987 L
.368 .272 L
.372 .26478 L
.376 .25822 L
.38 .2521 L
.384 .24609 L
.388 .23985 L
.392 .23308 L
.396 .22564 L
.4 .21752 L
Mistroke
.404 .20887 L
.408 .19994 L
.412 .19103 L
.416 .18245 L
.42 .17443 L
.424 .16715 L
.428 .16069 L
.432 .15508 L
.436 .15025 L
.44 .14609 L
.444 .14249 L
.448 .13929 L
.452 .13637 L
.456 .13361 L
.46 .13093 L
.464 .12828 L
.468 .12562 L
.472 .12297 L
.476 .12032 L
.48 .1177 L
.484 .11514 L
.488 .11265 L
.492 .11025 L
.496 .10795 L
.5 .10575 L
.504 .10362 L
.508 .10156 L
.512 .09952 L
.516 .09748 L
.52 .09542 L
.524 .0933 L
.528 .09109 L
.532 .08879 L
.536 .08636 L
.54 .08381 L
.544 .08113 L
.548 .07836 L
.552 .0755 L
.556 .07258 L
.56 .06963 L
.564 .06668 L
.568 .06376 L
.572 .0609 L
.576 .05814 L
.58 .0555 L
.584 .05299 L
.588 .05064 L
.592 .04845 L
.596 .04643 L
.6 .04459 L
Mistroke
.604 .04293 L
.608 .04145 L
.612 .04013 L
.616 .03898 L
.62 .03796 L
.624 .03708 L
.628 .03633 L
.632 .03568 L
.636 .03514 L
.64 .03468 L
.644 .0343 L
.648 .03398 L
.652 .03372 L
.656 .03351 L
.66 .03335 L
.664 .03321 L
.668 .0331 L
.672 .03301 L
.676 .03294 L
.68 .03289 L
.684 .03285 L
.688 .03282 L
.692 .03281 L
.696 .03279 L
.7 .03278 L
.704 .03277 L
.708 .03277 L
.712 .03276 L
.716 .03276 L
.72 .03277 L
.724 .03277 L
.728 .03278 L
.732 .03279 L
.736 .03279 L
.74 .03279 L
.744 .0328 L
.748 .0328 L
.752 .0328 L
.756 .03281 L
.76 .03282 L
.764 .03283 L
.768 .03284 L
.772 .03284 L
.776 .03284 L
.78 .03285 L
.784 .03285 L
.788 .03286 L
.792 .03287 L
.796 .03288 L
.8 .03288 L
Mistroke
.804 .03289 L
.808 .0329 L
.812 .0329 L
.816 .0329 L
.82 .03291 L
.824 .03292 L
.828 .03293 L
.832 .03293 L
.836 .03294 L
.84 .03295 L
.844 .03295 L
.848 .03296 L
.852 .03296 L
.856 .03297 L
.86 .03298 L
.864 .03298 L
.868 .03299 L
.872 .033 L
.876 .033 L
.88 .03301 L
.884 .03301 L
.888 .03302 L
.892 .03303 L
.896 .03303 L
.9 .03304 L
.904 .03305 L
.908 .03305 L
.912 .03306 L
.916 .03306 L
.92 .03307 L
.924 .03308 L
.928 .03308 L
.932 .03309 L
.936 .0331 L
.94 .03311 L
.944 .03311 L
.948 .03312 L
.952 .03312 L
.956 .03313 L
.96 .03313 L
.964 .03315 L
.968 .03315 L
.972 .03316 L
.976 .03316 L
.98 .03317 L
.984 .03317 L
.988 .03318 L
.992 .03318 L
.996 .0332 L
1 .0332 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo01Ioo`03001oogoo05=oo`008Woo1P0000=oo`0000001@0000=oo`0000000P0000Eoo`00
000007oo008001=oo``003Ioo`008WooH`0037oo000ROol01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo
Ool20002Ool01@00Oomoogoo00000goo00@007ooOomoobP000aoo`008Woo0P006Goo00<007ooOol0
3Goo00<007ooOol0@Goo000ROol00`00Oomoo`0IOol00`00Oomoo`0<Ool00`00Oomoo`11Ool0029o
o`8001]oo`80009oo`8000Qoo`03001oogoo045oo`008Woo0P007Goo10001goo00<007ooOol0@Woo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0LOol20002Ool40003Ool0
0`00Oomoo`12Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0097oo
00@007ooOol004Eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000U
Ool00`00Ool00015Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol097oo0`00AGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
06eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`80
00Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@00
0Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool0
1P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001o
o`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomo
o`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol0
00Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007oo
Ool000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo
0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo
0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol0
0003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eo
o`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000
0goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo
00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P00
17oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00
Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool0
00=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Ao
o`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009o
o`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogoo
Ool00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo
00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`00
17oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P00
0Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009o
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001o
o`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo
00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Ao
o`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol00goo8`000goo00@007ooOol0
00Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@0
07ooOomoo`H0009oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo
00<007ooOol0<Goo0`00<Woo000XOol00`00Oomoo`0`Ool2000dOol002Qooed000aoo`00:7oo00<0
07ooOol03goo00<007ooOol047oo00<007ooOol01Woo0`001Woo00<007ooOol03goo00<007ooOol0
47oo00<007ooOol02Woo000XOol00`00Oomoo`0YOol3000jOol002Qoo`03001oogoo02Moo`<003ao
o`00:7oo00<007ooOol09Woo0P00?Woo000XOol00`00Oomoo`0UOol00`00Oomoo`0nOol002Qoo`03
001oogoo02Aoo`03001oogoo03moo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`00
0goo00<007ooOol08goo0P00@Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`000goo00@007ooOol002Eoo`03001oogoo041oo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOol002Aoo`03001oogoo045oo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P008Woo0P00@goo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`0QOol00`00Oomoo`12
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0P
Ool20014Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo01moo`03001oogoo04Ao
o`00:7oo00<007ooOol07Woo0P00AWoo000XOol00`00Oomoo`0NOol00`00Oomoo`15Ool0015oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo01eoo`8004Moo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0MOol00`00Oomoo`16Ool0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol077oo00<007ooOol0Agoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8001aoo`03001oogoo04Qo
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0KOol00`00
Oomoo`18Ool0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol06Woo00<0
07ooOol0BGoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0IOol2001;Ool002Qo
o`03001oogoo01Qoo`8004aoo`00:7oo00<007ooOol05goo0P00CGoo000XOolH00000goo0000001>
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo01Eoo`8004mo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00
Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo
0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@0
07ooOol0041oobP000aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo03]oo`<003Aoo`00
2Woo00@007ooOol000Moo`03001oogoo00Aoo`8003Yoo`8003Moo`002goo0P0027oo1@000Woo00<0
07ooOol0>7oo0P00>7oo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005
Ool90004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eo
o`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool300000goo001oo`02Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<0
07ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0004Ool30006Ool01000Oomoo`000Woo00<007ooOol017oo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0002Ool40007Ool01000Oomoo`000Woo00<007oo
Ool01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007oo
Ool00Woo00@007ooOol0009oo`05001oogoo001oo`020002Ool01000Oomoogoo10000goo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol0
07oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol0
00Qoo`8000Aoo`04001oogoo0002Ool00`00Oomoo`020003Ool20003Ool00`00Oomoo`04Ool01000
Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomo
o`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool2
0004Ool30005Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@00
0goo0P001Woo000LOol00`00Oomoo`0[Ool20015Ool001aoo`03001oogoo02Yoo`8004Ioo`0077oo
J@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007oo001oo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo
00<007ooOol0:7oo0P00B7oo000LOol2000YOol00`00Oomoo`17Ool001aoo`03001oogoo02Moo`03
001oogoo04Qoo`0077oo00<007ooOol09goo00<007ooOol0B7oo000LOol2000XOol00`00Oomoo`18
Ool001aoo`03001oogoo02Ioo`03001oogoo04Uoo`0077oo00<007ooOol09Goo0P00Bgoo000LOol2
000VOol00`00Oomoo`1:Ool001aoo`03001oogoo02Aoo`03001oogoo04]oo`0077oo0P009Goo00<0
07ooOol0Bgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`0SOol00`00Oomoo`1<
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol08Woo0P00CWoo000:Ool0
1000Oomoo`002goo00<007ooOol00P008goo00<007ooOol0CGoo000:Ool01000Oomoo`002goo00@0
07ooOol002Aoo`03001oogoo04eoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo025oo`03
001oogoo04ioo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80025oo`80051oo`002goo0P00
27oo1@000Woo00<007ooOol087oo00<007ooOol0Cgoo000LOol00`00Oomoo`0POol00`00Oomoo`1?
Ool001aoo`80021oo`03001oogoo051oo`0077oo00<007ooOol07Woo00<007ooOol0DGoo000LOol2
000NOol2001COol001aoo`03001oogoo01eoo`03001oogoo059oo`0077oo00<007ooOol077oo0P00
E7oo000LOol2000MOol00`00Oomoo`1COol001Ioo`<000=oo`03001oogoo01]oo`03001oogoo05Ao
o`005goo00<007ooOol00Woo0P0077oo00<007ooOol0E7oo000GOol00`00Oomoo`02OolN001GOol0
01Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000F
Ool20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomo
o`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00
M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03
001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07
Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(27722\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29626 m
.008 .29781 L
.012 .29793 L
.016 .29829 L
.02 .29867 L
.024 .29841 L
.028 .29796 L
.032 .29787 L
.036 .29812 L
.04 .2989 L
.044 .29977 L
.048 .30008 L
.052 .29954 L
.056 .29837 L
.06 .29687 L
.064 .29474 L
.068 .29333 L
.072 .29423 L
.076 .2972 L
.08 .30031 L
.084 .30198 L
.088 .30256 L
.092 .30195 L
.096 .29963 L
.1 .29605 L
.104 .29285 L
.108 .29238 L
.112 .29521 L
.116 .29952 L
.12 .30249 L
.124 .30263 L
.128 .30066 L
.132 .29769 L
.136 .29473 L
.14 .29265 L
.144 .29191 L
.148 .29303 L
.152 .29605 L
.156 .30026 L
.16 .30415 L
.164 .3057 L
.168 .3036 L
.172 .29872 L
.176 .29428 L
.18 .29325 L
.184 .29586 L
.188 .29911 L
.192 .29917 L
.196 .29545 L
.2 .29128 L
Mistroke
.204 .2909 L
.208 .29565 L
.212 .30261 L
.216 .30696 L
.22 .30597 L
.224 .30063 L
.228 .29421 L
.232 .2897 L
.236 .2883 L
.24 .28981 L
.244 .29373 L
.248 .29938 L
.252 .30522 L
.256 .3087 L
.26 .30744 L
.264 .30106 L
.268 .29214 L
.272 .28501 L
.276 .2831 L
.28 .28688 L
.284 .2939 L
.288 .30077 L
.292 .30563 L
.296 .30917 L
.3 .31361 L
.304 .32065 L
.308 .32988 L
.312 .33893 L
.316 .34519 L
.32 .34757 L
.324 .34737 L
.328 .34738 L
.332 .35014 L
.336 .3563 L
.34 .36417 L
.344 .3707 L
.348 .37315 L
.352 .3706 L
.356 .36437 L
.36 .35735 L
.364 .35263 L
.368 .35213 L
.372 .35591 L
.376 .36232 L
.38 .36892 L
.384 .37349 L
.388 .37488 L
.392 .37329 L
.396 .37001 L
.4 .36686 L
Mistroke
.404 .36553 L
.408 .36708 L
.412 .37173 L
.416 .37893 L
.42 .38748 L
.424 .39589 L
.428 .40266 L
.432 .40657 L
.436 .40691 L
.44 .40359 L
.444 .39707 L
.448 .38819 L
.452 .37791 L
.456 .36703 L
.46 .3561 L
.464 .34547 L
.468 .33539 L
.472 .32614 L
.476 .318 L
.48 .31118 L
.484 .30574 L
.488 .30151 L
.492 .29829 L
.496 .29589 L
.5 .29429 L
.504 .29353 L
.508 .2936 L
.512 .29434 L
.516 .29544 L
.52 .29656 L
.524 .2975 L
.528 .29825 L
.532 .29891 L
.536 .29954 L
.54 .30003 L
.544 .30023 L
.548 .29999 L
.552 .29939 L
.556 .29865 L
.56 .298 L
.564 .29756 L
.568 .29729 L
.572 .29706 L
.576 .29683 L
.58 .29672 L
.584 .29688 L
.588 .29743 L
.592 .29831 L
.596 .29936 L
.6 .30043 L
Mistroke
.604 .3015 L
.608 .30267 L
.612 .304 L
.616 .30547 L
.62 .30691 L
.624 .30817 L
.628 .30924 L
.632 .31022 L
.636 .31124 L
.64 .31232 L
.644 .31335 L
.648 .31417 L
.652 .31472 L
.656 .31508 L
.66 .31543 L
.664 .31586 L
.668 .31634 L
.672 .31673 L
.676 .31696 L
.68 .31706 L
.684 .31714 L
.688 .31726 L
.692 .31742 L
.696 .31752 L
.7 .3175 L
.704 .31745 L
.708 .31745 L
.712 .31757 L
.716 .31775 L
.72 .31785 L
.724 .3178 L
.728 .31764 L
.732 .31749 L
.736 .31748 L
.74 .3176 L
.744 .31777 L
.748 .31787 L
.752 .31784 L
.756 .31774 L
.76 .31765 L
.764 .31761 L
.768 .31762 L
.772 .31766 L
.776 .3177 L
.78 .31776 L
.784 .31783 L
.788 .31786 L
.792 .3178 L
.796 .31768 L
.8 .31758 L
Mistroke
.804 .31758 L
.808 .3177 L
.812 .31785 L
.816 .31793 L
.82 .31789 L
.824 .31776 L
.828 .31765 L
.832 .31763 L
.836 .31769 L
.84 .31779 L
.844 .31786 L
.848 .31788 L
.852 .31785 L
.856 .3178 L
.86 .31774 L
.864 .31771 L
.868 .31773 L
.872 .31779 L
.876 .31786 L
.88 .3179 L
.884 .31788 L
.888 .31781 L
.892 .31775 L
.896 .31775 L
.9 .31779 L
.904 .31786 L
.908 .31789 L
.912 .31788 L
.916 .31784 L
.92 .31781 L
.924 .31781 L
.928 .31784 L
.932 .31788 L
.936 .3179 L
.94 .31788 L
.944 .31784 L
.948 .31783 L
.952 .31784 L
.956 .31789 L
.96 .31794 L
.964 .31793 L
.968 .31791 L
.972 .31786 L
.976 .31782 L
.98 .31785 L
.984 .31789 L
.988 .31795 L
.992 .318 L
.996 .31798 L
1 .31793 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .59156 m
.008 .58363 L
.012 .58108 L
.016 .58374 L
.02 .58467 L
.024 .58377 L
.028 .58356 L
.032 .58391 L
.036 .58409 L
.04 .584 L
.044 .58396 L
.048 .58392 L
.052 .5839 L
.056 .58379 L
.06 .5837 L
.064 .58357 L
.068 .58356 L
.072 .58359 L
.076 .58363 L
.08 .58363 L
.084 .58371 L
.088 .58386 L
.092 .58399 L
.096 .584 L
.1 .58396 L
.104 .58393 L
.108 .58398 L
.112 .584 L
.116 .58393 L
.12 .58378 L
.124 .58372 L
.128 .58378 L
.132 .58385 L
.136 .5838 L
.14 .58364 L
.144 .58345 L
.148 .5834 L
.152 .58353 L
.156 .5837 L
.16 .58378 L
.164 .58372 L
.168 .58364 L
.172 .58375 L
.176 .58409 L
.18 .58446 L
.184 .58457 L
.188 .58427 L
.192 .58376 L
.196 .58344 L
.2 .58354 L
Mistroke
.204 .58395 L
.208 .5843 L
.212 .58426 L
.216 .58383 L
.22 .58331 L
.224 .58302 L
.228 .58311 L
.232 .58349 L
.236 .58394 L
.24 .58425 L
.244 .5843 L
.248 .584 L
.252 .58336 L
.256 .5825 L
.26 .58172 L
.264 .5814 L
.268 .58186 L
.272 .58313 L
.276 .5849 L
.28 .58671 L
.284 .58808 L
.288 .58876 L
.292 .58871 L
.296 .58795 L
.3 .58649 L
.304 .58423 L
.308 .58106 L
.312 .57699 L
.316 .57221 L
.32 .56706 L
.324 .56185 L
.328 .55676 L
.332 .55177 L
.336 .54671 L
.34 .54139 L
.344 .53576 L
.348 .52989 L
.352 .52399 L
.356 .51824 L
.36 .51274 L
.364 .50739 L
.368 .502 L
.372 .49634 L
.376 .49024 L
.38 .48371 L
.384 .47693 L
.388 .47015 L
.392 .46365 L
.396 .45765 L
.4 .45218 L
Mistroke
.404 .44715 L
.408 .44234 L
.412 .43746 L
.416 .43226 L
.42 .42657 L
.424 .42031 L
.428 .41357 L
.432 .40648 L
.436 .39929 L
.44 .39223 L
.444 .38551 L
.448 .37931 L
.452 .37372 L
.456 .3688 L
.46 .36452 L
.464 .36082 L
.468 .35762 L
.472 .35481 L
.476 .35227 L
.48 .34993 L
.484 .34769 L
.488 .34552 L
.492 .34336 L
.496 .34121 L
.5 .33907 L
.504 .33693 L
.508 .33482 L
.512 .33277 L
.516 .33078 L
.52 .32887 L
.524 .32704 L
.528 .32528 L
.532 .32358 L
.536 .32192 L
.54 .32028 L
.544 .31863 L
.548 .31694 L
.552 .3152 L
.556 .31338 L
.56 .31147 L
.564 .30946 L
.568 .30737 L
.572 .30518 L
.576 .30291 L
.58 .30058 L
.584 .2982 L
.588 .29581 L
.592 .29342 L
.596 .29108 L
.6 .28879 L
Mistroke
.604 .28658 L
.608 .28447 L
.612 .28247 L
.616 .2806 L
.62 .27886 L
.624 .27726 L
.628 .27581 L
.632 .27449 L
.636 .27331 L
.64 .27226 L
.644 .27134 L
.648 .27054 L
.652 .26984 L
.656 .26924 L
.66 .26871 L
.664 .26827 L
.668 .26789 L
.672 .26757 L
.676 .2673 L
.68 .26708 L
.684 .26689 L
.688 .26674 L
.692 .26661 L
.696 .2665 L
.7 .2664 L
.704 .26632 L
.708 .26625 L
.712 .2662 L
.716 .26615 L
.72 .26611 L
.724 .26607 L
.728 .26604 L
.732 .26601 L
.736 .26597 L
.74 .26594 L
.744 .26592 L
.748 .26589 L
.752 .26587 L
.756 .26585 L
.76 .26582 L
.764 .2658 L
.768 .26577 L
.772 .26575 L
.776 .26573 L
.78 .2657 L
.784 .26568 L
.788 .26566 L
.792 .26564 L
.796 .26562 L
.8 .26559 L
Mistroke
.804 .26557 L
.808 .26554 L
.812 .26552 L
.816 .2655 L
.82 .26548 L
.824 .26546 L
.828 .26544 L
.832 .26541 L
.836 .26539 L
.84 .26537 L
.844 .26534 L
.848 .26532 L
.852 .2653 L
.856 .26528 L
.86 .26526 L
.864 .26523 L
.868 .26521 L
.872 .26519 L
.876 .26516 L
.88 .26514 L
.884 .26512 L
.888 .2651 L
.892 .26508 L
.896 .26505 L
.9 .26503 L
.904 .26501 L
.908 .26499 L
.912 .26496 L
.916 .26494 L
.92 .26492 L
.924 .2649 L
.928 .26487 L
.932 .26485 L
.936 .26483 L
.94 .26481 L
.944 .26478 L
.948 .26476 L
.952 .26474 L
.956 .26472 L
.96 .26469 L
.964 .26467 L
.968 .26465 L
.972 .26463 L
.976 .2646 L
.98 .26458 L
.984 .26456 L
.988 .26454 L
.992 .26451 L
.996 .2645 L
1 .26447 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42856 L
.012 .42947 L
.016 .43009 L
.02 .42982 L
.024 .42959 L
.028 .42956 L
.032 .42976 L
.036 .42985 L
.04 .42988 L
.044 .42984 L
.048 .42986 L
.052 .4298 L
.056 .4297 L
.06 .42948 L
.064 .42932 L
.068 .42919 L
.072 .42916 L
.076 .42911 L
.08 .42909 L
.084 .42912 L
.088 .42928 L
.092 .42942 L
.096 .42944 L
.1 .42934 L
.104 .42932 L
.108 .42937 L
.112 .4294 L
.116 .42928 L
.12 .42909 L
.124 .42897 L
.128 .42898 L
.132 .429 L
.136 .42889 L
.14 .4286 L
.144 .42832 L
.148 .42822 L
.152 .42835 L
.156 .42857 L
.16 .42867 L
.164 .4286 L
.168 .42852 L
.172 .42865 L
.176 .42905 L
.18 .42946 L
.184 .42949 L
.188 .42902 L
.192 .42831 L
.196 .42784 L
.2 .42794 L
Mistroke
.204 .42847 L
.208 .42893 L
.212 .42891 L
.216 .42839 L
.22 .42772 L
.224 .42731 L
.228 .42735 L
.232 .42774 L
.236 .42823 L
.24 .42856 L
.244 .42857 L
.248 .42817 L
.252 .42736 L
.256 .4263 L
.26 .42534 L
.264 .42496 L
.268 .42552 L
.272 .42706 L
.276 .42919 L
.28 .43135 L
.284 .43297 L
.288 .43376 L
.292 .43366 L
.296 .43273 L
.3 .43093 L
.304 .42812 L
.308 .42417 L
.312 .41907 L
.316 .41306 L
.32 .40658 L
.324 .40002 L
.328 .39362 L
.332 .38736 L
.336 .38103 L
.34 .37441 L
.344 .3674 L
.348 .3601 L
.352 .35275 L
.356 .34558 L
.36 .33868 L
.364 .33197 L
.368 .32521 L
.372 .31811 L
.376 .31049 L
.38 .30235 L
.384 .29391 L
.388 .28548 L
.392 .27741 L
.396 .26993 L
.4 .2631 L
Mistroke
.404 .25681 L
.408 .25079 L
.412 .24469 L
.416 .2382 L
.42 .2311 L
.424 .22333 L
.428 .21494 L
.432 .20614 L
.436 .19719 L
.44 .18839 L
.444 .18002 L
.448 .17228 L
.452 .16532 L
.456 .15919 L
.46 .15388 L
.464 .1493 L
.468 .14533 L
.472 .14184 L
.476 .13871 L
.48 .13581 L
.484 .13304 L
.488 .13034 L
.492 .12766 L
.496 .12499 L
.5 .12233 L
.504 .11969 L
.508 .1171 L
.512 .11457 L
.516 .11212 L
.52 .10975 L
.524 .10749 L
.528 .10531 L
.532 .10321 L
.536 .10117 L
.54 .09914 L
.544 .09711 L
.548 .09503 L
.552 .09289 L
.556 .09065 L
.56 .0883 L
.564 .08583 L
.568 .08324 L
.572 .08053 L
.576 .07772 L
.58 .07484 L
.584 .07191 L
.588 .06896 L
.592 .06603 L
.596 .06313 L
.6 .0603 L
Mistroke
.604 .05758 L
.608 .05497 L
.612 .05251 L
.616 .05021 L
.62 .04807 L
.624 .04612 L
.628 .04434 L
.632 .04274 L
.636 .04131 L
.64 .04004 L
.644 .03892 L
.648 .03794 L
.652 .03709 L
.656 .03637 L
.66 .03576 L
.664 .03524 L
.668 .03481 L
.672 .03445 L
.676 .03415 L
.68 .0339 L
.684 .0337 L
.688 .03354 L
.692 .03341 L
.696 .0333 L
.7 .03322 L
.704 .03316 L
.708 .03312 L
.712 .03308 L
.716 .03305 L
.72 .03303 L
.724 .03301 L
.728 .033 L
.732 .033 L
.736 .033 L
.74 .033 L
.744 .033 L
.748 .033 L
.752 .033 L
.756 .03301 L
.76 .03301 L
.764 .03302 L
.768 .03302 L
.772 .03303 L
.776 .03304 L
.78 .03304 L
.784 .03305 L
.788 .03305 L
.792 .03306 L
.796 .03306 L
.8 .03307 L
Mistroke
.804 .03308 L
.808 .03309 L
.812 .03309 L
.816 .0331 L
.82 .0331 L
.824 .03311 L
.828 .03311 L
.832 .03312 L
.836 .03313 L
.84 .03313 L
.844 .03314 L
.848 .03315 L
.852 .03315 L
.856 .03316 L
.86 .03316 L
.864 .03317 L
.868 .03318 L
.872 .03318 L
.876 .03319 L
.88 .0332 L
.884 .0332 L
.888 .03321 L
.892 .03321 L
.896 .03322 L
.9 .03323 L
.904 .03323 L
.908 .03324 L
.912 .03325 L
.916 .03325 L
.92 .03326 L
.924 .03327 L
.928 .03327 L
.932 .03328 L
.936 .03328 L
.94 .03329 L
.944 .0333 L
.948 .03331 L
.952 .03331 L
.956 .03332 L
.96 .03332 L
.964 .03333 L
.968 .03333 L
.972 .03335 L
.976 .03335 L
.98 .03336 L
.984 .03336 L
.988 .03337 L
.992 .03337 L
.996 .03339 L
1 .03338 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo01Aoo`05001oogooOol0001COol0029oo`D00005Ool00000001oo`0200001Goo00000000
Ool0100000Qoo`00000007oo001oo`004goo1@0000=oo`0000000`00=7oo000ROomS000<Ool0029o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`08001oogoo001o
o`00Ool000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03
001oo`0002D000aoo`008Woo0P0077oo00<007ooOol03Goo00<007ooOol0?Woo000ROol00`00Oomo
o`0KOol2000>Ool00`00Oomoo`0nOol0029oo`8001eoo`8000aoo`03001oogoo03moo`008Woo0P00
7Woo0P0000=oo`00000027oo00<007ooOol0?goo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool00`00Oomoo`0NOol300000goo001oo`020004Ool00`00Oomoo`0oOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0087oo00H007ooOomoo`00Ool20002Ool00`00
Oomoo`10Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P009goo00@0
07ooOol0049oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`0VOol00`00Ool00013Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00:7oo0P00@goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo
0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool2
0002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009o
o`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/
Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007oo
Ool000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029o
o`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool2
0003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003
Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03
001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00
Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D0
07ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001o
ogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo
00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo
0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001o
ogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`00
0goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomo
ogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eo
o`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04
001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool2
0004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`00
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool0
00030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`00
1Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04OolR0003Ool0
1000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool2
0004Ool01000Oomoogoo2P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000X
Ool00`00Oomoo`0dOol2000`Ool002Qoo`03001oogoo039oo`80039oo`00:7ooG@0037oo000XOol0
0`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`09Ool30003Ool00`00Oomoo`0?Ool00`00Oomo
o`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo02aoo`8003Qoo`00:7oo00<007ooOol0:Woo0P00
>Woo000XOol00`00Oomoo`0XOol2000lOol002Qoo`03001oogoo02Moo`8003eoo`00:7oo00<007oo
Ool09Woo0P00?Woo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomo
o`0VOol00`00Oomoo`0mOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0003Ool01000Oomoo`009goo00<007ooOol0?Woo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0005Ool01000Oomoo`009goo00<007ooOol0?Woo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000UOol00`00Oomoo`0oOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo02=oo`80045oo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo029oo`80
049oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol08Woo00<007ooOol0@Goo000X
Ool00`00Oomoo`0QOol00`00Oomoo`12Ool002Qoo`03001oogoo021oo`8004Aoo`004Goo0P0017oo
00<007ooOol00goo0P000goo0`000goo00<007ooOol087oo00<007ooOol0@goo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo01moo`03001oogoo04Aoo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0NOol20016Ool0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P007goo00<007ooOol0AGoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo01eoo`03001oogoo
04Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0LOol20018Ool0
015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo01]oo`8004Uoo`00:7oo00<007ooOol0
6goo00<007ooOol0B7oo000XOol00`00Oomoo`0JOol00`00Oomoo`19Ool002Qooa/00003Ool00000
04]oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol05goo0P00
CGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00
J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Mo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5
001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<0
00=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool0
1000Oomoo`00@goo9@0037oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0?Woo0`00<Goo
000:Ool01000Oomoo`001goo00<007ooOol017oo0P00?Goo0P00=7oo000;Ool20008Ool50002Ool0
0`00Oomoo`0jOol3000eOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`80
00Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`00
77oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol20002Ool01000Oomoo`000Woo00<007ooOol00goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomo
o`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Ool0000017oo00@007ooOol0
009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009o
o`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo0P001Woo00@0
07ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@0
07ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo0`000goo10000goo
00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001o
ogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@0
07ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo10000goo00<007ooOol017oo
00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001o
ogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol0
0goo0P0017oo0P0000=oo`0000000goo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`80
00Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0;Woo0P00@Woo000LOol00`00Oomoo`0]
Ool20013Ool001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`04001oogoo
Ool20002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00
Oomoo`0:Ool001aoo`03001oogoo02]oo`03001oogoo04Aoo`0077oo0P00;7oo00<007ooOol0A7oo
000LOol00`00Oomoo`0ZOol00`00Oomoo`15Ool001aoo`03001oogoo02Yoo`03001oogoo04Eoo`00
77oo0P00:Woo00<007ooOol0AWoo000LOol00`00Oomoo`0YOol00`00Oomoo`16Ool001aoo`03001o
ogoo02Qoo`03001oogoo04Moo`0077oo0P00:Goo00<007ooOol0Agoo000LOol00`00Oomoo`0WOol0
0`00Oomoo`18Ool001aoo`8002Qoo`03001oogoo04Qoo`002goo0P0017oo00<007ooOol00Woo0`00
0goo00<007ooOol09Woo00<007ooOol0BGoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo02Eoo`03001oogoo04Yoo`002Woo00@007ooOol000]oo`03001oogoo008002Ioo`03
001oogoo04Yoo`002Woo00@007ooOol000]oo`04001oogoo000VOol00`00Oomoo`1;Ool000Yoo`04
001oogoo0007Ool40003Ool00`00Oomoo`0TOol00`00Oomoo`1;Ool000Yoo`04001oogoo0007Ool0
0`00Oomoo`04Ool2000TOol00`00Oomoo`1<Ool000]oo`8000Qoo`D0009oo`03001oogoo02=oo`03
001oogoo04aoo`0077oo00<007ooOol08Woo00<007ooOol0CGoo000LOol2000SOol00`00Oomoo`1=
Ool001aoo`03001oogoo025oo`03001oogoo04ioo`0077oo0P008Goo0P00D7oo000LOol00`00Oomo
o`0POol00`00Oomoo`1?Ool001aoo`03001oogoo01moo`80055oo`0077oo0P0087oo00<007ooOol0
D7oo000FOol30003Ool00`00Oomoo`0NOol00`00Oomoo`1AOol001Moo`03001oogoo009oo`03001o
ogoo01eoo`03001oogoo059oo`005goo00<007ooOol00Woo8@00E7oo000GOol00`00Oomoo`02Ool0
0`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000G
Ool00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yo
o`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00
009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol0
2goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`80
00Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000L
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(27889\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29964 m
.008 .29791 L
.012 .29635 L
.016 .29715 L
.02 .29981 L
.024 .30115 L
.028 .30062 L
.032 .29938 L
.036 .29785 L
.04 .29606 L
.044 .29483 L
.048 .29469 L
.052 .296 L
.056 .29873 L
.06 .30162 L
.064 .30285 L
.068 .3017 L
.072 .29939 L
.076 .29686 L
.08 .29434 L
.084 .29279 L
.088 .29344 L
.092 .29653 L
.096 .30016 L
.1 .30212 L
.104 .30167 L
.108 .29973 L
.112 .298 L
.116 .29682 L
.12 .29585 L
.124 .2955 L
.128 .29647 L
.132 .29857 L
.136 .30024 L
.14 .30027 L
.144 .29872 L
.148 .29683 L
.152 .29618 L
.156 .29698 L
.16 .29819 L
.164 .29831 L
.168 .29653 L
.172 .29393 L
.176 .29289 L
.18 .29509 L
.184 .29968 L
.188 .30365 L
.192 .30424 L
.196 .30145 L
.2 .29811 L
Mistroke
.204 .29675 L
.208 .29728 L
.212 .29741 L
.216 .29532 L
.22 .29206 L
.224 .29078 L
.228 .29349 L
.232 .29904 L
.236 .30397 L
.24 .3053 L
.244 .3028 L
.248 .29857 L
.252 .2948 L
.256 .29236 L
.26 .29099 L
.264 .29075 L
.268 .2925 L
.272 .29695 L
.276 .3031 L
.28 .308 L
.284 .30846 L
.288 .30332 L
.292 .29465 L
.296 .28662 L
.3 .28287 L
.304 .28447 L
.308 .28971 L
.312 .29578 L
.316 .30093 L
.32 .30548 L
.324 .31102 L
.328 .3188 L
.332 .32844 L
.336 .33791 L
.34 .34491 L
.344 .34839 L
.348 .34929 L
.352 .34998 L
.356 .35281 L
.36 .35868 L
.364 .36643 L
.368 .37349 L
.372 .37719 L
.376 .37619 L
.38 .37116 L
.384 .36442 L
.388 .35894 L
.392 .35706 L
.396 .35951 L
.4 .36532 L
Mistroke
.404 .37227 L
.408 .37789 L
.412 .38043 L
.416 .37946 L
.42 .37595 L
.424 .37178 L
.428 .36905 L
.432 .36928 L
.436 .37305 L
.44 .37987 L
.444 .38853 L
.448 .39749 L
.452 .40528 L
.456 .41075 L
.46 .41312 L
.464 .41201 L
.468 .40743 L
.472 .39982 L
.476 .38993 L
.48 .37874 L
.484 .36715 L
.488 .35584 L
.492 .34517 L
.496 .33526 L
.5 .32624 L
.504 .31827 L
.508 .31157 L
.512 .30629 L
.516 .30238 L
.52 .29959 L
.524 .29763 L
.528 .29634 L
.532 .29569 L
.536 .29572 L
.54 .2964 L
.544 .29748 L
.548 .29863 L
.552 .29958 L
.556 .30025 L
.56 .30072 L
.564 .3011 L
.568 .3014 L
.572 .30153 L
.576 .30135 L
.58 .30086 L
.584 .30022 L
.588 .29964 L
.592 .29926 L
.596 .29906 L
.6 .29894 L
Mistroke
.604 .29885 L
.608 .29889 L
.612 .29919 L
.616 .29984 L
.62 .30077 L
.624 .30183 L
.628 .30286 L
.632 .30383 L
.636 .30486 L
.64 .30603 L
.644 .30734 L
.648 .30867 L
.652 .30987 L
.656 .3109 L
.66 .31178 L
.664 .31261 L
.668 .31341 L
.672 .31414 L
.676 .31474 L
.68 .31523 L
.684 .31566 L
.688 .3161 L
.692 .31653 L
.696 .31685 L
.7 .31701 L
.704 .31703 L
.708 .31703 L
.712 .31713 L
.716 .31734 L
.72 .31757 L
.724 .3177 L
.728 .31769 L
.732 .31759 L
.736 .31751 L
.74 .31751 L
.744 .31758 L
.748 .31765 L
.752 .31768 L
.756 .31769 L
.76 .3177 L
.764 .31773 L
.768 .31773 L
.772 .31768 L
.776 .3176 L
.78 .31756 L
.784 .3176 L
.788 .31772 L
.792 .31782 L
.796 .31783 L
.8 .31775 L
Mistroke
.804 .31764 L
.808 .31759 L
.812 .31761 L
.816 .31768 L
.82 .31775 L
.824 .31779 L
.828 .3178 L
.832 .31778 L
.836 .31774 L
.84 .31768 L
.844 .31764 L
.848 .31765 L
.852 .31771 L
.856 .31781 L
.86 .31788 L
.864 .31786 L
.868 .31777 L
.872 .31767 L
.876 .31763 L
.88 .31767 L
.884 .31777 L
.888 .31786 L
.892 .31791 L
.896 .31788 L
.9 .31778 L
.904 .31769 L
.908 .31765 L
.912 .3177 L
.916 .3178 L
.92 .3179 L
.924 .31795 L
.928 .31791 L
.932 .3178 L
.936 .3177 L
.94 .31765 L
.944 .31773 L
.948 .31786 L
.952 .31797 L
.956 .31801 L
.96 .31792 L
.964 .31777 L
.968 .31767 L
.972 .31767 L
.976 .3178 L
.98 .31796 L
.984 .31804 L
.988 .31802 L
.992 .31788 L
.996 .31774 L
1 .31769 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .58625 m
.008 .58363 L
.012 .58267 L
.016 .58321 L
.02 .58361 L
.024 .5834 L
.028 .58322 L
.032 .58317 L
.036 .58325 L
.04 .58323 L
.044 .58325 L
.048 .58325 L
.052 .58335 L
.056 .58343 L
.06 .5835 L
.064 .58351 L
.068 .58356 L
.072 .58358 L
.076 .58355 L
.08 .58341 L
.084 .5833 L
.088 .58322 L
.092 .58318 L
.096 .58311 L
.1 .58307 L
.104 .5831 L
.108 .58325 L
.112 .58341 L
.116 .58348 L
.12 .58347 L
.124 .58349 L
.128 .58357 L
.132 .58363 L
.136 .58357 L
.14 .58344 L
.144 .58332 L
.148 .58333 L
.152 .58342 L
.156 .58346 L
.16 .58336 L
.164 .58317 L
.168 .58301 L
.172 .58302 L
.176 .58316 L
.18 .58328 L
.184 .58324 L
.188 .58308 L
.192 .58302 L
.196 .58325 L
.2 .58372 L
Mistroke
.204 .58412 L
.208 .58414 L
.212 .58376 L
.216 .58326 L
.22 .58302 L
.224 .5832 L
.228 .5836 L
.232 .58387 L
.236 .58379 L
.24 .58338 L
.244 .58292 L
.248 .58266 L
.252 .58269 L
.256 .58298 L
.26 .5834 L
.264 .58379 L
.268 .58399 L
.272 .58382 L
.276 .58321 L
.28 .58226 L
.284 .58131 L
.288 .58079 L
.292 .58104 L
.296 .5821 L
.3 .58372 L
.304 .58546 L
.308 .58693 L
.312 .58791 L
.316 .58833 L
.32 .58815 L
.324 .58729 L
.328 .58561 L
.332 .58296 L
.336 .57933 L
.34 .57492 L
.344 .57005 L
.348 .56503 L
.352 .56006 L
.356 .55515 L
.36 .55014 L
.364 .54489 L
.368 .53932 L
.372 .53352 L
.376 .52767 L
.38 .52195 L
.384 .51646 L
.388 .51115 L
.392 .50584 L
.396 .50028 L
.4 .49432 L
Mistroke
.404 .48792 L
.408 .48119 L
.412 .47439 L
.416 .46777 L
.42 .46158 L
.424 .45591 L
.428 .45072 L
.432 .44584 L
.436 .44101 L
.44 .43597 L
.444 .43052 L
.448 .42455 L
.452 .41805 L
.456 .41114 L
.46 .40399 L
.464 .39685 L
.468 .38992 L
.472 .3834 L
.476 .37744 L
.48 .3721 L
.484 .36741 L
.488 .36334 L
.492 .35981 L
.496 .35674 L
.5 .35401 L
.504 .35152 L
.508 .3492 L
.512 .34696 L
.516 .34477 L
.52 .3426 L
.524 .34043 L
.528 .33828 L
.532 .33615 L
.536 .33406 L
.54 .33203 L
.544 .33008 L
.548 .32821 L
.552 .32641 L
.556 .32468 L
.56 .32299 L
.564 .32134 L
.568 .3197 L
.572 .31804 L
.576 .31634 L
.58 .31458 L
.584 .31273 L
.588 .31079 L
.592 .30876 L
.596 .30663 L
.6 .30441 L
Mistroke
.604 .30212 L
.608 .29977 L
.612 .29738 L
.616 .29499 L
.62 .29262 L
.624 .2903 L
.628 .28804 L
.632 .28586 L
.636 .28378 L
.64 .28182 L
.644 .27999 L
.648 .27829 L
.652 .27674 L
.656 .27533 L
.66 .27406 L
.664 .27293 L
.668 .27192 L
.672 .27103 L
.676 .27025 L
.68 .26958 L
.684 .269 L
.688 .2685 L
.692 .26807 L
.696 .26772 L
.7 .26742 L
.704 .26716 L
.708 .26695 L
.712 .26676 L
.716 .26661 L
.72 .26648 L
.724 .26638 L
.728 .2663 L
.732 .26622 L
.736 .26616 L
.74 .2661 L
.744 .26605 L
.748 .26601 L
.752 .26597 L
.756 .26594 L
.76 .26591 L
.764 .26588 L
.768 .26585 L
.772 .26583 L
.776 .2658 L
.78 .26577 L
.784 .26575 L
.788 .26572 L
.792 .2657 L
.796 .26568 L
.8 .26566 L
Mistroke
.804 .26564 L
.808 .26561 L
.812 .26559 L
.816 .26557 L
.82 .26554 L
.824 .26552 L
.828 .2655 L
.832 .26548 L
.836 .26546 L
.84 .26543 L
.844 .26541 L
.848 .26539 L
.852 .26536 L
.856 .26534 L
.86 .26532 L
.864 .2653 L
.868 .26528 L
.872 .26525 L
.876 .26523 L
.88 .26521 L
.884 .26518 L
.888 .26516 L
.892 .26514 L
.896 .26512 L
.9 .2651 L
.904 .26507 L
.908 .26505 L
.912 .26503 L
.916 .26501 L
.92 .26498 L
.924 .26496 L
.928 .26494 L
.932 .26492 L
.936 .26489 L
.94 .26487 L
.944 .26485 L
.948 .26483 L
.952 .2648 L
.956 .26478 L
.96 .26476 L
.964 .26474 L
.968 .26471 L
.972 .26469 L
.976 .26467 L
.98 .26465 L
.984 .26462 L
.988 .26461 L
.992 .26458 L
.996 .26456 L
1 .26453 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43549 L
.012 .42982 L
.016 .42806 L
.02 .42991 L
.024 .43051 L
.028 .42975 L
.032 .42952 L
.036 .42965 L
.04 .42968 L
.044 .42949 L
.048 .42946 L
.052 .42949 L
.056 .42958 L
.06 .42959 L
.064 .42962 L
.068 .42964 L
.072 .42967 L
.076 .42959 L
.08 .42945 L
.084 .42927 L
.088 .42918 L
.092 .42911 L
.096 .42902 L
.1 .42888 L
.104 .42887 L
.108 .42898 L
.112 .42912 L
.116 .42913 L
.12 .42909 L
.124 .42908 L
.128 .42916 L
.132 .42923 L
.136 .42918 L
.14 .42901 L
.144 .42888 L
.148 .42887 L
.152 .42894 L
.156 .42893 L
.16 .42872 L
.164 .42837 L
.168 .4281 L
.172 .42806 L
.176 .42823 L
.18 .4284 L
.184 .42838 L
.188 .42821 L
.192 .42813 L
.196 .42839 L
.2 .42891 L
Mistroke
.204 .42934 L
.208 .42928 L
.212 .42873 L
.216 .42805 L
.22 .42772 L
.224 .42793 L
.228 .42843 L
.232 .42878 L
.236 .42868 L
.24 .42819 L
.244 .42759 L
.248 .4272 L
.252 .42716 L
.256 .42743 L
.26 .42787 L
.264 .42831 L
.268 .42854 L
.272 .42834 L
.276 .4276 L
.28 .42644 L
.284 .42524 L
.288 .42456 L
.292 .42481 L
.296 .42606 L
.3 .428 L
.304 .43011 L
.308 .43191 L
.312 .43311 L
.316 .43362 L
.32 .4334 L
.324 .43233 L
.328 .43022 L
.332 .42688 L
.336 .42231 L
.34 .41675 L
.344 .41061 L
.348 .40431 L
.352 .39809 L
.356 .39195 L
.36 .38572 L
.364 .37918 L
.368 .37224 L
.372 .36499 L
.376 .35766 L
.38 .3505 L
.384 .34362 L
.388 .33697 L
.392 .33032 L
.396 .32339 L
.4 .31597 L
Mistroke
.404 .30799 L
.408 .29962 L
.412 .29113 L
.416 .28288 L
.42 .27514 L
.424 .26805 L
.428 .26157 L
.432 .25548 L
.436 .24946 L
.44 .24319 L
.444 .23641 L
.448 .22897 L
.452 .22088 L
.456 .21227 L
.46 .20337 L
.464 .19446 L
.468 .18582 L
.472 .17771 L
.476 .17028 L
.48 .16365 L
.484 .15783 L
.488 .15278 L
.492 .14841 L
.496 .14459 L
.5 .14119 L
.504 .13811 L
.508 .13522 L
.512 .13245 L
.516 .12974 L
.52 .12705 L
.524 .12438 L
.528 .12171 L
.532 .11908 L
.536 .11651 L
.54 .114 L
.544 .11159 L
.548 .10926 L
.552 .10703 L
.556 .10489 L
.56 .10282 L
.564 .1008 L
.568 .09878 L
.572 .09674 L
.576 .09464 L
.58 .09246 L
.584 .09019 L
.588 .08779 L
.592 .08528 L
.596 .08265 L
.6 .07991 L
Mistroke
.604 .07708 L
.608 .07419 L
.612 .07125 L
.616 .06831 L
.62 .06538 L
.624 .0625 L
.628 .0597 L
.632 .05701 L
.636 .05446 L
.64 .05205 L
.644 .04981 L
.648 .04773 L
.652 .04583 L
.656 .0441 L
.66 .04254 L
.664 .04116 L
.668 .03994 L
.672 .03886 L
.676 .03793 L
.68 .03713 L
.684 .03644 L
.688 .03585 L
.692 .03536 L
.696 .03494 L
.7 .03459 L
.704 .0343 L
.708 .03407 L
.712 .03389 L
.716 .03374 L
.72 .03362 L
.724 .03352 L
.728 .03344 L
.732 .03338 L
.736 .03333 L
.74 .0333 L
.744 .03328 L
.748 .03326 L
.752 .03325 L
.756 .03324 L
.76 .03323 L
.764 .03323 L
.768 .03323 L
.772 .03323 L
.776 .03323 L
.78 .03324 L
.784 .03324 L
.788 .03325 L
.792 .03325 L
.796 .03325 L
.8 .03326 L
Mistroke
.804 .03326 L
.808 .03327 L
.812 .03328 L
.816 .03329 L
.82 .03329 L
.824 .0333 L
.828 .0333 L
.832 .03331 L
.836 .03331 L
.84 .03332 L
.844 .03333 L
.848 .03333 L
.852 .03334 L
.856 .03335 L
.86 .03335 L
.864 .03336 L
.868 .03336 L
.872 .03337 L
.876 .03338 L
.88 .03338 L
.884 .03339 L
.888 .0334 L
.892 .0334 L
.896 .03341 L
.9 .03342 L
.904 .03342 L
.908 .03343 L
.912 .03343 L
.916 .03344 L
.92 .03345 L
.924 .03346 L
.928 .03346 L
.932 .03347 L
.936 .03347 L
.94 .03348 L
.944 .03348 L
.948 .03349 L
.952 .0335 L
.956 .03351 L
.96 .03351 L
.964 .03352 L
.968 .03352 L
.972 .03353 L
.976 .03353 L
.98 .03355 L
.984 .03355 L
.988 .03356 L
.992 .03356 L
.996 .03357 L
1 .03357 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo01Yoo`80051oo`008Woo0`0000Eoo`00000007oo00800003Ool0000000H00005Ool00000
001oo`04000017oo000000004goo1000>7oo000ROomS000<Ool0029oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`04001oogoo0003Ool20002Ool01@00Oomoogoo
00000goo00H007ooOomoo`00Ool30003Ool01@00Oomoogoo00000Woo00<007oo00008P0037oo000R
Ool2000NOol00`00Oomoo`0>Ool00`00Oomoo`0kOol0029oo`03001oogoo01ioo`03001oogoo00ao
o`03001oogoo03aoo`008Woo0P007goo0P003Goo00<007ooOol0?7oo000ROol2000QOol00`00Oomo
o`020008Ool00`00Oomoo`0lOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001o
ogoo025oo`04001oo`000002Ool00`00Oomoo`02Ool00`00Oomoo`0mOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P008Woo0P000Woo0P0000=oo`00Ool00Woo00<007oo
Ool0?Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8002Uoo`05001o
ogooOol0000oOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0:Goo00<007oo0000@7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8002Yoo`<0041oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2000[Ool00`00
Oomoo`0oOol000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo
00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]
Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`00
0goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001o
ogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`00
2goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo
0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
2goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007oo
Oomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo
1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001o
ogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`80
00Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`80
00Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007oo
Ool02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006
Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04
001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=o
o`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001o
ogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0
0goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo1000
0goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007oo
Oomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol0
17oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007oo
Ool017oo00<007ooOol07`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P00
27oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D0009oo`@0009oo`<000Aoo`8000Ao
o`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0=Woo0`00;Goo000XOol00`00Oomo
o`0dOol3000_Ool002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol0
2goo0`0000=oo`00Ool047oo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`0^Ool3
000eOol002Qoo`03001oogoo02aoo`<003Moo`00:7oo00<007ooOol0:Woo0`00>Goo000XOol00`00
Oomoo`0YOol2000kOol002Qoo`03001oogoo02Uoo`03001oogoo03Yoo`002goo0P0017oo00<007oo
Ool00goo0P0017oo0P000goo0`000goo00<007ooOol0:7oo00<007ooOol0>goo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol002Yoo`03001oogoo03]o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol002Uoo`03
001oogoo03aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool00P009goo00<007ooOol0?Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo
001oo`040003Ool00`00Oomoo`0VOol00`00Oomoo`0mOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0UOol00`00Oomoo`0nOol000]oo`8000Yoo`80
00Aoo`80009oo`D0009oo`03001oogoo02Aoo`80041oo`00:7oo00<007ooOol097oo00<007ooOol0
?goo000XOol00`00Oomoo`0SOol00`00Oomoo`10Ool0015oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`03001oogoo029oo`03001oogoo045oo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`0ROol00`00Oomoo`11Ool0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol08Goo00<007ooOol0@Woo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`80025oo`8004Aoo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0OOol20015Ool0011oo`04001oogoo0008Ool0
1000Oomoo`000Woo0P0017oo00<007ooOol07goo00<007ooOol0A7oo000AOol2000:Ool20004Ool0
0`00Oomoo`02Ool00`00Oomoo`0NOol00`00Oomoo`15Ool002Qoo`03001oogoo01eoo`8004Moo`00
:7oo00<007ooOol077oo0P00B7oo000XOolM00000goo00000019Ool000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`<000=oo`03001oogoo01Uoo`<004Yoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<0
07ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`00
2goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol004Eoob<000aoo`002Woo
00@007ooOol000Moo`@000=oo`03001oogoo045oo`<002ioo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`80041oo`80035oo`002goo0P0027oo1@000Woo00<007ooOol0?Goo0`00<Woo000LOol0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool50002Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002
Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomo
ogoo001oo`<0009oo`04001oogoo0005Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo
011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo009oo`800005Ool007ooOol00002Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000=oo`04001oogoo0002Ool00`00Oomo
o`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04
001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`<00003Ool00000008000=oo`04001oogoo0004
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@0
00=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool2
0004Ool01000Oomoo`000Woo00@007ooOol000Aoo`<0009oo`03001oogoo00Aoo`04001oogoo0004
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`00
00Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`80
00Aoo`<000=oo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`00
77oo00<007ooOol0<Goo0P00?goo000LOol00`00Oomoo`0`Ool00`00Oomoo`0oOol001aoofT000ao
o`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00002Ool20003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<0
07ooOol0;Woo00<007ooOol0@Goo000LOol2000_Ool00`00Oomoo`11Ool001aoo`03001oogoo02eo
o`03001oogoo049oo`0077oo00<007ooOol0;Goo00<007ooOol0@Woo000LOol2000]Ool00`00Oomo
o`13Ool001aoo`03001oogoo02aoo`03001oogoo04=oo`0077oo00<007ooOol0:goo00<007ooOol0
A7oo000LOol2000[Ool20016Ool001aoo`03001oogoo02Yoo`03001oogoo04Eoo`0077oo0P00:Woo
00<007ooOol0AWoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`0YOol00`00Oomo
o`16Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0:7oo00<007ooOol0
Agoo000:Ool01000Oomoo`002goo00<007ooOol00P00:Goo00<007ooOol0Agoo000:Ool01000Oomo
o`002goo00@007ooOol002Uoo`03001oogoo04Qoo`002Woo00@007ooOol000Moo`@000=oo`03001o
ogoo02Moo`03001oogoo04Qoo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8002Moo`03001o
ogoo04Uoo`002goo0P0027oo1@000Woo00<007ooOol09Goo0P00Bgoo000LOol00`00Oomoo`0UOol0
0`00Oomoo`1:Ool001aoo`8002Eoo`03001oogoo04]oo`0077oo00<007ooOol097oo00<007ooOol0
Bgoo000LOol2000TOol00`00Oomoo`1<Ool001aoo`03001oogoo029oo`8004ioo`0077oo00<007oo
Ool08Woo00<007ooOol0CGoo000LOol2000ROol2001?Ool001Ioo`<000=oo`03001oogoo025oo`03
001oogoo04ioo`005goo00<007ooOol00Woo00<007ooOol06goo00<007ooOol00Woo00<007ooOol0
Cgoo000GOol00`00Oomoo`02OolT001AOol001Moo`03001oogoo009oo`8007=oo`005goo00<007oo
Ool00Woo00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo
079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`00
0goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool0
0`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]o
o`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007oo
Ool0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(28056\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30264 m
.008 .30041 L
.012 .29862 L
.016 .29622 L
.02 .29462 L
.024 .29457 L
.028 .29608 L
.032 .29821 L
.036 .3002 L
.04 .30153 L
.044 .30134 L
.048 .29942 L
.052 .29677 L
.056 .29511 L
.06 .29522 L
.064 .29637 L
.068 .29795 L
.072 .29971 L
.076 .30101 L
.08 .30071 L
.084 .29878 L
.088 .29675 L
.092 .29605 L
.096 .29687 L
.1 .29805 L
.104 .29852 L
.108 .29837 L
.112 .29806 L
.116 .29753 L
.12 .29634 L
.124 .29536 L
.128 .29617 L
.132 .2988 L
.136 .30151 L
.14 .30218 L
.144 .30024 L
.148 .29706 L
.152 .29467 L
.156 .2943 L
.16 .29563 L
.164 .2977 L
.168 .29949 L
.172 .30042 L
.176 .30058 L
.18 .29998 L
.184 .29831 L
.188 .29548 L
.192 .29234 L
.196 .291 L
.2 .29326 L
Mistroke
.204 .29851 L
.208 .30341 L
.212 .30449 L
.216 .30125 L
.22 .29678 L
.224 .29517 L
.228 .29754 L
.232 .30099 L
.236 .30149 L
.24 .2976 L
.244 .29194 L
.248 .28888 L
.252 .29081 L
.256 .29646 L
.26 .30228 L
.264 .30531 L
.268 .30477 L
.272 .30168 L
.276 .2974 L
.28 .29291 L
.284 .28923 L
.288 .28788 L
.292 .29032 L
.296 .29657 L
.3 .30432 L
.304 .30972 L
.308 .30963 L
.312 .30374 L
.316 .29485 L
.32 .28715 L
.324 .28364 L
.328 .28464 L
.332 .28823 L
.336 .29211 L
.34 .29547 L
.344 .29937 L
.348 .30561 L
.352 .31505 L
.356 .32658 L
.36 .33756 L
.364 .3454 L
.368 .34911 L
.372 .34995 L
.376 .35064 L
.38 .35378 L
.384 .36028 L
.388 .36893 L
.392 .37698 L
.396 .38162 L
.4 .38142 L
Mistroke
.404 .37694 L
.408 .37043 L
.412 .36481 L
.416 .36239 L
.42 .36406 L
.424 .36912 L
.428 .37571 L
.432 .38159 L
.436 .38498 L
.44 .38508 L
.444 .38226 L
.448 .37795 L
.452 .37408 L
.456 .37253 L
.46 .3745 L
.464 .38014 L
.468 .38857 L
.472 .39821 L
.476 .4073 L
.48 .41437 L
.484 .41848 L
.488 .41921 L
.492 .41651 L
.496 .41058 L
.5 .40189 L
.504 .39114 L
.508 .37924 L
.512 .36711 L
.516 .35548 L
.52 .34474 L
.524 .33501 L
.528 .32628 L
.532 .31861 L
.536 .31217 L
.54 .30712 L
.544 .30344 L
.548 .30093 L
.552 .29929 L
.556 .29829 L
.56 .29784 L
.564 .29796 L
.568 .29861 L
.572 .29958 L
.576 .30059 L
.58 .30141 L
.584 .30197 L
.588 .30236 L
.592 .30269 L
.596 .30296 L
.6 .30303 L
Mistroke
.604 .3028 L
.608 .30229 L
.612 .30167 L
.616 .30118 L
.62 .30095 L
.624 .30093 L
.628 .30101 L
.632 .3011 L
.636 .30126 L
.64 .30159 L
.644 .3022 L
.648 .30305 L
.652 .30403 L
.656 .30505 L
.66 .30607 L
.664 .30714 L
.668 .30827 L
.672 .30941 L
.676 .31046 L
.68 .31135 L
.684 .31213 L
.688 .3129 L
.692 .31369 L
.696 .31448 L
.7 .31516 L
.704 .31566 L
.708 .31598 L
.712 .31621 L
.716 .31644 L
.72 .31671 L
.724 .31696 L
.728 .31718 L
.732 .31733 L
.736 .31744 L
.74 .31751 L
.744 .31754 L
.748 .31752 L
.752 .31748 L
.756 .31746 L
.76 .31752 L
.764 .31766 L
.768 .31778 L
.772 .31781 L
.776 .31771 L
.78 .31756 L
.784 .31748 L
.788 .31751 L
.792 .31763 L
.796 .31776 L
.8 .3178 L
Mistroke
.804 .31776 L
.808 .31768 L
.812 .3176 L
.816 .31757 L
.82 .31758 L
.824 .31764 L
.828 .31772 L
.832 .31779 L
.836 .3178 L
.84 .31774 L
.844 .31764 L
.848 .31757 L
.852 .31758 L
.856 .31768 L
.86 .31778 L
.864 .31783 L
.868 .31781 L
.872 .31771 L
.876 .31763 L
.88 .31761 L
.884 .31766 L
.888 .31775 L
.892 .31782 L
.896 .31783 L
.9 .31778 L
.904 .31771 L
.908 .31767 L
.912 .31768 L
.916 .31773 L
.92 .31781 L
.924 .31784 L
.928 .31782 L
.932 .31777 L
.936 .31771 L
.94 .3177 L
.944 .31774 L
.948 .3178 L
.952 .31787 L
.956 .31787 L
.96 .3178 L
.964 .31773 L
.968 .31771 L
.972 .31775 L
.976 .31784 L
.98 .3179 L
.984 .31791 L
.988 .31784 L
.992 .31774 L
.996 .31773 L
1 .31776 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57551 m
.008 .58287 L
.012 .58536 L
.016 .58281 L
.02 .58211 L
.024 .583 L
.028 .58331 L
.032 .58298 L
.036 .58292 L
.04 .58299 L
.044 .58302 L
.048 .58292 L
.052 .58289 L
.056 .58286 L
.06 .58284 L
.064 .58275 L
.068 .58275 L
.072 .58278 L
.076 .58285 L
.08 .58289 L
.084 .58296 L
.088 .58306 L
.092 .58316 L
.096 .58317 L
.1 .58311 L
.104 .58301 L
.108 .58295 L
.112 .58289 L
.116 .58277 L
.12 .58262 L
.124 .58258 L
.128 .58266 L
.132 .5828 L
.136 .58289 L
.14 .58293 L
.144 .58297 L
.148 .58308 L
.152 .58318 L
.156 .58319 L
.16 .58307 L
.164 .58293 L
.168 .58288 L
.172 .58296 L
.176 .58308 L
.18 .58309 L
.184 .58293 L
.188 .5827 L
.192 .58257 L
.196 .58264 L
.2 .5828 L
Mistroke
.204 .58284 L
.208 .58267 L
.212 .58245 L
.216 .58245 L
.22 .5828 L
.224 .58334 L
.228 .58371 L
.232 .58366 L
.236 .58325 L
.24 .58281 L
.244 .58265 L
.248 .58285 L
.252 .58319 L
.256 .5834 L
.26 .58331 L
.264 .58299 L
.268 .5826 L
.272 .58233 L
.276 .58226 L
.28 .58244 L
.284 .58281 L
.288 .58328 L
.292 .58363 L
.296 .5836 L
.3 .58306 L
.304 .58209 L
.308 .58103 L
.312 .58034 L
.316 .58035 L
.32 .58116 L
.324 .58254 L
.328 .58415 L
.332 .58566 L
.336 .58686 L
.34 .58767 L
.344 .58801 L
.348 .58774 L
.352 .58663 L
.356 .58453 L
.36 .58139 L
.364 .57738 L
.368 .57283 L
.372 .56804 L
.376 .56323 L
.38 .55842 L
.384 .55351 L
.388 .54835 L
.392 .54287 L
.396 .53714 L
.4 .53132 L
Mistroke
.404 .52561 L
.408 .52012 L
.412 .51483 L
.416 .50958 L
.42 .50415 L
.424 .49835 L
.428 .4921 L
.432 .48547 L
.436 .47867 L
.44 .47196 L
.444 .46559 L
.448 .45971 L
.452 .45433 L
.456 .44933 L
.46 .4445 L
.464 .43959 L
.468 .43436 L
.472 .42865 L
.476 .42242 L
.48 .41572 L
.484 .40869 L
.488 .40152 L
.492 .39445 L
.496 .38768 L
.5 .38138 L
.504 .37566 L
.508 .37057 L
.512 .36611 L
.516 .36223 L
.52 .35885 L
.524 .35588 L
.528 .35322 L
.532 .35077 L
.536 .34845 L
.54 .34621 L
.544 .344 L
.548 .34182 L
.552 .33965 L
.556 .3375 L
.56 .33539 L
.564 .33332 L
.568 .33132 L
.572 .3294 L
.576 .32755 L
.58 .32578 L
.584 .32407 L
.588 .3224 L
.592 .32076 L
.596 .31912 L
.6 .31746 L
Mistroke
.604 .31574 L
.608 .31395 L
.612 .31208 L
.616 .3101 L
.62 .30803 L
.624 .30587 L
.628 .30363 L
.632 .30132 L
.636 .29896 L
.64 .29658 L
.644 .2942 L
.648 .29184 L
.652 .28953 L
.656 .28729 L
.66 .28514 L
.664 .2831 L
.668 .28118 L
.672 .2794 L
.676 .27775 L
.68 .27625 L
.684 .27488 L
.688 .27364 L
.692 .27254 L
.696 .27157 L
.7 .27072 L
.704 .26998 L
.708 .26933 L
.712 .26878 L
.716 .2683 L
.72 .26789 L
.724 .26754 L
.728 .26725 L
.732 .26701 L
.736 .26681 L
.74 .26664 L
.744 .2665 L
.748 .26638 L
.752 .26627 L
.756 .26619 L
.76 .26611 L
.764 .26605 L
.768 .266 L
.772 .26596 L
.776 .26592 L
.78 .26588 L
.784 .26584 L
.788 .26581 L
.792 .26578 L
.796 .26576 L
.8 .26573 L
Mistroke
.804 .26571 L
.808 .26568 L
.812 .26566 L
.816 .26563 L
.82 .26561 L
.824 .26559 L
.828 .26556 L
.832 .26554 L
.836 .26552 L
.84 .2655 L
.844 .26548 L
.848 .26545 L
.852 .26543 L
.856 .26541 L
.86 .26538 L
.864 .26536 L
.868 .26534 L
.872 .26532 L
.876 .2653 L
.88 .26527 L
.884 .26525 L
.888 .26523 L
.892 .2652 L
.896 .26518 L
.9 .26516 L
.904 .26514 L
.908 .26512 L
.912 .26509 L
.916 .26507 L
.92 .26505 L
.924 .26503 L
.928 .265 L
.932 .26498 L
.936 .26496 L
.94 .26494 L
.944 .26491 L
.948 .26489 L
.952 .26487 L
.956 .26485 L
.96 .26482 L
.964 .2648 L
.968 .26478 L
.972 .26476 L
.976 .26473 L
.98 .26472 L
.984 .26469 L
.988 .26467 L
.992 .26464 L
.996 .26463 L
1 .2646 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43231 L
.012 .43014 L
.016 .42921 L
.02 .42967 L
.024 .43006 L
.028 .42987 L
.032 .42973 L
.036 .42969 L
.04 .42975 L
.044 .42967 L
.048 .42961 L
.052 .42954 L
.056 .42952 L
.06 .42944 L
.064 .42938 L
.068 .42931 L
.072 .42934 L
.076 .42934 L
.08 .42935 L
.084 .42934 L
.088 .42941 L
.092 .42948 L
.096 .42947 L
.1 .42935 L
.104 .42924 L
.108 .42917 L
.112 .42909 L
.116 .42893 L
.12 .42877 L
.124 .42868 L
.128 .42874 L
.132 .42883 L
.136 .42886 L
.14 .42881 L
.144 .4288 L
.148 .42889 L
.152 .42902 L
.156 .42905 L
.16 .42895 L
.164 .42879 L
.168 .42872 L
.172 .42877 L
.176 .42884 L
.18 .42877 L
.184 .42849 L
.188 .42814 L
.192 .42794 L
.196 .428 L
.2 .42819 L
Mistroke
.204 .42824 L
.208 .42805 L
.212 .42778 L
.216 .42777 L
.22 .42817 L
.224 .42878 L
.228 .42916 L
.232 .42901 L
.236 .42842 L
.24 .42783 L
.244 .42763 L
.248 .42789 L
.252 .42835 L
.256 .42862 L
.26 .42849 L
.264 .42803 L
.268 .42748 L
.272 .42706 L
.276 .42691 L
.28 .42708 L
.284 .42753 L
.288 .4281 L
.292 .42853 L
.296 .4285 L
.3 .42781 L
.304 .42658 L
.308 .42522 L
.312 .4243 L
.316 .42426 L
.32 .4252 L
.324 .42688 L
.328 .42885 L
.332 .43072 L
.336 .43221 L
.34 .43322 L
.344 .43363 L
.348 .43325 L
.352 .43183 L
.356 .42914 L
.36 .42517 L
.364 .42014 L
.368 .41443 L
.372 .40844 L
.376 .40244 L
.38 .39645 L
.384 .39031 L
.388 .38386 L
.392 .37699 L
.396 .36981 L
.4 .36252 L
Mistroke
.404 .35538 L
.408 .34852 L
.412 .34192 L
.416 .33537 L
.42 .3286 L
.424 .32136 L
.428 .31356 L
.432 .30529 L
.436 .2968 L
.44 .28842 L
.444 .28046 L
.448 .27312 L
.452 .26641 L
.456 .26018 L
.46 .25417 L
.464 .24806 L
.468 .24154 L
.472 .23442 L
.476 .22665 L
.48 .21829 L
.484 .20953 L
.488 .20061 L
.492 .19181 L
.496 .18338 L
.5 .17554 L
.504 .16842 L
.508 .1621 L
.512 .15656 L
.516 .15174 L
.52 .14755 L
.524 .14386 L
.528 .14054 L
.532 .1375 L
.536 .13463 L
.54 .13187 L
.544 .12914 L
.548 .12644 L
.552 .12375 L
.556 .12109 L
.56 .11847 L
.564 .11592 L
.568 .11345 L
.572 .11107 L
.576 .10879 L
.58 .1066 L
.584 .1045 L
.588 .10245 L
.592 .10043 L
.596 .09841 L
.6 .09635 L
Mistroke
.604 .09423 L
.608 .09202 L
.612 .08971 L
.616 .08728 L
.62 .08473 L
.624 .08207 L
.628 .0793 L
.632 .07644 L
.636 .07352 L
.64 .07058 L
.644 .06764 L
.648 .06473 L
.652 .06189 L
.656 .05913 L
.66 .05648 L
.664 .05397 L
.668 .05161 L
.672 .04942 L
.676 .04739 L
.68 .04554 L
.684 .04387 L
.688 .04237 L
.692 .04104 L
.696 .03987 L
.7 .03883 L
.704 .03793 L
.708 .03716 L
.712 .0365 L
.716 .03594 L
.72 .03547 L
.724 .03508 L
.728 .03475 L
.732 .03448 L
.736 .03426 L
.74 .03408 L
.744 .03393 L
.748 .03381 L
.752 .03372 L
.756 .03365 L
.76 .0336 L
.764 .03356 L
.768 .03353 L
.772 .0335 L
.776 .03348 L
.78 .03347 L
.784 .03346 L
.788 .03346 L
.792 .03346 L
.796 .03346 L
.8 .03346 L
Mistroke
.804 .03346 L
.808 .03346 L
.812 .03347 L
.816 .03347 L
.82 .03348 L
.824 .03349 L
.828 .03349 L
.832 .0335 L
.836 .0335 L
.84 .03351 L
.844 .03351 L
.848 .03352 L
.852 .03353 L
.856 .03354 L
.86 .03354 L
.864 .03355 L
.868 .03355 L
.872 .03356 L
.876 .03356 L
.88 .03357 L
.884 .03358 L
.888 .03359 L
.892 .03359 L
.896 .0336 L
.9 .0336 L
.904 .03361 L
.908 .03362 L
.912 .03362 L
.916 .03363 L
.92 .03364 L
.924 .03364 L
.928 .03365 L
.932 .03365 L
.936 .03366 L
.94 .03367 L
.944 .03367 L
.948 .03368 L
.952 .03369 L
.956 .0337 L
.96 .0337 L
.964 .03371 L
.968 .03371 L
.972 .03372 L
.976 .03372 L
.98 .03373 L
.984 .03373 L
.988 .03375 L
.992 .03375 L
.996 .03376 L
1 .03376 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo01Uoo`03001oogoo008004ioo`008Woo100000Eoo`00000007oo00D00004Ool00000Ool3
00000goo001oo`02000027oo00000000Ool007oo000DOol2000gOol0029oof<000aoo`008Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`80
009oo`8000=oo`05001oogooOol00003Ool01000Oomoogoo0P000Woo00D007ooOomoo`00009oo`04
001oogooOolQ000<Ool0029oo`80025oo`03001oogoo00ioo`03001oogoo03Qoo`008Woo00<007oo
Ool087oo00<007ooOol03Goo00<007ooOol0>Goo000ROol2000ROol00`00Oomoo`0<Ool00`00Oomo
o`0iOol0029oo`8002=oo`8000]oo`03001oogoo03Yoo`002goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo00<007ooOol08goo00@007oo000000Qoo`03001oogoo03Yoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000TOol01P00Ool007oo001oo`8000Aoo`03001o
ogoo03Yoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000UOol00`00
Oomoo`020002Ool01000Oomoo`00?Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo02]oo`04001oogoo000mOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P00;Goo0`00?Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`8002eoo`8003ioo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;
Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007oo
Oomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool2
0003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
1Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomo
o`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0
K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004
Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007oo
Ool00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P00
17oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo
0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo
0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003
Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@0
07ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo
000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`00
0Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomo
o`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool0
0`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003
Ool00`00Oomoo`04Ool01@00Oomoo`00Ool07@000goo00@007ooOol000Eoo`00:7oo00<007ooOol0
2Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`P000Ao
o`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0>Goo0P00:goo000XOol0
0`00Oomoo`0gOol2000]Ool002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<0
07ooOol03Woo0`0047oo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`0aOol2000c
Ool002Qoo`03001oogoo02ioo`<003Eoo`00:7oo00<007ooOol0;Goo0P00=goo000XOol00`00Oomo
o`0/Ool2000hOol002Qoo`03001oogoo02]oo`8003Uoo`002goo0P0017oo00<007ooOol00goo0P00
17oo0P000goo0`000goo00<007ooOol0:Woo0P00>Woo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`06001oogoo001oo`000goo00@007ooOol002aoo`03001oogoo03Uoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol002]oo`8003]oo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00:Woo00<007ooOol0>Woo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`0X
Ool00`00Oomoo`0kOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006
Ool00`00Oomoo`0WOol2000mOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo02Io
o`8003ioo`00:7oo00<007ooOol09Woo00<007ooOol0?Goo000XOol00`00Oomoo`0UOol00`00Oomo
o`0nOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo02Eoo`03001oogoo
03ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0TOol0
0`00Oomoo`0oOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool08goo0P00@Goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8002=o
o`80049oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0R
Ool00`00Oomoo`11Ool0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0
8Goo00<007ooOol0@Woo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0POol20014
Ool002Qoo`03001oogoo01moo`8004Eoo`00:7oo00<007ooOol07goo00<007ooOol0A7oo000XOolO
00000goo00000017Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001o
ogoo01aoo`8004Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo
00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00
Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007oo
Ool0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool0
1000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00
Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000
Oomoo`002goo00@007ooOol004Qoob0000aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo
04=oo`@002]oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80049oo`<002ioo`002goo0P00
27oo1@000Woo00<007ooOol0@7oo0P00<7oo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004
Ool20004Ool20005Ool30003Ool30003Ool30005Ool50003Ool20004Ool20005Ool50002Ool30004
Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo10000Woo00<007ooOol00goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000
Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol0
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool200001Goo
001oogoo00001Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<0
07ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`03Ool3
0002Ool01000Oomoo`001goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomo
o`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo
00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001o
ogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@0
07ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P0000Aoo`00000000Ioo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomo
ogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=o
o`8000Aoo`8000Ioo`<00003Ool0000000<000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009o
o`D000=oo`8000Ioo`0077oo00<007ooOol0<goo0`00?7oo000LOol00`00Oomoo`0cOol00`00Oomo
o`0lOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Ool007oo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomo
o`0:Ool001aoo`03001oogoo035oo`03001oogoo03ioo`0077oo0P00<Goo00<007ooOol0?goo000L
Ool00`00Oomoo`0`Ool00`00Oomoo`0oOol001aoo`03001oogoo02moo`03001oogoo041oo`0077oo
0P00<7oo00<007ooOol0@7oo000LOol00`00Oomoo`0^Ool00`00Oomoo`11Ool001aoo`03001oogoo
02ioo`03001oogoo045oo`0077oo0P00;Woo0P00@goo000LOol00`00Oomoo`0]Ool00`00Oomoo`12
Ool001aoo`8002eoo`03001oogoo04=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007oo
Ool0;7oo00<007ooOol0@goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo
02]oo`03001oogoo04Aoo`002Woo00@007ooOol000]oo`03001oogoo008002]oo`03001oogoo04Eo
o`002Woo00@007ooOol000]oo`04001oogoo000/Ool00`00Oomoo`15Ool000Yoo`04001oogoo0007
Ool40003Ool00`00Oomoo`0YOol00`00Oomoo`16Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04
Ool2000ZOol00`00Oomoo`16Ool000]oo`8000Qoo`D0009oo`03001oogoo02Qoo`8004Qoo`0077oo
00<007ooOol0:7oo00<007ooOol0Agoo000LOol2000XOol00`00Oomoo`18Ool001aoo`03001oogoo
02Moo`03001oogoo04Qoo`0077oo0P009goo00<007ooOol0BGoo000LOol00`00Oomoo`0UOol2001;
Ool001aoo`03001oogoo02Eoo`03001oogoo04Yoo`0077oo0P009Goo00<007ooOol0Bgoo000FOol3
0003Ool00`00Oomoo`0SOol2001=Ool001Moo`03001oogoo009oo`03001oogoo01eoo`8000Aoo`03
001oogoo04aoo`005goo00<007ooOol00Woo9P00Cgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1b
Ool001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomo
o`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03
001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001o
ogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007oo
Ool00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001o
ogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(28223\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29382 m
.008 .29656 L
.012 .3005 L
.016 .30178 L
.02 .30009 L
.024 .29876 L
.028 .298 L
.032 .297 L
.036 .29624 L
.04 .29706 L
.044 .29902 L
.048 .30022 L
.052 .30004 L
.056 .29893 L
.06 .2975 L
.064 .29607 L
.068 .2953 L
.072 .29611 L
.076 .29833 L
.08 .30045 L
.084 .30101 L
.088 .29979 L
.092 .29784 L
.096 .29626 L
.1 .29552 L
.104 .29571 L
.108 .29717 L
.112 .29983 L
.116 .30204 L
.12 .30184 L
.124 .29914 L
.128 .29595 L
.132 .29426 L
.136 .29437 L
.14 .29556 L
.144 .29702 L
.148 .2986 L
.152 .30016 L
.156 .30096 L
.16 .30029 L
.164 .29836 L
.168 .29642 L
.172 .2957 L
.176 .29651 L
.18 .29805 L
.184 .29888 L
.188 .29829 L
.192 .29695 L
.196 .29645 L
.2 .2979 L
Mistroke
.204 .30033 L
.208 .30118 L
.212 .29875 L
.216 .29421 L
.22 .29104 L
.224 .29208 L
.228 .2967 L
.232 .3012 L
.236 .3023 L
.24 .30006 L
.244 .29751 L
.248 .29756 L
.252 .30002 L
.256 .30191 L
.26 .30054 L
.264 .2961 L
.268 .29149 L
.272 .28982 L
.276 .29194 L
.28 .29626 L
.284 .30044 L
.288 .30307 L
.292 .30393 L
.296 .30305 L
.3 .3002 L
.304 .29537 L
.308 .28989 L
.312 .28649 L
.316 .28779 L
.32 .29424 L
.324 .30317 L
.328 .31005 L
.332 .31121 L
.336 .30603 L
.34 .29723 L
.344 .28901 L
.348 .28442 L
.352 .28396 L
.356 .28598 L
.36 .2885 L
.364 .29089 L
.368 .2943 L
.372 .3005 L
.376 .31035 L
.38 .32275 L
.384 .335 L
.388 .34429 L
.392 .34929 L
.396 .3509 L
.4 .35172 L
Mistroke
.404 .35457 L
.408 .36089 L
.412 .36994 L
.416 .37916 L
.42 .38547 L
.424 .38685 L
.428 .38331 L
.432 .37685 L
.436 .37054 L
.44 .36713 L
.444 .36798 L
.448 .37267 L
.452 .37937 L
.456 .38573 L
.46 .38979 L
.464 .39058 L
.468 .3883 L
.472 .38409 L
.476 .37968 L
.48 .37686 L
.484 .37706 L
.488 .38097 L
.492 .38831 L
.496 .39789 L
.5 .408 L
.504 .41683 L
.508 .42299 L
.512 .42569 L
.516 .42476 L
.52 .4204 L
.524 .41305 L
.528 .40328 L
.532 .39179 L
.536 .37941 L
.54 .36699 L
.544 .35518 L
.548 .34438 L
.552 .33471 L
.556 .32619 L
.56 .31886 L
.564 .31282 L
.568 .30816 L
.572 .30481 L
.576 .30254 L
.58 .30107 L
.584 .30018 L
.588 .29983 L
.592 .30003 L
.596 .3007 L
.6 .30164 L
Mistroke
.604 .30258 L
.608 .30331 L
.612 .30376 L
.616 .30402 L
.62 .30421 L
.624 .30432 L
.628 .30431 L
.632 .3041 L
.636 .30375 L
.64 .30337 L
.644 .3031 L
.648 .30298 L
.652 .30294 L
.656 .30296 L
.66 .30305 L
.664 .30333 L
.668 .30389 L
.672 .3047 L
.676 .30564 L
.68 .30655 L
.684 .30738 L
.688 .30818 L
.692 .30906 L
.696 .31006 L
.7 .31111 L
.704 .31211 L
.708 .31297 L
.712 .31369 L
.716 .31429 L
.72 .31483 L
.724 .31531 L
.728 .31574 L
.732 .31613 L
.736 .31648 L
.74 .31681 L
.744 .31708 L
.748 .31725 L
.752 .31732 L
.756 .31731 L
.76 .31732 L
.764 .3174 L
.768 .31754 L
.772 .31767 L
.776 .31772 L
.78 .31769 L
.784 .31762 L
.788 .31757 L
.792 .31756 L
.796 .31759 L
.8 .31762 L
Mistroke
.804 .31765 L
.808 .31769 L
.812 .3177 L
.816 .31769 L
.82 .31764 L
.824 .31758 L
.828 .31755 L
.832 .31759 L
.836 .31766 L
.84 .31773 L
.844 .31774 L
.848 .3177 L
.852 .31763 L
.856 .31759 L
.86 .31759 L
.864 .31763 L
.868 .31769 L
.872 .31773 L
.876 .31774 L
.88 .31772 L
.884 .31768 L
.888 .31764 L
.892 .31762 L
.896 .31764 L
.9 .31769 L
.904 .31775 L
.908 .31779 L
.912 .31777 L
.916 .31771 L
.92 .31766 L
.924 .31763 L
.928 .31766 L
.932 .31774 L
.936 .3178 L
.94 .31782 L
.944 .31779 L
.948 .31772 L
.952 .31767 L
.956 .31766 L
.96 .3177 L
.964 .31777 L
.968 .31783 L
.972 .31786 L
.976 .31783 L
.98 .31775 L
.984 .31768 L
.988 .31765 L
.992 .31772 L
.996 .31784 L
1 .3179 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57849 m
.008 .58235 L
.012 .58379 L
.016 .58263 L
.02 .58209 L
.024 .58232 L
.028 .58255 L
.032 .58243 L
.036 .58239 L
.04 .5824 L
.044 .58248 L
.048 .58247 L
.052 .58251 L
.056 .58253 L
.06 .58257 L
.064 .58255 L
.068 .58255 L
.072 .58253 L
.076 .58252 L
.08 .58245 L
.084 .58239 L
.088 .58234 L
.092 .58234 L
.096 .58234 L
.1 .58234 L
.104 .58236 L
.108 .58248 L
.112 .58262 L
.116 .5827 L
.12 .58269 L
.124 .58267 L
.128 .58266 L
.132 .58261 L
.136 .58247 L
.14 .58229 L
.144 .58217 L
.148 .58218 L
.152 .58228 L
.156 .58236 L
.16 .58238 L
.164 .5824 L
.168 .58249 L
.172 .58263 L
.176 .58273 L
.18 .5827 L
.184 .58257 L
.188 .58246 L
.192 .58248 L
.196 .58261 L
.2 .58272 L
Mistroke
.204 .58267 L
.208 .58246 L
.212 .58224 L
.216 .5822 L
.22 .58233 L
.224 .58244 L
.228 .58235 L
.232 .58207 L
.236 .58184 L
.24 .58193 L
.244 .58239 L
.248 .58296 L
.252 .58326 L
.256 .58314 L
.26 .58273 L
.264 .58235 L
.268 .58226 L
.272 .58246 L
.276 .58276 L
.28 .58295 L
.284 .5829 L
.288 .58265 L
.292 .58229 L
.296 .58197 L
.3 .58179 L
.304 .58186 L
.308 .58222 L
.312 .58276 L
.316 .58324 L
.32 .58336 L
.324 .58291 L
.328 .58197 L
.332 .58085 L
.336 .58001 L
.34 .5798 L
.344 .58032 L
.348 .58142 L
.352 .58284 L
.356 .5843 L
.36 .58565 L
.364 .58679 L
.368 .58758 L
.372 .58784 L
.376 .58729 L
.38 .58573 L
.384 .5831 L
.388 .57954 L
.392 .57535 L
.396 .57086 L
.4 .56626 L
Mistroke
.404 .56161 L
.408 .55682 L
.412 .55177 L
.416 .54638 L
.42 .54071 L
.424 .53492 L
.428 .52922 L
.432 .52373 L
.436 .51845 L
.44 .51326 L
.444 .50795 L
.448 .50232 L
.452 .49624 L
.456 .48974 L
.46 .48297 L
.464 .4762 L
.468 .46967 L
.472 .46358 L
.476 .45799 L
.48 .45285 L
.484 .44798 L
.488 .44314 L
.492 .43808 L
.496 .43262 L
.5 .42666 L
.504 .42019 L
.508 .41332 L
.512 .40622 L
.516 .39908 L
.52 .39212 L
.524 .38553 L
.528 .37946 L
.532 .37398 L
.536 .36913 L
.54 .36488 L
.544 .36117 L
.548 .35793 L
.552 .35504 L
.556 .35243 L
.56 .35 L
.564 .34769 L
.568 .34544 L
.572 .34323 L
.576 .34104 L
.58 .33887 L
.584 .33673 L
.588 .33463 L
.592 .33259 L
.596 .33061 L
.6 .32872 L
Mistroke
.604 .3269 L
.608 .32516 L
.612 .32348 L
.616 .32183 L
.62 .3202 L
.624 .31855 L
.628 .31686 L
.632 .31512 L
.636 .31331 L
.64 .3114 L
.644 .3094 L
.648 .3073 L
.652 .30511 L
.656 .30285 L
.66 .30052 L
.664 .29815 L
.668 .29576 L
.672 .29339 L
.676 .29105 L
.68 .28876 L
.684 .28656 L
.688 .28444 L
.692 .28244 L
.696 .28056 L
.7 .27882 L
.704 .27722 L
.708 .27575 L
.712 .27443 L
.716 .27324 L
.72 .27218 L
.724 .27125 L
.728 .27042 L
.732 .26971 L
.736 .26908 L
.74 .26855 L
.744 .2681 L
.748 .26771 L
.752 .26738 L
.756 .26711 L
.76 .26687 L
.764 .26667 L
.768 .26651 L
.772 .26637 L
.776 .26626 L
.78 .26616 L
.784 .26608 L
.788 .26601 L
.792 .26595 L
.796 .2659 L
.8 .26586 L
Mistroke
.804 .26582 L
.808 .26578 L
.812 .26575 L
.816 .26572 L
.82 .26569 L
.824 .26566 L
.828 .26564 L
.832 .26561 L
.836 .26559 L
.84 .26556 L
.844 .26554 L
.848 .26552 L
.852 .2655 L
.856 .26547 L
.86 .26545 L
.864 .26543 L
.868 .2654 L
.872 .26538 L
.876 .26536 L
.88 .26534 L
.884 .26532 L
.888 .26529 L
.892 .26527 L
.896 .26525 L
.9 .26522 L
.904 .2652 L
.908 .26518 L
.912 .26516 L
.916 .26514 L
.92 .26511 L
.924 .26509 L
.928 .26507 L
.932 .26505 L
.936 .26502 L
.94 .265 L
.944 .26498 L
.948 .26496 L
.952 .26493 L
.956 .26491 L
.96 .26489 L
.964 .26487 L
.968 .26484 L
.972 .26482 L
.976 .2648 L
.98 .26478 L
.984 .26475 L
.988 .26474 L
.992 .26471 L
.996 .26469 L
1 .26466 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42488 L
.012 .42998 L
.016 .4316 L
.02 .42968 L
.024 .42916 L
.028 .42972 L
.032 .42991 L
.036 .42966 L
.04 .42964 L
.044 .42969 L
.048 .42972 L
.052 .42964 L
.056 .42962 L
.06 .42957 L
.064 .42953 L
.068 .42944 L
.072 .42942 L
.076 .42938 L
.08 .42932 L
.084 .42921 L
.088 .42917 L
.092 .42916 L
.096 .42915 L
.1 .4291 L
.104 .4291 L
.108 .42916 L
.112 .42925 L
.116 .42925 L
.12 .4292 L
.124 .42913 L
.128 .42912 L
.132 .42909 L
.136 .42897 L
.14 .42875 L
.144 .42859 L
.148 .42854 L
.152 .42857 L
.156 .42857 L
.16 .42853 L
.164 .4285 L
.168 .42859 L
.172 .42875 L
.176 .42887 L
.18 .42884 L
.184 .42869 L
.188 .42854 L
.192 .42855 L
.196 .42867 L
.2 .42874 L
Mistroke
.204 .42859 L
.208 .42825 L
.212 .42791 L
.216 .42782 L
.22 .42798 L
.224 .42815 L
.228 .42806 L
.232 .42772 L
.236 .4274 L
.24 .42746 L
.244 .42795 L
.248 .42857 L
.252 .42889 L
.256 .4287 L
.26 .42817 L
.264 .4277 L
.268 .42758 L
.272 .42783 L
.276 .42819 L
.28 .42839 L
.284 .42829 L
.288 .42791 L
.292 .42741 L
.296 .42694 L
.3 .42668 L
.304 .42674 L
.308 .42718 L
.312 .42786 L
.316 .42846 L
.32 .42858 L
.324 .42799 L
.328 .42675 L
.332 .4253 L
.336 .4242 L
.34 .42389 L
.344 .42451 L
.348 .42588 L
.352 .42763 L
.356 .42944 L
.36 .4311 L
.364 .43248 L
.368 .43343 L
.372 .43369 L
.376 .43296 L
.38 .43097 L
.384 .42766 L
.388 .42321 L
.392 .41798 L
.396 .41235 L
.4 .40659 L
Mistroke
.404 .40077 L
.408 .39478 L
.412 .38844 L
.416 .38169 L
.42 .3746 L
.424 .36736 L
.428 .36024 L
.432 .35338 L
.436 .3468 L
.44 .34033 L
.444 .3337 L
.448 .32665 L
.452 .31905 L
.456 .31092 L
.46 .30248 L
.464 .29403 L
.468 .28589 L
.472 .2783 L
.476 .27133 L
.48 .26492 L
.484 .25885 L
.488 .25281 L
.492 .24651 L
.496 .2397 L
.5 .23226 L
.504 .2242 L
.508 .21564 L
.512 .20679 L
.516 .19791 L
.52 .18925 L
.524 .18106 L
.528 .1735 L
.532 .16668 L
.536 .16064 L
.54 .15535 L
.544 .15075 L
.548 .14672 L
.552 .14315 L
.556 .13991 L
.56 .13691 L
.564 .13404 L
.568 .13126 L
.572 .12853 L
.576 .12581 L
.58 .12312 L
.584 .12046 L
.588 .11787 L
.592 .11535 L
.596 .11292 L
.6 .11058 L
Mistroke
.604 .10834 L
.608 .10618 L
.612 .1041 L
.616 .10207 L
.62 .10006 L
.624 .09803 L
.628 .09596 L
.632 .09382 L
.636 .09158 L
.64 .08922 L
.644 .08675 L
.648 .08416 L
.652 .08146 L
.656 .07866 L
.66 .07578 L
.664 .07287 L
.668 .06993 L
.672 .067 L
.676 .0641 L
.68 .06128 L
.684 .05855 L
.688 .05595 L
.692 .05349 L
.696 .05119 L
.7 .04905 L
.704 .04708 L
.708 .04529 L
.712 .04367 L
.716 .04221 L
.72 .04093 L
.724 .03979 L
.728 .0388 L
.732 .03795 L
.736 .03721 L
.74 .03658 L
.744 .03604 L
.748 .03559 L
.752 .03521 L
.756 .0349 L
.76 .03465 L
.764 .03444 L
.768 .03427 L
.772 .03413 L
.776 .03402 L
.78 .03394 L
.784 .03387 L
.788 .03382 L
.792 .03378 L
.796 .03375 L
.8 .03373 L
Mistroke
.804 .03371 L
.808 .0337 L
.812 .03369 L
.816 .03369 L
.82 .03369 L
.824 .03369 L
.828 .03369 L
.832 .03369 L
.836 .0337 L
.84 .0337 L
.844 .03371 L
.848 .03371 L
.852 .03372 L
.856 .03372 L
.86 .03373 L
.864 .03374 L
.868 .03374 L
.872 .03375 L
.876 .03375 L
.88 .03376 L
.884 .03377 L
.888 .03377 L
.892 .03378 L
.896 .03378 L
.9 .03379 L
.904 .0338 L
.908 .0338 L
.912 .03381 L
.916 .03382 L
.92 .03382 L
.924 .03383 L
.928 .03383 L
.932 .03384 L
.936 .03385 L
.94 .03386 L
.944 .03386 L
.948 .03387 L
.952 .03387 L
.956 .03388 L
.96 .03388 L
.964 .0339 L
.968 .0339 L
.972 .03391 L
.976 .03391 L
.98 .03392 L
.984 .03392 L
.988 .03393 L
.992 .03393 L
.996 .03395 L
1 .03395 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo01aoo`03001oogoo008004]oo`008Woo1@0000=oo`000000100000=oo`000000200000=o
o`00Ool00P000Woo0P0000Eoo`00001oo`0004Yoo`008WooH`0037oo000ROol01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoo`000goo0P000Woo00D007oo
001oo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`03001o
o`0001h000aoo`008Woo0P008goo00<007ooOol03Woo00<007ooOol0=Woo000ROol00`00Oomoo`0S
Ool00`00Oomoo`0=Ool00`00Oomoo`0fOol0029oo`8002Aoo`03001oogoo00eoo`03001oogoo03Io
o`008Woo0P009Goo0P0037oo00<007ooOol0=goo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool00`00Oomoo`0UOol01000Oomoo`002Goo00<007ooOol0=goo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8002Moo`800005Ool007ooOol00004Ool00`00Oomoo`0h
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P009goo0P000Woo0P00
00=oo`00Ool00Woo00<007ooOol0>7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo02eoo`05001oogooOol0000jOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P00;goo00@007ooOol003Yoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool20004Ool2000_Ool00`00Ool0000kOol000]oo`8000Yoo`8000Aoo`03001oogoo009o
o`03001oogoo02moo`03001oogoo03Yoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000
Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`00
0goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qo
o`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol0
00Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00
KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003
Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
1Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03
001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo
00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Ao
o`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo
00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomo
o`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=o
o`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=o
o`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80
009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04
001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol0
0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D0
07ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`00
0Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo
1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0
009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`00
0goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@0
07ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04
001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0002OolJ
0003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool2
0004Ool20004Ool01000Oomoogoo1@000goo0P000Woo100017oo0P0017oo0P0017oo0`000Woo1@00
0goo0P001Woo000XOol00`00Oomoo`0kOol2000YOol002Qoo`03001oogoo03Uoo`<002Yoo`00:7oo
G@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool4000>Ool00`00Oomo
o`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo03=oo`<0031oo`00:7oo00<007ooOol0<Goo0`00
<Woo000XOol00`00Oomoo`0`Ool2000dOol002Qoo`03001oogoo02ioo`8003Ioo`00:7oo00<007oo
Ool0;Woo00<007ooOol0=Goo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool0
0`00Oomoo`0]Ool00`00Oomoo`0fOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007oo
Ool007oo0003Ool01000Oomoo`00;Woo0P00>7oo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0005Ool01000Oomoo`00;Woo00<007ooOol0=goo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000/Ool2000iOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo02Yoo`8003Yoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo02Yoo`03001oogoo
03Uoo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0:Goo00<007ooOol0>Woo000X
Ool00`00Oomoo`0XOol2000lOol002Qoo`03001oogoo02Qoo`03001oogoo03]oo`004Goo0P0017oo
00<007ooOol00goo0P000goo0`000goo00<007ooOol09goo00<007ooOol0?7oo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo02Ioo`8003ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0VOol00`00Oomoo`0mOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P009Woo00<007ooOol0?Woo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo02Aoo`80041oo`00
47oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0TOol00`00Oomoo`0oOol0
015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo02=oo`03001oogoo041oo`00:7oo00<0
07ooOol08Woo00<007ooOol0@Goo000XOol00`00Oomoo`0QOol20013Ool002Qoob800003Ool00000
04Aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol07Woo0P00
AWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00
J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Mo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5
001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<0
00=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool0
1000Oomoo`00Bgoo7@0037oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0AWoo1000:7oo
000:Ool01000Oomoo`001goo00<007ooOol017oo0P00AGoo0`00:goo000;Ool20008Ool50002Ool0
0`00Oomoo`13Ool2000]Ool001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`80
00Eoo`<000=oo`<000Aoo`@000=oo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`00
77oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`05001oogooOol00003Ool00`00Oomoo`040005Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`03001oogoo00800003Ool007oo
00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo10000Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo1@000Woo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo
10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qo
o`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo0`0017oo00@007ooOol000Aoo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo
00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo
00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`00
77oo00<007ooOol0=Woo0P00>Woo000LOol00`00Oomoo`0eOol2000kOol001aoofT000aoo`0077oo
00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01000Oomoogoo0P000Woo
00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo03=o
o`8003eoo`0077oo0P00=7oo00<007ooOol0?7oo000LOol00`00Oomoo`0cOol00`00Oomoo`0lOol0
01aoo`03001oogoo039oo`03001oogoo03eoo`0077oo0P00<goo00<007ooOol0?Goo000LOol00`00
Oomoo`0aOol00`00Oomoo`0nOol001aoo`03001oogoo031oo`80041oo`0077oo0P00<Goo00<007oo
Ool0?goo000LOol00`00Oomoo`0_Ool20011Ool001aoo`80031oo`03001oogoo041oo`002goo0P00
17oo00<007ooOol00Woo0`000goo00<007ooOol0;Woo00<007ooOol0@Goo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo02ioo`03001oogoo045oo`002Woo00@007ooOol000]o
o`03001oogoo008002ioo`03001oogoo049oo`002Woo00@007ooOol000]oo`04001oogoo000_Ool0
0`00Oomoo`12Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0/Ool00`00Oomoo`13Ool0
00Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2000]Ool00`00Oomoo`13Ool000]oo`8000Qoo`D0
009oo`03001oogoo02]oo`03001oogoo04Aoo`0077oo00<007ooOol0:Woo0P00AWoo000LOol2000[
Ool00`00Oomoo`15Ool001aoo`03001oogoo02Uoo`03001oogoo04Ioo`0077oo0P00:Woo00<007oo
Ool0AWoo000LOol00`00Oomoo`0XOol00`00Oomoo`17Ool001aoo`03001oogoo02Moo`8004Uoo`00
77oo0P00:7oo00<007ooOol0B7oo000FOol30003Ool00`00Oomoo`0VOol2001:Ool001Moo`03001o
ogoo009oo`03001oogoo021oo`8000=oo`8004]oo`005goo00<007ooOol00Woo:@00C7oo000GOol0
0`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P00
17oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo
00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`00
2goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomo
o`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@00
0Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(28390\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29473 m
.008 .29608 L
.012 .29714 L
.016 .29911 L
.02 .30028 L
.024 .30071 L
.028 .30022 L
.032 .29832 L
.036 .29603 L
.04 .29459 L
.044 .29508 L
.048 .29706 L
.052 .29937 L
.056 .30139 L
.06 .30218 L
.064 .30109 L
.068 .29851 L
.072 .29583 L
.076 .29463 L
.08 .29527 L
.084 .29703 L
.088 .29889 L
.092 .30021 L
.096 .30067 L
.1 .29979 L
.104 .29765 L
.108 .29566 L
.112 .29544 L
.116 .29694 L
.12 .29849 L
.124 .29902 L
.128 .29889 L
.132 .29881 L
.136 .29878 L
.14 .29838 L
.144 .29776 L
.148 .29759 L
.152 .29817 L
.156 .29868 L
.16 .29793 L
.164 .29607 L
.168 .29454 L
.172 .29483 L
.176 .29711 L
.18 .30002 L
.184 .30174 L
.188 .30125 L
.192 .29914 L
.196 .2969 L
.2 .29582 L
Mistroke
.204 .29599 L
.208 .2964 L
.212 .2964 L
.216 .29658 L
.22 .29803 L
.224 .30065 L
.228 .30248 L
.232 .30115 L
.236 .29665 L
.24 .29198 L
.244 .29079 L
.248 .29405 L
.252 .29898 L
.256 .30149 L
.26 .29999 L
.264 .29676 L
.268 .29554 L
.272 .298 L
.276 .30214 L
.28 .30414 L
.284 .30185 L
.288 .29646 L
.292 .29132 L
.296 .28925 L
.3 .29081 L
.304 .29463 L
.308 .29897 L
.312 .30268 L
.316 .30503 L
.32 .30513 L
.324 .30207 L
.328 .29607 L
.332 .28923 L
.336 .28505 L
.34 .28637 L
.344 .29328 L
.348 .30268 L
.352 .30991 L
.356 .3115 L
.36 .30708 L
.364 .29924 L
.368 .29168 L
.372 .28686 L
.376 .28504 L
.38 .28487 L
.384 .28509 L
.388 .28579 L
.392 .28848 L
.396 .29486 L
.4 .30541 L
Mistroke
.404 .31867 L
.408 .33179 L
.412 .34197 L
.416 .3479 L
.42 .35043 L
.424 .35197 L
.428 .35521 L
.432 .36165 L
.436 .37086 L
.44 .38067 L
.444 .38818 L
.448 .39118 L
.452 .38912 L
.456 .38341 L
.46 .37683 L
.464 .37234 L
.468 .37191 L
.472 .37576 L
.476 .38244 L
.48 .38952 L
.484 .39466 L
.488 .39641 L
.492 .39465 L
.496 .39041 L
.5 .38545 L
.504 .3816 L
.508 .3804 L
.512 .38272 L
.516 .38865 L
.52 .39745 L
.524 .40773 L
.528 .41777 L
.532 .4259 L
.536 .43089 L
.54 .43215 L
.544 .42966 L
.548 .42379 L
.552 .4151 L
.556 .40426 L
.56 .39201 L
.564 .37918 L
.568 .36655 L
.572 .35471 L
.576 .34402 L
.58 .33457 L
.584 .32635 L
.588 .31935 L
.592 .31363 L
.596 .30923 L
.6 .30609 L
Mistroke
.604 .30402 L
.608 .30277 L
.612 .30215 L
.616 .30203 L
.62 .30234 L
.624 .30293 L
.628 .30364 L
.632 .30429 L
.636 .30482 L
.64 .30522 L
.644 .30557 L
.648 .30585 L
.652 .30599 L
.656 .30591 L
.66 .3056 L
.664 .3052 L
.668 .30488 L
.672 .30475 L
.676 .30481 L
.68 .30498 L
.684 .30518 L
.688 .30542 L
.692 .30578 L
.696 .30631 L
.7 .307 L
.704 .30779 L
.708 .30862 L
.712 .30949 L
.716 .31039 L
.72 .3113 L
.724 .31218 L
.728 .31295 L
.732 .31359 L
.736 .31416 L
.74 .31473 L
.744 .31533 L
.748 .3159 L
.752 .31637 L
.756 .31669 L
.76 .31686 L
.764 .31698 L
.768 .3171 L
.772 .31726 L
.776 .31742 L
.78 .31756 L
.784 .31766 L
.788 .3177 L
.792 .31769 L
.796 .31763 L
.8 .31756 L
Mistroke
.804 .31754 L
.808 .31759 L
.812 .31768 L
.816 .31776 L
.82 .31777 L
.824 .31769 L
.828 .31757 L
.832 .31751 L
.836 .31752 L
.84 .31761 L
.844 .3177 L
.848 .31773 L
.852 .31771 L
.856 .31763 L
.86 .31756 L
.864 .31753 L
.868 .31756 L
.872 .31763 L
.876 .3177 L
.88 .31773 L
.884 .31771 L
.888 .31764 L
.892 .31757 L
.896 .31756 L
.9 .3176 L
.904 .31768 L
.908 .31775 L
.912 .31776 L
.916 .31771 L
.92 .31762 L
.924 .31757 L
.928 .3176 L
.932 .31768 L
.936 .31776 L
.94 .31779 L
.944 .31775 L
.948 .31767 L
.952 .31762 L
.956 .31762 L
.96 .31768 L
.964 .31775 L
.968 .3178 L
.972 .3178 L
.976 .31773 L
.98 .31767 L
.984 .31763 L
.988 .31765 L
.992 .31775 L
.996 .31784 L
1 .31786 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .58859 m
.008 .58189 L
.012 .57978 L
.016 .58209 L
.02 .58282 L
.024 .58198 L
.028 .58181 L
.032 .58208 L
.036 .58219 L
.04 .58205 L
.044 .58203 L
.048 .582 L
.052 .582 L
.056 .58197 L
.06 .58199 L
.064 .58197 L
.068 .582 L
.072 .58201 L
.076 .58206 L
.08 .58207 L
.084 .58209 L
.088 .5821 L
.092 .58214 L
.096 .58214 L
.1 .5821 L
.104 .58201 L
.108 .58197 L
.112 .58193 L
.116 .58189 L
.12 .58183 L
.124 .58185 L
.128 .58194 L
.132 .58207 L
.136 .58216 L
.14 .58219 L
.144 .5822 L
.148 .58225 L
.152 .58226 L
.156 .58219 L
.16 .58203 L
.164 .58188 L
.168 .5818 L
.172 .58182 L
.176 .58186 L
.18 .58186 L
.184 .58185 L
.188 .58191 L
.192 .58205 L
.196 .5822 L
.2 .58226 L
Mistroke
.204 .58219 L
.208 .58204 L
.212 .58199 L
.216 .5821 L
.22 .58229 L
.224 .58237 L
.228 .58224 L
.232 .58197 L
.236 .58179 L
.24 .58183 L
.244 .582 L
.248 .58206 L
.252 .58186 L
.256 .58151 L
.26 .58131 L
.264 .58148 L
.268 .58197 L
.272 .5825 L
.276 .58274 L
.28 .58259 L
.284 .58224 L
.288 .58193 L
.292 .58187 L
.296 .58205 L
.3 .58231 L
.304 .5825 L
.308 .58252 L
.312 .58233 L
.316 .58199 L
.32 .58159 L
.324 .58129 L
.328 .58127 L
.332 .58161 L
.336 .58223 L
.34 .58284 L
.344 .58309 L
.348 .58275 L
.352 .58186 L
.356 .58073 L
.36 .57977 L
.364 .57935 L
.368 .57959 L
.372 .5804 L
.376 .58159 L
.38 .58295 L
.384 .58436 L
.388 .58572 L
.392 .58688 L
.396 .58759 L
.4 .58757 L
Mistroke
.404 .58655 L
.408 .58446 L
.412 .5814 L
.416 .57764 L
.42 .57347 L
.424 .56912 L
.428 .56467 L
.432 .56003 L
.436 .5551 L
.44 .54982 L
.444 .54423 L
.448 .53849 L
.452 .53279 L
.456 .5273 L
.46 .52203 L
.464 .5169 L
.468 .51169 L
.472 .50621 L
.476 .5003 L
.48 .49395 L
.484 .48726 L
.488 .48047 L
.492 .47382 L
.496 .46753 L
.5 .46174 L
.504 .45642 L
.508 .45146 L
.512 .44663 L
.516 .4417 L
.52 .43646 L
.524 .43075 L
.528 .42454 L
.532 .41788 L
.536 .41089 L
.54 .40375 L
.544 .39668 L
.548 .38987 L
.552 .38348 L
.556 .37764 L
.56 .3724 L
.564 .36776 L
.568 .3637 L
.572 .36015 L
.576 .35701 L
.58 .35421 L
.584 .35165 L
.588 .34924 L
.592 .34693 L
.596 .34468 L
.6 .34246 L
Mistroke
.604 .34026 L
.608 .33809 L
.612 .33596 L
.616 .33388 L
.62 .33186 L
.624 .32992 L
.628 .32806 L
.632 .32628 L
.636 .32456 L
.64 .32289 L
.644 .32125 L
.648 .31962 L
.652 .31796 L
.656 .31627 L
.66 .31451 L
.664 .31266 L
.668 .31072 L
.672 .30869 L
.676 .30656 L
.68 .30434 L
.684 .30205 L
.688 .29972 L
.692 .29734 L
.696 .29496 L
.7 .2926 L
.704 .29027 L
.708 .28801 L
.712 .28583 L
.716 .28375 L
.72 .28179 L
.724 .27996 L
.728 .27826 L
.732 .2767 L
.736 .27528 L
.74 .27399 L
.744 .27284 L
.748 .27182 L
.752 .27092 L
.756 .27013 L
.76 .26945 L
.764 .26885 L
.768 .26834 L
.772 .2679 L
.776 .26753 L
.78 .26722 L
.784 .26695 L
.788 .26673 L
.792 .26655 L
.796 .26639 L
.8 .26626 L
Mistroke
.804 .26615 L
.808 .26605 L
.812 .26598 L
.816 .26591 L
.82 .26585 L
.824 .26581 L
.828 .26576 L
.832 .26572 L
.836 .26569 L
.84 .26565 L
.844 .26562 L
.848 .2656 L
.852 .26557 L
.856 .26554 L
.86 .26552 L
.864 .2655 L
.868 .26547 L
.872 .26545 L
.876 .26543 L
.88 .2654 L
.884 .26538 L
.888 .26536 L
.892 .26534 L
.896 .26531 L
.9 .26529 L
.904 .26527 L
.908 .26524 L
.912 .26522 L
.916 .2652 L
.92 .26518 L
.924 .26516 L
.928 .26513 L
.932 .26511 L
.936 .26509 L
.94 .26507 L
.944 .26504 L
.948 .26502 L
.952 .265 L
.956 .26498 L
.96 .26495 L
.964 .26493 L
.968 .26491 L
.972 .26489 L
.976 .26486 L
.98 .26484 L
.984 .26482 L
.988 .2648 L
.992 .26477 L
.996 .26476 L
1 .26473 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42672 L
.012 .42969 L
.016 .43097 L
.02 .43004 L
.024 .42958 L
.028 .42973 L
.032 .42988 L
.036 .42972 L
.04 .42962 L
.044 .42955 L
.048 .42955 L
.052 .42948 L
.056 .42949 L
.06 .42947 L
.064 .42949 L
.068 .42946 L
.072 .42948 L
.076 .42948 L
.08 .42946 L
.084 .42937 L
.088 .42933 L
.092 .42929 L
.096 .42926 L
.1 .42916 L
.104 .42909 L
.108 .42906 L
.112 .42906 L
.116 .429 L
.12 .42892 L
.124 .42884 L
.128 .42887 L
.132 .42894 L
.136 .42898 L
.14 .42896 L
.144 .42897 L
.148 .42902 L
.152 .42906 L
.156 .42897 L
.16 .42877 L
.164 .42855 L
.168 .42844 L
.172 .42841 L
.176 .42839 L
.18 .42831 L
.184 .42823 L
.188 .42823 L
.192 .42838 L
.196 .42858 L
.2 .42869 L
Mistroke
.204 .42861 L
.208 .42844 L
.212 .42833 L
.216 .4284 L
.22 .42855 L
.224 .42857 L
.228 .42834 L
.232 .42798 L
.236 .42775 L
.24 .42781 L
.244 .42802 L
.248 .42809 L
.252 .42782 L
.256 .42735 L
.26 .42704 L
.264 .42719 L
.268 .42774 L
.272 .42834 L
.276 .4286 L
.28 .42841 L
.284 .42796 L
.288 .42758 L
.292 .4275 L
.296 .42769 L
.3 .42797 L
.304 .42815 L
.308 .42811 L
.312 .42783 L
.316 .42737 L
.32 .42684 L
.324 .42646 L
.328 .42642 L
.332 .42684 L
.336 .42758 L
.34 .42831 L
.344 .42857 L
.348 .42809 L
.352 .42694 L
.356 .42549 L
.36 .42427 L
.364 .42373 L
.368 .42401 L
.372 .425 L
.376 .42645 L
.38 .42811 L
.384 .42983 L
.388 .43149 L
.392 .43289 L
.396 .43374 L
.4 .43367 L
Mistroke
.404 .43237 L
.408 .42974 L
.412 .4259 L
.416 .42119 L
.42 .41597 L
.424 .41052 L
.428 .40493 L
.432 .39911 L
.436 .39294 L
.44 .38633 L
.444 .37935 L
.448 .37218 L
.452 .36506 L
.456 .35819 L
.46 .35161 L
.464 .34519 L
.468 .33869 L
.472 .33184 L
.476 .32446 L
.48 .31652 L
.484 .30817 L
.488 .2997 L
.492 .29141 L
.496 .28358 L
.5 .27635 L
.504 .26972 L
.508 .26352 L
.512 .25749 L
.516 .25134 L
.52 .24481 L
.524 .2377 L
.528 .22997 L
.532 .22167 L
.536 .21296 L
.54 .20407 L
.544 .19527 L
.548 .18679 L
.552 .17884 L
.556 .17156 L
.56 .16504 L
.564 .15928 L
.568 .15424 L
.572 .14983 L
.576 .14595 L
.58 .14246 L
.584 .13928 L
.588 .13629 L
.592 .13343 L
.596 .13064 L
.6 .1279 L
Mistroke
.604 .12518 L
.608 .1225 L
.612 .11986 L
.616 .11728 L
.62 .11479 L
.624 .11239 L
.628 .11009 L
.632 .10789 L
.636 .10577 L
.64 .10372 L
.644 .10171 L
.648 .09969 L
.652 .09765 L
.656 .09556 L
.66 .09338 L
.664 .0911 L
.668 .08872 L
.672 .08621 L
.676 .08359 L
.68 .08085 L
.684 .07802 L
.688 .07513 L
.692 .0722 L
.696 .06926 L
.7 .06634 L
.704 .06348 L
.708 .06069 L
.712 .058 L
.716 .05545 L
.72 .05303 L
.724 .05078 L
.728 .04869 L
.732 .04678 L
.736 .04504 L
.74 .04347 L
.744 .04208 L
.748 .04084 L
.752 .03974 L
.756 .03879 L
.76 .03796 L
.764 .03726 L
.768 .03666 L
.772 .03615 L
.776 .03572 L
.78 .03536 L
.784 .03507 L
.788 .03482 L
.792 .03462 L
.796 .03446 L
.8 .03433 L
Mistroke
.804 .03423 L
.808 .03415 L
.812 .03409 L
.816 .03404 L
.82 .034 L
.824 .03397 L
.828 .03395 L
.832 .03394 L
.836 .03393 L
.84 .03392 L
.844 .03392 L
.848 .03392 L
.852 .03392 L
.856 .03392 L
.86 .03392 L
.864 .03393 L
.868 .03393 L
.872 .03394 L
.876 .03394 L
.88 .03395 L
.884 .03396 L
.888 .03396 L
.892 .03397 L
.896 .03397 L
.9 .03398 L
.904 .03399 L
.908 .03399 L
.912 .034 L
.916 .034 L
.92 .03401 L
.924 .03402 L
.928 .03402 L
.932 .03403 L
.936 .03403 L
.94 .03404 L
.944 .03405 L
.948 .03406 L
.952 .03406 L
.956 .03407 L
.96 .03407 L
.964 .03408 L
.968 .03408 L
.972 .0341 L
.976 .0341 L
.98 .03411 L
.984 .03411 L
.988 .03412 L
.992 .03412 L
.996 .03414 L
1 .03413 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo01ioo`03001oogoo00<004Qoo`008Woo0P0000Eoo`00000007oo00800005Ool00000001o
o`0400000goo0000000400000goo0000000300001Woo001oo`00Ool0009oo`03001oogoo04Eoo`00
8WooH`0037oo000ROol01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01000Oomoo`000goo00<007ooOol00P000goo0P000Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00002Ool20002Ool01@00Oomoogoo00000goo7@0037oo000ROol2000VOol00`00Oomoo`0>Ool0
0`00Oomoo`0cOol0029oo`03001oogoo02Eoo`03001oogoo00ioo`03001oogoo03=oo`008Woo0P00
9Woo0P003Woo00<007ooOol0=7oo000ROol2000WOol2000=Ool00`00Oomoo`0dOol000]oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo02Moo`03001oogoo00Yoo`03001oogoo03Eo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000YOol01000Ool00000
0goo00<007ooOol00Woo00<007ooOol0=Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8002Uoo`<00003Ool00000008000Aoo`03001oogoo03Eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0YOol00`00Oomoo`020002Ool01@00
Oomoogoo0000=goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80035o
o`04001oogoo000hOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00<Woo00<0
07oo0000>7oo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0aOol3000hOol000]o
o`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomo
ogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool0
00Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`80
00=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003
Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo0080
06eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo
001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/
Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Ao
o`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001o
ogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004
Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool3
0004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool3
0004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=o
o`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000
Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol0
0004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03
001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo
00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=o
o`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03
001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=o
o`03001oogoo00Aoo`06001oogoo001oo`000goo00<007oo00005P000goo00@007ooOol000Eoo`00
:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomo
o`D000=oo`8000=oo`D0009oo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007oo
Ool0?Goo0`009Woo000XOol00`00Oomoo`0lOol2000XOol002Qooed000aoo`00:7oo00<007ooOol0
3goo00<007ooOol047oo00<007ooOol03goo00@007ooOomoo`8000aoo`03001oogoo011oo`03001o
ogoo00Yoo`00:7oo00<007ooOol0=Goo0`00;Woo000XOol00`00Oomoo`0dOol2000`Ool002Qoo`03
001oogoo039oo`80039oo`00:7oo00<007ooOol0<Goo00<007ooOol0<Woo000XOol00`00Oomoo`0`
Ool00`00Oomoo`0cOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001o
ogoo02moo`8003Eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=o
o`04001oogoo000aOol00`00Oomoo`0dOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogoo000`Ool00`00Oomoo`0eOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo008002moo`03001oogoo03Eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0;Goo00<007ooOol0=Woo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0;7oo
0P00>7oo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0/Ool00`00Oomoo`0gOol0
02Qoo`03001oogoo02]oo`03001oogoo03Qoo`00:7oo00<007ooOol0:Woo00<007ooOol0>Goo000A
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0YOol2000kOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0:Goo00<007ooOol0>Woo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo02Qoo`8003aoo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000YOol00`00Oomoo`0kOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol09goo00<007oo
Ool0?7oo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo02Ioo`03001o
ogoo03eoo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol09Goo0P00?goo000XOol0
0`00Oomoo`0TOol20010Ool002Qoo`03001oogoo02Aoo`03001oogoo03moo`00:7oo9`00@Woo000;
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`0QOol20013Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo
1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo
001>OolJ000<Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`19Ool4000UOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool20018Ool2000YOol000]oo`8000Qoo`D0009oo`03001oogoo
04Ioo`8002Yoo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`00
0goo0`0017oo0P000Woo0P0000=oo`0000000`000goo0P0017oo0P001Goo1@000Woo0`0017oo0P00
1Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool30003Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`05001oogoo001o
o`030005Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`03001o
ogoo00@000Moo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol0
17oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@00004Ool000000002
Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00
Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04
001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`04001oogooOol2
00001Goo001oogoo000017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00
Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo
0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`0iOol2000gOol001aoo`03001oogoo03Qoo`80
03Qoo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo
00Yoo`0077oo00<007ooOol0=Woo00<007ooOol0>Goo000LOol2000gOol00`00Oomoo`0iOol001ao
o`03001oogoo03Eoo`03001oogoo03Yoo`0077oo00<007ooOol0=Goo00<007ooOol0>Woo000LOol2
000fOol00`00Oomoo`0jOol001aoo`03001oogoo03Aoo`03001oogoo03]oo`0077oo00<007ooOol0
<goo00<007ooOol0?7oo000LOol2000dOol00`00Oomoo`0lOol001aoo`03001oogoo039oo`8003io
o`0077oo0P00<Woo0P00?goo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`0aOol0
0`00Oomoo`0nOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0<7oo00<0
07ooOol0?goo000:Ool01000Oomoo`002goo00<007ooOol00P00<Goo00<007ooOol0?goo000:Ool0
1000Oomoo`002goo00@007ooOol0035oo`80045oo`002Woo00@007ooOol000Moo`@000=oo`03001o
ogoo02moo`03001oogoo041oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8002moo`03001o
ogoo045oo`002goo0P0027oo1@000Woo00<007ooOol0;Woo00<007ooOol0@Goo000LOol00`00Oomo
o`0]Ool20013Ool001aoo`8002ioo`03001oogoo049oo`0077oo00<007ooOol0;7oo00<007ooOol0
@goo000LOol2000]Ool00`00Oomoo`13Ool001aoo`03001oogoo02]oo`03001oogoo04Aoo`0077oo
00<007ooOol0:Woo0P00AWoo000LOol2000ZOol20017Ool001Ioo`<000=oo`03001oogoo02Uoo`03
001oogoo04Ioo`005goo00<007ooOol00Woo00<007ooOol08Woo0P0017oo0P00B7oo000GOol00`00
Oomoo`02OolV00000goo000000030019Ool001Moo`03001oogoo009oo`03001oogoo079oo`005goo
00<007ooOol00Woo00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03
001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol0
0Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo
000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001c
Ool000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo
00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`00
77oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(28557\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30338 m
.008 .30117 L
.012 .29681 L
.016 .29444 L
.02 .29531 L
.024 .29662 L
.028 .29843 L
.032 .30076 L
.036 .3022 L
.04 .30174 L
.044 .29944 L
.048 .2968 L
.052 .29492 L
.056 .29456 L
.06 .29608 L
.064 .29836 L
.068 .30011 L
.072 .30053 L
.076 .29973 L
.08 .29853 L
.084 .29739 L
.088 .29676 L
.092 .29713 L
.096 .29841 L
.1 .29955 L
.104 .29926 L
.108 .29782 L
.112 .29672 L
.116 .29675 L
.12 .29743 L
.124 .29812 L
.128 .2988 L
.132 .29944 L
.136 .29943 L
.14 .29817 L
.144 .2961 L
.148 .29488 L
.152 .2958 L
.156 .29827 L
.16 .30043 L
.164 .30101 L
.168 .30022 L
.172 .29891 L
.176 .29767 L
.18 .29651 L
.184 .29539 L
.188 .29475 L
.192 .29519 L
.196 .29685 L
.2 .29903 L
Mistroke
.204 .30052 L
.208 .30044 L
.212 .299 L
.216 .29756 L
.22 .29728 L
.224 .29797 L
.228 .29818 L
.232 .29674 L
.236 .29452 L
.24 .29404 L
.244 .29685 L
.248 .30152 L
.252 .3043 L
.256 .30238 L
.26 .29678 L
.264 .29173 L
.268 .29096 L
.272 .29448 L
.276 .29879 L
.28 .30024 L
.284 .29833 L
.288 .29583 L
.292 .29584 L
.296 .29892 L
.3 .30265 L
.304 .30394 L
.308 .30159 L
.312 .29702 L
.316 .29272 L
.32 .29047 L
.324 .29063 L
.328 .29276 L
.332 .29642 L
.336 .30108 L
.34 .30542 L
.344 .30726 L
.348 .30467 L
.352 .2977 L
.356 .2892 L
.36 .28362 L
.364 .28436 L
.368 .29152 L
.372 .30166 L
.376 .30975 L
.38 .31214 L
.384 .30844 L
.388 .30126 L
.392 .2941 L
.396 .28923 L
.4 .28666 L
Mistroke
.404 .28502 L
.408 .28326 L
.412 .28191 L
.416 .28296 L
.42 .28851 L
.424 .29917 L
.428 .3133 L
.432 .32767 L
.436 .33908 L
.44 .346 L
.444 .3492 L
.448 .3512 L
.452 .35482 L
.456 .36166 L
.46 .37139 L
.464 .38193 L
.468 .39047 L
.472 .39477 L
.476 .39405 L
.48 .38935 L
.484 .38307 L
.488 .37803 L
.492 .37644 L
.496 .3791 L
.5 .38517 L
.504 .39256 L
.508 .39878 L
.512 .40191 L
.516 .40124 L
.52 .39739 L
.524 .39199 L
.528 .38704 L
.532 .3843 L
.536 .38495 L
.54 .38934 L
.544 .39709 L
.548 .4071 L
.552 .41783 L
.556 .42754 L
.56 .4347 L
.564 .43828 L
.568 .4379 L
.572 .43374 L
.576 .42636 L
.58 .41645 L
.584 .40476 L
.588 .39201 L
.592 .37893 L
.596 .3662 L
.6 .35434 L
Mistroke
.604 .34366 L
.608 .33431 L
.612 .32633 L
.616 .31972 L
.62 .31448 L
.624 .31055 L
.628 .30775 L
.632 .30586 L
.636 .30467 L
.64 .30405 L
.644 .30393 L
.648 .30424 L
.652 .30485 L
.656 .30556 L
.66 .3062 L
.664 .30666 L
.668 .30696 L
.672 .30714 L
.676 .30723 L
.68 .30724 L
.684 .30716 L
.688 .30704 L
.692 .30693 L
.696 .30687 L
.7 .30685 L
.704 .30686 L
.708 .30692 L
.712 .3071 L
.716 .30747 L
.72 .30805 L
.724 .30879 L
.728 .30955 L
.732 .31026 L
.736 .31091 L
.74 .31156 L
.744 .31228 L
.748 .31308 L
.752 .31388 L
.756 .31461 L
.76 .3152 L
.764 .31567 L
.768 .31605 L
.772 .31639 L
.776 .3167 L
.78 .31697 L
.784 .31723 L
.788 .31745 L
.792 .31761 L
.796 .3177 L
.8 .31771 L
Mistroke
.804 .31768 L
.808 .31766 L
.812 .31769 L
.816 .31775 L
.82 .3178 L
.824 .31781 L
.828 .31777 L
.832 .3177 L
.836 .31764 L
.84 .31762 L
.844 .31763 L
.848 .31765 L
.852 .31767 L
.856 .31767 L
.86 .31766 L
.864 .31763 L
.868 .31759 L
.872 .31757 L
.876 .31757 L
.88 .3176 L
.884 .31763 L
.888 .31765 L
.892 .31765 L
.896 .31762 L
.9 .31759 L
.904 .31759 L
.908 .3176 L
.912 .31763 L
.916 .31765 L
.92 .31765 L
.924 .31765 L
.928 .31764 L
.932 .31764 L
.936 .31764 L
.94 .31763 L
.944 .31763 L
.948 .31765 L
.952 .31767 L
.956 .31769 L
.96 .3177 L
.964 .31767 L
.968 .31765 L
.972 .31764 L
.976 .31765 L
.98 .31768 L
.984 .3177 L
.988 .31772 L
.992 .31773 L
.996 .31771 L
1 .31768 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .58689 m
.008 .58172 L
.012 .57996 L
.016 .58143 L
.02 .58214 L
.024 .58166 L
.028 .58143 L
.032 .58152 L
.036 .58164 L
.04 .58158 L
.044 .58158 L
.048 .58158 L
.052 .58162 L
.056 .58162 L
.06 .58164 L
.064 .58162 L
.068 .58162 L
.072 .58159 L
.076 .58159 L
.08 .58155 L
.084 .58153 L
.088 .5815 L
.092 .58153 L
.096 .58157 L
.1 .5816 L
.104 .58161 L
.108 .58166 L
.112 .58171 L
.116 .58172 L
.12 .58167 L
.124 .58162 L
.128 .58159 L
.132 .58157 L
.136 .58152 L
.14 .58144 L
.144 .58139 L
.148 .58143 L
.152 .58152 L
.156 .58159 L
.16 .58163 L
.164 .58168 L
.168 .58176 L
.172 .58184 L
.176 .58184 L
.18 .58173 L
.184 .58158 L
.188 .58148 L
.192 .58146 L
.196 .58147 L
.2 .58145 L
Mistroke
.204 .58139 L
.208 .58135 L
.212 .58141 L
.216 .58158 L
.22 .58174 L
.224 .58177 L
.228 .58167 L
.232 .58155 L
.236 .58158 L
.24 .58176 L
.244 .58194 L
.248 .58194 L
.252 .58173 L
.256 .58147 L
.26 .58138 L
.264 .58151 L
.268 .58169 L
.272 .58167 L
.276 .58138 L
.28 .581 L
.284 .58083 L
.288 .58104 L
.292 .58152 L
.296 .58198 L
.3 .58217 L
.304 .58205 L
.308 .58176 L
.312 .58153 L
.316 .58149 L
.32 .58162 L
.324 .58185 L
.328 .58206 L
.332 .58214 L
.336 .58201 L
.34 .58167 L
.344 .5812 L
.348 .58081 L
.352 .58071 L
.356 .58104 L
.36 .5817 L
.364 .5824 L
.368 .58276 L
.372 .58253 L
.376 .58173 L
.38 .58063 L
.384 .57962 L
.388 .57904 L
.392 .57901 L
.396 .57952 L
.4 .58044 L
Mistroke
.404 .58163 L
.408 .58302 L
.412 .5845 L
.416 .58593 L
.42 .58703 L
.424 .58749 L
.428 .58702 L
.432 .58548 L
.436 .58295 L
.44 .57964 L
.444 .57585 L
.448 .57179 L
.452 .56756 L
.456 .5631 L
.46 .55834 L
.464 .55319 L
.468 .5477 L
.472 .54202 L
.476 .53634 L
.48 .53083 L
.484 .52557 L
.488 .52047 L
.492 .51535 L
.496 .51002 L
.5 .50429 L
.504 .4981 L
.508 .49152 L
.512 .48475 L
.516 .47803 L
.52 .47158 L
.524 .46558 L
.528 .46006 L
.532 .45496 L
.536 .45009 L
.54 .44524 L
.544 .44016 L
.548 .4347 L
.552 .42876 L
.556 .42233 L
.56 .41551 L
.564 .40845 L
.568 .40133 L
.572 .39435 L
.576 .3877 L
.58 .38152 L
.584 .3759 L
.588 .37089 L
.592 .36646 L
.596 .36258 L
.6 .35917 L
Mistroke
.604 .35613 L
.608 .35339 L
.612 .35086 L
.616 .34847 L
.62 .34615 L
.624 .3439 L
.628 .34167 L
.632 .33948 L
.636 .33732 L
.64 .3352 L
.644 .33314 L
.648 .33115 L
.652 .32924 L
.656 .32741 L
.66 .32566 L
.664 .32397 L
.668 .32232 L
.672 .32069 L
.676 .31905 L
.68 .31738 L
.684 .31566 L
.688 .31387 L
.692 .312 L
.696 .31003 L
.7 .30797 L
.704 .30581 L
.708 .30357 L
.712 .30126 L
.716 .29891 L
.72 .29653 L
.724 .29415 L
.728 .2918 L
.732 .2895 L
.736 .28727 L
.74 .28512 L
.744 .28308 L
.748 .28116 L
.752 .27937 L
.756 .27771 L
.76 .27619 L
.764 .27482 L
.768 .27358 L
.772 .27247 L
.776 .27148 L
.78 .27061 L
.784 .26985 L
.788 .26919 L
.792 .26862 L
.796 .26813 L
.8 .26772 L
Mistroke
.804 .26736 L
.808 .26706 L
.812 .26681 L
.816 .26659 L
.82 .26642 L
.824 .26627 L
.828 .26614 L
.832 .26604 L
.836 .26595 L
.84 .26587 L
.844 .26581 L
.848 .26575 L
.852 .26571 L
.856 .26566 L
.86 .26563 L
.864 .26559 L
.868 .26556 L
.872 .26553 L
.876 .2655 L
.88 .26548 L
.884 .26545 L
.888 .26543 L
.892 .2654 L
.896 .26538 L
.9 .26536 L
.904 .26533 L
.908 .26531 L
.912 .26529 L
.916 .26527 L
.92 .26524 L
.924 .26522 L
.928 .2652 L
.932 .26518 L
.936 .26515 L
.94 .26513 L
.944 .26511 L
.948 .26509 L
.952 .26506 L
.956 .26504 L
.96 .26502 L
.964 .265 L
.968 .26497 L
.972 .26495 L
.976 .26493 L
.98 .26491 L
.984 .26488 L
.988 .26487 L
.992 .26484 L
.996 .26482 L
1 .26479 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43439 L
.012 .42964 L
.016 .42826 L
.02 .42985 L
.024 .43031 L
.028 .42968 L
.032 .42957 L
.036 .42973 L
.04 .4298 L
.044 .42969 L
.048 .42968 L
.052 .42964 L
.056 .42963 L
.06 .42954 L
.064 .42948 L
.068 .42937 L
.072 .42932 L
.076 .42928 L
.08 .42929 L
.084 .42926 L
.088 .42928 L
.092 .4293 L
.096 .42932 L
.1 .42926 L
.104 .42919 L
.108 .42914 L
.112 .42915 L
.116 .42912 L
.12 .42907 L
.124 .429 L
.128 .42898 L
.132 .42896 L
.136 .42889 L
.14 .42875 L
.144 .42866 L
.148 .42865 L
.152 .42869 L
.156 .42871 L
.16 .42869 L
.164 .4287 L
.168 .42878 L
.172 .42889 L
.176 .42892 L
.18 .4288 L
.184 .42861 L
.188 .42843 L
.192 .42833 L
.196 .42826 L
.2 .42816 L
Mistroke
.204 .42802 L
.208 .42795 L
.212 .42803 L
.216 .42825 L
.22 .42845 L
.224 .42848 L
.228 .42831 L
.232 .42813 L
.236 .42811 L
.24 .42827 L
.244 .42844 L
.248 .42839 L
.252 .42809 L
.256 .42775 L
.26 .42764 L
.264 .42781 L
.268 .42802 L
.272 .42796 L
.276 .42755 L
.28 .42701 L
.284 .42675 L
.288 .42696 L
.292 .42753 L
.296 .42808 L
.3 .42831 L
.304 .42814 L
.308 .42777 L
.312 .42746 L
.316 .42736 L
.32 .42748 L
.324 .42771 L
.328 .42793 L
.332 .42799 L
.336 .42781 L
.34 .42736 L
.344 .42676 L
.348 .42625 L
.352 .42609 L
.356 .42646 L
.36 .42725 L
.364 .42808 L
.368 .42849 L
.372 .42817 L
.376 .42715 L
.38 .42575 L
.384 .42446 L
.388 .42371 L
.392 .42366 L
.396 .42426 L
.4 .42537 L
Mistroke
.404 .42681 L
.408 .42849 L
.412 .43031 L
.416 .43206 L
.42 .43341 L
.424 .43396 L
.428 .43333 L
.432 .43138 L
.436 .42819 L
.44 .42404 L
.444 .41928 L
.448 .4142 L
.452 .40889 L
.456 .4033 L
.46 .39733 L
.464 .39089 L
.468 .38403 L
.472 .37693 L
.476 .36984 L
.48 .36296 L
.484 .35636 L
.488 .34998 L
.492 .34358 L
.496 .33692 L
.5 .32977 L
.504 .32205 L
.508 .31385 L
.512 .30539 L
.516 .297 L
.52 .28896 L
.524 .28147 L
.528 .27459 L
.532 .26822 L
.536 .26215 L
.54 .25609 L
.544 .24977 L
.548 .24297 L
.552 .23557 L
.556 .22756 L
.56 .21905 L
.564 .21024 L
.568 .20137 L
.572 .19269 L
.576 .18442 L
.58 .17674 L
.584 .16975 L
.588 .16351 L
.592 .15801 L
.596 .15318 L
.6 .14894 L
Mistroke
.604 .14517 L
.608 .14178 L
.612 .13864 L
.616 .13567 L
.62 .13282 L
.624 .13002 L
.628 .12727 L
.632 .12454 L
.636 .12186 L
.64 .11924 L
.644 .1167 L
.648 .11425 L
.652 .1119 L
.656 .10964 L
.66 .10747 L
.664 .10538 L
.668 .10334 L
.672 .10133 L
.676 .09932 L
.68 .09727 L
.684 .09515 L
.688 .09295 L
.692 .09063 L
.696 .0882 L
.7 .08565 L
.704 .08299 L
.708 .08022 L
.712 .07738 L
.716 .07448 L
.72 .07154 L
.724 .06861 L
.728 .06571 L
.732 .06286 L
.736 .0601 L
.74 .05746 L
.744 .05495 L
.748 .05259 L
.752 .05039 L
.756 .04836 L
.76 .0465 L
.764 .04481 L
.768 .04329 L
.772 .04194 L
.776 .04075 L
.78 .0397 L
.784 .03879 L
.788 .038 L
.792 .03732 L
.796 .03675 L
.8 .03626 L
Mistroke
.804 .03585 L
.808 .03551 L
.812 .03523 L
.816 .035 L
.82 .03481 L
.824 .03466 L
.828 .03454 L
.832 .03444 L
.836 .03436 L
.84 .0343 L
.844 .03426 L
.848 .03422 L
.852 .0342 L
.856 .03418 L
.86 .03417 L
.864 .03416 L
.868 .03415 L
.872 .03415 L
.876 .03415 L
.88 .03415 L
.884 .03415 L
.888 .03415 L
.892 .03416 L
.896 .03416 L
.9 .03417 L
.904 .03417 L
.908 .03418 L
.912 .03419 L
.916 .03419 L
.92 .0342 L
.924 .03421 L
.928 .03421 L
.932 .03422 L
.936 .03422 L
.94 .03423 L
.944 .03423 L
.948 .03424 L
.952 .03425 L
.956 .03426 L
.96 .03426 L
.964 .03427 L
.968 .03427 L
.972 .03428 L
.976 .03428 L
.98 .0343 L
.984 .0343 L
.988 .03431 L
.992 .03431 L
.996 .03432 L
1 .03432 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo021oo`80009oo`<004Eoo`008Woo100000Aoo`00001oo`D00004Ool00000Ool300000goo
00000007000017oo000007oo0`0000Eoo`00001oo`0004Eoo`008WooH`0037oo000ROol01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoo`000goo00T007oo
Oomoo`00Ool007oo00000Woo0P000goo00D007ooOomoo`0000=oo`06001oogooOol007oo0P000goo
00@007ooOomooad000aoo`008Woo0P00:7oo00<007ooOol03goo00<007ooOol0<7oo000ROol00`00
Oomoo`0XOol00`00Oomoo`0=Ool00`00Oomoo`0aOol0029oo`8002Uoo`03001oogoo00eoo`03001o
ogoo035oo`008Woo0P00:Woo00<007ooOol037oo00<007ooOol0<Goo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool00`00Oomoo`0ZOol00`00Oomoo`0:Ool00`00Oomoo`0bOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00:goo00@007ooOol000Uoo`03001o
ogoo039oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000[Ool30000
17oo001oogoo0P0017oo00<007ooOol0<Woo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo02]oo`800006Ool00000001oo`000goo00<007ooOol0<goo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80031oo`05001oogooOol00002Ool0
0`00Oomoo`0cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00=7oo00@007oo
Ool003Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0<goo00<007oo0000=Woo
000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2000eOol2000fOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
17oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007oo
Ool00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;
Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
0`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo
00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo
1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2
000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P00
17oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo
1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`00
17oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P00
0goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo
001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo
00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool0
1@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool0
1000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001o
ogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000X
Ool00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00
Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo
0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`03001oogoo01H000=oo`04001o
ogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ao
o`04001oogooOol50003Ool20003Ool300000goo000000030004Ool20004Ool30002Ool50003Ool2
0006Ool002Qoo`03001oogoo041oo`<002=oo`00:7oo00<007ooOol0?Woo0`009Goo000XOomM000<
Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00=oo`<000Uo
o`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0>7oo0P00;7oo000XOol00`00Oomo
o`0fOol2000^Ool002Qoo`03001oogoo03Aoo`80031oo`00:7oo00<007ooOol0<goo0P00<Goo000X
Ool00`00Oomoo`0cOol00`00Oomoo`0`Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=o
o`<000=oo`03001oogoo039oo`03001oogoo035oo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000=oo`04001oogoo000cOol00`00Oomoo`0bOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000cOol00`00Oomoo`0bOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo0080035oo`03001oogoo
03=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007oo
Ool0<7oo00<007ooOol0<goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`001Woo00<007ooOol0;goo00<007ooOol0=7oo000;Ool2000:Ool20004Ool20002Ool50002Ool0
0`00Oomoo`0^Ool00`00Oomoo`0eOol002Qoo`03001oogoo02eoo`03001oogoo03Ioo`00:7oo00<0
07ooOol0;Goo00<007ooOol0=Woo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00
Oomoo`0/Ool00`00Oomoo`0gOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0:goo0P00>Goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo02Yoo`8003Yoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2000[Ool00`00Oomoo`0iOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0:Goo00<007ooOol0>Woo000@Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`03001oogoo02Qoo`8003aoo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007oo
Ool0:7oo00<007ooOol0>goo000XOol00`00Oomoo`0WOol00`00Oomoo`0lOol002Qoo`03001oogoo
02Ioo`03001oogoo03eoo`00:7oo9`0000=oo`000000?goo000;Ool20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool30003Ool00`00Oomoo`0TOol00`00Oomoo`0oOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03
001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol0
00]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001AOolG000<Ool000Yo
o`04001oogoo0007Ool40003Ool00`00Oomoo`1<Ool4000ROol000Yoo`04001oogoo0007Ool00`00
Oomoo`04Ool2001;Ool2000VOol000]oo`8000Qoo`D0009oo`03001oogoo04Qoo`<002Moo`0077oo
00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo
1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo0000
0Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007oo
Oomoo`0000=oo`04001oogoo0002Ool01000Oomoogoo0`000Woo00@007ooOol0009oo`04001oogoo
0002Ool00`00Oomoo`03Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool0
01aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool01000Ool000000goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo0P00
1Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000
Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo100017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool200000goo001oo`03Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol700000goo00000006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001ao
o`03001oogoo03aoo`8003Aoo`0077oo00<007ooOol0>goo0P00=Goo000LOomY000<Ool001aoo`05
001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03
001oogoo008000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo03Uoo`03
001oogoo03Ioo`0077oo0P00>Woo00<007ooOol0=Woo000LOol00`00Oomoo`0hOol00`00Oomoo`0g
Ool001aoo`03001oogoo03Qoo`03001oogoo03Moo`0077oo0P00>7oo00<007ooOol0>7oo000LOol0
0`00Oomoo`0gOol00`00Oomoo`0hOol001aoo`03001oogoo03Ioo`03001oogoo03Uoo`0077oo0P00
=Woo0P00>goo000LOol00`00Oomoo`0eOol00`00Oomoo`0jOol001aoo`8003Eoo`8003aoo`002goo
0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0=7oo00<007ooOol0>goo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo03=oo`03001oogoo03aoo`002Woo00@007ooOol0
00]oo`03001oogoo008003Aoo`03001oogoo03aoo`002Woo00@007ooOol000]oo`04001oogoo000d
Ool00`00Oomoo`0mOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0bOol00`00Oomoo`0m
Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2000bOol00`00Oomoo`0nOol000]oo`8000Qo
o`D0009oo`03001oogoo031oo`80041oo`0077oo00<007ooOol0<7oo00<007ooOol0?goo000LOol2
000`Ool20011Ool001aoo`03001oogoo02moo`03001oogoo041oo`0077oo0P00;goo00<007ooOol0
@Goo000LOol00`00Oomoo`0^Ool00`00Oomoo`11Ool001aoo`03001oogoo02eoo`03001oogoo049o
o`0077oo0P00;Goo0P00A7oo000FOol30003Ool00`00Oomoo`0/Ool00`00Oomoo`13Ool001Moo`03
001oogoo009oo`03001oogoo02Eoo`8000Aoo`03001oogoo04Aoo`005goo00<007ooOol00Woo:000
0Woo1000Agoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079o
o`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<0
07ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007oo
Ool007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003
Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007oo
Ool01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(28724\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30202 m
.008 .30088 L
.012 .30026 L
.016 .29871 L
.02 .29757 L
.024 .29656 L
.028 .29583 L
.032 .29654 L
.036 .29804 L
.04 .29949 L
.044 .30018 L
.048 .29969 L
.052 .29862 L
.056 .29747 L
.06 .29702 L
.064 .29768 L
.068 .29873 L
.072 .29948 L
.076 .29949 L
.08 .29875 L
.084 .29756 L
.088 .29616 L
.092 .29561 L
.096 .29669 L
.1 .29878 L
.104 .30034 L
.108 .30049 L
.112 .29968 L
.116 .29853 L
.12 .29715 L
.124 .29593 L
.128 .29569 L
.132 .29696 L
.136 .29899 L
.14 .30021 L
.144 .29975 L
.148 .29835 L
.152 .2974 L
.156 .29726 L
.16 .29725 L
.164 .29694 L
.168 .29678 L
.172 .29725 L
.176 .29814 L
.18 .29875 L
.184 .29873 L
.188 .29851 L
.192 .29875 L
.196 .29936 L
.2 .29952 L
Mistroke
.204 .29843 L
.208 .29621 L
.212 .29411 L
.216 .2937 L
.22 .29559 L
.224 .29868 L
.228 .30089 L
.232 .30088 L
.236 .29919 L
.24 .29776 L
.244 .29776 L
.248 .29836 L
.252 .29775 L
.256 .29542 L
.26 .29328 L
.264 .29407 L
.268 .29827 L
.272 .30301 L
.276 .30437 L
.28 .30094 L
.284 .29528 L
.288 .29181 L
.292 .2928 L
.296 .29659 L
.3 .29938 L
.304 .29883 L
.308 .29601 L
.312 .29416 L
.316 .29553 L
.32 .29951 L
.324 .30326 L
.328 .30423 L
.332 .30191 L
.336 .29778 L
.34 .29377 L
.344 .29108 L
.348 .29014 L
.352 .29122 L
.356 .29464 L
.36 .30004 L
.364 .30565 L
.368 .30853 L
.372 .3063 L
.376 .29901 L
.38 .28979 L
.384 .28335 L
.388 .2833 L
.392 .28987 L
.396 .29983 L
.4 .30834 L
Mistroke
.404 .3118 L
.408 .30956 L
.412 .3037 L
.416 .29727 L
.42 .29228 L
.424 .2888 L
.428 .28572 L
.432 .28224 L
.436 .27908 L
.44 .27839 L
.444 .28255 L
.448 .29245 L
.452 .30672 L
.456 .32208 L
.46 .335 L
.464 .3434 L
.468 .34761 L
.472 .35003 L
.476 .35368 L
.48 .3606 L
.484 .37079 L
.488 .38231 L
.492 .39224 L
.496 .39806 L
.5 .39871 L
.504 .39495 L
.508 .38896 L
.512 .38353 L
.516 .38102 L
.52 .38263 L
.524 .38798 L
.528 .39539 L
.532 .40245 L
.536 .40693 L
.54 .40759 L
.544 .40451 L
.548 .39903 L
.552 .39317 L
.556 .38897 L
.56 .38792 L
.564 .3907 L
.568 .39717 L
.572 .40648 L
.576 .41727 L
.58 .42792 L
.584 .43683 L
.588 .4427 L
.592 .44478 L
.596 .44288 L
.6 .4373 L
Mistroke
.604 .42864 L
.608 .41763 L
.612 .40502 L
.616 .39161 L
.62 .37819 L
.624 .36541 L
.628 .35374 L
.632 .3434 L
.636 .33443 L
.64 .32678 L
.644 .32046 L
.648 .31544 L
.652 .3117 L
.656 .30911 L
.66 .30746 L
.664 .30653 L
.668 .30615 L
.672 .30616 L
.676 .30643 L
.68 .30683 L
.684 .30727 L
.688 .3077 L
.692 .3081 L
.696 .30847 L
.7 .30875 L
.704 .30889 L
.708 .30887 L
.712 .30873 L
.716 .30856 L
.72 .30847 L
.724 .30852 L
.728 .30868 L
.732 .3089 L
.736 .30917 L
.74 .30948 L
.744 .30989 L
.748 .3104 L
.752 .311 L
.756 .31165 L
.76 .31235 L
.764 .31307 L
.768 .3138 L
.772 .31448 L
.776 .31507 L
.78 .31556 L
.784 .31598 L
.788 .3164 L
.792 .31682 L
.796 .31721 L
.8 .31752 L
Mistroke
.804 .31772 L
.808 .3178 L
.812 .31783 L
.816 .31786 L
.82 .31791 L
.824 .31798 L
.828 .31804 L
.832 .31806 L
.836 .31802 L
.84 .31794 L
.844 .31784 L
.848 .31776 L
.852 .31774 L
.856 .31776 L
.86 .3178 L
.864 .3178 L
.868 .31776 L
.872 .31767 L
.876 .31759 L
.88 .31755 L
.884 .31757 L
.888 .31763 L
.892 .31768 L
.896 .31768 L
.9 .31763 L
.904 .31756 L
.908 .31752 L
.912 .31753 L
.916 .31757 L
.92 .31763 L
.924 .31766 L
.928 .31766 L
.932 .31761 L
.936 .31756 L
.94 .31753 L
.944 .31755 L
.948 .31761 L
.952 .31767 L
.956 .31771 L
.96 .31767 L
.964 .3176 L
.968 .31755 L
.972 .31755 L
.976 .31761 L
.98 .31769 L
.984 .31772 L
.988 .31771 L
.992 .31765 L
.996 .31759 L
1 .31758 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .5756 m
.008 .58126 L
.012 .58312 L
.016 .58101 L
.02 .5805 L
.024 .58121 L
.028 .58141 L
.032 .5811 L
.036 .58107 L
.04 .58116 L
.044 .58121 L
.048 .58115 L
.052 .58116 L
.056 .58113 L
.06 .58114 L
.064 .58111 L
.068 .58112 L
.072 .58113 L
.076 .58118 L
.08 .58121 L
.084 .58123 L
.088 .5812 L
.092 .58119 L
.096 .58116 L
.1 .58112 L
.104 .58107 L
.108 .58106 L
.112 .58109 L
.116 .58112 L
.12 .58112 L
.124 .58114 L
.128 .58117 L
.132 .58124 L
.136 .58126 L
.14 .58125 L
.144 .58121 L
.148 .5812 L
.152 .58119 L
.156 .58115 L
.16 .58105 L
.164 .58099 L
.168 .58099 L
.172 .58105 L
.176 .58109 L
.18 .58111 L
.184 .58112 L
.188 .58119 L
.192 .5813 L
.196 .58138 L
.2 .58138 L
Mistroke
.204 .58129 L
.208 .58119 L
.212 .58114 L
.216 .58113 L
.22 .5811 L
.224 .581 L
.228 .58087 L
.232 .58084 L
.236 .58095 L
.24 .58115 L
.244 .58129 L
.248 .58126 L
.252 .58114 L
.256 .58107 L
.26 .58119 L
.264 .58142 L
.268 .58155 L
.272 .58145 L
.276 .58119 L
.28 .58098 L
.284 .58101 L
.288 .58122 L
.292 .58138 L
.296 .58128 L
.3 .58091 L
.304 .58052 L
.308 .58038 L
.312 .58059 L
.316 .58102 L
.32 .58143 L
.324 .58161 L
.328 .58154 L
.332 .58133 L
.336 .58114 L
.34 .58108 L
.344 .58116 L
.348 .58136 L
.352 .5816 L
.356 .58176 L
.36 .58169 L
.364 .58136 L
.368 .58084 L
.372 .58036 L
.376 .58018 L
.38 .58047 L
.384 .58114 L
.388 .5819 L
.392 .58236 L
.396 .58225 L
.4 .58158 L
Mistroke
.404 .58056 L
.408 .57955 L
.412 .57884 L
.416 .57858 L
.42 .57879 L
.424 .57941 L
.428 .58037 L
.432 .58165 L
.436 .58318 L
.44 .58479 L
.444 .58622 L
.448 .5871 L
.452 .58714 L
.456 .58615 L
.46 .58416 L
.464 .58135 L
.468 .57797 L
.472 .57424 L
.476 .57026 L
.48 .56603 L
.484 .56145 L
.488 .55646 L
.492 .55111 L
.496 .54551 L
.5 .53986 L
.504 .53435 L
.508 .52906 L
.512 .52397 L
.516 .51893 L
.52 .51373 L
.524 .50818 L
.528 .50218 L
.532 .49575 L
.536 .48905 L
.54 .48229 L
.544 .47571 L
.548 .46951 L
.552 .46378 L
.556 .4585 L
.56 .45355 L
.564 .44871 L
.568 .44377 L
.572 .43853 L
.576 .43284 L
.58 .42667 L
.584 .42005 L
.588 .41311 L
.592 .406 L
.596 .39893 L
.6 .39208 L
Mistroke
.604 .38561 L
.608 .37966 L
.612 .37427 L
.616 .36947 L
.62 .36523 L
.624 .3615 L
.628 .3582 L
.632 .35526 L
.636 .35257 L
.64 .35007 L
.644 .34769 L
.648 .34538 L
.652 .34312 L
.656 .34089 L
.66 .33869 L
.664 .33654 L
.668 .33444 L
.672 .33241 L
.676 .33045 L
.68 .32858 L
.684 .32678 L
.688 .32505 L
.692 .32338 L
.696 .32174 L
.7 .32011 L
.704 .31847 L
.708 .31679 L
.712 .31506 L
.716 .31324 L
.72 .31133 L
.724 .30933 L
.728 .30723 L
.732 .30505 L
.736 .30279 L
.74 .30047 L
.744 .29811 L
.748 .29573 L
.752 .29336 L
.756 .29102 L
.76 .28874 L
.764 .28653 L
.768 .28442 L
.772 .28242 L
.776 .28054 L
.78 .27879 L
.784 .27718 L
.788 .2757 L
.792 .27437 L
.796 .27317 L
.8 .27209 L
Mistroke
.804 .27114 L
.808 .27031 L
.812 .26958 L
.816 .26895 L
.82 .2684 L
.824 .26793 L
.828 .26753 L
.832 .26719 L
.836 .26691 L
.84 .26667 L
.844 .26646 L
.848 .26629 L
.852 .26615 L
.856 .26603 L
.86 .26593 L
.864 .26584 L
.868 .26577 L
.872 .26571 L
.876 .26566 L
.88 .26561 L
.884 .26557 L
.888 .26553 L
.892 .2655 L
.896 .26547 L
.9 .26544 L
.904 .26541 L
.908 .26539 L
.912 .26536 L
.916 .26534 L
.92 .26531 L
.924 .26529 L
.928 .26526 L
.932 .26524 L
.936 .26522 L
.94 .2652 L
.944 .26517 L
.948 .26515 L
.952 .26513 L
.956 .26511 L
.96 .26508 L
.964 .26506 L
.968 .26504 L
.972 .26502 L
.976 .26499 L
.98 .26497 L
.984 .26495 L
.988 .26493 L
.992 .2649 L
.996 .26489 L
1 .26486 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43407 L
.012 .43014 L
.016 .42867 L
.02 .42976 L
.024 .4303 L
.028 .42986 L
.032 .42962 L
.036 .42962 L
.04 .42966 L
.044 .42957 L
.048 .42953 L
.052 .4295 L
.056 .42954 L
.06 .42954 L
.064 .42956 L
.068 .42952 L
.072 .42951 L
.076 .42946 L
.08 .42941 L
.084 .42932 L
.088 .42925 L
.092 .4292 L
.096 .42919 L
.1 .42914 L
.104 .4291 L
.108 .42907 L
.112 .42909 L
.116 .42909 L
.12 .42906 L
.124 .429 L
.128 .42899 L
.132 .42899 L
.136 .42897 L
.14 .4289 L
.144 .42885 L
.148 .42885 L
.152 .42887 L
.156 .42882 L
.16 .42869 L
.164 .42855 L
.168 .42848 L
.172 .42846 L
.176 .42844 L
.18 .42841 L
.184 .42841 L
.188 .4285 L
.192 .42865 L
.196 .42876 L
.2 .42874 L
Mistroke
.204 .42859 L
.208 .42841 L
.212 .42829 L
.216 .42822 L
.22 .42812 L
.224 .42796 L
.228 .42778 L
.232 .42772 L
.236 .42786 L
.24 .4281 L
.244 .42826 L
.248 .42819 L
.252 .42798 L
.256 .42785 L
.26 .42793 L
.264 .42817 L
.268 .42831 L
.272 .42817 L
.276 .42783 L
.28 .42756 L
.284 .42757 L
.288 .4278 L
.292 .42796 L
.296 .42778 L
.3 .42728 L
.304 .42675 L
.308 .42654 L
.312 .42678 L
.316 .42731 L
.32 .42779 L
.324 .42799 L
.328 .42787 L
.332 .42757 L
.336 .4273 L
.34 .42717 L
.344 .42724 L
.348 .42746 L
.352 .42773 L
.356 .42789 L
.36 .42779 L
.364 .42735 L
.368 .42667 L
.372 .42604 L
.376 .42579 L
.38 .4261 L
.384 .4269 L
.388 .4278 L
.392 .42835 L
.396 .4282 L
.4 .42733 L
Mistroke
.404 .42604 L
.408 .42474 L
.412 .42382 L
.416 .42346 L
.42 .42369 L
.424 .42443 L
.428 .4256 L
.432 .42716 L
.436 .42903 L
.44 .431 L
.444 .43275 L
.448 .43384 L
.452 .43385 L
.456 .43259 L
.46 .43006 L
.464 .42651 L
.468 .42226 L
.472 .41759 L
.476 .41262 L
.48 .40731 L
.484 .40158 L
.488 .39534 L
.492 .38863 L
.496 .38163 L
.5 .37456 L
.504 .36767 L
.508 .36106 L
.512 .3547 L
.516 .3484 L
.52 .34191 L
.524 .33498 L
.528 .32749 L
.532 .31946 L
.536 .31108 L
.54 .30264 L
.544 .29443 L
.548 .2867 L
.552 .27956 L
.556 .27299 L
.56 .26681 L
.564 .26077 L
.568 .25461 L
.572 .24806 L
.576 .24098 L
.58 .23329 L
.584 .22505 L
.588 .21639 L
.592 .20755 L
.596 .19874 L
.6 .19022 L
Mistroke
.604 .18217 L
.608 .17474 L
.612 .16803 L
.616 .16206 L
.62 .1568 L
.624 .15218 L
.628 .1481 L
.632 .14444 L
.636 .1411 L
.64 .138 L
.644 .13504 L
.648 .13218 L
.652 .12938 L
.656 .12663 L
.66 .12392 L
.664 .12125 L
.668 .11866 L
.672 .11614 L
.676 .11372 L
.68 .1114 L
.684 .10918 L
.688 .10705 L
.692 .10499 L
.696 .10297 L
.7 .10097 L
.704 .09894 L
.708 .09687 L
.712 .09473 L
.716 .09249 L
.72 .09014 L
.724 .08767 L
.728 .08509 L
.732 .08239 L
.736 .0796 L
.74 .07673 L
.744 .07381 L
.748 .07088 L
.752 .06796 L
.756 .06507 L
.76 .06226 L
.764 .05954 L
.768 .05694 L
.772 .05447 L
.776 .05216 L
.78 .05001 L
.784 .04803 L
.788 .04623 L
.792 .0446 L
.796 .04313 L
.8 .04183 L
Mistroke
.804 .04068 L
.808 .03967 L
.812 .03879 L
.816 .03804 L
.82 .03739 L
.824 .03684 L
.828 .03638 L
.832 .03599 L
.836 .03566 L
.84 .0354 L
.844 .03518 L
.848 .035 L
.852 .03486 L
.856 .03474 L
.86 .03465 L
.864 .03458 L
.868 .03452 L
.872 .03448 L
.876 .03445 L
.88 .03442 L
.884 .03441 L
.888 .03439 L
.892 .03439 L
.896 .03438 L
.9 .03438 L
.904 .03438 L
.908 .03438 L
.912 .03438 L
.916 .03439 L
.92 .03439 L
.924 .0344 L
.928 .0344 L
.932 .03441 L
.936 .03441 L
.94 .03442 L
.944 .03442 L
.948 .03443 L
.952 .03443 L
.956 .03444 L
.96 .03445 L
.964 .03446 L
.968 .03446 L
.972 .03447 L
.976 .03447 L
.98 .03448 L
.984 .03448 L
.988 .0345 L
.992 .03449 L
.996 .03451 L
1 .03451 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo02=oo`04001oogooOol20013Ool0029oo`h00003Ool0000000H00005Ool00000001oo`04
00001Goo00000000Ool00P000Woo00@007ooOol0049oo`008WooH`0037oo000ROol01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoo`000goo00D007ooOomo
o`0000=oo`80009oo`80009oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo0`0000=oo`00
Ool00Woo00<007oo00006P0037oo000ROol2000[Ool00`00Oomoo`0>Ool2000_Ool0029oo`03001o
ogoo02Yoo`03001oogoo00ioo`03001oogoo02ioo`008Woo0P00:goo0P003goo00<007ooOol0;Woo
000ROol2000]Ool00`00Oomoo`0;Ool00`00Oomoo`0_Ool000]oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`03001oogoo02aoo`03001oogoo00]oo`03001oogoo02moo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000]Ool00`00Oomoo`0;Ool00`00Oomoo`0_Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00;Woo00@007oo0000009o
o`8000Eoo`03001oogoo02moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`0]Ool20002Ool01000Ool0000017oo00<007ooOol0<7oo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`80039oo`80009oo`05001oogooOol0000bOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00=Woo00@007ooOol003=oo`002goo0P00
2Woo0P0017oo00<007ooOol00Woo00<007ooOol0=Woo00<007oo0000<goo000;Ool20004Ool00`00
Oomoo`03Ool20002Ool50002Ool2000gOol00`00Ool0000cOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol0009oo`8003Moo`8003Aoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo
00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol0
0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2
000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00
Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
1000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<0
07ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@00
0Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:
Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
06Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo
00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
2goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@00
0Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo
0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo
1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001o
o`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo0000
0goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00
Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo
0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol0
0`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomo
o`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002
Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002OolC0003Ool01000
Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004
Ool01000Oomoogoo1@000goo0P000goo0`000goo10000goo0P0017oo0`000Woo1@000goo0P001Woo
000XOol00`00Oomoo`12Ool3000QOol002Qoo`03001oogoo045oo`8002=oo`00:7ooG@0037oo000X
Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool30007Ool00`00
Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo03Yoo`<002Uoo`00:7oo00<007ooOol0>7oo
0`00:goo000XOol00`00Oomoo`0gOol2000]Ool002Qoo`03001oogoo03Ioo`8002ioo`00:7oo00<0
07ooOol0=Goo00<007ooOol0;Woo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003
Ool00`00Oomoo`0dOol2000`Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0003Ool01000Oomoo`00=Woo00<007ooOol0;goo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0005Ool01000Oomoo`00=Goo00<007ooOol0<7oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000dOol00`00Oomoo`0`Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo039oo`03001o
ogoo035oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001o
ogoo035oo`03001oogoo039oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0<7oo
0P00=7oo000XOol00`00Oomoo`0`Ool00`00Oomoo`0cOol002Qoo`03001oogoo02moo`03001oogoo
03Aoo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0;Woo00<007ooOol0
=Goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo02ioo`03
001oogoo03Eoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`0]Ool00`00Oomoo`0fOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00;Goo0P00>7oo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo02aoo`03001oogoo03Moo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00
Oomoo`0[Ool00`00Oomoo`0hOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo02Yo
o`03001oogoo03Uoo`00:7oo00<007ooOol0:Goo0P00>goo000XOol00`00Oomoo`0XOol2000lOol0
02Qoob`003eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0
9Woo00<007ooOol0?Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003
Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03
001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00
Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Ao
o`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03
001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04
001oogoo000;Ool01000Oomoo`00E7oo500037oo000:Ool01000Oomoo`001goo10000goo00<007oo
Ool0Cgoo10007goo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00CWoo0P008goo000;Ool2
0008Ool50002Ool00`00Oomoo`1;Ool2000UOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<0
00Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<0
00Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<0
07ooOol00goo10000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`02Ool30004Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`020003Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@0
00=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001o
ogooOol40003Ool00`00Oomoo`030002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03
001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=o
o`03001oogoo00Aoo`03001oo`00008000=oo`05001oogooOol00002Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo
0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`80
00Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0?goo0P00<Goo000LOol00`00
Oomoo`0nOol2000bOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOomoo`80009oo`05001oogooOol00004
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool00`00Oomoo`0:Ool001aoo`03001oogoo03aoo`03001oogoo03=oo`0077oo0P00?7oo00<007oo
Ool0=7oo000LOol00`00Oomoo`0kOol00`00Oomoo`0dOol001aoo`03001oogoo03Yoo`03001oogoo
03Eoo`0077oo0P00>goo00<007ooOol0=Goo000LOol00`00Oomoo`0jOol00`00Oomoo`0eOol001ao
o`03001oogoo03Uoo`03001oogoo03Ioo`0077oo0P00>Goo0P00>7oo000LOol00`00Oomoo`0hOol0
0`00Oomoo`0gOol001aoo`8003Qoo`8003Uoo`002goo0P0017oo00<007ooOol00Woo0`000goo00<0
07ooOol0=goo00<007ooOol0>7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo03Ioo`03001oogoo03Uoo`002Woo00@007ooOol000]oo`03001oogoo008003Ioo`03001oogoo
03Yoo`002Woo00@007ooOol000]oo`04001oogoo000gOol00`00Oomoo`0jOol000Yoo`04001oogoo
0007Ool40003Ool00`00Oomoo`0eOol00`00Oomoo`0jOol000Yoo`04001oogoo0007Ool00`00Oomo
o`04Ool2000eOol00`00Oomoo`0kOol000]oo`8000Qoo`D0009oo`03001oogoo03=oo`03001oogoo
03aoo`0077oo00<007ooOol0<goo00<007ooOol0?7oo000LOol2000cOol2000nOol001aoo`03001o
ogoo039oo`03001oogoo03eoo`0077oo0P00<Woo00<007ooOol0?Woo000LOol00`00Oomoo`0`Ool0
0`00Oomoo`0oOol001aoo`03001oogoo031oo`03001oogoo03moo`0077oo0P00<7oo00<007ooOol0
@7oo000FOol30003Ool00`00Oomoo`0^Ool20012Ool001Moo`03001oogoo009oo`03001oogoo02Qo
o`8000Aoo`03001oogoo045oo`005goo00<007ooOol00Woo:`0000=oo`0000000`00A7oo000GOol0
0`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P00
17oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo
00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`00
2goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomo
o`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@00
0Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(28891\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29215 m
.008 .29384 L
.012 .29841 L
.016 .30167 L
.02 .30182 L
.024 .30142 L
.028 .30011 L
.032 .29766 L
.036 .29572 L
.04 .29543 L
.044 .29702 L
.048 .29912 L
.052 .3004 L
.056 .30038 L
.06 .29896 L
.064 .29724 L
.068 .29616 L
.072 .29609 L
.076 .29731 L
.08 .29924 L
.084 .30075 L
.088 .30074 L
.092 .29923 L
.096 .29754 L
.1 .29655 L
.104 .29627 L
.108 .29666 L
.112 .2977 L
.116 .29905 L
.12 .29973 L
.124 .29914 L
.128 .29791 L
.132 .29722 L
.136 .29759 L
.14 .29828 L
.144 .29837 L
.148 .29798 L
.152 .29782 L
.156 .29802 L
.16 .29802 L
.164 .29766 L
.168 .29758 L
.172 .29823 L
.176 .29913 L
.18 .29918 L
.184 .29796 L
.188 .29633 L
.192 .29561 L
.196 .2963 L
.2 .2977 L
Mistroke
.204 .2988 L
.208 .29914 L
.212 .29906 L
.216 .29912 L
.22 .29934 L
.224 .2991 L
.228 .29784 L
.232 .2958 L
.236 .2943 L
.24 .29463 L
.244 .29678 L
.248 .2991 L
.252 .29982 L
.256 .29878 L
.26 .29764 L
.264 .29812 L
.268 .29981 L
.272 .30034 L
.276 .29797 L
.28 .29381 L
.284 .29141 L
.288 .29352 L
.292 .29916 L
.296 .30409 L
.3 .30445 L
.304 .30008 L
.308 .29464 L
.312 .29228 L
.316 .29412 L
.32 .29767 L
.324 .29941 L
.328 .29797 L
.332 .29503 L
.336 .29358 L
.34 .29517 L
.344 .2989 L
.348 .30241 L
.352 .30381 L
.356 .30266 L
.36 .29968 L
.364 .29581 L
.368 .29194 L
.372 .28918 L
.376 .28897 L
.38 .29241 L
.384 .29902 L
.388 .30616 L
.392 .31004 L
.396 .30793 L
.4 .30015 L
Mistroke
.404 .29026 L
.408 .28326 L
.412 .28268 L
.416 .28866 L
.42 .29805 L
.424 .30642 L
.428 .31053 L
.432 .30974 L
.436 .30569 L
.44 .3007 L
.444 .29618 L
.448 .29204 L
.452 .28742 L
.456 .28199 L
.46 .27686 L
.464 .27442 L
.468 .27711 L
.472 .28599 L
.476 .29986 L
.48 .3156 L
.484 .32962 L
.488 .33946 L
.492 .34498 L
.496 .34819 L
.5 .35209 L
.504 .35902 L
.508 .36945 L
.512 .38175 L
.516 .39305 L
.52 .40056 L
.524 .4028 L
.528 .40016 L
.532 .39465 L
.536 .38901 L
.54 .38577 L
.544 .3864 L
.548 .39092 L
.552 .39803 L
.556 .40553 L
.56 .41116 L
.564 .41329 L
.568 .41149 L
.572 .40658 L
.576 .40034 L
.58 .39485 L
.584 .39191 L
.588 .39267 L
.592 .39739 L
.596 .40559 L
.6 .41615 L
Mistroke
.604 .42752 L
.608 .43798 L
.612 .44598 L
.616 .45042 L
.62 .45077 L
.624 .44712 L
.628 .43998 L
.632 .43004 L
.636 .41809 L
.64 .40489 L
.644 .39118 L
.648 .37766 L
.652 .3649 L
.656 .35329 L
.66 .34305 L
.664 .33428 L
.668 .32698 L
.672 .32113 L
.676 .31662 L
.68 .31328 L
.684 .31091 L
.688 .30932 L
.692 .30836 L
.696 .30793 L
.7 .30795 L
.704 .30827 L
.708 .30873 L
.712 .30918 L
.716 .30954 L
.72 .30979 L
.724 .30996 L
.728 .31008 L
.732 .31017 L
.736 .31024 L
.74 .31031 L
.744 .31038 L
.748 .31044 L
.752 .3105 L
.756 .31061 L
.76 .31081 L
.764 .31115 L
.768 .31166 L
.772 .31226 L
.776 .31288 L
.78 .31345 L
.784 .31398 L
.788 .31451 L
.792 .31509 L
.796 .31571 L
.8 .31631 L
Mistroke
.804 .31684 L
.808 .31726 L
.812 .31756 L
.816 .31779 L
.82 .31798 L
.824 .31816 L
.828 .31831 L
.832 .31843 L
.836 .3185 L
.84 .3185 L
.844 .31845 L
.848 .31836 L
.852 .31828 L
.856 .31822 L
.86 .31819 L
.864 .31816 L
.868 .31811 L
.872 .31803 L
.876 .31793 L
.88 .31784 L
.884 .31778 L
.888 .31776 L
.892 .31775 L
.896 .31774 L
.9 .3177 L
.904 .31766 L
.908 .31762 L
.912 .31759 L
.916 .31759 L
.92 .3176 L
.924 .3176 L
.928 .3176 L
.932 .31759 L
.936 .31757 L
.94 .31756 L
.944 .31756 L
.948 .31757 L
.952 .3176 L
.956 .31761 L
.96 .31759 L
.964 .31757 L
.968 .31756 L
.972 .31757 L
.976 .31761 L
.98 .31763 L
.984 .31763 L
.988 .3176 L
.992 .31757 L
.996 .31758 L
1 .3176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57445 m
.008 .58056 L
.012 .58274 L
.016 .58082 L
.02 .58009 L
.024 .58064 L
.028 .58095 L
.032 .58074 L
.036 .58065 L
.04 .58067 L
.044 .58073 L
.048 .5807 L
.052 .58072 L
.056 .58072 L
.06 .58075 L
.064 .58074 L
.068 .58073 L
.072 .58069 L
.076 .58069 L
.08 .58067 L
.084 .58068 L
.088 .58066 L
.092 .5807 L
.096 .58073 L
.1 .58076 L
.104 .58076 L
.108 .58077 L
.112 .58077 L
.116 .58077 L
.12 .58072 L
.124 .58066 L
.128 .58063 L
.132 .58064 L
.136 .58065 L
.14 .58065 L
.144 .58066 L
.148 .58072 L
.152 .58078 L
.156 .58081 L
.16 .58078 L
.164 .58075 L
.168 .58075 L
.172 .58078 L
.176 .58077 L
.18 .58071 L
.184 .58064 L
.188 .58061 L
.192 .58062 L
.196 .58063 L
.2 .58061 L
Mistroke
.204 .58058 L
.208 .58061 L
.212 .58072 L
.216 .58085 L
.22 .58093 L
.224 .58092 L
.228 .58085 L
.232 .5808 L
.236 .5808 L
.24 .58079 L
.244 .5807 L
.248 .58052 L
.252 .58037 L
.256 .58036 L
.26 .58053 L
.264 .58074 L
.268 .58083 L
.272 .58074 L
.276 .58062 L
.28 .58062 L
.284 .58081 L
.288 .58104 L
.292 .5811 L
.296 .58093 L
.3 .58067 L
.304 .58055 L
.308 .58068 L
.312 .58092 L
.316 .58104 L
.32 .58086 L
.324 .58046 L
.328 .58007 L
.332 .57995 L
.336 .58014 L
.34 .58052 L
.344 .58088 L
.348 .58107 L
.352 .58105 L
.356 .58091 L
.36 .58073 L
.364 .58063 L
.368 .58067 L
.372 .58086 L
.376 .58115 L
.38 .58137 L
.384 .58138 L
.388 .58106 L
.392 .5805 L
.396 .57994 L
.4 .57968 L
Mistroke
.404 .57991 L
.408 .58056 L
.412 .58134 L
.416 .58189 L
.42 .58192 L
.424 .5814 L
.428 .5805 L
.432 .57952 L
.436 .57873 L
.44 .57828 L
.444 .57821 L
.448 .57852 L
.452 .57922 L
.456 .58032 L
.46 .5818 L
.464 .58351 L
.468 .58518 L
.472 .58644 L
.476 .58695 L
.48 .58649 L
.484 .58503 L
.488 .58272 L
.492 .57978 L
.496 .57642 L
.5 .57275 L
.504 .56878 L
.508 .56443 L
.512 .55964 L
.516 .55444 L
.52 .54894 L
.524 .54334 L
.528 .53782 L
.532 .53251 L
.536 .52742 L
.54 .52244 L
.544 .51736 L
.548 .51199 L
.552 .50619 L
.556 .49993 L
.56 .49332 L
.564 .48656 L
.568 .47989 L
.572 .47351 L
.576 .46758 L
.58 .46211 L
.584 .45703 L
.588 .45217 L
.592 .4473 L
.596 .44223 L
.6 .43678 L
Mistroke
.604 .43086 L
.608 .42448 L
.612 .41771 L
.616 .41069 L
.62 .40358 L
.624 .3966 L
.628 .38989 L
.632 .38362 L
.636 .37787 L
.64 .3727 L
.644 .3681 L
.648 .36404 L
.652 .36046 L
.656 .35728 L
.66 .35441 L
.664 .35176 L
.668 .34928 L
.672 .3469 L
.676 .34459 L
.68 .34233 L
.684 .3401 L
.688 .33792 L
.692 .33578 L
.696 .3337 L
.7 .33169 L
.704 .32977 L
.708 .32792 L
.712 .32616 L
.716 .32445 L
.72 .3228 L
.724 .32117 L
.728 .31954 L
.732 .31789 L
.736 .31619 L
.74 .31443 L
.744 .31259 L
.748 .31065 L
.752 .30862 L
.756 .30649 L
.76 .30428 L
.764 .302 L
.768 .29966 L
.772 .2973 L
.776 .29492 L
.78 .29257 L
.784 .29025 L
.788 .28799 L
.792 .28581 L
.796 .28373 L
.8 .28177 L
Mistroke
.804 .27993 L
.808 .27823 L
.812 .27666 L
.816 .27523 L
.82 .27393 L
.824 .27277 L
.828 .27174 L
.832 .27082 L
.836 .27002 L
.84 .26931 L
.844 .26871 L
.848 .26819 L
.852 .26774 L
.856 .26735 L
.86 .26703 L
.864 .26676 L
.868 .26653 L
.872 .26633 L
.876 .26617 L
.88 .26603 L
.884 .26592 L
.888 .26582 L
.892 .26574 L
.896 .26567 L
.9 .26561 L
.904 .26556 L
.908 .26551 L
.912 .26547 L
.916 .26544 L
.92 .2654 L
.924 .26537 L
.928 .26534 L
.932 .26532 L
.936 .26529 L
.94 .26527 L
.944 .26524 L
.948 .26522 L
.952 .26519 L
.956 .26517 L
.96 .26515 L
.964 .26513 L
.968 .2651 L
.972 .26508 L
.976 .26506 L
.98 .26504 L
.984 .26501 L
.988 .265 L
.992 .26497 L
.996 .26495 L
1 .26492 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42623 L
.012 .43003 L
.016 .43113 L
.02 .4296 L
.024 .42929 L
.028 .42978 L
.032 .42994 L
.036 .42973 L
.04 .42973 L
.044 .42975 L
.048 .42973 L
.052 .42959 L
.056 .42952 L
.06 .42944 L
.064 .42942 L
.068 .42936 L
.072 .42937 L
.076 .42936 L
.08 .42938 L
.084 .42934 L
.088 .42932 L
.092 .42929 L
.096 .42929 L
.1 .42925 L
.104 .4292 L
.108 .42914 L
.112 .4291 L
.116 .42906 L
.12 .429 L
.124 .42893 L
.128 .42891 L
.132 .42893 L
.136 .42892 L
.14 .42886 L
.144 .4288 L
.148 .42877 L
.152 .42878 L
.156 .42878 L
.16 .42874 L
.164 .42871 L
.168 .42873 L
.172 .42876 L
.176 .42872 L
.18 .4286 L
.184 .42845 L
.188 .42835 L
.192 .42831 L
.196 .42828 L
.2 .42822 L
Mistroke
.204 .42816 L
.208 .42819 L
.212 .42831 L
.216 .42847 L
.22 .42855 L
.224 .4285 L
.228 .42836 L
.232 .42824 L
.236 .42818 L
.24 .42813 L
.244 .42799 L
.248 .42775 L
.252 .42755 L
.256 .42754 L
.26 .42772 L
.264 .42794 L
.268 .428 L
.272 .42785 L
.276 .42764 L
.28 .42761 L
.284 .42782 L
.288 .42808 L
.292 .42814 L
.296 .42791 L
.3 .42756 L
.304 .42737 L
.308 .42749 L
.312 .42776 L
.316 .42786 L
.32 .4276 L
.324 .42707 L
.328 .42657 L
.332 .42638 L
.336 .42659 L
.34 .42704 L
.344 .42746 L
.348 .42767 L
.352 .42761 L
.356 .42739 L
.36 .42713 L
.364 .42697 L
.368 .42699 L
.372 .42721 L
.376 .42754 L
.38 .42779 L
.384 .42776 L
.388 .42732 L
.392 .42659 L
.396 .42586 L
.4 .42551 L
Mistroke
.404 .42576 L
.408 .42654 L
.412 .42748 L
.416 .42813 L
.42 .42815 L
.424 .42747 L
.428 .42632 L
.432 .42507 L
.436 .42404 L
.44 .42343 L
.444 .42331 L
.448 .42367 L
.452 .42452 L
.456 .42587 L
.46 .42769 L
.464 .42978 L
.468 .43182 L
.472 .43336 L
.476 .43396 L
.48 .43335 L
.484 .4315 L
.488 .42859 L
.492 .42489 L
.496 .42068 L
.5 .41608 L
.504 .4111 L
.508 .40565 L
.512 .39965 L
.516 .39313 L
.52 .38625 L
.524 .37925 L
.528 .37236 L
.532 .36573 L
.536 .35937 L
.54 .35313 L
.544 .34678 L
.548 .34006 L
.552 .33281 L
.556 .325 L
.56 .31676 L
.564 .30832 L
.568 .29999 L
.572 .29205 L
.576 .28464 L
.58 .27782 L
.584 .27148 L
.588 .26541 L
.592 .25934 L
.596 .25301 L
.6 .24623 L
Mistroke
.604 .23886 L
.608 .23091 L
.612 .22247 L
.616 .21371 L
.62 .20486 L
.624 .19616 L
.628 .18782 L
.632 .18002 L
.636 .17287 L
.64 .16643 L
.644 .16071 L
.648 .15567 L
.652 .15122 L
.656 .14727 L
.66 .1437 L
.664 .14043 L
.668 .13735 L
.672 .13441 L
.676 .13155 L
.68 .12875 L
.684 .12599 L
.688 .12328 L
.692 .12063 L
.696 .11807 L
.7 .11559 L
.704 .11321 L
.708 .11094 L
.712 .10875 L
.716 .10665 L
.72 .10461 L
.724 .1026 L
.728 .1006 L
.732 .09856 L
.736 .09647 L
.74 .0943 L
.744 .09203 L
.748 .08964 L
.752 .08713 L
.756 .0845 L
.76 .08177 L
.764 .07896 L
.768 .07608 L
.772 .07316 L
.776 .07022 L
.78 .06731 L
.784 .06445 L
.788 .06166 L
.792 .05898 L
.796 .05643 L
.8 .05401 L
Mistroke
.804 .05175 L
.808 .04966 L
.812 .04773 L
.816 .04598 L
.82 .0444 L
.824 .04298 L
.828 .04173 L
.832 .04062 L
.836 .03965 L
.84 .03881 L
.844 .03809 L
.848 .03747 L
.852 .03694 L
.856 .0365 L
.86 .03613 L
.864 .03582 L
.868 .03557 L
.872 .03536 L
.876 .03519 L
.88 .03505 L
.884 .03495 L
.888 .03486 L
.892 .03479 L
.896 .03474 L
.9 .0347 L
.904 .03467 L
.908 .03465 L
.912 .03463 L
.916 .03462 L
.92 .03461 L
.924 .03461 L
.928 .03461 L
.932 .03461 L
.936 .03461 L
.94 .03461 L
.944 .03461 L
.948 .03462 L
.952 .03462 L
.956 .03463 L
.96 .03463 L
.964 .03464 L
.968 .03464 L
.972 .03466 L
.976 .03466 L
.98 .03467 L
.984 .03467 L
.988 .03468 L
.992 .03468 L
.996 .0347 L
1 .03469 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`<000Eoo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo02Eoo`04001oogooOol30010Ool0029oo`800004Ool00000Ool3000017oo000007oo2000
00=oo`0000001@0000=oo`0000000P000Woo0P000Woo0P0000Eoo`00001oo`00041oo`008WooH`00
37oo000ROol01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000
Oomoo`000goo00D007ooOomoo`00009oo`80009oo`8000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000Woo00@007ooOomoo`80009ooad000aoo`008Woo0P00;Goo00<007ooOol03goo0P00;7oo
000ROol00`00Oomoo`0/Ool2000@Ool00`00Oomoo`0[Ool0029oo`8002ioo`03001oogoo00eoo`03
001oogoo02aoo`008Woo0P00;goo00<007ooOol037oo00<007ooOol0;7oo000;Ool20004Ool00`00
Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0_Ool00`00Oomoo`0;Ool00`00Oomoo`0/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00<7oo00<007ooOol02Woo00<0
07ooOol0;Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80031oo`03
001oo`00008000Qoo`03001oogoo02eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`0_Ool300000goo001oo`030004Ool00`00Oomoo`0]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00<Goo00<007ooOol00`0000=oo`00Ool0
0Woo00<007ooOol0;Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8003Eoo`05
001oogooOol00002Ool00`00Oomoo`0^Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001o
ogoo03Qoo`04001oogoo000`Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8003Uo
o`03001oo`00035oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00
>Woo0P00<Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000
Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool0
1P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`00
8Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool0
00Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`80
00=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo
00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@0
07ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003
Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo
0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004
Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool3
0003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001o
ogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol0
0goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0
3Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo
00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yo
o`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo
00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo
0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
o`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo
0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001o
ogoo001oo`000goo00@007ooOol0009oo`03001oogoo010000=oo`04001oogoo0005Ool002Qoo`03
001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003
Ool20003Ool30004Ool80004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo04Eoo`8001mo
o`00:7oo00<007ooOol0@goo0P008Goo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo
011oo`03001oogoo00moo`03001oogoo00Qoo`<000Aoo`03001oogoo011oo`03001oogoo00Yoo`00
:7oo00<007ooOol0?Goo0`009Woo000XOol00`00Oomoo`0kOol2000YOol002Qoo`03001oogoo03Uo
o`<002Yoo`00:7oo00<007ooOol0>7oo0P00;7oo000XOol00`00Oomoo`0gOol2000]Ool000]oo`80
00Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo03Moo`03001oogoo02aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000hOol0
0`00Oomoo`0]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001o
ogoo000gOol2000_Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo008003Ioo`03001oogoo02ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00
Oomoo`00Ool010000goo00<007ooOol0=7oo0P00<7oo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`06001oogoo001oo`001Woo00<007ooOol0=7oo00<007ooOol0;goo000;Ool2000:Ool20004
Ool20002Ool50002Ool00`00Oomoo`0cOol00`00Oomoo`0`Ool002Qoo`03001oogoo039oo`80039o
o`00:7oo00<007ooOol0<Goo0P00<goo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool0
0`00Oomoo`0aOol00`00Oomoo`0bOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0<7oo00<007ooOol0<goo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo031oo`03001oogoo03=oo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2000`Ool00`00Oomoo`0dOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0;Woo00<007ooOol0=Goo000@Ool01000Oomoo`00
27oo00@007ooOol0009oo`8000Aoo`03001oogoo02eoo`8003Moo`004Goo0P002Woo0P0017oo00<0
07ooOol00Woo00<007ooOol0;Goo00<007ooOol0=Woo000XOol00`00Oomoo`0/Ool00`00Oomoo`0g
Ool002Qoo`03001oogoo02]oo`03001oogoo03Qoo`00:7oo;P00>goo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool30003Ool00`00Oomoo`0YOol00`00Oomoo`0jOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@0
07ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001GOolA000<
Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1BOol3000MOol000Yoo`04001oogoo0007
Ool00`00Oomoo`04Ool2001@Ool3000POol000]oo`8000Qoo`D0009oo`03001oogoo04ioo`80029o
o`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo
0P001Goo1@0000=oo`0000000P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool0
1@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`020000
1Goo001oogoo00000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03
001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00Aoo`<0009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00=oo`<000=oo`04001oogoo0002Ool01000Oomoo`001goo00<007ooOol017oo00@0
07ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0003Ool2
0003Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo009oo`06001oogooOol007oo1000
0goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`80
00Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00D007ooOol007oo
00@000=oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo00L007ooOomoo`00Ool0
0006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool2
0006Ool01000Oomoogoo1@000goo0P0000=oo`0000000goo0`0017oo0P0017oo0P001Woo0`000Woo
1@000goo0P001Woo000LOol00`00Oomoo`11Ool3000^Ool001aoo`03001oogoo045oo`03001oogoo
02ioo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo
00Yoo`0077oo00<007ooOol0?goo00<007ooOol0<7oo000LOol2000oOol00`00Oomoo`0aOol001ao
o`03001oogoo03ioo`03001oogoo035oo`0077oo00<007ooOol0?Goo00<007ooOol0<Woo000LOol2
000nOol00`00Oomoo`0bOol001aoo`03001oogoo03aoo`03001oogoo03=oo`0077oo00<007ooOol0
?7oo00<007ooOol0<goo000LOol2000lOol00`00Oomoo`0dOol001aoo`03001oogoo03Yoo`8003Io
o`0077oo0P00>goo00<007ooOol0=Goo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomo
o`0iOol2000gOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0>Goo00<0
07ooOol0=Woo000:Ool01000Oomoo`002goo00<007ooOol00P00>Goo00<007ooOol0=goo000:Ool0
1000Oomoo`002goo00@007ooOol003Yoo`03001oogoo03Moo`002Woo00@007ooOol000Moo`@000=o
o`03001oogoo03Moo`03001oogoo03Qoo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8003Qo
o`03001oogoo03Qoo`002goo0P0027oo1@000Woo00<007ooOol0=Woo00<007ooOol0>Goo000LOol0
0`00Oomoo`0eOol2000kOol001aoo`8003Ioo`03001oogoo03Yoo`0077oo00<007ooOol0=7oo0P00
?7oo000LOol2000eOol00`00Oomoo`0kOol001aoo`03001oogoo03=oo`03001oogoo03aoo`0077oo
00<007ooOol0<goo00<007ooOol0?7oo000LOol2000cOol00`00Oomoo`0mOol001Ioo`<000=oo`03
001oogoo035oo`8003moo`005goo00<007ooOol00Woo00<007ooOol0:Woo0`000goo0P00@7oo000G
Ool00`00Oomoo`02Ool^00000goo000000030011Ool001Moo`03001oogoo009oo`03001oogoo079o
o`005goo00<007ooOol00Woo00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo
009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<0
07ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomo
o`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007oo
Ool017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(29058\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29736 m
.008 .2983 L
.012 .29809 L
.016 .29808 L
.02 .29764 L
.024 .29776 L
.028 .29867 L
.032 .29874 L
.036 .29824 L
.04 .29781 L
.044 .29777 L
.048 .29848 L
.052 .29922 L
.056 .29958 L
.06 .29941 L
.064 .29865 L
.068 .29779 L
.072 .29699 L
.076 .29671 L
.08 .29747 L
.084 .29869 L
.088 .29945 L
.092 .29928 L
.096 .29857 L
.1 .29795 L
.104 .29744 L
.108 .29722 L
.112 .29766 L
.116 .2987 L
.12 .29959 L
.124 .29943 L
.128 .29823 L
.132 .29706 L
.136 .29678 L
.14 .29726 L
.144 .29777 L
.148 .29816 L
.152 .29873 L
.156 .29925 L
.16 .29899 L
.164 .29785 L
.168 .29677 L
.172 .29678 L
.176 .2978 L
.18 .29873 L
.184 .29873 L
.188 .2981 L
.192 .29777 L
.196 .29804 L
.2 .29836 L
Mistroke
.204 .29814 L
.208 .29745 L
.212 .29691 L
.216 .29697 L
.22 .29746 L
.224 .29778 L
.228 .29766 L
.232 .29747 L
.236 .29791 L
.24 .2992 L
.244 .30049 L
.248 .30037 L
.252 .29827 L
.256 .29532 L
.26 .29371 L
.264 .29473 L
.268 .2974 L
.272 .2993 L
.276 .29896 L
.28 .29743 L
.284 .29707 L
.288 .29891 L
.292 .3012 L
.296 .30097 L
.3 .29727 L
.304 .29264 L
.308 .29104 L
.312 .29425 L
.316 .30001 L
.32 .30386 L
.324 .30305 L
.328 .29873 L
.332 .29468 L
.336 .29387 L
.34 .2961 L
.344 .29862 L
.348 .29889 L
.352 .29672 L
.356 .29413 L
.36 .29337 L
.364 .29512 L
.368 .29831 L
.372 .30131 L
.376 .30302 L
.38 .3031 L
.384 .30147 L
.388 .29802 L
.392 .2932 L
.396 .28865 L
.4 .28692 L
Mistroke
.404 .28999 L
.408 .29749 L
.412 .30616 L
.416 .31134 L
.42 .30978 L
.424 .30175 L
.428 .29115 L
.432 .28333 L
.436 .28199 L
.44 .28732 L
.444 .29622 L
.448 .30446 L
.452 .30902 L
.456 .30938 L
.46 .30695 L
.464 .30357 L
.468 .30007 L
.472 .29597 L
.476 .29036 L
.48 .28317 L
.484 .2759 L
.488 .27131 L
.492 .27213 L
.496 .2796 L
.5 .29271 L
.504 .30849 L
.508 .32331 L
.512 .33449 L
.516 .3414 L
.52 .34562 L
.524 .34991 L
.528 .35681 L
.532 .36724 L
.536 .38007 L
.54 .39267 L
.544 .40207 L
.548 .40632 L
.552 .40524 L
.556 .40043 L
.56 .39459 L
.564 .39045 L
.568 .38994 L
.572 .39355 L
.576 .40034 L
.58 .40831 L
.584 .4151 L
.588 .41875 L
.592 .41833 L
.596 .41419 L
.6 .40782 L
Mistroke
.604 .40131 L
.608 .39672 L
.612 .39555 L
.616 .39848 L
.62 .40531 L
.624 .41514 L
.628 .42654 L
.632 .43788 L
.636 .44754 L
.64 .45422 L
.644 .4571 L
.648 .45592 L
.652 .45085 L
.656 .44241 L
.66 .4313 L
.664 .41833 L
.668 .40437 L
.672 .39026 L
.676 .37669 L
.68 .36416 L
.684 .35291 L
.688 .34304 L
.692 .33458 L
.696 .32754 L
.7 .32192 L
.704 .31766 L
.708 .31458 L
.712 .3125 L
.716 .31116 L
.72 .31039 L
.724 .31003 L
.728 .30997 L
.732 .31011 L
.736 .31038 L
.74 .31071 L
.744 .31106 L
.748 .31137 L
.752 .31159 L
.756 .3117 L
.76 .31174 L
.764 .31176 L
.768 .31182 L
.772 .31196 L
.776 .31218 L
.78 .31244 L
.784 .31274 L
.788 .31307 L
.792 .31347 L
.796 .31394 L
.8 .31447 L
Mistroke
.804 .31504 L
.808 .31563 L
.812 .31623 L
.816 .31679 L
.82 .3173 L
.824 .31772 L
.828 .31808 L
.832 .31838 L
.836 .31866 L
.84 .3189 L
.844 .31909 L
.848 .3192 L
.852 .31922 L
.856 .31917 L
.86 .31909 L
.864 .31901 L
.868 .31894 L
.872 .31888 L
.876 .3188 L
.88 .31868 L
.884 .31854 L
.888 .31838 L
.892 .31825 L
.896 .31814 L
.9 .31807 L
.904 .31802 L
.908 .31798 L
.912 .31791 L
.916 .31782 L
.92 .31773 L
.924 .31766 L
.928 .31764 L
.932 .31765 L
.936 .31766 L
.94 .31766 L
.944 .31762 L
.948 .31757 L
.952 .31754 L
.956 .31753 L
.96 .31754 L
.964 .31757 L
.968 .31759 L
.972 .3176 L
.976 .31759 L
.98 .31755 L
.984 .31752 L
.988 .31751 L
.992 .31754 L
.996 .3176 L
1 .31762 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .58473 m
.008 .58012 L
.012 .57873 L
.016 .58039 L
.02 .58083 L
.024 .58016 L
.028 .58009 L
.032 .58032 L
.036 .58039 L
.04 .58027 L
.044 .58026 L
.048 .58026 L
.052 .58026 L
.056 .58023 L
.06 .58026 L
.064 .58027 L
.068 .5803 L
.072 .58029 L
.076 .58031 L
.08 .5803 L
.084 .5803 L
.088 .58028 L
.092 .58028 L
.096 .58027 L
.1 .58026 L
.104 .58022 L
.108 .58021 L
.112 .58022 L
.116 .58027 L
.12 .5803 L
.124 .58032 L
.128 .58034 L
.132 .58036 L
.136 .58035 L
.14 .5803 L
.144 .58023 L
.148 .58021 L
.152 .58022 L
.156 .58023 L
.16 .58022 L
.164 .58022 L
.168 .58025 L
.172 .5803 L
.176 .58032 L
.18 .58031 L
.184 .58029 L
.188 .5803 L
.192 .58034 L
.196 .58037 L
.2 .58034 L
Mistroke
.204 .58028 L
.208 .58024 L
.212 .58024 L
.216 .58023 L
.22 .58019 L
.224 .58011 L
.228 .58007 L
.232 .58013 L
.236 .58026 L
.24 .5804 L
.244 .58046 L
.248 .58045 L
.252 .58041 L
.256 .58042 L
.26 .58045 L
.264 .58042 L
.268 .58026 L
.272 .58004 L
.276 .5799 L
.28 .57996 L
.284 .58016 L
.288 .58033 L
.292 .58033 L
.296 .58019 L
.3 .58009 L
.304 .58018 L
.308 .58043 L
.312 .58063 L
.316 .58062 L
.32 .58041 L
.324 .58018 L
.328 .58014 L
.332 .58034 L
.336 .58059 L
.34 .58066 L
.344 .58044 L
.348 .58003 L
.352 .57967 L
.356 .57954 L
.36 .57969 L
.364 .58001 L
.368 .58034 L
.372 .58055 L
.376 .58058 L
.38 .58048 L
.384 .5803 L
.388 .58016 L
.392 .58016 L
.396 .58036 L
.4 .5807 L
Mistroke
.404 .58099 L
.408 .58105 L
.412 .58075 L
.416 .58017 L
.42 .57955 L
.424 .57922 L
.428 .57937 L
.432 .57997 L
.436 .58075 L
.44 .58136 L
.444 .58153 L
.448 .58118 L
.452 .58043 L
.456 .57953 L
.46 .57869 L
.464 .57808 L
.468 .57776 L
.472 .57777 L
.476 .57819 L
.48 .57907 L
.484 .58043 L
.488 .58215 L
.492 .58397 L
.496 .58553 L
.5 .58645 L
.504 .58649 L
.508 .58556 L
.512 .58376 L
.516 .58129 L
.52 .57834 L
.524 .57502 L
.528 .57134 L
.532 .56725 L
.536 .56269 L
.54 .55767 L
.544 .5523 L
.548 .54676 L
.552 .54126 L
.556 .53594 L
.56 .53084 L
.564 .52589 L
.568 .52091 L
.572 .5157 L
.576 .51009 L
.58 .50402 L
.584 .49755 L
.588 .49084 L
.592 .48412 L
.596 .47761 L
.6 .47148 L
Mistroke
.604 .4658 L
.608 .46056 L
.612 .45561 L
.616 .45076 L
.62 .44582 L
.624 .44058 L
.628 .43492 L
.632 .42879 L
.636 .42223 L
.64 .41533 L
.644 .40826 L
.648 .40119 L
.652 .39431 L
.656 .38778 L
.66 .38171 L
.664 .37617 L
.668 .37121 L
.672 .3668 L
.676 .36291 L
.68 .35945 L
.684 .35636 L
.688 .35355 L
.692 .35095 L
.696 .34848 L
.7 .34611 L
.704 .3438 L
.708 .34154 L
.712 .33931 L
.716 .33714 L
.72 .33502 L
.724 .33297 L
.728 .33099 L
.732 .3291 L
.736 .32729 L
.74 .32554 L
.744 .32386 L
.748 .32222 L
.752 .3206 L
.756 .31897 L
.76 .31731 L
.764 .31559 L
.768 .3138 L
.772 .31193 L
.776 .30996 L
.78 .3079 L
.784 .30574 L
.788 .30351 L
.792 .30121 L
.796 .29886 L
.8 .29649 L
Mistroke
.804 .29412 L
.808 .29178 L
.812 .28948 L
.816 .28725 L
.82 .2851 L
.824 .28306 L
.828 .28114 L
.832 .27934 L
.836 .27768 L
.84 .27615 L
.844 .27476 L
.848 .27351 L
.852 .27239 L
.856 .27139 L
.86 .27051 L
.864 .26973 L
.868 .26906 L
.872 .26848 L
.876 .26798 L
.88 .26755 L
.884 .26718 L
.888 .26687 L
.892 .26661 L
.896 .26639 L
.9 .2662 L
.904 .26605 L
.908 .26592 L
.912 .26581 L
.916 .26572 L
.92 .26564 L
.924 .26557 L
.928 .26551 L
.932 .26546 L
.936 .26542 L
.94 .26538 L
.944 .26534 L
.948 .26531 L
.952 .26528 L
.956 .26525 L
.96 .26522 L
.964 .2652 L
.968 .26517 L
.972 .26515 L
.976 .26513 L
.98 .26511 L
.984 .26508 L
.988 .26506 L
.992 .26503 L
.996 .26502 L
1 .26499 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42527 L
.012 .42981 L
.016 .43153 L
.02 .43002 L
.024 .42938 L
.028 .4297 L
.032 .42987 L
.036 .42964 L
.04 .42954 L
.044 .42954 L
.048 .4296 L
.052 .42957 L
.056 .42959 L
.06 .42957 L
.064 .42957 L
.068 .42951 L
.072 .42947 L
.076 .4294 L
.08 .42936 L
.084 .42928 L
.088 .42924 L
.092 .42919 L
.096 .42919 L
.1 .42918 L
.104 .42916 L
.108 .42913 L
.112 .42913 L
.116 .42911 L
.12 .42907 L
.124 .429 L
.128 .42896 L
.132 .42896 L
.136 .42895 L
.14 .4289 L
.144 .42884 L
.148 .42879 L
.152 .42877 L
.156 .42873 L
.16 .42866 L
.164 .42859 L
.168 .42857 L
.172 .4286 L
.176 .42861 L
.18 .42857 L
.184 .42854 L
.188 .42854 L
.192 .42858 L
.196 .42859 L
.2 .42851 L
Mistroke
.204 .42838 L
.208 .42827 L
.212 .42821 L
.216 .42817 L
.22 .42809 L
.224 .42799 L
.228 .42793 L
.232 .42799 L
.236 .42813 L
.24 .42826 L
.244 .42829 L
.248 .42821 L
.252 .42812 L
.256 .4281 L
.26 .42811 L
.264 .42806 L
.268 .42784 L
.272 .42754 L
.276 .42734 L
.28 .42737 L
.284 .42758 L
.288 .42775 L
.292 .42771 L
.296 .42751 L
.3 .42736 L
.304 .42744 L
.308 .42772 L
.312 .42795 L
.316 .42791 L
.32 .42761 L
.324 .42729 L
.328 .42721 L
.332 .42741 L
.336 .42769 L
.34 .42774 L
.344 .42744 L
.348 .42691 L
.352 .42643 L
.356 .42625 L
.36 .4264 L
.364 .42676 L
.368 .42713 L
.372 .42735 L
.376 .42737 L
.38 .42721 L
.384 .42695 L
.388 .42675 L
.392 .42672 L
.396 .42694 L
.4 .42733 L
Mistroke
.404 .42767 L
.408 .42771 L
.412 .4273 L
.416 .42653 L
.42 .42572 L
.424 .42528 L
.428 .42544 L
.432 .42617 L
.436 .42712 L
.44 .42785 L
.444 .42802 L
.448 .42754 L
.452 .42657 L
.456 .42541 L
.46 .42434 L
.464 .42355 L
.468 .42312 L
.472 .42311 L
.476 .4236 L
.48 .42467 L
.484 .42633 L
.488 .42844 L
.492 .43067 L
.496 .43257 L
.5 .43369 L
.504 .43371 L
.508 .43253 L
.512 .43026 L
.516 .42714 L
.52 .42342 L
.524 .41925 L
.528 .41463 L
.532 .40951 L
.536 .4038 L
.54 .39752 L
.544 .39081 L
.548 .38388 L
.552 .377 L
.556 .37034 L
.56 .36397 L
.564 .35778 L
.568 .35155 L
.572 .34503 L
.576 .33803 L
.58 .33046 L
.584 .32238 L
.588 .31401 L
.592 .30561 L
.596 .29748 L
.6 .28983 L
Mistroke
.604 .28276 L
.608 .27622 L
.612 .27005 L
.616 .26401 L
.62 .25783 L
.624 .2513 L
.628 .24424 L
.632 .23661 L
.636 .22843 L
.64 .21984 L
.644 .21103 L
.648 .20223 L
.652 .19366 L
.656 .18553 L
.66 .17797 L
.664 .17108 L
.668 .16491 L
.672 .15943 L
.676 .1546 L
.68 .15031 L
.684 .14648 L
.688 .14299 L
.692 .13975 L
.696 .1367 L
.7 .13376 L
.704 .1309 L
.708 .1281 L
.712 .12535 L
.716 .12266 L
.72 .12004 L
.724 .1175 L
.728 .11505 L
.732 .11271 L
.736 .11048 L
.74 .10833 L
.744 .10626 L
.748 .10424 L
.752 .10223 L
.756 .10022 L
.76 .09818 L
.764 .09606 L
.768 .09386 L
.772 .09155 L
.776 .08912 L
.78 .08657 L
.784 .08391 L
.788 .08115 L
.792 .07832 L
.796 .07542 L
.8 .07249 L
Mistroke
.804 .06957 L
.808 .06667 L
.812 .06384 L
.816 .06108 L
.82 .05844 L
.824 .05593 L
.828 .05356 L
.832 .05136 L
.836 .04932 L
.84 .04745 L
.844 .04575 L
.848 .04422 L
.852 .04285 L
.856 .04164 L
.86 .04057 L
.864 .03964 L
.868 .03884 L
.872 .03814 L
.876 .03755 L
.88 .03705 L
.884 .03663 L
.888 .03627 L
.892 .03598 L
.896 .03574 L
.9 .03555 L
.904 .03538 L
.908 .03526 L
.912 .03515 L
.916 .03507 L
.92 .03501 L
.924 .03496 L
.928 .03492 L
.932 .03489 L
.936 .03487 L
.94 .03486 L
.944 .03485 L
.948 .03484 L
.952 .03484 L
.956 .03484 L
.96 .03483 L
.964 .03484 L
.968 .03484 L
.972 .03485 L
.976 .03485 L
.98 .03486 L
.984 .03486 L
.988 .03487 L
.992 .03487 L
.996 .03488 L
1 .03488 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`800003Ool00000
00=oo`04001oogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006
Ool0029oo`03001oogoo02Aoo`03001oogoo008000=oo`8003ioo`008Woo2@0000Aoo`00001oo`/0
0003Ool0000000X00005Ool00000001oo`020002Ool200000goo001oo`0lOol0029oof<000aoo`00
8Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol0
00=oo`05001oogooOol00003Ool03@00Ool007oo001oo`00Ool007oo001oo`0000=oo`05001oogoo
Ool00002Ool01@00Oomoogoo00000Woo7P0037oo000ROol2000`Ool00`00Oomoo`0?Ool00`00Oomo
o`0XOol0029oo`03001oogoo02moo`03001oogoo00moo`03001oogoo02Qoo`008Woo0P00<7oo0P00
3goo00<007ooOol0:Goo000ROol2000bOol00`00Oomoo`0<Ool00`00Oomoo`0YOol000]oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo035oo`03001oogoo00]oo`03001oogoo02Yo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000bOol00`00Oomoo`0;
Ool00`00Oomoo`0ZOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
<Woo00@007ooOol000Yoo`03001oogoo02Yoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`0bOol40002Ool20005Ool00`00Oomoo`0ZOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00<goo0P000Woo00D007oo001oo`0000=oo`03
001oogoo02]oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2000gOol20002Ool0
1@00Oomoogoo0000;Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0jOol01000
Oomoo`00;Woo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2000lOol00`00Ool0000^
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8003aoo`03001oo`00
02ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0kOol2
000_Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0
029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool2
0003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029o
o`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04
001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P00
0goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P00
17oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06
001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo
0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00
Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo
00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009o
o`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:
Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomo
o`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo
00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00
Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomo
o`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00
Oomoo`00Ool000=oo`04001oogoo0002Ool01@00Oomoo`00Ool03P000goo00@007ooOol000Eoo`00
:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomo
o`D000=oo`8000=oo`<000Aoo`80009oo`@000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007oo
Ool0Agoo0`0077oo000XOol00`00Oomoo`16Ool2000NOol002Qooed000aoo`00:7oo00<007ooOol0
3goo00<007ooOol047oo00<007ooOol03goo00<007ooOol02Woo0`000Woo00<007ooOol047oo00<0
07ooOol02Woo000XOol00`00Oomoo`0oOol3000TOol002Qoo`03001oogoo03eoo`<002Ioo`00:7oo
00<007ooOol0?7oo0P00:7oo000XOol00`00Oomoo`0kOol00`00Oomoo`0XOol002Qoo`03001oogoo
03Yoo`03001oogoo02Uoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<0
07ooOol0>Goo00<007ooOol0:Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`000goo00@007ooOol003]oo`03001oogoo02Yoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOol003Yoo`03001oogoo02]oo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00>7oo0P00;Goo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`0gOol00`00Oomoo`0/
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0f
Ool2000^Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo03Eoo`8002moo`00:7oo
00<007ooOol0=7oo0P00<7oo000XOol00`00Oomoo`0dOol00`00Oomoo`0_Ool0015oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`03001oogoo03=oo`80035oo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0cOol00`00Oomoo`0`Ool0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0<Woo00<007ooOol0<Goo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80039oo`03001oogoo039oo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0`Ool2000dOol0011o
o`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0<7oo00<007ooOol0<goo000A
Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0_Ool00`00Oomoo`0dOol002Qoo`03001o
ogoo02ioo`03001oogoo03Eoo`00:7oo00<007ooOol0;Goo0P00=goo000XOola000hOol000]oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P00
0goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000
Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol005Yoo`h000ao
o`002Woo00@007ooOol000Moo`@000=oo`03001oogoo05Aoo`@001Yoo`002Woo00@007ooOol000Mo
o`03001oogoo00Aoo`8005=oo`<001eoo`002goo0P0027oo1@000Woo00<007ooOol0DGoo0P007goo
000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool2
0005Ool50003Ool30003Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogoo
Ool00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
1@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool200001Goo
001oogoo00000Woo00<007ooOol00goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007oo
Ool00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
17oo00@007ooOomoo`80009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol0
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol01Goo0`0000Eoo`00Oomoo`00009oo`04001oogoo0007Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol0
00Aoo`03001oo`000080009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool4
0003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo
0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`00
17oo0P000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02Ool01`00Oomoogoo001o
o`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Ao
o`8000Ioo`04001oogooOol50003Ool20004Ool50004Ool20004Ool20006Ool30002Ool50003Ool2
0006Ool001aoo`03001oogoo04Aoo`8002aoo`0077oo00<007ooOol0@goo0P00;Goo000LOomY000<
Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool00`00Oomoo`020004Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001o
ogoo045oo`03001oogoo02ioo`0077oo0P00@Woo00<007ooOol0;Woo000LOol00`00Oomoo`11Ool0
0`00Oomoo`0^Ool001aoo`03001oogoo041oo`03001oogoo02moo`0077oo0P00@7oo00<007ooOol0
<7oo000LOol00`00Oomoo`0oOol00`00Oomoo`0`Ool001aoo`03001oogoo03moo`03001oogoo031o
o`0077oo0P00?goo00<007ooOol0<Goo000LOol00`00Oomoo`0mOol2000cOol001aoo`8003ioo`03
001oogoo039oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0?7oo00<007ooOol0
<goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo03aoo`03001oogoo03=o
o`002Woo00@007ooOol000]oo`03001oogoo008003aoo`03001oogoo03Aoo`002Woo00@007ooOol0
00]oo`04001oogoo000lOol00`00Oomoo`0eOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomo
o`0jOol00`00Oomoo`0eOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2000kOol00`00Oomo
o`0eOol000]oo`8000Qoo`D0009oo`03001oogoo03Uoo`03001oogoo03Ioo`0077oo00<007ooOol0
>7oo0P00>7oo000LOol2000iOol00`00Oomoo`0gOol001aoo`03001oogoo03Moo`8003Uoo`0077oo
0P00>7oo00<007ooOol0>7oo000LOol00`00Oomoo`0fOol00`00Oomoo`0iOol001aoo`03001oogoo
03Eoo`03001oogoo03Yoo`0077oo0P00=Woo00<007ooOol0>Woo000FOol30003Ool00`00Oomoo`0d
Ool00`00Oomoo`0kOol001Moo`03001oogoo009oo`03001oogoo02eoo`<000=oo`03001oogoo03ao
o`005goo00<007ooOol00Woo<0000Woo1@00?Woo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol0
01Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001o
ogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo
079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol0
0P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo
00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(29225\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30198 m
.008 .30116 L
.012 .29787 L
.016 .29591 L
.02 .29664 L
.024 .29754 L
.028 .29869 L
.032 .3005 L
.036 .30141 L
.04 .30059 L
.044 .29831 L
.048 .29612 L
.052 .29532 L
.056 .29579 L
.06 .29754 L
.064 .29976 L
.068 .30118 L
.072 .30106 L
.076 .29942 L
.08 .2975 L
.084 .29642 L
.088 .29629 L
.092 .29709 L
.096 .2984 L
.1 .29961 L
.104 .29997 L
.108 .29913 L
.112 .29782 L
.116 .29706 L
.12 .29716 L
.124 .29773 L
.128 .29813 L
.132 .29841 L
.136 .2988 L
.14 .29896 L
.144 .29851 L
.148 .29775 L
.152 .29754 L
.156 .29803 L
.16 .29841 L
.164 .29808 L
.168 .2974 L
.172 .29727 L
.176 .29787 L
.18 .2985 L
.184 .29849 L
.188 .29806 L
.192 .29792 L
.196 .29819 L
.2 .29829 L
Mistroke
.204 .29782 L
.208 .29718 L
.212 .29713 L
.216 .2979 L
.22 .29886 L
.224 .2991 L
.228 .29835 L
.232 .29724 L
.236 .29666 L
.24 .29695 L
.244 .2976 L
.248 .29778 L
.252 .29727 L
.256 .29686 L
.26 .29755 L
.264 .29934 L
.268 .30083 L
.272 .30038 L
.276 .29788 L
.28 .2952 L
.284 .2945 L
.288 .29609 L
.292 .29808 L
.296 .29829 L
.3 .29676 L
.304 .29576 L
.308 .29735 L
.312 .30085 L
.316 .30303 L
.32 .30114 L
.324 .29586 L
.328 .29115 L
.332 .29085 L
.336 .29529 L
.34 .30095 L
.344 .30356 L
.348 .30164 L
.352 .29745 L
.356 .29465 L
.36 .29514 L
.364 .29769 L
.368 .2995 L
.372 .29879 L
.376 .29613 L
.38 .29362 L
.384 .29301 L
.388 .29456 L
.392 .29732 L
.396 .3002 L
.4 .30252 L
Mistroke
.404 .30375 L
.408 .3031 L
.412 .29983 L
.416 .29421 L
.42 .28834 L
.424 .28546 L
.428 .2881 L
.432 .29598 L
.436 .30559 L
.44 .31185 L
.444 .31112 L
.448 .30345 L
.452 .29268 L
.456 .28418 L
.46 .28182 L
.464 .28605 L
.468 .29409 L
.472 .30201 L
.476 .30699 L
.48 .30846 L
.484 .30766 L
.488 .30601 L
.492 .30386 L
.496 .30032 L
.5 .29426 L
.504 .28562 L
.508 .27622 L
.512 .26921 L
.516 .26778 L
.52 .27353 L
.524 .28564 L
.528 .30122 L
.532 .31654 L
.536 .32869 L
.54 .33671 L
.544 .34184 L
.548 .34666 L
.552 .35377 L
.556 .3644 L
.56 .3778 L
.564 .39156 L
.568 .40269 L
.572 .40886 L
.576 .40945 L
.58 .40564 L
.584 .39996 L
.588 .39528 L
.592 .39381 L
.596 .39647 L
.6 .40269 L
Mistroke
.604 .41072 L
.608 .41829 L
.612 .42328 L
.616 .42441 L
.62 .42157 L
.624 .41577 L
.628 .40885 L
.632 .40289 L
.636 .39968 L
.64 .40036 L
.644 .40525 L
.648 .41383 L
.652 .42495 L
.656 .43698 L
.66 .44817 L
.664 .45695 L
.668 .46219 L
.672 .46334 L
.676 .46038 L
.68 .45369 L
.684 .44392 L
.688 .43181 L
.692 .41818 L
.696 .40385 L
.7 .38957 L
.704 .37597 L
.708 .36347 L
.712 .35235 L
.716 .34275 L
.72 .33471 L
.724 .32818 L
.728 .32304 L
.732 .31911 L
.736 .31621 L
.74 .31416 L
.744 .31283 L
.748 .31211 L
.752 .31185 L
.756 .31188 L
.76 .31204 L
.764 .31223 L
.768 .31241 L
.772 .31258 L
.776 .31275 L
.78 .31293 L
.784 .31313 L
.788 .31331 L
.792 .31348 L
.796 .31363 L
.8 .31379 L
Mistroke
.804 .314 L
.808 .3143 L
.812 .31473 L
.816 .31525 L
.82 .3158 L
.824 .31634 L
.828 .31684 L
.832 .31732 L
.836 .31782 L
.84 .31833 L
.844 .31884 L
.848 .31929 L
.852 .31964 L
.856 .31987 L
.86 .32001 L
.864 .3201 L
.868 .32015 L
.872 .32019 L
.876 .32018 L
.88 .32012 L
.884 .31999 L
.888 .31981 L
.892 .3196 L
.896 .31941 L
.9 .31923 L
.904 .31908 L
.908 .31894 L
.912 .31878 L
.916 .3186 L
.92 .31842 L
.924 .31825 L
.928 .31814 L
.932 .31806 L
.936 .318 L
.94 .31794 L
.944 .31785 L
.948 .31776 L
.952 .31769 L
.956 .31765 L
.96 .31763 L
.964 .31763 L
.968 .31763 L
.972 .31761 L
.976 .31758 L
.98 .31754 L
.984 .31751 L
.988 .31751 L
.992 .31755 L
.996 .31758 L
1 .31759 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .58695 m
.008 .57992 L
.012 .57758 L
.016 .57972 L
.02 .58059 L
.024 .57986 L
.028 .57959 L
.032 .57978 L
.036 .57993 L
.04 .57985 L
.044 .57984 L
.048 .57985 L
.052 .57988 L
.056 .57985 L
.06 .57985 L
.064 .57983 L
.068 .57984 L
.072 .57981 L
.076 .57981 L
.08 .5798 L
.084 .57982 L
.088 .57982 L
.092 .57985 L
.096 .57987 L
.1 .5799 L
.104 .57989 L
.108 .57987 L
.112 .57984 L
.116 .57983 L
.12 .5798 L
.124 .57978 L
.128 .57977 L
.132 .5798 L
.136 .57983 L
.14 .57985 L
.144 .57985 L
.148 .57987 L
.152 .5799 L
.156 .57991 L
.16 .57988 L
.164 .57984 L
.168 .57981 L
.172 .57982 L
.176 .57981 L
.18 .57979 L
.184 .57977 L
.188 .57979 L
.192 .57983 L
.196 .57986 L
.2 .57984 L
Mistroke
.204 .57981 L
.208 .57982 L
.212 .57988 L
.216 .57993 L
.22 .57994 L
.224 .5799 L
.228 .57986 L
.232 .57985 L
.236 .57985 L
.24 .57981 L
.244 .57972 L
.248 .57963 L
.252 .57961 L
.256 .57969 L
.26 .57984 L
.264 .57994 L
.268 .57997 L
.272 .57994 L
.276 .57996 L
.28 .58004 L
.284 .5801 L
.288 .58003 L
.292 .57982 L
.296 .57958 L
.3 .57948 L
.304 .57959 L
.308 .57978 L
.312 .57988 L
.316 .5798 L
.32 .57964 L
.324 .5796 L
.328 .57977 L
.332 .58004 L
.336 .5802 L
.34 .58013 L
.344 .5799 L
.348 .57971 L
.352 .57975 L
.356 .57998 L
.36 .58021 L
.364 .58025 L
.368 .58003 L
.372 .57965 L
.376 .5793 L
.38 .57915 L
.384 .57924 L
.388 .57949 L
.392 .5798 L
.396 .58003 L
.4 .58012 L
Mistroke
.404 .58004 L
.408 .57985 L
.412 .57967 L
.416 .57964 L
.42 .57985 L
.424 .58024 L
.428 .58061 L
.432 .58072 L
.436 .58044 L
.44 .57984 L
.444 .57918 L
.448 .57878 L
.452 .57885 L
.456 .57938 L
.46 .58014 L
.464 .5808 L
.468 .58108 L
.472 .58089 L
.476 .58031 L
.48 .57952 L
.484 .57869 L
.488 .57797 L
.492 .57744 L
.496 .57719 L
.5 .57732 L
.504 .57794 L
.508 .57911 L
.512 .58075 L
.516 .58263 L
.52 .5844 L
.524 .58568 L
.528 .58618 L
.532 .58576 L
.536 .58448 L
.54 .58249 L
.544 .57996 L
.548 .57701 L
.552 .57367 L
.556 .56987 L
.56 .56558 L
.564 .56079 L
.568 .55558 L
.572 .55014 L
.576 .54467 L
.58 .53933 L
.584 .53422 L
.588 .52928 L
.592 .52438 L
.596 .51931 L
.6 .5139 L
Mistroke
.604 .50804 L
.608 .50174 L
.612 .49512 L
.616 .48838 L
.62 .48176 L
.624 .47545 L
.628 .46958 L
.632 .46414 L
.636 .45908 L
.64 .45421 L
.644 .44934 L
.648 .44426 L
.652 .43883 L
.656 .43296 L
.66 .42663 L
.664 .41991 L
.668 .41293 L
.672 .40585 L
.676 .39885 L
.68 .3921 L
.684 .38574 L
.688 .37987 L
.692 .37455 L
.696 .36979 L
.7 .36556 L
.704 .36182 L
.708 .35848 L
.712 .35547 L
.716 .35271 L
.72 .35013 L
.724 .34768 L
.728 .34531 L
.732 .34301 L
.736 .34075 L
.74 .33853 L
.744 .33637 L
.748 .33427 L
.752 .33224 L
.756 .3303 L
.76 .32844 L
.764 .32666 L
.768 .32494 L
.772 .32328 L
.776 .32165 L
.78 .32003 L
.784 .31839 L
.788 .31672 L
.792 .31498 L
.796 .31316 L
.8 .31126 L
Mistroke
.804 .30926 L
.808 .30717 L
.812 .30499 L
.816 .30273 L
.82 .30041 L
.824 .29806 L
.828 .29569 L
.832 .29333 L
.836 .291 L
.84 .28872 L
.844 .28651 L
.848 .2844 L
.852 .2824 L
.856 .28052 L
.86 .27876 L
.864 .27714 L
.868 .27566 L
.872 .27431 L
.876 .2731 L
.88 .27201 L
.884 .27105 L
.888 .2702 L
.892 .26946 L
.896 .26881 L
.9 .26825 L
.904 .26777 L
.908 .26736 L
.912 .26701 L
.916 .26672 L
.92 .26646 L
.924 .26626 L
.928 .26608 L
.932 .26593 L
.936 .2658 L
.94 .2657 L
.944 .26561 L
.948 .26554 L
.952 .26547 L
.956 .26542 L
.96 .26536 L
.964 .26532 L
.968 .26528 L
.972 .26525 L
.976 .26522 L
.98 .26519 L
.984 .26516 L
.988 .26514 L
.992 .2651 L
.996 .26509 L
1 .26505 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43273 L
.012 .42953 L
.016 .42875 L
.02 .42988 L
.024 .43017 L
.028 .42972 L
.032 .4297 L
.036 .42981 L
.04 .42981 L
.044 .42967 L
.048 .42963 L
.052 .42957 L
.056 .42953 L
.06 .42946 L
.064 .42943 L
.068 .42938 L
.072 .42938 L
.076 .42936 L
.08 .42939 L
.084 .42938 L
.088 .42937 L
.092 .42931 L
.096 .42926 L
.1 .4292 L
.104 .42914 L
.108 .42908 L
.112 .42907 L
.116 .42906 L
.12 .42905 L
.124 .429 L
.128 .42896 L
.132 .42892 L
.136 .4289 L
.14 .42885 L
.144 .42882 L
.148 .4288 L
.152 .42882 L
.156 .42882 L
.16 .42878 L
.164 .4287 L
.168 .42866 L
.172 .42863 L
.176 .42859 L
.18 .4285 L
.184 .42842 L
.188 .42839 L
.192 .42841 L
.196 .42842 L
.2 .42839 L
Mistroke
.204 .42835 L
.208 .42835 L
.212 .42838 L
.216 .42841 L
.22 .42836 L
.224 .42827 L
.228 .42817 L
.232 .42812 L
.236 .4281 L
.24 .42804 L
.244 .42791 L
.248 .42777 L
.252 .42771 L
.256 .42778 L
.26 .42791 L
.264 .42801 L
.268 .428 L
.272 .42794 L
.276 .42793 L
.28 .428 L
.284 .42805 L
.288 .42794 L
.292 .42765 L
.296 .42732 L
.3 .42716 L
.304 .42725 L
.308 .42746 L
.312 .42754 L
.316 .4274 L
.32 .42718 L
.324 .42711 L
.328 .4273 L
.332 .4276 L
.336 .42777 L
.34 .42764 L
.344 .42731 L
.348 .42705 L
.352 .42706 L
.356 .42732 L
.36 .42759 L
.364 .4276 L
.368 .42729 L
.372 .42678 L
.376 .42633 L
.38 .42611 L
.384 .42619 L
.388 .42647 L
.392 .42681 L
.396 .42706 L
.4 .42714 L
Mistroke
.404 .42702 L
.408 .42676 L
.412 .42651 L
.416 .42644 L
.42 .42666 L
.424 .4271 L
.428 .42753 L
.432 .42764 L
.436 .42727 L
.44 .42649 L
.444 .42563 L
.448 .4251 L
.452 .42516 L
.456 .42579 L
.46 .4267 L
.464 .42749 L
.468 .4278 L
.472 .42753 L
.476 .42678 L
.48 .42576 L
.484 .42471 L
.488 .42379 L
.492 .4231 L
.496 .42274 L
.5 .42286 L
.504 .4236 L
.508 .42503 L
.512 .42706 L
.516 .42938 L
.52 .43155 L
.524 .4331 L
.528 .43368 L
.532 .43313 L
.536 .4315 L
.54 .42898 L
.544 .4258 L
.548 .4221 L
.552 .4179 L
.556 .41315 L
.56 .40777 L
.564 .40176 L
.568 .39524 L
.572 .38843 L
.576 .38158 L
.58 .37492 L
.584 .36853 L
.588 .36236 L
.592 .35623 L
.596 .34989 L
.6 .34312 L
Mistroke
.604 .3358 L
.608 .32793 L
.612 .31967 L
.616 .31127 L
.62 .30301 L
.624 .29514 L
.628 .28781 L
.632 .28103 L
.636 .2747 L
.64 .26862 L
.644 .26255 L
.648 .25623 L
.652 .24946 L
.656 .24214 L
.66 .23426 L
.664 .22588 L
.668 .21718 L
.672 .20836 L
.676 .19965 L
.68 .19124 L
.684 .18333 L
.688 .17603 L
.692 .16941 L
.696 .16348 L
.7 .15823 L
.704 .15357 L
.708 .14943 L
.712 .14569 L
.716 .14228 L
.72 .13908 L
.724 .13605 L
.728 .13311 L
.732 .13025 L
.736 .12745 L
.74 .12471 L
.744 .12204 L
.748 .11944 L
.752 .11694 L
.756 .11454 L
.76 .11224 L
.764 .11003 L
.768 .10792 L
.772 .10587 L
.776 .10386 L
.78 .10187 L
.784 .09985 L
.788 .09778 L
.792 .09564 L
.796 .0934 L
.8 .09105 L
Mistroke
.804 .08859 L
.808 .086 L
.812 .08331 L
.816 .08053 L
.82 .07767 L
.824 .07476 L
.828 .07184 L
.832 .06892 L
.836 .06604 L
.84 .06323 L
.844 .06052 L
.848 .05792 L
.852 .05545 L
.856 .05313 L
.86 .05098 L
.864 .04899 L
.868 .04717 L
.872 .04553 L
.876 .04405 L
.88 .04273 L
.884 .04156 L
.888 .04053 L
.892 .03964 L
.896 .03887 L
.9 .03821 L
.904 .03764 L
.908 .03716 L
.912 .03676 L
.916 .03643 L
.92 .03615 L
.924 .03592 L
.928 .03573 L
.932 .03558 L
.936 .03546 L
.94 .03536 L
.944 .03528 L
.948 .03523 L
.952 .03518 L
.956 .03514 L
.96 .03511 L
.964 .0351 L
.968 .03508 L
.972 .03508 L
.976 .03507 L
.98 .03507 L
.984 .03506 L
.988 .03507 L
.992 .03507 L
.996 .03508 L
1 .03507 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000=oo`<000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`<000=o
o`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007oo
Ool09Woo0P000Woo00L007ooOomoo`00Ool0000kOol0029oo`L00003Ool0000001000003Ool00000
00800003Ool0000000D0009oo`800004Ool007oo0002Ool00`00Ool0000kOol0029oof<000aoo`00
8Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol0
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOomoo`80009oo`05001oogoo
Ool00002Ool01@00Oomoogoo00000goo3P000Woo00<007oo00002P0037oo000ROol2000bOol00`00
Oomoo`0@Ool00`00Oomoo`09Ool5000GOol0029oo`03001oogoo039oo`03001oogoo00ioo`03001o
ogoo02Ioo`008Woo0P00<goo0P003goo00<007ooOol09Woo000ROol2000dOol00`00Oomoo`0=Ool0
0`00Oomoo`0VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo03=oo`03
001oogoo00aoo`03001oogoo02Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2000eOol00`00Oomoo`0;Ool00`00Oomoo`0WOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P00=Goo00<007ooOol02Woo00<007ooOol0:7oo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo03Aoo`04001oo`000003Ool00`00
Oomoo`03Ool00`00Oomoo`0XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P00=Goo0`0000=oo`00Ool00`0017oo00<007ooOol0:7oo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000Aoo`8003Uoo`05001oo`00Ool00004Ool00`00Oomoo`0XOol000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`03001oogoo03Uoo`05001oogooOol00002Ool00`00Oomoo`0YOol0
00]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8003ioo`04001oogoo000[Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8003ioo`04001oogoo000[Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0?Woo0P00;7oo000:
Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol20010Ool00`00Oomoo`0ZOol000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol0
00Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00
KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000
Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo0080
06eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P00
2Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo
000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0
009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=o
o`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`80
00=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo
00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00
Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo
0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo
0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@0
07ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@0
00=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@0
07ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo
00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oo`0000X000=oo`04
001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`80
00Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool40002Ool30002Ool50003Ool20006
Ool002Qoo`03001oogoo04Yoo`8001Yoo`00:7oo00<007ooOol0B7oo0P0077oo000XOomM000<Ool0
02Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00eoo`<0019oo`03
001oogoo00Yoo`00:7oo00<007ooOol0@Woo0P008Woo000XOol00`00Oomoo`10Ool2000TOol002Qo
o`03001oogoo03ioo`8002Ioo`00:7oo00<007ooOol0?Goo0P009goo000XOol00`00Oomoo`0lOol2
000XOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo03aoo`03
001oogoo02Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04
001oogoo000mOol00`00Oomoo`0XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogoo000mOol00`00Oomoo`0XOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo008003]oo`03001oogoo02Uoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0>Goo00<007ooOol0:Woo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0>7oo0P00
;7oo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0hOol00`00Oomoo`0[Ool002Qo
o`03001oogoo03Moo`03001oogoo02aoo`00:7oo00<007ooOol0=Woo0P00;Woo000AOol20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0fOol00`00Oomoo`0]Ool0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0=Goo00<007ooOol0;Woo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo03Aoo`80031oo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000eOol00`00Oomoo`0_Ool0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0<goo00<007ooOol0
<7oo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo039oo`80039oo`00
4Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0<Goo0P00<goo000XOol00`00Oomoo`0a
Ool00`00Oomoo`0bOol002Qoo`03001oogoo031oo`03001oogoo03=oo`00:7oo<`00=Woo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@0
07ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001MOol;000<
Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1GOol5000FOol000Yoo`04001oogoo0007
Ool00`00Oomoo`04Ool2001FOol3000JOol000]oo`8000Qoo`D0009oo`03001oogoo05Aoo`8001ao
o`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo
0P001Goo1@000goo0P0000Aoo`00001oo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo
00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009o
o`03001oogoo00800005Ool007ooOol00005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool40002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00Eoo`03001oogoo00<00005Ool007ooOol00002Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007oo
Ool000Aoo`04001oogooOol40002Ool01000Oomoo`000Woo00<007ooOol00Woo00H007ooOomoo`00
Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`00
27oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomo
o`0017oo00<007ooOol00P000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001o
o`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Ao
o`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool2
0006Ool001aoo`03001oogoo04Moo`8002Uoo`0077oo00<007ooOol0AWoo0P00:Woo000LOomY000<
Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01`00Oomoogoo001oo`00009oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo
00<007ooOol0A7oo00<007ooOol0:goo000LOol20014Ool2000]Ool001aoo`03001oogoo04=oo`03
001oogoo02aoo`0077oo00<007ooOol0@goo00<007ooOol0;7oo000LOol20013Ool00`00Oomoo`0]
Ool001aoo`03001oogoo049oo`03001oogoo02eoo`0077oo00<007ooOol0@Goo00<007ooOol0;Woo
000LOol20012Ool00`00Oomoo`0^Ool001aoo`03001oogoo041oo`03001oogoo02moo`0077oo0P00
@7oo0P00<Goo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`0oOol00`00Oomoo`0`
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0?Woo0P00<Woo000:Ool0
1000Oomoo`002goo00<007ooOol00P00?goo00<007ooOol0<Goo000:Ool01000Oomoo`002goo00@0
07ooOol003moo`03001oogoo039oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo03eoo`03
001oogoo039oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8003eoo`03001oogoo03=oo`00
2goo0P0027oo1@000Woo00<007ooOol0?7oo00<007ooOol0<goo000LOol00`00Oomoo`0kOol00`00
Oomoo`0dOol001aoo`8003]oo`8003Ioo`0077oo00<007ooOol0>Woo00<007ooOol0=Goo000LOol2
000jOol2000gOol001aoo`03001oogoo03Uoo`03001oogoo03Ioo`0077oo00<007ooOol0>7oo00<0
07ooOol0=goo000LOol2000iOol00`00Oomoo`0gOol001Ioo`<000=oo`03001oogoo03Moo`03001o
ogoo03Qoo`005goo00<007ooOol00Woo00<007ooOol0<7oo0P0017oo00<007ooOol0>Goo000GOol0
0`00Oomoo`02Oolc0002Ool4000lOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<0
07ooOol00Woo00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001o
ogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo
0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;
Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol0
00]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<0
07ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo
00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(29392\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30153 m
.008 .30001 L
.012 .29907 L
.016 .29832 L
.02 .29846 L
.024 .29805 L
.028 .29701 L
.032 .29715 L
.036 .29823 L
.04 .29911 L
.044 .29951 L
.048 .29934 L
.052 .299 L
.056 .29853 L
.06 .298 L
.064 .29798 L
.068 .29822 L
.072 .29829 L
.076 .29813 L
.08 .29787 L
.084 .29796 L
.088 .29828 L
.092 .29857 L
.096 .29893 L
.1 .29916 L
.104 .299 L
.108 .29827 L
.112 .29727 L
.116 .29688 L
.12 .29741 L
.124 .29838 L
.128 .29908 L
.132 .29923 L
.136 .29911 L
.14 .29864 L
.144 .29763 L
.148 .2966 L
.152 .29647 L
.156 .29752 L
.16 .29889 L
.164 .29949 L
.168 .29917 L
.172 .29858 L
.176 .29821 L
.18 .29786 L
.184 .29725 L
.188 .2968 L
.192 .29712 L
.196 .2981 L
.2 .29884 L
Mistroke
.204 .29868 L
.208 .29796 L
.212 .29755 L
.216 .29784 L
.22 .29837 L
.224 .29836 L
.228 .29773 L
.232 .29712 L
.236 .29718 L
.24 .2979 L
.244 .29863 L
.248 .2987 L
.252 .2981 L
.256 .29747 L
.26 .29743 L
.264 .29782 L
.268 .29786 L
.272 .29699 L
.276 .29584 L
.28 .29586 L
.284 .29778 L
.288 .30046 L
.292 .30163 L
.296 .30001 L
.3 .29679 L
.304 .29471 L
.308 .2954 L
.312 .29768 L
.316 .29878 L
.32 .29728 L
.324 .29481 L
.328 .29454 L
.332 .29781 L
.336 .30235 L
.34 .3041 L
.344 .30094 L
.348 .29488 L
.352 .29054 L
.356 .29116 L
.36 .29599 L
.364 .30109 L
.368 .30278 L
.372 .30051 L
.376 .29689 L
.38 .29504 L
.384 .29603 L
.388 .2984 L
.392 .29976 L
.396 .2989 L
.4 .29646 L
Mistroke
.404 .29406 L
.408 .293 L
.412 .29359 L
.416 .29557 L
.42 .29854 L
.424 .30195 L
.428 .30468 L
.432 .30506 L
.436 .30176 L
.44 .29518 L
.444 .28798 L
.448 .28409 L
.452 .28635 L
.456 .2945 L
.46 .30479 L
.464 .31195 L
.468 .31212 L
.472 .30513 L
.476 .29456 L
.48 .28558 L
.484 .28213 L
.488 .28496 L
.492 .29183 L
.496 .29923 L
.5 .30455 L
.504 .30714 L
.508 .30792 L
.512 .30793 L
.516 .30718 L
.52 .30449 L
.524 .29852 L
.528 .28911 L
.532 .27807 L
.536 .26879 L
.54 .26482 L
.544 .26823 L
.548 .27866 L
.552 .29347 L
.556 .30896 L
.56 .322 L
.564 .33122 L
.568 .33741 L
.572 .34286 L
.576 .35014 L
.58 .36076 L
.584 .37442 L
.588 .38912 L
.592 .40194 L
.596 .41032 L
.6 .41304 L
Mistroke
.604 .41074 L
.608 .40555 L
.612 .40036 L
.616 .39773 L
.62 .39913 L
.624 .40453 L
.628 .41255 L
.632 .42096 L
.636 .42745 L
.64 .43029 L
.644 .42887 L
.648 .42379 L
.652 .41668 L
.656 .40963 L
.66 .40468 L
.664 .40333 L
.668 .40625 L
.672 .41327 L
.676 .42348 L
.68 .43544 L
.684 .44746 L
.688 .45791 L
.692 .46547 L
.696 .46925 L
.7 .46887 L
.704 .46438 L
.708 .45623 L
.712 .44511 L
.716 .4319 L
.72 .41753 L
.724 .40286 L
.728 .38858 L
.732 .37517 L
.736 .36295 L
.74 .35211 L
.744 .34278 L
.748 .33502 L
.752 .32881 L
.756 .32402 L
.76 .32042 L
.764 .31781 L
.768 .31597 L
.772 .31475 L
.776 .31401 L
.78 .31366 L
.784 .31358 L
.788 .31367 L
.792 .31385 L
.796 .31404 L
.8 .3142 L
Mistroke
.804 .31432 L
.808 .31444 L
.812 .31459 L
.816 .3148 L
.82 .31505 L
.824 .31534 L
.828 .31566 L
.832 .31602 L
.836 .31643 L
.84 .3169 L
.844 .31743 L
.848 .318 L
.852 .31857 L
.856 .31912 L
.86 .31964 L
.864 .32011 L
.868 .32053 L
.872 .32087 L
.876 .32114 L
.88 .32134 L
.884 .32147 L
.888 .32153 L
.892 .32152 L
.896 .32144 L
.9 .32129 L
.904 .3211 L
.908 .32088 L
.912 .32065 L
.916 .32041 L
.92 .32015 L
.924 .31989 L
.928 .31963 L
.932 .31938 L
.936 .31914 L
.94 .31892 L
.944 .31872 L
.948 .31855 L
.952 .3184 L
.956 .31827 L
.96 .31814 L
.964 .31802 L
.968 .31792 L
.972 .31783 L
.976 .31777 L
.98 .31773 L
.984 .3177 L
.988 .31767 L
.992 .31765 L
.996 .31762 L
1 .3176 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57626 m
.008 .5795 L
.012 .58055 L
.016 .57924 L
.02 .57904 L
.024 .57953 L
.028 .57962 L
.032 .57936 L
.036 .57935 L
.04 .57938 L
.044 .5794 L
.048 .57936 L
.052 .57938 L
.056 .57938 L
.06 .5794 L
.064 .5794 L
.068 .57943 L
.072 .57943 L
.076 .57945 L
.08 .57944 L
.084 .57943 L
.088 .57939 L
.092 .57936 L
.096 .57934 L
.1 .57935 L
.104 .57936 L
.108 .5794 L
.112 .57942 L
.116 .57946 L
.12 .57946 L
.124 .57945 L
.128 .57942 L
.132 .57941 L
.136 .5794 L
.14 .57939 L
.144 .57936 L
.148 .57935 L
.152 .57937 L
.156 .57939 L
.16 .57939 L
.164 .57939 L
.168 .5794 L
.172 .57944 L
.176 .57946 L
.18 .57944 L
.184 .57941 L
.188 .5794 L
.192 .57942 L
.196 .57942 L
.2 .57939 L
Mistroke
.204 .57935 L
.208 .57934 L
.212 .57936 L
.216 .57939 L
.22 .57938 L
.224 .57935 L
.228 .57936 L
.232 .5794 L
.236 .57947 L
.24 .5795 L
.244 .57949 L
.248 .57945 L
.252 .57944 L
.256 .57945 L
.26 .57945 L
.264 .57939 L
.268 .57927 L
.272 .57918 L
.276 .57918 L
.28 .57928 L
.284 .5794 L
.288 .57945 L
.292 .57944 L
.296 .57944 L
.3 .57953 L
.304 .57966 L
.308 .57973 L
.312 .57961 L
.316 .57936 L
.32 .57915 L
.324 .57911 L
.328 .57924 L
.332 .57939 L
.336 .5794 L
.34 .57925 L
.344 .57912 L
.348 .57915 L
.352 .57937 L
.356 .57964 L
.36 .57974 L
.364 .57962 L
.368 .57939 L
.372 .57926 L
.376 .57935 L
.38 .57959 L
.384 .57981 L
.388 .57984 L
.392 .57963 L
.396 .57928 L
.4 .57896 L
Mistroke
.404 .57877 L
.408 .57879 L
.412 .57898 L
.416 .57927 L
.42 .57953 L
.424 .57966 L
.428 .5796 L
.432 .5794 L
.436 .57918 L
.44 .57913 L
.444 .57934 L
.448 .57977 L
.452 .58019 L
.456 .58036 L
.46 .58012 L
.464 .57953 L
.468 .57884 L
.472 .57838 L
.476 .57837 L
.48 .57881 L
.484 .57951 L
.488 .58018 L
.492 .58056 L
.496 .58053 L
.5 .58014 L
.504 .57949 L
.508 .57872 L
.512 .57795 L
.516 .57726 L
.52 .57676 L
.524 .5766 L
.528 .57693 L
.532 .57786 L
.536 .57936 L
.54 .58123 L
.544 .58314 L
.548 .5847 L
.552 .58559 L
.556 .58565 L
.56 .58486 L
.564 .58336 L
.568 .58127 L
.572 .57873 L
.576 .57575 L
.58 .57229 L
.584 .5683 L
.588 .56376 L
.592 .55875 L
.596 .55344 L
.6 .54801 L
Mistroke
.604 .54268 L
.608 .53755 L
.612 .53262 L
.616 .52778 L
.62 .52283 L
.624 .5176 L
.628 .51195 L
.632 .50583 L
.636 .49935 L
.64 .49265 L
.644 .48598 L
.648 .47952 L
.652 .47345 L
.656 .46781 L
.66 .46258 L
.664 .45764 L
.668 .45279 L
.672 .44784 L
.676 .44262 L
.68 .43699 L
.684 .43091 L
.688 .4244 L
.692 .41756 L
.696 .41053 L
.7 .40347 L
.704 .39656 L
.708 .38996 L
.712 .38379 L
.716 .37812 L
.72 .37301 L
.724 .36843 L
.728 .36437 L
.732 .36076 L
.736 .35752 L
.74 .35458 L
.744 .35187 L
.748 .34932 L
.752 .34688 L
.756 .34451 L
.76 .34221 L
.764 .33995 L
.768 .33775 L
.772 .33561 L
.776 .33353 L
.78 .33154 L
.784 .32962 L
.788 .32779 L
.792 .32604 L
.796 .32435 L
.8 .3227 L
Mistroke
.804 .32108 L
.808 .31946 L
.812 .31782 L
.816 .31612 L
.82 .31436 L
.824 .31251 L
.828 .31058 L
.832 .30855 L
.836 .30643 L
.84 .30422 L
.844 .30195 L
.848 .29962 L
.852 .29726 L
.856 .29489 L
.86 .29254 L
.864 .29022 L
.868 .28797 L
.872 .28579 L
.876 .28372 L
.88 .28175 L
.884 .27991 L
.888 .2782 L
.892 .27662 L
.896 .27518 L
.9 .27387 L
.904 .2727 L
.908 .27165 L
.912 .27072 L
.916 .26991 L
.92 .26919 L
.924 .26857 L
.928 .26803 L
.932 .26757 L
.936 .26718 L
.94 .26685 L
.944 .26656 L
.948 .26632 L
.952 .26612 L
.956 .26595 L
.96 .26581 L
.964 .26569 L
.968 .26559 L
.972 .26551 L
.976 .26543 L
.98 .26537 L
.984 .26531 L
.988 .26527 L
.992 .26522 L
.996 .26518 L
1 .26514 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43525 L
.012 .43006 L
.016 .42825 L
.02 .4298 L
.024 .43043 L
.028 .4298 L
.032 .42954 L
.036 .4296 L
.04 .42967 L
.044 .42958 L
.048 .42957 L
.052 .42957 L
.056 .42961 L
.06 .42958 L
.064 .42957 L
.068 .4295 L
.072 .42945 L
.076 .42936 L
.08 .42932 L
.084 .42927 L
.088 .42926 L
.092 .42922 L
.096 .42923 L
.1 .42921 L
.104 .42919 L
.108 .42914 L
.112 .42911 L
.116 .42908 L
.12 .42906 L
.124 .42901 L
.128 .42897 L
.132 .42894 L
.136 .42893 L
.14 .42889 L
.144 .42883 L
.148 .42878 L
.152 .42876 L
.156 .42873 L
.16 .42868 L
.164 .42862 L
.168 .42861 L
.172 .42864 L
.176 .42866 L
.18 .42863 L
.184 .42858 L
.188 .42853 L
.192 .4285 L
.196 .42845 L
.2 .42836 L
Mistroke
.204 .42827 L
.208 .42823 L
.212 .42824 L
.216 .42825 L
.22 .42823 L
.224 .42817 L
.228 .42814 L
.232 .42815 L
.236 .42819 L
.24 .42819 L
.244 .42813 L
.248 .42806 L
.252 .42801 L
.256 .42801 L
.26 .42799 L
.264 .42788 L
.268 .4277 L
.272 .42755 L
.276 .42751 L
.28 .4276 L
.284 .42771 L
.288 .42774 L
.292 .42769 L
.296 .42767 L
.3 .42776 L
.304 .4279 L
.308 .42795 L
.312 .42778 L
.316 .42743 L
.32 .42711 L
.324 .42703 L
.328 .42717 L
.332 .42733 L
.336 .42731 L
.34 .4271 L
.344 .42689 L
.348 .4269 L
.352 .42715 L
.356 .42745 L
.36 .42755 L
.364 .42736 L
.368 .42704 L
.372 .42684 L
.376 .42691 L
.38 .42719 L
.384 .42744 L
.388 .42745 L
.392 .42716 L
.396 .42669 L
.4 .42624 L
Mistroke
.404 .42598 L
.408 .42597 L
.412 .42619 L
.416 .42651 L
.42 .42681 L
.424 .42693 L
.428 .42683 L
.432 .42654 L
.436 .42624 L
.44 .42615 L
.444 .42637 L
.448 .42687 L
.452 .42737 L
.456 .42755 L
.46 .42723 L
.464 .42647 L
.468 .42558 L
.472 .42496 L
.476 .4249 L
.48 .42542 L
.484 .42627 L
.488 .42708 L
.492 .42753 L
.496 .42746 L
.5 .42693 L
.504 .42608 L
.508 .42509 L
.512 .4241 L
.516 .42321 L
.52 .42256 L
.524 .42233 L
.528 .42271 L
.532 .42385 L
.536 .42569 L
.54 .42798 L
.544 .43032 L
.548 .43222 L
.552 .4333 L
.556 .43334 L
.56 .43234 L
.564 .43043 L
.568 .42781 L
.572 .4246 L
.576 .42085 L
.58 .4165 L
.584 .4115 L
.588 .40582 L
.592 .39955 L
.596 .3929 L
.6 .38612 L
Mistroke
.604 .37945 L
.608 .37303 L
.612 .36686 L
.616 .3608 L
.62 .35462 L
.624 .34808 L
.628 .34102 L
.632 .33339 L
.636 .32529 L
.64 .31694 L
.644 .3086 L
.648 .30054 L
.652 .29296 L
.656 .28593 L
.66 .27942 L
.664 .27325 L
.668 .2672 L
.672 .26103 L
.676 .25451 L
.68 .24749 L
.684 .23992 L
.688 .23181 L
.692 .22328 L
.696 .21452 L
.7 .20573 L
.704 .19713 L
.708 .18891 L
.712 .18123 L
.716 .17418 L
.72 .16781 L
.724 .16213 L
.728 .15709 L
.732 .1526 L
.736 .14858 L
.74 .14493 L
.744 .14157 L
.748 .1384 L
.752 .13538 L
.756 .13246 L
.76 .1296 L
.764 .12681 L
.768 .12408 L
.772 .12143 L
.776 .11886 L
.78 .1164 L
.784 .11403 L
.788 .11177 L
.792 .10961 L
.796 .10752 L
.8 .10549 L
Mistroke
.804 .1035 L
.808 .1015 L
.812 .09947 L
.816 .09738 L
.82 .09521 L
.824 .09294 L
.828 .09055 L
.832 .08804 L
.836 .08542 L
.84 .0827 L
.844 .07989 L
.848 .07702 L
.852 .0741 L
.856 .07118 L
.86 .06828 L
.864 .06542 L
.868 .06264 L
.872 .05996 L
.876 .0574 L
.88 .05499 L
.884 .05272 L
.888 .05062 L
.892 .04869 L
.896 .04692 L
.9 .04533 L
.904 .04389 L
.908 .04262 L
.912 .04149 L
.916 .04051 L
.92 .03965 L
.924 .03891 L
.928 .03828 L
.932 .03774 L
.936 .03728 L
.94 .0369 L
.944 .03658 L
.948 .03632 L
.952 .0361 L
.956 .03592 L
.96 .03578 L
.964 .03567 L
.968 .03557 L
.972 .0355 L
.976 .03544 L
.98 .03541 L
.984 .03537 L
.988 .03535 L
.992 .03533 L
.996 .03533 L
1 .03531 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`<0009oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`80009o
o`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007oo
Ool0:7oo0P000Woo0P000goo00<007oo0000>7oo000ROol500000goo00000002000017oo000007oo
0P0000=oo`0000003P0000Aoo`00001oo`D00005Ool007oo001oo`020002Ool200000goo001oo`0g
Ool0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00@007ooOol000=oo`05001oogooOol00003Ool01P00Oomoogoo001oo`<000=oo`03001o
ogoo008000=oo`04001oogoo0003Ool01@00Oomoogoo00000goo2`0000=oo`00Ool00Woo2@0037oo
000ROol2000eOol00`00Oomoo`0?Ool20009Ool8000COol0029oo`03001oogoo03Aoo`03001oogoo
00moo`03001oogoo02=oo`008Woo0P00=Woo00<007ooOol03Woo00<007ooOol08goo000ROol2000f
Ool00`00Oomoo`0=Ool00`00Oomoo`0TOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`03001oogoo03Ioo`03001oogoo00aoo`03001oogoo02Aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2000gOol00`00Oomoo`0;Ool00`00Oomoo`0UOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00=goo00<007ooOol02goo00<007ooOol0
9Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo03Ioo`03
001oogoo008000Uoo`03001oogoo02Eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2000hOol2000017oo001oogoo0P001Goo00<007ooOol09Goo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`8000Aoo`8003Uoo`08001oo`00001oo`00Ool000=oo`03001oogoo02Io
o`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0>goo0P000Woo00D007ooOomoo`00
02Qoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00@7oo00D007ooOomoo`0002Qo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00@Goo00@007ooOol0
02Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`10Ool0
0`00Ool0000YOol000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`80049oo`80
02Uoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool3
0003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<0
07ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo
000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000R
Ool2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000
Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009
Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<0
07ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo
0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo
0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00
Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0
009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool0
00Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo
00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
0goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomo
o`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool4
0003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000
Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomo
o`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00
Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol0
2P000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo
0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`800003Ool0000000@0
009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0C7oo0`005goo000XOol00`00Oomoo`1:Ool3000I
Ool002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007oo
Ool03goo0`0047oo00<007ooOol02Woo000XOol00`00Oomoo`14Ool3000OOol002Qoo`03001oogoo
049oo`<0025oo`00:7oo00<007ooOol0@Goo0P008goo000XOol00`00Oomoo`10Ool00`00Oomoo`0S
Ool002Qoo`03001oogoo03moo`03001oogoo02Aoo`002goo0P0017oo00<007ooOol00goo0P0017oo
0P000goo0`000goo00<007ooOol0?Woo00<007ooOol09Goo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`000goo00@007ooOol003moo`03001oogoo02Ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol003moo`03001oogoo02Ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00?Goo00<0
07ooOol09goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool0
0`00Oomoo`0lOol00`00Oomoo`0WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007oo
Ool007oo0006Ool00`00Oomoo`0kOol00`00Oomoo`0XOol000]oo`8000Yoo`8000Aoo`80009oo`D0
009oo`03001oogoo03Yoo`8002Yoo`00:7oo00<007ooOol0>Goo0P00:goo000XOol00`00Oomoo`0i
Ool00`00Oomoo`0ZOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo03Qo
o`03001oogoo02]oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`0hOol00`00Oomoo`0[Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0=goo00<007ooOol0;7oo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8003Moo`8002ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`0eOol2000_Ool0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
00<007ooOol0=7oo0P00<7oo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0dOol0
0`00Oomoo`0_Ool002Qoo`03001oogoo03=oo`03001oogoo031oo`00:7oo00<007ooOol0<Woo0P00
<Woo000XOole000dOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007oo
Ool006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02
001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomo
ogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02
Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`00
2goo00@007ooOol0061oo`P000aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo05Yoo`D0
01=oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8005Uoo`8001Qoo`002goo0P0027oo1@00
0Woo00<007ooOol0Egoo0P006Goo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004
Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006
Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=o
o`04001oogoo0002Ool01000Oomoo`000Woo0P0000=oo`00Ool017oo00H007ooOol007oo0003Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol010000Woo00<007ooOol017oo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007oo
Ool0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`06001oogooOol007oo0`0000Eoo`00Oomo
o`0000Moo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=o
o`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo
Ool40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`@0009oo`04001oogoo0004Ool01P00
Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04
001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Ao
o`04001oogoo0004Ool01P00Oomoogoo001oo`80009oo`04001oogoo0002Ool00`00Oomoo`02Ool0
1`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001o
ogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool50002Ool20004Ool20006Ool3
0002Ool50003Ool20006Ool001aoo`03001oogoo04Yoo`8002Ioo`0077oo00<007ooOol0BGoo0P00
9goo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol0
2Woo000LOol00`00Oomoo`17Ool00`00Oomoo`0XOol001aoo`8004Moo`03001oogoo02Uoo`0077oo
00<007ooOol0AWoo00<007ooOol0:Goo000LOol00`00Oomoo`16Ool00`00Oomoo`0YOol001aoo`80
04Ioo`03001oogoo02Yoo`0077oo00<007ooOol0AGoo00<007ooOol0:Woo000LOol00`00Oomoo`14
Ool00`00Oomoo`0[Ool001aoo`8004Aoo`03001oogoo02aoo`0077oo00<007ooOol0@goo00<007oo
Ool0;7oo000LOol20013Ool2000^Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo
045oo`8002moo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`11Ool00`00
Oomoo`0^Ool000Yoo`04001oogoo000;Ool00`00Oomoo`020012Ool00`00Oomoo`0^Ool000Yoo`04
001oogoo000;Ool01000Oomoo`00@Woo00<007ooOol0;goo000:Ool01000Oomoo`001goo10000goo
00<007ooOol0?goo0P00<Goo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00@7oo00<007oo
Ool0<7oo000;Ool20008Ool50002Ool00`00Oomoo`0oOol00`00Oomoo`0`Ool001aoo`03001oogoo
03ioo`03001oogoo035oo`0077oo0P00?Woo0P00<goo000LOol00`00Oomoo`0mOol00`00Oomoo`0b
Ool001aoo`8003eoo`03001oogoo03=oo`0077oo00<007ooOol0?7oo00<007ooOol0<goo000LOol0
0`00Oomoo`0kOol00`00Oomoo`0dOol001aoo`8003]oo`03001oogoo03Eoo`005Woo0`000goo00<0
07ooOol0>Woo00<007ooOol0=Goo000GOol00`00Oomoo`02Ool00`00Oomoo`0bOol30003Ool2000h
Ool001Moo`03001oogoo009oocH0009oo`@003Uoo`005goo00<007ooOol00Woo0P00Lgoo000GOol0
0`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol00Woo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2
001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02
Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=o
o`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool0
0`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(29559\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29497 m
.008 .29565 L
.012 .29895 L
.016 .30108 L
.02 .30083 L
.024 .30025 L
.028 .29914 L
.032 .2974 L
.036 .29641 L
.04 .29672 L
.044 .29808 L
.048 .29953 L
.052 .30013 L
.056 .29976 L
.06 .29853 L
.064 .29727 L
.068 .29694 L
.072 .29744 L
.076 .2985 L
.08 .29953 L
.084 .29992 L
.088 .2995 L
.092 .29831 L
.096 .2971 L
.1 .29672 L
.104 .29727 L
.108 .29831 L
.112 .29911 L
.116 .2994 L
.12 .29931 L
.124 .29873 L
.128 .29776 L
.132 .29698 L
.136 .29706 L
.14 .29793 L
.144 .29872 L
.148 .29891 L
.152 .29879 L
.156 .2987 L
.16 .29853 L
.164 .29795 L
.168 .29717 L
.172 .29692 L
.176 .29749 L
.18 .2983 L
.184 .2986 L
.188 .29843 L
.192 .29842 L
.196 .29873 L
.2 .2988 L
Mistroke
.204 .29816 L
.208 .29719 L
.212 .29674 L
.216 .29718 L
.22 .29798 L
.224 .29836 L
.228 .29821 L
.232 .29801 L
.236 .29817 L
.24 .29848 L
.244 .29839 L
.248 .29771 L
.252 .29692 L
.256 .29676 L
.26 .29751 L
.264 .29856 L
.268 .29899 L
.272 .29839 L
.276 .29739 L
.28 .29711 L
.284 .29787 L
.288 .29872 L
.292 .29831 L
.296 .29648 L
.3 .29483 L
.304 .2953 L
.308 .29808 L
.312 .30103 L
.316 .30156 L
.32 .29919 L
.324 .29614 L
.328 .29519 L
.332 .29684 L
.336 .29883 L
.34 .2985 L
.344 .29575 L
.348 .29339 L
.352 .29441 L
.356 .29886 L
.36 .30337 L
.364 .30405 L
.368 .3 L
.372 .29417 L
.376 .29088 L
.38 .29228 L
.384 .29674 L
.388 .30063 L
.392 .30135 L
.396 .29921 L
.4 .2966 L
Mistroke
.404 .29574 L
.408 .29695 L
.412 .29884 L
.416 .29973 L
.42 .29897 L
.424 .29705 L
.428 .29489 L
.432 .29324 L
.436 .29265 L
.44 .29367 L
.444 .29668 L
.448 .30122 L
.452 .30551 L
.456 .30695 L
.46 .30366 L
.464 .29616 L
.468 .28775 L
.472 .28293 L
.476 .28484 L
.48 .29314 L
.484 .3039 L
.488 .3117 L
.492 .31263 L
.496 .30642 L
.5 .29637 L
.504 .28735 L
.508 .28313 L
.512 .28462 L
.516 .29003 L
.52 .29641 L
.524 .30155 L
.528 .30488 L
.532 .30713 L
.536 .309 L
.54 .31007 L
.544 .30879 L
.548 .30346 L
.552 .29367 L
.556 .2812 L
.56 .26961 L
.564 .26289 L
.568 .26369 L
.572 .27215 L
.576 .28594 L
.58 .30136 L
.584 .31501 L
.588 .3251 L
.592 .33204 L
.596 .33793 L
.6 .34536 L
Mistroke
.604 .35611 L
.608 .37022 L
.612 .38594 L
.616 .40042 L
.62 .41086 L
.624 .41564 L
.628 .41493 L
.632 .41054 L
.636 .40528 L
.64 .40188 L
.644 .4022 L
.648 .40666 L
.652 .41426 L
.656 .42302 L
.66 .43062 L
.664 .43511 L
.668 .43544 L
.672 .43171 L
.676 .42511 L
.68 .41751 L
.684 .41103 L
.688 .40747 L
.692 .40803 L
.696 .41302 L
.7 .42193 L
.704 .43351 L
.708 .44612 L
.712 .45797 L
.716 .46752 L
.72 .47364 L
.724 .4757 L
.728 .47356 L
.732 .46746 L
.736 .45794 L
.74 .44575 L
.744 .43178 L
.748 .41691 L
.752 .40195 L
.756 .38756 L
.76 .37421 L
.764 .36222 L
.768 .35177 L
.772 .34292 L
.776 .33563 L
.78 .32978 L
.784 .32521 L
.788 .32177 L
.792 .31929 L
.796 .31761 L
.8 .31653 L
Mistroke
.804 .3159 L
.808 .31555 L
.812 .31539 L
.816 .31533 L
.82 .31537 L
.824 .31548 L
.828 .31563 L
.832 .31582 L
.836 .31602 L
.84 .31622 L
.844 .31644 L
.848 .31671 L
.852 .31705 L
.856 .3175 L
.86 .31802 L
.864 .31859 L
.868 .31917 L
.872 .31973 L
.876 .32028 L
.88 .32081 L
.884 .32135 L
.888 .32186 L
.892 .3223 L
.896 .32265 L
.9 .32287 L
.904 .32299 L
.908 .32302 L
.912 .323 L
.916 .32293 L
.92 .3228 L
.924 .3226 L
.928 .32232 L
.932 .322 L
.936 .32164 L
.94 .32128 L
.944 .32094 L
.948 .32062 L
.952 .32031 L
.956 .32 L
.96 .31968 L
.964 .31937 L
.968 .3191 L
.972 .31887 L
.976 .3187 L
.98 .31855 L
.984 .31841 L
.988 .31828 L
.992 .31816 L
.996 .31806 L
1 .31799 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57143 m
.008 .57893 L
.012 .58151 L
.016 .57902 L
.02 .57814 L
.024 .57886 L
.028 .5792 L
.032 .57893 L
.036 .57887 L
.04 .57896 L
.044 .57905 L
.048 .57903 L
.052 .57903 L
.056 .57899 L
.06 .57898 L
.064 .57893 L
.068 .57892 L
.072 .5789 L
.076 .57892 L
.08 .57894 L
.084 .57899 L
.088 .579 L
.092 .57902 L
.096 .57901 L
.1 .57901 L
.104 .57898 L
.108 .57896 L
.112 .57893 L
.116 .57893 L
.12 .57892 L
.124 .57893 L
.128 .57893 L
.132 .57897 L
.136 .579 L
.14 .57902 L
.144 .579 L
.148 .57899 L
.152 .57898 L
.156 .57898 L
.16 .57896 L
.164 .57894 L
.168 .57893 L
.172 .57895 L
.176 .57897 L
.18 .57895 L
.184 .57893 L
.188 .57893 L
.192 .57896 L
.196 .57899 L
.2 .57899 L
Mistroke
.204 .57899 L
.208 .57899 L
.212 .57901 L
.216 .57902 L
.22 .57899 L
.224 .57894 L
.228 .57891 L
.232 .57891 L
.236 .57894 L
.24 .57894 L
.244 .57892 L
.248 .5789 L
.252 .57892 L
.256 .57898 L
.26 .57904 L
.264 .57904 L
.268 .57902 L
.272 .579 L
.276 .57902 L
.28 .57906 L
.284 .57905 L
.288 .57896 L
.292 .57883 L
.296 .57875 L
.3 .57878 L
.304 .57887 L
.308 .57894 L
.312 .57893 L
.316 .5789 L
.32 .57895 L
.324 .57912 L
.328 .57929 L
.332 .57933 L
.336 .57917 L
.34 .57891 L
.344 .57874 L
.348 .57876 L
.352 .5789 L
.356 .57898 L
.36 .5789 L
.364 .57872 L
.368 .57862 L
.372 .57872 L
.376 .57898 L
.38 .57922 L
.384 .57926 L
.388 .57911 L
.392 .5789 L
.396 .57881 L
.4 .57892 L
Mistroke
.404 .57917 L
.408 .57939 L
.412 .57943 L
.416 .57926 L
.42 .57894 L
.424 .57862 L
.428 .57839 L
.432 .57834 L
.436 .57848 L
.44 .57875 L
.444 .57904 L
.448 .57921 L
.452 .57916 L
.456 .57894 L
.46 .57869 L
.464 .57861 L
.468 .57882 L
.472 .57927 L
.476 .57975 L
.48 .57998 L
.484 .5798 L
.488 .57924 L
.492 .57854 L
.496 .57802 L
.5 .57791 L
.504 .57825 L
.508 .57887 L
.512 .57954 L
.516 .57999 L
.52 .58012 L
.524 .5799 L
.528 .57941 L
.532 .57874 L
.536 .57797 L
.54 .57717 L
.544 .57647 L
.548 .57604 L
.552 .57608 L
.556 .57674 L
.56 .57803 L
.564 .57981 L
.568 .58176 L
.572 .58352 L
.576 .58475 L
.58 .58524 L
.584 .58493 L
.588 .58391 L
.592 .58228 L
.596 .58016 L
.6 .57756 L
Mistroke
.604 .57447 L
.608 .57081 L
.612 .56657 L
.616 .5618 L
.62 .55665 L
.624 .55131 L
.628 .546 L
.632 .54085 L
.636 .53591 L
.64 .5311 L
.644 .52626 L
.648 .5212 L
.652 .51575 L
.656 .50985 L
.66 .50353 L
.664 .49692 L
.668 .49022 L
.672 .48365 L
.676 .4774 L
.68 .47156 L
.684 .46616 L
.688 .46109 L
.692 .45622 L
.696 .45134 L
.7 .44628 L
.704 .44088 L
.708 .43505 L
.712 .42878 L
.716 .42212 L
.72 .41519 L
.724 .40813 L
.728 .40113 L
.732 .39433 L
.736 .38789 L
.74 .38191 L
.744 .37645 L
.748 .37153 L
.752 .36714 L
.756 .36322 L
.76 .35973 L
.764 .35658 L
.768 .35371 L
.772 .35103 L
.776 .3485 L
.78 .34607 L
.784 .34371 L
.788 .34141 L
.792 .33916 L
.796 .33698 L
.8 .33485 L
Mistroke
.804 .33281 L
.808 .33084 L
.812 .32896 L
.816 .32716 L
.82 .32543 L
.824 .32376 L
.828 .32213 L
.832 .32052 L
.836 .31889 L
.84 .31723 L
.844 .31552 L
.848 .31373 L
.852 .31186 L
.856 .30989 L
.86 .30783 L
.864 .30568 L
.868 .30345 L
.872 .30116 L
.876 .29882 L
.88 .29646 L
.884 .29409 L
.888 .29175 L
.892 .28946 L
.896 .28723 L
.9 .28509 L
.904 .28304 L
.908 .28112 L
.912 .27932 L
.916 .27765 L
.92 .27611 L
.924 .27471 L
.928 .27345 L
.932 .27231 L
.936 .2713 L
.94 .2704 L
.944 .26961 L
.948 .26893 L
.952 .26833 L
.956 .26782 L
.96 .26737 L
.964 .267 L
.968 .26667 L
.972 .2664 L
.976 .26616 L
.98 .26597 L
.984 .2658 L
.988 .26566 L
.992 .26553 L
.996 .26542 L
1 .26531 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42809 L
.012 .43011 L
.016 .43057 L
.02 .4296 L
.024 .42952 L
.028 .42981 L
.032 .42987 L
.036 .42971 L
.04 .42972 L
.044 .42971 L
.048 .42968 L
.052 .42956 L
.056 .42951 L
.06 .42944 L
.064 .42944 L
.068 .42942 L
.072 .42943 L
.076 .4294 L
.08 .42939 L
.084 .42935 L
.088 .42932 L
.092 .42926 L
.096 .42924 L
.1 .42921 L
.104 .42918 L
.108 .42913 L
.112 .42909 L
.116 .42905 L
.12 .42902 L
.124 .42898 L
.128 .42895 L
.132 .42892 L
.136 .42892 L
.14 .42889 L
.144 .42886 L
.148 .42882 L
.152 .42881 L
.156 .42879 L
.16 .42875 L
.164 .42868 L
.168 .42863 L
.172 .42859 L
.176 .42856 L
.18 .4285 L
.184 .42845 L
.188 .42844 L
.192 .42846 L
.196 .42848 L
.2 .42846 L
Mistroke
.204 .42841 L
.208 .42837 L
.212 .42835 L
.216 .42832 L
.22 .42825 L
.224 .42815 L
.228 .42809 L
.232 .42808 L
.236 .42808 L
.24 .42806 L
.244 .42799 L
.248 .42794 L
.252 .42793 L
.256 .42797 L
.26 .428 L
.264 .42797 L
.268 .4279 L
.272 .42786 L
.276 .42787 L
.28 .42789 L
.284 .42785 L
.288 .42769 L
.292 .42749 L
.296 .42735 L
.3 .42735 L
.304 .42744 L
.308 .4275 L
.312 .42746 L
.316 .42739 L
.32 .42743 L
.324 .4276 L
.328 .42779 L
.332 .4278 L
.336 .42757 L
.34 .42721 L
.344 .42696 L
.348 .42695 L
.352 .42709 L
.356 .42717 L
.36 .42705 L
.364 .4268 L
.368 .42664 L
.372 .42672 L
.376 .427 L
.38 .42726 L
.384 .42729 L
.388 .42708 L
.392 .42679 L
.396 .42665 L
.4 .42676 L
Mistroke
.404 .42703 L
.408 .42726 L
.412 .42728 L
.416 .42704 L
.42 .42661 L
.424 .42617 L
.428 .42586 L
.432 .42577 L
.436 .42592 L
.44 .42624 L
.444 .42656 L
.448 .42672 L
.452 .42663 L
.456 .42632 L
.46 .42598 L
.464 .42585 L
.468 .42609 L
.472 .42662 L
.476 .42718 L
.48 .42743 L
.484 .42717 L
.488 .42644 L
.492 .42554 L
.496 .42486 L
.5 .42469 L
.504 .42509 L
.508 .42584 L
.512 .42663 L
.516 .42717 L
.52 .42728 L
.524 .42698 L
.528 .42634 L
.532 .42548 L
.536 .42449 L
.54 .42347 L
.544 .42256 L
.548 .42199 L
.552 .422 L
.556 .42279 L
.56 .42437 L
.564 .42656 L
.568 .42896 L
.572 .43112 L
.576 .43262 L
.58 .43319 L
.584 .43278 L
.588 .43147 L
.592 .4294 L
.596 .42672 L
.6 .42346 L
Mistroke
.604 .41958 L
.608 .415 L
.612 .40968 L
.616 .40371 L
.62 .39725 L
.624 .39057 L
.628 .38393 L
.632 .37749 L
.636 .37132 L
.64 .3653 L
.644 .35925 L
.648 .35292 L
.652 .34611 L
.656 .33874 L
.66 .33084 L
.664 .32259 L
.668 .31423 L
.672 .30604 L
.676 .29823 L
.68 .29095 L
.684 .2842 L
.688 .27788 L
.692 .2718 L
.696 .26573 L
.7 .25941 L
.704 .25268 L
.708 .24541 L
.712 .23759 L
.716 .22929 L
.72 .22065 L
.724 .21187 L
.728 .20315 L
.732 .19469 L
.736 .18667 L
.74 .17923 L
.744 .17243 L
.748 .16631 L
.752 .16085 L
.756 .15599 L
.76 .15166 L
.764 .14775 L
.768 .14418 L
.772 .14086 L
.776 .13772 L
.78 .13471 L
.784 .13179 L
.788 .12894 L
.792 .12616 L
.796 .12346 L
.8 .12083 L
Mistroke
.804 .1183 L
.808 .11587 L
.812 .11354 L
.816 .11132 L
.82 .10919 L
.824 .10713 L
.828 .10512 L
.832 .10313 L
.836 .10113 L
.84 .09908 L
.844 .09697 L
.848 .09477 L
.852 .09246 L
.856 .09003 L
.86 .08749 L
.864 .08483 L
.868 .08208 L
.872 .07925 L
.876 .07636 L
.88 .07345 L
.884 .07053 L
.888 .06764 L
.892 .06481 L
.896 .06206 L
.9 .05942 L
.904 .05691 L
.908 .05454 L
.912 .05232 L
.916 .05028 L
.92 .04839 L
.924 .04668 L
.928 .04514 L
.932 .04376 L
.936 .04252 L
.94 .04144 L
.944 .0405 L
.948 .03968 L
.952 .03897 L
.956 .03836 L
.96 .03785 L
.964 .03742 L
.968 .03705 L
.972 .03676 L
.976 .0365 L
.98 .03631 L
.984 .03615 L
.988 .03603 L
.992 .03593 L
.996 .03587 L
1 .03581 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`80009oo`8000Ioo`04001oogoo0002Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`03001oogoo00H0
00=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol0
:goo0P0000=oo`0000000goo00<007oo0000=Woo000ROol2000017oo000007oo6@0000Eoo`000000
07oo00P00005Ool007oo001oo`030002Ool00`00Ool0000fOol0029oof<000aoo`008Woo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo0P000Woo00T007oo001oo`00Ool007oo00000Woo00D0
07ooOomoo`0000=oo`05001oogooOol00002Ool:0003Ool01000Oomoogoo1@0037oo000ROol2000g
Ool00`00Oomoo`0AOol00`00Oomoo`05Ool:000@Ool0029oo`03001oogoo03Moo`03001oogoo00mo
o`03001oogoo021oo`008Woo0P00>Goo00<007ooOol03Goo00<007ooOol08Goo000ROol2000iOol0
0`00Oomoo`0=Ool00`00Oomoo`0QOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03
001oogoo03Qoo`03001oogoo00eoo`03001oogoo025oo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool2000iOol00`00Oomoo`0<Ool00`00Oomoo`0ROol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00>Woo00<007ooOol02goo00<007ooOol08Woo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo03Uoo`03001o
ogoo00]oo`03001oogoo029oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool2000kOol30003Ool20004Ool00`00Oomoo`0SOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo0P0017oo0P00>goo00P007ooOol007oo001oo`0017oo00<007ooOol08goo000;Ool2000:Ool2
0004Ool00`00Oomoo`02Ool00`00Oomoo`0mOol01@00Ool007oo000017oo00<007ooOol08goo000;
Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2000oOol01@00Oomoogoo00000goo00<007oo
Ool08goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool20013Ool01000
Oomoo`009Woo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
04=oo`03001oo`0002Ioo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00
A7oo0P009goo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`020014Ool2
000WOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`80
00Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03
Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001o
ogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04
001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00
Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yo
o`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;
Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool50002
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool2
0007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool5
0002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo
00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06
001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001o
ogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001o
ogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03
001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomo
o`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo
00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009o
o`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`000Woo1`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P00
27oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Ao
o`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0Cgoo0P005Goo000XOol00`00Oomo
o`1=Ool2000GOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol0
3goo00<007ooOol03goo00<007oo00000`003Goo00<007ooOol02Woo000XOol00`00Oomoo`16Ool3
000MOol002Qoo`03001oogoo04Aoo`<001moo`00:7oo00<007ooOol0@goo0P008Goo000XOol00`00
Oomoo`12Ool2000ROol002Qoo`03001oogoo045oo`8002=oo`002goo0P0017oo00<007ooOol00goo
0P0017oo0P000goo0`000goo00<007ooOol0@7oo0P0097oo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`000goo00@007ooOol0049oo`03001oogoo02=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0045oo`8002Eoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00@7oo00<007ooOol0
97oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomo
o`0nOol00`00Oomoo`0UOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0006Ool00`00Oomoo`0mOol2000WOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo
03eoo`03001oogoo02Ioo`00:7oo00<007ooOol0?7oo00<007ooOol09goo000XOol00`00Oomoo`0k
Ool00`00Oomoo`0XOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo03]o
o`03001oogoo02Qoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`0jOol00`00Oomoo`0YOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0>Goo00<007ooOol0:Woo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8003Yoo`03001oogoo02Yoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`0hOol00`00Oomoo`0[Ool0011oo`04001oogoo0008Ool01000Oomo
o`000Woo0P0017oo00<007ooOol0=goo00<007ooOol0;7oo000AOol2000:Ool20004Ool00`00Oomo
o`02Ool00`00Oomoo`0fOol2000^Ool002Qoo`03001oogoo03Eoo`8002moo`00:7oo00<007ooOol0
=7oo0P00<7oo000XOolh000aOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=o
o`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo
00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00
Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007oo
Ool0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool0
1000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00
Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000
Oomoo`002goo00@007ooOol006=oo`D000aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo
05eoo`@0015oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8005aoo`8001Eoo`002goo0P00
27oo1@000Woo00<007ooOol0FGoo0P005goo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004
Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool200000goo00000002Ool5
0002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0
009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00P0017oo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000
Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009o
o`@000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011o
o`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@0
07oo0000009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool0
01aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`03001oogoo
00800005Ool007ooOol00004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03
001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo10000Woo
00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@00
0goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000=o
o`<000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0CGoo0P008goo000LOol0
0`00Oomoo`1<Ool2000TOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0004Ool00`00Ool000020003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo
009oo`03001oogoo00Yoo`0077oo00<007ooOol0BWoo00<007ooOol09Goo000LOol2001:Ool00`00
Oomoo`0VOol001aoo`03001oogoo04Uoo`03001oogoo02Ioo`0077oo00<007ooOol0B7oo00<007oo
Ool09goo000LOol20019Ool00`00Oomoo`0WOol001aoo`03001oogoo04Moo`03001oogoo02Qoo`00
77oo00<007ooOol0Agoo00<007ooOol0:7oo000LOol20017Ool00`00Oomoo`0YOol001aoo`03001o
ogoo04Ioo`03001oogoo02Uoo`0077oo0P00AWoo00<007ooOol0:Woo000;Ool20004Ool00`00Oomo
o`02Ool30003Ool00`00Oomoo`14Ool2000/Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0A7oo00<007ooOol0:goo000:Ool01000Oomoo`002goo00<007ooOol00P00A7oo
00<007ooOol0;7oo000:Ool01000Oomoo`002goo00@007ooOol004Eoo`03001oogoo02aoo`002Woo
00@007ooOol000Moo`@000=oo`03001oogoo049oo`03001oogoo02eoo`002Woo00@007ooOol000Mo
o`03001oogoo00Aoo`8004=oo`03001oogoo02eoo`002goo0P0027oo1@000Woo00<007ooOol0@Goo
00<007ooOol0;Woo000LOol00`00Oomoo`11Ool00`00Oomoo`0^Ool001aoo`80045oo`03001oogoo
02moo`0077oo00<007ooOol0?goo0P00<Goo000LOol20010Ool00`00Oomoo`0`Ool001aoo`03001o
ogoo03ioo`80039oo`0077oo00<007ooOol0?Woo00<007ooOol0<Goo000LOol2000nOol00`00Oomo
o`0bOol001Ioo`<000=oo`03001oogoo03aoo`03001oogoo03=oo`005goo00<007ooOol00Woo00<0
07ooOol0=Goo0`000goo0P00=Goo000GOol00`00Oomoo`02Oolh0003Ool4000fOol001Moo`03001o
ogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000FOol20004Ool2
001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo
079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool0
0`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079o
o`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2
001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(29726\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29619 m
.008 .29753 L
.012 .29844 L
.016 .29884 L
.02 .29811 L
.024 .29812 L
.028 .29907 L
.032 .29916 L
.036 .29868 L
.04 .29842 L
.044 .2984 L
.048 .29862 L
.052 .29871 L
.056 .2986 L
.06 .2984 L
.064 .2981 L
.068 .2981 L
.072 .29839 L
.076 .29868 L
.08 .2989 L
.084 .29886 L
.088 .29853 L
.092 .29805 L
.096 .29757 L
.1 .29761 L
.104 .29826 L
.108 .29899 L
.112 .2993 L
.116 .299 L
.12 .29847 L
.124 .29794 L
.128 .29739 L
.132 .29718 L
.136 .2977 L
.14 .29872 L
.144 .29941 L
.148 .29916 L
.152 .29834 L
.156 .29769 L
.16 .29747 L
.164 .2975 L
.168 .29766 L
.172 .29817 L
.176 .299 L
.18 .29948 L
.184 .29896 L
.188 .29772 L
.192 .29682 L
.196 .29689 L
.2 .29755 L
Mistroke
.204 .29807 L
.208 .29828 L
.212 .29851 L
.216 .29889 L
.22 .29899 L
.224 .29839 L
.228 .29743 L
.232 .29689 L
.236 .29721 L
.24 .29793 L
.244 .29829 L
.248 .298 L
.252 .29755 L
.256 .2976 L
.26 .29823 L
.264 .29882 L
.268 .29863 L
.272 .29765 L
.276 .29668 L
.28 .29663 L
.284 .2976 L
.288 .29866 L
.292 .29876 L
.296 .29788 L
.3 .29711 L
.304 .29749 L
.308 .29872 L
.312 .29924 L
.316 .29791 L
.32 .29553 L
.324 .29433 L
.328 .29581 L
.332 .29898 L
.336 .3011 L
.34 .30034 L
.344 .29763 L
.348 .29579 L
.352 .2966 L
.356 .29893 L
.36 .29979 L
.364 .29753 L
.368 .29377 L
.372 .29213 L
.376 .29477 L
.38 .30018 L
.384 .30423 L
.388 .30368 L
.392 .29894 L
.396 .29361 L
.4 .29145 L
Mistroke
.404 .29341 L
.408 .29734 L
.412 .30007 L
.416 .30006 L
.42 .29816 L
.424 .29644 L
.428 .29625 L
.432 .29745 L
.436 .29889 L
.44 .29958 L
.444 .29922 L
.448 .29797 L
.452 .29605 L
.456 .29375 L
.46 .29186 L
.464 .29177 L
.468 .29462 L
.472 .30011 L
.476 .30591 L
.48 .30857 L
.484 .30564 L
.488 .29759 L
.492 .28808 L
.496 .28216 L
.5 .28334 L
.504 .29141 L
.508 .30245 L
.512 .31096 L
.516 .31292 L
.52 .3078 L
.524 .29853 L
.528 .28959 L
.532 .28457 L
.536 .28459 L
.54 .28834 L
.544 .29349 L
.548 .29825 L
.552 .30219 L
.556 .30581 L
.56 .30946 L
.564 .31234 L
.568 .31259 L
.572 .30822 L
.576 .29862 L
.58 .28536 L
.584 .272 L
.588 .26275 L
.592 .26071 L
.596 .26662 L
.6 .27865 L
Mistroke
.604 .29336 L
.608 .30725 L
.612 .31817 L
.616 .32604 L
.62 .33255 L
.624 .34016 L
.628 .35083 L
.632 .36501 L
.636 .38139 L
.64 .39734 L
.644 .40997 L
.648 .4172 L
.652 .41861 L
.656 .41548 L
.66 .41038 L
.664 .40619 L
.668 .40522 L
.672 .40848 L
.676 .41548 L
.68 .42453 L
.684 .43326 L
.688 .43945 L
.692 .44158 L
.696 .43932 L
.7 .43345 L
.704 .42569 L
.708 .41813 L
.712 .4128 L
.716 .41118 L
.72 .41398 L
.724 .42106 L
.728 .43154 L
.732 .44397 L
.736 .45667 L
.74 .46798 L
.744 .47648 L
.748 .48119 L
.752 .48162 L
.756 .47776 L
.76 .47 L
.764 .45906 L
.768 .44581 L
.772 .43118 L
.776 .416 L
.78 .40095 L
.784 .38661 L
.788 .37341 L
.792 .36166 L
.796 .35153 L
.8 .34308 L
Mistroke
.804 .33621 L
.808 .33075 L
.812 .3265 L
.816 .32329 L
.82 .32094 L
.824 .31931 L
.828 .31826 L
.832 .31762 L
.836 .31727 L
.84 .31708 L
.844 .31698 L
.848 .31695 L
.852 .31699 L
.856 .31709 L
.86 .31727 L
.864 .31751 L
.868 .31779 L
.872 .31812 L
.876 .31849 L
.88 .31894 L
.884 .31947 L
.888 .32008 L
.892 .32072 L
.896 .32137 L
.9 .322 L
.904 .32259 L
.908 .32314 L
.912 .32364 L
.916 .32406 L
.92 .3244 L
.924 .32463 L
.928 .32475 L
.932 .32477 L
.936 .32469 L
.94 .32454 L
.944 .32431 L
.948 .32402 L
.952 .32369 L
.956 .3233 L
.96 .32289 L
.964 .32246 L
.968 .32203 L
.972 .32163 L
.976 .32126 L
.98 .32091 L
.984 .32057 L
.988 .32027 L
.992 .32 L
.996 .31979 L
1 .31964 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .58022 m
.008 .5783 L
.012 .57784 L
.016 .57868 L
.02 .57884 L
.024 .57846 L
.028 .5785 L
.032 .57863 L
.036 .57862 L
.04 .57849 L
.044 .57848 L
.048 .57845 L
.052 .57847 L
.056 .57848 L
.06 .57854 L
.064 .57858 L
.068 .57861 L
.072 .5786 L
.076 .57859 L
.08 .57854 L
.084 .57852 L
.088 .57848 L
.092 .57848 L
.096 .57848 L
.1 .57851 L
.104 .57853 L
.108 .57855 L
.112 .57856 L
.116 .57858 L
.12 .57858 L
.124 .57857 L
.128 .57854 L
.132 .57852 L
.136 .57851 L
.14 .5785 L
.144 .57849 L
.148 .5785 L
.152 .57852 L
.156 .57855 L
.16 .57856 L
.164 .57855 L
.168 .57854 L
.172 .57855 L
.176 .57856 L
.18 .57855 L
.184 .57853 L
.188 .57853 L
.192 .57854 L
.196 .57854 L
.2 .57852 L
Mistroke
.204 .57849 L
.208 .57847 L
.212 .5785 L
.216 .57853 L
.22 .57854 L
.224 .57854 L
.228 .57855 L
.232 .57858 L
.236 .5786 L
.24 .57859 L
.244 .57854 L
.248 .5785 L
.252 .57849 L
.256 .5785 L
.26 .57851 L
.264 .57849 L
.268 .57846 L
.272 .57846 L
.276 .5785 L
.28 .57856 L
.284 .57858 L
.288 .57856 L
.292 .57854 L
.296 .57856 L
.3 .57863 L
.304 .57868 L
.308 .57864 L
.312 .57852 L
.316 .57838 L
.32 .57834 L
.324 .57839 L
.328 .57846 L
.332 .57846 L
.336 .57839 L
.34 .57837 L
.344 .57849 L
.348 .57871 L
.352 .5789 L
.356 .5789 L
.36 .5787 L
.364 .57847 L
.368 .57836 L
.372 .57842 L
.376 .57854 L
.38 .57855 L
.384 .57841 L
.388 .57822 L
.392 .57816 L
.396 .5783 L
.4 .57856 L
Mistroke
.404 .57876 L
.408 .57877 L
.412 .57861 L
.416 .57842 L
.42 .57837 L
.424 .57849 L
.428 .57873 L
.432 .57895 L
.436 .57901 L
.44 .57888 L
.444 .5786 L
.448 .57827 L
.452 .57801 L
.456 .5779 L
.46 .57801 L
.464 .57827 L
.468 .57857 L
.472 .57876 L
.476 .57871 L
.48 .57847 L
.484 .57819 L
.488 .57809 L
.492 .5783 L
.496 .57877 L
.5 .57929 L
.504 .57958 L
.508 .57946 L
.512 .57894 L
.516 .57825 L
.52 .57769 L
.524 .57749 L
.528 .57772 L
.532 .57826 L
.536 .57888 L
.54 .57938 L
.544 .57962 L
.548 .57958 L
.552 .57927 L
.556 .57874 L
.56 .57801 L
.564 .57717 L
.568 .57631 L
.572 .57564 L
.576 .57539 L
.58 .57575 L
.584 .57678 L
.588 .5784 L
.592 .58032 L
.596 .58221 L
.6 .5837 L
Mistroke
.604 .58457 L
.608 .5847 L
.612 .58413 L
.616 .58296 L
.62 .58127 L
.624 .57909 L
.628 .57639 L
.632 .5731 L
.636 .5692 L
.64 .5647 L
.644 .55975 L
.648 .55453 L
.652 .54926 L
.656 .54411 L
.66 .53916 L
.664 .53437 L
.668 .52961 L
.672 .52469 L
.676 .51945 L
.68 .51376 L
.684 .50763 L
.688 .50114 L
.692 .49447 L
.696 .48784 L
.7 .48144 L
.704 .47541 L
.708 .4698 L
.712 .46459 L
.716 .45964 L
.72 .45479 L
.724 .44985 L
.728 .44464 L
.732 .43905 L
.736 .43302 L
.74 .42658 L
.744 .41979 L
.748 .4128 L
.752 .40575 L
.756 .39883 L
.76 .39217 L
.764 .3859 L
.768 .38011 L
.772 .37485 L
.776 .37011 L
.78 .36589 L
.784 .36212 L
.788 .35873 L
.792 .35566 L
.796 .35284 L
.8 .35019 L
Mistroke
.804 .34768 L
.808 .34526 L
.812 .34291 L
.816 .34061 L
.82 .33838 L
.824 .33621 L
.828 .33411 L
.832 .33209 L
.836 .33016 L
.84 .32831 L
.844 .32654 L
.848 .32484 L
.852 .32319 L
.856 .32156 L
.86 .31995 L
.864 .31832 L
.868 .31664 L
.872 .3149 L
.876 .31309 L
.88 .31119 L
.884 .30919 L
.888 .3071 L
.892 .30493 L
.896 .30267 L
.9 .30037 L
.904 .29802 L
.908 .29566 L
.912 .2933 L
.916 .29097 L
.92 .2887 L
.924 .2865 L
.928 .28438 L
.932 .28238 L
.936 .28049 L
.94 .27873 L
.944 .2771 L
.948 .2756 L
.952 .27424 L
.956 .27301 L
.96 .2719 L
.964 .27091 L
.968 .27003 L
.972 .26926 L
.976 .26857 L
.98 .26798 L
.984 .26745 L
.988 .26699 L
.992 .26657 L
.996 .26621 L
1 .26586 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .4244 L
.012 .42984 L
.016 .43177 L
.02 .42989 L
.024 .42922 L
.028 .42972 L
.032 .42995 L
.036 .4297 L
.04 .42962 L
.044 .42962 L
.048 .42964 L
.052 .42956 L
.056 .42954 L
.06 .4295 L
.064 .42951 L
.068 .42947 L
.072 .42946 L
.076 .42941 L
.08 .42938 L
.084 .42932 L
.088 .42928 L
.092 .42922 L
.096 .4292 L
.1 .42918 L
.104 .42917 L
.108 .42913 L
.112 .42911 L
.116 .42908 L
.12 .42907 L
.124 .42903 L
.128 .429 L
.132 .42895 L
.136 .42892 L
.14 .42887 L
.144 .42881 L
.148 .42875 L
.152 .42873 L
.156 .42873 L
.16 .42872 L
.164 .4287 L
.168 .42868 L
.172 .42866 L
.176 .42865 L
.18 .42859 L
.184 .42853 L
.188 .42847 L
.192 .42845 L
.196 .42842 L
.2 .42837 L
Mistroke
.204 .4283 L
.208 .42827 L
.212 .42827 L
.216 .42828 L
.22 .42826 L
.224 .42822 L
.228 .42819 L
.232 .4282 L
.236 .42819 L
.24 .42814 L
.244 .42805 L
.248 .42797 L
.252 .42793 L
.256 .42793 L
.26 .42791 L
.264 .42785 L
.268 .42776 L
.272 .42772 L
.276 .42774 L
.28 .42779 L
.284 .42779 L
.288 .42774 L
.292 .42768 L
.296 .42767 L
.3 .42772 L
.304 .42775 L
.308 .42767 L
.312 .42749 L
.316 .42729 L
.32 .4272 L
.324 .42723 L
.328 .42729 L
.332 .42725 L
.336 .42715 L
.34 .4271 L
.344 .42721 L
.348 .42745 L
.352 .42764 L
.356 .4276 L
.36 .42733 L
.364 .42701 L
.368 .42685 L
.372 .4269 L
.376 .42701 L
.38 .42699 L
.384 .42678 L
.388 .42651 L
.392 .4264 L
.396 .42655 L
.4 .42684 L
Mistroke
.404 .42706 L
.408 .42704 L
.412 .42682 L
.416 .42656 L
.42 .42645 L
.424 .42657 L
.428 .42683 L
.432 .42706 L
.436 .42711 L
.44 .42693 L
.444 .42656 L
.448 .42612 L
.452 .42575 L
.456 .42558 L
.46 .42567 L
.464 .42597 L
.468 .42632 L
.472 .42652 L
.476 .42643 L
.48 .4261 L
.484 .42572 L
.488 .42556 L
.492 .42579 L
.496 .42634 L
.5 .42695 L
.504 .42728 L
.508 .4271 L
.512 .42643 L
.516 .42555 L
.52 .42482 L
.524 .42453 L
.528 .42478 L
.532 .42541 L
.536 .42616 L
.54 .42675 L
.544 .42703 L
.548 .42695 L
.552 .42653 L
.556 .42583 L
.56 .42489 L
.564 .4238 L
.568 .42271 L
.572 .42184 L
.576 .4215 L
.58 .42192 L
.584 .42318 L
.588 .42516 L
.592 .42753 L
.596 .42984 L
.6 .43167 L
Mistroke
.604 .43271 L
.608 .43285 L
.612 .43211 L
.616 .43062 L
.62 .42848 L
.624 .42572 L
.628 .42232 L
.632 .4182 L
.636 .4133 L
.64 .40767 L
.644 .40147 L
.648 .39494 L
.652 .38835 L
.656 .38191 L
.66 .37571 L
.664 .36972 L
.668 .36377 L
.672 .35762 L
.676 .35106 L
.68 .34396 L
.684 .3363 L
.688 .3282 L
.692 .31987 L
.696 .31159 L
.7 .3036 L
.704 .29608 L
.708 .28909 L
.712 .28258 L
.716 .27641 L
.72 .27036 L
.724 .26419 L
.728 .2577 L
.732 .25073 L
.736 .24322 L
.74 .23518 L
.744 .22673 L
.748 .21802 L
.752 .20924 L
.756 .20062 L
.76 .19233 L
.764 .18452 L
.768 .17732 L
.772 .17077 L
.776 .16489 L
.78 .15964 L
.784 .15495 L
.788 .15075 L
.792 .14694 L
.796 .14343 L
.8 .14016 L
Mistroke
.804 .13704 L
.808 .13404 L
.812 .13113 L
.816 .12829 L
.82 .12552 L
.824 .12284 L
.828 .12024 L
.832 .11774 L
.836 .11536 L
.84 .11307 L
.844 .11089 L
.848 .10879 L
.852 .10675 L
.856 .10475 L
.86 .10276 L
.864 .10075 L
.868 .09869 L
.872 .09655 L
.876 .09431 L
.88 .09196 L
.884 .0895 L
.888 .08692 L
.892 .08424 L
.896 .08146 L
.9 .07861 L
.904 .07571 L
.908 .07279 L
.912 .06988 L
.916 .06702 L
.92 .06421 L
.924 .0615 L
.928 .0589 L
.932 .05644 L
.936 .05411 L
.94 .05196 L
.944 .04996 L
.948 .04814 L
.952 .04648 L
.956 .045 L
.96 .04367 L
.964 .04251 L
.968 .04148 L
.972 .04059 L
.976 .03983 L
.98 .03919 L
.984 .03864 L
.988 .03821 L
.992 .03785 L
.996 .0376 L
1 .03739 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`<000Aoo`04001oogoo0002Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo
02eoo`80009oo`8000=oo`03001oo`0003=oo`008Woo0`0000=oo`0000001@0000=oo`0000004`00
00=oo`00Ool00P0000=oo`0000000P0000Eoo`00000007oo00800003Ool0000000800005Ool007oo
Ool0000cOol0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00P000goo00@007ooOomoo`800003Ool007oo009oo`05001oogooOol00003Ool01@00Oomo
ogoo00000Woo1P000goo00D007ooOomoo`0000=oo`03001oogoo00Yoo`008Woo0P00>Woo00<007oo
Ool047oo0P001Goo3@0037oo000ROol00`00Oomoo`0jOol00`00Oomoo`0>Ool2000OOol0029oo`80
03]oo`03001oogoo00ioo`03001oogoo01ioo`008Woo0P00>goo00<007ooOol03Woo00<007ooOol0
7Woo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0kOol00`00Oomoo`0<
Ool00`00Oomoo`0OOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
?7oo00<007ooOol037oo00<007ooOol07goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8003aoo`03001oogoo00aoo`03001oogoo01moo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0kOol00`00Oomoo`0;Ool00`00Oomoo`0POol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00?Goo10000goo00<007oo
Ool00goo00<007ooOol087oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8003eo
o`800004Ool007ooOol30004Ool00`00Oomoo`0POol000]oo`8000Yoo`8000Aoo`03001oogoo009o
o`03001oogoo03moo`06001oogoo001oo`000goo00<007ooOol08Goo000;Ool20004Ool00`00Oomo
o`03Ool20002Ool50002Ool20011Ool20002Ool01@00Oomoogoo00008goo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0002Ool20015Ool01@00Oomoogoo00008goo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo04Eoo`04001oogoo000SOol0
00Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8004Ioo`03001oo`0002Aoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00Agoo0P0097oo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool3
0003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<0
07ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo
000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000R
Ool2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000
Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009
Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<0
07ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo
0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo
0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00
Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0
009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool0
00Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo
00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
0goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomo
o`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool4
0003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000
Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomo
o`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00
Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
00=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qo
o`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool2
0004Ool:0003Ool20006Ool002Qoo`03001oogoo055oo`8001=oo`00:7oo00<007ooOol0Cgoo0`00
57oo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001o
ogoo00moo`03001oogoo009oo`<000]oo`03001oogoo00Yoo`00:7oo00<007ooOol0BGoo0`006Woo
000XOol00`00Oomoo`17Ool2000MOol002Qoo`03001oogoo04Ioo`8001ioo`00:7oo00<007ooOol0
A7oo0P0087oo000XOol00`00Oomoo`14Ool00`00Oomoo`0OOol000]oo`8000Aoo`03001oogoo00=o
o`8000Aoo`8000=oo`<000=oo`03001oogoo04=oo`03001oogoo021oo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo0014Ool2000ROol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo0014Ool00`00Oomoo`0QOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo0080049oo`80
02=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007oo
Ool0@7oo0P0097oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo
00<007ooOol0@7oo00<007ooOol08goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomo
o`0oOol00`00Oomoo`0TOol002Qoo`03001oogoo03ioo`8002Ioo`00:7oo00<007ooOol0?Goo0P00
9goo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0mOol00`00Oomoo`0V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0?7oo00<0
07ooOol09goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
03aoo`03001oogoo02Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2
000lOol00`00Oomoo`0XOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0>Woo0P00:Woo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001o
ogoo03Uoo`8002]oo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0>Goo00<007oo
Ool0:Woo000XOol00`00Oomoo`0hOol00`00Oomoo`0[Ool002Qoo`03001oogoo035oo`8000Aoo`03
001oogoo02aoo`00:7oo=@0000=oo`0000000`00;Woo000;Ool20004Ool00`00Oomoo`03Ool20003
Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D0
07ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo
1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo
0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
2goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo0080
07=oo`002Woo00@007ooOol000]oo`04001oogoo001WOol00`00Oomoo`0:Ool000Yoo`04001oogoo
0007Ool40003Ool00`00Oomoo`1POol5000=Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2
001OOol2000BOol000]oo`8000Qoo`D0009oo`03001oogoo05aoo`8001Aoo`0077oo00<007ooOol0
3Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P00
17oo0P0017oo1P000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007oo
Ool000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogoo
001oo`020002Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03
001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00<007ooOol00`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00Eoo`05001oogooOol00002Ool01@00Oomoo`00Ool00P001goo00<007ooOol017oo00@007ooOol0
009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`800003Ool007oo00=oo`06001oogooOol007oo10000goo00@0
07ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04
001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001o
ogooOol00002Ool00`00Oomoo`040002Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000Ioo`04
001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04
001oogooOol50003Ool20006Ool30004Ool40002Ool20006Ool30002Ool50003Ool20006Ool001ao
o`03001oogoo04moo`80025oo`0077oo00<007ooOol0Cgoo00<007ooOol087oo000LOomY000<Ool0
01aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00@007ooOomoo`80009oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomo
o`1=Ool00`00Oomoo`0ROol001aoo`8004eoo`03001oogoo02=oo`0077oo00<007ooOol0Bgoo00<0
07ooOol097oo000LOol00`00Oomoo`1;Ool00`00Oomoo`0TOol001aoo`8004aoo`03001oogoo02Ao
o`0077oo00<007ooOol0BWoo00<007ooOol09Goo000LOol00`00Oomoo`1:Ool00`00Oomoo`0UOol0
01aoo`8004Yoo`03001oogoo02Ioo`0077oo00<007ooOol0B7oo0P00:7oo000LOol20019Ool00`00
Oomoo`0WOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo04Moo`8002Uoo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`16Ool2000ZOol000Yoo`04001oogoo
000;Ool00`00Oomoo`020017Ool00`00Oomoo`0YOol000Yoo`04001oogoo000;Ool01000Oomoo`00
B7oo00<007ooOol0:Goo000:Ool01000Oomoo`001goo10000goo00<007ooOol0AGoo00<007ooOol0
:Woo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00AWoo00<007ooOol0:Woo000;Ool20008
Ool50002Ool00`00Oomoo`14Ool00`00Oomoo`0[Ool001aoo`03001oogoo04=oo`03001oogoo02ao
o`0077oo0P00A7oo00<007ooOol0;7oo000LOol00`00Oomoo`12Ool2000^Ool001aoo`80049oo`80
02moo`0077oo00<007ooOol0@Goo00<007ooOol0;Woo000LOol00`00Oomoo`10Ool2000`Ool001ao
o`80045oo`03001oogoo02moo`005Woo0`000goo00<007ooOol0?goo00<007ooOol0<7oo000GOol0
0`00Oomoo`02Ool2000dOol00`00Oomoo`02Ool30003Ool2000bOol001Moo`03001oogoo009ooc/0
009oo`D003=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00
Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol0
0`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol0
00]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]o
o`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol0
1goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]o
o`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(29893\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30089 m
.008 .30091 L
.012 .29855 L
.016 .29716 L
.02 .29755 L
.024 .2979 L
.028 .29845 L
.032 .29944 L
.036 .29986 L
.04 .29941 L
.044 .29833 L
.048 .29748 L
.052 .29746 L
.056 .298 L
.06 .29889 L
.064 .29957 L
.068 .29957 L
.072 .299 L
.076 .29806 L
.08 .29729 L
.084 .29727 L
.088 .29795 L
.092 .29894 L
.096 .29956 L
.1 .29952 L
.104 .29903 L
.108 .29824 L
.112 .29738 L
.116 .29697 L
.12 .29735 L
.124 .29834 L
.128 .29918 L
.132 .29937 L
.136 .29913 L
.14 .29872 L
.144 .29816 L
.148 .29752 L
.152 .29713 L
.156 .29746 L
.16 .2983 L
.164 .29893 L
.168 .2989 L
.172 .29848 L
.176 .29823 L
.18 .29814 L
.184 .29785 L
.188 .29745 L
.192 .29748 L
.196 .29816 L
.2 .29892 L
Mistroke
.204 .29901 L
.208 .29843 L
.212 .2978 L
.216 .29762 L
.22 .29768 L
.224 .29753 L
.228 .29729 L
.232 .2975 L
.236 .29832 L
.24 .29916 L
.244 .29922 L
.248 .2984 L
.252 .29739 L
.256 .297 L
.26 .29736 L
.264 .29791 L
.268 .29802 L
.272 .2977 L
.276 .29747 L
.28 .29778 L
.284 .29846 L
.288 .29879 L
.292 .29827 L
.296 .29726 L
.3 .29671 L
.304 .29719 L
.308 .29818 L
.312 .29854 L
.316 .29777 L
.32 .29677 L
.324 .29695 L
.328 .29856 L
.332 .30008 L
.336 .2996 L
.34 .29695 L
.344 .29426 L
.348 .29408 L
.352 .29679 L
.356 .30003 L
.36 .3009 L
.364 .29881 L
.368 .29612 L
.372 .29575 L
.376 .29815 L
.38 .3007 L
.384 .30026 L
.388 .29644 L
.392 .29225 L
.396 .29151 L
.4 .29539 L
Mistroke
.404 .30116 L
.408 .30448 L
.412 .30298 L
.416 .29805 L
.42 .29348 L
.424 .29224 L
.428 .29445 L
.432 .29773 L
.436 .29954 L
.44 .29905 L
.444 .29738 L
.448 .29618 L
.452 .2963 L
.456 .29742 L
.46 .29874 L
.464 .29968 L
.468 .29996 L
.472 .29927 L
.476 .29725 L
.48 .29404 L
.484 .29087 L
.488 .28986 L
.492 .29272 L
.496 .29914 L
.5 .30629 L
.504 .31002 L
.508 .30741 L
.512 .29892 L
.516 .2885 L
.52 .28162 L
.524 .28208 L
.528 .28982 L
.532 .30097 L
.536 .31002 L
.54 .31288 L
.544 .3088 L
.548 .3004 L
.552 .2918 L
.556 .28637 L
.56 .28525 L
.564 .28747 L
.568 .29116 L
.572 .29501 L
.576 .29888 L
.58 .30336 L
.584 .30862 L
.588 .31356 L
.592 .31588 L
.596 .31316 L
.6 .30433 L
Mistroke
.604 .29067 L
.608 .27568 L
.612 .26384 L
.616 .25882 L
.62 .26198 L
.624 .27205 L
.628 .28581 L
.632 .29964 L
.636 .31102 L
.64 .31943 L
.644 .32626 L
.648 .33391 L
.652 .34452 L
.656 .35887 L
.66 .37597 L
.664 .39334 L
.668 .40801 L
.672 .41757 L
.676 .42113 L
.68 .41955 L
.684 .41509 L
.688 .41061 L
.692 .40867 L
.696 .4107 L
.7 .41676 L
.704 .42555 L
.708 .43495 L
.712 .44262 L
.716 .44674 L
.72 .44641 L
.724 .44189 L
.728 .43451 L
.732 .42624 L
.736 .41924 L
.74 .41536 L
.744 .41578 L
.748 .42081 L
.752 .42987 L
.756 .44175 L
.76 .4548 L
.764 .46731 L
.768 .47773 L
.772 .48487 L
.776 .48794 L
.78 .48666 L
.784 .48116 L
.788 .47195 L
.792 .45981 L
.796 .44566 L
.8 .4304 L
Mistroke
.804 .41486 L
.808 .39972 L
.812 .38552 L
.816 .37262 L
.82 .36127 L
.824 .35155 L
.828 .34346 L
.832 .3369 L
.836 .33172 L
.84 .32774 L
.844 .32477 L
.848 .32261 L
.852 .32109 L
.856 .32004 L
.86 .31934 L
.864 .31889 L
.868 .31863 L
.872 .3185 L
.876 .31847 L
.88 .31851 L
.884 .31862 L
.888 .3188 L
.892 .31904 L
.896 .31937 L
.9 .3198 L
.904 .32032 L
.908 .32093 L
.912 .32159 L
.916 .32227 L
.92 .32296 L
.924 .32365 L
.928 .32433 L
.932 .32497 L
.936 .32556 L
.94 .32605 L
.944 .32642 L
.948 .32667 L
.952 .32682 L
.956 .32687 L
.96 .32683 L
.964 .32672 L
.968 .32652 L
.972 .32626 L
.976 .32593 L
.98 .32556 L
.984 .32518 L
.988 .3248 L
.992 .32446 L
.996 .32414 L
1 .32385 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .5861 m
.008 .57816 L
.012 .57553 L
.016 .57803 L
.02 .57894 L
.024 .57805 L
.028 .57777 L
.032 .57804 L
.036 .57821 L
.04 .57812 L
.044 .57812 L
.048 .57813 L
.052 .57816 L
.056 .57812 L
.06 .57811 L
.064 .57807 L
.068 .57807 L
.072 .57804 L
.076 .57806 L
.08 .57806 L
.084 .57811 L
.088 .57813 L
.092 .57816 L
.096 .57815 L
.1 .57814 L
.104 .57811 L
.108 .57808 L
.112 .57805 L
.116 .57805 L
.12 .57806 L
.124 .57809 L
.128 .57809 L
.132 .57811 L
.136 .57812 L
.14 .57813 L
.144 .57812 L
.148 .57811 L
.152 .57811 L
.156 .57811 L
.16 .5781 L
.164 .57808 L
.168 .57806 L
.172 .57807 L
.176 .57808 L
.18 .57809 L
.184 .57809 L
.188 .57809 L
.192 .57811 L
.196 .57813 L
.2 .57813 L
Mistroke
.204 .57811 L
.208 .5781 L
.212 .57811 L
.216 .57812 L
.22 .5781 L
.224 .57806 L
.228 .57804 L
.232 .57805 L
.236 .57807 L
.24 .57808 L
.244 .57808 L
.248 .57809 L
.252 .57813 L
.256 .57816 L
.26 .57817 L
.264 .57813 L
.268 .57809 L
.272 .57807 L
.276 .57808 L
.28 .5781 L
.284 .57808 L
.288 .57804 L
.292 .57801 L
.296 .57803 L
.3 .57808 L
.304 .57813 L
.308 .57812 L
.312 .57808 L
.316 .57807 L
.32 .57814 L
.324 .57823 L
.328 .57828 L
.332 .57821 L
.336 .57807 L
.34 .57797 L
.344 .57796 L
.348 .57802 L
.352 .57804 L
.356 .57797 L
.36 .57787 L
.364 .57788 L
.368 .57806 L
.372 .57831 L
.376 .57847 L
.38 .57842 L
.384 .57822 L
.388 .57804 L
.392 .578 L
.396 .57809 L
.4 .57817 L
Mistroke
.404 .57812 L
.408 .57793 L
.412 .57775 L
.416 .57772 L
.42 .57788 L
.424 .57813 L
.428 .5783 L
.432 .57829 L
.436 .57814 L
.44 .57798 L
.444 .57793 L
.448 .57804 L
.452 .57826 L
.456 .57848 L
.46 .57859 L
.464 .57852 L
.468 .57828 L
.472 .57795 L
.476 .57764 L
.48 .57748 L
.484 .57754 L
.488 .57779 L
.492 .57811 L
.496 .57831 L
.5 .57827 L
.504 .57802 L
.508 .57771 L
.512 .57758 L
.516 .57777 L
.52 .57824 L
.524 .57879 L
.528 .57914 L
.532 .57909 L
.536 .57864 L
.54 .57799 L
.544 .5774 L
.548 .57711 L
.552 .57722 L
.556 .57764 L
.56 .57821 L
.564 .57873 L
.568 .57907 L
.572 .57919 L
.576 .57906 L
.58 .57868 L
.584 .57805 L
.588 .5772 L
.592 .57625 L
.596 .57539 L
.6 .57487 L
Mistroke
.604 .57492 L
.608 .57566 L
.612 .57706 L
.616 .57888 L
.62 .5808 L
.624 .58249 L
.628 .58366 L
.632 .58419 L
.636 .58406 L
.64 .58334 L
.644 .58208 L
.648 .58032 L
.652 .57803 L
.656 .57514 L
.66 .5716 L
.664 .56743 L
.668 .56272 L
.672 .55766 L
.676 .55247 L
.68 .54733 L
.684 .54237 L
.688 .53759 L
.692 .53288 L
.696 .52809 L
.7 .52303 L
.704 .51756 L
.708 .51164 L
.712 .50531 L
.716 .49872 L
.72 .49206 L
.724 .48555 L
.728 .47934 L
.732 .47354 L
.736 .46815 L
.74 .46308 L
.744 .45821 L
.748 .45333 L
.752 .44828 L
.756 .44291 L
.76 .43713 L
.764 .43092 L
.768 .42432 L
.772 .41744 L
.776 .41041 L
.78 .40341 L
.784 .39658 L
.788 .39007 L
.792 .38398 L
.796 .37839 L
.8 .37331 L
Mistroke
.804 .36876 L
.808 .36469 L
.812 .36104 L
.816 .35775 L
.82 .35475 L
.824 .35197 L
.828 .34936 L
.832 .34686 L
.836 .34444 L
.84 .3421 L
.844 .33982 L
.848 .3376 L
.852 .33545 L
.856 .33338 L
.86 .33139 L
.864 .32949 L
.868 .32767 L
.872 .32593 L
.876 .32425 L
.88 .32261 L
.884 .321 L
.888 .31938 L
.892 .31774 L
.896 .31604 L
.9 .31428 L
.904 .31244 L
.908 .3105 L
.912 .30847 L
.916 .30635 L
.92 .30415 L
.924 .30187 L
.928 .29954 L
.932 .29719 L
.936 .29481 L
.94 .29245 L
.944 .29013 L
.948 .28786 L
.952 .28566 L
.956 .28355 L
.96 .28154 L
.964 .27965 L
.968 .27786 L
.972 .27621 L
.976 .27466 L
.98 .27325 L
.984 .27193 L
.988 .27072 L
.992 .26959 L
.996 .26856 L
1 .26759 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43079 L
.012 .4296 L
.016 .42952 L
.02 .43 L
.024 .43 L
.028 .42968 L
.032 .4297 L
.036 .42971 L
.04 .42969 L
.044 .42959 L
.048 .42962 L
.052 .4296 L
.056 .42961 L
.06 .42955 L
.064 .42951 L
.068 .42944 L
.072 .42939 L
.076 .42933 L
.08 .42932 L
.084 .4293 L
.088 .42931 L
.092 .42929 L
.096 .42928 L
.1 .42924 L
.104 .42921 L
.108 .42914 L
.112 .42909 L
.116 .42903 L
.12 .429 L
.124 .42896 L
.128 .42894 L
.132 .42891 L
.136 .42892 L
.14 .42892 L
.144 .4289 L
.148 .42886 L
.152 .42882 L
.156 .42878 L
.16 .42872 L
.164 .42865 L
.168 .42859 L
.172 .42857 L
.176 .42856 L
.18 .42855 L
.184 .42852 L
.188 .4285 L
.192 .42849 L
.196 .42848 L
.2 .42844 L
Mistroke
.204 .42837 L
.208 .42833 L
.212 .42831 L
.216 .42829 L
.22 .42823 L
.224 .42816 L
.228 .42811 L
.232 .4281 L
.236 .42809 L
.24 .42807 L
.244 .42803 L
.248 .428 L
.252 .42801 L
.256 .42802 L
.26 .42801 L
.264 .42794 L
.268 .42785 L
.272 .4278 L
.276 .42778 L
.28 .42776 L
.284 .42771 L
.288 .42762 L
.292 .42755 L
.296 .42754 L
.3 .42758 L
.304 .4276 L
.308 .42756 L
.312 .42749 L
.316 .42746 L
.32 .4275 L
.324 .42758 L
.328 .42759 L
.332 .42747 L
.336 .42727 L
.34 .42712 L
.344 .42709 L
.348 .42714 L
.352 .42712 L
.356 .42699 L
.36 .42684 L
.364 .42682 L
.368 .42701 L
.372 .42729 L
.376 .42746 L
.38 .42737 L
.384 .42709 L
.388 .42683 L
.392 .42676 L
.396 .42684 L
.4 .4269 L
Mistroke
.404 .4268 L
.408 .42653 L
.412 .42627 L
.416 .42621 L
.42 .42639 L
.424 .42667 L
.428 .42684 L
.432 .42679 L
.436 .42656 L
.44 .42633 L
.444 .42624 L
.448 .42636 L
.452 .42661 L
.456 .42685 L
.46 .42694 L
.464 .42682 L
.468 .4265 L
.472 .42605 L
.476 .42563 L
.48 .42539 L
.484 .42544 L
.488 .42573 L
.492 .4261 L
.496 .42632 L
.5 .42624 L
.504 .42588 L
.508 .42546 L
.512 .42527 L
.516 .42548 L
.52 .42605 L
.524 .4267 L
.528 .4271 L
.532 .427 L
.536 .42641 L
.54 .42555 L
.544 .42479 L
.548 .42441 L
.552 .42452 L
.556 .42501 L
.56 .42569 L
.564 .4263 L
.568 .4267 L
.572 .42681 L
.576 .42662 L
.58 .42611 L
.584 .42529 L
.588 .42421 L
.592 .42299 L
.596 .42189 L
.6 .4212 L
Mistroke
.604 .42123 L
.608 .42213 L
.612 .42384 L
.616 .42608 L
.62 .42845 L
.624 .43052 L
.628 .43195 L
.632 .43257 L
.636 .43237 L
.64 .43143 L
.644 .42983 L
.648 .42761 L
.652 .42473 L
.656 .42109 L
.66 .41665 L
.664 .41142 L
.668 .40552 L
.672 .39919 L
.676 .39269 L
.68 .38627 L
.684 .38006 L
.688 .37408 L
.692 .36819 L
.696 .3622 L
.7 .35587 L
.704 .34904 L
.708 .34164 L
.712 .33374 L
.716 .32551 L
.72 .3172 L
.724 .30906 L
.728 .30132 L
.732 .29408 L
.736 .28735 L
.74 .28104 L
.744 .27495 L
.748 .26887 L
.752 .26257 L
.756 .25588 L
.76 .24867 L
.764 .24092 L
.768 .2327 L
.772 .22413 L
.776 .21538 L
.78 .20666 L
.784 .19815 L
.788 .19005 L
.792 .18247 L
.796 .17551 L
.8 .1692 L
Mistroke
.804 .16354 L
.808 .15848 L
.812 .15395 L
.816 .14987 L
.82 .14614 L
.824 .1427 L
.828 .13945 L
.832 .13635 L
.836 .13336 L
.84 .13046 L
.844 .12764 L
.848 .12489 L
.852 .12223 L
.856 .11967 L
.86 .11721 L
.864 .11486 L
.868 .11261 L
.872 .11046 L
.876 .10839 L
.88 .10638 L
.884 .10439 L
.888 .1024 L
.892 .10037 L
.896 .09829 L
.9 .09612 L
.904 .09385 L
.908 .09147 L
.912 .08897 L
.916 .08636 L
.92 .08364 L
.924 .08085 L
.928 .07799 L
.932 .0751 L
.936 .07219 L
.94 .06932 L
.944 .06649 L
.948 .06374 L
.952 .06109 L
.956 .05858 L
.96 .0562 L
.964 .054 L
.968 .05196 L
.972 .05011 L
.976 .04844 L
.98 .04697 L
.984 .04568 L
.988 .04458 L
.992 .04365 L
.996 .04292 L
1 .04234 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`04001oogooOol200001Goo001oogoo00000Woo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006Ool0
1000Oomoo`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1P000Woo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000R
Ool00`00Oomoo`0_Ool20002Ool20003Ool00`00Ool0000aOol0029oo`L00004Ool00000Ool20000
0goo0000000C00000goo0000000200000goo00000003000027oo000007oo001oo`00Ool30002Ool0
0`00Ool0000aOol0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00@007oo001oo`<00003Ool007oo00<0009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00H007ooOomoo`00Ool40002Ool01@00Oomoogoo00000goo00<007ooOol02Woo000ROol2000lOol2
000BOol30002Ool<000<Ool0029oo`03001oogoo03aoo`03001oogoo00moo`8001aoo`008Woo0P00
?Woo00<007ooOol03Woo00<007ooOol06goo000ROol2000nOol00`00Oomoo`0=Ool00`00Oomoo`0L
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo03eoo`03001oogoo00eo
o`03001oogoo01aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000n
Ool00`00Oomoo`0=Ool00`00Oomoo`0LOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P00?Woo00<007ooOol037oo00<007ooOol07Goo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00]oo`03001oogoo01eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000oOol01000Ool000002Woo
00<007ooOol07Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`80041oo`<000=o
o`8000Aoo`03001oogoo01ioo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0@Woo
00D007oo001oo`0000Aoo`03001oogoo01ioo`002goo0P0017oo00<007ooOol00goo0P000Woo1@00
0Woo0P00@goo00<007oo00000Woo00D007ooOomoo`00021oo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`000Woo0P00A7oo00D007ooOomoo`0000=oo`03001oogoo01ioo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`17Ool01000Oomoo`00
8Goo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol20019Ool00`00Ool0000Q
Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008004Uoo`03001oo`00
025oo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol004Yoo`80029oo`00
2goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`00
0goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029o
o`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=o
o`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo
0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo
0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`80
00Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=o
o`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<0
00Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`80
00=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomo
o`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001o
o`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000
Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00
:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<0
07ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomo
o`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0003Ool01000Ool007oo0P000goo00@007ooOol000Eoo`00:7oo00<007oo
Ool02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`80
00=oo`<000Aoo`8000Aoo`8000Aoo`<00003Ool0000000@000=oo`8000Ioo`00:7oo00<007ooOol0
Dgoo0`0047oo000XOol00`00Oomoo`1BOol2000BOol002Qooed000aoo`00:7oo00<007ooOol03goo
00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol017oo0`002Goo00<007oo
Ool02Woo000XOol00`00Oomoo`1;Ool3000HOol002Qoo`03001oogoo04Yoo`8001Yoo`00:7oo00<0
07ooOol0B7oo0P0077oo000XOol00`00Oomoo`17Ool2000MOol002Qoo`03001oogoo04Ioo`8001io
o`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0AWoo00<007oo
Ool07Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007oo
Ool004Moo`03001oogoo01ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOol004Ioo`03001oogoo01moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol00P00AGoo00<007ooOol07goo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`13Ool00`00Oomoo`0POol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`12Ool2000ROol0
00]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo049oo`03001oogoo025oo`00:7oo00<0
07ooOol0@Goo00<007ooOol08Woo000XOol00`00Oomoo`10Ool00`00Oomoo`0SOol0015oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo03moo`8002Eoo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0oOol00`00Oomoo`0TOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0?Woo00<007ooOol09Goo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8003ioo`8002Moo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0mOol00`00Oomoo`0VOol0
011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0?7oo00<007ooOol09goo
000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0kOol00`00Oomoo`0XOol002Qoo`03
001oogoo03Yoo`8002Yoo`00:7oo0P00=Goo0P000goo0P00:goo000XOolg00000goo00000003000/
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool5
0002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol0
07Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo069oo`@000aoo`002Woo00@007ooOol0
00Moo`03001oogoo00Aoo`80065oo`<000moo`002goo0P0027oo1@000Woo00<007ooOol0Ggoo0P00
4Goo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004
Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001o
ogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`80009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`800003Ool007oo00Ioo`04001o
ogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oo`000004Ool0
0`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomo
o`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo
00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00P000goo00H0
07ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool0
1000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04
Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool40004Ool01`00Oomoogoo
001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`80
00Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20003Ool30006Ool30002Ool50003
Ool20006Ool001aoo`03001oogoo059oo`8001ioo`0077oo00<007ooOol0DWoo00<007ooOol07Goo
000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo
000LOol00`00Oomoo`1?Ool00`00Oomoo`0POol001aoo`80051oo`03001oogoo021oo`0077oo00<0
07ooOol0CWoo00<007ooOol08Goo000LOol00`00Oomoo`1>Ool00`00Oomoo`0QOol001aoo`8004io
o`03001oogoo029oo`0077oo00<007ooOol0CGoo00<007ooOol08Woo000LOol00`00Oomoo`1=Ool0
0`00Oomoo`0ROol001aoo`8004eoo`03001oogoo02=oo`0077oo00<007ooOol0Bgoo00<007ooOol0
97oo000LOol2001<Ool00`00Oomoo`0TOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001o
ogoo04Yoo`03001oogoo02Eoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`19Ool2000WOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001:Ool00`00Oomoo`0VOol000Yo
o`04001oogoo000;Ool01000Oomoo`00BWoo00<007ooOol09goo000:Ool01000Oomoo`001goo1000
0goo00<007ooOol0B7oo00<007ooOol09goo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00
B7oo00<007ooOol0:7oo000;Ool20008Ool50002Ool00`00Oomoo`17Ool00`00Oomoo`0XOol001ao
o`03001oogoo04Ioo`03001oogoo02Uoo`0077oo0P00Agoo00<007ooOol0:Goo000LOol00`00Oomo
o`15Ool00`00Oomoo`0ZOol001aoo`8004Eoo`8002aoo`0077oo00<007ooOol0A7oo00<007ooOol0
:goo000LOol00`00Oomoo`13Ool00`00Oomoo`0/Ool001aoo`8004Aoo`03001oogoo02aoo`005Woo
0`000goo00<007ooOol0@Woo00<007ooOol0;Goo000GOol00`00Oomoo`02Ool00`00Oomoo`0fOol0
1000Oomoogoo0`0017oo00<007ooOol0;Woo000GOol00`00Oomoo`02Ooli00000goo000000020002
Ool5000`Ool001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007oo
Ool0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;
Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool0
1000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Mo
o`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool0
0`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(30060\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30145 m
.008 .2997 L
.012 .29807 L
.016 .29757 L
.02 .29873 L
.024 .2992 L
.028 .29865 L
.032 .29874 L
.036 .29913 L
.04 .29897 L
.044 .29846 L
.048 .29794 L
.052 .29792 L
.056 .29831 L
.06 .29876 L
.064 .29915 L
.068 .29916 L
.072 .29883 L
.076 .2984 L
.08 .29796 L
.084 .29793 L
.088 .29833 L
.092 .29878 L
.096 .29894 L
.1 .29865 L
.104 .29825 L
.108 .29802 L
.112 .29795 L
.116 .29815 L
.12 .29868 L
.124 .29922 L
.128 .29927 L
.132 .2986 L
.136 .29768 L
.14 .29722 L
.144 .29734 L
.148 .29784 L
.152 .29848 L
.156 .29915 L
.16 .29961 L
.164 .29935 L
.168 .29829 L
.172 .29715 L
.176 .29678 L
.18 .29735 L
.184 .29817 L
.188 .29869 L
.192 .29892 L
.196 .299 L
.2 .29876 L
Mistroke
.204 .298 L
.208 .2971 L
.212 .29685 L
.216 .29756 L
.22 .29863 L
.224 .29911 L
.228 .29877 L
.232 .29818 L
.236 .29791 L
.24 .29788 L
.244 .29769 L
.248 .29729 L
.252 .29712 L
.256 .29758 L
.26 .29842 L
.264 .29896 L
.268 .29878 L
.272 .29812 L
.276 .29762 L
.28 .29759 L
.284 .29781 L
.288 .29778 L
.292 .29737 L
.296 .29703 L
.3 .29735 L
.304 .29831 L
.308 .29911 L
.312 .29888 L
.316 .29765 L
.32 .29654 L
.324 .29668 L
.328 .29793 L
.332 .29889 L
.336 .29834 L
.34 .2967 L
.344 .29583 L
.348 .29708 L
.352 .29962 L
.356 .30096 L
.36 .2994 L
.364 .29595 L
.368 .29365 L
.372 .29463 L
.376 .29797 L
.38 .30051 L
.384 .29992 L
.388 .29705 L
.392 .29508 L
.396 .29631 L
.4 .29977 L
Mistroke
.404 .30197 L
.408 .30023 L
.412 .2954 L
.416 .29128 L
.42 .29141 L
.424 .29593 L
.428 .30152 L
.432 .30415 L
.436 .30227 L
.44 .29773 L
.444 .29395 L
.448 .29319 L
.452 .29509 L
.456 .29757 L
.46 .29877 L
.464 .29831 L
.468 .29711 L
.472 .29628 L
.476 .29629 L
.48 .29701 L
.484 .29815 L
.488 .29951 L
.492 .30064 L
.496 .30067 L
.5 .29866 L
.504 .29463 L
.508 .29023 L
.512 .28825 L
.516 .29089 L
.52 .2979 L
.524 .30611 L
.528 .31089 L
.532 .30893 L
.536 .30049 L
.54 .28957 L
.544 .28179 L
.548 .28121 L
.552 .28812 L
.556 .29893 L
.56 .30836 L
.564 .31227 L
.568 .30961 L
.572 .30247 L
.576 .29449 L
.58 .28872 L
.584 .28639 L
.588 .2869 L
.592 .28894 L
.596 .2917 L
.6 .29533 L
Mistroke
.604 .30046 L
.608 .30711 L
.612 .31393 L
.616 .3183 L
.62 .31745 L
.624 .30988 L
.628 .29651 L
.632 .2806 L
.636 .26668 L
.64 .25877 L
.644 .25887 L
.648 .26636 L
.652 .2785 L
.656 .29177 L
.66 .30341 L
.664 .31241 L
.668 .31967 L
.672 .32735 L
.676 .33768 L
.68 .35182 L
.684 .36924 L
.688 .38779 L
.692 .4045 L
.696 .41665 L
.7 .42278 L
.704 .42315 L
.708 .41962 L
.712 .415 L
.716 .41209 L
.72 .41285 L
.724 .41786 L
.728 .42627 L
.732 .43615 L
.736 .44513 L
.74 .45107 L
.744 .45268 L
.748 .44977 L
.752 .44326 L
.756 .43489 L
.76 .42679 L
.764 .42099 L
.768 .41901 L
.772 .42161 L
.776 .42869 L
.78 .43938 L
.784 .45225 L
.788 .4656 L
.792 .47771 L
.796 .48712 L
.8 .49276 L
Mistroke
.804 .49407 L
.808 .49097 L
.812 .48381 L
.816 .47323 L
.82 .46006 L
.824 .44518 L
.828 .42945 L
.832 .41366 L
.836 .39849 L
.84 .38444 L
.844 .37187 L
.848 .36093 L
.852 .35165 L
.856 .34397 L
.86 .33774 L
.864 .33283 L
.868 .32907 L
.872 .32628 L
.876 .32425 L
.88 .32281 L
.884 .32178 L
.888 .32105 L
.892 .32055 L
.896 .32023 L
.9 .32006 L
.904 .32003 L
.908 .3201 L
.912 .32026 L
.916 .32051 L
.92 .32086 L
.924 .32132 L
.928 .32191 L
.932 .32262 L
.936 .32342 L
.94 .32427 L
.944 .32515 L
.948 .32603 L
.952 .3269 L
.956 .32775 L
.96 .32856 L
.964 .32928 L
.968 .3299 L
.972 .3304 L
.976 .33077 L
.98 .33102 L
.984 .33116 L
.988 .3312 L
.992 .33115 L
.996 .33099 L
1 .33075 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57739 m
.008 .57778 L
.012 .57788 L
.016 .57748 L
.02 .57761 L
.024 .5778 L
.028 .57777 L
.032 .57762 L
.036 .57765 L
.04 .57765 L
.044 .57766 L
.048 .57762 L
.052 .57765 L
.056 .57765 L
.06 .57767 L
.064 .57766 L
.068 .57769 L
.072 .57769 L
.076 .5777 L
.08 .57769 L
.084 .57768 L
.088 .57766 L
.092 .57765 L
.096 .57762 L
.1 .57763 L
.104 .57764 L
.108 .57767 L
.112 .57768 L
.116 .5777 L
.12 .5777 L
.124 .5777 L
.128 .57768 L
.132 .57766 L
.136 .57765 L
.14 .57765 L
.144 .57764 L
.148 .57764 L
.152 .57764 L
.156 .57766 L
.16 .57767 L
.164 .57768 L
.168 .57768 L
.172 .57769 L
.176 .5777 L
.18 .57769 L
.184 .57766 L
.188 .57764 L
.192 .57764 L
.196 .57764 L
.2 .57764 L
Mistroke
.204 .57764 L
.208 .57764 L
.212 .57767 L
.216 .57769 L
.22 .57769 L
.224 .57768 L
.228 .57768 L
.232 .57769 L
.236 .5777 L
.24 .57768 L
.244 .57765 L
.248 .57762 L
.252 .57763 L
.256 .57764 L
.26 .57764 L
.264 .57763 L
.268 .57763 L
.272 .57765 L
.276 .5777 L
.28 .57773 L
.284 .57773 L
.288 .57769 L
.292 .57765 L
.296 .57766 L
.3 .57768 L
.304 .57768 L
.308 .57764 L
.312 .57759 L
.316 .57757 L
.32 .57761 L
.324 .57766 L
.328 .57768 L
.332 .57764 L
.336 .5776 L
.34 .57763 L
.344 .57774 L
.348 .57783 L
.352 .57784 L
.356 .57774 L
.36 .57762 L
.364 .57757 L
.368 .57761 L
.372 .57765 L
.376 .5776 L
.38 .57747 L
.384 .57737 L
.388 .57742 L
.392 .57763 L
.396 .57788 L
.4 .578 L
Mistroke
.404 .57792 L
.408 .57775 L
.412 .57764 L
.416 .57766 L
.42 .57776 L
.424 .57779 L
.428 .57767 L
.432 .57746 L
.436 .57729 L
.44 .57729 L
.444 .57746 L
.448 .57769 L
.452 .57783 L
.456 .57781 L
.46 .57767 L
.464 .57752 L
.468 .57747 L
.472 .57757 L
.476 .57778 L
.48 .57802 L
.484 .57817 L
.488 .57815 L
.492 .57795 L
.496 .57761 L
.5 .57726 L
.504 .57705 L
.508 .57708 L
.512 .57733 L
.516 .57766 L
.52 .57787 L
.524 .57783 L
.528 .57756 L
.532 .57723 L
.536 .57707 L
.54 .57724 L
.544 .57771 L
.548 .57828 L
.552 .57868 L
.556 .57871 L
.56 .57833 L
.564 .57772 L
.568 .57712 L
.572 .57677 L
.576 .57677 L
.58 .57707 L
.584 .57755 L
.588 .57806 L
.592 .57847 L
.596 .57872 L
.6 .57877 L
Mistroke
.604 .57856 L
.608 .57806 L
.612 .57727 L
.616 .57628 L
.62 .57526 L
.624 .5745 L
.628 .57425 L
.632 .57468 L
.636 .57581 L
.64 .57747 L
.644 .57936 L
.648 .58116 L
.652 .58257 L
.656 .58344 L
.66 .58371 L
.664 .5834 L
.668 .58257 L
.672 .58124 L
.676 .57938 L
.68 .57691 L
.684 .57377 L
.688 .56995 L
.692 .56553 L
.696 .56067 L
.7 .55559 L
.704 .5505 L
.708 .54554 L
.712 .54075 L
.716 .53609 L
.72 .53139 L
.724 .5265 L
.728 .52124 L
.732 .51554 L
.736 .5094 L
.74 .50293 L
.744 .4963 L
.748 .48971 L
.752 .48335 L
.756 .47736 L
.76 .47178 L
.764 .46657 L
.768 .46162 L
.772 .45677 L
.776 .45183 L
.78 .44664 L
.784 .44109 L
.788 .43512 L
.792 .42874 L
.796 .42202 L
.8 .41507 L
Mistroke
.804 .40805 L
.808 .4011 L
.812 .3944 L
.816 .38804 L
.82 .38214 L
.824 .37673 L
.828 .37185 L
.832 .36746 L
.836 .36353 L
.84 .36 L
.844 .35679 L
.848 .35385 L
.852 .35111 L
.856 .34852 L
.86 .34603 L
.864 .34363 L
.868 .34129 L
.872 .33902 L
.876 .33682 L
.88 .33469 L
.884 .33265 L
.888 .33069 L
.892 .32881 L
.896 .32702 L
.9 .3253 L
.904 .32363 L
.908 .322 L
.912 .32038 L
.916 .31874 L
.92 .31706 L
.924 .31533 L
.928 .31351 L
.932 .3116 L
.936 .30959 L
.94 .30747 L
.944 .30526 L
.948 .30295 L
.952 .30056 L
.956 .29811 L
.96 .29561 L
.964 .29309 L
.968 .29055 L
.972 .28803 L
.976 .28553 L
.98 .28309 L
.984 .28069 L
.988 .27838 L
.992 .27612 L
.996 .27395 L
1 .27186 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43565 L
.012 .42984 L
.016 .42793 L
.02 .42977 L
.024 .43047 L
.028 .4298 L
.032 .42959 L
.036 .42972 L
.04 .42979 L
.044 .42964 L
.048 .42958 L
.052 .42954 L
.056 .42954 L
.06 .42948 L
.064 .42947 L
.068 .42944 L
.072 .42945 L
.076 .42942 L
.08 .42942 L
.084 .42937 L
.088 .42933 L
.092 .42925 L
.096 .42919 L
.1 .42912 L
.104 .42911 L
.108 .42909 L
.112 .42911 L
.116 .42911 L
.12 .42911 L
.124 .42908 L
.128 .42902 L
.132 .42894 L
.136 .42889 L
.14 .42884 L
.144 .4288 L
.148 .42876 L
.152 .42875 L
.156 .42874 L
.16 .42874 L
.164 .42872 L
.168 .42869 L
.172 .42866 L
.176 .42863 L
.18 .42858 L
.184 .42852 L
.188 .42846 L
.192 .42842 L
.196 .4284 L
.2 .42837 L
Mistroke
.204 .42834 L
.208 .42832 L
.212 .42831 L
.216 .42831 L
.22 .42827 L
.224 .42822 L
.228 .42817 L
.232 .42816 L
.236 .42815 L
.24 .42811 L
.244 .42804 L
.248 .42798 L
.252 .42794 L
.256 .42792 L
.26 .42789 L
.264 .42784 L
.268 .42781 L
.272 .42781 L
.276 .42783 L
.28 .42784 L
.284 .4278 L
.288 .42773 L
.292 .42766 L
.296 .42763 L
.3 .42762 L
.304 .42758 L
.308 .4275 L
.312 .4274 L
.316 .42736 L
.32 .42738 L
.324 .42742 L
.328 .42741 L
.332 .42732 L
.336 .42724 L
.34 .42724 L
.344 .42734 L
.348 .42743 L
.352 .42741 L
.356 .42725 L
.36 .42707 L
.364 .42698 L
.368 .427 L
.372 .42702 L
.376 .42692 L
.38 .42672 L
.384 .42655 L
.388 .42659 L
.392 .42683 L
.396 .42712 L
.4 .42724 L
Mistroke
.404 .42711 L
.408 .42685 L
.412 .42667 L
.416 .42666 L
.42 .42676 L
.424 .42678 L
.428 .42661 L
.432 .42631 L
.436 .42606 L
.44 .42603 L
.444 .42621 L
.448 .42646 L
.452 .42661 L
.456 .42655 L
.46 .42634 L
.464 .42613 L
.468 .42604 L
.472 .42613 L
.476 .42636 L
.48 .42661 L
.484 .42676 L
.488 .42671 L
.492 .42643 L
.496 .42599 L
.5 .42552 L
.504 .42523 L
.508 .42523 L
.512 .42551 L
.516 .42588 L
.52 .42612 L
.524 .42604 L
.528 .42567 L
.532 .42523 L
.536 .425 L
.54 .42518 L
.544 .42573 L
.548 .42641 L
.552 .42687 L
.556 .42687 L
.56 .42637 L
.564 .42558 L
.568 .42481 L
.572 .42434 L
.576 .4243 L
.58 .42464 L
.584 .42521 L
.588 .42581 L
.592 .4263 L
.596 .42659 L
.6 .42661 L
Mistroke
.604 .42632 L
.608 .42566 L
.612 .42464 L
.616 .42337 L
.62 .42208 L
.624 .4211 L
.628 .42076 L
.632 .42127 L
.636 .42264 L
.64 .42468 L
.644 .427 L
.648 .42921 L
.652 .43094 L
.656 .43199 L
.66 .43229 L
.664 .43187 L
.668 .43081 L
.672 .42912 L
.676 .42676 L
.68 .42365 L
.684 .4197 L
.688 .41491 L
.692 .40938 L
.696 .4033 L
.7 .39694 L
.704 .39056 L
.708 .38435 L
.712 .37837 L
.716 .37253 L
.72 .36666 L
.724 .36054 L
.728 .35397 L
.732 .34685 L
.736 .33918 L
.74 .3311 L
.744 .32282 L
.748 .31459 L
.752 .30666 L
.756 .29918 L
.76 .29222 L
.764 .28572 L
.768 .27954 L
.772 .27349 L
.776 .26733 L
.78 .26086 L
.784 .25395 L
.788 .2465 L
.792 .23855 L
.796 .23017 L
.8 .22151 L
Mistroke
.804 .21276 L
.808 .20412 L
.812 .19576 L
.816 .18786 L
.82 .18051 L
.824 .17378 L
.828 .16771 L
.832 .16225 L
.836 .15737 L
.84 .15298 L
.844 .14901 L
.848 .14536 L
.852 .14196 L
.856 .13874 L
.86 .13566 L
.864 .13269 L
.868 .1298 L
.872 .12699 L
.876 .12427 L
.88 .12164 L
.884 .11912 L
.888 .1167 L
.892 .11439 L
.896 .11219 L
.9 .11009 L
.904 .10805 L
.908 .10606 L
.912 .10409 L
.916 .10211 L
.92 .1001 L
.924 .09802 L
.928 .09585 L
.932 .0936 L
.936 .09123 L
.94 .08877 L
.944 .0862 L
.948 .08356 L
.952 .08086 L
.956 .07814 L
.96 .07541 L
.964 .07272 L
.968 .07008 L
.972 .06755 L
.976 .06513 L
.98 .06288 L
.984 .06079 L
.988 .05892 L
.992 .05725 L
.996 .05581 L
1 .0546 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00=oo`80009oo`04001oogoo0003Ool0
1000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00003Ool00`00Ool00006Ool01000Oomo
o`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomo
ogoo1@0000=oo`0000000P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000R
Ool00`00Oomoo`0_Ool00`00Oomoo`020002Ool00`00Oomoo`02Ool00`00Ool0000^Ool0029oo`L0
0003Ool0000000H00004Ool00000Ool600000goo0000000600000goo0000000400000goo00000003
00001Goo00000000Ool00P0000=oo`0000000P0000Eoo`00Oomoo`0002ioo`008WooH`0037oo000R
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoogoo0P000Woo00@007ooOomo
o`@0009oo`8000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol0000<Ool0029oo`8003moo`80019oo`X0011oo`008Woo00<007ooOol0?goo00<0
07ooOol03goo00<007ooOol01goo1@0037oo000ROol20010Ool00`00Oomoo`0?Ool00`00Oomoo`0H
Ool0029oo`80041oo`03001oogoo00ioo`03001oogoo01Uoo`002goo0P0017oo00<007ooOol00goo
0P000goo0`000goo00<007ooOol0@7oo00<007ooOol03Goo00<007ooOol06Goo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`80045oo`03001oogoo00aoo`03001oogoo01Yo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20011Ool00`00Oomoo`0<
Ool00`00Oomoo`0JOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0@7oo00<007ooOol037oo00<007ooOol06Woo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80049oo`03001oogoo00]oo`03001oogoo01Yoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool20004Ool20012Ool40003Ool00`00Oomoo`03Ool00`00Oomoo`0KOol0
00]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo045oo`800007Ool007ooOol007oo0000
17oo00<007ooOol06goo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool20015Ool01P00
Oomoo`00Ool000Aoo`03001oogoo01]oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`000Woo0P00AWoo0P000goo00@007ooOol001ioo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1:Ool01000Oomoo`007Woo000:Ool01000Oomoo`0027oo
00@007ooOol000Aoo`04001oogooOol2001;Ool01000Oomoo`007Woo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool00`00Oomoo`02001;Ool01000Oomoo`007Woo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool01000Oomoo`00CGoo0P007goo000;Ool2000:Ool20003Ool30003
Ool2001<Ool00`00Oomoo`0NOol0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo
0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomo
o`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000
Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool2
0004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Mo
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<0
07ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo
0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P00
1goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@00
0Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`04
0003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo
00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00
Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomo
ogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002
Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00
Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09
Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool2
0003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=o
o`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool2
0004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo05Ioo`8000ioo`00:7oo00<0
07ooOol0E7oo0P0047oo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001o
ogoo00moo`03001oogoo00moo`03001oogoo00Moo`<000Ioo`03001oogoo00Yoo`00:7oo00<007oo
Ool0CWoo0P005Woo000XOol00`00Oomoo`1<Ool2000HOol002Qoo`03001oogoo04Yoo`8001Yoo`00
:7oo00<007ooOol0BGoo0P006goo000XOol00`00Oomoo`18Ool2000LOol000]oo`8000Aoo`03001o
ogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo04Qoo`03001oogoo01]oo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo0019Ool00`00Oomoo`0L
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo0019Ool0
0`00Oomoo`0LOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo008004Moo`03001oogoo01eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomo
o`00Ool010000goo00<007ooOol0AWoo00<007ooOol07Goo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`001Woo00<007ooOol0AGoo00<007ooOol07Woo000;Ool2000:Ool2
0004Ool20002Ool50002Ool00`00Oomoo`14Ool00`00Oomoo`0OOol002Qoo`03001oogoo04=oo`80
025oo`00:7oo00<007ooOol0@Woo0P008Woo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003
Ool00`00Oomoo`12Ool00`00Oomoo`0QOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0@Goo0P008goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo041oo`8002Aoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool20011Ool00`00Oomoo`0SOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0?goo0P009Goo000@Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`03001oogoo03ioo`8002Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007oo
Ool0?Goo0P009goo000XOol00`00Oomoo`0mOol00`00Oomoo`0VOol002Qoo`03001oogoo03Ioo`80
00Aoo`03001oogoo02Moo`00:7oo>@000Woo1000:Woo000;Ool20004Ool00`00Oomoo`03Ool20003
Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D0
07ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo
1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo
0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
2goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo0080
07=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001UOol2000<Ool000]oo`80
00Qoo`D0009oo`03001oogoo069oo`<000eoo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`00
17oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo2P0017oo0P00
1Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Ool00000Ool000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`80
00Ioo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogooOol300000goo001oo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003
Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomo
ogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00D007ooOol0
07oo00@000=oo`03001oo`0000<000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001o
ogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03
001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo
00<0009oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P00
2Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Ao
o`<000Eoo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0EGoo0P006goo000LOol00`00Oomo
o`1DOol2000LOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool0
1@00Oomoogoo00000goo00<007ooOol00P000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03
001oogoo00Yoo`0077oo00<007ooOol0DWoo00<007ooOol07Goo000LOol2001COol00`00Oomoo`0M
Ool001aoo`03001oogoo055oo`03001oogoo01ioo`0077oo00<007ooOol0DGoo00<007ooOol07Woo
000LOol2001AOol00`00Oomoo`0OOol001aoo`03001oogoo04moo`80025oo`0077oo00<007ooOol0
Cgoo00<007ooOol087oo000LOol2001@Ool00`00Oomoo`0POol001aoo`03001oogoo04ioo`03001o
ogoo025oo`0077oo0P00CWoo0P008goo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomo
o`1=Ool00`00Oomoo`0ROol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
C7oo0P0097oo000:Ool01000Oomoo`002goo00<007ooOol00P00CGoo00<007ooOol08goo000:Ool0
1000Oomoo`002goo00@007ooOol004eoo`03001oogoo02Aoo`002Woo00@007ooOol000Moo`@000=o
o`03001oogoo04]oo`03001oogoo02Aoo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8004]o
o`03001oogoo02Eoo`002goo0P0027oo1@000Woo00<007ooOol0BWoo00<007ooOol09Goo000LOol0
0`00Oomoo`19Ool00`00Oomoo`0VOol001aoo`8004Uoo`03001oogoo02Moo`0077oo00<007ooOol0
B7oo00<007ooOol09goo000LOol20018Ool2000YOol001aoo`03001oogoo04Ioo`8002Yoo`0077oo
00<007ooOol0AWoo00<007ooOol0:Goo000LOol20016Ool2000[Ool001Ioo`<000=oo`03001oogoo
04Aoo`8002aoo`005goo00<007ooOol00Woo00<007ooOol0>7oo0P000Woo10000goo0P00;Goo000G
Ool00`00Oomoo`02Ooll000017oo000000000goo1000;Woo000GOol00`00Oomoo`02Ool2001cOol0
01Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001o
ogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo
079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol0
0P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo
00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(30227\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29824 m
.008 .29784 L
.012 .29936 L
.016 .29986 L
.02 .29915 L
.024 .29866 L
.028 .29822 L
.032 .2977 L
.036 .29774 L
.04 .29839 L
.044 .29929 L
.048 .29979 L
.052 .29962 L
.056 .29906 L
.06 .29828 L
.064 .2976 L
.068 .2975 L
.072 .29793 L
.076 .2987 L
.08 .29929 L
.084 .29936 L
.088 .29912 L
.092 .29862 L
.096 .29806 L
.1 .29776 L
.104 .29791 L
.108 .29846 L
.112 .2989 L
.116 .29891 L
.12 .29866 L
.124 .29835 L
.128 .29806 L
.132 .29786 L
.136 .29793 L
.14 .29841 L
.144 .29901 L
.148 .29918 L
.152 .29877 L
.156 .29813 L
.16 .29773 L
.164 .29763 L
.168 .29761 L
.172 .29779 L
.176 .29837 L
.18 .29911 L
.184 .29937 L
.188 .29885 L
.192 .29801 L
.196 .29751 L
.2 .29748 L
Mistroke
.204 .29761 L
.208 .29773 L
.212 .29808 L
.216 .29876 L
.22 .29926 L
.224 .29895 L
.228 .29791 L
.232 .297 L
.236 .29696 L
.24 .29763 L
.244 .29834 L
.248 .29863 L
.252 .29862 L
.256 .29859 L
.26 .29846 L
.264 .29798 L
.268 .29724 L
.272 .29675 L
.276 .29703 L
.28 .29794 L
.284 .29877 L
.288 .29888 L
.292 .29829 L
.296 .29766 L
.3 .29759 L
.304 .29803 L
.308 .2983 L
.312 .29784 L
.316 .29693 L
.32 .29654 L
.324 .29729 L
.328 .29868 L
.332 .29938 L
.336 .29861 L
.34 .29707 L
.344 .29634 L
.348 .29723 L
.352 .29874 L
.356 .29905 L
.36 .29749 L
.364 .29554 L
.368 .29545 L
.372 .29781 L
.376 .30065 L
.38 .30118 L
.384 .2986 L
.388 .29508 L
.392 .29378 L
.396 .29578 L
.4 .29899 L
Mistroke
.404 .30024 L
.408 .29838 L
.412 .29549 L
.416 .29481 L
.42 .29747 L
.424 .30126 L
.428 .3025 L
.432 .29952 L
.436 .29428 L
.44 .29082 L
.444 .29189 L
.448 .29668 L
.452 .30169 L
.456 .30352 L
.46 .30143 L
.464 .29745 L
.468 .29446 L
.472 .29401 L
.476 .29556 L
.48 .29744 L
.484 .29835 L
.488 .29806 L
.492 .29714 L
.496 .29623 L
.5 .29576 L
.504 .296 L
.508 .29723 L
.512 .29942 L
.516 .3017 L
.52 .30247 L
.524 .30028 L
.528 .29521 L
.532 .28946 L
.536 .28652 L
.54 .28902 L
.544 .29669 L
.548 .30596 L
.552 .31174 L
.556 .31038 L
.56 .30201 L
.564 .29064 L
.568 .28205 L
.572 .28052 L
.576 .2866 L
.58 .297 L
.584 .30664 L
.588 .31138 L
.592 .30997 L
.596 .30409 L
.6 .29692 L
Mistroke
.604 .29122 L
.608 .28812 L
.612 .28723 L
.616 .2876 L
.62 .28888 L
.624 .29162 L
.628 .29673 L
.632 .30434 L
.636 .31299 L
.64 .31973 L
.644 .32128 L
.648 .31557 L
.652 .30298 L
.656 .28651 L
.66 .27071 L
.664 .26002 L
.668 .25707 L
.672 .26188 L
.676 .27216 L
.68 .2845 L
.684 .29594 L
.688 .30508 L
.692 .31246 L
.696 .32004 L
.7 .33009 L
.704 .34403 L
.708 .36168 L
.712 .38119 L
.716 .39967 L
.72 .41423 L
.724 .42297 L
.728 .42562 L
.732 .42357 L
.736 .41937 L
.74 .41587 L
.744 .41539 L
.748 .41908 L
.752 .42665 L
.756 .43659 L
.76 .4466 L
.764 .45437 L
.768 .45815 L
.772 .45721 L
.776 .452 L
.78 .44394 L
.784 .43511 L
.788 .42767 L
.792 .42346 L
.796 .42362 L
.8 .42847 L
Mistroke
.804 .43751 L
.808 .44958 L
.812 .46311 L
.816 .47637 L
.82 .48773 L
.824 .49588 L
.828 .49992 L
.832 .49948 L
.836 .49466 L
.84 .48593 L
.844 .47406 L
.848 .4599 L
.852 .44435 L
.856 .42826 L
.86 .41239 L
.864 .39733 L
.868 .38356 L
.872 .37134 L
.876 .3608 L
.88 .35194 L
.884 .34466 L
.888 .33882 L
.892 .33426 L
.896 .33078 L
.9 .32819 L
.904 .3263 L
.908 .32495 L
.912 .32401 L
.916 .32337 L
.92 .32297 L
.924 .32277 L
.928 .32274 L
.932 .32286 L
.936 .32312 L
.94 .32351 L
.944 .32405 L
.948 .32474 L
.952 .32558 L
.956 .32655 L
.96 .32761 L
.964 .32873 L
.968 .32989 L
.972 .33104 L
.976 .33217 L
.98 .33322 L
.984 .33416 L
.988 .33495 L
.992 .33557 L
.996 .33598 L
1 .3362 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .56933 m
.008 .57723 L
.012 .57991 L
.016 .57723 L
.02 .57637 L
.024 .57721 L
.028 .57754 L
.032 .5772 L
.036 .57713 L
.04 .57722 L
.044 .57729 L
.048 .57725 L
.052 .57726 L
.056 .57724 L
.06 .57725 L
.064 .57722 L
.068 .57723 L
.072 .57722 L
.076 .57723 L
.08 .57722 L
.084 .57723 L
.088 .57723 L
.092 .57724 L
.096 .57723 L
.1 .57725 L
.104 .57726 L
.108 .57727 L
.112 .57725 L
.116 .57723 L
.12 .57721 L
.124 .5772 L
.128 .57719 L
.132 .57721 L
.136 .57723 L
.14 .57726 L
.144 .57727 L
.148 .57727 L
.152 .57726 L
.156 .57725 L
.16 .57724 L
.164 .57722 L
.168 .5772 L
.172 .5772 L
.176 .57721 L
.18 .57722 L
.184 .57723 L
.188 .57724 L
.192 .57725 L
.196 .57728 L
.2 .57728 L
Mistroke
.204 .57726 L
.208 .57723 L
.212 .57722 L
.216 .57722 L
.22 .57721 L
.224 .57719 L
.228 .5772 L
.232 .57722 L
.236 .57725 L
.24 .57725 L
.244 .57724 L
.248 .57723 L
.252 .57725 L
.256 .57727 L
.26 .57727 L
.264 .57724 L
.268 .57721 L
.272 .5772 L
.276 .57721 L
.28 .57722 L
.284 .5772 L
.288 .57718 L
.292 .57718 L
.296 .57722 L
.3 .57727 L
.304 .57729 L
.308 .57727 L
.312 .57724 L
.316 .57724 L
.32 .57726 L
.324 .57727 L
.328 .57724 L
.332 .57718 L
.336 .57714 L
.34 .57715 L
.344 .57721 L
.348 .57725 L
.352 .57722 L
.356 .57716 L
.36 .57714 L
.364 .57721 L
.368 .57733 L
.372 .57741 L
.376 .57737 L
.38 .57727 L
.384 .57719 L
.388 .57721 L
.392 .57727 L
.396 .57727 L
.4 .57715 L
Mistroke
.404 .57697 L
.408 .57688 L
.412 .57697 L
.416 .57721 L
.42 .57744 L
.424 .57751 L
.428 .57742 L
.432 .57729 L
.436 .57723 L
.44 .5773 L
.444 .5774 L
.448 .57739 L
.452 .57724 L
.456 .57702 L
.46 .57686 L
.464 .57688 L
.468 .57704 L
.472 .57724 L
.476 .57736 L
.48 .57734 L
.484 .57722 L
.488 .57708 L
.492 .57703 L
.496 .5771 L
.5 .57729 L
.504 .57753 L
.508 .57773 L
.512 .57777 L
.516 .57761 L
.52 .57727 L
.524 .5769 L
.528 .57665 L
.532 .57665 L
.536 .57689 L
.54 .57722 L
.544 .57743 L
.548 .5774 L
.552 .57712 L
.556 .57677 L
.56 .57658 L
.564 .57672 L
.568 .57717 L
.572 .57774 L
.576 .57819 L
.58 .57829 L
.584 .578 L
.588 .57746 L
.592 .57687 L
.596 .57647 L
.6 .57635 L
Mistroke
.604 .57653 L
.608 .57691 L
.612 .57737 L
.616 .57782 L
.62 .57819 L
.624 .57839 L
.628 .57836 L
.632 .57802 L
.636 .57733 L
.64 .57634 L
.644 .57524 L
.648 .57428 L
.652 .57375 L
.656 .57387 L
.66 .5747 L
.664 .57613 L
.668 .57791 L
.672 .57975 L
.676 .58133 L
.68 .58248 L
.684 .5831 L
.688 .58318 L
.692 .58277 L
.696 .58186 L
.7 .58043 L
.704 .57839 L
.708 .57567 L
.712 .57225 L
.716 .56816 L
.72 .56355 L
.724 .55862 L
.728 .5536 L
.732 .54865 L
.736 .54387 L
.74 .53922 L
.744 .53461 L
.748 .52986 L
.752 .52481 L
.756 .51933 L
.76 .5134 L
.764 .50709 L
.768 .50052 L
.772 .49391 L
.776 .48744 L
.78 .48127 L
.784 .4755 L
.788 .47011 L
.792 .46505 L
.796 .46017 L
.8 .4553 L
Mistroke
.804 .45026 L
.808 .44493 L
.812 .4392 L
.816 .43305 L
.82 .42651 L
.824 .41969 L
.828 .4127 L
.832 .4057 L
.836 .39884 L
.84 .39227 L
.844 .38608 L
.848 .38036 L
.852 .37514 L
.856 .37043 L
.86 .36619 L
.864 .36239 L
.868 .35896 L
.872 .35583 L
.876 .35293 L
.88 .35021 L
.884 .34763 L
.888 .34514 L
.892 .34273 L
.896 .34038 L
.9 .3381 L
.904 .33588 L
.908 .33374 L
.912 .33167 L
.916 .32968 L
.92 .32776 L
.924 .3259 L
.928 .3241 L
.932 .32232 L
.936 .32054 L
.94 .31874 L
.944 .31689 L
.948 .31496 L
.952 .31293 L
.956 .31078 L
.96 .3085 L
.964 .30608 L
.968 .30351 L
.972 .30081 L
.976 .29798 L
.98 .29505 L
.984 .29202 L
.988 .28893 L
.992 .2858 L
.996 .28266 L
1 .27953 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43021 L
.012 .43021 L
.016 .42998 L
.02 .42968 L
.024 .42979 L
.028 .42981 L
.032 .42973 L
.036 .4296 L
.04 .42965 L
.044 .42964 L
.048 .42965 L
.052 .42961 L
.056 .42961 L
.06 .42955 L
.064 .42952 L
.068 .42945 L
.072 .42941 L
.076 .42934 L
.08 .42932 L
.084 .42928 L
.088 .42928 L
.092 .42926 L
.096 .42927 L
.1 .42925 L
.104 .42923 L
.108 .42917 L
.112 .42912 L
.116 .42904 L
.12 .42899 L
.124 .42894 L
.128 .42892 L
.132 .42891 L
.136 .42892 L
.14 .42892 L
.144 .42891 L
.148 .42886 L
.152 .42882 L
.156 .42876 L
.16 .42871 L
.164 .42865 L
.168 .42861 L
.172 .42857 L
.176 .42856 L
.18 .42855 L
.184 .42853 L
.188 .42851 L
.192 .4285 L
.196 .42848 L
.2 .42844 L
Mistroke
.204 .42838 L
.208 .42833 L
.212 .42829 L
.216 .42826 L
.22 .42822 L
.224 .42817 L
.228 .42813 L
.232 .42812 L
.236 .42812 L
.24 .4281 L
.244 .42806 L
.248 .42802 L
.252 .428 L
.256 .42799 L
.26 .42796 L
.264 .42791 L
.268 .42784 L
.272 .4278 L
.276 .42777 L
.28 .42774 L
.284 .42768 L
.288 .42762 L
.292 .4276 L
.296 .42763 L
.3 .42766 L
.304 .42765 L
.308 .42759 L
.312 .42752 L
.316 .42748 L
.32 .42747 L
.324 .42746 L
.328 .4274 L
.332 .42729 L
.336 .4272 L
.34 .42719 L
.344 .42723 L
.348 .42724 L
.352 .42718 L
.356 .42706 L
.36 .427 L
.364 .42706 L
.368 .42719 L
.372 .42726 L
.376 .42719 L
.38 .42702 L
.384 .42688 L
.388 .42686 L
.392 .42691 L
.396 .42689 L
.4 .42672 L
Mistroke
.404 .42646 L
.408 .42631 L
.412 .42639 L
.416 .42665 L
.42 .4269 L
.424 .42697 L
.428 .42683 L
.432 .42662 L
.436 .42653 L
.44 .42658 L
.444 .42667 L
.448 .42664 L
.452 .42641 L
.456 .4261 L
.46 .42587 L
.464 .42585 L
.468 .42603 L
.472 .42626 L
.476 .42638 L
.48 .42633 L
.484 .42613 L
.488 .42592 L
.492 .42582 L
.496 .42588 L
.5 .42609 L
.504 .42637 L
.508 .42658 L
.512 .4266 L
.516 .42636 L
.52 .42591 L
.524 .42541 L
.528 .42507 L
.532 .42504 L
.536 .42531 L
.54 .42569 L
.544 .42593 L
.548 .42585 L
.552 .42547 L
.556 .425 L
.56 .42473 L
.564 .42487 L
.568 .4254 L
.572 .4261 L
.576 .42662 L
.58 .42671 L
.584 .42632 L
.588 .4256 L
.592 .42484 L
.596 .42431 L
.6 .42414 L
Mistroke
.604 .42433 L
.608 .42477 L
.612 .42532 L
.616 .42585 L
.62 .42627 L
.624 .42649 L
.628 .42642 L
.632 .42596 L
.636 .42507 L
.64 .42381 L
.644 .42241 L
.648 .42118 L
.652 .42049 L
.656 .4206 L
.66 .4216 L
.664 .42336 L
.668 .42556 L
.672 .42781 L
.676 .42975 L
.68 .43115 L
.684 .43188 L
.688 .43195 L
.692 .4314 L
.696 .43024 L
.7 .42842 L
.704 .42585 L
.708 .42243 L
.712 .41813 L
.716 .413 L
.72 .40723 L
.724 .40107 L
.728 .39478 L
.732 .38859 L
.736 .3826 L
.74 .37679 L
.744 .37102 L
.748 .36508 L
.752 .35876 L
.756 .35192 L
.76 .34451 L
.764 .33662 L
.768 .32843 L
.772 .32017 L
.776 .31209 L
.78 .3044 L
.784 .29719 L
.788 .29047 L
.792 .28416 L
.796 .27807 L
.8 .27199 L
Mistroke
.804 .26571 L
.808 .25905 L
.812 .25191 L
.816 .24424 L
.82 .2361 L
.824 .2276 L
.828 .21889 L
.832 .21018 L
.836 .20164 L
.84 .19345 L
.844 .18576 L
.848 .17864 L
.852 .17215 L
.856 .16629 L
.86 .16104 L
.864 .15632 L
.868 .15207 L
.872 .1482 L
.876 .14462 L
.88 .14128 L
.884 .1381 L
.888 .13505 L
.892 .13212 L
.896 .12927 L
.9 .12652 L
.904 .12386 L
.908 .12132 L
.912 .1189 L
.916 .11661 L
.92 .11443 L
.924 .11239 L
.928 .11044 L
.932 .10859 L
.936 .1068 L
.94 .10506 L
.944 .10333 L
.948 .10159 L
.952 .09981 L
.956 .098 L
.96 .09613 L
.964 .09421 L
.968 .09223 L
.972 .09021 L
.976 .08817 L
.98 .08612 L
.984 .08409 L
.988 .0821 L
.992 .08017 L
.996 .07834 L
1 .07661 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oo`000002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oo`000002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool30003Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo035oo`03001oogoo0080009oo`8000=oo`03001oo`0002aoo`008Woo1@0000=oo`000000
2P0000=oo`0000001`0000=oo`0000001P0000=oo`0000000P0000=oo`0000001P0000]oo`00001o
o`00Ool007oo001oo`00009oo`04001oogoo000[Ool0029oof<000aoo`008Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`800004Ool000000002Ool20002Ool0
1@00Ool007oo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00<007ooOol02Woo000ROol2000lOol20004Ool00`00Oomoo`0AOol7000@Ool0029oo`03001o
ogoo045oo`03001oogoo011oo`03001oogoo00Aoo`D000aoo`008Woo0P00@goo00<007ooOol03Woo
00<007ooOol05Woo000ROol20013Ool00`00Oomoo`0>Ool00`00Oomoo`0FOol000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`03001oogoo049oo`03001oogoo00eoo`03001oogoo01Moo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20013Ool00`00Oomoo`0=Ool0
0`00Oomoo`0GOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00A7oo
00<007ooOol037oo00<007ooOol05goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo04=oo`03001oogoo00]oo`03001oogoo01Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool20014Ool00`00Oomoo`0;Ool00`00Oomoo`0HOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00A7oo00@007oo000000Yoo`03001oogoo
01Qoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0A7oo00<007oo00000goo0P00
1Goo00<007ooOol067oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool20018Ool00`00
Oomoo`020005Ool00`00Oomoo`0HOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool0009oo`8004Qoo`03001oo`00009oo`05001oogooOol0000KOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0B7oo00D007ooOomoo`0000=oo`03001oogoo
01Uoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00CGoo00D007ooOomo
o`0001]oo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00CWoo00<0
07oo000077oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00Cgoo00<0
07oo000077oo000;Ool2000:Ool20003Ool30003Ool2001>Ool3000LOol0029oo`03001oogoo06ao
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
1Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]
Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003
Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=o
o`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05
Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<0
07ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool0
0`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo
00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo
06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo
00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo
00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P00
0Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@0
07ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`00
00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00
Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo
00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool5
0002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D0
07ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`00
0Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000
Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@0
07ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005
Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001o
ogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03
001oogoo05Moo`8000eoo`00:7oo00<007ooOol0EWoo0P003Woo000XOomM000<Ool002Qoo`03001o
ogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo00Uoo`<000Ao
o`03001oogoo00Yoo`00:7oo00<007ooOol0D7oo0`004goo000XOol00`00Oomoo`1>Ool3000EOol0
02Qoo`03001oogoo04eoo`8001Moo`00:7oo00<007ooOol0C7oo00<007ooOol05goo000XOol00`00
Oomoo`1;Ool00`00Oomoo`0HOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=o
o`03001oogoo04Yoo`8001Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00
Ool000=oo`04001oogoo001<Ool00`00Oomoo`0IOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogoo001;Ool00`00Oomoo`0JOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008004Uoo`8001aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0B7oo00<007ooOol06goo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0Agoo
00<007ooOol077oo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`16Ool2000NOol0
02Qoo`03001oogoo04Ioo`03001oogoo01eoo`00:7oo00<007ooOol0AGoo00<007ooOol07Woo000A
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`14Ool00`00Oomoo`0OOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0A7oo00<007ooOol0
7goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo04=oo`03
001oogoo021oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20013Ool2
000ROol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0@Woo
00<007ooOol08Goo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo045o
o`03001oogoo029oo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0@7oo00<007oo
Ool08goo000XOol00`00Oomoo`0oOol00`00Oomoo`0TOol002Qoo`03001oogoo03Qoo`8000Aoo`80
02Ioo`00:7oo?00000=oo`0000000P00:7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003
Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomo
o`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
1Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eo
o`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo
0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P00
17oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`00
2Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03
001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`00
0goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=
Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoo`00Ool01@000Woo00@007ooOol000Eo
o`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol00P000goo00@007ooOol0
009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo0`001Goo
00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool300000goo001oo`040003
Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P00
17oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo
00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo0P000goo00<007oo00001Woo
00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo
00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`80009oo`80009oo`<0009oo`D000=oo`80
00Ioo`0077oo00<007ooOol0F7oo0P0067oo000LOol00`00Oomoo`1GOol2000IOol001aoofT000ao
o`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00@007oo
Oomoo`<00003Ool007oo009oo`05001oogooOol00004Ool00`00Oomoo`0:Ool001aoo`03001oogoo
05Eoo`03001oogoo01Yoo`0077oo0P00EGoo00<007ooOol06goo000LOol00`00Oomoo`1DOol00`00
Oomoo`0KOol001aoo`03001oogoo05=oo`03001oogoo01aoo`0077oo0P00E7oo00<007ooOol077oo
000LOol00`00Oomoo`1BOol00`00Oomoo`0MOol001aoo`03001oogoo059oo`03001oogoo01eoo`00
77oo0P00Dgoo00<007ooOol07Goo000LOol00`00Oomoo`1AOol00`00Oomoo`0NOol001aoo`80055o
o`03001oogoo01moo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0Cgoo0P008Goo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo04moo`03001oogoo021oo`00
2Woo00@007ooOol000]oo`03001oogoo008004moo`80029oo`002Woo00@007ooOol000]oo`04001o
ogoo001@Ool00`00Oomoo`0QOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1=Ool00`00
Oomoo`0ROol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001>Ool00`00Oomoo`0ROol000]o
o`8000Qoo`D0009oo`03001oogoo04aoo`8002Aoo`0077oo00<007ooOol0C7oo00<007ooOol08goo
000LOol2001<Ool00`00Oomoo`0TOol001aoo`03001oogoo04]oo`03001oogoo02Aoo`0077oo0P00
Bgoo00<007ooOol09Goo000LOol00`00Oomoo`19Ool2000WOol001aoo`03001oogoo04Qoo`8002Qo
o`0077oo0P00BGoo00<007ooOol09goo000FOol30003Ool00`00Oomoo`17Ool2000YOol001Moo`03
001oogoo009oo`03001oogoo03]oo`80009oo`@000=oo`8002Yoo`005goo00<007ooOol00Woo?P00
00=oo`0000000P000Woo1@00:goo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001o
ogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<0
00=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo
00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;
Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001o
ogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03
001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(30394\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29517 m
.008 .29702 L
.012 .29932 L
.016 .30027 L
.02 .29921 L
.024 .29881 L
.028 .2992 L
.032 .29886 L
.036 .2982 L
.04 .29812 L
.044 .29853 L
.048 .2989 L
.052 .29889 L
.056 .29868 L
.06 .29851 L
.064 .29836 L
.068 .29846 L
.072 .29882 L
.076 .29914 L
.08 .29915 L
.084 .29872 L
.088 .29815 L
.092 .29784 L
.096 .29781 L
.1 .29816 L
.104 .29877 L
.108 .29931 L
.112 .29942 L
.116 .2989 L
.12 .29813 L
.124 .29767 L
.128 .29768 L
.132 .29807 L
.136 .29857 L
.14 .29901 L
.144 .29919 L
.148 .29882 L
.152 .29802 L
.156 .2974 L
.16 .29749 L
.164 .29821 L
.168 .29889 L
.172 .29914 L
.176 .29902 L
.18 .29865 L
.184 .29802 L
.188 .29729 L
.192 .29699 L
.196 .29753 L
.2 .29861 L
Mistroke
.204 .29935 L
.208 .29924 L
.212 .29857 L
.216 .29799 L
.22 .29774 L
.224 .29755 L
.228 .2974 L
.232 .29758 L
.236 .29825 L
.24 .29896 L
.244 .29906 L
.248 .29843 L
.252 .29766 L
.256 .29735 L
.26 .29754 L
.264 .29779 L
.268 .29786 L
.272 .29797 L
.276 .29837 L
.28 .29886 L
.284 .29889 L
.288 .29817 L
.292 .29711 L
.296 .29655 L
.3 .29696 L
.304 .29797 L
.308 .29871 L
.312 .29864 L
.316 .298 L
.32 .2976 L
.324 .29789 L
.328 .29843 L
.332 .29838 L
.336 .29745 L
.34 .29643 L
.344 .29645 L
.348 .29772 L
.352 .2991 L
.356 .2992 L
.36 .29788 L
.364 .29655 L
.368 .2967 L
.372 .29823 L
.376 .29935 L
.38 .29851 L
.384 .29618 L
.388 .2947 L
.392 .2959 L
.396 .29906 L
.4 .30136 L
Mistroke
.404 .30054 L
.408 .2972 L
.412 .29436 L
.416 .29456 L
.42 .29743 L
.424 .3 L
.428 .29963 L
.432 .29666 L
.436 .2941 L
.44 .29478 L
.444 .29856 L
.448 .30231 L
.452 .30263 L
.456 .29885 L
.46 .29367 L
.464 .29094 L
.468 .29252 L
.472 .29706 L
.476 .30126 L
.48 .30254 L
.484 .3007 L
.488 .29758 L
.492 .29533 L
.496 .29492 L
.5 .29586 L
.504 .29709 L
.508 .29783 L
.512 .29787 L
.516 .29731 L
.52 .29633 L
.524 .29531 L
.528 .29499 L
.532 .29621 L
.536 .2991 L
.54 .30244 L
.544 .304 L
.548 .30186 L
.552 .29605 L
.556 .2892 L
.56 .28531 L
.564 .2874 L
.568 .29528 L
.572 .30525 L
.576 .31195 L
.58 .31145 L
.584 .3036 L
.588 .29223 L
.592 .28301 L
.596 .28037 L
.6 .28521 L
Mistroke
.604 .29475 L
.608 .30431 L
.612 .30988 L
.616 .30992 L
.62 .30561 L
.624 .29955 L
.628 .2941 L
.632 .29032 L
.636 .28802 L
.64 .28668 L
.644 .28638 L
.648 .28805 L
.652 .29283 L
.656 .30099 L
.66 .31106 L
.664 .31993 L
.668 .32396 L
.672 .32055 L
.676 .30948 L
.68 .29324 L
.684 .27622 L
.688 .26305 L
.692 .25695 L
.696 .2587 L
.7 .26662 L
.704 .27762 L
.708 .28861 L
.712 .2978 L
.716 .30524 L
.72 .31257 L
.724 .32207 L
.728 .33546 L
.732 .35299 L
.736 .37321 L
.74 .39337 L
.744 .41038 L
.748 .42191 L
.752 .4271 L
.756 .42683 L
.76 .42336 L
.764 .41955 L
.768 .41805 L
.772 .42046 L
.776 .42705 L
.78 .43669 L
.784 .44733 L
.788 .45661 L
.792 .46246 L
.796 .46371 L
.8 .46028 L
Mistroke
.804 .45317 L
.808 .4442 L
.812 .43554 L
.816 .42926 L
.82 .42691 L
.824 .42928 L
.828 .43628 L
.832 .44708 L
.836 .46029 L
.84 .47421 L
.844 .4871 L
.848 .49746 L
.852 .50413 L
.856 .50648 L
.86 .50431 L
.864 .49789 L
.868 .48778 L
.872 .4748 L
.876 .45982 L
.88 .44378 L
.884 .42751 L
.888 .41175 L
.892 .39704 L
.896 .38375 L
.9 .37209 L
.904 .36214 L
.908 .35387 L
.912 .34718 L
.916 .34193 L
.92 .33791 L
.924 .33491 L
.928 .33273 L
.932 .33117 L
.936 .33009 L
.94 .32938 L
.944 .32895 L
.948 .32873 L
.952 .32869 L
.956 .32877 L
.96 .32894 L
.964 .3292 L
.968 .32956 L
.972 .33001 L
.976 .33058 L
.98 .33121 L
.984 .33189 L
.988 .33259 L
.992 .33327 L
.996 .33394 L
1 .33456 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57565 m
.008 .57661 L
.012 .57711 L
.016 .57696 L
.02 .57675 L
.024 .57667 L
.028 .57681 L
.032 .57684 L
.036 .57684 L
.04 .57679 L
.044 .57683 L
.048 .57681 L
.052 .57681 L
.056 .57678 L
.06 .57679 L
.064 .57678 L
.068 .5768 L
.072 .5768 L
.076 .57682 L
.08 .57682 L
.084 .57683 L
.088 .57682 L
.092 .57682 L
.096 .5768 L
.1 .57679 L
.104 .57678 L
.108 .57678 L
.112 .57678 L
.116 .57679 L
.12 .57681 L
.124 .57684 L
.128 .57684 L
.132 .57684 L
.136 .57682 L
.14 .57681 L
.144 .57678 L
.148 .57676 L
.152 .57675 L
.156 .57677 L
.16 .5768 L
.164 .57682 L
.168 .57683 L
.172 .57684 L
.176 .57684 L
.18 .57684 L
.184 .57681 L
.188 .57678 L
.192 .57677 L
.196 .57677 L
.2 .57677 L
Mistroke
.204 .57678 L
.208 .57679 L
.212 .57681 L
.216 .57683 L
.22 .57684 L
.224 .57683 L
.228 .57682 L
.232 .57681 L
.236 .57681 L
.24 .57679 L
.244 .57677 L
.248 .57675 L
.252 .57677 L
.256 .5768 L
.26 .57681 L
.264 .5768 L
.268 .5768 L
.272 .5768 L
.276 .57682 L
.28 .57683 L
.284 .57683 L
.288 .57681 L
.292 .5768 L
.296 .5768 L
.3 .5768 L
.304 .57678 L
.308 .57674 L
.312 .57673 L
.316 .57675 L
.32 .5768 L
.324 .57684 L
.328 .57684 L
.332 .57682 L
.336 .5768 L
.34 .57683 L
.344 .57686 L
.348 .57685 L
.352 .5768 L
.356 .57673 L
.36 .57671 L
.364 .57676 L
.368 .57682 L
.372 .57682 L
.376 .57675 L
.38 .57667 L
.384 .57668 L
.388 .57679 L
.392 .57692 L
.396 .57696 L
.4 .5769 L
Mistroke
.404 .57681 L
.408 .57678 L
.412 .57684 L
.416 .57691 L
.42 .57687 L
.424 .5767 L
.428 .5765 L
.432 .57643 L
.436 .57655 L
.44 .57678 L
.444 .57697 L
.448 .577 L
.452 .57691 L
.456 .57683 L
.46 .57684 L
.464 .57694 L
.468 .57703 L
.472 .57699 L
.476 .57682 L
.48 .57659 L
.484 .57644 L
.488 .57646 L
.492 .5766 L
.496 .57679 L
.5 .5769 L
.504 .5769 L
.508 .57678 L
.512 .57664 L
.516 .57656 L
.52 .5766 L
.524 .57678 L
.528 .57705 L
.532 .57729 L
.536 .57739 L
.54 .57726 L
.544 .57693 L
.548 .57653 L
.552 .57625 L
.556 .57623 L
.56 .57645 L
.564 .57678 L
.568 .57701 L
.572 .57697 L
.576 .57668 L
.58 .57631 L
.584 .57609 L
.588 .57619 L
.592 .57661 L
.596 .57719 L
.6 .57767 L
Mistroke
.604 .57785 L
.608 .57765 L
.612 .57718 L
.616 .57663 L
.62 .57619 L
.624 .57598 L
.628 .57604 L
.632 .5763 L
.636 .5767 L
.64 .57715 L
.644 .57759 L
.648 .57793 L
.652 .57808 L
.656 .57791 L
.66 .57736 L
.664 .57644 L
.668 .5753 L
.672 .57419 L
.676 .57341 L
.68 .57322 L
.684 .57373 L
.688 .57489 L
.692 .57651 L
.696 .57831 L
.7 .57999 L
.704 .58135 L
.708 .58226 L
.712 .5827 L
.716 .58267 L
.72 .58217 L
.724 .58117 L
.728 .57957 L
.732 .5773 L
.736 .57429 L
.74 .57058 L
.744 .56626 L
.748 .56154 L
.752 .55662 L
.756 .55171 L
.76 .54693 L
.764 .5423 L
.768 .53775 L
.772 .53312 L
.776 .52825 L
.78 .523 L
.784 .5173 L
.788 .51117 L
.792 .50472 L
.796 .49812 L
.8 .49158 L
Mistroke
.804 .48526 L
.808 .4793 L
.812 .47373 L
.816 .46853 L
.82 .46357 L
.824 .45871 L
.828 .45378 L
.832 .44862 L
.836 .44311 L
.84 .4372 L
.844 .43088 L
.848 .42421 L
.852 .4173 L
.856 .41029 L
.86 .40333 L
.864 .39656 L
.868 .39011 L
.872 .38406 L
.876 .37849 L
.88 .37341 L
.884 .36882 L
.888 .36467 L
.892 .36091 L
.896 .35748 L
.9 .35431 L
.904 .35134 L
.908 .34851 L
.912 .34577 L
.916 .3431 L
.92 .34047 L
.924 .33788 L
.928 .33532 L
.932 .33279 L
.936 .33031 L
.94 .32786 L
.944 .32545 L
.948 .32308 L
.952 .32073 L
.956 .31839 L
.96 .31604 L
.964 .31367 L
.968 .31125 L
.972 .30876 L
.976 .30619 L
.98 .30354 L
.984 .30078 L
.988 .29794 L
.992 .295 L
.996 .29198 L
1 .28891 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42429 L
.012 .42988 L
.016 .43177 L
.02 .42977 L
.024 .42916 L
.028 .42976 L
.032 .43001 L
.036 .42975 L
.04 .42967 L
.044 .42967 L
.048 .42965 L
.052 .42953 L
.056 .42949 L
.06 .42945 L
.064 .42947 L
.068 .42945 L
.072 .42947 L
.076 .42943 L
.08 .42941 L
.084 .42935 L
.088 .42931 L
.092 .42924 L
.096 .42921 L
.1 .42916 L
.104 .42914 L
.108 .42911 L
.112 .42909 L
.116 .42907 L
.12 .42906 L
.124 .42904 L
.128 .42902 L
.132 .42898 L
.136 .42893 L
.14 .42887 L
.144 .42882 L
.148 .42876 L
.152 .42873 L
.156 .42872 L
.16 .42872 L
.164 .42871 L
.168 .4287 L
.172 .42867 L
.176 .42863 L
.18 .42859 L
.184 .42853 L
.188 .42847 L
.192 .42843 L
.196 .4284 L
.2 .42838 L
Mistroke
.204 .42834 L
.208 .42831 L
.212 .42831 L
.216 .42831 L
.22 .42829 L
.224 .42825 L
.228 .4282 L
.232 .42816 L
.236 .42812 L
.24 .42807 L
.244 .42801 L
.248 .42797 L
.252 .42795 L
.256 .42794 L
.26 .42792 L
.264 .42788 L
.268 .42785 L
.272 .42784 L
.276 .42784 L
.28 .42782 L
.284 .42777 L
.288 .4277 L
.292 .42765 L
.296 .42763 L
.3 .4276 L
.304 .42755 L
.308 .42748 L
.312 .42742 L
.316 .42742 L
.32 .42745 L
.324 .42746 L
.328 .42743 L
.332 .42737 L
.336 .42732 L
.34 .42731 L
.344 .42733 L
.348 .4273 L
.352 .4272 L
.356 .42708 L
.36 .42702 L
.364 .42703 L
.368 .42707 L
.372 .42705 L
.376 .42694 L
.38 .42682 L
.384 .42681 L
.388 .4269 L
.392 .42702 L
.396 .42704 L
.4 .42693 L
Mistroke
.404 .42678 L
.408 .42672 L
.412 .42677 L
.416 .42683 L
.42 .42674 L
.424 .4265 L
.428 .42622 L
.432 .4261 L
.436 .42621 L
.44 .42647 L
.444 .42667 L
.448 .42669 L
.452 .42655 L
.456 .42641 L
.46 .42639 L
.464 .42648 L
.468 .42655 L
.472 .42648 L
.476 .42623 L
.48 .42592 L
.484 .42571 L
.488 .42569 L
.492 .42584 L
.496 .42604 L
.5 .42615 L
.504 .42611 L
.508 .42594 L
.512 .42573 L
.516 .4256 L
.52 .42563 L
.524 .42582 L
.528 .42612 L
.532 .42638 L
.536 .42646 L
.54 .42627 L
.544 .42583 L
.548 .42531 L
.552 .42494 L
.556 .42487 L
.56 .42512 L
.564 .42549 L
.568 .42574 L
.572 .42567 L
.576 .42528 L
.58 .42479 L
.584 .42448 L
.588 .42458 L
.592 .42507 L
.596 .42575 L
.6 .42632 L
Mistroke
.604 .42651 L
.608 .42623 L
.612 .42562 L
.616 .4249 L
.62 .42432 L
.624 .42403 L
.628 .42406 L
.632 .42436 L
.636 .42482 L
.64 .42536 L
.644 .42588 L
.648 .42627 L
.652 .42642 L
.656 .42618 L
.66 .42546 L
.664 .42428 L
.668 .42283 L
.672 .42142 L
.676 .42042 L
.68 .42015 L
.684 .42075 L
.688 .42217 L
.692 .42416 L
.696 .42637 L
.7 .42843 L
.704 .43009 L
.708 .43119 L
.712 .43171 L
.716 .43164 L
.72 .43098 L
.724 .4297 L
.728 .42768 L
.732 .42481 L
.736 .42104 L
.74 .41637 L
.744 .41096 L
.748 .40505 L
.752 .39889 L
.756 .39275 L
.76 .38677 L
.764 .38097 L
.768 .37528 L
.772 .36949 L
.776 .3634 L
.78 .35683 L
.784 .3497 L
.788 .34205 L
.792 .33399 L
.796 .32576 L
.8 .31759 L
Mistroke
.804 .30971 L
.808 .30227 L
.812 .29533 L
.816 .28883 L
.82 .28265 L
.824 .27659 L
.828 .27045 L
.832 .26402 L
.836 .25716 L
.84 .24979 L
.844 .24193 L
.848 .23363 L
.852 .22505 L
.856 .21634 L
.86 .20771 L
.864 .19932 L
.868 .19135 L
.872 .1839 L
.876 .17705 L
.88 .17084 L
.884 .16526 L
.888 .16026 L
.892 .15578 L
.896 .15175 L
.9 .1481 L
.904 .14473 L
.908 .1416 L
.912 .13866 L
.916 .13588 L
.92 .13324 L
.924 .13073 L
.928 .12837 L
.932 .12616 L
.936 .12412 L
.94 .12225 L
.944 .12055 L
.948 .11903 L
.952 .11766 L
.956 .11644 L
.96 .11533 L
.964 .11431 L
.968 .11333 L
.972 .11237 L
.976 .11138 L
.98 .11033 L
.984 .1092 L
.988 .10796 L
.992 .10661 L
.996 .10513 L
1 .10352 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`05001oogoo001oo`020003Ool01000Oomoo`000Woo00@007oo
Ool0009oo`05001oogooOol00003Ool00`00Ool000030003Ool01000Oomoo`001Goo000;Ool2000:
Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@0
07ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`040003Ool01000
Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00003Ool00`00Ool00006Ool01000Oomoo`00
1Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo
1@000goo0P0000=oo`00Ool0100017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol0
0`00Oomoo`0dOol00`00Oomoo`020002Ool20003Ool00`00Ool0000YOol0029oo`80009oo`03001o
o`0000@00004Ool00000Ool200000goo0000000C00000goo00000002000017oo000007oo1@0000Qo
o`00001oo`00Ool007oo0P0000Aoo`00Ool0009oo`8002Qoo`008WooH`0037oo000ROol01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoo`000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo0`0000Uoo`00001oo`00Ool0
07oo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000aoo`008Woo0P00?goo0P0017oo00<007ooOol04Woo0`0047oo000ROol00`00Oomo
o`14Ool00`00Oomoo`0@Ool20003Ool4000<Ool0029oo`8004Eoo`03001oogoo00moo`03001oogoo
01=oo`008Woo0P00AGoo00<007ooOol03goo00<007ooOol04goo000;Ool20004Ool00`00Oomoo`03
Ool20003Ool30003Ool00`00Oomoo`14Ool00`00Oomoo`0>Ool00`00Oomoo`0DOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00AWoo00<007ooOol03Goo00<007ooOol0
57oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8004Ioo`03001oogoo
00aoo`03001oogoo01Eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`15Ool00`00Oomoo`0<Ool00`00Oomoo`0EOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P00Agoo00<007ooOol02goo00<007ooOol05Goo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000Aoo`8004Moo`03001oo`0000]oo`03001oogoo01Eoo`002goo
0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0AWoo0P0000=oo`00Ool00Woo00<007ooOol0
0goo00<007ooOol05Woo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001:Ool01P00
Oomoo`00Ool000Aoo`03001oogoo01Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`000Woo0P00Bgoo00D007oo001oo`0000Aoo`03001oogoo01Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1:Ool20003Ool01000Oomoo`006Goo000:
Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001<Ool01@00Oomoogoo00000Woo
00<007ooOol05goo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001@
Ool01000Oomoo`006Goo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00
DGoo00@007ooOol001Uoo`002goo0P002Woo0P000goo0`000goo0P00DGoo0P006Woo000ROol00`00
Oomoo`1@Ool2000JOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P00
0goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol0
0`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05
001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000
Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=o
o`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool2
0004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Ao
o`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00
Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<0
00=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007oo
Oomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=o
o`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=
Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool0
1000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo
0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol0
17oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol0
00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06
001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo
00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol0
00Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006
Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004
Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo
0P001Woo000XOol00`00Oomoo`1IOol00`00Oomoo`0:Ool002Qoo`03001oogoo05Moo`8000eoo`00
:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?
Ool00`00Oomoo`0;Ool20003Ool00`00Oomoo`0:Ool002Qoo`03001oogoo059oo`80019oo`00:7oo
00<007ooOol0DGoo0P004goo000XOol00`00Oomoo`1?Ool2000EOol002Qoo`03001oogoo04ioo`80
01Ioo`00:7oo00<007ooOol0CGoo0P005goo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003
Ool30003Ool00`00Oomoo`1=Ool00`00Oomoo`0FOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00H007ooOol007oo0003Ool01000Oomoo`00CWoo00<007ooOol05goo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00CGoo0P006Goo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001<Ool00`00Oomoo`0HOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo04Yo
o`8001Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001o
ogoo04Yoo`03001oogoo01Uoo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0BGoo
00<007ooOol06Woo000XOol00`00Oomoo`18Ool00`00Oomoo`0KOol002Qoo`03001oogoo04Moo`80
01eoo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0Agoo00<007ooOol0
77oo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo04Ioo`03
001oogoo01eoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`16Ool00`00Oomoo`0MOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00AWoo00<007ooOol07Woo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo04Aoo`03001oogoo01moo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004
Ool00`00Oomoo`13Ool2000QOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo049o
o`80029oo`00:7oo00<007ooOol0@Woo00<007ooOol08Goo000XOol00`00Oomoo`0jOol30003Ool2
000TOol002Qooch00003Ool0000000<002Eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogoo
Ool00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05
Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006ao
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yo
o`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`80
00Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol0
00Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool0
0`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<0
00=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P00
3Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool30002Ool01000Oomoo`001Goo000LOol2000=Ool40003Ool01000Oomoo`00
2Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@0
07ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`04001oogoo
Ool60003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`00
27oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomo
o`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007oo00000P00
00=oo`00Ool01Goo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo
0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Eoo`@0009oo`D0
00=oo`8000Ioo`0077oo00<007ooOol0Fgoo0P005Goo000LOol00`00Oomoo`1JOol2000FOol001ao
ofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`80009oo`05001oogooOol00004Ool00`00Oomoo`0:Ool001aoo`03001o
ogoo05Qoo`03001oogoo01Moo`0077oo0P00F7oo00<007ooOol067oo000LOol00`00Oomoo`1GOol0
0`00Oomoo`0HOol001aoo`03001oogoo05Ioo`03001oogoo01Uoo`0077oo0P00Egoo00<007ooOol0
6Goo000LOol00`00Oomoo`1EOol00`00Oomoo`0JOol001aoo`03001oogoo05Eoo`03001oogoo01Yo
o`0077oo0P00EGoo00<007ooOol06goo000LOol00`00Oomoo`1DOol00`00Oomoo`0KOol001aoo`80
05Aoo`03001oogoo01aoo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0DWoo0P00
7Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo059oo`03001oogoo01eo
o`002Woo00@007ooOol000]oo`03001oogoo0080059oo`03001oogoo01ioo`002Woo00@007ooOol0
00]oo`04001oogoo001COol00`00Oomoo`0NOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomo
o`1@Ool00`00Oomoo`0OOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001@Ool00`00Oomo
o`0POol000]oo`8000Qoo`D0009oo`03001oogoo04moo`03001oogoo021oo`0077oo00<007ooOol0
Cgoo00<007ooOol087oo000LOol2001?Ool00`00Oomoo`0QOol001aoo`03001oogoo04eoo`03001o
ogoo029oo`0077oo0P00CWoo00<007ooOol08Woo000LOol00`00Oomoo`1<Ool00`00Oomoo`0SOol0
01aoo`03001oogoo04]oo`8002Eoo`0077oo0P00C7oo00<007ooOol097oo000FOol30003Ool00`00
Oomoo`1:Ool00`00Oomoo`0UOol001Moo`03001oogoo009oo`8003]oo`03001oogoo00<0009oo`@0
00=oo`8002Moo`005goo00<007ooOol00Woo@@0000Aoo`00000000=oo`D002Qoo`005goo00<007oo
Ool00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`80
07=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03
001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo
000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`80
07=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(30561\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29902 m
.008 .29971 L
.012 .29857 L
.016 .29813 L
.02 .29836 L
.024 .29845 L
.028 .29874 L
.032 .29912 L
.036 .29922 L
.04 .29904 L
.044 .2987 L
.048 .29848 L
.052 .29844 L
.056 .29851 L
.06 .29876 L
.064 .29892 L
.068 .29887 L
.072 .29872 L
.076 .2985 L
.08 .2983 L
.084 .29826 L
.088 .29842 L
.092 .29878 L
.096 .29906 L
.1 .29901 L
.104 .29876 L
.108 .29842 L
.112 .29812 L
.116 .29797 L
.12 .29804 L
.124 .29842 L
.128 .29891 L
.132 .2991 L
.136 .29888 L
.14 .29845 L
.144 .29814 L
.148 .29801 L
.152 .29796 L
.156 .29811 L
.16 .29853 L
.164 .29897 L
.168 .29899 L
.172 .29848 L
.176 .2979 L
.18 .29769 L
.184 .29782 L
.188 .29808 L
.192 .29839 L
.196 .29883 L
.2 .2992 L
Mistroke
.204 .29902 L
.208 .29814 L
.212 .29718 L
.216 .29692 L
.22 .29753 L
.224 .29838 L
.228 .29891 L
.232 .29903 L
.236 .29892 L
.24 .29856 L
.244 .29787 L
.248 .29708 L
.252 .29686 L
.256 .29752 L
.26 .2986 L
.264 .29921 L
.268 .29891 L
.272 .29814 L
.276 .29759 L
.28 .29753 L
.284 .29766 L
.288 .29764 L
.292 .29759 L
.296 .29784 L
.3 .29846 L
.304 .299 L
.308 .29887 L
.312 .298 L
.316 .29701 L
.32 .29667 L
.324 .29722 L
.328 .29807 L
.332 .29845 L
.336 .29812 L
.34 .29768 L
.344 .29779 L
.348 .29842 L
.352 .29873 L
.356 .29804 L
.36 .29675 L
.364 .29613 L
.368 .29696 L
.372 .29857 L
.376 .29932 L
.38 .29837 L
.384 .29669 L
.388 .29617 L
.392 .29758 L
.396 .29954 L
.4 .2998 L
Mistroke
.404 .29764 L
.408 .29487 L
.412 .29423 L
.416 .29663 L
.42 .30008 L
.424 .30144 L
.428 .29946 L
.432 .29602 L
.436 .29436 L
.44 .29593 L
.444 .29901 L
.448 .30037 L
.452 .29845 L
.456 .29491 L
.46 .29318 L
.464 .29526 L
.468 .29978 L
.472 .30311 L
.476 .30243 L
.48 .29805 L
.484 .29315 L
.488 .29113 L
.492 .2931 L
.496 .29733 L
.5 .30089 L
.504 .30182 L
.508 .30026 L
.512 .29775 L
.516 .29588 L
.52 .29532 L
.524 .29585 L
.528 .29685 L
.532 .29781 L
.536 .29827 L
.54 .29781 L
.544 .29633 L
.548 .29444 L
.552 .29351 L
.556 .29488 L
.56 .29872 L
.564 .30333 L
.568 .30575 L
.572 .30361 L
.576 .297 L
.58 .28897 L
.584 .2841 L
.588 .28575 L
.592 .29384 L
.596 .30449 L
.6 .31208 L
Mistroke
.604 .31242 L
.608 .30512 L
.612 .2938 L
.616 .28407 L
.62 .28045 L
.624 .28413 L
.628 .29275 L
.632 .30201 L
.636 .30808 L
.64 .30931 L
.644 .30649 L
.648 .30173 L
.652 .29696 L
.656 .29301 L
.66 .2897 L
.664 .28675 L
.668 .28462 L
.672 .28469 L
.676 .28855 L
.68 .29676 L
.684 .30798 L
.688 .31897 L
.692 .32569 L
.696 .32495 L
.7 .31584 L
.704 .30034 L
.708 .28258 L
.712 .26737 L
.716 .25841 L
.72 .25713 L
.724 .26248 L
.728 .27171 L
.732 .28177 L
.736 .29058 L
.74 .29783 L
.744 .30483 L
.748 .31375 L
.752 .32647 L
.756 .34363 L
.76 .36416 L
.764 .3856 L
.768 .40484 L
.772 .41919 L
.776 .42724 L
.78 .42925 L
.784 .42702 L
.788 .42331 L
.792 .42094 L
.796 .42201 L
.8 .42737 L
Mistroke
.804 .43642 L
.808 .4474 L
.812 .45796 L
.816 .46582 L
.82 .46935 L
.824 .46799 L
.828 .4623 L
.832 .45378 L
.836 .4445 L
.84 .43663 L
.844 .43201 L
.848 .43184 L
.852 .43652 L
.856 .44562 L
.86 .45803 L
.864 .47219 L
.868 .48631 L
.872 .49873 L
.876 .50805 L
.88 .51335 L
.884 .51416 L
.888 .51051 L
.892 .50277 L
.896 .49161 L
.9 .47786 L
.904 .46246 L
.908 .44629 L
.912 .43018 L
.916 .41477 L
.92 .40056 L
.924 .38782 L
.928 .37673 L
.932 .36729 L
.936 .35945 L
.94 .35308 L
.944 .34799 L
.948 .34397 L
.952 .34082 L
.956 .33832 L
.96 .3363 L
.964 .33467 L
.968 .33332 L
.972 .33221 L
.976 .33129 L
.98 .33055 L
.984 .32997 L
.988 .32957 L
.992 .32937 L
.996 .3294 L
1 .32966 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .58408 m
.008 .5763 L
.012 .57379 L
.016 .57639 L
.02 .57728 L
.024 .57637 L
.028 .57612 L
.032 .57639 L
.036 .5765 L
.04 .57634 L
.044 .57632 L
.048 .57633 L
.052 .57637 L
.056 .57637 L
.06 .57641 L
.064 .57641 L
.068 .57642 L
.072 .57639 L
.076 .57637 L
.08 .57634 L
.084 .57634 L
.088 .57634 L
.092 .57636 L
.096 .57638 L
.1 .5764 L
.104 .5764 L
.108 .57641 L
.112 .57639 L
.116 .57638 L
.12 .57637 L
.124 .57636 L
.128 .57635 L
.132 .57635 L
.136 .57634 L
.14 .57636 L
.144 .57638 L
.148 .5764 L
.152 .57641 L
.156 .57642 L
.16 .5764 L
.164 .57638 L
.168 .57635 L
.172 .57633 L
.176 .57632 L
.18 .57634 L
.184 .57636 L
.188 .57638 L
.192 .5764 L
.196 .57641 L
.2 .57641 L
Mistroke
.204 .5764 L
.208 .57637 L
.212 .57636 L
.216 .57635 L
.22 .57635 L
.224 .57633 L
.228 .57633 L
.232 .57635 L
.236 .57638 L
.24 .5764 L
.244 .5764 L
.248 .57639 L
.252 .57639 L
.256 .57639 L
.26 .57638 L
.264 .57636 L
.268 .57634 L
.272 .57634 L
.276 .57635 L
.28 .57636 L
.284 .57636 L
.288 .57635 L
.292 .57636 L
.296 .57638 L
.3 .5764 L
.304 .5764 L
.308 .57639 L
.312 .57637 L
.316 .57638 L
.32 .57639 L
.324 .57638 L
.328 .57634 L
.332 .5763 L
.336 .5763 L
.34 .57633 L
.344 .57638 L
.348 .5764 L
.352 .57638 L
.356 .57636 L
.36 .57637 L
.364 .57642 L
.368 .57645 L
.372 .57642 L
.376 .57635 L
.38 .57629 L
.384 .5763 L
.388 .57636 L
.392 .5764 L
.396 .57636 L
.4 .57627 L
Mistroke
.404 .57622 L
.408 .57627 L
.412 .57639 L
.416 .57649 L
.42 .57649 L
.424 .57641 L
.428 .57634 L
.432 .57638 L
.436 .57649 L
.44 .57654 L
.444 .57646 L
.448 .57625 L
.452 .57605 L
.456 .57601 L
.46 .57614 L
.464 .57634 L
.468 .57648 L
.472 .57649 L
.476 .57642 L
.48 .57638 L
.484 .57644 L
.488 .57656 L
.492 .57664 L
.496 .57658 L
.5 .5764 L
.504 .57618 L
.508 .57604 L
.512 .57605 L
.516 .57617 L
.52 .57633 L
.524 .57645 L
.528 .57645 L
.532 .57635 L
.536 .57621 L
.54 .5761 L
.544 .57611 L
.548 .57628 L
.552 .57656 L
.556 .57684 L
.56 .57698 L
.564 .57689 L
.568 .57657 L
.572 .57617 L
.576 .57587 L
.58 .57582 L
.584 .57603 L
.588 .57635 L
.592 .57658 L
.596 .57655 L
.6 .57626 L
Mistroke
.604 .57588 L
.608 .57563 L
.612 .57568 L
.616 .57606 L
.62 .57662 L
.624 .57712 L
.628 .57737 L
.632 .57728 L
.636 .5769 L
.64 .57639 L
.644 .57593 L
.648 .57565 L
.652 .57559 L
.656 .57573 L
.66 .57604 L
.664 .57646 L
.668 .57694 L
.672 .5774 L
.676 .57771 L
.68 .57772 L
.684 .57734 L
.688 .57653 L
.692 .57541 L
.696 .5742 L
.7 .57322 L
.704 .57274 L
.708 .57292 L
.712 .57379 L
.716 .57519 L
.72 .57688 L
.724 .57859 L
.728 .58009 L
.732 .58124 L
.736 .58198 L
.74 .5823 L
.744 .58219 L
.748 .5816 L
.752 .58045 L
.756 .57863 L
.76 .57607 L
.764 .57276 L
.768 .56879 L
.772 .56431 L
.776 .55954 L
.78 .5547 L
.784 .54994 L
.788 .54532 L
.792 .54081 L
.796 .53628 L
.8 .53157 L
Mistroke
.804 .52653 L
.808 .52106 L
.812 .51513 L
.816 .50883 L
.82 .5023 L
.824 .49572 L
.828 .48928 L
.832 .48314 L
.836 .47736 L
.84 .47197 L
.844 .46687 L
.848 .46195 L
.852 .45704 L
.856 .45198 L
.86 .44662 L
.864 .44087 L
.868 .43469 L
.872 .42812 L
.876 .42123 L
.88 .41414 L
.884 .40698 L
.888 .3999 L
.892 .39303 L
.896 .38648 L
.9 .38033 L
.904 .37462 L
.908 .36936 L
.912 .36452 L
.916 .36007 L
.92 .35595 L
.924 .35209 L
.928 .34844 L
.932 .34493 L
.936 .34152 L
.94 .33819 L
.944 .33491 L
.948 .33168 L
.952 .32849 L
.956 .32537 L
.96 .32233 L
.964 .31937 L
.968 .31652 L
.972 .31377 L
.976 .31113 L
.98 .30859 L
.984 .30614 L
.988 .30377 L
.992 .30143 L
.996 .29913 L
1 .29681 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42872 L
.012 .42963 L
.016 .43025 L
.02 .43001 L
.024 .42976 L
.028 .42967 L
.032 .42977 L
.036 .42971 L
.04 .42967 L
.044 .42959 L
.048 .42962 L
.052 .42958 L
.056 .42958 L
.06 .42954 L
.064 .42953 L
.068 .42947 L
.072 .42943 L
.076 .42936 L
.08 .42933 L
.084 .42929 L
.088 .42928 L
.092 .42926 L
.096 .42925 L
.1 .42922 L
.104 .4292 L
.108 .42916 L
.112 .42912 L
.116 .42907 L
.12 .42904 L
.124 .42899 L
.128 .42896 L
.132 .42891 L
.136 .42889 L
.14 .42887 L
.144 .42886 L
.148 .42884 L
.152 .42882 L
.156 .42879 L
.16 .42876 L
.164 .4287 L
.168 .42864 L
.172 .42858 L
.176 .42854 L
.18 .42852 L
.184 .42851 L
.188 .4285 L
.192 .42849 L
.196 .42848 L
.2 .42846 L
Mistroke
.204 .4284 L
.208 .42834 L
.212 .42829 L
.216 .42825 L
.22 .42821 L
.224 .42817 L
.228 .42813 L
.232 .42812 L
.236 .42812 L
.24 .42811 L
.244 .42808 L
.248 .42805 L
.252 .42803 L
.256 .428 L
.26 .42794 L
.264 .42787 L
.268 .42781 L
.272 .42778 L
.276 .42777 L
.28 .42776 L
.284 .42773 L
.288 .42768 L
.292 .42766 L
.296 .42765 L
.3 .42764 L
.304 .42761 L
.308 .42756 L
.312 .42751 L
.316 .42749 L
.32 .42747 L
.324 .42743 L
.328 .42735 L
.332 .42727 L
.336 .42723 L
.34 .42723 L
.344 .42726 L
.348 .42725 L
.352 .42721 L
.356 .42716 L
.36 .42714 L
.364 .42716 L
.368 .42716 L
.372 .42709 L
.376 .42697 L
.38 .42687 L
.384 .42686 L
.388 .4269 L
.392 .42692 L
.396 .42684 L
.4 .42669 L
Mistroke
.404 .42659 L
.408 .42662 L
.412 .42674 L
.416 .42683 L
.42 .4268 L
.424 .42667 L
.428 .42657 L
.432 .42659 L
.436 .42668 L
.44 .42671 L
.444 .42657 L
.448 .42628 L
.452 .42601 L
.456 .42592 L
.46 .42606 L
.464 .42628 L
.468 .42642 L
.472 .4264 L
.476 .42627 L
.48 .42619 L
.484 .42624 L
.488 .42636 L
.492 .42642 L
.496 .42633 L
.5 .42607 L
.504 .42576 L
.508 .42555 L
.512 .42552 L
.516 .42565 L
.52 .42582 L
.524 .42594 L
.528 .42591 L
.532 .42576 L
.536 .42554 L
.54 .42538 L
.544 .42536 L
.548 .42553 L
.552 .42585 L
.556 .42618 L
.56 .42632 L
.564 .42617 L
.568 .42574 L
.572 .4252 L
.576 .4248 L
.58 .42471 L
.584 .42494 L
.588 .42531 L
.592 .42556 L
.596 .42549 L
.6 .42511 L
Mistroke
.604 .4246 L
.608 .42425 L
.612 .42429 L
.616 .42473 L
.62 .4254 L
.624 .42599 L
.628 .42627 L
.632 .42611 L
.636 .42561 L
.64 .42495 L
.644 .42435 L
.648 .42397 L
.652 .42386 L
.656 .42401 L
.66 .42436 L
.664 .42485 L
.668 .42542 L
.672 .42596 L
.676 .42631 L
.68 .4263 L
.684 .42579 L
.688 .42475 L
.692 .42331 L
.696 .42178 L
.7 .42053 L
.704 .41989 L
.708 .4201 L
.712 .42115 L
.716 .42287 L
.72 .42494 L
.724 .42704 L
.728 .42887 L
.732 .43027 L
.736 .43116 L
.74 .43153 L
.744 .43136 L
.748 .4306 L
.752 .42913 L
.756 .42683 L
.76 .4236 L
.764 .41945 L
.768 .41446 L
.772 .40885 L
.776 .40289 L
.78 .39683 L
.784 .39087 L
.788 .38509 L
.792 .37945 L
.796 .37378 L
.8 .3679 L
Mistroke
.804 .3616 L
.808 .35477 L
.812 .34738 L
.816 .33952 L
.82 .33138 L
.824 .32318 L
.828 .31517 L
.832 .30754 L
.836 .30038 L
.84 .29369 L
.844 .28741 L
.848 .28135 L
.852 .27532 L
.856 .26913 L
.86 .26259 L
.864 .25561 L
.868 .24813 L
.872 .2402 L
.876 .23193 L
.88 .22346 L
.884 .21497 L
.888 .20666 L
.892 .1987 L
.896 .19123 L
.9 .18435 L
.904 .17813 L
.908 .17259 L
.912 .16769 L
.916 .16341 L
.92 .15966 L
.924 .15637 L
.928 .15346 L
.932 .15086 L
.936 .14851 L
.94 .14636 L
.944 .14437 L
.948 .14252 L
.952 .14079 L
.956 .13919 L
.96 .1377 L
.964 .13632 L
.968 .13504 L
.972 .13385 L
.976 .13273 L
.98 .13167 L
.984 .13063 L
.988 .1296 L
.992 .12852 L
.996 .1274 L
1 .12619 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool20002Ool01000Oomoo`000Woo00@007oo
Ool0009oo`05001oogooOol00003Ool00`00Ool000030003Ool01000Oomoo`001Goo000;Ool2000:
Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@0
07ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`000Woo0`0000Eo
o`00Oomoo`00009oo`04001oogoo0002Ool01@00Oomoogoo00000goo00<007oo00001Woo00@007oo
Ool000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007oo
Oomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<0
07ooOol0=Woo00<007ooOol00P000goo0P000Woo00<007oo00009goo000ROol=00000goo00000007
000017oo000007oo0`0000=oo`0000001P0000=oo`000000100000Aoo`00001oo`T00003Ool00000
009oo`03001oo`00009oo`04001oogoo000VOol0029oof<000aoo`008Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00002Ool01000Oomoogoo
0`0000Aoo`00Oomoo`8000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000aoo`008Woo0P00@Woo00<007ooOol00Woo00<007ooOol05Goo00<007ooOol02goo000ROol0
0`00Oomoo`16Ool00`00Oomoo`0AOol400000goo001oo`0;Ool0029oo`8004Qoo`03001oogoo00mo
o`80015oo`008Woo0P00B7oo00<007ooOol03Woo0P004Woo000;Ool20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool00`00Oomoo`17Ool00`00Oomoo`0>Ool00`00Oomoo`0AOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00B7oo00<007ooOol03Woo00<007ooOol04Goo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8004Uoo`03001oogoo00ao
o`03001oogoo019oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`18Ool00`00Oomoo`0<Ool00`00Oomoo`0BOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P00BGoo00<007ooOol037oo00<007ooOol04Woo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`8000Aoo`8004Uoo`03001oo`0000]oo`03001oogoo01=oo`002goo0P00
2Woo0P0017oo00<007ooOol00Woo00<007ooOol0BGoo0`000goo0P001Goo00<007ooOol04goo000;
Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001<Ool01000Oomoogoo0P001Goo00<007oo
Ool04goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001=Ool01P00
Oomoo`00Ool000Aoo`03001oogoo01=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1<Ool00`00Ool00002Ool01@00Oomoogoo00005Woo000:Ool01000Oomo
o`0027oo00@007ooOol000Aoo`04001oogooOol2001>Ool01@00Oomoogoo00000goo00<007ooOol0
57oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001BOol01@00Oomo
ogoo00005Woo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00E7oo00<0
07oo00005goo000;Ool2000:Ool20003Ool30003Ool2001COol00`00Ool0000GOol0029oo`03001o
ogoo059oo`<001Moo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool2
0003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003
Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03
001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00
Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D0
07ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001o
ogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo
00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo
0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001o
ogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`00
0goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomo
ogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eo
o`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04
001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool2
0004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`00
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool0
00030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`00
1Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Io
o`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Ao
o`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool2
0006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0F7oo0P0037oo000XOomM000<Ool002Qo
o`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo00ao
o`80009oo`03001oogoo00Yoo`00:7oo00<007ooOol0Dgoo0`0047oo000XOol00`00Oomoo`1BOol2
000BOol002Qoo`03001oogoo055oo`8001=oo`00:7oo00<007ooOol0DGoo00<007ooOol04Woo000X
Ool00`00Oomoo`1@Ool00`00Oomoo`0COol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=o
o`<000=oo`03001oogoo04moo`03001oogoo01Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000=oo`04001oogoo001@Ool2000FOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001@Ool00`00Oomoo`0EOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008004ioo`8001Moo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0CGoo00<007oo
Ool05Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007oo
Ool0C7oo00<007ooOol05goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1;Ool2
000IOol002Qoo`03001oogoo04]oo`03001oogoo01Qoo`00:7oo00<007ooOol0BWoo00<007ooOol0
6Goo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`19Ool00`00Oomoo`0J
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0B7oo0P00
77oo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo04Qoo`03
001oogoo01]oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20018Ool0
0`00Oomoo`0LOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0AWoo0P007Woo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo04Io
o`03001oogoo01eoo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0AGoo00<007oo
Ool07Woo000XOol00`00Oomoo`14Ool00`00Oomoo`0OOol002Qoo`8003=oo`04001oogoo0002Ool2
0002Ool40003Ool00`00Oomoo`0POol002Qood00009oo`D0029oo`002goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@0
07ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]
Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00
Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo
10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool2
0008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`80
00Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`80
00Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol0
0goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomo
o`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=
Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
1000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo
00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P00
0goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo
0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`80
00Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0Ggoo0`0047oo000LOol00`00
Oomoo`1MOol3000BOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo008000=oo`03001oogoo009o
o`03001oogoo00Yoo`0077oo00<007ooOol0Fgoo00<007ooOol057oo000LOol2001KOol00`00Oomo
o`0EOol001aoo`03001oogoo05Uoo`03001oogoo01Ioo`0077oo00<007ooOol0FGoo00<007ooOol0
5Woo000LOol2001JOol00`00Oomoo`0FOol001aoo`03001oogoo05Qoo`03001oogoo01Moo`0077oo
00<007ooOol0Egoo0P006Goo000LOol2001HOol00`00Oomoo`0HOol001aoo`03001oogoo05Moo`03
001oogoo01Qoo`0077oo0P00Egoo00<007ooOol06Goo000;Ool20004Ool00`00Oomoo`02Ool30003
Ool00`00Oomoo`1EOol00`00Oomoo`0JOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0E7oo0P0077oo000:Ool01000Oomoo`002goo00<007ooOol00P00EGoo00<007ooOol0
6goo000:Ool01000Oomoo`002goo00@007ooOol005Eoo`8001eoo`002Woo00@007ooOol000Moo`@0
00=oo`03001oogoo05=oo`03001oogoo01aoo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80
05=oo`03001oogoo01eoo`002goo0P0027oo1@000Woo00<007ooOol0DWoo00<007ooOol07Goo000L
Ool00`00Oomoo`1BOol00`00Oomoo`0MOol001aoo`80059oo`03001oogoo01ioo`0077oo00<007oo
Ool0D7oo00<007ooOol07goo000LOol2001@Ool2000QOol001aoo`03001oogoo04moo`03001oogoo
021oo`0077oo00<007ooOol0CWoo00<007ooOol08Goo000LOol2001>Ool2000SOol001Ioo`<000=o
o`03001oogoo04eoo`03001oogoo029oo`005goo00<007ooOol00Woo00<007ooOol0?7oo00@007oo
Oomoo`8000=oo`<000Aoo`03001oogoo02=oo`005goo00<007ooOol00Woo?`0000Aoo`000000009o
o`<000=oo`@002Ioo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool0
0`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001c
Ool000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo
00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007oo
Ool01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol0
00]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1b
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(30728\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30203 m
.008 .30039 L
.012 .29813 L
.016 .29745 L
.02 .29877 L
.024 .29923 L
.028 .29874 L
.032 .29884 L
.036 .29918 L
.04 .29906 L
.044 .2986 L
.048 .29827 L
.052 .29837 L
.056 .29866 L
.06 .299 L
.064 .29919 L
.068 .29902 L
.072 .29865 L
.076 .29834 L
.08 .2982 L
.084 .29836 L
.088 .29872 L
.092 .29907 L
.096 .29916 L
.1 .29883 L
.104 .29829 L
.108 .29797 L
.112 .29801 L
.116 .29839 L
.12 .29885 L
.124 .29917 L
.128 .2992 L
.132 .29879 L
.136 .2981 L
.14 .29762 L
.144 .29772 L
.148 .29831 L
.152 .29889 L
.156 .2991 L
.16 .29899 L
.164 .29864 L
.168 .29813 L
.172 .29767 L
.176 .29763 L
.18 .29819 L
.184 .29889 L
.188 .29914 L
.192 .29877 L
.196 .29819 L
.2 .29785 L
Mistroke
.204 .29776 L
.208 .29776 L
.212 .29793 L
.216 .29843 L
.22 .29904 L
.224 .2992 L
.228 .29865 L
.232 .29782 L
.236 .29735 L
.24 .29743 L
.244 .29774 L
.248 .29801 L
.252 .29834 L
.256 .29882 L
.26 .29915 L
.264 .29882 L
.268 .29786 L
.272 .29695 L
.276 .29686 L
.28 .29762 L
.284 .29853 L
.288 .2989 L
.292 .29865 L
.296 .29821 L
.3 .29793 L
.304 .29776 L
.308 .29753 L
.312 .29728 L
.316 .29733 L
.32 .29789 L
.324 .29866 L
.328 .29903 L
.332 .29861 L
.336 .29767 L
.34 .29699 L
.344 .2971 L
.348 .29775 L
.352 .29815 L
.356 .29785 L
.36 .29729 L
.364 .29734 L
.368 .29825 L
.372 .29918 L
.376 .29898 L
.38 .29751 L
.384 .29605 L
.388 .29607 L
.392 .29763 L
.396 .29917 L
.4 .29902 L
Mistroke
.404 .29729 L
.408 .29588 L
.412 .29653 L
.416 .29886 L
.42 .30051 L
.424 .29947 L
.428 .29629 L
.432 .29379 L
.436 .29444 L
.44 .29783 L
.444 .30097 L
.448 .30104 L
.452 .29808 L
.456 .29496 L
.46 .29463 L
.464 .2973 L
.468 .30026 L
.472 .30046 L
.476 .29741 L
.48 .29372 L
.484 .2928 L
.488 .29576 L
.492 .30043 L
.496 .3032 L
.5 .30192 L
.504 .29757 L
.508 .29326 L
.512 .29178 L
.516 .29368 L
.52 .29723 L
.524 .3001 L
.528 .30093 L
.532 .29991 L
.536 .29811 L
.54 .29655 L
.544 .29574 L
.548 .29579 L
.552 .29659 L
.556 .2978 L
.56 .29868 L
.564 .29834 L
.568 .29641 L
.572 .29372 L
.576 .29217 L
.58 .29355 L
.584 .29812 L
.588 .3038 L
.592 .30709 L
.596 .30522 L
.6 .29818 L
Mistroke
.604 .28928 L
.608 .28345 L
.612 .2844 L
.616 .29226 L
.62 .30324 L
.624 .31163 L
.628 .31301 L
.632 .30664 L
.636 .29575 L
.64 .28569 L
.644 .28102 L
.648 .28328 L
.652 .29066 L
.656 .29938 L
.66 .30584 L
.664 .30827 L
.668 .30704 L
.672 .30373 L
.676 .29983 L
.68 .29592 L
.684 .29184 L
.688 .28749 L
.692 .28361 L
.696 .28196 L
.7 .28449 L
.704 .29217 L
.708 .30393 L
.712 .31663 L
.716 .32597 L
.72 .32821 L
.724 .3217 L
.728 .30768 L
.732 .28987 L
.736 .27306 L
.74 .26141 L
.744 .25705 L
.748 .25961 L
.752 .26683 L
.756 .2757 L
.76 .28391 L
.764 .29074 L
.768 .29717 L
.772 .30525 L
.776 .31705 L
.78 .33357 L
.784 .35416 L
.788 .37662 L
.792 .3979 L
.796 .41501 L
.8 .42603 L
Mistroke
.804 .43065 L
.808 .43018 L
.812 .42711 L
.816 .42433 L
.82 .4243 L
.824 .4284 L
.828 .4366 L
.832 .44759 L
.836 .45919 L
.84 .469 L
.844 .47504 L
.848 .47623 L
.852 .47262 L
.856 .4653 L
.86 .45615 L
.864 .44736 L
.868 .44098 L
.872 .4386 L
.876 .44102 L
.88 .44826 L
.884 .45953 L
.888 .47346 L
.892 .48835 L
.896 .50242 L
.9 .5141 L
.904 .52217 L
.908 .52586 L
.912 .52489 L
.916 .51941 L
.92 .50992 L
.924 .49717 L
.928 .48206 L
.932 .46554 L
.936 .4485 L
.94 .43169 L
.944 .41573 L
.948 .40105 L
.952 .38793 L
.956 .37651 L
.96 .36681 L
.964 .35877 L
.968 .35224 L
.972 .34703 L
.976 .34294 L
.98 .33977 L
.984 .33735 L
.988 .33554 L
.992 .33423 L
.996 .33334 L
1 .33278 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57861 m
.008 .57612 L
.012 .57522 L
.016 .57574 L
.02 .57616 L
.024 .576 L
.028 .57588 L
.032 .57587 L
.036 .57598 L
.04 .57597 L
.044 .57598 L
.048 .57595 L
.052 .57597 L
.056 .57595 L
.06 .57594 L
.064 .57591 L
.068 .57592 L
.072 .57591 L
.076 .57594 L
.08 .57595 L
.084 .57598 L
.088 .57598 L
.092 .57598 L
.096 .57595 L
.1 .57594 L
.104 .57591 L
.108 .57591 L
.112 .57591 L
.116 .57593 L
.12 .57594 L
.124 .57597 L
.128 .57597 L
.132 .57597 L
.136 .57596 L
.14 .57596 L
.144 .57594 L
.148 .57593 L
.152 .57592 L
.156 .57592 L
.16 .57592 L
.164 .57593 L
.168 .57594 L
.172 .57596 L
.176 .57597 L
.18 .57599 L
.184 .57598 L
.188 .57595 L
.192 .57593 L
.196 .57591 L
.2 .5759 L
Mistroke
.204 .5759 L
.208 .57591 L
.212 .57594 L
.216 .57597 L
.22 .57598 L
.224 .57598 L
.228 .57596 L
.232 .57595 L
.236 .57595 L
.24 .57594 L
.244 .57592 L
.248 .5759 L
.252 .5759 L
.256 .57592 L
.26 .57594 L
.264 .57595 L
.268 .57595 L
.272 .57597 L
.276 .57598 L
.28 .57598 L
.284 .57595 L
.288 .57592 L
.292 .57591 L
.296 .57592 L
.3 .57593 L
.304 .57592 L
.308 .57591 L
.312 .57591 L
.316 .57594 L
.32 .57596 L
.324 .57597 L
.328 .57596 L
.332 .57594 L
.336 .57594 L
.34 .57596 L
.344 .57598 L
.348 .57595 L
.352 .5759 L
.356 .57587 L
.36 .57587 L
.364 .57591 L
.368 .57594 L
.372 .57594 L
.376 .57591 L
.38 .57592 L
.384 .57596 L
.388 .57602 L
.392 .57603 L
.396 .57597 L
.4 .57589 L
Mistroke
.404 .57586 L
.408 .57591 L
.412 .57597 L
.416 .57598 L
.42 .5759 L
.424 .57581 L
.428 .57578 L
.432 .57586 L
.436 .57598 L
.44 .57604 L
.444 .576 L
.448 .57592 L
.452 .57591 L
.456 .576 L
.46 .57612 L
.464 .57615 L
.468 .57603 L
.472 .5758 L
.476 .57563 L
.48 .57561 L
.484 .57574 L
.488 .5759 L
.492 .576 L
.496 .57598 L
.5 .57592 L
.504 .57593 L
.508 .57602 L
.512 .57616 L
.516 .57624 L
.52 .57618 L
.524 .576 L
.528 .57578 L
.532 .57564 L
.536 .57563 L
.54 .57573 L
.544 .57588 L
.548 .576 L
.552 .57603 L
.556 .57594 L
.56 .57578 L
.564 .57564 L
.568 .57562 L
.572 .57577 L
.576 .57606 L
.58 .57638 L
.584 .57657 L
.588 .57651 L
.592 .57621 L
.596 .5758 L
.6 .57548 L
Mistroke
.604 .57542 L
.608 .57561 L
.612 .57593 L
.616 .57615 L
.62 .57614 L
.624 .57586 L
.628 .57546 L
.632 .57518 L
.636 .57518 L
.64 .57551 L
.644 .57604 L
.648 .57656 L
.652 .57687 L
.656 .57686 L
.66 .57658 L
.664 .57614 L
.668 .57569 L
.672 .57536 L
.676 .57519 L
.68 .57521 L
.684 .57541 L
.688 .57577 L
.692 .57626 L
.696 .57679 L
.7 .57724 L
.704 .57744 L
.708 .57725 L
.712 .57659 L
.716 .57553 L
.72 .57429 L
.724 .57315 L
.728 .57241 L
.732 .57229 L
.736 .57284 L
.74 .57398 L
.744 .57551 L
.748 .57717 L
.752 .57874 L
.756 .58006 L
.76 .58105 L
.764 .58168 L
.768 .58193 L
.772 .58173 L
.776 .58101 L
.78 .57965 L
.784 .57755 L
.788 .57467 L
.792 .57107 L
.796 .56688 L
.8 .5623 L
Mistroke
.804 .55755 L
.808 .55282 L
.812 .5482 L
.816 .54369 L
.82 .53921 L
.824 .5346 L
.828 .52972 L
.832 .52442 L
.836 .51866 L
.84 .51247 L
.844 .50595 L
.848 .49928 L
.852 .49264 L
.856 .4862 L
.86 .48006 L
.864 .47428 L
.868 .46881 L
.872 .46355 L
.876 .45835 L
.88 .45304 L
.884 .44748 L
.888 .44154 L
.892 .43516 L
.896 .42832 L
.9 .42109 L
.904 .41355 L
.908 .40585 L
.912 .39811 L
.916 .39051 L
.92 .38315 L
.924 .37616 L
.928 .36959 L
.932 .3635 L
.936 .35789 L
.94 .35274 L
.944 .34802 L
.948 .34368 L
.952 .33965 L
.956 .33589 L
.96 .33235 L
.964 .32898 L
.968 .32576 L
.972 .32266 L
.976 .31966 L
.98 .31676 L
.984 .31395 L
.988 .31123 L
.992 .30858 L
.996 .30602 L
1 .30351 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43537 L
.012 .42979 L
.016 .42805 L
.02 .42986 L
.024 .43046 L
.028 .42975 L
.032 .42955 L
.036 .42969 L
.04 .42976 L
.044 .42963 L
.048 .42961 L
.052 .42959 L
.056 .42959 L
.06 .42952 L
.064 .42948 L
.068 .42942 L
.072 .4294 L
.076 .42937 L
.08 .42937 L
.084 .42935 L
.088 .42934 L
.092 .4293 L
.096 .42926 L
.1 .42919 L
.104 .42915 L
.108 .4291 L
.112 .42908 L
.116 .42905 L
.12 .42904 L
.124 .42902 L
.128 .429 L
.132 .42897 L
.136 .42893 L
.14 .42889 L
.144 .42886 L
.148 .42881 L
.152 .42876 L
.156 .42872 L
.16 .42869 L
.164 .42866 L
.168 .42865 L
.172 .42864 L
.176 .42864 L
.18 .42862 L
.184 .42858 L
.188 .42851 L
.192 .42845 L
.196 .42839 L
.2 .42836 L
Mistroke
.204 .42832 L
.208 .4283 L
.212 .4283 L
.216 .4283 L
.22 .42829 L
.224 .42826 L
.228 .42822 L
.232 .42817 L
.236 .42813 L
.24 .42807 L
.244 .42801 L
.248 .42796 L
.252 .42794 L
.256 .42794 L
.26 .42793 L
.264 .42791 L
.268 .42788 L
.272 .42786 L
.276 .42784 L
.28 .42781 L
.284 .42774 L
.288 .42768 L
.292 .42763 L
.296 .42761 L
.3 .42759 L
.304 .42756 L
.308 .42751 L
.312 .42748 L
.316 .42747 L
.32 .42746 L
.324 .42745 L
.328 .42741 L
.332 .42736 L
.336 .42734 L
.34 .42733 L
.344 .4273 L
.348 .42723 L
.352 .42714 L
.356 .42707 L
.36 .42705 L
.364 .42707 L
.368 .42708 L
.372 .42704 L
.376 .42697 L
.38 .42694 L
.384 .42697 L
.388 .427 L
.392 .42698 L
.396 .42688 L
.4 .42676 L
Mistroke
.404 .4267 L
.408 .42672 L
.412 .42677 L
.416 .42674 L
.42 .4266 L
.424 .42645 L
.428 .42639 L
.432 .42647 L
.436 .42659 L
.44 .42663 L
.444 .42654 L
.448 .42641 L
.452 .42636 L
.456 .42644 L
.46 .42657 L
.464 .42658 L
.468 .42639 L
.472 .42608 L
.476 .42583 L
.48 .42577 L
.484 .4259 L
.488 .42607 L
.492 .42616 L
.496 .42611 L
.5 .42601 L
.504 .42598 L
.508 .42607 L
.512 .42621 L
.516 .42627 L
.52 .42616 L
.524 .42591 L
.528 .42562 L
.532 .42541 L
.536 .42536 L
.54 .42545 L
.544 .42561 L
.548 .42572 L
.552 .42572 L
.556 .42558 L
.56 .42536 L
.564 .42515 L
.568 .42509 L
.572 .42525 L
.576 .42558 L
.58 .42595 L
.584 .42615 L
.588 .42605 L
.592 .42564 L
.596 .4251 L
.6 .42468 L
Mistroke
.604 .42456 L
.608 .42477 L
.612 .42513 L
.616 .42538 L
.62 .42533 L
.624 .42495 L
.628 .42443 L
.632 .42405 L
.636 .42402 L
.64 .42439 L
.644 .42502 L
.648 .42564 L
.652 .42599 L
.656 .42596 L
.66 .42557 L
.664 .42499 L
.668 .4244 L
.672 .42395 L
.676 .42371 L
.68 .42371 L
.684 .42393 L
.688 .42435 L
.692 .42492 L
.696 .42556 L
.7 .42608 L
.704 .4263 L
.708 .42602 L
.712 .42517 L
.716 .42383 L
.72 .42225 L
.724 .4208 L
.728 .41985 L
.732 .41966 L
.736 .42032 L
.74 .42171 L
.744 .42358 L
.748 .42562 L
.752 .42755 L
.756 .42917 L
.76 .43037 L
.764 .43112 L
.768 .4314 L
.772 .43113 L
.776 .4302 L
.78 .42848 L
.784 .42583 L
.788 .42223 L
.792 .41772 L
.796 .41249 L
.8 .40678 L
Mistroke
.804 .40087 L
.808 .39498 L
.812 .38925 L
.816 .38367 L
.82 .37814 L
.824 .37247 L
.828 .36648 L
.832 .36 L
.836 .35298 L
.84 .34545 L
.844 .33756 L
.848 .32953 L
.852 .32159 L
.856 .31397 L
.86 .3068 L
.864 .30015 L
.868 .29398 L
.872 .28816 L
.876 .28253 L
.88 .27687 L
.884 .27102 L
.888 .26481 L
.892 .25819 L
.896 .25113 L
.9 .24371 L
.904 .23603 L
.908 .22827 L
.912 .22059 L
.916 .21317 L
.92 .20615 L
.924 .19964 L
.928 .19372 L
.932 .18842 L
.936 .18372 L
.94 .17959 L
.944 .17595 L
.948 .17273 L
.952 .16983 L
.956 .16718 L
.96 .16471 L
.964 .16238 L
.968 .16013 L
.972 .15796 L
.976 .15585 L
.98 .15383 L
.984 .1519 L
.988 .15008 L
.992 .14839 L
.996 .14684 L
1 .14543 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`020002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007oo
Ool000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007oo
Oomoo`D000=oo`8000Aoo`<00004Ool007ooOol20004Ool20005Ool30002Ool50003Ool20006Ool0
029oo`03001oogoo03Qoo`800003Ool0000000=oo`8000=oo`03001oo`0002Aoo`008Woo300000=o
o`000000600000=oo`00Ool0100000=oo`0000002@0000Qoo`00001oo`00Ool007oo0P0000Aoo`00
Ool000=oo`03001oogoo025oo`008WooH`0037oo000ROol01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00H007ooOomoo`00Ool20003Ool01000Oomoogoo0P000Woo
00D007oo001oo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol02Woo
000ROol20014Ool20004Ool00`00Oomoo`0POol0029oo`03001oogoo04Uoo`03001oogoo015oo`<0
00aoo`008Woo0P00BWoo00<007ooOol047oo00<007ooOol03Goo000ROol2001;Ool00`00Oomoo`0>
Ool00`00Oomoo`0>Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo04Yo
o`03001oogoo00ioo`03001oogoo00ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2001;Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P00Bgoo00<007ooOol03Goo00<007ooOol03goo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo04Yoo`03001oogoo00aoo`03
001oogoo011oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001;Ool0
0`00Oomoo`0<Ool00`00Oomoo`0@Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
0P00C7oo00<007ooOol02goo00<007ooOol047oo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool0
0`00Oomoo`1;Ool3000;Ool00`00Oomoo`0@Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0
009oo`8004moo`05001oogooOol00006Ool00`00Oomoo`0@Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol0009oo`8004moo`06001oogoo001oo`0017oo00<007ooOol04Goo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo04moo`05001oo`00
Ool00004Ool00`00Oomoo`0AOol000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomo
o`80051oo`<00003Ool007oo00=oo`03001oogoo015oo`002Woo00@007ooOol000Qoo`06001oogoo
001oo`000goo00<007ooOol00P00D7oo0P000goo00D007ooOomoo`0001=oo`002Woo00@007ooOol0
00Qoo`06001oogoo001oo`000goo00@007ooOol005Ioo`05001oogooOol0000COol000]oo`8000Yo
o`8000=oo`<000=oo`8005Eoo`04001oogoo000DOol0029oo`03001oogoo05Eoo`03001oo`0001Ao
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00EWoo0P005Goo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001GOol00`00Oomoo`0COol000Yoo`04001o
ogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:
Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0
029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00
0Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo
0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P00
0goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool0
1@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001o
ogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0
009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2
000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000
Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo1000
0goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000
Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
o`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=o
o`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool5
0003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qo
o`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo00eo
o`800003Ool007oo00]oo`00:7oo00<007ooOol0EGoo0P003goo000XOol00`00Oomoo`1DOol2000@
Ool002Qoo`03001oogoo05=oo`03001oogoo011oo`00:7oo00<007ooOol0DWoo0P004Woo000XOol0
0`00Oomoo`1BOol00`00Oomoo`0AOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<0
00=oo`03001oogoo055oo`03001oogoo019oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1P00Oomoo`00Ool000=oo`04001oogoo001COol00`00Oomoo`0BOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001BOol00`00Oomoo`0COol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo0080051oo`8001Eoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0Cgoo00<0
07ooOol057oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<0
07ooOol0CWoo0P005Woo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1>Ool00`00
Oomoo`0EOol002Qoo`03001oogoo04eoo`03001oogoo01Ioo`00:7oo00<007ooOol0C7oo00<007oo
Ool05goo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1;Ool2000IOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0Bgoo00<007oo
Ool067oo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo04Yo
o`03001oogoo01Uoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001;
Ool00`00Oomoo`0IOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0BGoo00<007ooOol06Woo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03
001oogoo04Qoo`03001oogoo01]oo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0
Agoo0P007Goo000XOol00`00Oomoo`16Ool2000NOol002Qoo`<002Aoo`04001oogooOol20003Ool2
00000goo00000002Ool2000017oo000007oo0`000Woo0`000goo0P007goo000XOol/00000goo0000
0002000017oo000007oo0P0000Aoo`00001oo`<00004Ool000000003Ool4000POol000]oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo
00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomo
o`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@0
07ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80
07=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009
Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002
Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009o
o`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo
001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0
009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol0
47oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool0
1000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=o
o`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03
001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`80
00eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006
Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo
00<007ooOol0Hgoo0`0037oo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo0P0017oo
00<007ooOol02Woo000LOol00`00Oomoo`1NOol2000BOol001aoo`8005moo`03001oogoo015oo`00
77oo00<007ooOol0GGoo00<007ooOol04Woo000LOol00`00Oomoo`1LOol00`00Oomoo`0COol001ao
o`8005aoo`8001Eoo`0077oo00<007ooOol0Fgoo00<007ooOol057oo000LOol00`00Oomoo`1KOol0
0`00Oomoo`0DOol001aoo`8005]oo`03001oogoo01Eoo`0077oo00<007ooOol0FGoo0P005goo000L
Ool2001JOol00`00Oomoo`0FOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo05Qo
o`8001Qoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1GOol2000IOol0
00Yoo`04001oogoo000;Ool00`00Oomoo`02001HOol00`00Oomoo`0HOol000Yoo`04001oogoo000;
Ool01000Oomoo`00F7oo0P006Woo000:Ool01000Oomoo`001goo10000goo00<007ooOol0EWoo00<0
07ooOol06Goo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00EWoo00<007ooOol06Woo000;
Ool20008Ool50002Ool00`00Oomoo`1DOol2000LOol001aoo`03001oogoo05Aoo`03001oogoo01]o
o`0077oo0P00EGoo00<007ooOol06goo000LOol00`00Oomoo`1COol00`00Oomoo`0LOol001aoo`80
05=oo`03001oogoo01eoo`0077oo00<007ooOol0DWoo00<007ooOol07Goo000LOol00`00Oomoo`1A
Ool00`00Oomoo`0NOol001aoo`80055oo`03001oogoo01moo`005Woo0`000goo00<007ooOol0Cgoo
0P008Goo000GOol00`00Oomoo`02Ool00`00Oomoo`0kOol200000goo00000002Ool30002Ool40004
Ool00`00Oomoo`0POol001Moo`03001oogoo009ood800004Ool000000002Ool30003Ool4000SOol0
01Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000FOol20004
Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2
001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;
Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo
079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(30895\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29968 m
.008 .29845 L
.012 .29883 L
.016 .29892 L
.02 .29891 L
.024 .29905 L
.028 .29895 L
.032 .29876 L
.036 .29871 L
.04 .29874 L
.044 .29882 L
.048 .29879 L
.052 .29878 L
.056 .29883 L
.06 .29882 L
.064 .29877 L
.068 .2987 L
.072 .29863 L
.076 .29868 L
.08 .29874 L
.084 .29875 L
.088 .29873 L
.092 .29866 L
.096 .29858 L
.1 .29852 L
.104 .29847 L
.108 .29858 L
.112 .29878 L
.116 .29889 L
.12 .2988 L
.124 .29855 L
.128 .29832 L
.132 .2982 L
.136 .29816 L
.14 .2983 L
.144 .29868 L
.148 .29907 L
.152 .29912 L
.156 .29871 L
.16 .29817 L
.164 .29786 L
.168 .29784 L
.172 .29805 L
.176 .29844 L
.18 .29894 L
.184 .29922 L
.188 .29892 L
.192 .29814 L
.196 .2975 L
.2 .29752 L
Mistroke
.204 .2981 L
.208 .2987 L
.212 .29894 L
.216 .29889 L
.22 .29862 L
.224 .2981 L
.228 .29748 L
.232 .29721 L
.236 .29768 L
.24 .29864 L
.244 .2993 L
.248 .29915 L
.252 .29844 L
.256 .2978 L
.26 .29756 L
.264 .29751 L
.268 .29751 L
.272 .29771 L
.276 .2983 L
.28 .299 L
.284 .29922 L
.288 .29864 L
.292 .29766 L
.296 .29703 L
.3 .29713 L
.304 .29769 L
.308 .29821 L
.312 .29844 L
.316 .2985 L
.32 .29852 L
.324 .2984 L
.328 .29794 L
.332 .29723 L
.336 .29677 L
.34 .29704 L
.344 .29802 L
.348 .29899 L
.352 .29915 L
.356 .29836 L
.36 .29734 L
.364 .297 L
.368 .2975 L
.372 .2981 L
.376 .29797 L
.38 .2972 L
.384 .29679 L
.388 .29754 L
.392 .29897 L
.396 .29961 L
.4 .29855 L
Mistroke
.404 .29659 L
.408 .29559 L
.412 .29661 L
.416 .29866 L
.42 .29958 L
.424 .2983 L
.428 .29609 L
.432 .29536 L
.436 .2972 L
.44 .3 L
.444 .30093 L
.448 .29876 L
.452 .29522 L
.456 .29352 L
.46 .29527 L
.464 .29888 L
.468 .30106 L
.472 .29986 L
.476 .29659 L
.48 .29446 L
.484 .29558 L
.488 .29891 L
.492 .3012 L
.496 .30007 L
.5 .29616 L
.504 .29271 L
.508 .2927 L
.512 .29637 L
.516 .301 L
.52 .30318 L
.524 .30146 L
.528 .29722 L
.532 .2934 L
.536 .29225 L
.54 .29395 L
.544 .29699 L
.548 .29951 L
.552 .30046 L
.556 .29989 L
.56 .29844 L
.564 .29682 L
.568 .29565 L
.572 .29545 L
.576 .29645 L
.58 .29822 L
.584 .29957 L
.588 .29913 L
.592 .29646 L
.596 .29277 L
.6 .29055 L
Mistroke
.604 .29203 L
.608 .29744 L
.612 .30426 L
.616 .30844 L
.62 .30684 L
.624 .29941 L
.628 .28968 L
.632 .28294 L
.636 .2832 L
.64 .29077 L
.644 .30194 L
.648 .31101 L
.652 .31335 L
.656 .30792 L
.66 .29761 L
.664 .28746 L
.668 .28196 L
.672 .28292 L
.676 .28897 L
.68 .29685 L
.684 .3033 L
.688 .3066 L
.692 .30685 L
.696 .30516 L
.7 .3025 L
.704 .29912 L
.708 .29468 L
.712 .28913 L
.716 .28346 L
.72 .27981 L
.724 .28062 L
.728 .28729 L
.732 .29916 L
.736 .31322 L
.74 .325 L
.744 .33029 L
.748 .32671 L
.752 .31475 L
.756 .2976 L
.76 .27988 L
.764 .26603 L
.768 .25879 L
.772 .25849 L
.776 .26339 L
.78 .27074 L
.784 .2781 L
.788 .28439 L
.792 .29022 L
.796 .29744 L
.8 .30819 L
Mistroke
.804 .32382 L
.808 .34416 L
.812 .36738 L
.816 .39056 L
.82 .41053 L
.824 .42489 L
.828 .43267 L
.832 .43464 L
.836 .43291 L
.84 .43035 L
.844 .42969 L
.848 .4328 L
.852 .44022 L
.856 .45109 L
.86 .46352 L
.864 .4751 L
.868 .48359 L
.872 .48747 L
.876 .48624 L
.88 .48051 L
.884 .47183 L
.888 .46226 L
.892 .45398 L
.896 .44888 L
.9 .44822 L
.904 .45244 L
.908 .46117 L
.912 .47333 L
.916 .48739 L
.92 .50159 L
.924 .51424 L
.928 .52394 L
.932 .52968 L
.936 .53091 L
.94 .52754 L
.944 .51988 L
.948 .50857 L
.952 .49445 L
.956 .47848 L
.96 .4616 L
.964 .44465 L
.968 .42833 L
.972 .41317 L
.976 .39954 L
.98 .38768 L
.984 .37767 L
.988 .36955 L
.992 .36319 L
.996 .35852 L
1 .3553 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .56832 m
.008 .57555 L
.012 .57798 L
.016 .57544 L
.02 .57471 L
.024 .57555 L
.028 .57583 L
.032 .57549 L
.036 .57542 L
.04 .5755 L
.044 .57555 L
.048 .5755 L
.052 .57551 L
.056 .57551 L
.06 .57553 L
.064 .57551 L
.068 .57553 L
.072 .57553 L
.076 .57554 L
.08 .57552 L
.084 .57552 L
.088 .5755 L
.092 .57549 L
.096 .57549 L
.1 .5755 L
.104 .57552 L
.108 .57554 L
.112 .57555 L
.116 .57555 L
.12 .57553 L
.124 .57551 L
.128 .57549 L
.132 .57549 L
.136 .57549 L
.14 .5755 L
.144 .57552 L
.148 .57553 L
.152 .57553 L
.156 .57553 L
.16 .57553 L
.164 .57553 L
.168 .57552 L
.172 .57551 L
.176 .5755 L
.18 .57549 L
.184 .57549 L
.188 .57549 L
.192 .5755 L
.196 .57553 L
.2 .57555 L
Mistroke
.204 .57555 L
.208 .57554 L
.212 .57553 L
.216 .57551 L
.22 .5755 L
.224 .57548 L
.228 .57547 L
.232 .57548 L
.236 .5755 L
.24 .57553 L
.244 .57554 L
.248 .57554 L
.252 .57555 L
.256 .57554 L
.26 .57553 L
.264 .5755 L
.268 .57548 L
.272 .57547 L
.276 .57548 L
.28 .57549 L
.284 .57549 L
.288 .5755 L
.292 .57553 L
.296 .57555 L
.3 .57556 L
.304 .57554 L
.308 .57551 L
.312 .57549 L
.316 .57549 L
.32 .5755 L
.324 .5755 L
.328 .57549 L
.332 .57548 L
.336 .57548 L
.34 .57551 L
.344 .57552 L
.348 .57552 L
.352 .57551 L
.356 .57551 L
.36 .57553 L
.364 .57556 L
.368 .57555 L
.372 .57551 L
.376 .57546 L
.38 .57544 L
.384 .57546 L
.388 .5755 L
.392 .57551 L
.396 .57548 L
.4 .57546 L
Mistroke
.404 .57549 L
.408 .57555 L
.412 .5756 L
.416 .57558 L
.42 .57551 L
.424 .57545 L
.428 .57546 L
.432 .57553 L
.436 .57558 L
.44 .57554 L
.444 .57543 L
.448 .57535 L
.452 .57536 L
.456 .57547 L
.46 .57556 L
.464 .57558 L
.468 .57551 L
.472 .57544 L
.476 .57548 L
.48 .57561 L
.484 .57574 L
.488 .57575 L
.492 .5756 L
.496 .57538 L
.5 .57523 L
.504 .57522 L
.508 .57533 L
.512 .57545 L
.516 .5755 L
.52 .57548 L
.524 .57544 L
.528 .57548 L
.532 .5756 L
.536 .57575 L
.54 .57582 L
.544 .57577 L
.548 .5756 L
.552 .5754 L
.556 .57525 L
.56 .57522 L
.564 .57529 L
.568 .57543 L
.572 .57556 L
.576 .5756 L
.58 .57553 L
.584 .57536 L
.588 .57519 L
.592 .57513 L
.596 .57526 L
.6 .57556 L
Mistroke
.604 .57591 L
.608 .57614 L
.612 .57612 L
.616 .57584 L
.62 .57544 L
.624 .57511 L
.628 .57502 L
.632 .5752 L
.636 .5755 L
.64 .57573 L
.644 .57573 L
.648 .57546 L
.652 .57507 L
.656 .57475 L
.66 .5747 L
.664 .57497 L
.668 .57545 L
.672 .57597 L
.676 .57633 L
.68 .57642 L
.684 .57624 L
.688 .57588 L
.692 .57546 L
.696 .57509 L
.7 .57484 L
.704 .57474 L
.708 .57483 L
.712 .5751 L
.716 .57556 L
.72 .57614 L
.724 .5767 L
.728 .57707 L
.732 .57707 L
.736 .57659 L
.74 .57565 L
.744 .57442 L
.748 .57318 L
.752 .57223 L
.756 .5718 L
.76 .57203 L
.764 .57288 L
.768 .57419 L
.772 .57574 L
.776 .5773 L
.78 .57872 L
.784 .57988 L
.788 .58075 L
.792 .58128 L
.796 .58141 L
.8 .58106 L
Mistroke
.804 .5801 L
.808 .57841 L
.812 .57592 L
.816 .57265 L
.82 .56869 L
.824 .56423 L
.828 .55949 L
.832 .55466 L
.836 .54986 L
.84 .54515 L
.844 .54048 L
.848 .5357 L
.852 .53066 L
.856 .52523 L
.86 .51931 L
.864 .51289 L
.868 .50606 L
.872 .49895 L
.876 .49175 L
.88 .48464 L
.884 .47777 L
.888 .47122 L
.892 .46501 L
.896 .45906 L
.9 .45327 L
.904 .4475 L
.908 .44158 L
.912 .43541 L
.916 .42889 L
.92 .42199 L
.924 .41475 L
.928 .40722 L
.932 .39954 L
.936 .39182 L
.94 .38422 L
.944 .37686 L
.948 .36985 L
.952 .36327 L
.956 .35716 L
.96 .35153 L
.964 .34637 L
.968 .34162 L
.972 .33724 L
.976 .33316 L
.98 .32931 L
.984 .32564 L
.988 .3221 L
.992 .31865 L
.996 .31527 L
1 .31195 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43219 L
.012 .4301 L
.016 .42921 L
.02 .42964 L
.024 .43003 L
.028 .42986 L
.032 .42972 L
.036 .42967 L
.04 .42972 L
.044 .42965 L
.048 .42961 L
.052 .42955 L
.056 .42955 L
.06 .4295 L
.064 .42949 L
.068 .42946 L
.072 .42945 L
.076 .42941 L
.08 .42939 L
.084 .42933 L
.088 .42929 L
.092 .42923 L
.096 .4292 L
.1 .42917 L
.104 .42917 L
.108 .42916 L
.112 .42915 L
.116 .42911 L
.12 .42907 L
.124 .42901 L
.128 .42896 L
.132 .42891 L
.136 .42888 L
.14 .42885 L
.144 .42885 L
.148 .42883 L
.152 .42881 L
.156 .42878 L
.16 .42875 L
.164 .42871 L
.168 .42867 L
.172 .42862 L
.176 .42857 L
.18 .42853 L
.184 .4285 L
.188 .42846 L
.192 .42845 L
.196 .42845 L
.2 .42845 L
Mistroke
.204 .42843 L
.208 .42839 L
.212 .42833 L
.216 .42827 L
.22 .42821 L
.224 .42816 L
.228 .42812 L
.232 .42811 L
.236 .42812 L
.24 .42811 L
.244 .42809 L
.248 .42805 L
.252 .42802 L
.256 .42799 L
.26 .42795 L
.264 .42788 L
.268 .42782 L
.272 .42778 L
.276 .42776 L
.28 .42775 L
.284 .42772 L
.288 .42769 L
.292 .42768 L
.296 .42768 L
.3 .42766 L
.304 .42761 L
.308 .42755 L
.312 .4275 L
.316 .42747 L
.32 .42744 L
.324 .4274 L
.328 .42735 L
.332 .42731 L
.336 .42729 L
.34 .42729 L
.344 .42728 L
.348 .42725 L
.352 .42719 L
.356 .42716 L
.36 .42716 L
.364 .42716 L
.368 .42712 L
.372 .42704 L
.376 .42694 L
.38 .42689 L
.384 .42689 L
.388 .4269 L
.392 .42687 L
.396 .4268 L
.4 .42675 L
Mistroke
.404 .42675 L
.408 .42681 L
.412 .42684 L
.416 .42679 L
.42 .42666 L
.424 .42655 L
.428 .42653 L
.432 .42658 L
.436 .42661 L
.44 .42654 L
.444 .42638 L
.448 .42624 L
.452 .42622 L
.456 .42632 L
.46 .42641 L
.464 .42639 L
.468 .42627 L
.472 .42616 L
.476 .42618 L
.48 .42631 L
.484 .42644 L
.488 .42642 L
.492 .4262 L
.496 .42589 L
.5 .42567 L
.504 .42564 L
.508 .42575 L
.512 .42587 L
.516 .4259 L
.52 .42583 L
.524 .42575 L
.528 .42576 L
.532 .42589 L
.536 .42604 L
.54 .4261 L
.544 .426 L
.548 .42576 L
.552 .42548 L
.556 .42526 L
.56 .42519 L
.564 .42525 L
.568 .4254 L
.572 .42553 L
.576 .42555 L
.58 .42542 L
.584 .42518 L
.588 .42493 L
.592 .42483 L
.596 .42496 L
.6 .42531 L
Mistroke
.604 .42572 L
.608 .42597 L
.612 .42591 L
.616 .42553 L
.62 .42499 L
.624 .42456 L
.628 .42442 L
.632 .42461 L
.636 .42495 L
.64 .42521 L
.644 .42517 L
.648 .4248 L
.652 .42428 L
.656 .42386 L
.66 .42377 L
.664 .42407 L
.668 .42465 L
.672 .42526 L
.676 .42567 L
.68 .42575 L
.684 .42549 L
.688 .42501 L
.692 .42446 L
.696 .42397 L
.7 .42362 L
.704 .42347 L
.708 .42355 L
.712 .42386 L
.716 .4244 L
.72 .42509 L
.724 .42576 L
.728 .42619 L
.732 .42616 L
.736 .42553 L
.74 .42433 L
.744 .42278 L
.748 .4212 L
.752 .41999 L
.756 .41944 L
.76 .41971 L
.764 .42075 L
.768 .42237 L
.772 .42429 L
.776 .42624 L
.78 .42801 L
.784 .42947 L
.788 .43058 L
.792 .43128 L
.796 .43151 L
.8 .43115 L
Mistroke
.804 .43006 L
.808 .42808 L
.812 .42514 L
.816 .42127 L
.82 .41659 L
.824 .41135 L
.828 .4058 L
.832 .40022 L
.836 .39476 L
.84 .3895 L
.844 .38436 L
.848 .3792 L
.852 .37384 L
.856 .36809 L
.86 .36186 L
.864 .35514 L
.868 .34802 L
.872 .3407 L
.876 .3334 L
.88 .32633 L
.884 .31967 L
.888 .31351 L
.892 .30786 L
.896 .30262 L
.9 .29764 L
.904 .2927 L
.908 .28761 L
.912 .28219 L
.916 .2763 L
.92 .26989 L
.924 .26299 L
.928 .25566 L
.932 .24804 L
.936 .2403 L
.94 .23261 L
.944 .22514 L
.948 .21805 L
.952 .21144 L
.956 .2054 L
.96 .19994 L
.964 .19509 L
.968 .19079 L
.972 .18702 L
.976 .18368 L
.98 .18073 L
.984 .17809 L
.988 .1757 L
.992 .17352 L
.996 .17151 L
1 .16965 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01P00Oomo
ogoo001oo`80009oo`04001oogoo0002Ool01@00Oomoogoo00000goo00<007oo00001Woo00@007oo
Ool000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007oo
Oomoo`D000=oo`8000Aoo`<0009oo`@000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<0
07ooOol0>goo00<007ooOol00P000goo0P000Woo00@007ooOol0025oo`008Woo0P0000=oo`000000
0Woo2`0000Aoo`00001ooaP00003Ool007oo00800004Ool00000Ool500001goo000007oo001oo`00
009oo`<0009oo`03001oogoo0080021oo`008WooH`0037oo000ROol01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`<00003Ool007oo009o
o`03001oo`00008000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00aoo`008Woo0P00AWoo0P0017oo00<007ooOol07Woo000ROol00`00Oomoo`16Ool00`00Oomoo`02
Ool00`00Oomoo`0NOol0029oo`8004eoo`03001oogoo01eoo`008Woo0P00CGoo00<007ooOol03goo
0P0037oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1<Ool00`00Oomo
o`0>Ool2000=Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00CGoo
00<007ooOol03Woo00<007ooOol037oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`8004ioo`03001oogoo00eoo`03001oogoo00aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1=Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00CWoo00<007ooOol037oo00<0
07ooOol03Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8004ioo`03001oogoo
00aoo`03001oogoo00eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0CGoo00<0
07oo00002goo00<007ooOol03Woo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001?
Ool3000:Ool00`00Oomoo`0>Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
009oo`80059oo`03001oogoo008000Eoo`03001oogoo00ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1AOol01P00Oomoo`00Ool000Aoo`03001oogoo00io
o`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00DWoo00<007oo00000Woo
00<007ooOol00Woo00<007ooOol03Woo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
0`00Oomoo`02001BOol00`00Ool00002Ool01@00Oomoogoo00004Goo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool01000Oomoo`00E7oo00D007ooOomoo`0000=oo`03001oogoo00moo`00
2goo0P002Woo0P000goo0`000goo0P00F7oo00@007ooOol0015oo`008Woo00<007ooOol0Egoo00<0
07oo00004Woo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001IOol2000BOol000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008005Uoo`80019oo`002Woo00@0
07ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02
001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`80
00Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eo
o`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol5
0002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03
Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool2
0003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uo
o`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<0
07ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomo
o`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]o
o`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03
001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04
001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol4
0003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=o
o`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04
001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Ao
o`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<0
07oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol0
0goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009o
o`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00
:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol0
3Woo0`0037oo000XOol00`00Oomoo`1FOol2000>Ool002Qoo`03001oogoo05Ioo`03001oogoo00eo
o`00:7oo00<007ooOol0EGoo00<007ooOol03Woo000XOol00`00Oomoo`1DOol00`00Oomoo`0?Ool0
02Qoo`03001oogoo05=oo`80015oo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`00
0goo00<007ooOol0Dgoo00<007ooOol047oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06
001oogoo001oo`000goo00@007ooOol005Aoo`80019oo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOol005Aoo`03001oogoo015oo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00DWoo0P004goo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1AOol00`00Oomoo`0B
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1@
Ool2000DOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo04moo`8001Eoo`00:7oo
00<007ooOol0Cgoo00<007ooOol057oo000XOol00`00Oomoo`1>Ool00`00Oomoo`0EOol0015oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo04ioo`03001oogoo01Eoo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1=Ool00`00Oomoo`0FOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0C7oo00<007oo
Ool05goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8004eoo`03001o
ogoo01Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1;
Ool00`00Oomoo`0HOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0
BWoo0P006Woo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1:Ool00`00Oomoo`0I
Ool002Qoo`03001oogoo04Qoo`8001aoo`00:7oo>00000=oo`0000000`0000=oo`0000000P0000=o
o`0000000P000goo00<007ooOol06goo000XOol200000goo001oo`0bOol20005Ool20002Ool20003
Ool4000NOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Io
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00
Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo
0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@0
07ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00
Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003
Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool0
1000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<0
07ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eo
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04
001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04
001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04
001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001ao
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol00003
Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00@007ooOomoo`8000aoo`0077oo00<007ooOol0HWoo0`003Goo000LOol2001ROol2000?
Ool001aoo`03001oogoo061oo`80011oo`0077oo00<007ooOol0H7oo00<007ooOol03goo000LOol2
001POol00`00Oomoo`0@Ool001aoo`03001oogoo05moo`03001oogoo011oo`0077oo00<007ooOol0
GWoo00<007ooOol04Goo000LOol2001OOol00`00Oomoo`0AOol001aoo`03001oogoo05eoo`03001o
ogoo019oo`0077oo0P00GWoo00<007ooOol04Woo000;Ool20004Ool00`00Oomoo`02Ool30003Ool0
0`00Oomoo`1LOol00`00Oomoo`0COol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0Fgoo00<007ooOol057oo000:Ool01000Oomoo`002goo00<007ooOol00P00Fgoo0P005Woo
000:Ool01000Oomoo`002goo00@007ooOol005]oo`8001Moo`002Woo00@007ooOol000Moo`@000=o
o`03001oogoo05Uoo`03001oogoo01Ioo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8005Uo
o`8001Qoo`002goo0P0027oo1@000Woo00<007ooOol0F7oo00<007ooOol05goo000LOol00`00Oomo
o`1GOol00`00Oomoo`0HOol001aoo`8005Qoo`03001oogoo01Qoo`0077oo00<007ooOol0EWoo00<0
07ooOol06Goo000LOol2001FOol2000KOol001aoo`03001oogoo05Aoo`8001aoo`0077oo00<007oo
Ool0E7oo00<007ooOol06goo000LOol2001DOol00`00Oomoo`0LOol001Ioo`<000=oo`03001oogoo
059oo`8001ioo`005goo00<007ooOol00Woo00<007ooOol0?Woo0P0000=oo`0000000Woo0`000Woo
100017oo00<007ooOol07Goo000GOol00`00Oomoo`02Oom100000goo00000002Ool20003Ool20003
Ool5000POol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007oo
Ool0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;
Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool0
1000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Mo
o`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool0
0`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(31062\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29628 m
.008 .29772 L
.012 .29991 L
.016 .30032 L
.02 .2988 L
.024 .29829 L
.028 .29882 L
.032 .29884 L
.036 .29854 L
.04 .29868 L
.044 .29912 L
.048 .29934 L
.052 .29916 L
.056 .29883 L
.06 .29853 L
.064 .29833 L
.068 .2984 L
.072 .29867 L
.076 .299 L
.08 .2992 L
.084 .29908 L
.088 .29874 L
.092 .29842 L
.096 .29829 L
.1 .29845 L
.104 .2987 L
.108 .29891 L
.112 .29898 L
.116 .2988 L
.12 .29845 L
.124 .29819 L
.128 .29826 L
.132 .29861 L
.136 .29892 L
.14 .29897 L
.144 .2988 L
.148 .29852 L
.152 .29819 L
.156 .29795 L
.16 .29803 L
.164 .29846 L
.168 .29895 L
.172 .29908 L
.176 .29882 L
.18 .29843 L
.184 .29816 L
.188 .29799 L
.192 .29789 L
.196 .29803 L
.2 .2985 L
Mistroke
.204 .29898 L
.208 .29903 L
.212 .29857 L
.216 .29802 L
.22 .29777 L
.224 .29784 L
.228 .29803 L
.232 .29829 L
.236 .29869 L
.24 .29903 L
.244 .29888 L
.248 .29811 L
.252 .29728 L
.256 .29711 L
.26 .29775 L
.264 .29862 L
.268 .29905 L
.272 .29892 L
.276 .29853 L
.28 .29813 L
.284 .2977 L
.288 .29728 L
.292 .29718 L
.296 .29767 L
.3 .29855 L
.304 .29916 L
.308 .299 L
.312 .29823 L
.316 .29748 L
.32 .29726 L
.324 .29749 L
.328 .29781 L
.332 .29796 L
.336 .29807 L
.34 .29834 L
.344 .29866 L
.348 .29862 L
.352 .29796 L
.356 .29703 L
.36 .29658 L
.364 .29712 L
.368 .29827 L
.372 .29905 L
.376 .29879 L
.38 .29779 L
.384 .29711 L
.388 .29741 L
.392 .2982 L
.396 .2984 L
.4 .29753 L
Mistroke
.404 .29645 L
.408 .29649 L
.412 .29794 L
.416 .29951 L
.42 .29955 L
.424 .29784 L
.428 .29598 L
.432 .29587 L
.436 .29763 L
.44 .29939 L
.444 .29915 L
.448 .29695 L
.452 .29502 L
.456 .29558 L
.46 .29848 L
.464 .3011 L
.468 .3008 L
.472 .29758 L
.476 .29417 L
.48 .29362 L
.484 .29637 L
.488 .29984 L
.492 .30086 L
.496 .29861 L
.5 .29536 L
.504 .29428 L
.508 .29651 L
.512 .30006 L
.516 .30163 L
.52 .29956 L
.524 .29536 L
.528 .29236 L
.532 .29298 L
.536 .2968 L
.54 .301 L
.544 .30267 L
.548 .30091 L
.552 .29719 L
.556 .29396 L
.56 .29292 L
.564 .29415 L
.568 .29652 L
.572 .29872 L
.576 .29994 L
.58 .29995 L
.584 .29886 L
.588 .29712 L
.592 .29554 L
.596 .29508 L
.6 .29627 L
Mistroke
.604 .2986 L
.608 .30045 L
.612 .3 L
.616 .2967 L
.62 .29207 L
.624 .28912 L
.628 .29049 L
.632 .29646 L
.636 .30425 L
.64 .30938 L
.644 .30832 L
.648 .30086 L
.652 .29056 L
.656 .2829 L
.66 .28223 L
.664 .28918 L
.668 .30029 L
.672 .30995 L
.676 .31337 L
.68 .30914 L
.684 .29964 L
.688 .28955 L
.692 .28328 L
.696 .28287 L
.7 .28747 L
.704 .29435 L
.708 .30062 L
.712 .30461 L
.716 .30619 L
.72 .30607 L
.724 .30481 L
.728 .30228 L
.732 .29793 L
.736 .29163 L
.74 .28445 L
.744 .27879 L
.748 .27754 L
.752 .28267 L
.756 .29405 L
.76 .309 L
.764 .32304 L
.768 .33152 L
.772 .33132 L
.776 .3221 L
.78 .30637 L
.784 .28851 L
.788 .27313 L
.792 .26349 L
.796 .26062 L
.8 .26334 L
Mistroke
.804 .26919 L
.808 .27568 L
.812 .28145 L
.816 .28676 L
.82 .29323 L
.824 .30303 L
.828 .31777 L
.832 .33769 L
.836 .36141 L
.84 .3862 L
.844 .4088 L
.848 .4264 L
.852 .43745 L
.856 .44203 L
.86 .44181 L
.864 .43944 L
.868 .43782 L
.872 .43924 L
.876 .4448 L
.88 .45424 L
.884 .46605 L
.888 .47795 L
.892 .48759 L
.896 .49307 L
.9 .49344 L
.904 .48885 L
.908 .48045 L
.912 .47014 L
.916 .46014 L
.92 .45257 L
.924 .44907 L
.928 .45055 L
.932 .45708 L
.936 .46794 L
.94 .48181 L
.944 .497 L
.948 .51175 L
.952 .52445 L
.956 .53385 L
.96 .53909 L
.964 .53986 L
.968 .53623 L
.972 .52874 L
.976 .51813 L
.98 .50544 L
.984 .49166 L
.988 .47779 L
.992 .46471 L
.996 .45302 L
1 .44336 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57119 m
.008 .57491 L
.012 .57631 L
.016 .57524 L
.02 .57475 L
.024 .57498 L
.028 .57521 L
.032 .57511 L
.036 .57506 L
.04 .57506 L
.044 .57511 L
.048 .5751 L
.052 .5751 L
.056 .57508 L
.06 .5751 L
.064 .57508 L
.068 .57509 L
.072 .57508 L
.076 .57509 L
.08 .57508 L
.084 .57509 L
.088 .57508 L
.092 .5751 L
.096 .5751 L
.1 .57511 L
.104 .5751 L
.108 .5751 L
.112 .57508 L
.116 .57507 L
.12 .57506 L
.124 .57507 L
.128 .57508 L
.132 .5751 L
.136 .57511 L
.14 .57512 L
.144 .57511 L
.148 .5751 L
.152 .57507 L
.156 .57506 L
.16 .57506 L
.164 .57507 L
.168 .57508 L
.172 .57509 L
.176 .5751 L
.18 .5751 L
.184 .57511 L
.188 .57511 L
.192 .5751 L
.196 .57509 L
.2 .57508 L
Mistroke
.204 .57506 L
.208 .57505 L
.212 .57505 L
.216 .57507 L
.22 .5751 L
.224 .57512 L
.228 .57512 L
.232 .57512 L
.236 .57511 L
.24 .57509 L
.244 .57507 L
.248 .57504 L
.252 .57504 L
.256 .57505 L
.26 .57507 L
.264 .57509 L
.268 .5751 L
.272 .57511 L
.276 .57513 L
.28 .57512 L
.284 .5751 L
.288 .57507 L
.292 .57506 L
.296 .57506 L
.3 .57506 L
.304 .57506 L
.308 .57506 L
.312 .57507 L
.316 .57509 L
.32 .57512 L
.324 .57512 L
.328 .57511 L
.332 .57509 L
.336 .57508 L
.34 .57508 L
.344 .57508 L
.348 .57506 L
.352 .57504 L
.356 .57504 L
.36 .57506 L
.364 .57508 L
.368 .57509 L
.372 .57508 L
.376 .57507 L
.38 .57509 L
.384 .57512 L
.388 .57514 L
.392 .57512 L
.396 .57507 L
.4 .57503 L
Mistroke
.404 .57504 L
.408 .57507 L
.412 .57508 L
.416 .57505 L
.42 .57501 L
.424 .57501 L
.428 .57507 L
.432 .57515 L
.436 .57518 L
.44 .57513 L
.444 .57505 L
.448 .57502 L
.452 .57507 L
.456 .57514 L
.46 .57516 L
.464 .57509 L
.468 .57498 L
.472 .57492 L
.476 .57497 L
.48 .57507 L
.484 .57513 L
.488 .5751 L
.492 .57501 L
.496 .57497 L
.5 .57506 L
.504 .57522 L
.508 .57534 L
.512 .57532 L
.516 .57516 L
.52 .57496 L
.524 .57484 L
.528 .57484 L
.532 .57493 L
.536 .57501 L
.54 .57502 L
.544 .57498 L
.548 .57496 L
.552 .57502 L
.556 .57516 L
.56 .57531 L
.564 .5754 L
.568 .57536 L
.572 .57521 L
.576 .57502 L
.58 .57486 L
.584 .5748 L
.588 .57485 L
.592 .57499 L
.596 .57513 L
.6 .57519 L
Mistroke
.604 .57512 L
.608 .57494 L
.612 .57474 L
.616 .57464 L
.62 .57475 L
.624 .57506 L
.628 .57543 L
.632 .5757 L
.636 .57571 L
.64 .57546 L
.644 .57507 L
.648 .57474 L
.652 .57464 L
.656 .57479 L
.66 .57508 L
.664 .57532 L
.668 .57532 L
.672 .57507 L
.676 .57468 L
.68 .57434 L
.684 .57424 L
.688 .57444 L
.692 .57487 L
.696 .57538 L
.7 .57577 L
.704 .57594 L
.708 .57586 L
.712 .57559 L
.716 .57522 L
.72 .57484 L
.724 .57452 L
.728 .57431 L
.732 .57427 L
.736 .57444 L
.74 .57483 L
.744 .5754 L
.748 .57604 L
.752 .57654 L
.756 .57672 L
.76 .57641 L
.764 .57561 L
.768 .57442 L
.772 .57309 L
.776 .57192 L
.78 .57118 L
.784 .57103 L
.788 .57149 L
.792 .57245 L
.796 .57371 L
.8 .57508 L
Mistroke
.804 .57638 L
.808 .57748 L
.812 .57834 L
.816 .57889 L
.82 .57907 L
.824 .57879 L
.828 .57792 L
.832 .57631 L
.836 .57387 L
.84 .57059 L
.844 .56652 L
.848 .56184 L
.852 .55674 L
.856 .55145 L
.86 .54613 L
.864 .54087 L
.868 .53566 L
.872 .53042 L
.876 .52501 L
.88 .51929 L
.884 .51317 L
.888 .5066 L
.892 .49963 L
.896 .4924 L
.9 .48506 L
.904 .47781 L
.908 .47081 L
.912 .46417 L
.916 .45793 L
.92 .45205 L
.924 .44645 L
.928 .44096 L
.932 .43544 L
.936 .42971 L
.94 .42367 L
.944 .41723 L
.948 .41036 L
.952 .40312 L
.956 .39558 L
.96 .38785 L
.964 .38008 L
.968 .37241 L
.972 .36495 L
.976 .35781 L
.98 .35107 L
.984 .34474 L
.988 .33885 L
.992 .33334 L
.996 .32818 L
1 .32327 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42498 L
.012 .43003 L
.016 .43163 L
.02 .42976 L
.024 .42924 L
.028 .42977 L
.032 .42994 L
.036 .42966 L
.04 .42961 L
.044 .42965 L
.048 .42967 L
.052 .42959 L
.056 .42957 L
.06 .42952 L
.064 .4295 L
.068 .42944 L
.072 .42942 L
.076 .42937 L
.08 .42935 L
.084 .42931 L
.088 .4293 L
.092 .42927 L
.096 .42926 L
.1 .42923 L
.104 .4292 L
.108 .42914 L
.112 .42909 L
.116 .42903 L
.12 .429 L
.124 .42898 L
.128 .42898 L
.132 .42897 L
.136 .42896 L
.14 .42892 L
.144 .42888 L
.148 .42882 L
.152 .42877 L
.156 .42872 L
.16 .42869 L
.164 .42867 L
.168 .42865 L
.172 .42863 L
.176 .42861 L
.18 .42859 L
.184 .42857 L
.188 .42853 L
.192 .42848 L
.196 .42843 L
.2 .42839 L
Mistroke
.204 .42834 L
.208 .4283 L
.212 .42827 L
.216 .42827 L
.22 .42826 L
.224 .42825 L
.228 .42822 L
.232 .42819 L
.236 .42815 L
.24 .4281 L
.244 .42803 L
.248 .42797 L
.252 .42794 L
.256 .42792 L
.26 .42791 L
.264 .4279 L
.268 .42788 L
.272 .42786 L
.276 .42784 L
.28 .42782 L
.284 .42776 L
.288 .4277 L
.292 .42765 L
.296 .42761 L
.3 .42757 L
.304 .42753 L
.308 .4275 L
.312 .4275 L
.316 .4275 L
.32 .4275 L
.324 .42747 L
.328 .42741 L
.332 .42736 L
.336 .42732 L
.34 .42729 L
.344 .42726 L
.348 .4272 L
.352 .42715 L
.356 .42712 L
.36 .42711 L
.364 .42711 L
.368 .42708 L
.372 .42703 L
.376 .42698 L
.38 .42698 L
.384 .427 L
.388 .42699 L
.392 .42693 L
.396 .42683 L
.4 .42675 L
Mistroke
.404 .42672 L
.408 .42673 L
.412 .42672 L
.416 .42666 L
.42 .42658 L
.424 .42654 L
.428 .42658 L
.432 .42665 L
.436 .42665 L
.44 .42656 L
.444 .42643 L
.448 .42636 L
.452 .42639 L
.456 .42645 L
.46 .42645 L
.464 .42632 L
.468 .42615 L
.472 .42604 L
.476 .42607 L
.48 .42617 L
.484 .42622 L
.488 .42615 L
.492 .42601 L
.496 .42593 L
.5 .42599 L
.504 .42616 L
.508 .42629 L
.512 .42624 L
.516 .42601 L
.52 .42573 L
.524 .42554 L
.528 .42551 L
.532 .42559 L
.536 .42566 L
.54 .42564 L
.544 .42556 L
.548 .4255 L
.552 .42555 L
.556 .42569 L
.56 .42585 L
.564 .42592 L
.568 .42584 L
.572 .42562 L
.576 .42535 L
.58 .42513 L
.584 .42502 L
.588 .42506 L
.592 .42519 L
.596 .42534 L
.6 .42539 L
Mistroke
.604 .42527 L
.608 .42501 L
.612 .42472 L
.616 .42457 L
.62 .42468 L
.624 .42503 L
.628 .42547 L
.632 .42576 L
.636 .42575 L
.64 .4254 L
.644 .42488 L
.648 .42444 L
.652 .42428 L
.656 .42444 L
.66 .42478 L
.664 .42504 L
.668 .42502 L
.672 .42467 L
.676 .42415 L
.68 .4237 L
.684 .42354 L
.688 .42376 L
.692 .42427 L
.696 .42487 L
.7 .42533 L
.704 .42551 L
.708 .42538 L
.712 .42501 L
.716 .42452 L
.72 .42402 L
.724 .4236 L
.728 .42332 L
.732 .42325 L
.736 .42344 L
.74 .42391 L
.744 .42462 L
.748 .42541 L
.752 .42604 L
.756 .42627 L
.76 .42592 L
.764 .42495 L
.768 .42353 L
.772 .42195 L
.776 .42059 L
.78 .4198 L
.784 .41977 L
.788 .42054 L
.792 .42197 L
.796 .42384 L
.8 .42589 L
Mistroke
.804 .42792 L
.808 .42979 L
.812 .43142 L
.816 .43277 L
.82 .43376 L
.824 .43427 L
.828 .43416 L
.832 .43325 L
.836 .43144 L
.84 .4287 L
.844 .42511 L
.848 .42088 L
.852 .41626 L
.856 .41152 L
.86 .40684 L
.864 .40234 L
.868 .39798 L
.872 .39365 L
.876 .38914 L
.88 .38427 L
.884 .37889 L
.888 .37294 L
.892 .36645 L
.896 .35956 L
.9 .35248 L
.904 .34542 L
.908 .33858 L
.912 .3321 L
.916 .32604 L
.92 .32036 L
.924 .31496 L
.928 .30968 L
.932 .30434 L
.936 .29875 L
.94 .2928 L
.944 .28641 L
.948 .27957 L
.952 .27233 L
.956 .26481 L
.96 .25717 L
.964 .24956 L
.968 .24215 L
.972 .23511 L
.976 .22856 L
.98 .22258 L
.984 .21722 L
.988 .21252 L
.992 .20846 L
.996 .20502 L
1 .20214 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo10000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eo
o`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D0
00=oo`8000Aoo`@000=oo`<000=oo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol0
?Goo00D007ooOomoo`0000=oo`8000=oo`04001oo`00000NOol0029oo`<00003Ool007oo00800004
Ool00000Ool2000017oo000007oo300000=oo`000000500000=oo`0000001`0000Qoo`00001oo`00
Ool007oo0P0000Eoo`00Oomoo`00009oo`03001oogoo01aoo`008WooH`0037oo000ROol01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoo`000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`05
001oogooOol00003Ool02@00Oomoogoo001oo`00Ool00002Ool20003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000aoo`008Woo0P00BGoo0P0017oo00<007ooOol06goo000ROol00`00Oomoo`18
Ool00`00Oomoo`03Ool00`00Oomoo`0KOol0029oo`8004moo`03001oogoo01]oo`008Woo0P00D7oo
00<007ooOol06Woo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1?Ool0
0`00Oomoo`0JOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00D7oo
00<007ooOol06Woo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80051o
o`03001oogoo01Yoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1?Ool00`00Oomoo`0JOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P00D7oo00<007ooOol06Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`80
051oo`03001oogoo01Yoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0D7oo00<0
07ooOol06Goo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001AOol3000IOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8005=oo`03001oogoo009oo`80
00Ioo`03001oogoo00Yoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1COol01P00Oomoo`00Ool000Eoo`03001oogoo00]oo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01000Oomoogoo0P00E7oo00H007ooOol007oo0005Ool00`00Oomoo`0;Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008005Eoo`03001oo`00009oo`05
001oogooOol0000>Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001F
Ool20003Ool01@00Oomoogoo00003Woo000;Ool2000:Ool20003Ool30003Ool2001JOol01@00Oomo
ogoo00003Woo000ROol00`00Oomoo`1IOol01@00Oomoogoo00003Woo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001KOol00`00Ool0000?Ool000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`03001oogoo008005]oo`03001oo`0000moo`002Woo00@007ooOol000Qoo`04001o
ogoo0005Ool01000Oomoo`00GGoo00<007ooOol03Woo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]
Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yo
o`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`00
8Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool2
0003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool2
0004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007oo
Ool0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003
Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05
001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007oo
Ool00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007oo
Ool03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`80
00Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001o
ogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001o
ogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003
Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03
001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001o
ogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06
001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo
00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo
0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D0
00=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo
00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo
00<007ooOol02Woo000XOol00`00Oomoo`1HOol00`00Oomoo`0;Ool002Qoo`03001oogoo05Moo`03
001oogoo00aoo`00:7oo00<007ooOol0Egoo00<007ooOol037oo000XOol00`00Oomoo`1FOol00`00
Oomoo`0=Ool002Qoo`03001oogoo05Ioo`03001oogoo00eoo`002goo0P0017oo00<007ooOol00goo
0P0017oo0P000goo0`000goo00<007ooOol0EGoo00<007ooOol03Woo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol005Moo`03001oogoo00ioo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol005Ioo`03001oogoo
00moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00
E7oo00<007ooOol047oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`04
0003Ool00`00Oomoo`1COol00`00Oomoo`0@Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0006Ool00`00Oomoo`1BOol00`00Oomoo`0AOol000]oo`8000Yoo`8000Aoo`80
009oo`D0009oo`03001oogoo055oo`8001=oo`00:7oo00<007ooOol0DGoo00<007ooOol04Woo000X
Ool00`00Oomoo`1@Ool00`00Oomoo`0COol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`03001oogoo04moo`8001Eoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1?Ool00`00Oomoo`0DOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0CWoo0P005Woo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8004moo`03001oogoo01Eoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1=Ool00`00Oomoo`0FOol0011oo`04001oogoo0008Ool01000Oomo
o`000Woo0P0017oo00<007ooOol0C7oo00<007ooOol05goo000AOol2000:Ool20004Ool00`00Oomo
o`02Ool00`00Oomoo`1;Ool2000IOol002Qoo`03001oogoo04]oo`03001oogoo01Qoo`00:7ooA@00
00=oo`0000000P000goo00<007ooOol06Goo000XOol2000nOol20003Ool20003Ool3000LOol000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool0
1000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`00
2Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo
00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004
Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005
Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007oo
Ool0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06
001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<0
07ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001o
ogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool0
01aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo
00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0
01aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003
Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo
Ool00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1TOol2000<Ool001aoo`8006Aoo`03001oogoo00aoo`0077oo00<007oo
Ool0HWoo00<007ooOol03Goo000LOol00`00Oomoo`1ROol00`00Oomoo`0=Ool001aoo`80069oo`03
001oogoo00ioo`0077oo00<007ooOol0H7oo00<007ooOol03goo000LOol2001QOol00`00Oomoo`0?
Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo061oo`03001oogoo00moo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1OOol00`00Oomoo`0@Ool000Yoo`04
001oogoo000;Ool00`00Oomoo`02001OOol00`00Oomoo`0AOol000Yoo`04001oogoo000;Ool01000
Oomoo`00H7oo00<007ooOol04Goo000:Ool01000Oomoo`001goo10000goo00<007ooOol0GGoo00<0
07ooOol04Woo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00GGoo00<007ooOol04goo000;
Ool20008Ool50002Ool00`00Oomoo`1KOol00`00Oomoo`0DOol001aoo`03001oogoo05]oo`03001o
ogoo01Aoo`0077oo0P00Fgoo00<007ooOol05Goo000LOol00`00Oomoo`1IOol2000GOol001aoo`80
05Yoo`03001oogoo01Ioo`0077oo00<007ooOol0F7oo0P0067oo000LOol00`00Oomoo`1GOol2000I
Ool001aoo`8005Qoo`03001oogoo01Qoo`005Woo0`000goo00<007ooOol0EWoo00<007ooOol06Goo
000GOol00`00Oomoo`02Ool00`00Oomoo`0mOol00`00Oomoo`0200001Goo00000000Ool010000Woo
0`001Goo00<007ooOol06Woo000GOol00`00Oomoo`02Oom000000goo000000030002Ool30003Ool2
0003Ool5000MOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo00<0
07ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo
000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;
Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo
00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;
Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(31229\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29738 m
.008 .29894 L
.012 .29917 L
.016 .29934 L
.02 .29915 L
.024 .29893 L
.028 .29898 L
.032 .299 L
.036 .29885 L
.04 .29872 L
.044 .29876 L
.048 .29888 L
.052 .29892 L
.056 .29885 L
.06 .29882 L
.064 .29881 L
.068 .29884 L
.072 .29889 L
.076 .29889 L
.08 .29885 L
.084 .29873 L
.088 .29854 L
.092 .29848 L
.096 .29859 L
.1 .29881 L
.104 .29898 L
.108 .29897 L
.112 .29882 L
.116 .29859 L
.12 .29834 L
.124 .29827 L
.128 .29847 L
.132 .29883 L
.136 .29903 L
.14 .29888 L
.144 .29853 L
.148 .29825 L
.152 .29817 L
.156 .2983 L
.16 .29861 L
.164 .29897 L
.168 .2991 L
.172 .29878 L
.176 .29816 L
.18 .29774 L
.184 .29785 L
.188 .29836 L
.192 .29883 L
.196 .29902 L
.2 .29897 L
Mistroke
.204 .29868 L
.208 .29817 L
.212 .29767 L
.216 .29758 L
.22 .29808 L
.224 .29876 L
.228 .29906 L
.232 .29882 L
.236 .29839 L
.24 .29808 L
.244 .29791 L
.248 .29776 L
.252 .29778 L
.256 .29818 L
.26 .29882 L
.264 .29915 L
.268 .29877 L
.272 .29796 L
.276 .29736 L
.28 .29736 L
.284 .29777 L
.288 .29821 L
.292 .29855 L
.296 .29882 L
.3 .29891 L
.304 .29856 L
.308 .29776 L
.312 .29699 L
.316 .2969 L
.32 .29762 L
.324 .2986 L
.328 .29909 L
.332 .29882 L
.336 .29816 L
.34 .29765 L
.344 .29753 L
.348 .29757 L
.352 .29754 L
.356 .29752 L
.36 .2978 L
.364 .29846 L
.368 .29902 L
.372 .29886 L
.376 .29787 L
.38 .29674 L
.384 .29644 L
.388 .29725 L
.392 .29842 L
.396 .29887 L
.4 .29829 L
Mistroke
.404 .29746 L
.408 .29739 L
.412 .29812 L
.416 .29865 L
.42 .29803 L
.424 .29662 L
.428 .29589 L
.432 .29686 L
.436 .29886 L
.44 .29998 L
.444 .29899 L
.448 .29675 L
.452 .29547 L
.456 .29648 L
.46 .29875 L
.464 .29985 L
.468 .29843 L
.472 .29573 L
.476 .29448 L
.48 .29622 L
.484 .29958 L
.488 .30149 L
.492 .30006 L
.496 .29643 L
.5 .29382 L
.504 .29449 L
.508 .29768 L
.512 .30035 L
.516 .30001 L
.52 .29704 L
.524 .29433 L
.528 .29453 L
.532 .29768 L
.536 .30112 L
.54 .30179 L
.544 .29892 L
.548 .29463 L
.552 .29216 L
.556 .29331 L
.56 .29715 L
.564 .30093 L
.568 .30224 L
.572 .30056 L
.576 .29727 L
.58 .29441 L
.584 .29331 L
.588 .2941 L
.592 .29605 L
.596 .29822 L
.6 .29978 L
Mistroke
.604 .30016 L
.608 .29912 L
.612 .29706 L
.616 .29508 L
.62 .29457 L
.624 .29623 L
.628 .29927 L
.632 .30158 L
.636 .301 L
.64 .29695 L
.644 .29133 L
.648 .28767 L
.652 .28893 L
.656 .29542 L
.66 .3041 L
.664 .31011 L
.668 .30963 L
.672 .30227 L
.676 .29158 L
.68 .28318 L
.684 .28161 L
.688 .28781 L
.692 .29865 L
.696 .30866 L
.7 .31306 L
.704 .31008 L
.708 .30164 L
.712 .29194 L
.716 .28519 L
.72 .28357 L
.724 .28668 L
.728 .29235 L
.732 .29814 L
.736 .30258 L
.74 .30541 L
.744 .30699 L
.748 .30746 L
.752 .30627 L
.756 .30257 L
.76 .29606 L
.764 .28782 L
.768 .28044 L
.772 .2772 L
.776 .28066 L
.78 .29126 L
.784 .30679 L
.788 .32293 L
.792 .33471 L
.796 .33835 L
.8 .33264 L
Mistroke
.804 .31929 L
.808 .30222 L
.812 .28604 L
.816 .27444 L
.82 .2691 L
.824 .26945 L
.828 .27338 L
.832 .27844 L
.836 .28303 L
.84 .28704 L
.844 .29183 L
.848 .29955 L
.852 .31205 L
.856 .33005 L
.86 .35262 L
.864 .37737 L
.868 .40108 L
.872 .42066 L
.876 .43404 L
.88 .44069 L
.884 .44175 L
.888 .43963 L
.892 .43726 L
.896 .43727 L
.9 .44133 L
.904 .44974 L
.908 .46147 L
.912 .47452 L
.916 .48647 L
.92 .49514 L
.924 .49909 L
.928 .49791 L
.932 .4923 L
.936 .48384 L
.94 .4747 L
.944 .46714 L
.948 .46319 L
.952 .46421 L
.956 .47081 L
.96 .48274 L
.964 .49905 L
.968 .5183 L
.972 .53868 L
.976 .55858 L
.98 .57615 L
.984 .59042 L
.988 .60006 L
.992 .60507 L
.996 .60476 L
1 .59991 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .58116 m
.008 .57455 L
.012 .57246 L
.016 .57473 L
.02 .57544 L
.024 .57459 L
.028 .5744 L
.032 .57467 L
.036 .57478 L
.04 .57466 L
.044 .57465 L
.048 .57466 L
.052 .57468 L
.056 .57464 L
.06 .57465 L
.064 .57465 L
.068 .57467 L
.072 .57466 L
.076 .57467 L
.08 .57467 L
.084 .57467 L
.088 .57466 L
.092 .57467 L
.096 .57466 L
.1 .57466 L
.104 .57464 L
.108 .57465 L
.112 .57465 L
.116 .57467 L
.12 .57468 L
.124 .57469 L
.128 .57468 L
.132 .57467 L
.136 .57465 L
.14 .57464 L
.144 .57463 L
.148 .57464 L
.152 .57465 L
.156 .57467 L
.16 .57468 L
.164 .57469 L
.168 .57469 L
.172 .57467 L
.176 .57465 L
.18 .57464 L
.184 .57463 L
.188 .57463 L
.192 .57464 L
.196 .57466 L
.2 .57467 L
Mistroke
.204 .57468 L
.208 .57468 L
.212 .57468 L
.216 .57467 L
.22 .57467 L
.224 .57465 L
.228 .57463 L
.232 .57462 L
.236 .57463 L
.24 .57464 L
.244 .57466 L
.248 .57468 L
.252 .57469 L
.256 .5747 L
.26 .57469 L
.264 .57467 L
.268 .57464 L
.272 .57462 L
.276 .57463 L
.28 .57463 L
.284 .57464 L
.288 .57464 L
.292 .57466 L
.296 .57468 L
.3 .5747 L
.304 .57469 L
.308 .57468 L
.312 .57466 L
.316 .57465 L
.32 .57464 L
.324 .57462 L
.328 .57461 L
.332 .57461 L
.336 .57464 L
.34 .57467 L
.344 .57469 L
.348 .57469 L
.352 .57467 L
.356 .57466 L
.36 .57467 L
.364 .57466 L
.368 .57465 L
.372 .57463 L
.376 .57461 L
.38 .57463 L
.384 .57465 L
.388 .57466 L
.392 .57464 L
.396 .57462 L
.4 .57463 L
Mistroke
.404 .57467 L
.408 .57471 L
.412 .57472 L
.416 .57468 L
.42 .57463 L
.424 .57461 L
.428 .57463 L
.432 .57466 L
.436 .57464 L
.44 .57459 L
.444 .57456 L
.448 .57459 L
.452 .57467 L
.456 .57473 L
.46 .57473 L
.464 .57466 L
.468 .5746 L
.472 .57461 L
.476 .57468 L
.48 .57475 L
.484 .57473 L
.488 .57463 L
.492 .57453 L
.496 .5745 L
.5 .57458 L
.504 .57467 L
.508 .57469 L
.512 .57462 L
.516 .57453 L
.52 .57452 L
.524 .57463 L
.528 .5748 L
.532 .57492 L
.536 .57489 L
.54 .57474 L
.544 .57456 L
.548 .57446 L
.552 .57447 L
.556 .57453 L
.56 .57457 L
.564 .57455 L
.568 .5745 L
.572 .57449 L
.576 .57456 L
.58 .57471 L
.584 .57487 L
.588 .57496 L
.592 .57495 L
.596 .57482 L
.6 .57464 L
Mistroke
.604 .57447 L
.608 .57438 L
.612 .57442 L
.616 .57455 L
.62 .57471 L
.624 .57479 L
.628 .57472 L
.632 .57453 L
.636 .57429 L
.64 .57417 L
.644 .57425 L
.648 .57455 L
.652 .57494 L
.656 .57524 L
.66 .57529 L
.664 .57507 L
.668 .57469 L
.672 .57436 L
.676 .57425 L
.68 .57438 L
.684 .57466 L
.688 .57489 L
.692 .57492 L
.696 .57469 L
.7 .5743 L
.704 .57394 L
.708 .57378 L
.712 .5739 L
.716 .57426 L
.72 .57473 L
.724 .57513 L
.728 .57535 L
.732 .57535 L
.736 .57515 L
.74 .57482 L
.744 .57441 L
.748 .574 L
.752 .57365 L
.756 .57342 L
.76 .57339 L
.764 .5736 L
.768 .57403 L
.772 .57457 L
.776 .57504 L
.78 .57522 L
.784 .57492 L
.788 .57406 L
.792 .57272 L
.796 .5711 L
.8 .56948 L
Mistroke
.804 .56815 L
.808 .5673 L
.812 .567 L
.816 .5672 L
.82 .56775 L
.824 .56847 L
.828 .56918 L
.832 .56979 L
.836 .57021 L
.84 .5704 L
.844 .5703 L
.848 .56984 L
.852 .56887 L
.856 .56726 L
.86 .56491 L
.864 .56176 L
.868 .55785 L
.872 .55333 L
.876 .54837 L
.88 .54321 L
.884 .53802 L
.888 .53293 L
.892 .52796 L
.896 .52304 L
.9 .51805 L
.904 .51282 L
.908 .50722 L
.912 .50116 L
.916 .49465 L
.92 .48775 L
.924 .48061 L
.928 .47339 L
.932 .46627 L
.936 .45937 L
.94 .45279 L
.944 .44653 L
.948 .44053 L
.952 .43467 L
.956 .42881 L
.96 .42279 L
.964 .41647 L
.968 .40973 L
.972 .40252 L
.976 .39482 L
.98 .38667 L
.984 .37816 L
.988 .36938 L
.992 .36048 L
.996 .35155 L
1 .34277 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42681 L
.012 .42965 L
.016 .43086 L
.02 .42996 L
.024 .42952 L
.028 .42968 L
.032 .42986 L
.036 .42975 L
.04 .42968 L
.044 .42963 L
.048 .42964 L
.052 .42956 L
.056 .42954 L
.06 .42949 L
.064 .42949 L
.068 .42945 L
.072 .42945 L
.076 .4294 L
.08 .42938 L
.084 .42933 L
.088 .4293 L
.092 .42925 L
.096 .42923 L
.1 .42918 L
.104 .42916 L
.108 .42913 L
.112 .42911 L
.116 .42908 L
.12 .42906 L
.124 .42903 L
.128 .42901 L
.132 .42896 L
.136 .42891 L
.14 .42885 L
.144 .42881 L
.148 .42879 L
.152 .42878 L
.156 .42877 L
.16 .42876 L
.164 .42873 L
.168 .42869 L
.172 .42863 L
.176 .42858 L
.18 .42854 L
.184 .42851 L
.188 .42848 L
.192 .42846 L
.196 .42843 L
.2 .42842 L
Mistroke
.204 .42839 L
.208 .42836 L
.212 .42833 L
.216 .4283 L
.22 .42826 L
.224 .42821 L
.228 .42815 L
.232 .42811 L
.236 .42808 L
.24 .42807 L
.244 .42805 L
.248 .42804 L
.252 .42803 L
.256 .42801 L
.26 .42798 L
.264 .42792 L
.268 .42785 L
.272 .42779 L
.276 .42775 L
.28 .42773 L
.284 .4277 L
.288 .42769 L
.292 .42769 L
.296 .42768 L
.3 .42767 L
.304 .42762 L
.308 .42756 L
.312 .42751 L
.316 .42747 L
.32 .42743 L
.324 .42738 L
.328 .42734 L
.332 .42731 L
.336 .42731 L
.34 .42731 L
.344 .4273 L
.348 .42726 L
.352 .42721 L
.356 .42718 L
.36 .42715 L
.364 .42712 L
.368 .42707 L
.372 .42701 L
.376 .42695 L
.38 .42693 L
.384 .42693 L
.388 .42692 L
.392 .42687 L
.396 .42682 L
.4 .42679 L
Mistroke
.404 .4268 L
.408 .42682 L
.412 .4268 L
.416 .42672 L
.42 .42663 L
.424 .42658 L
.428 .42658 L
.432 .42658 L
.436 .42653 L
.44 .42643 L
.444 .42635 L
.448 .42635 L
.452 .42642 L
.456 .42648 L
.46 .42645 L
.464 .42633 L
.468 .42622 L
.472 .42619 L
.476 .42625 L
.48 .4263 L
.484 .42625 L
.488 .4261 L
.492 .42594 L
.496 .42588 L
.5 .42594 L
.504 .42602 L
.508 .42602 L
.512 .4259 L
.516 .42575 L
.52 .42571 L
.524 .42582 L
.528 .426 L
.532 .42611 L
.536 .42604 L
.54 .42582 L
.544 .42557 L
.548 .42541 L
.552 .42539 L
.556 .42544 L
.56 .42546 L
.564 .4254 L
.568 .42531 L
.572 .42526 L
.576 .42532 L
.58 .42547 L
.584 .42564 L
.588 .42573 L
.592 .42568 L
.596 .42549 L
.6 .42523 L
Mistroke
.604 .42498 L
.608 .42485 L
.612 .42486 L
.616 .425 L
.62 .42516 L
.624 .42523 L
.628 .42512 L
.632 .42484 L
.636 .42452 L
.64 .42433 L
.644 .42441 L
.648 .42475 L
.652 .42521 L
.656 .42554 L
.66 .42557 L
.664 .42526 L
.668 .42476 L
.672 .42433 L
.676 .42415 L
.68 .42429 L
.684 .42461 L
.688 .42487 L
.692 .42488 L
.696 .42456 L
.7 .42406 L
.704 .42359 L
.708 .42337 L
.712 .42351 L
.716 .42395 L
.72 .42452 L
.724 .42503 L
.728 .42532 L
.732 .42534 L
.736 .42512 L
.74 .42476 L
.744 .42432 L
.748 .4239 L
.752 .42358 L
.756 .42345 L
.76 .42359 L
.764 .42408 L
.768 .42489 L
.772 .4259 L
.776 .42688 L
.78 .42757 L
.784 .42774 L
.788 .42731 L
.792 .42637 L
.796 .42518 L
.8 .42411 L
Mistroke
.804 .42352 L
.808 .42365 L
.812 .42459 L
.816 .42628 L
.82 .42854 L
.824 .43112 L
.828 .43382 L
.832 .43649 L
.836 .43903 L
.84 .44137 L
.844 .44342 L
.848 .44505 L
.852 .44608 L
.856 .44632 L
.86 .44561 L
.864 .44388 L
.868 .44115 L
.872 .43758 L
.876 .43339 L
.88 .42885 L
.884 .4242 L
.888 .41958 L
.892 .41504 L
.896 .41049 L
.9 .40582 L
.904 .40082 L
.908 .39537 L
.912 .38938 L
.916 .38286 L
.92 .37593 L
.924 .36877 L
.928 .36161 L
.932 .35466 L
.936 .3481 L
.94 .34202 L
.944 .33643 L
.948 .33125 L
.952 .32634 L
.956 .32152 L
.96 .31662 L
.964 .31148 L
.968 .30601 L
.972 .30017 L
.976 .294 L
.98 .28762 L
.984 .28116 L
.988 .27479 L
.992 .26874 L
.996 .2631 L
1 .25809 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30002Ool01@00Ool00000Ool00P0000=oo`0000001Goo0`000Woo1@00
0goo0P001Woo000ROol00`00Oomoo`0lOol00`00Oomoo`020002Ool20003Ool20002Ool01000Ool0
000077oo000ROol20002Ool01000Oomoogoo2`0000=oo`000000100000=oo`0000003P0000=oo`00
00001`0000=oo`0000000`0000=oo`0000000`0000Eoo`00Ool007oo0080009oo`03001oo`00009o
o`04001oogoo000LOol0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00002Ool00`00Oomoo`02000017oo000000000goo
00<007ooOol00P000goo0P000Woo00D007ooOomoo`0000=oo`05001oogooOol0000<Ool0029oo`80
04]oo`8000Aoo`03001oogoo01Uoo`008Woo00<007ooOol0BWoo0P001Goo00<007ooOol067oo000R
Ool2001BOol00`00Oomoo`0HOol0029oo`80059oo`03001oogoo01Qoo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo00<007ooOol0DGoo00<007ooOol067oo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`80059oo`03001oogoo01Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001BOol00`00Oomoo`0HOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0DWoo00<007ooOol05goo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8005=oo`03001oogoo01Moo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool20004Ool2001COol00`00Oomoo`0GOol000]oo`8000Yoo`80
00Aoo`03001oogoo009oo`03001oogoo059oo`03001oogoo01Moo`002goo0P0017oo00<007ooOol0
0goo0P000Woo1@000Woo0P00Dgoo10005Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04
001oogoo0002Ool2001FOol00`00Oomoo`0DOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0EWoo00<007ooOol04goo000:Ool01000Oomoo`0027oo00@007oo
Ool000Aoo`04001oogooOol2001GOol00`00Oomoo`02000AOol000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`03001oogoo008005Moo`06001oogoo001oo`0047oo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool01000Oomoo`00F7oo00<007oo00000Woo00<007ooOol03Woo000;
Ool2000:Ool20003Ool30003Ool2001HOol20002Ool00`00Oomoo`0>Ool0029oo`03001oogoo05]o
o`03001oogoo00ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00G7oo00<007oo
Ool03Woo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001LOol00`00
Oomoo`0>Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol005ioo`03001oogoo
00eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001MOol00`00Oomoo`0=Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00GGoo00<007ooOol03Goo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00GWoo00<007ooOol03Goo000;
Ool2000:Ool20003Ool30003Ool2001NOol00`00Oomoo`0<Ool0029oo`8005ioo`03001oogoo00ao
o`008Woo00<007ooOol0GGoo0`0037oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003
Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001o
ogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00
Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0
0P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomo
o`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007oo
Ool0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomo
o`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`00
4Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007oo
Ool006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@00
0goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol0
00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo
00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04
001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool0
0`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`00
1Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0
009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qo
o`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol5
0003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011o
o`03001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1IOol00`00Oomoo`0:Ool002Qoo`03001oogoo05Qoo`03001oogoo
00]oo`00:7oo00<007ooOol0F7oo00<007ooOol02goo000XOol00`00Oomoo`1GOol00`00Oomoo`0<
Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo05Moo`03001o
ogoo00aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001o
ogoo001HOol00`00Oomoo`0=Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`04001oogoo001HOol00`00Oomoo`0=Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo008005Ioo`03001oogoo00ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0EGoo00<007ooOol03Woo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0E7oo00<007oo
Ool03goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1COol00`00Oomoo`0@Ool0
02Qoo`03001oogoo059oo`80019oo`00:7oo00<007ooOol0DWoo00<007ooOol04Goo000AOol20004
Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1AOol2000COol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0DGoo00<007ooOol04Woo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo051oo`8001Aoo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001@Ool2000EOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0Cgoo00<007ooOol057oo000@Ool0
1000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo04ioo`03001oogoo01Eoo`004Goo
0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0CGoo0P005goo000XOol00`00Oomoo`1<Ool0
0`00Oomoo`0GOol002Qooe0001Uoo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03
Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000
Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eo
o`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001o
ogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool4
0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`80
00Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P00
17oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P00
1Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo
0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eo
o`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04
001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000
Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool0
0`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003
Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000
Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2
000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P00
17oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yo
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo06Eoo`03001oogoo00Yoo`0077oo0P00IGoo00<007ooOol02goo000;Ool20004
Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1SOol00`00Oomoo`0<Ool000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0HWoo0P003Woo000:Ool01000Oomoo`002goo00<007oo
Ool00P00Hgoo00<007ooOol03Goo000:Ool01000Oomoo`002goo00@007ooOol006=oo`8000moo`00
2Woo00@007ooOol000Moo`@000=oo`03001oogoo061oo`80011oo`002Woo00@007ooOol000Moo`03
001oogoo00Aoo`80065oo`03001oogoo00moo`002goo0P0027oo1@000Woo00<007ooOol0Ggoo00<0
07ooOol047oo000LOol00`00Oomoo`1NOol00`00Oomoo`0AOol001aoo`8005moo`03001oogoo015o
o`0077oo00<007ooOol0GGoo00<007ooOol04Woo000LOol2001MOol2000DOol001aoo`03001oogoo
05aoo`03001oogoo01=oo`0077oo00<007ooOol0Fgoo00<007ooOol057oo000LOol2001LOol00`00
Oomoo`0DOol001Ioo`<000=oo`03001oogoo05Yoo`03001oogoo01Eoo`005goo00<007ooOol00Woo
00<007ooOol0?goo0P000Woo1P0000Aoo`00000000=oo`8000Moo`03001oogoo01Ioo`005goo00<0
07ooOol00WooAP0000=oo`0000000Woo0`000Woo0`000Woo0P0017oo00<007ooOol05goo000GOol0
0`00Oomoo`02Ool00`00Oomoo`1COol20002Ool00`00Oomoo`0HOol001Moo`03001oogoo009oo`03
001oogoo05Eoo`8001]oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1b
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=o
o`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<0
07ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool0
0`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo
079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(31396\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30151 m
.008 .3003 L
.012 .29811 L
.016 .2977 L
.02 .29911 L
.024 .29948 L
.028 .2989 L
.032 .29885 L
.036 .29919 L
.04 .29914 L
.044 .29882 L
.048 .29868 L
.052 .29877 L
.056 .29888 L
.06 .29897 L
.064 .29902 L
.068 .29897 L
.072 .29881 L
.076 .29866 L
.08 .29862 L
.084 .29873 L
.088 .29886 L
.092 .29894 L
.096 .29896 L
.1 .29886 L
.104 .29868 L
.108 .29852 L
.112 .29849 L
.116 .29863 L
.12 .29877 L
.124 .29882 L
.128 .29882 L
.132 .29878 L
.136 .29866 L
.14 .29849 L
.144 .29839 L
.148 .29847 L
.152 .29865 L
.156 .29876 L
.16 .29874 L
.164 .29865 L
.168 .29854 L
.172 .29838 L
.176 .29821 L
.18 .29824 L
.184 .29856 L
.188 .29893 L
.192 .29897 L
.196 .29863 L
.2 .2982 L
Mistroke
.204 .29796 L
.208 .29796 L
.212 .29814 L
.216 .2985 L
.22 .29895 L
.224 .29915 L
.228 .2988 L
.232 .29804 L
.236 .29749 L
.24 .29759 L
.244 .29818 L
.248 .29872 L
.252 .29889 L
.256 .29878 L
.26 .29853 L
.264 .29815 L
.268 .29768 L
.272 .29743 L
.276 .29773 L
.28 .29847 L
.284 .29907 L
.288 .29903 L
.292 .29842 L
.296 .29779 L
.3 .29753 L
.304 .29756 L
.308 .2977 L
.312 .29794 L
.316 .29839 L
.32 .29892 L
.324 .29907 L
.328 .29852 L
.332 .29754 L
.336 .29685 L
.34 .29699 L
.344 .29781 L
.348 .29864 L
.352 .2989 L
.356 .29856 L
.36 .29807 L
.364 .29779 L
.368 .29769 L
.372 .29754 L
.376 .29729 L
.38 .2973 L
.384 .29786 L
.388 .29873 L
.392 .29916 L
.396 .29862 L
.4 .29741 L
Mistroke
.404 .29653 L
.408 .29676 L
.412 .29783 L
.416 .29862 L
.42 .29837 L
.424 .29748 L
.428 .29711 L
.432 .29783 L
.436 .29887 L
.44 .29888 L
.444 .29749 L
.448 .29591 L
.452 .29582 L
.456 .29754 L
.46 .2995 L
.464 .29973 L
.468 .29793 L
.472 .29588 L
.476 .29572 L
.48 .29771 L
.484 .29981 L
.488 .29968 L
.492 .29713 L
.496 .29447 L
.5 .2944 L
.504 .29728 L
.508 .30068 L
.512 .30155 L
.516 .29904 L
.52 .29536 L
.524 .29374 L
.528 .29549 L
.532 .29882 L
.536 .30057 L
.54 .29911 L
.544 .29579 L
.548 .2937 L
.552 .29488 L
.556 .2985 L
.56 .30163 L
.564 .30165 L
.568 .29846 L
.572 .2944 L
.576 .29239 L
.58 .29369 L
.584 .29718 L
.588 .30048 L
.592 .30164 L
.596 .30033 L
.6 .29763 L
Mistroke
.604 .29506 L
.608 .29369 L
.612 .2939 L
.616 .29543 L
.62 .29767 L
.624 .2997 L
.628 .30049 L
.632 .29946 L
.636 .29698 L
.64 .29454 L
.644 .29395 L
.648 .29607 L
.652 .29987 L
.656 .30276 L
.66 .30218 L
.664 .29751 L
.668 .29094 L
.672 .28646 L
.676 .28741 L
.68 .29421 L
.684 .30368 L
.688 .31067 L
.692 .311 L
.696 .30404 L
.7 .2932 L
.704 .28415 L
.708 .28165 L
.712 .28703 L
.716 .29752 L
.72 .30792 L
.724 .31341 L
.728 .31191 L
.732 .30483 L
.736 .29592 L
.74 .28911 L
.744 .2867 L
.748 .28866 L
.752 .29332 L
.756 .2987 L
.76 .30357 L
.764 .30766 L
.768 .31111 L
.772 .31369 L
.776 .31445 L
.78 .31211 L
.784 .30608 L
.788 .29726 L
.792 .28833 L
.796 .28289 L
.8 .28406 L
Mistroke
.804 .29299 L
.808 .30804 L
.812 .32514 L
.816 .33916 L
.82 .34573 L
.824 .34279 L
.828 .33123 L
.832 .3144 L
.836 .29681 L
.84 .28247 L
.844 .27367 L
.848 .2705 L
.852 .27135 L
.856 .27394 L
.86 .27655 L
.864 .27879 L
.868 .28177 L
.872 .28753 L
.876 .29814 L
.88 .31473 L
.884 .33688 L
.888 .36256 L
.892 .38868 L
.896 .41192 L
.9 .42968 L
.904 .44077 L
.908 .44572 L
.912 .44653 L
.916 .44606 L
.92 .4472 L
.924 .45216 L
.928 .46188 L
.932 .47595 L
.936 .4928 L
.94 .51016 L
.944 .52575 L
.948 .53762 L
.952 .54489 L
.956 .54739 L
.96 .5463 L
.964 .54296 L
.968 .53959 L
.972 .53764 L
.976 .53873 L
.98 .54321 L
.984 .55107 L
.988 .56155 L
.992 .57311 L
.996 .58487 L
1 .59462 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57934 m
.008 .57435 L
.012 .57265 L
.016 .57407 L
.02 .57476 L
.024 .57431 L
.028 .5741 L
.032 .57419 L
.036 .5743 L
.04 .57424 L
.044 .57422 L
.048 .5742 L
.052 .57424 L
.056 .57423 L
.06 .57425 L
.064 .57425 L
.068 .57426 L
.072 .57424 L
.076 .57424 L
.08 .57422 L
.084 .57422 L
.088 .57422 L
.092 .57424 L
.096 .57424 L
.1 .57425 L
.104 .57424 L
.108 .57425 L
.112 .57424 L
.116 .57424 L
.12 .57423 L
.124 .57423 L
.128 .57422 L
.132 .57422 L
.136 .57422 L
.14 .57424 L
.144 .57425 L
.148 .57427 L
.152 .57426 L
.156 .57425 L
.16 .57423 L
.164 .57421 L
.168 .5742 L
.172 .57421 L
.176 .57422 L
.18 .57425 L
.184 .57426 L
.188 .57427 L
.192 .57426 L
.196 .57424 L
.2 .57423 L
Mistroke
.204 .57422 L
.208 .57421 L
.212 .57421 L
.216 .57421 L
.22 .57423 L
.224 .57424 L
.228 .57425 L
.232 .57425 L
.236 .57425 L
.24 .57425 L
.244 .57424 L
.248 .57423 L
.252 .57421 L
.256 .57421 L
.26 .5742 L
.264 .57421 L
.268 .57421 L
.272 .57423 L
.276 .57426 L
.28 .57428 L
.284 .57427 L
.288 .57425 L
.292 .57422 L
.296 .57421 L
.3 .5742 L
.304 .57419 L
.308 .57419 L
.312 .57421 L
.316 .57423 L
.32 .57426 L
.324 .57427 L
.328 .57426 L
.332 .57425 L
.336 .57424 L
.34 .57423 L
.344 .57421 L
.348 .57419 L
.352 .57418 L
.356 .57419 L
.36 .57422 L
.364 .57424 L
.368 .57425 L
.372 .57424 L
.376 .57424 L
.38 .57425 L
.384 .57426 L
.388 .57425 L
.392 .57422 L
.396 .57419 L
.4 .57419 L
Mistroke
.404 .57421 L
.408 .57423 L
.412 .57422 L
.416 .5742 L
.42 .57418 L
.424 .57421 L
.428 .57425 L
.432 .57429 L
.436 .57427 L
.44 .57423 L
.444 .5742 L
.448 .57421 L
.452 .57424 L
.456 .57425 L
.46 .5742 L
.464 .57414 L
.468 .57412 L
.472 .57417 L
.476 .57426 L
.48 .57431 L
.484 .57428 L
.488 .5742 L
.492 .57416 L
.496 .57421 L
.5 .57429 L
.504 .57433 L
.508 .57428 L
.512 .57418 L
.516 .5741 L
.52 .57411 L
.524 .57419 L
.528 .57426 L
.532 .57424 L
.536 .57414 L
.54 .57406 L
.544 .57408 L
.548 .57421 L
.552 .57438 L
.556 .57448 L
.56 .57445 L
.564 .57431 L
.568 .57416 L
.572 .57409 L
.576 .57409 L
.58 .57413 L
.584 .57414 L
.588 .57409 L
.592 .57403 L
.596 .57402 L
.6 .57409 L
Mistroke
.604 .57424 L
.608 .57441 L
.612 .57452 L
.616 .57454 L
.62 .57443 L
.624 .57425 L
.628 .57407 L
.632 .57396 L
.636 .57398 L
.64 .57412 L
.644 .57429 L
.648 .57438 L
.652 .57433 L
.656 .57412 L
.66 .57385 L
.664 .57369 L
.668 .57375 L
.672 .57404 L
.676 .57443 L
.68 .57475 L
.684 .57483 L
.688 .57463 L
.692 .57427 L
.696 .57393 L
.7 .57379 L
.704 .57388 L
.708 .57412 L
.712 .57433 L
.716 .57434 L
.72 .57409 L
.724 .57366 L
.728 .57323 L
.732 .57294 L
.736 .5729 L
.74 .57308 L
.744 .57337 L
.748 .57363 L
.752 .57373 L
.756 .57362 L
.76 .57329 L
.764 .57278 L
.768 .57212 L
.772 .57136 L
.776 .57057 L
.78 .56984 L
.784 .56924 L
.788 .56887 L
.792 .56874 L
.796 .56876 L
.8 .56876 L
Mistroke
.804 .56853 L
.808 .56786 L
.812 .56664 L
.816 .56489 L
.82 .56279 L
.824 .56061 L
.828 .55863 L
.832 .55711 L
.836 .55616 L
.84 .55579 L
.844 .55589 L
.848 .55631 L
.852 .55691 L
.856 .55756 L
.86 .55817 L
.864 .5587 L
.868 .55907 L
.872 .55918 L
.876 .55888 L
.88 .55801 L
.884 .55641 L
.888 .554 L
.892 .55076 L
.896 .54676 L
.9 .54218 L
.904 .53722 L
.908 .53208 L
.912 .5269 L
.916 .52176 L
.92 .51664 L
.924 .51144 L
.928 .50601 L
.932 .50022 L
.936 .49395 L
.94 .48716 L
.944 .47989 L
.948 .47222 L
.952 .4643 L
.956 .45628 L
.96 .4483 L
.964 .44044 L
.968 .43277 L
.972 .42523 L
.976 .41781 L
.98 .41034 L
.984 .40279 L
.988 .39499 L
.992 .38695 L
.996 .37857 L
1 .36995 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43437 L
.012 .42971 L
.016 .42836 L
.02 .42992 L
.024 .43036 L
.028 .42972 L
.032 .42958 L
.036 .42971 L
.04 .42975 L
.044 .42962 L
.048 .4296 L
.052 .42957 L
.056 .42958 L
.06 .42952 L
.064 .42951 L
.068 .42946 L
.072 .42943 L
.076 .42938 L
.08 .42936 L
.084 .42931 L
.088 .4293 L
.092 .42926 L
.096 .42924 L
.1 .42921 L
.104 .42918 L
.108 .42914 L
.112 .42912 L
.116 .42908 L
.12 .42904 L
.124 .429 L
.128 .42897 L
.132 .42893 L
.136 .42891 L
.14 .42888 L
.144 .42887 L
.148 .42884 L
.152 .42882 L
.156 .42877 L
.16 .42873 L
.164 .42867 L
.168 .42863 L
.172 .4286 L
.176 .42858 L
.18 .42857 L
.184 .42856 L
.188 .42854 L
.192 .4285 L
.196 .42846 L
.2 .42841 L
Mistroke
.204 .42836 L
.208 .42831 L
.212 .42828 L
.216 .42826 L
.22 .42824 L
.224 .42822 L
.228 .42819 L
.232 .42817 L
.236 .42815 L
.24 .42813 L
.244 .42808 L
.248 .42802 L
.252 .42796 L
.256 .42792 L
.26 .42789 L
.264 .42787 L
.268 .42786 L
.272 .42785 L
.276 .42785 L
.28 .42783 L
.284 .42778 L
.288 .42772 L
.292 .42766 L
.296 .42762 L
.3 .42758 L
.304 .42754 L
.308 .4275 L
.312 .42749 L
.316 .42749 L
.32 .42749 L
.324 .42746 L
.328 .42742 L
.332 .42738 L
.336 .42734 L
.34 .42731 L
.344 .42725 L
.348 .42719 L
.352 .42714 L
.356 .42711 L
.36 .42712 L
.364 .42712 L
.368 .4271 L
.372 .42706 L
.376 .42703 L
.38 .427 L
.384 .42698 L
.388 .42693 L
.392 .42687 L
.396 .42681 L
.4 .42678 L
Mistroke
.404 .42677 L
.408 .42676 L
.412 .42672 L
.416 .42666 L
.42 .4266 L
.424 .4266 L
.428 .42663 L
.432 .42664 L
.436 .4266 L
.44 .42652 L
.444 .42644 L
.448 .42642 L
.452 .42643 L
.456 .4264 L
.46 .42631 L
.464 .42621 L
.468 .42615 L
.472 .42618 L
.476 .42626 L
.48 .42629 L
.484 .42622 L
.488 .4261 L
.492 .42602 L
.496 .42604 L
.5 .42611 L
.504 .42614 L
.508 .42605 L
.512 .42588 L
.516 .42574 L
.52 .42573 L
.524 .4258 L
.528 .42586 L
.532 .42581 L
.536 .42565 L
.54 .42551 L
.544 .4255 L
.548 .42564 L
.552 .42582 L
.556 .42591 L
.56 .42584 L
.564 .42564 L
.568 .42542 L
.572 .4253 L
.576 .42527 L
.58 .42529 L
.584 .42526 L
.588 .42518 L
.592 .42507 L
.596 .42503 L
.6 .42508 L
Mistroke
.604 .42524 L
.608 .42541 L
.612 .42553 L
.616 .42551 L
.62 .42535 L
.624 .4251 L
.628 .42484 L
.632 .42467 L
.636 .42467 L
.64 .4248 L
.644 .42498 L
.648 .42508 L
.652 .42498 L
.656 .42469 L
.66 .42433 L
.664 .4241 L
.668 .42415 L
.672 .42448 L
.676 .42496 L
.68 .42533 L
.684 .42541 L
.688 .42515 L
.692 .42469 L
.696 .42428 L
.7 .42411 L
.704 .42425 L
.708 .42458 L
.712 .42488 L
.716 .42496 L
.72 .42473 L
.724 .42431 L
.728 .42391 L
.732 .42373 L
.736 .42389 L
.74 .42438 L
.744 .42506 L
.748 .42576 L
.752 .42633 L
.756 .42672 L
.76 .42692 L
.764 .42698 L
.768 .42696 L
.772 .42693 L
.776 .42698 L
.78 .42721 L
.784 .42774 L
.788 .42868 L
.792 .43004 L
.796 .43172 L
.8 .4335 L
Mistroke
.804 .4351 L
.808 .43625 L
.812 .4368 L
.816 .43676 L
.82 .43634 L
.824 .43586 L
.828 .43564 L
.832 .43598 L
.836 .437 L
.84 .43869 L
.844 .44091 L
.848 .44345 L
.852 .44612 L
.856 .44876 L
.86 .45128 L
.864 .4536 L
.868 .45566 L
.872 .45734 L
.876 .45848 L
.88 .45891 L
.884 .45845 L
.888 .45701 L
.892 .45459 L
.896 .45132 L
.9 .44739 L
.904 .44309 L
.908 .43866 L
.912 .43429 L
.916 .43006 L
.92 .42594 L
.924 .42181 L
.928 .41749 L
.932 .41283 L
.936 .40772 L
.94 .40212 L
.944 .39613 L
.948 .3899 L
.952 .38367 L
.956 .37768 L
.96 .37215 L
.964 .36722 L
.968 .36298 L
.972 .35933 L
.976 .35623 L
.98 .35337 L
.984 .35064 L
.988 .34768 L
.992 .34439 L
.996 .34053 L
1 .33609 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20003Ool30005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo03moo`03001oogoo0080009oo`04001oogooOol20003Ool01000Ool000006Goo000ROol3
0002Ool01@00Oomoo`00Ool00P0000=oo`0000001`0000=oo`0000000`0000=oo`0000004`0000=o
o`0000001@0000=oo`0000000`0000Qoo`00001oo`00Ool007oo0`000Woo0P000goo00@007ooOol0
01Uoo`008WooH`0037oo000ROol01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`00009oo`04001oogooOol300000goo00000002Ool3000017oo0000
07oo0P000goo00D007ooOomoo`0000=oo`05001oogooOol0000<Ool0029oo`8004eoo`03001oo`00
00Aoo`03001oogoo01Ioo`008Woo00<007ooOol0CGoo0P0017oo00<007ooOol05Woo000ROol2001>
Ool00`00Oomoo`03Ool00`00Oomoo`0FOol0029oo`8005Eoo`03001oogoo01Eoo`002goo0P0017oo
00<007ooOol00goo0P000goo0`000goo00<007ooOol0E7oo00<007ooOol05Goo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8005Eoo`03001oogoo01Eoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001EOol00`00Oomoo`0EOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0E7oo00<007ooOol05Goo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8005Eoo`03001oogoo01Eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001EOol00`00Oomoo`0EOol000]oo`80
00Yoo`8000Aoo`03001oogoo009oo`03001oogoo05Eoo`03001oogoo01Aoo`002goo0P0017oo00<0
07ooOol00goo0P000Woo1@000Woo0P00EWoo00<007ooOol057oo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0002Ool2001GOol2000DOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0F7oo00<007ooOol04Goo000:Ool01000Oomoo`0027oo
00@007ooOol000Aoo`04001oogooOol2001IOol00`00Oomoo`0AOol000Yoo`04001oogoo0008Ool0
1P00Oomoo`00Ool000=oo`03001oogoo008005Uoo`03001oogoo015oo`002Woo00@007ooOol000Qo
o`06001oogoo001oo`000goo00@007ooOol005Yoo`03001oogoo015oo`002goo0P002Woo0P000goo
0`000goo0P00FGoo00<007ooOol04Goo000ROol00`00Oomoo`1IOol00`00Oomoo`0@Ool000]oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`8005Yoo`03001oogoo011oo`002Woo00@007ooOol0
00Qoo`06001oogoo001oo`000goo00<007ooOol00P00FWoo00<007ooOol047oo000:Ool01000Oomo
o`0027oo00@007ooOol000Eoo`04001oogoo001KOol5000>Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo0P000goo0P00Fgoo0P0000=oo`00Ool03Goo000:Ool01000Oomoo`0027oo00@007oo
Ool000Eoo`03001oogoo008005ioo`03001oogoo00aoo`002Woo00@007ooOol000Qoo`06001oogoo
001oo`000goo00@007ooOol0061oo`03001oogoo00]oo`002goo0P002Woo0P000goo0`000goo0P00
Ggoo00<007ooOol02goo000ROol2001POol00`00Oomoo`0:Ool0029oo`03001oogoo06aoo`008Woo
0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
2goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007oo
Oomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo
1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001o
ogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`80
00Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`80
00Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007oo
Ool02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006
Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04
001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=o
o`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001o
ogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0
0goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo1000
0goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007oo
Oomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol0
17oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007oo
Ool017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003
Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00
Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo
0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@00
37oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00
Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0F7oo0P0037oo000;Ool20004
Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1HOol00`00Oomoo`0;Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00FGoo00<0
07ooOol037oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomo
o`00FGoo00<007ooOol037oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`02001GOol00`00Oomoo`0=Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00D007ooOol007oo00@000=oo`03001oogoo05Ioo`03001oogoo00eoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo05Eoo`03001oogoo00ioo`002goo
0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0EGoo00<007ooOol03Woo000XOol00`00Oomo
o`1DOol2000@Ool002Qoo`03001oogoo05Aoo`03001oogoo00moo`004Goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo00<007ooOol0Dgoo00<007ooOol047oo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo05=oo`03001oogoo011oo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1BOol00`00Oomoo`0AOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00DWoo0P004goo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo051oo`8001Aoo`0047oo00@007oo
Ool000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1?Ool2000EOol0015oo`8000Yoo`8000Ao
o`03001oogoo009oo`03001oogoo04moo`03001oogoo01Aoo`00:7oo00<007ooOol0B7oo1`005goo
000XOom;000NOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogoo
Ool00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05
Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006ao
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yo
o`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`80
00Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol0
00Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool0
0`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<0
00=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P00
3Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000
Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo1000
0goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06
001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo
00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol0
17oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07
001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007oo
Ool00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0
009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000ao
o`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]o
o`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo
0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol0
00]oo`8000Qoo`D0009oo`03001oogoo06Eoo`03001oogoo00Yoo`0077oo00<007ooOol0I7oo00<0
07ooOol02goo000LOol2001SOol2000>Ool001aoo`03001oogoo065oo`8000moo`0077oo0P00HGoo
0P0047oo000LOol00`00Oomoo`1POol00`00Oomoo`0?Ool001aoo`03001oogoo05moo`03001oogoo
011oo`0077oo0P00Ggoo0P004Woo000FOol30003Ool00`00Oomoo`1NOol00`00Oomoo`0AOol001Mo
o`03001oogoo009oo`03001oogoo03moo`03001oo`0000800004Ool00000Ool3000BOol00`00Oomo
o`0BOol001Moo`03001oogoo009oodD00005Ool00000001oo`0200000goo00000005000:Ool2000E
Ool001Moo`03001oogoo009oo`80055oo`H000Eoo`03001oogoo01Aoo`005goo00<007ooOol00Woo
00<007ooOol0EGoo0`000Woo00<007ooOol05Goo000FOol20004Ool2001HOol3000HOol001Moo`03
001oogoo009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`00
17oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool0
0`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo
00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(31563\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3011 m
.008 .29931 L
.012 .29868 L
.016 .29845 L
.02 .29892 L
.024 .29921 L
.028 .29902 L
.032 .29895 L
.036 .29908 L
.04 .29912 L
.044 .29895 L
.048 .29878 L
.052 .2988 L
.056 .29891 L
.06 .29901 L
.064 .29905 L
.068 .29898 L
.072 .29882 L
.076 .29868 L
.08 .29867 L
.084 .29883 L
.088 .299 L
.092 .29904 L
.096 .29894 L
.1 .29875 L
.104 .29853 L
.108 .29846 L
.112 .29861 L
.116 .2989 L
.12 .2991 L
.124 .29903 L
.128 .29875 L
.132 .29847 L
.136 .29833 L
.14 .29839 L
.144 .29861 L
.148 .29889 L
.152 .29904 L
.156 .2989 L
.16 .29853 L
.164 .29825 L
.168 .29825 L
.172 .29847 L
.176 .29868 L
.18 .29879 L
.184 .29881 L
.188 .29871 L
.192 .29844 L
.196 .29813 L
.2 .29806 L
Mistroke
.204 .29834 L
.208 .29871 L
.212 .29886 L
.216 .29876 L
.22 .29856 L
.224 .29835 L
.228 .29809 L
.232 .29786 L
.236 .29793 L
.24 .29841 L
.244 .29897 L
.248 .29911 L
.252 .29867 L
.256 .29805 L
.26 .29771 L
.264 .29774 L
.268 .29798 L
.272 .2983 L
.276 .29868 L
.28 .29897 L
.284 .29885 L
.288 .2982 L
.292 .29746 L
.296 .29724 L
.3 .29774 L
.304 .2985 L
.308 .29891 L
.312 .29879 L
.316 .2984 L
.32 .29807 L
.324 .29782 L
.328 .29755 L
.332 .29739 L
.336 .29763 L
.34 .2983 L
.344 .29898 L
.348 .29909 L
.352 .29845 L
.356 .29753 L
.36 .297 L
.364 .29719 L
.368 .29781 L
.372 .29832 L
.376 .29845 L
.38 .29836 L
.384 .2983 L
.388 .29826 L
.392 .29797 L
.396 .29734 L
.4 .2968 L
Mistroke
.404 .29696 L
.408 .29793 L
.412 .29903 L
.416 .29927 L
.42 .29837 L
.424 .29711 L
.428 .29663 L
.432 .29726 L
.436 .29818 L
.44 .2983 L
.444 .29752 L
.448 .29688 L
.452 .29738 L
.456 .29874 L
.46 .29949 L
.464 .29853 L
.468 .29649 L
.472 .29528 L
.476 .29622 L
.48 .29855 L
.484 .30003 L
.488 .29915 L
.492 .29676 L
.496 .29527 L
.5 .29628 L
.504 .29888 L
.508 .30041 L
.512 .2991 L
.516 .29594 L
.52 .29382 L
.524 .29487 L
.528 .29833 L
.532 .30119 L
.536 .30094 L
.54 .29785 L
.544 .29472 L
.548 .2943 L
.552 .29679 L
.556 .29975 L
.56 .30035 L
.564 .29795 L
.568 .29463 L
.572 .29337 L
.576 .29541 L
.58 .29926 L
.584 .30192 L
.588 .30136 L
.592 .29801 L
.596 .2943 L
.6 .29269 L
Mistroke
.604 .29403 L
.608 .29716 L
.612 .30006 L
.616 .30118 L
.62 .30025 L
.624 .298 L
.628 .29555 L
.632 .2939 L
.636 .29365 L
.64 .29498 L
.644 .29743 L
.648 .29988 L
.652 .30093 L
.656 .29975 L
.66 .29683 L
.664 .29404 L
.668 .29355 L
.672 .29627 L
.676 .3009 L
.68 .30441 L
.684 .30392 L
.688 .29881 L
.692 .29152 L
.696 .28641 L
.7 .28714 L
.704 .29425 L
.708 .30453 L
.712 .31263 L
.716 .31413 L
.72 .30808 L
.724 .29767 L
.728 .28849 L
.732 .28544 L
.736 .29019 L
.74 .30045 L
.744 .31134 L
.748 .3181 L
.752 .3184 L
.756 .3131 L
.76 .30538 L
.764 .29885 L
.768 .29577 L
.772 .29644 L
.776 .29968 L
.78 .30397 L
.784 .30836 L
.788 .31265 L
.792 .31686 L
.796 .32048 L
.8 .32217 L
Mistroke
.804 .32029 L
.808 .31386 L
.812 .30355 L
.816 .292 L
.82 .28309 L
.824 .28055 L
.828 .28627 L
.832 .2994 L
.836 .31634 L
.84 .332 L
.844 .34156 L
.848 .34214 L
.852 .33374 L
.856 .31902 L
.86 .3022 L
.864 .28745 L
.868 .27753 L
.872 .27313 L
.876 .27311 L
.88 .27541 L
.884 .27822 L
.888 .28089 L
.892 .28428 L
.896 .29035 L
.9 .30136 L
.904 .3189 L
.908 .34312 L
.912 .37253 L
.916 .40428 L
.92 .43499 L
.924 .46153 L
.928 .48206 L
.932 .49608 L
.936 .50494 L
.94 .51069 L
.944 .51609 L
.948 .52307 L
.952 .53286 L
.956 .54514 L
.96 .55854 L
.964 .57104 L
.968 .58006 L
.972 .58421 L
.976 .582 L
.98 .5743 L
.984 .56189 L
.988 .54751 L
.992 .53366 L
.996 .52279 L
1 .51762 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .56833 m
.008 .57392 L
.012 .57576 L
.016 .57367 L
.02 .57315 L
.024 .57385 L
.028 .57406 L
.032 .57376 L
.036 .57374 L
.04 .57381 L
.044 .57386 L
.048 .57381 L
.052 .57382 L
.056 .57381 L
.06 .57382 L
.064 .57379 L
.068 .57381 L
.072 .5738 L
.076 .57381 L
.08 .57381 L
.084 .57383 L
.088 .57382 L
.092 .57383 L
.096 .57381 L
.1 .57381 L
.104 .5738 L
.108 .5738 L
.112 .5738 L
.116 .57381 L
.12 .57381 L
.124 .57382 L
.128 .57382 L
.132 .57382 L
.136 .57381 L
.14 .57381 L
.144 .5738 L
.148 .5738 L
.152 .5738 L
.156 .5738 L
.16 .5738 L
.164 .57381 L
.168 .57382 L
.172 .57383 L
.176 .57383 L
.18 .57383 L
.184 .57381 L
.188 .57379 L
.192 .57378 L
.196 .57378 L
.2 .57379 L
Mistroke
.204 .57381 L
.208 .57383 L
.212 .57383 L
.216 .57383 L
.22 .57382 L
.224 .57381 L
.228 .5738 L
.232 .57379 L
.236 .57379 L
.24 .57379 L
.244 .57379 L
.248 .5738 L
.252 .57381 L
.256 .57383 L
.26 .57384 L
.264 .57384 L
.268 .57382 L
.272 .5738 L
.276 .57379 L
.28 .57378 L
.284 .57377 L
.288 .57377 L
.292 .57379 L
.296 .57381 L
.3 .57384 L
.304 .57385 L
.308 .57384 L
.312 .57382 L
.316 .57381 L
.32 .57379 L
.324 .57378 L
.328 .57376 L
.332 .57376 L
.336 .57378 L
.34 .5738 L
.344 .57382 L
.348 .57382 L
.352 .57383 L
.356 .57383 L
.36 .57383 L
.364 .57382 L
.368 .57379 L
.372 .57376 L
.376 .57375 L
.38 .57376 L
.384 .57379 L
.388 .5738 L
.392 .57381 L
.396 .57381 L
.4 .57382 L
Mistroke
.404 .57383 L
.408 .57384 L
.412 .57381 L
.416 .57378 L
.42 .57377 L
.424 .57378 L
.428 .5738 L
.432 .57381 L
.436 .57378 L
.44 .57375 L
.444 .57375 L
.448 .57379 L
.452 .57384 L
.456 .57386 L
.46 .57383 L
.464 .57379 L
.468 .57378 L
.472 .57381 L
.476 .57384 L
.48 .57382 L
.484 .57375 L
.488 .57369 L
.492 .57369 L
.496 .57377 L
.5 .57385 L
.504 .57386 L
.508 .57381 L
.512 .57374 L
.516 .57374 L
.52 .57381 L
.524 .5739 L
.528 .57391 L
.532 .57383 L
.536 .57373 L
.54 .57368 L
.544 .57372 L
.548 .57381 L
.552 .57385 L
.556 .57379 L
.56 .57368 L
.564 .5736 L
.568 .57364 L
.572 .57378 L
.576 .57395 L
.58 .57403 L
.584 .574 L
.588 .57389 L
.592 .57377 L
.596 .57372 L
.6 .57372 L
Mistroke
.604 .57373 L
.608 .57371 L
.612 .57365 L
.616 .57358 L
.62 .57356 L
.624 .57362 L
.628 .57376 L
.632 .57393 L
.636 .57407 L
.64 .57411 L
.644 .57403 L
.648 .57386 L
.652 .57366 L
.656 .57352 L
.66 .57352 L
.664 .57364 L
.668 .57381 L
.672 .57392 L
.676 .57385 L
.68 .57361 L
.684 .57329 L
.688 .57307 L
.692 .57305 L
.696 .57327 L
.7 .57361 L
.704 .57387 L
.708 .57389 L
.712 .57362 L
.716 .57316 L
.72 .57269 L
.724 .57237 L
.728 .57225 L
.732 .57226 L
.736 .57221 L
.74 .57196 L
.744 .57142 L
.748 .57067 L
.752 .56983 L
.756 .56908 L
.76 .56851 L
.764 .56812 L
.768 .56784 L
.772 .56754 L
.776 .56712 L
.78 .56651 L
.784 .56571 L
.788 .56471 L
.792 .56356 L
.796 .56229 L
.8 .56097 L
Mistroke
.804 .5597 L
.808 .55861 L
.812 .55781 L
.816 .55735 L
.82 .55718 L
.824 .55717 L
.828 .55709 L
.832 .5567 L
.836 .55585 L
.84 .5545 L
.844 .55277 L
.848 .55088 L
.852 .54909 L
.856 .54764 L
.86 .54667 L
.864 .54623 L
.868 .54624 L
.872 .54657 L
.876 .54707 L
.88 .54763 L
.884 .54816 L
.888 .5486 L
.892 .5489 L
.896 .54895 L
.9 .54863 L
.904 .54776 L
.908 .54618 L
.912 .54376 L
.916 .54044 L
.92 .53626 L
.924 .53132 L
.928 .5258 L
.932 .51989 L
.936 .51375 L
.94 .50747 L
.944 .50108 L
.948 .49451 L
.952 .4877 L
.956 .48049 L
.96 .47286 L
.964 .46476 L
.968 .45628 L
.972 .44753 L
.976 .4387 L
.98 .42997 L
.984 .42151 L
.988 .41344 L
.992 .40578 L
.996 .39852 L
1 .39152 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43391 L
.012 .43007 L
.016 .42864 L
.02 .42969 L
.024 .43023 L
.028 .42983 L
.032 .42963 L
.036 .42966 L
.04 .42973 L
.044 .42965 L
.048 .42962 L
.052 .42958 L
.056 .42958 L
.06 .42952 L
.064 .4295 L
.068 .42944 L
.072 .42942 L
.076 .42937 L
.08 .42937 L
.084 .42934 L
.088 .42932 L
.092 .42928 L
.096 .42925 L
.1 .42919 L
.104 .42916 L
.108 .42912 L
.112 .4291 L
.116 .42907 L
.12 .42905 L
.124 .42901 L
.128 .42899 L
.132 .42896 L
.136 .42893 L
.14 .4289 L
.144 .42886 L
.148 .42881 L
.152 .42877 L
.156 .42873 L
.16 .4287 L
.164 .42869 L
.168 .42868 L
.172 .42866 L
.176 .42863 L
.18 .42859 L
.184 .42854 L
.188 .42848 L
.192 .42843 L
.196 .4284 L
.2 .42839 L
Mistroke
.204 .42838 L
.208 .42837 L
.212 .42835 L
.216 .42832 L
.22 .42828 L
.224 .42822 L
.228 .42817 L
.232 .42812 L
.236 .42809 L
.24 .42807 L
.244 .42805 L
.248 .42803 L
.252 .428 L
.256 .42798 L
.26 .42796 L
.264 .42793 L
.268 .42788 L
.272 .42784 L
.276 .42779 L
.28 .42774 L
.284 .4277 L
.288 .42767 L
.292 .42765 L
.296 .42765 L
.3 .42765 L
.304 .42763 L
.308 .42759 L
.312 .42754 L
.316 .4275 L
.32 .42745 L
.324 .42739 L
.328 .42734 L
.332 .4273 L
.336 .42729 L
.34 .4273 L
.344 .42729 L
.348 .42727 L
.352 .42724 L
.356 .4272 L
.36 .42717 L
.364 .42712 L
.368 .42706 L
.372 .42699 L
.376 .42695 L
.38 .42694 L
.384 .42693 L
.388 .42692 L
.392 .42689 L
.396 .42686 L
.4 .42684 L
Mistroke
.404 .42683 L
.408 .4268 L
.412 .42675 L
.416 .42668 L
.42 .42662 L
.424 .4266 L
.428 .4266 L
.432 .42657 L
.436 .42651 L
.44 .42644 L
.444 .42641 L
.448 .42643 L
.452 .42646 L
.456 .42645 L
.46 .42638 L
.464 .4263 L
.468 .42626 L
.472 .42627 L
.476 .42628 L
.48 .42622 L
.484 .4261 L
.488 .42599 L
.492 .42596 L
.496 .42602 L
.5 .42609 L
.504 .42608 L
.508 .42598 L
.512 .42587 L
.516 .42584 L
.52 .42589 L
.524 .42596 L
.528 .42595 L
.532 .42583 L
.536 .42566 L
.54 .42557 L
.544 .42559 L
.548 .42567 L
.552 .42569 L
.556 .42559 L
.56 .42541 L
.564 .42529 L
.568 .4253 L
.572 .42545 L
.576 .42563 L
.58 .4257 L
.584 .42563 L
.588 .42545 L
.592 .42528 L
.596 .42518 L
.6 .42515 L
Mistroke
.604 .42514 L
.608 .42508 L
.612 .42497 L
.616 .42485 L
.62 .4248 L
.624 .42485 L
.628 .425 L
.632 .42518 L
.636 .42533 L
.64 .42535 L
.644 .42523 L
.648 .42498 L
.652 .42472 L
.656 .42453 L
.66 .42452 L
.664 .42466 L
.668 .42488 L
.672 .42501 L
.676 .42494 L
.68 .42467 L
.684 .42432 L
.688 .4241 L
.692 .42416 L
.696 .42454 L
.7 .42509 L
.704 .42558 L
.708 .42581 L
.712 .42572 L
.716 .42545 L
.72 .42523 L
.724 .42526 L
.728 .42561 L
.732 .4262 L
.736 .42682 L
.74 .42727 L
.744 .42749 L
.748 .42754 L
.752 .42761 L
.756 .42791 L
.76 .42856 L
.764 .42957 L
.768 .43083 L
.772 .43219 L
.776 .43351 L
.78 .43471 L
.784 .43575 L
.788 .43664 L
.792 .43738 L
.796 .43802 L
.8 .43862 L
Mistroke
.804 .43928 L
.808 .44013 L
.812 .4413 L
.816 .44284 L
.82 .44467 L
.824 .44661 L
.828 .44837 L
.832 .44966 L
.836 .45029 L
.84 .45023 L
.844 .44964 L
.848 .4488 L
.852 .44808 L
.856 .4478 L
.86 .44815 L
.864 .44921 L
.868 .45089 L
.872 .45306 L
.876 .45553 L
.88 .45817 L
.884 .46087 L
.888 .46356 L
.892 .46616 L
.896 .46855 L
.9 .47057 L
.904 .47202 L
.908 .4727 L
.912 .4725 L
.916 .47136 L
.92 .46938 L
.924 .46675 L
.928 .46375 L
.932 .46065 L
.936 .45769 L
.94 .455 L
.944 .45262 L
.948 .45041 L
.952 .44824 L
.956 .44583 L
.96 .44305 L
.964 .43968 L
.968 .43575 L
.972 .43124 L
.976 .42632 L
.98 .42117 L
.984 .41598 L
.988 .41097 L
.992 .40625 L
.996 .40192 L
1 .39798 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool40003Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo045oo`04001oogoo0008Ool20002Ool01000Oomoo`005goo000ROol30005Ool01@00Ool0
0000Ool00P0000=oo`0000009`0000Aoo`00001oo`H00004Ool00000Ool20002Ool00`00Oomoo`02
Ool20002Ool01000Oomoo`005goo000ROomS000<Ool0029oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`04001oogoo0003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000=oo`03
001oogoo0080009oo`<0009oo`09001oo`00Ool007oo001oo`0000=oo`05001oogooOol0000<Ool0
029oo`8004aoo`07001oogooOol007oo00000goo00<007ooOol057oo000ROol00`00Oomoo`1?Ool2
0005Ool00`00Oomoo`0COol0029oo`80051oo`8000Eoo`03001oogoo01=oo`008Woo0P00Egoo00<0
07ooOol04goo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1FOol00`00
Oomoo`0COol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Egoo00<0
07ooOol04goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8005Moo`03
001oogoo01=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1FOol00`00Oomoo`0COol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00Egoo00<007ooOol04goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8005Mo
o`03001oogoo01=oo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0Egoo00<007oo
Ool04Woo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001HOol00`00Oomoo`0BOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8005Qoo`03001oogoo019o
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1GOol00`00
Oomoo`0BOol000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8005Qoo`03001o
ogoo019oo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00FGoo00<0
07ooOol04Goo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00FWoo00<0
07ooOol04Goo000;Ool2000:Ool20003Ool30003Ool2001IOol00`00Oomoo`0AOol0029oo`03001o
ogoo05Qoo`80019oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00FWoo00<007oo
Ool00Woo0P0037oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001K
Ool01@00Oomoogoo00003Goo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001L
Ool01@00Oomoogoo00003Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8005]o
o`04001oogoo000>Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00G7oo
00<007oo00003Woo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00GGoo
00<007oo00003Woo000;Ool2000:Ool20003Ool30003Ool2001LOol2000?Ool0029oo`8006eoo`00
8Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`00
0goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;
Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003
Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo
000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo
0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`00
0goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo
0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo
0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001o
ogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<0
07oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002
Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=
Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo
000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol0
0`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001o
ogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo
00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003
Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo
00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001JOol2
000<Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001J
Ool00`00Oomoo`0;Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo008005Qoo`03001oogoo00aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00
Oomoo`00Ool010000goo00<007ooOol0Egoo00<007ooOol037oo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0EWoo00<007ooOol03Goo000;Ool2000:
Ool20004Ool20002Ool50002Ool00`00Oomoo`1FOol00`00Oomoo`0=Ool002Qoo`03001oogoo05Eo
o`8000moo`00:7oo00<007ooOol0EGoo00<007ooOol03Woo000AOol20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool00`00Oomoo`1DOol2000@Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0E7oo00<007ooOol03goo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo05=oo`03001oogoo011oo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001COol2000BOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0DWoo00<007ooOol04Goo000@Ool01000Oomoo`00
27oo00@007ooOol0009oo`8000Aoo`03001oogoo055oo`03001oogoo019oo`004Goo0P002Woo0P00
17oo00<007ooOol00Woo00<007ooOol0BWoo200057oo000XOol00`00Oomoo`15Ool6000KOol002Qo
odT0021oo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3
0003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`00
00=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo
00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03
001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P00
17oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo
00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo
00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001o
ogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo
0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool0
1@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo
0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool0
1000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007oo
Oomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000
Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool0
1000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007oo
Oomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03
Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo
1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000L
Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<0
07ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Mo
o`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo
0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2
001UOol2000<Ool001Ioo`<000=oo`03001oogoo06=oo`8000eoo`005goo00<007ooOol00Woo00<0
07ooOol0@Goo1@0077oo0P003Woo000GOol00`00Oomoo`02Oom70002Ool8000DOol00`00Oomoo`0=
Ool001Moo`03001oogoo009oo`03001oogoo04ioo`D000eoo`80011oo`005goo00<007ooOol00Woo
00<007ooOol0DWoo1P001goo0P004Goo000FOol20004Ool2001IOol20004Ool00`00Oomoo`0AOol0
01Moo`03001oogoo009oo`03001oogoo05Uoo`D001Aoo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo
079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool0
0`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079o
o`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2
001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(31730\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29709 m
.008 .29791 L
.012 .29987 L
.016 .30017 L
.02 .29883 L
.024 .29855 L
.028 .29916 L
.032 .29924 L
.036 .29893 L
.04 .29888 L
.044 .29904 L
.048 .29904 L
.052 .29895 L
.056 .29893 L
.06 .29895 L
.064 .29897 L
.068 .29899 L
.072 .29894 L
.076 .29888 L
.08 .29883 L
.084 .29883 L
.088 .29886 L
.092 .29888 L
.096 .29887 L
.1 .29885 L
.104 .29881 L
.108 .29876 L
.112 .29878 L
.116 .29884 L
.12 .29887 L
.124 .29878 L
.128 .29863 L
.132 .29855 L
.136 .29861 L
.14 .29875 L
.144 .29887 L
.148 .29891 L
.152 .29883 L
.156 .29861 L
.16 .29835 L
.164 .29827 L
.168 .2985 L
.172 .29884 L
.176 .299 L
.18 .29885 L
.184 .29855 L
.188 .29832 L
.192 .29822 L
.196 .29828 L
.2 .29853 L
Mistroke
.204 .29886 L
.208 .29899 L
.212 .29872 L
.216 .29823 L
.22 .29794 L
.224 .29806 L
.228 .29842 L
.232 .2987 L
.236 .29879 L
.24 .29877 L
.244 .29862 L
.248 .29826 L
.252 .29784 L
.256 .2977 L
.26 .29807 L
.264 .29866 L
.268 .29899 L
.272 .29885 L
.276 .29844 L
.28 .29808 L
.284 .29785 L
.288 .2977 L
.292 .29777 L
.296 .2982 L
.3 .29885 L
.304 .29918 L
.308 .2988 L
.312 .29794 L
.316 .29727 L
.32 .29727 L
.324 .29784 L
.328 .29845 L
.332 .29874 L
.336 .29874 L
.34 .29857 L
.344 .29825 L
.348 .29775 L
.352 .29724 L
.356 .29714 L
.36 .29766 L
.364 .29853 L
.368 .29912 L
.372 .29895 L
.376 .29817 L
.38 .29737 L
.384 .29711 L
.388 .29741 L
.392 .29786 L
.396 .2981 L
.4 .29817 L
Mistroke
.404 .2983 L
.408 .29853 L
.412 .29849 L
.416 .29787 L
.42 .29695 L
.424 .29649 L
.428 .29708 L
.432 .29838 L
.436 .29927 L
.44 .29894 L
.444 .29771 L
.448 .29679 L
.452 .29704 L
.456 .29802 L
.46 .29848 L
.464 .29777 L
.468 .29665 L
.472 .29652 L
.476 .29786 L
.48 .29946 L
.484 .2996 L
.488 .29785 L
.492 .29573 L
.496 .29533 L
.5 .29711 L
.504 .29937 L
.508 .29985 L
.512 .298 L
.516 .29566 L
.52 .29527 L
.524 .29741 L
.528 .30006 L
.532 .30053 L
.536 .29806 L
.54 .29471 L
.544 .29353 L
.548 .29569 L
.552 .29938 L
.556 .30141 L
.56 .30008 L
.564 .2967 L
.568 .29432 L
.572 .29499 L
.576 .29796 L
.58 .30042 L
.584 .30004 L
.588 .29702 L
.592 .29387 L
.596 .29326 L
.6 .29581 L
Mistroke
.604 .29962 L
.608 .30191 L
.612 .30111 L
.616 .29793 L
.62 .29461 L
.624 .29321 L
.628 .29433 L
.632 .29703 L
.636 .29969 L
.64 .30105 L
.644 .30069 L
.648 .29891 L
.652 .2965 L
.656 .29449 L
.66 .29389 L
.664 .29525 L
.668 .2982 L
.672 .30133 L
.676 .30281 L
.68 .30162 L
.684 .29842 L
.688 .2955 L
.692 .29539 L
.696 .29906 L
.7 .30492 L
.704 .30952 L
.708 .30963 L
.712 .30456 L
.716 .29695 L
.72 .29149 L
.724 .29215 L
.728 .29966 L
.732 .31081 L
.736 .32011 L
.74 .32285 L
.744 .31775 L
.748 .3077 L
.752 .2981 L
.756 .29397 L
.76 .2973 L
.764 .30625 L
.768 .31637 L
.772 .32305 L
.776 .32373 L
.78 .31884 L
.784 .31106 L
.788 .30361 L
.792 .29872 L
.796 .29695 L
.8 .2976 L
Mistroke
.804 .29965 L
.808 .30258 L
.812 .3064 L
.816 .31115 L
.82 .31613 L
.824 .31972 L
.828 .31982 L
.832 .31498 L
.836 .30547 L
.84 .29372 L
.844 .28373 L
.848 .27967 L
.852 .2842 L
.856 .29723 L
.86 .3158 L
.864 .335 L
.868 .34973 L
.872 .35644 L
.876 .35429 L
.88 .34523 L
.884 .33311 L
.888 .32217 L
.892 .31555 L
.896 .31452 L
.9 .31832 L
.904 .32506 L
.908 .33257 L
.912 .3397 L
.916 .34649 L
.92 .35439 L
.924 .36517 L
.928 .38042 L
.932 .40045 L
.936 .42406 L
.94 .44888 L
.944 .47155 L
.948 .48945 L
.952 .50041 L
.956 .50463 L
.96 .50332 L
.964 .49948 L
.968 .49645 L
.972 .49695 L
.976 .50337 L
.98 .51516 L
.984 .53201 L
.988 .55029 L
.992 .56762 L
.996 .58049 L
1 .58642 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .56732 m
.008 .57324 L
.012 .57536 L
.016 .5735 L
.02 .57278 L
.024 .5733 L
.028 .57361 L
.032 .57341 L
.036 .57333 L
.04 .57336 L
.044 .57342 L
.048 .57339 L
.052 .57339 L
.056 .57337 L
.06 .57339 L
.064 .57338 L
.068 .57339 L
.072 .57339 L
.076 .5734 L
.08 .57339 L
.084 .57339 L
.088 .57338 L
.092 .57338 L
.096 .57337 L
.1 .57339 L
.104 .57339 L
.108 .5734 L
.112 .57339 L
.116 .5734 L
.12 .57339 L
.124 .57338 L
.128 .57338 L
.132 .57338 L
.136 .57338 L
.14 .57338 L
.144 .57338 L
.148 .57339 L
.152 .57339 L
.156 .5734 L
.16 .5734 L
.164 .5734 L
.168 .57339 L
.172 .57338 L
.176 .57337 L
.18 .57337 L
.184 .57337 L
.188 .57338 L
.192 .57339 L
.196 .5734 L
.2 .57341 L
Mistroke
.204 .57341 L
.208 .57339 L
.212 .57337 L
.216 .57335 L
.22 .57335 L
.224 .57336 L
.228 .57338 L
.232 .57339 L
.236 .57341 L
.24 .57342 L
.244 .57341 L
.248 .57339 L
.252 .57337 L
.256 .57336 L
.26 .57336 L
.264 .57336 L
.268 .57336 L
.272 .57337 L
.276 .57338 L
.28 .5734 L
.284 .57341 L
.288 .57341 L
.292 .5734 L
.296 .57339 L
.3 .57338 L
.304 .57336 L
.308 .57334 L
.312 .57334 L
.316 .57336 L
.32 .57338 L
.324 .5734 L
.328 .57341 L
.332 .57341 L
.336 .57341 L
.34 .5734 L
.344 .57338 L
.348 .57335 L
.352 .57333 L
.356 .57334 L
.36 .57335 L
.364 .57337 L
.368 .57338 L
.372 .57339 L
.376 .5734 L
.38 .57342 L
.384 .57342 L
.388 .57339 L
.392 .57336 L
.396 .57334 L
.4 .57333 L
Mistroke
.404 .57335 L
.408 .57336 L
.412 .57337 L
.416 .57336 L
.42 .57337 L
.424 .57339 L
.428 .57341 L
.432 .57341 L
.436 .57338 L
.44 .57335 L
.444 .57335 L
.448 .57337 L
.452 .57339 L
.456 .57337 L
.46 .57333 L
.464 .57331 L
.468 .57333 L
.472 .57338 L
.476 .57342 L
.48 .57341 L
.484 .57337 L
.488 .57335 L
.492 .57338 L
.496 .57342 L
.5 .57344 L
.504 .57339 L
.508 .5733 L
.512 .57325 L
.516 .57328 L
.52 .57336 L
.524 .57342 L
.528 .57341 L
.532 .57334 L
.536 .5733 L
.54 .57333 L
.544 .57341 L
.548 .57348 L
.552 .57347 L
.556 .57338 L
.56 .57329 L
.564 .57327 L
.568 .57333 L
.572 .57341 L
.576 .57343 L
.58 .57334 L
.584 .57322 L
.588 .57316 L
.592 .57321 L
.596 .57335 L
.6 .5735 L
Mistroke
.604 .57357 L
.608 .57354 L
.612 .57345 L
.616 .57337 L
.62 .57332 L
.624 .57332 L
.628 .57331 L
.632 .57327 L
.636 .57318 L
.64 .57309 L
.644 .57304 L
.648 .57307 L
.652 .57318 L
.656 .57333 L
.66 .57346 L
.664 .57349 L
.668 .57338 L
.672 .57316 L
.676 .57288 L
.68 .57264 L
.684 .57252 L
.688 .57253 L
.692 .57258 L
.696 .57253 L
.7 .57229 L
.704 .57183 L
.708 .57126 L
.712 .57073 L
.716 .57038 L
.72 .57023 L
.724 .57018 L
.728 .57003 L
.732 .56964 L
.736 .56892 L
.74 .56799 L
.744 .56699 L
.748 .56611 L
.752 .5654 L
.756 .56482 L
.76 .5642 L
.764 .56341 L
.768 .56238 L
.772 .56116 L
.776 .55987 L
.78 .55869 L
.784 .55773 L
.788 .55701 L
.792 .55648 L
.796 .55605 L
.8 .55563 L
Mistroke
.804 .55515 L
.808 .55457 L
.812 .55387 L
.816 .55303 L
.82 .55207 L
.824 .55103 L
.828 .54998 L
.832 .54904 L
.836 .54834 L
.84 .54795 L
.844 .54785 L
.848 .54791 L
.852 .5479 L
.856 .5476 L
.86 .5468 L
.864 .54544 L
.868 .54356 L
.872 .54138 L
.876 .53913 L
.88 .53707 L
.884 .53538 L
.888 .53412 L
.892 .53326 L
.896 .53268 L
.9 .53224 L
.904 .53182 L
.908 .53133 L
.912 .53068 L
.916 .52982 L
.92 .52868 L
.924 .52713 L
.928 .52506 L
.932 .52231 L
.936 .51882 L
.94 .51451 L
.944 .50949 L
.948 .50386 L
.952 .49784 L
.956 .49163 L
.96 .48542 L
.964 .47932 L
.968 .47332 L
.972 .46735 L
.976 .46126 L
.98 .45484 L
.984 .44799 L
.988 .44052 L
.992 .43256 L
.996 .42405 L
1 .41531 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42629 L
.012 .43007 L
.016 .43118 L
.02 .42969 L
.024 .42937 L
.028 .42982 L
.032 .42993 L
.036 .42968 L
.04 .42964 L
.044 .42965 L
.048 .42965 L
.052 .42956 L
.056 .42955 L
.06 .42951 L
.064 .4295 L
.068 .42945 L
.072 .42944 L
.076 .4294 L
.08 .42938 L
.084 .42933 L
.088 .4293 L
.092 .42925 L
.096 .42922 L
.1 .42919 L
.104 .42917 L
.108 .42915 L
.112 .42913 L
.116 .4291 L
.12 .42906 L
.124 .42901 L
.128 .42897 L
.132 .42893 L
.136 .4289 L
.14 .42888 L
.144 .42886 L
.148 .42883 L
.152 .42881 L
.156 .42877 L
.16 .42874 L
.164 .4287 L
.168 .42867 L
.172 .42862 L
.176 .42858 L
.18 .42854 L
.184 .42852 L
.188 .4285 L
.192 .42849 L
.196 .42847 L
.2 .42844 L
Mistroke
.204 .4284 L
.208 .42835 L
.212 .42829 L
.216 .42825 L
.22 .42822 L
.224 .4282 L
.228 .42818 L
.232 .42817 L
.236 .42815 L
.24 .42812 L
.244 .42809 L
.248 .42804 L
.252 .42799 L
.256 .42795 L
.26 .42791 L
.264 .42788 L
.268 .42784 L
.272 .42782 L
.276 .42781 L
.28 .4278 L
.284 .42777 L
.288 .42774 L
.292 .42771 L
.296 .42766 L
.3 .42761 L
.304 .42755 L
.308 .4275 L
.312 .42747 L
.316 .42746 L
.32 .42746 L
.324 .42746 L
.328 .42743 L
.332 .4274 L
.336 .42736 L
.34 .42732 L
.344 .42726 L
.348 .4272 L
.352 .42715 L
.356 .42712 L
.36 .42711 L
.364 .4271 L
.368 .42708 L
.372 .42706 L
.376 .42704 L
.38 .42703 L
.384 .427 L
.388 .42694 L
.392 .42687 L
.396 .42681 L
.4 .42677 L
Mistroke
.404 .42675 L
.408 .42674 L
.412 .42671 L
.416 .42668 L
.42 .42667 L
.424 .42666 L
.428 .42665 L
.432 .42661 L
.436 .42654 L
.44 .42648 L
.444 .42645 L
.448 .42644 L
.452 .42643 L
.456 .42638 L
.46 .4263 L
.464 .42624 L
.468 .42623 L
.472 .42626 L
.476 .42627 L
.48 .42624 L
.484 .42616 L
.488 .42611 L
.492 .4261 L
.496 .42613 L
.5 .42611 L
.504 .42601 L
.508 .42588 L
.512 .42579 L
.516 .4258 L
.52 .42587 L
.524 .42591 L
.528 .42586 L
.532 .42574 L
.536 .42566 L
.54 .42566 L
.544 .42574 L
.548 .4258 L
.552 .42575 L
.556 .42561 L
.56 .42546 L
.564 .4254 L
.568 .42545 L
.572 .42552 L
.576 .42551 L
.58 .42538 L
.584 .42519 L
.588 .42508 L
.592 .42511 L
.596 .42526 L
.6 .42542 L
Mistroke
.604 .42548 L
.608 .42542 L
.612 .42528 L
.616 .42515 L
.62 .42507 L
.624 .42505 L
.628 .42502 L
.632 .42495 L
.636 .42483 L
.64 .42472 L
.644 .42466 L
.648 .42471 L
.652 .42487 L
.656 .4251 L
.66 .42531 L
.664 .42543 L
.668 .42539 L
.672 .42524 L
.676 .42504 L
.68 .42494 L
.684 .42503 L
.688 .42533 L
.692 .42573 L
.696 .42608 L
.7 .42626 L
.704 .42625 L
.708 .42618 L
.712 .42626 L
.716 .42667 L
.72 .42745 L
.724 .42846 L
.728 .42948 L
.732 .4303 L
.736 .43087 L
.74 .43127 L
.744 .43173 L
.748 .43245 L
.752 .43349 L
.756 .43477 L
.76 .4361 L
.764 .43728 L
.768 .43821 L
.772 .43891 L
.776 .43955 L
.78 .4403 L
.784 .44129 L
.788 .44252 L
.792 .44392 L
.796 .44537 L
.8 .44674 L
Mistroke
.804 .44794 L
.808 .44894 L
.812 .44971 L
.816 .45025 L
.82 .45059 L
.824 .45079 L
.828 .451 L
.832 .45137 L
.836 .45208 L
.84 .45324 L
.844 .45484 L
.848 .45672 L
.852 .45863 L
.856 .46026 L
.86 .46138 L
.864 .46188 L
.868 .46185 L
.872 .46153 L
.876 .46123 L
.88 .4613 L
.884 .46196 L
.888 .46334 L
.892 .46544 L
.896 .46816 L
.9 .47138 L
.904 .47499 L
.908 .47891 L
.912 .48309 L
.916 .48743 L
.92 .49183 L
.924 .49609 L
.928 .49998 L
.932 .50322 L
.936 .50558 L
.94 .50688 L
.944 .5071 L
.948 .50628 L
.952 .50464 L
.956 .5024 L
.96 .49981 L
.964 .4971 L
.968 .49435 L
.972 .49163 L
.976 .48888 L
.98 .48595 L
.984 .48281 L
.988 .47923 L
.992 .47532 L
.996 .4709 L
1 .46625 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo04moo`8001]oo`008Woo0`0027oo00<007oo0000400000=oo`0000007P0000Aoo`00001o
o`800004Ool00000Ool20002Ool20003Ool00`00Ool0000JOol0029oof<000aoo`008Woo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00002Ool0
1@00Oomoogoo00000Woo0`0000=oo`000000100000Moo`00000007oo001oo`0300000goo001oo`02
Ool01@00Oomoogoo000037oo000ROol20016Ool00`00Oomoo`020003Ool20002Ool00`00Oomoo`02
000FOol0029oo`03001oogoo055oo`03001oo`00009oo`03001oogoo01=oo`008Woo0P00Dgoo0P00
0Woo00<007ooOol04goo000ROol2001COol00`00Oomoo`02Ool00`00Oomoo`0BOol000]oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo05Moo`03001oogoo019oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001IOol00`00Oomoo`0AOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00FGoo00<007ooOol04Goo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo05Qoo`03001oogoo015oo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001IOol00`00Oomoo`0AOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00FGoo00<007ooOol04Goo000;Ool2
000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1HOol00`00Oomoo`0AOol000]oo`8000Aoo`03
001oogoo00=oo`80009oo`D0009oo`8005Uoo`03001oogoo015oo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`000Woo0P00FWoo00<007ooOol047oo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo05Uoo`03001oogoo011oo`002Woo00@007oo
Ool000Qoo`04001oogoo0004Ool01000Oomoogoo0P00FWoo00<007ooOol047oo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001JOol00`00Oomoo`0@Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001KOol00`00Oomoo`0@Ool000]oo`8000Yo
o`8000=oo`<000=oo`8005]oo`<000moo`008Woo00<007ooOol0FWoo00<007oo00003goo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool2001NOol00`00Oomoo`0<Ool000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008005ioo`03001oogoo00aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0005Ool01000Oomoo`00Ggoo00<007ooOol037oo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`8000=oo`8005ioo`03001oogoo00aoo`002Woo00@007ooOol000Qoo`04
001oogoo0005Ool00`00Oomoo`02001NOol00`00Oomoo`0<Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`04001oogoo001POol00`00Oomoo`0;Ool000]oo`8000Yoo`8000=oo`<000=o
o`8005moo`03001oogoo00]oo`008Woo0P00H7oo00<007ooOol02Woo000ROol00`00Oomoo`1/Ool0
029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04
001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo
06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
00Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool0
0`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004
Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004
Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03
001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004
Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001o
ogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uo
o`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04
001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001o
ogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03
001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo
00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`80
00Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
oed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo
00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo
00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00FWoo00<007ooOol02Woo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1HOol00`00Oomo
o`0;Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomo
o`1GOol00`00Oomoo`0<Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo05Moo`03
001oogoo00aoo`00:7oo00<007ooOol0EWoo00<007ooOol03Goo000XOol00`00Oomoo`1FOol00`00
Oomoo`0=Ool0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo05Eoo`03001o
ogoo00ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1D
Ool2000@Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
Dgoo0P004Goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8005Aoo`03
001oogoo011oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1@Ool3000COol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0CGoo
0`005Woo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`17Ool6000IOol002Qoo`03
001oogoo049oo`H001ioo`00:7ooAP008goo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007oo
Ool0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo
00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol0
00Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`00
2goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004
Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004
Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001o
ogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`00
0goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03
001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo
0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo
00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Ao
o`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D0
00=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004
Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007oo
Ool02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00
M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<0
07ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomo
o`02Ool00`00Oomoo`10Ool00`00Oomoo`0_Ool001Moo`03001oogoo009oodl002Ioo`005goo00<0
07ooOol00Woo00<007ooOol0Bgoo1@008Woo000GOol00`00Oomoo`02Ool00`00Oomoo`1?Ool6000M
Ool001Ioo`8000Aoo`8005Eoo`H001Qoo`005goo00<007ooOol00Woo00<007ooOol0FGoo0P002Goo
0P0037oo000LOol00`00Oomoo`1KOol00`00Oomoo`05Ool2000=Ool001aoo`8005aoo`8000Eoo`80
00ioo`0077oo00<007ooOol0GGoo00<007ooOol00P0047oo000LOol2001OOol3000AOol001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001c
Ool000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo
00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007oo
Ool01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol0
00]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1b
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(31897\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29687 m
.008 .2988 L
.012 .29974 L
.016 .29993 L
.02 .29911 L
.024 .29869 L
.028 .29896 L
.032 .29911 L
.036 .299 L
.04 .299 L
.044 .29916 L
.048 .29924 L
.052 .29911 L
.056 .29892 L
.06 .2988 L
.064 .29879 L
.068 .29892 L
.072 .29906 L
.076 .29911 L
.08 .29906 L
.084 .29893 L
.088 .29879 L
.092 .29874 L
.096 .29878 L
.1 .29891 L
.104 .299 L
.108 .29896 L
.112 .29884 L
.116 .29873 L
.12 .29869 L
.124 .29872 L
.128 .29877 L
.132 .29885 L
.136 .2989 L
.14 .29886 L
.144 .29873 L
.148 .2986 L
.152 .29856 L
.156 .29861 L
.16 .29865 L
.164 .29871 L
.168 .29882 L
.172 .29888 L
.176 .29878 L
.18 .29852 L
.184 .29832 L
.188 .29834 L
.192 .29852 L
.196 .2987 L
.2 .29882 L
Mistroke
.204 .29884 L
.208 .29871 L
.212 .29841 L
.216 .29809 L
.22 .29808 L
.224 .29844 L
.228 .29887 L
.232 .29897 L
.236 .29869 L
.24 .29831 L
.244 .29809 L
.248 .29805 L
.252 .29814 L
.256 .2984 L
.26 .29876 L
.264 .29897 L
.268 .29875 L
.272 .29817 L
.276 .29772 L
.28 .29775 L
.284 .29817 L
.288 .29857 L
.292 .2987 L
.296 .29866 L
.3 .29855 L
.304 .29831 L
.308 .2979 L
.312 .29754 L
.316 .29761 L
.32 .2982 L
.324 .29888 L
.328 .29906 L
.332 .29861 L
.336 .29793 L
.34 .29751 L
.344 .29752 L
.348 .29776 L
.352 .29806 L
.356 .29837 L
.36 .29869 L
.364 .29881 L
.368 .29849 L
.372 .29777 L
.376 .29711 L
.38 .29704 L
.384 .29766 L
.388 .29851 L
.392 .29894 L
.396 .29869 L
.4 .29805 L
Mistroke
.404 .29757 L
.408 .2975 L
.412 .29761 L
.416 .29763 L
.42 .29758 L
.424 .2978 L
.428 .2984 L
.432 .29896 L
.436 .29878 L
.44 .29772 L
.444 .29653 L
.448 .29629 L
.452 .29729 L
.456 .29867 L
.46 .29916 L
.464 .2984 L
.468 .29728 L
.472 .29701 L
.476 .2978 L
.48 .29856 L
.484 .29818 L
.488 .29682 L
.492 .29595 L
.496 .29676 L
.5 .29877 L
.504 .30006 L
.508 .2992 L
.512 .29681 L
.516 .2951 L
.52 .29577 L
.524 .2982 L
.528 .3 L
.532 .29933 L
.536 .29678 L
.54 .29489 L
.544 .29566 L
.548 .29853 L
.552 .30081 L
.556 .3002 L
.56 .297 L
.564 .29397 L
.568 .2938 L
.572 .29666 L
.576 .30007 L
.58 .30111 L
.584 .29903 L
.588 .29584 L
.592 .29445 L
.596 .29605 L
.6 .29914 L
Mistroke
.604 .30091 L
.608 .2997 L
.612 .29641 L
.616 .29369 L
.62 .29375 L
.624 .29663 L
.628 .30032 L
.632 .30234 L
.636 .30158 L
.64 .29887 L
.644 .29614 L
.648 .29507 L
.652 .29614 L
.656 .29867 L
.66 .30147 L
.664 .30344 L
.668 .30395 L
.672 .30291 L
.676 .30085 L
.68 .29891 L
.684 .29844 L
.688 .30032 L
.692 .30417 L
.696 .30826 L
.7 .3104 L
.704 .3094 L
.708 .30608 L
.712 .3031 L
.716 .30328 L
.72 .30762 L
.724 .31429 L
.728 .31944 L
.732 .31955 L
.736 .3138 L
.74 .30494 L
.744 .29792 L
.748 .29701 L
.752 .30321 L
.756 .31347 L
.76 .32231 L
.764 .32483 L
.768 .31945 L
.772 .3087 L
.776 .29781 L
.78 .29187 L
.784 .29324 L
.788 .30063 L
.792 .31008 L
.796 .3172 L
.8 .31931 L
Mistroke
.804 .31637 L
.808 .3105 L
.812 .30448 L
.816 .30035 L
.82 .2988 L
.824 .29946 L
.828 .30175 L
.832 .30553 L
.836 .3111 L
.84 .31862 L
.844 .32741 L
.848 .33564 L
.852 .34089 L
.856 .34126 L
.86 .33656 L
.864 .32892 L
.868 .3223 L
.872 .32122 L
.876 .32886 L
.88 .34584 L
.884 .36953 L
.888 .39504 L
.892 .4166 L
.896 .42963 L
.9 .43192 L
.904 .42424 L
.908 .40964 L
.912 .3921 L
.916 .3753 L
.92 .36122 L
.924 .35049 L
.928 .34207 L
.932 .3351 L
.936 .32896 L
.94 .32445 L
.944 .32348 L
.948 .3281 L
.952 .34057 L
.956 .36087 L
.96 .38834 L
.964 .4194 L
.968 .45036 L
.972 .47701 L
.976 .49586 L
.98 .50624 L
.984 .50788 L
.988 .50434 L
.992 .49843 L
.996 .49416 L
1 .49484 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57737 m
.008 .57279 L
.012 .57142 L
.016 .57309 L
.02 .57354 L
.024 .57287 L
.028 .57278 L
.032 .57299 L
.036 .57305 L
.04 .57293 L
.044 .57295 L
.048 .57296 L
.052 .57298 L
.056 .57296 L
.06 .57297 L
.064 .57296 L
.068 .57297 L
.072 .57296 L
.076 .57297 L
.08 .57296 L
.084 .57296 L
.088 .57295 L
.092 .57296 L
.096 .57296 L
.1 .57297 L
.104 .57297 L
.108 .57298 L
.112 .57296 L
.116 .57296 L
.12 .57294 L
.124 .57295 L
.128 .57295 L
.132 .57297 L
.136 .57298 L
.14 .57298 L
.144 .57297 L
.148 .57296 L
.152 .57295 L
.156 .57295 L
.16 .57295 L
.164 .57295 L
.168 .57296 L
.172 .57296 L
.176 .57297 L
.18 .57297 L
.184 .57298 L
.188 .57298 L
.192 .57297 L
.196 .57295 L
.2 .57294 L
Mistroke
.204 .57294 L
.208 .57294 L
.212 .57295 L
.216 .57297 L
.22 .57298 L
.224 .57299 L
.228 .57298 L
.232 .57296 L
.236 .57295 L
.24 .57294 L
.244 .57293 L
.248 .57294 L
.252 .57295 L
.256 .57296 L
.26 .57298 L
.264 .57298 L
.268 .57298 L
.272 .57297 L
.276 .57296 L
.28 .57295 L
.284 .57294 L
.288 .57294 L
.292 .57293 L
.296 .57294 L
.3 .57295 L
.304 .57297 L
.308 .57298 L
.312 .57298 L
.316 .57299 L
.32 .57298 L
.324 .57296 L
.328 .57293 L
.332 .57291 L
.336 .57292 L
.34 .57293 L
.344 .57295 L
.348 .57296 L
.352 .57298 L
.356 .57299 L
.36 .57299 L
.364 .57298 L
.368 .57295 L
.372 .57293 L
.376 .57292 L
.38 .57292 L
.384 .57293 L
.388 .57294 L
.392 .57294 L
.396 .57295 L
.4 .57298 L
Mistroke
.404 .573 L
.408 .573 L
.412 .57297 L
.416 .57294 L
.42 .57292 L
.424 .57292 L
.428 .57293 L
.432 .57293 L
.436 .57292 L
.44 .57293 L
.444 .57295 L
.448 .57298 L
.452 .57299 L
.456 .57298 L
.46 .57294 L
.464 .57293 L
.468 .57294 L
.472 .57297 L
.476 .57297 L
.48 .57294 L
.484 .57289 L
.488 .57288 L
.492 .57291 L
.496 .57296 L
.5 .57298 L
.504 .57296 L
.508 .57293 L
.512 .57293 L
.516 .57298 L
.52 .57302 L
.524 .57301 L
.528 .57294 L
.532 .57286 L
.536 .57284 L
.54 .57289 L
.544 .57296 L
.548 .57299 L
.552 .57295 L
.556 .57288 L
.56 .57286 L
.564 .57292 L
.568 .57301 L
.572 .57306 L
.576 .57302 L
.58 .57292 L
.584 .57285 L
.588 .57286 L
.592 .57293 L
.596 .573 L
.6 .57298 L
Mistroke
.604 .57287 L
.608 .57274 L
.612 .57268 L
.616 .57272 L
.62 .57283 L
.624 .57295 L
.628 .57299 L
.632 .57294 L
.636 .57283 L
.64 .57273 L
.644 .57264 L
.648 .57257 L
.652 .57248 L
.656 .57233 L
.66 .57212 L
.664 .57188 L
.668 .57165 L
.672 .57148 L
.676 .57137 L
.68 .5713 L
.684 .57118 L
.688 .57095 L
.692 .57053 L
.696 .56995 L
.7 .56926 L
.704 .56857 L
.708 .56797 L
.712 .56748 L
.716 .56701 L
.72 .56643 L
.724 .56564 L
.728 .56461 L
.732 .56345 L
.736 .56233 L
.74 .56141 L
.744 .56072 L
.748 .56019 L
.752 .55964 L
.756 .55892 L
.76 .55797 L
.764 .55686 L
.768 .55576 L
.772 .55483 L
.776 .55414 L
.78 .55364 L
.784 .5532 L
.788 .55266 L
.792 .55193 L
.796 .55103 L
.8 .55005 L
Mistroke
.804 .54913 L
.808 .54836 L
.812 .54776 L
.816 .5473 L
.82 .54691 L
.824 .5465 L
.828 .546 L
.832 .54536 L
.836 .54454 L
.84 .54351 L
.844 .54227 L
.848 .54084 L
.852 .53931 L
.856 .53779 L
.86 .53643 L
.864 .53532 L
.868 .53447 L
.872 .53376 L
.876 .53297 L
.88 .53186 L
.884 .53019 L
.888 .52782 L
.892 .52478 L
.896 .52124 L
.9 .51744 L
.904 .51368 L
.908 .51021 L
.912 .5072 L
.916 .5047 L
.92 .50273 L
.924 .50119 L
.928 .50003 L
.932 .49916 L
.936 .4985 L
.94 .49797 L
.944 .49742 L
.948 .49669 L
.952 .49556 L
.956 .4938 L
.96 .49125 L
.964 .48776 L
.968 .48338 L
.972 .47816 L
.976 .47238 L
.98 .46622 L
.984 .46001 L
.988 .45388 L
.992 .44795 L
.996 .44221 L
1 .43654 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42536 L
.012 .42973 L
.016 .43139 L
.02 .42993 L
.024 .42934 L
.028 .42969 L
.032 .42991 L
.036 .42972 L
.04 .42964 L
.044 .42963 L
.048 .42965 L
.052 .42958 L
.056 .42956 L
.06 .42951 L
.064 .42951 L
.068 .42945 L
.072 .42943 L
.076 .42938 L
.08 .42936 L
.084 .42932 L
.088 .4293 L
.092 .42927 L
.096 .42925 L
.1 .42921 L
.104 .42918 L
.108 .42914 L
.112 .4291 L
.116 .42906 L
.12 .42904 L
.124 .42901 L
.128 .42899 L
.132 .42896 L
.136 .42893 L
.14 .4289 L
.144 .42886 L
.148 .42882 L
.152 .42879 L
.156 .42875 L
.16 .42872 L
.164 .42869 L
.168 .42867 L
.172 .42864 L
.176 .42861 L
.18 .42858 L
.184 .42855 L
.188 .42852 L
.192 .42848 L
.196 .42844 L
.2 .4284 L
Mistroke
.204 .42836 L
.208 .42832 L
.212 .4283 L
.216 .42828 L
.22 .42827 L
.224 .42826 L
.228 .42822 L
.232 .42817 L
.236 .42811 L
.24 .42806 L
.244 .42802 L
.248 .428 L
.252 .42798 L
.256 .42797 L
.26 .42796 L
.264 .42794 L
.268 .4279 L
.272 .42785 L
.276 .42781 L
.28 .42777 L
.284 .42772 L
.288 .42768 L
.292 .42765 L
.296 .42763 L
.3 .42762 L
.304 .4276 L
.308 .42758 L
.312 .42755 L
.316 .42752 L
.32 .42748 L
.324 .42743 L
.328 .42737 L
.332 .42732 L
.336 .42729 L
.34 .42727 L
.344 .42726 L
.348 .42725 L
.352 .42723 L
.356 .42721 L
.36 .42719 L
.364 .42714 L
.368 .42708 L
.372 .42702 L
.376 .42697 L
.38 .42694 L
.384 .42692 L
.388 .4269 L
.392 .42688 L
.396 .42686 L
.4 .42686 L
Mistroke
.404 .42685 L
.408 .42681 L
.412 .42675 L
.416 .42668 L
.42 .42663 L
.424 .4266 L
.428 .42658 L
.432 .42655 L
.436 .42651 L
.44 .42648 L
.444 .42647 L
.448 .42648 L
.452 .42647 L
.456 .42641 L
.46 .42634 L
.464 .42629 L
.468 .42628 L
.472 .42628 L
.476 .42625 L
.48 .42617 L
.484 .42609 L
.488 .42605 L
.492 .42606 L
.496 .42609 L
.5 .42608 L
.504 .42601 L
.508 .42594 L
.512 .42592 L
.516 .42595 L
.52 .42597 L
.524 .42593 L
.528 .42581 L
.532 .42568 L
.536 .42561 L
.54 .42565 L
.544 .42571 L
.548 .42571 L
.552 .42563 L
.556 .42552 L
.56 .42546 L
.564 .4255 L
.568 .42559 L
.572 .42562 L
.576 .42554 L
.58 .4254 L
.584 .42528 L
.588 .42526 L
.592 .42533 L
.596 .42539 L
.6 .42535 L
Mistroke
.604 .4252 L
.608 .42503 L
.612 .42495 L
.616 .425 L
.62 .42516 L
.624 .42532 L
.628 .4254 L
.632 .42539 L
.636 .42533 L
.64 .42529 L
.644 .42531 L
.648 .42537 L
.652 .42543 L
.656 .42547 L
.66 .42548 L
.664 .4255 L
.668 .42561 L
.672 .42586 L
.676 .42626 L
.68 .42679 L
.684 .42736 L
.688 .42788 L
.692 .42829 L
.696 .4286 L
.7 .4289 L
.704 .42933 L
.708 .42999 L
.712 .43091 L
.716 .43199 L
.72 .43305 L
.724 .43394 L
.728 .43465 L
.732 .43527 L
.736 .43602 L
.74 .43707 L
.744 .43844 L
.748 .44002 L
.752 .44156 L
.756 .44285 L
.76 .44381 L
.764 .44451 L
.768 .44515 L
.772 .44591 L
.776 .44688 L
.78 .44801 L
.784 .44913 L
.788 .45005 L
.792 .45069 L
.796 .45109 L
.8 .45138 L
Mistroke
.804 .45175 L
.808 .45235 L
.812 .45323 L
.816 .45435 L
.82 .45565 L
.824 .45702 L
.828 .45837 L
.832 .45965 L
.836 .46081 L
.84 .46181 L
.844 .46264 L
.848 .46334 L
.852 .46403 L
.856 .46488 L
.86 .46608 L
.864 .46781 L
.868 .47011 L
.872 .47289 L
.876 .47592 L
.88 .47894 L
.884 .48167 L
.888 .48398 L
.892 .48587 L
.896 .48751 L
.9 .48914 L
.904 .49106 L
.908 .49343 L
.912 .49637 L
.916 .49983 L
.92 .50368 L
.924 .50777 L
.928 .51197 L
.932 .51617 L
.936 .52033 L
.94 .52445 L
.944 .52847 L
.948 .53231 L
.952 .53585 L
.956 .53887 L
.96 .54124 L
.964 .54274 L
.968 .54338 L
.972 .54306 L
.976 .54201 L
.98 .54027 L
.984 .53812 L
.988 .53564 L
.992 .53298 L
.996 .53017 L
1 .52717 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo06aoo`008Woo0`001Woo00D007oo000007oo00<00003Ool0000001d00003Ool0000000L0
0004Ool00000Ool20002Ool00`00Oomoo`03Ool00`00Oomoo`02000QOol0029oof<000aoo`008Woo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0002Ool01P00Oomoogoo001oo`D00004Ool00000Ool30002Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`03001oogoo00Yoo`008Woo0P00AGoo00<007ooOol00P000Woo00H007ooOomoo`00
Ool20005Ool2000BOol0029oo`03001oogoo051oo`<000Eoo`80019oo`008Woo0P00DGoo0P0000=o
o`00Ool00goo00<007oo00004Goo000ROol2001DOol01@00Oomoogoo00000Woo00<007ooOol03goo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1COol01@00Oomoogoo0000
0Woo00<007ooOol03goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
05Aoo`04001oogoo0003Ool00`00Oomoo`0?Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00EGoo00<007oo000017oo00<007ooOol03Woo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo05Aoo`03001oo`0000Aoo`03001oogoo00io
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001EOol00`00Ool00004
Ool00`00Oomoo`0>Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00EGoo00<0
07oo000017oo00<007ooOol03Woo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1D
Ool20005Ool00`00Oomoo`0>Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8005ao
o`03001oogoo00ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00
G7oo00<007ooOol03Woo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo05]oo`03001oogoo00ioo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomo
ogoo0P00GGoo00<007ooOol03Goo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00
Oomoo`02001MOol00`00Oomoo`0=Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04
001oogoo001NOol00`00Oomoo`0=Ool000]oo`8000Yoo`8000=oo`<000=oo`8005eoo`04001oo`00
000<Ool0029oo`03001oogoo05eoo`03001oogoo00aoo`002goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
1Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomo
o`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0
K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004
Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007oo
Ool00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P00
17oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo
0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo
0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003
Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@0
07ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo
000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`00
0Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomo
o`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool0
0`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003
Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`80
00Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004
Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo
00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`80
00Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0F7oo0P0037oo000;Ool2000:
Ool20004Ool20002Ool50002Ool00`00Oomoo`1GOol2000=Ool002Qoo`03001oogoo05Moo`03001o
ogoo00aoo`00:7oo00<007ooOol0EWoo00<007ooOol03Goo000AOol20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool00`00Oomoo`1EOol2000?Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0DWoo100047oo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo051oo`<001=oo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2001@Ool2000EOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0CWoo0P005Woo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`03001oogoo04Yoo`@001Qoo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0
A7oo1`006goo000XOol00`00Oomoo`10Ool5000QOol002Qood<002Ioo`00:7oo00<007ooOol0IWoo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@00
0Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001d
Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00
Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol03Goo
0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo
0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol0
00Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005
Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011o
o`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001ao
o`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool0
0`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`00
1Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0
009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`00
1Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo
1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007oo
Ool00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo
Ool00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03
001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000;Ool20004Ool0
0`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomo
o`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001ao
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Ioo`<000=oo`03001oogoo
079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Oom<000YOol001Mo
o`03001oogoo009oo`03001oogoo04Qoo`D002Eoo`005goo00<007ooOol00Woo00<007ooOol0C7oo
1P0087oo000FOol20004Ool2001COol4000LOol001Moo`03001oogoo009oo`03001oogoo05Eoo`<0
01Yoo`0077oo00<007ooOol0F7oo0P0067oo000LOol2001JOol3000FOol001aoo`03001oogoo05]o
o`8001Eoo`0077oo0P00GGoo0P0057oo000LOol00`00Oomoo`1MOol2000COol001aoo`03001oogoo
05ioo`8000Aoo`8000aoo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00H7oo0P0000Aoo`00
000000eoo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo061oo`<000moo`00
2goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo
000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03
001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(32064\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30062 m
.008 .3002 L
.012 .29851 L
.016 .29835 L
.02 .29954 L
.024 .29968 L
.028 .29898 L
.032 .29881 L
.036 .29907 L
.04 .29914 L
.044 .29907 L
.048 .2991 L
.052 .29915 L
.056 .29906 L
.06 .29894 L
.064 .29889 L
.068 .29896 L
.072 .29906 L
.076 .2991 L
.08 .29905 L
.084 .29894 L
.088 .29882 L
.092 .29878 L
.096 .29884 L
.1 .29897 L
.104 .29907 L
.108 .29902 L
.112 .29886 L
.116 .29872 L
.12 .29869 L
.124 .29877 L
.128 .29888 L
.132 .29895 L
.136 .29893 L
.14 .2988 L
.144 .29863 L
.148 .29856 L
.152 .29866 L
.156 .29885 L
.16 .29894 L
.164 .29885 L
.168 .29869 L
.172 .29856 L
.176 .2985 L
.18 .29851 L
.184 .29862 L
.188 .29881 L
.192 .29891 L
.196 .2988 L
.2 .29854 L
Mistroke
.204 .29836 L
.208 .29836 L
.212 .29846 L
.216 .29855 L
.22 .29866 L
.224 .2988 L
.228 .29881 L
.232 .29857 L
.236 .2982 L
.24 .29803 L
.244 .29822 L
.248 .29858 L
.252 .29881 L
.256 .2988 L
.26 .29864 L
.264 .29839 L
.268 .29809 L
.272 .29786 L
.276 .29795 L
.28 .29843 L
.284 .29896 L
.288 .29906 L
.292 .29859 L
.296 .29797 L
.3 .29768 L
.304 .2978 L
.308 .29813 L
.312 .29842 L
.316 .29867 L
.32 .29883 L
.324 .29871 L
.328 .29821 L
.332 .29757 L
.336 .29729 L
.34 .29767 L
.344 .29843 L
.348 .29897 L
.352 .29894 L
.356 .29847 L
.36 .29795 L
.364 .29761 L
.368 .29748 L
.372 .29753 L
.376 .29782 L
.38 .29836 L
.384 .2989 L
.388 .29901 L
.392 .29845 L
.396 .29753 L
.4 .29691 L
Mistroke
.404 .29706 L
.408 .29784 L
.412 .2986 L
.416 .29879 L
.42 .29841 L
.424 .29792 L
.428 .29772 L
.432 .29773 L
.436 .29763 L
.44 .29734 L
.444 .29726 L
.448 .29781 L
.452 .29874 L
.456 .29923 L
.46 .2986 L
.464 .29721 L
.468 .29622 L
.472 .29655 L
.476 .29788 L
.48 .29891 L
.484 .29868 L
.488 .29757 L
.492 .29692 L
.496 .29751 L
.5 .29866 L
.504 .29889 L
.508 .29763 L
.512 .29595 L
.516 .29566 L
.52 .29732 L
.524 .29952 L
.528 .30011 L
.532 .29839 L
.536 .29593 L
.54 .2951 L
.544 .29673 L
.548 .29922 L
.552 .30008 L
.556 .29834 L
.56 .29565 L
.564 .2947 L
.568 .29662 L
.572 .29981 L
.576 .30132 L
.58 .29964 L
.584 .29612 L
.588 .29383 L
.592 .29477 L
.596 .29815 L
.6 .30108 L
Mistroke
.604 .30121 L
.608 .29872 L
.612 .29609 L
.616 .29585 L
.62 .29838 L
.624 .30166 L
.628 .30307 L
.632 .30157 L
.636 .29852 L
.64 .29654 L
.644 .29741 L
.648 .3008 L
.652 .30474 L
.656 .30709 L
.66 .30701 L
.664 .30523 L
.668 .30336 L
.672 .30276 L
.676 .30395 L
.68 .30659 L
.684 .30978 L
.688 .31245 L
.692 .31364 L
.696 .31287 L
.7 .31051 L
.704 .30789 L
.708 .30676 L
.712 .30821 L
.716 .3118 L
.72 .31546 L
.724 .31669 L
.728 .31421 L
.732 .30909 L
.736 .30439 L
.74 .30328 L
.744 .30686 L
.748 .31311 L
.752 .31793 L
.756 .31753 L
.76 .311 L
.764 .30118 L
.768 .29322 L
.772 .29166 L
.776 .29779 L
.78 .30877 L
.784 .31914 L
.788 .32382 L
.792 .32085 L
.796 .3123 L
.8 .30308 L
Mistroke
.804 .29822 L
.808 .30039 L
.812 .30882 L
.816 .32011 L
.82 .33022 L
.824 .33648 L
.828 .33857 L
.832 .33811 L
.836 .33746 L
.84 .33843 L
.844 .34167 L
.848 .347 L
.852 .354 L
.856 .36267 L
.86 .37325 L
.864 .38573 L
.868 .39894 L
.872 .41052 L
.876 .41725 L
.88 .41642 L
.884 .40712 L
.888 .39101 L
.892 .37228 L
.896 .35609 L
.9 .34721 L
.904 .34785 L
.908 .35739 L
.912 .37229 L
.916 .38762 L
.92 .39894 L
.924 .40325 L
.928 .40056 L
.932 .39234 L
.936 .38186 L
.94 .37151 L
.944 .36291 L
.948 .35609 L
.952 .3496 L
.956 .34264 L
.96 .33403 L
.964 .32517 L
.968 .31786 L
.972 .31497 L
.976 .31964 L
.98 .33221 L
.984 .35335 L
.988 .37913 L
.992 .40636 L
.996 .43043 L
1 .44674 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57945 m
.008 .57262 L
.012 .57033 L
.016 .57242 L
.02 .57328 L
.024 .57258 L
.028 .57232 L
.032 .5725 L
.036 .57264 L
.04 .57255 L
.044 .57253 L
.048 .57253 L
.052 .57256 L
.056 .57254 L
.06 .57254 L
.064 .57253 L
.068 .57254 L
.072 .57253 L
.076 .57255 L
.08 .57254 L
.084 .57255 L
.088 .57254 L
.092 .57255 L
.096 .57253 L
.1 .57254 L
.104 .57253 L
.108 .57254 L
.112 .57253 L
.116 .57255 L
.12 .57255 L
.124 .57255 L
.128 .57255 L
.132 .57255 L
.136 .57254 L
.14 .57253 L
.144 .57252 L
.148 .57253 L
.152 .57254 L
.156 .57255 L
.16 .57255 L
.164 .57255 L
.168 .57255 L
.172 .57254 L
.176 .57253 L
.18 .57253 L
.184 .57253 L
.188 .57254 L
.192 .57254 L
.196 .57254 L
.2 .57254 L
Mistroke
.204 .57254 L
.208 .57255 L
.212 .57255 L
.216 .57255 L
.22 .57254 L
.224 .57253 L
.228 .57252 L
.232 .57251 L
.236 .57252 L
.24 .57254 L
.244 .57255 L
.248 .57256 L
.252 .57256 L
.256 .57255 L
.26 .57254 L
.264 .57252 L
.268 .57251 L
.272 .57251 L
.276 .57252 L
.28 .57254 L
.284 .57255 L
.288 .57256 L
.292 .57256 L
.296 .57255 L
.3 .57254 L
.304 .57253 L
.308 .57251 L
.312 .57251 L
.316 .57251 L
.32 .57252 L
.324 .57253 L
.328 .57254 L
.332 .57255 L
.336 .57256 L
.34 .57256 L
.344 .57256 L
.348 .57253 L
.352 .57251 L
.356 .5725 L
.36 .5725 L
.364 .57251 L
.368 .57251 L
.372 .57253 L
.376 .57254 L
.38 .57256 L
.384 .57257 L
.388 .57256 L
.392 .57254 L
.396 .57251 L
.4 .5725 L
Mistroke
.404 .5725 L
.408 .5725 L
.412 .5725 L
.416 .57251 L
.42 .57253 L
.424 .57256 L
.428 .57258 L
.432 .57257 L
.436 .57254 L
.44 .57252 L
.444 .57251 L
.448 .57251 L
.452 .57251 L
.456 .57249 L
.46 .57248 L
.464 .5725 L
.468 .57253 L
.472 .57256 L
.476 .57256 L
.48 .57254 L
.484 .57251 L
.488 .57251 L
.492 .57254 L
.496 .57256 L
.5 .57254 L
.504 .57249 L
.508 .57246 L
.512 .57247 L
.516 .57251 L
.52 .57254 L
.524 .57253 L
.528 .5725 L
.532 .57248 L
.536 .57251 L
.54 .57258 L
.544 .57261 L
.548 .57258 L
.552 .57249 L
.556 .57242 L
.56 .57242 L
.564 .57248 L
.568 .57253 L
.572 .57253 L
.576 .57246 L
.58 .5724 L
.584 .57239 L
.588 .57246 L
.592 .57253 L
.596 .57254 L
.6 .57245 L
Mistroke
.604 .57233 L
.608 .57224 L
.612 .57223 L
.616 .57226 L
.62 .57225 L
.624 .57213 L
.628 .57193 L
.632 .57169 L
.636 .57151 L
.64 .5714 L
.644 .57133 L
.648 .57123 L
.652 .57103 L
.656 .57074 L
.66 .57037 L
.664 .56997 L
.668 .56954 L
.672 .56909 L
.676 .56856 L
.68 .56795 L
.684 .56724 L
.688 .56647 L
.692 .56568 L
.696 .56492 L
.7 .56423 L
.704 .56358 L
.708 .56293 L
.712 .56217 L
.716 .56127 L
.72 .56021 L
.724 .55909 L
.728 .55802 L
.732 .55711 L
.736 .55639 L
.74 .55578 L
.744 .55515 L
.748 .55438 L
.752 .55345 L
.756 .55243 L
.76 .5515 L
.764 .5508 L
.768 .55036 L
.772 .55011 L
.776 .54984 L
.78 .5494 L
.784 .54871 L
.788 .5478 L
.792 .54682 L
.796 .54592 L
.8 .54517 L
Mistroke
.804 .54453 L
.808 .54389 L
.812 .54311 L
.816 .5421 L
.82 .54086 L
.824 .53948 L
.828 .53807 L
.832 .53672 L
.836 .53548 L
.84 .5343 L
.844 .53314 L
.848 .5319 L
.852 .53051 L
.856 .5289 L
.86 .527 L
.864 .52477 L
.868 .52218 L
.872 .51928 L
.876 .51615 L
.88 .51298 L
.884 .50997 L
.888 .50731 L
.892 .50511 L
.896 .50335 L
.9 .50188 L
.904 .50048 L
.908 .49888 L
.912 .4969 L
.916 .49447 L
.92 .49161 L
.924 .48847 L
.928 .48527 L
.932 .48217 L
.936 .47934 L
.94 .47682 L
.944 .47467 L
.948 .47284 L
.952 .47135 L
.956 .47017 L
.96 .46931 L
.964 .46873 L
.968 .46836 L
.972 .46805 L
.976 .46761 L
.98 .46678 L
.984 .4654 L
.988 .46319 L
.992 .46026 L
.996 .45649 L
1 .45226 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43278 L
.012 .42965 L
.016 .42888 L
.02 .42996 L
.024 .43019 L
.028 .42969 L
.032 .42963 L
.036 .42973 L
.04 .42975 L
.044 .42963 L
.048 .42961 L
.052 .42958 L
.056 .42957 L
.06 .42951 L
.064 .4295 L
.068 .42945 L
.072 .42944 L
.076 .42939 L
.08 .42937 L
.084 .42932 L
.088 .4293 L
.092 .42927 L
.096 .42925 L
.1 .4292 L
.104 .42918 L
.108 .42913 L
.112 .4291 L
.116 .42907 L
.12 .42905 L
.124 .42902 L
.128 .429 L
.132 .42896 L
.136 .42892 L
.14 .42887 L
.144 .42884 L
.148 .42881 L
.152 .42879 L
.156 .42876 L
.16 .42874 L
.164 .42871 L
.168 .42868 L
.172 .42864 L
.176 .4286 L
.18 .42856 L
.184 .42853 L
.188 .42849 L
.192 .42846 L
.196 .42844 L
.2 .42842 L
Mistroke
.204 .4284 L
.208 .42837 L
.212 .42833 L
.216 .42829 L
.22 .42825 L
.224 .42821 L
.228 .42816 L
.232 .42813 L
.236 .42811 L
.24 .4281 L
.244 .42809 L
.248 .42807 L
.252 .42803 L
.256 .42798 L
.26 .42793 L
.264 .42788 L
.268 .42784 L
.272 .42781 L
.276 .42779 L
.28 .42779 L
.284 .42777 L
.288 .42774 L
.292 .4277 L
.296 .42767 L
.3 .42763 L
.304 .42759 L
.308 .42754 L
.312 .42749 L
.316 .42746 L
.32 .42744 L
.324 .42742 L
.328 .4274 L
.332 .42738 L
.336 .42737 L
.34 .42734 L
.344 .4273 L
.348 .42724 L
.352 .42718 L
.356 .42713 L
.36 .4271 L
.364 .42708 L
.368 .42706 L
.372 .42705 L
.376 .42704 L
.38 .42703 L
.384 .427 L
.388 .42695 L
.392 .42689 L
.396 .42684 L
.4 .4268 L
Mistroke
.404 .42676 L
.408 .42673 L
.412 .42669 L
.416 .42667 L
.42 .42667 L
.424 .42667 L
.428 .42666 L
.432 .42662 L
.436 .42656 L
.44 .4265 L
.444 .42646 L
.448 .42643 L
.452 .42639 L
.456 .42634 L
.46 .4263 L
.464 .42629 L
.468 .4263 L
.472 .4263 L
.476 .42627 L
.48 .42621 L
.484 .42614 L
.488 .42612 L
.492 .42612 L
.496 .42611 L
.5 .42606 L
.504 .42597 L
.508 .42589 L
.512 .42587 L
.516 .42589 L
.52 .4259 L
.524 .42586 L
.528 .42579 L
.532 .42574 L
.536 .42575 L
.54 .4258 L
.544 .42581 L
.548 .42574 L
.552 .4256 L
.556 .42549 L
.56 .42546 L
.564 .42551 L
.568 .42556 L
.572 .42553 L
.576 .42543 L
.58 .42534 L
.584 .42533 L
.588 .42542 L
.592 .42552 L
.596 .42554 L
.6 .42547 L
Mistroke
.604 .42537 L
.608 .42532 L
.612 .42539 L
.616 .42553 L
.62 .42566 L
.624 .42569 L
.628 .42565 L
.632 .42561 L
.636 .42569 L
.64 .42593 L
.644 .42628 L
.648 .42667 L
.652 .42703 L
.656 .42735 L
.66 .42767 L
.664 .42806 L
.668 .42854 L
.672 .42909 L
.676 .42969 L
.68 .43029 L
.684 .43091 L
.688 .43156 L
.692 .43232 L
.696 .43323 L
.7 .43432 L
.704 .43556 L
.708 .43686 L
.712 .4381 L
.716 .43919 L
.72 .4401 L
.724 .44093 L
.728 .4418 L
.732 .44283 L
.736 .44404 L
.74 .44531 L
.744 .44648 L
.748 .44738 L
.752 .44798 L
.756 .44841 L
.76 .44887 L
.764 .44956 L
.768 .45054 L
.772 .45173 L
.776 .45292 L
.78 .45392 L
.784 .45464 L
.788 .45518 L
.792 .45571 L
.796 .45643 L
.8 .45744 L
Mistroke
.804 .4587 L
.808 .46005 L
.812 .46133 L
.816 .46242 L
.82 .46334 L
.824 .46419 L
.828 .46514 L
.832 .46632 L
.836 .46782 L
.84 .46965 L
.844 .47177 L
.848 .47412 L
.852 .47666 L
.856 .47932 L
.86 .48206 L
.864 .48481 L
.868 .4875 L
.872 .49014 L
.876 .49275 L
.88 .49546 L
.884 .49841 L
.888 .50172 L
.892 .5054 L
.896 .50933 L
.9 .51329 L
.904 .51696 L
.908 .52008 L
.912 .52247 L
.916 .52415 L
.92 .5253 L
.924 .52624 L
.928 .52732 L
.932 .52884 L
.936 .53101 L
.94 .53384 L
.944 .53731 L
.948 .54119 L
.952 .54538 L
.956 .54965 L
.96 .55394 L
.964 .55812 L
.968 .56215 L
.972 .5659 L
.976 .56927 L
.98 .57204 L
.984 .5741 L
.988 .57515 L
.992 .57528 L
.996 .57422 L
1 .57226 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo06aoo`008Woo0`0027oo0P0000Aoo`00001oo`800003Ool0000000H00003Ool0000001T0
0003Ool0000000D000]oo`800003Ool007oo01moo`008WooH`0037oo000ROol01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoo`000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`04001oogoo
Ool3000017oo000007oo0P000Woo0`000Woo00D007ooOomoo`0000=oo`04001oogooOol20002Ool0
0`00Oomoo`0:Ool0029oo`8004]oo`04001oogoo000=Ool2000?Ool0029oo`03001oogoo04eoo`<0
00]oo`03001oo`0000ioo`008Woo0P00D7oo0P0017oo00<007ooOol00Woo00@007ooOol000ioo`00
8Woo0P00DGoo00L007ooOomoo`00Ool00002Ool01@00Oomoogoo00003Woo000;Ool20004Ool00`00
Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1AOol01P00Oomoo`00Ool0009oo`05001oogooOol0
000>Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00DWoo00H007oo
Ool007oo0002Ool01@00Oomoogoo00003Woo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`80059oo`08001oogoo001oo`00Ool000Aoo`03001oogoo00aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1BOol00`00Ool00002Ool20005
Ool00`00Oomoo`0;Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
Dgoo0P000goo00<007ooOol017oo00<007ooOol02goo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000Aoo`8005=oo`8000Yoo`03001oogoo00]oo`002goo0P002Woo0P0017oo00<007ooOol0
0Woo00<007ooOol0GWoo00<007ooOol02goo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002
Ool2001OOol00`00Oomoo`0;Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
009oo`80061oo`03001oogoo00Yoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`80
06eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool3
0003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<0
07ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo
000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000R
Ool2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000
Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009
Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<0
07ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo
0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo
0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00
Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0
009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool0
00Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo
00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
0goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomo
o`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool4
0003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000
Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomo
o`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00
Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
00=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03
001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004
Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM
000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03
001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03
001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool20002
Ool50002Ool00`00Oomoo`1IOol00`00Oomoo`0:Ool002Qoo`03001oogoo05Moo`8000eoo`00:7oo
00<007ooOol0Dgoo1@003Woo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomo
o`1BOol2000BOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0D7oo0`004goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo04ioo`<001Eoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001>
Ool2000GOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
Bgoo0P006Goo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo04Qoo`<0
01]oo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0@Woo1P007Woo000XOol00`00
Oomoo`0mOol6000SOol002Qood4002Qoo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo
06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03
001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007
Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]o
o`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo
0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo
0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Io
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001o
ogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`80
00eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool0
1000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<
Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool2
0003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool0
1000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003
Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo
0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo
079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo
00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:
Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Ao
o`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol0
0Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Oom:000[Ool001Moo`03001oogoo009oo`03001o
ogoo04Ioo`@002Qoo`005goo00<007ooOol00Woo00<007ooOol0BWoo100097oo000FOol20004Ool2
001?Ool5000OOol001Moo`03001oogoo009oo`03001oogoo059oo`<001eoo`0077oo00<007ooOol0
EGoo0P006goo000LOol2001HOol00`00Oomoo`0HOol001aoo`03001oogoo05Qoo`8001Qoo`0077oo
0P00FWoo0P005goo000LOol00`00Oomoo`1JOol2000FOol001aoo`03001oogoo05]oo`@001=oo`00
2Woo0`0017oo00<007ooOol00Woo0`000goo0P00Ggoo0P004Woo000;Ool00`00Oomoo`07Ool01@00
Oomoogoo00000Woo00<007ooOol0Ggoo0P004Goo000;Ool00`00Oomoo`0;Ool01000Oomoo`00HWoo
0P0047oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001ROol2000?Ool000]oo`03001oogoo00Mo
o`@000=oo`03001oogoo069oo`@000aoo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo
000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(32231\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30174 m
.008 .29968 L
.012 .29842 L
.016 .29825 L
.02 .2993 L
.024 .29972 L
.028 .29926 L
.032 .29899 L
.036 .29912 L
.04 .29915 L
.044 .29902 L
.048 .29899 L
.052 .2991 L
.056 .29918 L
.06 .29915 L
.064 .29907 L
.068 .299 L
.072 .29896 L
.076 .29897 L
.08 .29899 L
.084 .29902 L
.088 .29901 L
.092 .29899 L
.096 .29895 L
.1 .29894 L
.104 .29895 L
.108 .29893 L
.112 .29887 L
.116 .29882 L
.12 .29884 L
.124 .2989 L
.128 .29894 L
.132 .29893 L
.136 .29886 L
.14 .29877 L
.144 .29868 L
.148 .29867 L
.152 .29878 L
.156 .29894 L
.16 .29896 L
.164 .29881 L
.168 .29861 L
.172 .29852 L
.176 .29857 L
.18 .2987 L
.184 .29884 L
.188 .29892 L
.192 .29885 L
.196 .29862 L
.2 .29836 L
Mistroke
.204 .29831 L
.208 .29852 L
.212 .2988 L
.216 .2989 L
.22 .29879 L
.224 .2986 L
.228 .29844 L
.232 .29831 L
.236 .29826 L
.24 .29839 L
.244 .29868 L
.248 .29889 L
.252 .2988 L
.256 .29846 L
.26 .29818 L
.264 .29814 L
.268 .29826 L
.272 .29841 L
.276 .29855 L
.28 .29872 L
.284 .29877 L
.288 .29853 L
.292 .29806 L
.296 .29776 L
.3 .29793 L
.304 .29844 L
.308 .29883 L
.312 .2988 L
.316 .29847 L
.32 .29814 L
.324 .29795 L
.328 .29786 L
.332 .29789 L
.336 .29816 L
.34 .29862 L
.344 .29893 L
.348 .29874 L
.352 .2981 L
.356 .29748 L
.36 .29738 L
.364 .2978 L
.368 .29837 L
.372 .29869 L
.376 .29867 L
.38 .29847 L
.384 .29821 L
.388 .29786 L
.392 .29747 L
.396 .29727 L
.4 .29755 L
Mistroke
.404 .29827 L
.408 .29895 L
.412 .29904 L
.416 .29839 L
.42 .29748 L
.424 .297 L
.428 .29724 L
.432 .2979 L
.436 .29836 L
.44 .29836 L
.444 .29815 L
.448 .29809 L
.452 .29818 L
.456 .29802 L
.46 .29742 L
.464 .29681 L
.468 .29693 L
.472 .29797 L
.476 .29916 L
.48 .29939 L
.484 .29829 L
.488 .29678 L
.492 .2962 L
.496 .29702 L
.5 .2983 L
.504 .29869 L
.508 .2979 L
.512 .29697 L
.516 .29714 L
.52 .2984 L
.524 .29935 L
.528 .29869 L
.532 .29675 L
.536 .29534 L
.54 .29602 L
.544 .29838 L
.548 .30027 L
.552 .29987 L
.556 .29752 L
.56 .29549 L
.564 .29584 L
.568 .29831 L
.572 .30058 L
.576 .30044 L
.58 .29802 L
.584 .29572 L
.588 .29601 L
.592 .29901 L
.596 .30234 L
.6 .30323 L
Mistroke
.604 .30108 L
.608 .29799 L
.612 .29694 L
.616 .29914 L
.62 .30303 L
.624 .30573 L
.628 .30557 L
.632 .30346 L
.636 .30201 L
.64 .3032 L
.644 .30673 L
.648 .31032 L
.652 .31167 L
.656 .31026 L
.66 .30769 L
.664 .30632 L
.668 .30749 L
.672 .31071 L
.676 .31418 L
.68 .3161 L
.684 .31579 L
.688 .31378 L
.692 .31131 L
.696 .30953 L
.7 .30914 L
.704 .3102 L
.708 .31214 L
.712 .31389 L
.716 .3142 L
.72 .31228 L
.724 .30847 L
.728 .30441 L
.732 .30224 L
.736 .30332 L
.74 .30712 L
.744 .31127 L
.748 .31294 L
.752 .31075 L
.756 .30597 L
.76 .30196 L
.764 .30214 L
.768 .30766 L
.772 .31635 L
.776 .3238 L
.78 .32595 L
.784 .32171 L
.788 .31392 L
.792 .30788 L
.796 .30848 L
.8 .31739 L
Mistroke
.804 .33214 L
.808 .34744 L
.812 .35813 L
.816 .36184 L
.82 .36011 L
.824 .35726 L
.828 .35797 L
.832 .36481 L
.836 .37709 L
.84 .39152 L
.844 .40391 L
.848 .41122 L
.852 .41246 L
.856 .40856 L
.86 .40141 L
.864 .39268 L
.868 .38347 L
.872 .37432 L
.876 .36609 L
.88 .36003 L
.884 .35783 L
.888 .36061 L
.892 .36807 L
.896 .37824 L
.9 .3875 L
.904 .39239 L
.908 .39042 L
.912 .38189 L
.916 .36936 L
.92 .35717 L
.924 .34977 L
.928 .34958 L
.932 .35697 L
.936 .36897 L
.94 .3817 L
.944 .3908 L
.948 .39327 L
.952 .38886 L
.956 .37821 L
.96 .36459 L
.964 .34977 L
.968 .33562 L
.972 .3225 L
.976 .30881 L
.98 .2949 L
.984 .27888 L
.988 .26324 L
.992 .24942 L
.996 .24047 L
1 .24024 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .56903 m
.008 .57226 L
.012 .57329 L
.016 .57194 L
.02 .57171 L
.024 .57219 L
.028 .57229 L
.032 .57207 L
.036 .57208 L
.04 .57212 L
.044 .57214 L
.048 .5721 L
.052 .57212 L
.056 .57212 L
.06 .57214 L
.064 .57212 L
.068 .57213 L
.072 .57211 L
.076 .57212 L
.08 .57211 L
.084 .57212 L
.088 .57212 L
.092 .57213 L
.096 .57212 L
.1 .57212 L
.104 .57211 L
.108 .57212 L
.112 .57212 L
.116 .57212 L
.12 .57212 L
.124 .57212 L
.128 .57211 L
.132 .57211 L
.136 .57211 L
.14 .57212 L
.144 .57212 L
.148 .57213 L
.152 .57212 L
.156 .57212 L
.16 .57212 L
.164 .57211 L
.168 .57211 L
.172 .57211 L
.176 .57211 L
.18 .57212 L
.184 .57212 L
.188 .57213 L
.192 .57213 L
.196 .57212 L
.2 .57212 L
Mistroke
.204 .57211 L
.208 .57211 L
.212 .57211 L
.216 .57211 L
.22 .57211 L
.224 .57212 L
.228 .57212 L
.232 .57213 L
.236 .57213 L
.24 .57213 L
.244 .57212 L
.248 .5721 L
.252 .57209 L
.256 .57209 L
.26 .5721 L
.264 .57212 L
.268 .57213 L
.272 .57214 L
.276 .57214 L
.28 .57213 L
.284 .57211 L
.288 .57209 L
.292 .57209 L
.296 .57209 L
.3 .5721 L
.304 .57211 L
.308 .57212 L
.312 .57213 L
.316 .57213 L
.32 .57213 L
.324 .57212 L
.328 .57211 L
.332 .5721 L
.336 .57209 L
.34 .57209 L
.344 .57209 L
.348 .57209 L
.352 .5721 L
.356 .57212 L
.36 .57214 L
.364 .57215 L
.368 .57214 L
.372 .57211 L
.376 .57209 L
.38 .57208 L
.384 .57208 L
.388 .57208 L
.392 .57208 L
.396 .5721 L
.4 .57212 L
Mistroke
.404 .57214 L
.408 .57215 L
.412 .57213 L
.416 .57211 L
.42 .5721 L
.424 .57209 L
.428 .57208 L
.432 .57207 L
.436 .57206 L
.44 .57207 L
.444 .5721 L
.448 .57213 L
.452 .57215 L
.456 .57214 L
.46 .57212 L
.464 .57211 L
.468 .5721 L
.472 .5721 L
.476 .57208 L
.48 .57206 L
.484 .57205 L
.488 .57208 L
.492 .57212 L
.496 .57214 L
.5 .57212 L
.504 .57209 L
.508 .57208 L
.512 .5721 L
.516 .57213 L
.52 .57214 L
.524 .5721 L
.528 .57205 L
.532 .57203 L
.536 .57205 L
.54 .57209 L
.544 .57209 L
.548 .57206 L
.552 .57201 L
.556 .57201 L
.56 .57205 L
.564 .5721 L
.568 .5721 L
.572 .57203 L
.576 .57191 L
.58 .57183 L
.584 .57181 L
.588 .57182 L
.592 .57179 L
.596 .57168 L
.6 .57152 L
Mistroke
.604 .57136 L
.608 .57126 L
.612 .5712 L
.616 .5711 L
.62 .57089 L
.624 .57058 L
.628 .57022 L
.632 .56988 L
.636 .56957 L
.64 .56926 L
.644 .56885 L
.648 .56831 L
.652 .56765 L
.656 .56694 L
.66 .56625 L
.664 .5656 L
.668 .56496 L
.672 .56428 L
.676 .56351 L
.68 .56267 L
.684 .56177 L
.688 .56086 L
.692 .55996 L
.696 .55906 L
.7 .55816 L
.704 .55723 L
.708 .55626 L
.712 .5553 L
.716 .55439 L
.72 .55359 L
.724 .55294 L
.728 .55243 L
.732 .55198 L
.736 .5515 L
.74 .55089 L
.744 .55013 L
.748 .5493 L
.752 .54849 L
.756 .5478 L
.76 .54727 L
.764 .5468 L
.768 .54624 L
.772 .54547 L
.776 .54444 L
.78 .54325 L
.784 .54206 L
.788 .54102 L
.792 .54019 L
.796 .53948 L
.8 .53875 L
Mistroke
.804 .53782 L
.808 .53659 L
.812 .53509 L
.816 .53344 L
.82 .53175 L
.824 .5301 L
.828 .52845 L
.832 .52668 L
.836 .52467 L
.84 .52233 L
.844 .51966 L
.848 .51677 L
.852 .51379 L
.856 .51087 L
.86 .50811 L
.864 .50557 L
.868 .50327 L
.872 .50119 L
.876 .49928 L
.88 .4975 L
.884 .49575 L
.888 .49393 L
.892 .49193 L
.896 .48968 L
.9 .48718 L
.904 .48454 L
.908 .48188 L
.912 .4794 L
.916 .4772 L
.92 .47534 L
.924 .47373 L
.928 .47223 L
.932 .47062 L
.936 .46876 L
.94 .46657 L
.944 .46408 L
.948 .4614 L
.952 .45871 L
.956 .45617 L
.96 .45396 L
.964 .4521 L
.968 .45073 L
.972 .44976 L
.976 .44931 L
.98 .44929 L
.984 .44982 L
.988 .45082 L
.992 .45224 L
.996 .45395 L
1 .45573 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43507 L
.012 .42999 L
.016 .42822 L
.02 .42973 L
.024 .43038 L
.028 .42981 L
.032 .42958 L
.036 .42968 L
.04 .42976 L
.044 .42965 L
.048 .42961 L
.052 .42957 L
.056 .42957 L
.06 .42951 L
.064 .4295 L
.068 .42945 L
.072 .42944 L
.076 .4294 L
.08 .42937 L
.084 .42932 L
.088 .4293 L
.092 .42926 L
.096 .42924 L
.1 .4292 L
.104 .42918 L
.108 .42915 L
.112 .42912 L
.116 .42908 L
.12 .42905 L
.124 .42901 L
.128 .42898 L
.132 .42894 L
.136 .42891 L
.14 .42888 L
.144 .42886 L
.148 .42884 L
.152 .42881 L
.156 .42877 L
.16 .42873 L
.164 .42868 L
.168 .42865 L
.172 .42862 L
.176 .4286 L
.18 .42858 L
.184 .42856 L
.188 .42852 L
.192 .42849 L
.196 .42844 L
.2 .42841 L
Mistroke
.204 .42837 L
.208 .42834 L
.212 .42831 L
.216 .42828 L
.22 .42825 L
.224 .42823 L
.228 .4282 L
.232 .42817 L
.236 .42814 L
.24 .42811 L
.244 .42807 L
.248 .42802 L
.252 .42798 L
.256 .42794 L
.26 .42792 L
.264 .4279 L
.268 .42789 L
.272 .42787 L
.276 .42784 L
.28 .42781 L
.284 .42775 L
.288 .4277 L
.292 .42765 L
.296 .42762 L
.3 .4276 L
.304 .42759 L
.308 .42757 L
.312 .42755 L
.316 .42752 L
.32 .42749 L
.324 .42745 L
.328 .4274 L
.332 .42735 L
.336 .42731 L
.34 .42728 L
.344 .42725 L
.348 .42722 L
.352 .4272 L
.356 .42719 L
.36 .42718 L
.364 .42715 L
.368 .42711 L
.372 .42706 L
.376 .427 L
.38 .42696 L
.384 .42692 L
.388 .42688 L
.392 .42686 L
.396 .42685 L
.4 .42685 L
Mistroke
.404 .42684 L
.408 .42682 L
.412 .42677 L
.416 .42671 L
.42 .42667 L
.424 .42662 L
.428 .42658 L
.432 .42653 L
.436 .42649 L
.44 .42647 L
.444 .42648 L
.448 .42649 L
.452 .42647 L
.456 .42643 L
.46 .42637 L
.464 .42633 L
.468 .42629 L
.472 .42626 L
.476 .4262 L
.48 .42614 L
.484 .4261 L
.488 .4261 L
.492 .42612 L
.496 .42611 L
.5 .42607 L
.504 .426 L
.508 .42596 L
.512 .42595 L
.516 .42596 L
.52 .42594 L
.524 .42586 L
.528 .42577 L
.532 .42572 L
.536 .42573 L
.54 .42575 L
.544 .42574 L
.548 .42568 L
.552 .42561 L
.556 .4256 L
.56 .42565 L
.564 .42572 L
.568 .42574 L
.572 .42567 L
.576 .42557 L
.58 .42553 L
.584 .42558 L
.588 .42569 L
.592 .42579 L
.596 .42582 L
.6 .42582 L
Mistroke
.604 .42587 L
.608 .42605 L
.612 .42632 L
.616 .42661 L
.62 .42685 L
.624 .42703 L
.628 .42724 L
.632 .42757 L
.636 .42805 L
.64 .42863 L
.644 .42921 L
.648 .42975 L
.652 .43026 L
.656 .43083 L
.66 .43155 L
.664 .43245 L
.668 .43346 L
.672 .43454 L
.676 .4356 L
.68 .43664 L
.684 .43767 L
.688 .43874 L
.692 .43985 L
.696 .44096 L
.7 .44205 L
.704 .44307 L
.708 .44399 L
.712 .44484 L
.716 .44568 L
.72 .44658 L
.724 .44757 L
.728 .44864 L
.732 .44973 L
.736 .4507 L
.74 .45148 L
.744 .45205 L
.748 .45252 L
.752 .45304 L
.756 .45376 L
.76 .45473 L
.764 .45586 L
.768 .45698 L
.772 .45793 L
.776 .45867 L
.78 .45931 L
.784 .46005 L
.788 .46108 L
.792 .46247 L
.796 .46415 L
.8 .46591 L
Mistroke
.804 .46756 L
.808 .46904 L
.812 .47039 L
.816 .47181 L
.82 .47351 L
.824 .4756 L
.828 .47808 L
.832 .48083 L
.836 .4837 L
.84 .48655 L
.844 .48936 L
.848 .49217 L
.852 .49507 L
.856 .49812 L
.86 .50133 L
.864 .50467 L
.868 .50805 L
.872 .51137 L
.876 .51457 L
.88 .51759 L
.884 .52036 L
.888 .52285 L
.892 .52505 L
.896 .52701 L
.9 .52885 L
.904 .53078 L
.908 .533 L
.912 .53575 L
.916 .53907 L
.92 .5429 L
.924 .54698 L
.928 .55099 L
.932 .55451 L
.936 .55731 L
.94 .55924 L
.944 .56039 L
.948 .56101 L
.952 .56145 L
.956 .562 L
.96 .56296 L
.964 .56435 L
.968 .56628 L
.972 .56846 L
.976 .57089 L
.98 .57328 L
.984 .57559 L
.988 .5777 L
.992 .57955 L
.996 .5811 L
1 .58223 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`<0009o
o`04001oogoo0005Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0
2goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04
001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Ao
o`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0003Ool01P00Oomoogoo001oo`8000Eoo`04001oogoo0005
Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo
05eoo`03001oogoo00aoo`008Woo0`002goo0P0000=oo`0000000P0000=oo`000000800000=oo`00
Ool00P008goo00<007ooOol037oo000ROomS000<Ool0029oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`04001oogoo0003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo0`0000=oo`0000000`000Woo
0`0000=oo`0000000goo00D007ooOomoo`0000=oo`04001oogooOol20002Ool00`00Oomoo`0:Ool0
029oo`8004Yoo`<0011oo`03001oogoo00eoo`008Woo00<007ooOol0Bgoo00<007ooOol03Goo00<0
07ooOol03Woo000ROol2001=Ool00`00Oomoo`08Ool20002Ool00`00Oomoo`0>Ool0029oo`8004eo
o`<000Aoo`04001oogooOol20002Ool00`00Oomoo`0>Ool000]oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`03001oogoo04eoo`8000=oo`07001oo`00Ool007oo00000Woo00<007ooOol03Woo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80051oo`0<001oogoo001o
o`00Ool007oo001oo`004Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`80051oo`04001oogoo0002Ool20002Ool2000AOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0Cgoo00<007oo00000goo00D007ooOomoo`00019oo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001@Ool3000JOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo0P0017oo0P00DGoo00<007ooOol06Goo000;Ool2000:Ool20004
Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009o
o`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0
00=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0
K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008
Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo
0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eo
o`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`80
06eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo0000
0goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool0
0`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=o
o`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04
Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007oo
Ool0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003
Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003
Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool2
0002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool0
1000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05
001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0
009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo
Ool01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Ao
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009o
o`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo
0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool0
00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04
001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool0
1000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol0
00Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@0
07ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<0
07ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`00
0goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`00
0goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003
Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006
Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo05Eoo`@000eo
o`00:7oo00<007ooOol0Dgoo0`000goo00<007ooOol02Woo000XOol00`00Oomoo`1AOol3000BOol0
015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo04moo`<001Aoo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1=Ool3000FOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0C7oo0P0067oo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8004]oo`8001Yoo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`18Ool3000KOol0011oo`04001o
ogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0AGoo10007Goo000AOol2000:Ool20004
Ool00`00Oomoo`02Ool00`00Oomoo`0oOol6000QOol002Qoo`03001oogoo03]oo`D002Ioo`00:7oo
?P00:goo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo0000
0goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool0
0`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<0
07ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004
Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool0
0`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool0
1000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007oo
Ool0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool3
0004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05
001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001o
ogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol0
00Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomo
ogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001o
ogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomo
ogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=o
o`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool5
0003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001ao
o`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00
Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo
10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool2
0008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Mo
o`03001oogoo009oodH002moo`005goo00<007ooOol00Woo0P00A7oo1000:goo000GOol00`00Oomo
o`02Ool00`00Oomoo`17Ool5000VOol001Ioo`8000Aoo`8004aoo`D0029oo`005goo00<007ooOol0
0Woo00<007ooOol0Cgoo10007goo000LOol00`00Oomoo`1BOol2000NOol001aoo`8005Eoo`8001ao
o`0077oo00<007ooOol0EGoo0P006goo000LOol2001HOol00`00Oomoo`0HOol001aoo`03001oogoo
05Qoo`8001Qoo`0077oo00<007ooOol0FGoo0`005Woo000:Ool30004Ool00`00Oomoo`02Ool30003
Ool2001LOol2000EOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1LOol2
000DOol000]oo`03001oogoo00]oo`04001oogoo001OOol2000COol000]oo`03001oogoo00]oo`03
001oogoo0080061oo`@000moo`002goo00<007ooOol01goo10000goo00<007ooOol0HWoo0P003Woo
000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1TOol2000<Ool000]oo`03001oogoo00Moo`D0
009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(32398\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29837 m
.008 .29836 L
.012 .29972 L
.016 .29979 L
.02 .29881 L
.024 .29877 L
.028 .2994 L
.032 .2995 L
.036 .29919 L
.04 .29907 L
.044 .29909 L
.048 .29906 L
.052 .29907 L
.056 .29916 L
.06 .29922 L
.064 .29916 L
.068 .29904 L
.072 .29896 L
.076 .29896 L
.08 .29902 L
.084 .2991 L
.088 .29913 L
.092 .29908 L
.096 .29896 L
.1 .29888 L
.104 .29887 L
.108 .29894 L
.112 .299 L
.116 .299 L
.12 .29898 L
.124 .29892 L
.128 .29886 L
.132 .29882 L
.136 .29884 L
.14 .29888 L
.144 .29888 L
.148 .29884 L
.152 .29882 L
.156 .29883 L
.16 .29883 L
.164 .29877 L
.168 .29872 L
.172 .29873 L
.176 .29879 L
.18 .29881 L
.184 .29877 L
.188 .29871 L
.192 .29866 L
.196 .29861 L
.2 .29858 L
Mistroke
.204 .29864 L
.208 .29879 L
.212 .29888 L
.216 .29876 L
.22 .29849 L
.224 .29832 L
.228 .29838 L
.232 .29858 L
.236 .29875 L
.24 .29882 L
.244 .29878 L
.248 .29862 L
.252 .29834 L
.256 .2981 L
.26 .29815 L
.264 .29851 L
.268 .29887 L
.272 .29892 L
.276 .29865 L
.28 .29832 L
.284 .29814 L
.288 .29809 L
.292 .29814 L
.296 .29832 L
.3 .29865 L
.304 .29892 L
.308 .29881 L
.312 .29831 L
.316 .29781 L
.32 .29772 L
.324 .29806 L
.328 .2985 L
.332 .29873 L
.336 .2987 L
.34 .29853 L
.344 .29825 L
.348 .29789 L
.352 .29761 L
.356 .29769 L
.36 .29822 L
.364 .29885 L
.368 .29905 L
.372 .29862 L
.376 .29787 L
.38 .29737 L
.384 .29741 L
.388 .29783 L
.392 .29828 L
.396 .29855 L
.4 .29867 L
Mistroke
.404 .29862 L
.408 .29834 L
.412 .2978 L
.416 .29722 L
.42 .29705 L
.424 .29754 L
.428 .29844 L
.432 .29907 L
.436 .29893 L
.44 .29814 L
.444 .29734 L
.448 .29713 L
.452 .29751 L
.456 .29798 L
.46 .29811 L
.464 .29799 L
.468 .29803 L
.472 .29834 L
.476 .29849 L
.48 .298 L
.484 .29704 L
.488 .29648 L
.492 .29705 L
.496 .29845 L
.5 .29947 L
.504 .29913 L
.508 .29772 L
.512 .29657 L
.516 .29675 L
.52 .29793 L
.524 .29876 L
.528 .29834 L
.532 .29724 L
.536 .29692 L
.54 .29811 L
.544 .29985 L
.548 .30037 L
.552 .29895 L
.556 .29687 L
.56 .29627 L
.564 .29807 L
.568 .3009 L
.572 .30237 L
.576 .30135 L
.58 .29918 L
.584 .29837 L
.588 .30023 L
.592 .3035 L
.596 .30556 L
.6 .30491 L
Mistroke
.604 .30269 L
.608 .30166 L
.612 .30364 L
.616 .30775 L
.62 .31118 L
.624 .31165 L
.628 .30947 L
.632 .30721 L
.636 .30742 L
.64 .31042 L
.644 .31412 L
.648 .31587 L
.652 .31473 L
.656 .31217 L
.66 .31072 L
.664 .31179 L
.668 .31456 L
.672 .31671 L
.676 .31635 L
.68 .31342 L
.684 .30962 L
.688 .30708 L
.692 .3069 L
.696 .3086 L
.7 .31069 L
.704 .31175 L
.708 .31115 L
.712 .30919 L
.716 .30678 L
.72 .305 L
.724 .30476 L
.728 .30647 L
.732 .30974 L
.736 .31332 L
.74 .3156 L
.744 .31546 L
.748 .31324 L
.752 .31082 L
.756 .3107 L
.76 .31443 L
.764 .32138 L
.768 .32895 L
.772 .33408 L
.776 .33539 L
.78 .33439 L
.784 .33476 L
.788 .34019 L
.792 .35184 L
.796 .36732 L
.8 .38176 L
Mistroke
.804 .39054 L
.808 .39198 L
.812 .38833 L
.816 .38449 L
.82 .3851 L
.824 .3918 L
.828 .40222 L
.832 .4112 L
.836 .41366 L
.84 .40724 L
.844 .39356 L
.848 .37726 L
.852 .36379 L
.856 .35685 L
.86 .35718 L
.864 .36282 L
.868 .37051 L
.872 .3775 L
.876 .38228 L
.88 .38488 L
.884 .38568 L
.888 .38503 L
.892 .38268 L
.896 .37827 L
.9 .37219 L
.904 .36556 L
.908 .36067 L
.912 .35922 L
.916 .36202 L
.92 .36778 L
.924 .37333 L
.928 .37529 L
.932 .37037 L
.936 .35833 L
.94 .34076 L
.944 .3217 L
.948 .30599 L
.952 .29649 L
.956 .29533 L
.96 .30015 L
.964 .30842 L
.968 .31583 L
.972 .31894 L
.976 .31705 L
.98 .30955 L
.984 .29939 L
.988 .28846 L
.992 .27872 L
.996 .27204 L
1 .26738 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .5643 m
.008 .57162 L
.012 .57416 L
.016 .57175 L
.02 .57091 L
.024 .57164 L
.028 .57198 L
.032 .57171 L
.036 .57162 L
.04 .57168 L
.044 .57174 L
.048 .57169 L
.052 .5717 L
.056 .57169 L
.06 .57171 L
.064 .57169 L
.068 .57171 L
.072 .57169 L
.076 .5717 L
.08 .57169 L
.084 .5717 L
.088 .57169 L
.092 .5717 L
.096 .5717 L
.1 .5717 L
.104 .57169 L
.108 .5717 L
.112 .57169 L
.116 .5717 L
.12 .57169 L
.124 .5717 L
.128 .57169 L
.132 .5717 L
.136 .5717 L
.14 .57171 L
.144 .5717 L
.148 .5717 L
.152 .57169 L
.156 .57169 L
.16 .57168 L
.164 .57169 L
.168 .5717 L
.172 .57171 L
.176 .57171 L
.18 .57171 L
.184 .57169 L
.188 .57169 L
.192 .57168 L
.196 .57168 L
.2 .57169 L
Mistroke
.204 .5717 L
.208 .5717 L
.212 .57171 L
.216 .5717 L
.22 .5717 L
.224 .57169 L
.228 .57169 L
.232 .57168 L
.236 .57168 L
.24 .57169 L
.244 .57169 L
.248 .57169 L
.252 .5717 L
.256 .5717 L
.26 .57171 L
.264 .57171 L
.268 .5717 L
.272 .57169 L
.276 .57168 L
.28 .57167 L
.284 .57167 L
.288 .57168 L
.292 .5717 L
.296 .57171 L
.3 .57172 L
.304 .57171 L
.308 .5717 L
.312 .57168 L
.316 .57167 L
.32 .57167 L
.324 .57167 L
.328 .57168 L
.332 .57169 L
.336 .5717 L
.34 .57171 L
.344 .57172 L
.348 .5717 L
.352 .57169 L
.356 .57168 L
.36 .57167 L
.364 .57167 L
.368 .57166 L
.372 .57167 L
.376 .57168 L
.38 .5717 L
.384 .57171 L
.388 .57172 L
.392 .57171 L
.396 .5717 L
.4 .57168 L
Mistroke
.404 .57167 L
.408 .57166 L
.412 .57165 L
.416 .57165 L
.42 .57167 L
.424 .5717 L
.428 .57171 L
.432 .57172 L
.436 .57171 L
.44 .5717 L
.444 .57169 L
.448 .57168 L
.452 .57166 L
.456 .57164 L
.46 .57163 L
.464 .57165 L
.468 .57168 L
.472 .57171 L
.476 .57171 L
.48 .5717 L
.484 .57169 L
.488 .5717 L
.492 .57169 L
.496 .57168 L
.5 .57164 L
.504 .57162 L
.508 .57162 L
.512 .57165 L
.516 .57168 L
.52 .57168 L
.524 .57165 L
.528 .57162 L
.532 .57161 L
.536 .57163 L
.54 .57164 L
.544 .5716 L
.548 .57153 L
.552 .57146 L
.556 .57141 L
.56 .5714 L
.564 .57136 L
.568 .57127 L
.572 .57114 L
.576 .57101 L
.58 .57091 L
.584 .57083 L
.588 .57072 L
.592 .57052 L
.596 .57022 L
.6 .56988 L
Mistroke
.604 .56955 L
.608 .56925 L
.612 .56891 L
.616 .56849 L
.62 .56796 L
.624 .56735 L
.628 .56675 L
.632 .56617 L
.636 .56558 L
.64 .56492 L
.644 .56413 L
.648 .56325 L
.652 .56234 L
.656 .56146 L
.66 .56064 L
.664 .55982 L
.668 .55895 L
.672 .558 L
.676 .557 L
.68 .55602 L
.684 .55514 L
.688 .55435 L
.692 .55366 L
.696 .553 L
.7 .55234 L
.704 .55167 L
.708 .55101 L
.712 .55038 L
.716 .54978 L
.72 .54919 L
.724 .54858 L
.728 .5479 L
.732 .54714 L
.736 .54631 L
.74 .54545 L
.744 .54463 L
.748 .54389 L
.752 .54322 L
.756 .54257 L
.76 .54182 L
.764 .54088 L
.768 .53973 L
.772 .53844 L
.776 .53712 L
.78 .53588 L
.784 .53473 L
.788 .53358 L
.792 .53228 L
.796 .53068 L
.8 .52871 L
Mistroke
.804 .52645 L
.808 .52404 L
.812 .52164 L
.816 .51934 L
.82 .5171 L
.824 .51481 L
.828 .51235 L
.832 .50968 L
.836 .50688 L
.84 .5041 L
.844 .50151 L
.848 .49922 L
.852 .49722 L
.856 .4954 L
.86 .49363 L
.864 .49175 L
.868 .48971 L
.872 .48748 L
.876 .48512 L
.88 .4827 L
.884 .48027 L
.888 .47788 L
.892 .47556 L
.896 .47336 L
.9 .47128 L
.904 .46936 L
.908 .46754 L
.912 .46579 L
.916 .464 L
.92 .46211 L
.924 .46011 L
.928 .45806 L
.932 .45607 L
.936 .45435 L
.94 .45298 L
.944 .45211 L
.948 .45162 L
.952 .45147 L
.956 .45142 L
.96 .45134 L
.964 .45109 L
.968 .45065 L
.972 .45008 L
.976 .44949 L
.98 .44901 L
.984 .44878 L
.988 .44881 L
.992 .44917 L
.996 .44978 L
1 .45063 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42809 L
.012 .43012 L
.016 .43061 L
.02 .42966 L
.024 .42957 L
.028 .42984 L
.032 .42986 L
.036 .42965 L
.04 .42965 L
.044 .42965 L
.048 .42965 L
.052 .42958 L
.056 .42957 L
.06 .42952 L
.064 .4295 L
.068 .42944 L
.072 .42943 L
.076 .42939 L
.08 .42937 L
.084 .42933 L
.088 .42931 L
.092 .42927 L
.096 .42924 L
.1 .4292 L
.104 .42918 L
.108 .42914 L
.112 .42911 L
.116 .42907 L
.12 .42905 L
.124 .42901 L
.128 .42899 L
.132 .42896 L
.136 .42893 L
.14 .42889 L
.144 .42886 L
.148 .42882 L
.152 .42879 L
.156 .42876 L
.16 .42873 L
.164 .4287 L
.168 .42867 L
.172 .42864 L
.176 .42861 L
.18 .42858 L
.184 .42854 L
.188 .4285 L
.192 .42847 L
.196 .42843 L
.2 .42841 L
Mistroke
.204 .42838 L
.208 .42836 L
.212 .42833 L
.216 .4283 L
.22 .42826 L
.224 .42823 L
.228 .42819 L
.232 .42816 L
.236 .42812 L
.24 .42808 L
.244 .42805 L
.248 .42803 L
.252 .42801 L
.256 .42799 L
.26 .42796 L
.264 .42793 L
.268 .42788 L
.272 .42783 L
.276 .42778 L
.28 .42775 L
.284 .42773 L
.288 .42771 L
.292 .4277 L
.296 .42768 L
.3 .42766 L
.304 .42762 L
.308 .42756 L
.312 .42751 L
.316 .42746 L
.32 .42743 L
.324 .42741 L
.328 .42739 L
.332 .42737 L
.336 .42735 L
.34 .42733 L
.344 .4273 L
.348 .42726 L
.352 .42721 L
.356 .42717 L
.36 .42713 L
.364 .42709 L
.368 .42705 L
.372 .42702 L
.376 .42701 L
.38 .427 L
.384 .42699 L
.388 .42697 L
.392 .42692 L
.396 .42688 L
.4 .42683 L
Mistroke
.404 .42678 L
.408 .42673 L
.412 .42669 L
.416 .42666 L
.42 .42666 L
.424 .42666 L
.428 .42665 L
.432 .42662 L
.436 .42658 L
.44 .42653 L
.444 .4265 L
.448 .42645 L
.452 .42639 L
.456 .42634 L
.46 .42629 L
.464 .42628 L
.468 .42629 L
.472 .42629 L
.476 .42627 L
.48 .42623 L
.484 .42619 L
.488 .42616 L
.492 .42613 L
.496 .42608 L
.5 .42601 L
.504 .42595 L
.508 .42593 L
.512 .42595 L
.516 .42596 L
.52 .42595 L
.524 .42589 L
.528 .42585 L
.532 .42584 L
.536 .42587 L
.54 .4259 L
.544 .42588 L
.548 .42582 L
.552 .42578 L
.556 .42581 L
.56 .42588 L
.564 .42596 L
.568 .42601 L
.572 .42603 L
.576 .4261 L
.58 .42626 L
.584 .4265 L
.588 .42676 L
.592 .42698 L
.596 .42716 L
.6 .42737 L
Mistroke
.604 .42769 L
.608 .42814 L
.612 .42866 L
.616 .42918 L
.62 .42969 L
.624 .43023 L
.628 .4309 L
.632 .43172 L
.636 .43265 L
.64 .4336 L
.644 .43452 L
.648 .4354 L
.652 .43634 L
.656 .43738 L
.66 .43854 L
.664 .43974 L
.668 .44088 L
.672 .44191 L
.676 .44286 L
.68 .44378 L
.684 .44476 L
.688 .44578 L
.692 .44683 L
.696 .44784 L
.7 .44876 L
.704 .44959 L
.708 .45037 L
.712 .45112 L
.716 .45189 L
.72 .45266 L
.724 .45342 L
.728 .45414 L
.732 .45481 L
.736 .45546 L
.74 .45617 L
.744 .45702 L
.748 .45807 L
.752 .45933 L
.756 .46071 L
.76 .46207 L
.764 .46331 L
.768 .46441 L
.772 .46544 L
.776 .46658 L
.78 .46799 L
.784 .46972 L
.788 .4717 L
.792 .47377 L
.796 .47581 L
.8 .47776 L
Mistroke
.804 .47975 L
.808 .48197 L
.812 .48462 L
.816 .48775 L
.82 .49127 L
.824 .49495 L
.828 .49855 L
.832 .50189 L
.836 .50496 L
.84 .50785 L
.844 .51067 L
.848 .51353 L
.852 .5164 L
.856 .5192 L
.86 .52182 L
.864 .52419 L
.868 .52635 L
.872 .52843 L
.876 .53058 L
.88 .53294 L
.884 .5356 L
.888 .53857 L
.892 .54177 L
.896 .54514 L
.9 .54852 L
.904 .5518 L
.908 .55484 L
.912 .5575 L
.916 .55969 L
.92 .56139 L
.924 .5627 L
.928 .56382 L
.932 .56497 L
.936 .56645 L
.94 .56833 L
.944 .57067 L
.948 .57319 L
.952 .57562 L
.956 .57751 L
.96 .57859 L
.964 .57867 L
.968 .57777 L
.972 .57613 L
.976 .57405 L
.98 .57191 L
.984 .57004 L
.988 .56859 L
.992 .56773 L
.996 .56739 L
1 .56761 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`00009oo`05001o
ogooOol00002Ool00`00Oomoo`03Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`80
00Aoo`8000Ioo`04001oogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003
Ool20006Ool0029oo`03001oogoo05eoo`8000eoo`008Woo0P003goo3@0000=oo`000000400000=o
o`000000100000=oo`00Ool08Woo00@007ooOol000ioo`008WooH`0037oo000ROol01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoo`000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00H007ooOomoo`00Ool>0003Ool0
1@00Oomoogoo00000goo00P007ooOomoo`00Ool007oo0`0000=oo`00Ool02goo000ROol20019Ool0
0`00Oomoo`0>Ool00`00Oomoo`0@Ool0029oo`03001oogoo04Qoo`<000ioo`03001oogoo011oo`00
8Woo0P00Bgoo00<007ooOol037oo00<007ooOol047oo000ROol2001;Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Ool0000COol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001o
ogoo04]oo`03001oogoo009oo`<0009oo`@001=oo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2001<Ool00`00Oomoo`02Ool01000Ool007oo0P0000=oo`0000004goo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8004aoo`<0009oo`03001oo`00
008001Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1<
Ool200000goo001oo`0KOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00Cgoo0P0077oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`80051oo`03001o
ogoo01Yoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool0
0`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000
Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003
Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo
0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yo
o`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007oo
Ool00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;
Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2
001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomo
ogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool5
0002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007oo
Ool00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P00
17oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P00
1Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomo
o`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Io
o`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@0
07ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo
000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003
Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomo
ogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04
Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomo
o`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=o
o`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001o
ogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool3
0002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<
Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001o
ogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001o
ogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool20002Ool5
0002Ool00`00Oomoo`1COol7000<Ool002Qoo`03001oogoo055oo`8001=oo`00:7oo00<007ooOol0
Cgoo0P005Goo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1=Ool2000G
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0Bgoo0P00
6Goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo04Uoo`80
01]oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20019Ool2000LOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0AWoo0P007Woo
000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo049oo`D001moo`004Goo
0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0?7oo1`008goo000XOol00`00Oomoo`0hOol5
000YOol002Qooc`002eoo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003
Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D0
07ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo
1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo
0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
2goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo0080
07=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0
009oo`03001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P00
1Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000L
Ool2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001o
ogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=o
o`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo
Ool40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
17oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomo
o`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00
Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
17oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool0
0`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P00
1Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo
J@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomo
o`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@0
07ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80
07=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007oo
Ool0LWoo000GOol00`00Oomoo`02Oom3000bOol001Moo`03001oogoo009oo`03001oogoo041oo`@0
02ioo`005goo00<007ooOol00Woo00<007ooOol0A7oo1@00:Goo000FOol20004Ool20019Ool5000U
Ool001Moo`03001oogoo009oo`03001oogoo04eoo`<0029oo`0077oo00<007ooOol0Cgoo0`0087oo
000LOol2001BOol2000OOol001aoo`03001oogoo059oo`8001ioo`0077oo0P00EGoo00<007ooOol0
6goo000LOol00`00Oomoo`1EOol2000KOol001aoo`03001oogoo05Ioo`<001Uoo`002Woo0`0017oo
00<007ooOol00Woo0`000goo0P00FGoo0P0067oo000;Ool00`00Oomoo`07Ool01@00Oomoogoo0000
0Woo00<007ooOol0FGoo0P005goo000;Ool00`00Oomoo`0;Ool01000Oomoo`00GGoo0P005Goo000;
Ool00`00Oomoo`0;Ool00`00Oomoo`02001MOol30004Ool3000<Ool000]oo`03001oogoo00Moo`@0
00=oo`03001oogoo05moo`D000ioo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;
Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(32565\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .2967 m
.008 .29871 L
.012 .30012 L
.016 .30022 L
.02 .29899 L
.024 .29862 L
.028 .29926 L
.032 .29955 L
.036 .29928 L
.04 .29909 L
.044 .29914 L
.048 .29915 L
.052 .29912 L
.056 .29915 L
.06 .2992 L
.064 .29919 L
.068 .29912 L
.072 .29904 L
.076 .29903 L
.08 .29906 L
.084 .29911 L
.088 .29912 L
.092 .29908 L
.096 .29899 L
.1 .29892 L
.104 .29894 L
.108 .29903 L
.112 .29909 L
.116 .29907 L
.12 .29898 L
.124 .29888 L
.128 .2988 L
.132 .29881 L
.136 .29891 L
.14 .29903 L
.144 .29906 L
.148 .29896 L
.152 .2988 L
.156 .29871 L
.16 .29871 L
.164 .29878 L
.168 .29885 L
.172 .29892 L
.176 .29894 L
.18 .29885 L
.184 .2987 L
.188 .29861 L
.192 .29864 L
.196 .29872 L
.2 .29878 L
Mistroke
.204 .29879 L
.208 .2988 L
.212 .29877 L
.216 .29864 L
.22 .29849 L
.224 .29846 L
.228 .29861 L
.232 .29879 L
.236 .29883 L
.24 .29871 L
.244 .29855 L
.248 .29844 L
.252 .29838 L
.256 .29839 L
.26 .29854 L
.264 .29877 L
.268 .29888 L
.272 .29868 L
.276 .29829 L
.28 .29806 L
.284 .29818 L
.288 .29848 L
.292 .2987 L
.296 .29873 L
.3 .29865 L
.304 .2985 L
.308 .29827 L
.312 .298 L
.316 .29794 L
.32 .29823 L
.324 .29868 L
.328 .2989 L
.332 .29868 L
.336 .29823 L
.34 .29792 L
.344 .29791 L
.348 .29808 L
.352 .29826 L
.356 .29844 L
.36 .29863 L
.364 .29866 L
.368 .29837 L
.372 .29785 L
.376 .29749 L
.38 .29765 L
.384 .29826 L
.388 .29882 L
.392 .29889 L
.396 .29846 L
.4 .2979 L
Mistroke
.404 .29757 L
.408 .29756 L
.412 .29772 L
.416 .29797 L
.42 .2983 L
.424 .29867 L
.428 .29884 L
.432 .29854 L
.436 .29779 L
.44 .29706 L
.444 .29692 L
.448 .29755 L
.452 .29847 L
.456 .29898 L
.46 .29872 L
.464 .29802 L
.468 .29753 L
.472 .29753 L
.476 .29777 L
.48 .29782 L
.484 .29768 L
.488 .29778 L
.492 .29836 L
.496 .29901 L
.5 .29898 L
.504 .298 L
.508 .29686 L
.512 .2967 L
.516 .29791 L
.52 .29958 L
.524 .30031 L
.528 .29958 L
.532 .29836 L
.536 .29806 L
.54 .29911 L
.544 .3005 L
.548 .3009 L
.552 .30017 L
.556 .29962 L
.56 .30062 L
.564 .30305 L
.568 .3052 L
.572 .30543 L
.576 .30394 L
.58 .30273 L
.584 .30374 L
.588 .3069 L
.592 .3101 L
.596 .31114 L
.6 .30988 L
Mistroke
.604 .30841 L
.608 .30903 L
.612 .31204 L
.616 .31533 L
.62 .31638 L
.624 .31459 L
.628 .31194 L
.632 .31115 L
.636 .31323 L
.64 .31651 L
.644 .31811 L
.648 .31646 L
.652 .31268 L
.656 .30955 L
.66 .30911 L
.664 .311 L
.668 .31292 L
.672 .31268 L
.676 .31007 L
.68 .30692 L
.684 .30557 L
.688 .30695 L
.692 .30991 L
.696 .31227 L
.7 .31248 L
.704 .31071 L
.708 .30851 L
.712 .3077 L
.716 .30914 L
.72 .31246 L
.724 .31647 L
.728 .31996 L
.732 .32226 L
.736 .32336 L
.74 .32394 L
.744 .32513 L
.748 .3282 L
.752 .33398 L
.756 .34224 L
.76 .35156 L
.764 .35991 L
.768 .36583 L
.772 .36948 L
.776 .37275 L
.78 .37813 L
.784 .38686 L
.788 .39775 L
.792 .40741 L
.796 .41213 L
.8 .41013 L
Mistroke
.804 .40291 L
.808 .39444 L
.812 .38894 L
.816 .38816 L
.82 .39044 L
.824 .39159 L
.828 .38774 L
.832 .37791 L
.836 .36505 L
.84 .35466 L
.844 .35185 L
.848 .35863 L
.852 .37252 L
.856 .38796 L
.86 .39877 L
.864 .40123 L
.868 .39533 L
.872 .3843 L
.876 .37284 L
.88 .36446 L
.884 .36069 L
.888 .36053 L
.892 .36196 L
.896 .36313 L
.9 .36292 L
.904 .36143 L
.908 .35848 L
.912 .354 L
.916 .34707 L
.92 .33698 L
.924 .32426 L
.928 .31009 L
.932 .29782 L
.936 .2897 L
.94 .28769 L
.944 .29108 L
.948 .29672 L
.952 .30115 L
.956 .30008 L
.96 .29264 L
.964 .28002 L
.968 .2661 L
.972 .25662 L
.976 .25543 L
.98 .26479 L
.984 .28373 L
.988 .30678 L
.992 .32975 L
.996 .34535 L
1 .35072 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57305 m
.008 .57108 L
.012 .5706 L
.016 .57144 L
.02 .57157 L
.024 .57116 L
.028 .57118 L
.032 .5713 L
.036 .57133 L
.04 .57125 L
.044 .57128 L
.048 .57128 L
.052 .57129 L
.056 .57126 L
.06 .57128 L
.064 .57127 L
.068 .57128 L
.072 .57128 L
.076 .57129 L
.08 .57128 L
.084 .57128 L
.088 .57127 L
.092 .57128 L
.096 .57127 L
.1 .57128 L
.104 .57127 L
.108 .57128 L
.112 .57128 L
.116 .57129 L
.12 .57128 L
.124 .57128 L
.128 .57127 L
.132 .57127 L
.136 .57127 L
.14 .57127 L
.144 .57127 L
.148 .57128 L
.152 .57128 L
.156 .57128 L
.16 .57128 L
.164 .57128 L
.168 .57128 L
.172 .57128 L
.176 .57127 L
.18 .57127 L
.184 .57127 L
.188 .57127 L
.192 .57128 L
.196 .57128 L
.2 .57128 L
Mistroke
.204 .57128 L
.208 .57128 L
.212 .57127 L
.216 .57126 L
.22 .57127 L
.224 .57127 L
.228 .57127 L
.232 .57128 L
.236 .57128 L
.24 .57128 L
.244 .57128 L
.248 .57128 L
.252 .57127 L
.256 .57127 L
.26 .57126 L
.264 .57126 L
.268 .57126 L
.272 .57127 L
.276 .57127 L
.28 .57128 L
.284 .57129 L
.288 .57129 L
.292 .57128 L
.296 .57127 L
.3 .57125 L
.304 .57125 L
.308 .57125 L
.312 .57126 L
.316 .57128 L
.32 .57129 L
.324 .5713 L
.328 .57129 L
.332 .57127 L
.336 .57126 L
.34 .57125 L
.344 .57125 L
.348 .57125 L
.352 .57125 L
.356 .57127 L
.36 .57128 L
.364 .57129 L
.368 .57129 L
.372 .57128 L
.376 .57128 L
.38 .57127 L
.384 .57126 L
.388 .57124 L
.392 .57124 L
.396 .57124 L
.4 .57125 L
Mistroke
.404 .57127 L
.408 .57129 L
.412 .57129 L
.416 .57129 L
.42 .57128 L
.424 .57127 L
.428 .57125 L
.432 .57123 L
.436 .57122 L
.44 .57123 L
.444 .57125 L
.448 .57127 L
.452 .57128 L
.456 .57128 L
.46 .57128 L
.464 .57128 L
.468 .57128 L
.472 .57126 L
.476 .57123 L
.48 .5712 L
.484 .57119 L
.488 .57121 L
.492 .57123 L
.496 .57124 L
.5 .57124 L
.504 .57122 L
.508 .57122 L
.512 .57121 L
.516 .57118 L
.52 .57113 L
.524 .57106 L
.528 .571 L
.532 .57097 L
.536 .57094 L
.54 .57089 L
.544 .57079 L
.548 .57067 L
.552 .57054 L
.556 .57043 L
.56 .5703 L
.564 .57012 L
.568 .56987 L
.572 .56956 L
.576 .56925 L
.58 .56893 L
.584 .56859 L
.588 .56818 L
.592 .56768 L
.596 .56711 L
.6 .56653 L
Mistroke
.604 .56596 L
.608 .56537 L
.612 .56471 L
.616 .56394 L
.62 .56307 L
.624 .56218 L
.628 .56132 L
.632 .56049 L
.636 .55963 L
.64 .55871 L
.644 .55774 L
.648 .55679 L
.652 .5559 L
.656 .55511 L
.66 .55438 L
.664 .55363 L
.668 .55285 L
.672 .55206 L
.676 .55131 L
.68 .55066 L
.684 .55009 L
.688 .54955 L
.692 .54896 L
.696 .5483 L
.7 .54757 L
.704 .54682 L
.708 .5461 L
.712 .54541 L
.716 .54472 L
.72 .544 L
.724 .54321 L
.728 .54235 L
.732 .54143 L
.736 .54047 L
.74 .53949 L
.744 .53848 L
.748 .53739 L
.752 .53619 L
.756 .53483 L
.76 .53333 L
.764 .53171 L
.768 .53003 L
.772 .52834 L
.776 .52664 L
.78 .52483 L
.784 .52282 L
.788 .52052 L
.792 .51792 L
.796 .5151 L
.8 .51224 L
Mistroke
.804 .5095 L
.808 .50696 L
.812 .50461 L
.816 .50234 L
.82 .50003 L
.824 .49764 L
.828 .49524 L
.832 .49295 L
.836 .49088 L
.84 .48907 L
.844 .48741 L
.848 .48574 L
.852 .48386 L
.856 .48168 L
.86 .47921 L
.864 .47659 L
.868 .47399 L
.872 .47156 L
.876 .46935 L
.88 .46737 L
.884 .46552 L
.888 .46373 L
.892 .46195 L
.896 .46017 L
.9 .4584 L
.904 .45669 L
.908 .45507 L
.912 .45359 L
.916 .45226 L
.92 .45117 L
.924 .45034 L
.928 .44982 L
.932 .44958 L
.936 .44958 L
.94 .4497 L
.944 .44983 L
.948 .44991 L
.952 .44994 L
.956 .45 L
.96 .45024 L
.964 .45072 L
.968 .45155 L
.972 .45259 L
.976 .45374 L
.98 .4547 L
.984 .45529 L
.988 .45526 L
.992 .45469 L
.996 .4535 L
1 .45213 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42452 L
.012 .4298 L
.016 .43169 L
.02 .42987 L
.024 .42923 L
.028 .42973 L
.032 .42997 L
.036 .42971 L
.04 .42963 L
.044 .42963 L
.048 .42965 L
.052 .42958 L
.056 .42956 L
.06 .42951 L
.064 .4295 L
.068 .42945 L
.072 .42944 L
.076 .42939 L
.08 .42937 L
.084 .42933 L
.088 .42931 L
.092 .42926 L
.096 .42924 L
.1 .4292 L
.104 .42918 L
.108 .42914 L
.112 .42912 L
.116 .42908 L
.12 .42905 L
.124 .42901 L
.128 .42899 L
.132 .42895 L
.136 .42893 L
.14 .42889 L
.144 .42885 L
.148 .42882 L
.152 .42879 L
.156 .42876 L
.16 .42874 L
.164 .42871 L
.168 .42868 L
.172 .42864 L
.176 .4286 L
.18 .42856 L
.184 .42853 L
.188 .4285 L
.192 .42848 L
.196 .42846 L
.2 .42843 L
Mistroke
.204 .4284 L
.208 .42836 L
.212 .42831 L
.216 .42827 L
.22 .42824 L
.224 .42821 L
.228 .42819 L
.232 .42817 L
.236 .42814 L
.24 .42811 L
.244 .42807 L
.248 .42804 L
.252 .428 L
.256 .42796 L
.26 .42793 L
.264 .4279 L
.268 .42787 L
.272 .42784 L
.276 .42781 L
.28 .4278 L
.284 .42777 L
.288 .42774 L
.292 .4277 L
.296 .42765 L
.3 .4276 L
.304 .42757 L
.308 .42753 L
.312 .42751 L
.316 .4275 L
.32 .42749 L
.324 .42747 L
.328 .42743 L
.332 .42738 L
.336 .42733 L
.34 .42729 L
.344 .42725 L
.348 .42721 L
.352 .42719 L
.356 .42718 L
.36 .42717 L
.364 .42715 L
.368 .42711 L
.372 .42707 L
.376 .42703 L
.38 .42699 L
.384 .42695 L
.388 .4269 L
.392 .42686 L
.396 .42683 L
.4 .42682 L
Mistroke
.404 .42681 L
.408 .4268 L
.412 .42677 L
.416 .42674 L
.42 .4267 L
.424 .42666 L
.428 .4266 L
.432 .42654 L
.436 .4265 L
.44 .42647 L
.444 .42647 L
.448 .42646 L
.452 .42645 L
.456 .42642 L
.46 .42639 L
.464 .42637 L
.468 .42633 L
.472 .42628 L
.476 .42621 L
.48 .42616 L
.484 .42612 L
.488 .42612 L
.492 .42613 L
.496 .42613 L
.5 .42611 L
.504 .42609 L
.508 .42609 L
.512 .42609 L
.516 .42608 L
.52 .42605 L
.524 .42601 L
.528 .42601 L
.532 .42606 L
.536 .42614 L
.54 .42623 L
.544 .42629 L
.548 .42635 L
.552 .42646 L
.556 .42664 L
.56 .42686 L
.564 .42709 L
.568 .4273 L
.572 .42753 L
.576 .42784 L
.58 .42824 L
.584 .42873 L
.588 .42923 L
.592 .42974 L
.596 .43028 L
.6 .43094 L
Mistroke
.604 .43174 L
.608 .43264 L
.612 .43355 L
.616 .43444 L
.62 .43532 L
.624 .43626 L
.628 .4373 L
.632 .43843 L
.636 .43957 L
.64 .44065 L
.644 .44166 L
.648 .44267 L
.652 .44372 L
.656 .44484 L
.66 .44595 L
.664 .44696 L
.668 .44784 L
.672 .44862 L
.676 .44938 L
.68 .45019 L
.684 .45105 L
.688 .45189 L
.692 .45267 L
.696 .45335 L
.7 .45398 L
.704 .45464 L
.708 .4554 L
.712 .45629 L
.716 .45728 L
.72 .45832 L
.724 .45939 L
.728 .46048 L
.732 .46161 L
.736 .46279 L
.74 .46406 L
.744 .46541 L
.748 .46681 L
.752 .46822 L
.756 .46964 L
.76 .4711 L
.764 .47269 L
.768 .47453 L
.772 .4767 L
.776 .47925 L
.78 .48208 L
.784 .48506 L
.788 .48806 L
.792 .49101 L
.796 .49395 L
.8 .49701 L
Mistroke
.804 .50026 L
.808 .50371 L
.812 .50721 L
.816 .51054 L
.82 .51352 L
.824 .51605 L
.828 .51823 L
.832 .52029 L
.836 .52246 L
.84 .52489 L
.844 .5276 L
.848 .53047 L
.852 .53336 L
.856 .53618 L
.86 .53892 L
.864 .54167 L
.868 .54452 L
.872 .54752 L
.876 .55059 L
.88 .55358 L
.884 .55632 L
.888 .55868 L
.892 .56065 L
.896 .56229 L
.9 .56375 L
.904 .5652 L
.908 .56672 L
.912 .56839 L
.916 .57015 L
.92 .57198 L
.924 .57374 L
.928 .57531 L
.932 .57651 L
.936 .57722 L
.94 .5773 L
.944 .57673 L
.948 .57559 L
.952 .5741 L
.956 .57254 L
.96 .57126 L
.964 .57045 L
.968 .5703 L
.972 .57069 L
.976 .57148 L
.98 .57233 L
.984 .57303 L
.988 .5733 L
.992 .57322 L
.996 .57262 L
1 .57189 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10001Goo00@007ooOol0
00Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomo
o`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<00003Ool0000000@000=oo`8000Ioo`008Woo
00<007ooOol0FGoo00D007oo001oo`0000ioo`008Woo0`0037oo0P0000Aoo`00001oo`800004Ool0
0000OolH00000goo001oo`0UOol2000017oo001oo`003Woo000ROomS000<Ool0029oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`04001oogoo0003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`0900000goo0000
00020002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`80009oo`05001oo`00Ool0000<
Ool0029oo`8004Eoo`<0011oo`03001oogoo00Aoo`03001oogoo00]oo`008Woo00<007ooOol0AWoo
00<007ooOol03Woo00<007ooOol017oo00<007ooOol02goo000ROol20018Ool00`00Oomoo`0<Ool0
0`00Oomoo`05Ool00`00Oomoo`0;Ool0029oo`8004Qoo`8000Ioo`8000Eoo`03001oogoo00Ioo`03
001oogoo00Yoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0B7oo00<0
07ooOol017oo0P000Woo0`005Woo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8004Yoo`03001oogoo009oo`05001oo`00Ool0000IOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P00Bgoo00<007oo00000P000Woo0P006Goo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo04Yoo`04001oo`000003Ool2000I
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Bgoo0P0087oo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8004aoo`03001oogoo01ioo`002goo0P00
2Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002
Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`80
06eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol0
00Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007oo
Ool007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03
001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000
Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool3
0003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001o
ogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007oo
Oomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogoo
Ool40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<0
07ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000A
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Ao
o`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P00
0goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo
0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo
00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D0
07ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04
001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=o
o`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001o
ogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004
Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00003
0003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo
0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00
Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04
001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`80
00Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo
00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo
00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`80
00=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00
Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1@
Ool:000<Ool002Qoo`03001oogoo04ioo`<001Eoo`00:7oo00<007ooOol0C7oo0`005goo000AOol2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1:Ool3000IOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0B7oo0`006goo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo04Moo`8001eoo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20016Ool2000OOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0@goo0`0087oo000@Ool01000Oomoo`00
27oo00@007ooOol0009oo`8000Aoo`03001oogoo041oo`@0029oo`004Goo0P002Woo0P0017oo00<0
07ooOol00Woo00<007ooOol0>Woo1P009Woo000XOol00`00Oomoo`0eOol5000/Ool002QoocT0031o
o`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool0
0`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04
001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007oo
Ool00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@0
07ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007oo
Ool00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007oo
Ool000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079o
o`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo
0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomo
ogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomo
o`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00
Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`00
27oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomo
o`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00
Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004
Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo
0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00
Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol0
0P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo
1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`02
Oom0000eOol001Moo`03001oogoo009oo`03001oogoo03eoo`D0031oo`005goo00<007ooOol00Woo
00<007ooOol0@Goo1@00;7oo000FOol20004Ool20017Ool4000XOol001Moo`03001oogoo009oo`03
001oogoo04Yoo`<002Eoo`0077oo00<007ooOol0CGoo0P008goo000LOol2001?Ool2000ROol001ao
o`03001oogoo04moo`80025oo`0077oo0P00DWoo0P007goo000LOol00`00Oomoo`1BOol2000NOol0
01aoo`03001oogoo05Aoo`8001aoo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00EWoo0P00
6goo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0Egoo00<007ooOol067oo
000;Ool00`00Oomoo`0;Ool01000Oomoo`00FWoo0P0067oo000;Ool00`00Oomoo`0;Ool00`00Oomo
o`02001JOol3000FOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo05aoo`X000aoo`002Woo
0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(32732\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29983 m
.008 .30019 L
.012 .29903 L
.016 .29887 L
.02 .29956 L
.024 .29954 L
.028 .29907 L
.032 .29907 L
.036 .29932 L
.04 .29933 L
.044 .29923 L
.048 .29921 L
.052 .2992 L
.056 .29917 L
.06 .29915 L
.064 .29916 L
.068 .29917 L
.072 .29915 L
.076 .29912 L
.08 .2991 L
.084 .2991 L
.088 .29911 L
.092 .29911 L
.096 .29908 L
.1 .29903 L
.104 .299 L
.108 .29902 L
.112 .29905 L
.116 .29905 L
.12 .29902 L
.124 .29898 L
.128 .29893 L
.132 .29891 L
.136 .29894 L
.14 .29899 L
.144 .299 L
.148 .29893 L
.152 .29884 L
.156 .29881 L
.16 .29885 L
.164 .29891 L
.168 .29892 L
.172 .2989 L
.176 .29884 L
.18 .29876 L
.184 .2987 L
.188 .29872 L
.192 .29882 L
.196 .29891 L
.2 .29887 L
Mistroke
.204 .29873 L
.208 .29862 L
.212 .29862 L
.216 .29867 L
.22 .29872 L
.224 .29876 L
.228 .2988 L
.232 .29877 L
.236 .29863 L
.24 .29847 L
.244 .29844 L
.248 .29858 L
.252 .29874 L
.256 .29877 L
.26 .2987 L
.264 .2986 L
.268 .2985 L
.272 .29837 L
.276 .29827 L
.28 .29837 L
.284 .29867 L
.288 .2989 L
.292 .29882 L
.296 .29847 L
.3 .29814 L
.304 .29806 L
.308 .29822 L
.312 .29843 L
.316 .29863 L
.32 .29877 L
.324 .29878 L
.328 .29851 L
.332 .29806 L
.336 .29775 L
.34 .29789 L
.344 .29838 L
.348 .2988 L
.352 .29883 L
.356 .29853 L
.36 .29817 L
.364 .29797 L
.368 .2979 L
.372 .29794 L
.376 .29813 L
.38 .29849 L
.384 .29879 L
.388 .29872 L
.392 .29821 L
.396 .2976 L
.4 .29739 L
Mistroke
.404 .29776 L
.408 .2984 L
.412 .29882 L
.416 .29876 L
.42 .29837 L
.424 .29794 L
.428 .29767 L
.432 .29755 L
.436 .29756 L
.44 .29781 L
.444 .29832 L
.448 .29888 L
.452 .29906 L
.456 .29858 L
.46 .29769 L
.464 .29704 L
.468 .29717 L
.472 .29798 L
.476 .29882 L
.48 .29909 L
.484 .29878 L
.488 .29842 L
.492 .29844 L
.496 .29873 L
.5 .29884 L
.504 .29865 L
.508 .29865 L
.512 .29936 L
.516 .30066 L
.52 .30165 L
.524 .30156 L
.528 .30064 L
.532 .30012 L
.536 .30104 L
.54 .30317 L
.544 .30514 L
.548 .30581 L
.552 .30542 L
.556 .30533 L
.56 .30656 L
.564 .30865 L
.568 .31017 L
.572 .31023 L
.576 .30961 L
.58 .31 L
.584 .31226 L
.588 .31527 L
.592 .3169 L
.596 .31607 L
.6 .31389 L
Mistroke
.604 .31273 L
.608 .31393 L
.612 .31648 L
.616 .3179 L
.62 .31663 L
.624 .31354 L
.628 .31116 L
.632 .31129 L
.636 .3133 L
.64 .31468 L
.644 .31342 L
.648 .30992 L
.652 .3067 L
.656 .30621 L
.66 .30863 L
.664 .31176 L
.668 .31295 L
.672 .3114 L
.676 .30877 L
.68 .30771 L
.684 .30956 L
.688 .31337 L
.692 .31676 L
.696 .31803 L
.7 .31748 L
.704 .31711 L
.708 .31897 L
.712 .32358 L
.716 .32972 L
.72 .33549 L
.724 .33971 L
.728 .34269 L
.732 .34584 L
.736 .35065 L
.74 .35782 L
.744 .36699 L
.748 .37706 L
.752 .38665 L
.756 .39452 L
.76 .3999 L
.764 .40276 L
.768 .40388 L
.772 .40445 L
.776 .4054 L
.78 .40654 L
.784 .40639 L
.788 .40299 L
.792 .39529 L
.796 .38436 L
.8 .3733 L
Mistroke
.804 .36589 L
.808 .36444 L
.812 .36837 L
.816 .37454 L
.82 .37905 L
.824 .37983 L
.828 .37776 L
.832 .37613 L
.836 .37822 L
.84 .38485 L
.844 .39334 L
.848 .39867 L
.852 .39642 L
.856 .38528 L
.86 .36841 L
.864 .35181 L
.868 .34152 L
.872 .3406 L
.876 .3475 L
.88 .35732 L
.884 .36381 L
.888 .36279 L
.892 .35338 L
.896 .33797 L
.9 .32095 L
.904 .30585 L
.908 .29512 L
.912 .28859 L
.916 .28535 L
.92 .28417 L
.924 .28399 L
.928 .28485 L
.932 .28597 L
.936 .28698 L
.94 .28685 L
.944 .28487 L
.948 .28186 L
.952 .27936 L
.956 .28003 L
.96 .2864 L
.964 .29808 L
.968 .31384 L
.972 .32835 L
.976 .33641 L
.98 .33475 L
.984 .32049 L
.988 .29907 L
.992 .27431 L
.996 .25481 L
1 .24734 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .5786 m
.008 .57086 L
.012 .56832 L
.016 .57081 L
.02 .57174 L
.024 .57087 L
.028 .57059 L
.032 .57083 L
.036 .57096 L
.04 .57085 L
.044 .57084 L
.048 .57085 L
.052 .57088 L
.056 .57085 L
.06 .57086 L
.064 .57085 L
.068 .57087 L
.072 .57085 L
.076 .57086 L
.08 .57085 L
.084 .57086 L
.088 .57085 L
.092 .57086 L
.096 .57086 L
.1 .57087 L
.104 .57086 L
.108 .57086 L
.112 .57085 L
.116 .57086 L
.12 .57085 L
.124 .57086 L
.128 .57086 L
.132 .57086 L
.136 .57086 L
.14 .57086 L
.144 .57085 L
.148 .57086 L
.152 .57086 L
.156 .57086 L
.16 .57086 L
.164 .57086 L
.168 .57085 L
.172 .57085 L
.176 .57085 L
.18 .57086 L
.184 .57086 L
.188 .57086 L
.192 .57086 L
.196 .57086 L
.2 .57085 L
Mistroke
.204 .57085 L
.208 .57084 L
.212 .57085 L
.216 .57085 L
.22 .57086 L
.224 .57087 L
.228 .57087 L
.232 .57086 L
.236 .57085 L
.24 .57084 L
.244 .57084 L
.248 .57085 L
.252 .57085 L
.256 .57086 L
.26 .57086 L
.264 .57086 L
.268 .57086 L
.272 .57086 L
.276 .57085 L
.28 .57085 L
.284 .57085 L
.288 .57084 L
.292 .57084 L
.296 .57084 L
.3 .57085 L
.304 .57086 L
.308 .57087 L
.312 .57087 L
.316 .57086 L
.32 .57085 L
.324 .57084 L
.328 .57083 L
.332 .57082 L
.336 .57083 L
.34 .57085 L
.344 .57087 L
.348 .57087 L
.352 .57087 L
.356 .57086 L
.36 .57085 L
.364 .57084 L
.368 .57083 L
.372 .57082 L
.376 .57083 L
.38 .57084 L
.384 .57086 L
.388 .57086 L
.392 .57087 L
.396 .57086 L
.4 .57086 L
Mistroke
.404 .57085 L
.408 .57084 L
.412 .57082 L
.416 .57081 L
.42 .57082 L
.424 .57083 L
.428 .57084 L
.432 .57085 L
.436 .57086 L
.44 .57087 L
.444 .57087 L
.448 .57085 L
.452 .57083 L
.456 .5708 L
.46 .57078 L
.464 .57078 L
.468 .57079 L
.472 .5708 L
.476 .5708 L
.48 .57079 L
.484 .57079 L
.488 .57078 L
.492 .57075 L
.496 .57069 L
.5 .57062 L
.504 .57055 L
.508 .5705 L
.512 .57045 L
.516 .57039 L
.52 .57029 L
.524 .57018 L
.528 .57006 L
.532 .56992 L
.536 .56975 L
.54 .56952 L
.544 .56923 L
.548 .56891 L
.552 .56859 L
.556 .56825 L
.56 .56787 L
.564 .56742 L
.568 .5669 L
.572 .56632 L
.576 .56573 L
.58 .56512 L
.584 .56446 L
.588 .56372 L
.592 .56289 L
.596 .56203 L
.6 .56118 L
Mistroke
.604 .56034 L
.608 .55947 L
.612 .55856 L
.616 .5576 L
.62 .55665 L
.624 .55578 L
.628 .55498 L
.632 .55422 L
.636 .55345 L
.64 .55265 L
.644 .55185 L
.648 .55112 L
.652 .55047 L
.656 .54988 L
.66 .54928 L
.664 .54863 L
.668 .54794 L
.672 .54726 L
.676 .54663 L
.68 .54603 L
.684 .54541 L
.688 .54471 L
.692 .54389 L
.696 .543 L
.7 .5421 L
.704 .54121 L
.708 .54033 L
.712 .5394 L
.716 .53838 L
.72 .53723 L
.724 .53598 L
.728 .53465 L
.732 .53328 L
.736 .53187 L
.74 .53037 L
.744 .52875 L
.748 .52696 L
.752 .52498 L
.756 .52283 L
.76 .52054 L
.764 .51813 L
.768 .51563 L
.772 .51304 L
.776 .51036 L
.78 .5076 L
.784 .50482 L
.788 .50211 L
.792 .49958 L
.796 .49732 L
.8 .49535 L
Mistroke
.804 .49358 L
.808 .49187 L
.812 .49005 L
.816 .48806 L
.82 .48589 L
.824 .48364 L
.828 .48141 L
.832 .47925 L
.836 .4771 L
.84 .47489 L
.844 .47252 L
.848 .47 L
.852 .46744 L
.856 .46502 L
.86 .46292 L
.864 .46121 L
.868 .45984 L
.872 .45865 L
.876 .45746 L
.88 .45613 L
.884 .45465 L
.888 .45311 L
.892 .45167 L
.896 .45048 L
.9 .44961 L
.904 .44909 L
.908 .44886 L
.912 .44885 L
.916 .449 L
.92 .44924 L
.924 .44957 L
.928 .44996 L
.932 .45039 L
.936 .45086 L
.94 .45134 L
.944 .45186 L
.948 .45238 L
.952 .45292 L
.956 .45336 L
.96 .45366 L
.964 .45364 L
.968 .45331 L
.972 .45257 L
.976 .45166 L
.98 .45068 L
.984 .44999 L
.988 .44976 L
.992 .45009 L
.996 .45098 L
1 .45219 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43084 L
.012 .42962 L
.016 .42952 L
.02 .42999 L
.024 .42998 L
.028 .42967 L
.032 .4297 L
.036 .42974 L
.04 .42972 L
.044 .42962 L
.048 .42962 L
.052 .42958 L
.056 .42957 L
.06 .42951 L
.064 .4295 L
.068 .42946 L
.072 .42944 L
.076 .42939 L
.08 .42937 L
.084 .42933 L
.088 .4293 L
.092 .42926 L
.096 .42924 L
.1 .4292 L
.104 .42918 L
.108 .42915 L
.112 .42912 L
.116 .42908 L
.12 .42905 L
.124 .42901 L
.128 .42898 L
.132 .42895 L
.136 .42893 L
.14 .4289 L
.144 .42887 L
.148 .42883 L
.152 .4288 L
.156 .42876 L
.16 .42873 L
.164 .4287 L
.168 .42867 L
.172 .42863 L
.176 .42861 L
.18 .42858 L
.184 .42855 L
.188 .42852 L
.192 .42849 L
.196 .42845 L
.2 .42841 L
Mistroke
.204 .42837 L
.208 .42834 L
.212 .42832 L
.216 .42829 L
.22 .42827 L
.224 .42824 L
.228 .4282 L
.232 .42817 L
.236 .42813 L
.24 .42809 L
.244 .42806 L
.248 .42803 L
.252 .428 L
.256 .42797 L
.26 .42795 L
.264 .42792 L
.268 .42789 L
.272 .42785 L
.276 .42782 L
.28 .42778 L
.284 .42775 L
.288 .42771 L
.292 .42767 L
.296 .42764 L
.3 .42762 L
.304 .42761 L
.308 .42759 L
.312 .42755 L
.316 .42751 L
.32 .42747 L
.324 .42742 L
.328 .42737 L
.332 .42734 L
.336 .42732 L
.34 .42731 L
.344 .4273 L
.348 .42728 L
.352 .42724 L
.356 .4272 L
.36 .42715 L
.364 .42711 L
.368 .42706 L
.372 .42702 L
.376 .427 L
.38 .42699 L
.384 .42697 L
.388 .42695 L
.392 .42692 L
.396 .42689 L
.4 .42686 L
Mistroke
.404 .42682 L
.408 .42676 L
.412 .42671 L
.416 .42667 L
.42 .42664 L
.424 .42663 L
.428 .42662 L
.432 .4266 L
.436 .42658 L
.44 .42656 L
.444 .42653 L
.448 .42649 L
.452 .42643 L
.456 .42637 L
.46 .42633 L
.464 .42632 L
.468 .42631 L
.472 .42631 L
.476 .4263 L
.48 .4263 L
.484 .4263 L
.488 .42631 L
.492 .42631 L
.496 .42628 L
.5 .42626 L
.504 .42626 L
.508 .4263 L
.512 .42637 L
.516 .42646 L
.52 .42656 L
.524 .42668 L
.528 .42683 L
.532 .42702 L
.536 .42724 L
.54 .42746 L
.544 .42768 L
.548 .42796 L
.552 .42832 L
.556 .42877 L
.56 .42928 L
.564 .42982 L
.568 .43039 L
.572 .43102 L
.576 .43175 L
.58 .43258 L
.584 .43346 L
.588 .43435 L
.592 .43524 L
.596 .43619 L
.6 .43722 L
Mistroke
.604 .43832 L
.608 .43944 L
.612 .44052 L
.616 .44155 L
.62 .44258 L
.624 .44365 L
.628 .44477 L
.632 .44587 L
.636 .44688 L
.64 .44777 L
.644 .44858 L
.648 .44938 L
.652 .45021 L
.656 .45105 L
.66 .45183 L
.664 .45253 L
.668 .45318 L
.672 .45386 L
.676 .45464 L
.68 .45553 L
.684 .45648 L
.688 .45741 L
.692 .4583 L
.696 .45921 L
.7 .46021 L
.704 .46134 L
.708 .4626 L
.712 .46391 L
.716 .46522 L
.72 .46651 L
.724 .46782 L
.728 .46922 L
.732 .47078 L
.736 .47255 L
.74 .47451 L
.744 .47665 L
.748 .47896 L
.752 .48143 L
.756 .4841 L
.76 .48697 L
.764 .49005 L
.768 .49329 L
.772 .49662 L
.776 .49993 L
.78 .50312 L
.784 .50615 L
.788 .50905 L
.792 .51188 L
.796 .51471 L
.8 .51756 L
Mistroke
.804 .52037 L
.808 .52303 L
.812 .52547 L
.816 .5277 L
.82 .52986 L
.824 .53215 L
.828 .53475 L
.832 .53772 L
.836 .54096 L
.84 .54426 L
.844 .54736 L
.848 .55012 L
.852 .55255 L
.856 .55475 L
.86 .55691 L
.864 .55912 L
.868 .56139 L
.872 .56361 L
.876 .56566 L
.88 .56747 L
.884 .56906 L
.888 .57053 L
.892 .57194 L
.896 .57337 L
.9 .57472 L
.904 .57586 L
.908 .57661 L
.912 .57684 L
.916 .57653 L
.92 .57576 L
.924 .5747 L
.928 .57352 L
.932 .57239 L
.936 .57146 L
.94 .57078 L
.944 .57042 L
.948 .57036 L
.952 .5706 L
.956 .57103 L
.96 .57158 L
.964 .57204 L
.968 .57237 L
.972 .57237 L
.976 .57219 L
.98 .57177 L
.984 .57138 L
.988 .57114 L
.992 .57115 L
.996 .5715 L
1 .57206 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00=oo`80009o
o`04001oogoo0005Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0
2goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04
001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Ao
o`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0003Ool02@00Oomoogoo001oo`00Ool00004Ool01000Oomo
o`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomo
ogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00
Oomoo`1FOol60002Ool00`00Oomoo`0;Ool0029oo`80011oo`03001oo`0001L00004Ool00000Ool3
000VOol00`00Oomoo`02Ool00`00Ool0000>Ool0029oof<000aoo`008Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`T00003Ool0000000@000=oo`05001oogoo
Ool00003Ool02@00Oomoogoo001oo`00Ool00003Ool01@00Ool007oo000037oo000ROol20014Ool0
0`00Oomoo`0?Ool00`00Oomoo`04Ool2000>Ool0029oo`03001oogoo04=oo`8000moo`03001oogoo
00Eoo`8000ioo`008Woo0P00AGoo00<007ooOol02goo00<007oo00005goo000ROol20016Ool00`00
Oomoo`09Ool01000Ool000005goo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00
Oomoo`16Ool00`00Oomoo`02Ool20004Ool01000Ool000005goo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8004Moo`03001oogoo009oo`03001oo`0000800003Ool007oo
01Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20017Ool00`00Oomo
o`02Ool01`00Oomoogoo001oo`0001Yoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`17Ool01000Oomoo`0017oo0P006goo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8004Uoo`<0025oo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`00
2goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001o
ogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo
0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol0
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007oo
Ool006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo
06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P00
17oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<0
07ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001o
ogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`80
00Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Mo
o`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009o
o`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool01000
0goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007oo
Ool007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomo
o`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0
009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo
00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007oo
Ool02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo
00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P00
0goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool2
0008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P00
17oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomo
o`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool2
0004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo06Ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P00
17oo0P000Woo1@000Woo00<007ooOol0CWoo300037oo000XOol00`00Oomoo`1;Ool4000GOol002Qo
o`03001oogoo04Yoo`8001Yoo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007oo
Ool0B7oo0P0077oo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo04Ioo`8001ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`14Ool3000OOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
A7oo0P008Goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
041oo`<002=oo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0mOol4
000UOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo03Moo`H002Uoo`00:7oo00<0
07ooOol0<goo1@00;Woo000XOolf000cOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomo
o`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool0
0`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`00
1goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;
Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Ao
o`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Ao
o`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007oo
Ool00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003
Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<0
07ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000
Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo
0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2
000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol0
37oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo
0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@00
0goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Ao
o`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomo
o`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001d
Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00
Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo
009oo`03001oogoo079oo`005goo00<007ooOol00Woo?P00=goo000GOol00`00Oomoo`02Ool00`00
Oomoo`0jOol5000cOol001Moo`03001oogoo009oo`03001oogoo03ioo`D002moo`005Woo0P0017oo
0P00A7oo1000:goo000GOol00`00Oomoo`02Ool00`00Oomoo`17Ool3000XOol001aoo`03001oogoo
04Yoo`8002Ioo`0077oo0P00C7oo0P009Goo000LOol00`00Oomoo`1=Ool00`00Oomoo`0ROol001ao
o`8004moo`80029oo`0077oo00<007ooOol0Cgoo0P008Goo000LOol00`00Oomoo`1AOol2000OOol0
00Yoo`<000Aoo`03001oogoo009oo`<000=oo`8005=oo`8001ioo`002goo00<007ooOol01goo00D0
07ooOomoo`00009oo`03001oogoo05Aoo`8001aoo`002goo00<007ooOol02goo00@007ooOol005Mo
o`<001Yoo`002goo00<007ooOol02goo00<007ooOol00P00F7oo0`0067oo000;Ool00`00Oomoo`07
Ool40003Ool00`00Oomoo`1IOol=000<Ool000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079o
o`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo
079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(32899\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30203 m
.008 .30012 L
.012 .29853 L
.016 .29837 L
.02 .29965 L
.024 .29995 L
.028 .29918 L
.032 .2989 L
.036 .29925 L
.04 .29945 L
.044 .29935 L
.048 .29926 L
.052 .29922 L
.056 .29917 L
.06 .29915 L
.064 .29918 L
.068 .29924 L
.072 .29925 L
.076 .2992 L
.08 .29912 L
.084 .29907 L
.088 .29908 L
.092 .29914 L
.096 .29918 L
.1 .29916 L
.104 .29909 L
.108 .29902 L
.112 .29898 L
.116 .299 L
.12 .29904 L
.124 .29909 L
.128 .29909 L
.132 .29903 L
.136 .29896 L
.14 .29892 L
.144 .29892 L
.148 .29893 L
.152 .29893 L
.156 .29895 L
.16 .29898 L
.164 .29898 L
.168 .29892 L
.172 .29883 L
.176 .29878 L
.18 .29878 L
.184 .2988 L
.188 .29886 L
.192 .29894 L
.196 .29896 L
.2 .29886 L
Mistroke
.204 .29868 L
.208 .29858 L
.212 .29863 L
.216 .29877 L
.22 .29887 L
.224 .29887 L
.228 .29881 L
.232 .2987 L
.236 .29857 L
.24 .29848 L
.244 .29854 L
.248 .29873 L
.252 .29886 L
.256 .29881 L
.26 .29861 L
.264 .29846 L
.268 .29845 L
.272 .29851 L
.276 .29856 L
.28 .29863 L
.284 .29872 L
.288 .29873 L
.292 .29854 L
.296 .29828 L
.3 .29818 L
.304 .29836 L
.308 .29866 L
.312 .29879 L
.316 .29868 L
.32 .29847 L
.324 .29829 L
.328 .29816 L
.332 .2981 L
.336 .2982 L
.34 .2985 L
.344 .29883 L
.348 .29886 L
.352 .29848 L
.356 .29798 L
.36 .29776 L
.364 .29796 L
.368 .29834 L
.372 .29859 L
.376 .29863 L
.38 .29854 L
.384 .29837 L
.388 .29812 L
.392 .29784 L
.396 .29774 L
.4 .29801 L
Mistroke
.404 .29852 L
.408 .29887 L
.412 .29871 L
.416 .29815 L
.42 .29762 L
.424 .29754 L
.428 .29791 L
.432 .29842 L
.436 .29874 L
.44 .29878 L
.444 .29866 L
.448 .29846 L
.452 .29818 L
.456 .29787 L
.46 .29779 L
.464 .29821 L
.468 .2991 L
.472 .30001 L
.476 .30033 L
.48 .29989 L
.484 .29919 L
.488 .29898 L
.492 .29963 L
.496 .30078 L
.5 .30177 L
.504 .30229 L
.508 .30264 L
.512 .30328 L
.516 .30421 L
.52 .30497 L
.524 .30528 L
.528 .30551 L
.532 .30646 L
.536 .30842 L
.54 .31064 L
.544 .31192 L
.548 .31184 L
.552 .31124 L
.556 .31156 L
.56 .31332 L
.564 .31558 L
.568 .31685 L
.572 .31657 L
.576 .3157 L
.58 .31562 L
.584 .31666 L
.588 .3176 L
.592 .31703 L
.596 .3149 L
.6 .31277 L
Mistroke
.604 .31237 L
.608 .31377 L
.612 .31516 L
.616 .31453 L
.62 .31172 L
.624 .30867 L
.628 .30768 L
.632 .30927 L
.636 .31165 L
.64 .31242 L
.644 .3109 L
.648 .30877 L
.652 .30856 L
.656 .31123 L
.66 .31525 L
.664 .31797 L
.668 .31803 L
.672 .31664 L
.676 .31654 L
.68 .31962 L
.684 .32535 L
.688 .33129 L
.692 .33527 L
.696 .33728 L
.7 .33939 L
.704 .34399 L
.708 .35181 L
.712 .36143 L
.716 .37047 L
.72 .37748 L
.724 .38286 L
.728 .38822 L
.732 .39484 L
.736 .40252 L
.74 .40957 L
.744 .41395 L
.748 .41442 L
.752 .41114 L
.756 .40535 L
.76 .39862 L
.764 .39221 L
.768 .38681 L
.772 .38252 L
.776 .37901 L
.78 .3758 L
.784 .37264 L
.788 .36993 L
.792 .36885 L
.796 .37082 L
.8 .37654 L
Mistroke
.804 .38498 L
.808 .39337 L
.812 .39821 L
.816 .39719 L
.82 .39053 L
.824 .38104 L
.828 .37264 L
.832 .36795 L
.836 .36691 L
.84 .36686 L
.844 .36451 L
.848 .35833 L
.852 .34962 L
.856 .342 L
.86 .33872 L
.864 .34052 L
.868 .34447 L
.872 .34524 L
.876 .3383 L
.88 .32215 L
.884 .30019 L
.888 .27865 L
.892 .26419 L
.896 .26058 L
.9 .26684 L
.904 .27864 L
.908 .28977 L
.912 .29591 L
.916 .29584 L
.92 .29149 L
.924 .28692 L
.928 .28548 L
.932 .28879 L
.936 .2964 L
.94 .30547 L
.944 .31377 L
.948 .31875 L
.952 .31922 L
.956 .31577 L
.96 .30777 L
.964 .29786 L
.968 .28645 L
.972 .27616 L
.976 .27036 L
.98 .26939 L
.984 .27693 L
.988 .28981 L
.992 .30614 L
.996 .32194 L
1 .33013 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57014 m
.008 .5706 L
.012 .57069 L
.016 .57024 L
.02 .57034 L
.024 .57052 L
.028 .57051 L
.032 .57038 L
.036 .57043 L
.04 .57045 L
.044 .57046 L
.048 .57042 L
.052 .57044 L
.056 .57043 L
.06 .57045 L
.064 .57043 L
.068 .57045 L
.072 .57044 L
.076 .57045 L
.08 .57043 L
.084 .57044 L
.088 .57043 L
.092 .57044 L
.096 .57044 L
.1 .57045 L
.104 .57044 L
.108 .57044 L
.112 .57043 L
.116 .57044 L
.12 .57043 L
.124 .57044 L
.128 .57044 L
.132 .57045 L
.136 .57044 L
.14 .57044 L
.144 .57043 L
.148 .57044 L
.152 .57043 L
.156 .57044 L
.16 .57044 L
.164 .57044 L
.168 .57044 L
.172 .57044 L
.176 .57044 L
.18 .57044 L
.184 .57043 L
.188 .57043 L
.192 .57043 L
.196 .57043 L
.2 .57044 L
Mistroke
.204 .57044 L
.208 .57044 L
.212 .57044 L
.216 .57044 L
.22 .57044 L
.224 .57043 L
.228 .57043 L
.232 .57043 L
.236 .57043 L
.24 .57043 L
.244 .57044 L
.248 .57045 L
.252 .57045 L
.256 .57044 L
.26 .57043 L
.264 .57043 L
.268 .57043 L
.272 .57043 L
.276 .57043 L
.28 .57043 L
.284 .57044 L
.288 .57044 L
.292 .57044 L
.296 .57044 L
.3 .57044 L
.304 .57044 L
.308 .57043 L
.312 .57042 L
.316 .57042 L
.32 .57042 L
.324 .57043 L
.328 .57044 L
.332 .57045 L
.336 .57045 L
.34 .57045 L
.344 .57043 L
.348 .57042 L
.352 .57041 L
.356 .5704 L
.36 .57041 L
.364 .57043 L
.368 .57044 L
.372 .57045 L
.376 .57045 L
.38 .57045 L
.384 .57043 L
.388 .57042 L
.392 .57041 L
.396 .5704 L
.4 .57041 L
Mistroke
.404 .57042 L
.408 .57042 L
.412 .57043 L
.416 .57044 L
.42 .57044 L
.424 .57044 L
.428 .57043 L
.432 .5704 L
.436 .57038 L
.44 .57037 L
.444 .57036 L
.448 .57036 L
.452 .57036 L
.456 .57035 L
.46 .57035 L
.464 .57034 L
.468 .57031 L
.472 .57026 L
.476 .57019 L
.48 .57012 L
.484 .57004 L
.488 .56997 L
.492 .56988 L
.496 .56978 L
.5 .56966 L
.504 .56952 L
.508 .56937 L
.512 .56918 L
.516 .56893 L
.52 .56863 L
.524 .56829 L
.528 .56792 L
.532 .56753 L
.536 .5671 L
.54 .56662 L
.544 .56608 L
.548 .56551 L
.552 .5649 L
.556 .56425 L
.56 .56353 L
.564 .56273 L
.568 .56188 L
.572 .56101 L
.576 .56015 L
.58 .55929 L
.584 .5584 L
.588 .55749 L
.592 .55656 L
.596 .55567 L
.6 .55483 L
Mistroke
.604 .55403 L
.608 .55324 L
.612 .55244 L
.616 .55166 L
.62 .55093 L
.624 .55027 L
.628 .54965 L
.632 .54904 L
.636 .54838 L
.64 .54771 L
.644 .54705 L
.648 .54643 L
.652 .54585 L
.656 .54522 L
.66 .54451 L
.664 .54371 L
.668 .54285 L
.672 .54199 L
.676 .54113 L
.68 .54024 L
.684 .53926 L
.688 .53817 L
.692 .537 L
.696 .53581 L
.7 .53462 L
.704 .53339 L
.708 .53207 L
.712 .53058 L
.716 .5289 L
.72 .52705 L
.724 .52509 L
.728 .52302 L
.732 .52084 L
.736 .51851 L
.74 .51602 L
.744 .51337 L
.748 .51063 L
.752 .50787 L
.756 .50518 L
.76 .50262 L
.764 .5002 L
.768 .49792 L
.772 .49577 L
.776 .49372 L
.78 .49175 L
.784 .48987 L
.788 .48803 L
.792 .48618 L
.796 .48426 L
.8 .48217 L
Mistroke
.804 .47987 L
.808 .47736 L
.812 .47475 L
.816 .47217 L
.82 .46976 L
.824 .4676 L
.828 .46568 L
.832 .46392 L
.836 .4622 L
.84 .46046 L
.844 .45874 L
.848 .45712 L
.852 .45566 L
.856 .45442 L
.86 .45332 L
.864 .45226 L
.868 .45114 L
.872 .44998 L
.876 .44888 L
.88 .44802 L
.884 .44759 L
.888 .44766 L
.892 .4482 L
.896 .44901 L
.9 .4499 L
.904 .45068 L
.908 .45125 L
.912 .45166 L
.916 .45196 L
.92 .45225 L
.924 .45254 L
.928 .45281 L
.932 .45295 L
.936 .45293 L
.94 .45265 L
.944 .45221 L
.948 .45159 L
.952 .451 L
.956 .45047 L
.96 .45017 L
.964 .45013 L
.968 .45038 L
.972 .45092 L
.976 .45162 L
.98 .45235 L
.984 .453 L
.988 .45328 L
.992 .45328 L
.996 .45279 L
1 .45211 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43556 L
.012 .42991 L
.016 .42804 L
.02 .42979 L
.024 .43045 L
.028 .42976 L
.032 .42955 L
.036 .42969 L
.04 .42977 L
.044 .42965 L
.048 .42961 L
.052 .42957 L
.056 .42957 L
.06 .42952 L
.064 .4295 L
.068 .42945 L
.072 .42943 L
.076 .42939 L
.08 .42937 L
.084 .42933 L
.088 .42932 L
.092 .42927 L
.096 .42925 L
.1 .4292 L
.104 .42917 L
.108 .42913 L
.112 .42911 L
.116 .42908 L
.12 .42906 L
.124 .42902 L
.128 .42899 L
.132 .42895 L
.136 .42892 L
.14 .42889 L
.144 .42886 L
.148 .42882 L
.152 .4288 L
.156 .42876 L
.16 .42874 L
.164 .4287 L
.168 .42867 L
.172 .42864 L
.176 .42861 L
.18 .42857 L
.184 .42855 L
.188 .42851 L
.192 .42848 L
.196 .42844 L
.2 .42841 L
Mistroke
.204 .42838 L
.208 .42836 L
.212 .42833 L
.216 .4283 L
.22 .42827 L
.224 .42823 L
.228 .42818 L
.232 .42815 L
.236 .42812 L
.24 .4281 L
.244 .42808 L
.248 .42805 L
.252 .42802 L
.256 .42798 L
.26 .42794 L
.264 .4279 L
.268 .42787 L
.272 .42783 L
.276 .42781 L
.28 .42779 L
.284 .42776 L
.288 .42773 L
.292 .4277 L
.296 .42766 L
.3 .42763 L
.304 .42759 L
.308 .42756 L
.312 .42752 L
.316 .42749 L
.32 .42746 L
.324 .42744 L
.328 .42741 L
.332 .42739 L
.336 .42737 L
.34 .42733 L
.344 .42729 L
.348 .42723 L
.352 .42719 L
.356 .42715 L
.36 .42713 L
.364 .42712 L
.368 .4271 L
.372 .42708 L
.376 .42706 L
.38 .42702 L
.384 .42697 L
.388 .42692 L
.392 .42687 L
.396 .42684 L
.4 .42681 L
Mistroke
.404 .4268 L
.408 .42678 L
.412 .42676 L
.416 .42674 L
.42 .42672 L
.424 .42669 L
.428 .42665 L
.432 .4266 L
.436 .42655 L
.44 .42652 L
.444 .4265 L
.448 .4265 L
.452 .42649 L
.456 .42649 L
.46 .4265 L
.464 .42652 L
.468 .42653 L
.472 .42652 L
.476 .42652 L
.48 .42653 L
.484 .42656 L
.488 .42663 L
.492 .42673 L
.496 .42684 L
.5 .42698 L
.504 .42716 L
.508 .42738 L
.512 .42762 L
.516 .42787 L
.52 .42815 L
.524 .42846 L
.528 .42885 L
.532 .42931 L
.536 .42984 L
.54 .43042 L
.544 .43106 L
.548 .43177 L
.552 .43256 L
.556 .43342 L
.56 .4343 L
.564 .4352 L
.568 .43613 L
.572 .43711 L
.576 .43817 L
.58 .43928 L
.584 .44039 L
.588 .44147 L
.592 .44253 L
.596 .44359 L
.6 .44468 L
Mistroke
.604 .44575 L
.608 .44676 L
.612 .44768 L
.616 .44853 L
.62 .44936 L
.624 .4502 L
.628 .45103 L
.632 .45181 L
.636 .45251 L
.64 .45317 L
.644 .45386 L
.648 .45465 L
.652 .45553 L
.656 .45644 L
.66 .45733 L
.664 .4582 L
.668 .45912 L
.672 .46014 L
.676 .46127 L
.68 .46248 L
.684 .4637 L
.688 .4649 L
.692 .46613 L
.696 .46748 L
.7 .46899 L
.704 .47068 L
.708 .47248 L
.712 .47435 L
.716 .47632 L
.72 .47843 L
.724 .48078 L
.728 .4834 L
.732 .48628 L
.736 .48933 L
.74 .49248 L
.744 .49566 L
.748 .49885 L
.752 .50206 L
.756 .50527 L
.76 .50844 L
.764 .51152 L
.768 .51446 L
.772 .51721 L
.776 .51978 L
.78 .52221 L
.784 .52459 L
.788 .52698 L
.792 .52946 L
.796 .53203 L
.8 .53466 L
Mistroke
.804 .53732 L
.808 .53999 L
.812 .54271 L
.816 .54554 L
.82 .5485 L
.824 .55156 L
.828 .55455 L
.832 .55732 L
.836 .55969 L
.84 .56163 L
.844 .56326 L
.848 .56477 L
.852 .56638 L
.856 .5682 L
.86 .57014 L
.864 .57204 L
.868 .57363 L
.872 .57477 L
.876 .57542 L
.88 .57569 L
.884 .57571 L
.888 .57561 L
.892 .57541 L
.896 .57507 L
.9 .57453 L
.904 .57377 L
.908 .57286 L
.912 .57196 L
.916 .57121 L
.92 .57077 L
.924 .57062 L
.928 .57075 L
.932 .57101 L
.936 .57135 L
.94 .57164 L
.944 .5719 L
.948 .57206 L
.952 .57218 L
.956 .57216 L
.96 .57205 L
.964 .57185 L
.968 .57159 L
.972 .5714 L
.976 .57133 L
.98 .57143 L
.984 .57174 L
.988 .572 L
.992 .57227 L
.996 .57215 L
1 .57184 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`05001oogoo001oo`030003Ool00`00Ool00006Ool01000Oomo
o`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomo
ogoo1@000goo0P0017oo0`0017oo0P0017oo0P000Woo0P0000Aoo`000000009oo`D000=oo`8000Io
o`008Woo00<007ooOol0E7oo0P0000=oo`0000000Woo00<007oo00003Woo000ROol3000AOol20000
0goo0000000E000YOol00`00Ool000020002Ool00`00Ool0000>Ool0029oof<000aoo`008Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00H007ooOomoo`00Ool>0003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`06001oogooOol007oo0`000Woo0P0037oo000ROol20010Ool2
000BOol00`00Oomoo`08Ool00`00Oomoo`0;Ool0029oo`03001oogoo041oo`8000moo`8000aoo`03
001oogoo00Yoo`008Woo0P00@goo00<007ooOol02goo0`006Goo000ROol20013Ool00`00Oomoo`0;
Ool00`00Oomoo`0IOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo04=o
o`03001oogoo00Aoo`04001oogooOol2000LOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00A7oo00<007ooOol00goo0`000Woo00<007ooOol06goo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8004Eoo`05001oogooOol00002Ool00`00Ool0
000NOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0A7oo
00<007ooOol00P000goo0P007Woo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8004Ioo`<002Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool20017Ool0
0`00Oomoo`0SOol000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P00
17oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2
001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo
0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03
001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006io
o`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`00
8Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@0
07ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
2Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03
001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Ao
o`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Ao
o`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<0
07ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Ao
o`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo
10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@0
07ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007oo
Ool017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<0
07ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool0
0`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P00
17oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
G@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool0
0`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool0
0`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P00
0Woo1@000Woo00<007ooOol0Bgoo3`0037oo000XOol00`00Oomoo`19Ool3000JOol002Qoo`03001o
ogoo04Moo`8001eoo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0AGoo
0`007Woo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo04=o
o`<0021oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`12
Ool2000ROol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00@Goo0`00
8goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo03ioo`<0
02Eoo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0jOol4000XOol0
015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo03Eoo`H002]oo`00:7oo00<007ooOol0
<7oo1@00<Goo000XOold000eOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo
0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007oo
Oomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool0
00]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomo
o`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo1000
0goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008
Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Ao
o`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Io
o`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000
Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol0
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`00
0Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool4
0003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000
Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<0
07ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo
00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P00
2Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Ao
o`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
01aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@0
07ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yo
o`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04
Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2
001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03
001oogoo079oo`005goo00<007ooOol00Woo>`00>Woo000GOol00`00Oomoo`02Ool2000iOol4000f
Ool001Moo`03001oogoo009oo`03001oogoo03]oo`D0039oo`005Woo0P0017oo0P00@Goo1000;Woo
000GOol00`00Oomoo`02Ool00`00Oomoo`14Ool3000[Ool001aoo`03001oogoo04Moo`8002Uoo`00
77oo0P00BGoo0P00:7oo000LOol00`00Oomoo`1:Ool2000VOol001aoo`8004aoo`8002Eoo`0077oo
00<007ooOol0CGoo00<007ooOol08Woo000LOol00`00Oomoo`1>Ool2000ROol000Yoo`<000Aoo`03
001oogoo009oo`<000=oo`80051oo`<0021oo`002goo00<007ooOol01goo00D007ooOomoo`00009o
o`03001oogoo055oo`8001moo`002goo00<007ooOol02goo00@007ooOol005Aoo`<001eoo`002goo
00<007ooOol02goo00<007ooOol00P00EGoo0`006goo000;Ool00`00Oomoo`07Ool40003Ool00`00
Oomoo`1FOol@000<Ool000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007oo
Ool01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(33066\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29931 m
.008 .29862 L
.012 .29957 L
.016 .29975 L
.02 .29923 L
.024 .29922 L
.028 .29945 L
.032 .29935 L
.036 .29921 L
.04 .2993 L
.044 .2994 L
.048 .29935 L
.052 .29924 L
.056 .29918 L
.06 .29919 L
.064 .29924 L
.068 .29929 L
.072 .29931 L
.076 .29926 L
.08 .29915 L
.084 .29908 L
.088 .29908 L
.092 .29915 L
.096 .29922 L
.1 .29923 L
.104 .29917 L
.108 .29908 L
.112 .29902 L
.116 .29901 L
.12 .29905 L
.124 .29911 L
.128 .29912 L
.132 .29907 L
.136 .299 L
.14 .29897 L
.144 .29898 L
.148 .29901 L
.152 .299 L
.156 .29897 L
.16 .29895 L
.164 .29893 L
.168 .29891 L
.172 .2989 L
.176 .29892 L
.18 .29894 L
.184 .29891 L
.188 .29885 L
.192 .29882 L
.196 .29884 L
.2 .29884 L
Mistroke
.204 .29881 L
.208 .29879 L
.212 .29883 L
.216 .29886 L
.22 .29883 L
.224 .29873 L
.228 .29866 L
.232 .29867 L
.236 .29871 L
.24 .29874 L
.244 .29877 L
.248 .2988 L
.252 .29876 L
.256 .29863 L
.26 .29848 L
.264 .29848 L
.268 .29864 L
.272 .2988 L
.276 .29879 L
.28 .29865 L
.284 .29852 L
.288 .29846 L
.292 .29844 L
.296 .29845 L
.3 .29855 L
.304 .29872 L
.308 .29879 L
.312 .29862 L
.316 .29831 L
.32 .29813 L
.324 .29823 L
.328 .29849 L
.332 .29868 L
.336 .29871 L
.34 .29862 L
.344 .29848 L
.348 .29826 L
.352 .29802 L
.356 .29795 L
.36 .29821 L
.364 .29867 L
.368 .29894 L
.372 .29878 L
.376 .29831 L
.38 .29792 L
.384 .29785 L
.388 .29806 L
.392 .29832 L
.396 .29853 L
.4 .29868 L
Mistroke
.404 .29872 L
.408 .29855 L
.412 .29819 L
.416 .29789 L
.42 .29796 L
.424 .29847 L
.428 .29909 L
.432 .29937 L
.436 .29916 L
.44 .29875 L
.444 .29855 L
.448 .29879 L
.452 .29935 L
.456 .29996 L
.46 .3005 L
.464 .30099 L
.468 .30142 L
.472 .30171 L
.476 .30177 L
.48 .30182 L
.484 .3023 L
.488 .30351 L
.492 .30524 L
.496 .30681 L
.5 .30765 L
.504 .30783 L
.508 .30802 L
.512 .30885 L
.516 .31029 L
.52 .31178 L
.524 .31288 L
.528 .3137 L
.532 .31468 L
.536 .31593 L
.54 .31693 L
.544 .31708 L
.548 .31647 L
.552 .31601 L
.556 .31653 L
.56 .31781 L
.564 .31864 L
.568 .31794 L
.572 .3159 L
.576 .31391 L
.58 .31322 L
.584 .31372 L
.588 .31407 L
.592 .31318 L
.596 .31136 L
.6 .31008 L
Mistroke
.604 .31035 L
.608 .31163 L
.612 .31229 L
.616 .31134 L
.62 .30965 L
.624 .30923 L
.628 .31131 L
.632 .31498 L
.636 .31795 L
.64 .31868 L
.644 .31788 L
.648 .31793 L
.652 .32069 L
.656 .32576 L
.66 .3309 L
.664 .33418 L
.668 .33592 L
.672 .33843 L
.676 .34396 L
.68 .35263 L
.684 .36226 L
.688 .37028 L
.692 .3759 L
.696 .38069 L
.7 .38697 L
.704 .39558 L
.708 .4049 L
.712 .41203 L
.716 .41492 L
.72 .41381 L
.724 .41073 L
.728 .40766 L
.732 .40506 L
.736 .40172 L
.74 .39621 L
.744 .38835 L
.748 .37973 L
.752 .37285 L
.756 .36961 L
.76 .37035 L
.764 .37395 L
.768 .37865 L
.772 .38301 L
.776 .38636 L
.78 .38865 L
.784 .39009 L
.788 .39087 L
.792 .39093 L
.796 .3899 L
.8 .38709 L
Mistroke
.804 .38182 L
.808 .37397 L
.812 .36454 L
.816 .3557 L
.82 .34997 L
.824 .34887 L
.828 .35161 L
.832 .35518 L
.836 .35548 L
.84 .34967 L
.844 .33773 L
.848 .32251 L
.852 .30833 L
.856 .29817 L
.86 .29249 L
.864 .28892 L
.868 .28449 L
.872 .27787 L
.876 .27042 L
.88 .26597 L
.884 .26784 L
.888 .27702 L
.892 .29078 L
.896 .30386 L
.9 .31138 L
.904 .31117 L
.908 .305 L
.912 .29771 L
.916 .29386 L
.92 .29611 L
.924 .30297 L
.928 .31007 L
.932 .31328 L
.936 .30921 L
.94 .29956 L
.944 .28757 L
.948 .27815 L
.952 .2756 L
.956 .27944 L
.96 .28919 L
.964 .29996 L
.968 .30858 L
.972 .31366 L
.976 .31327 L
.98 .31056 L
.984 .30523 L
.988 .299 L
.992 .293 L
.996 .28597 L
1 .28073 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .56229 m
.008 .57001 L
.012 .57264 L
.016 .57 L
.02 .56916 L
.024 .57 L
.028 .57033 L
.032 .57002 L
.036 .56994 L
.04 .57001 L
.044 .57007 L
.048 .57001 L
.052 .57002 L
.056 .57001 L
.06 .57003 L
.064 .57001 L
.068 .57003 L
.072 .57002 L
.076 .57003 L
.08 .57002 L
.084 .57003 L
.088 .57002 L
.092 .57002 L
.096 .57001 L
.1 .57002 L
.104 .57002 L
.108 .57003 L
.112 .57002 L
.116 .57003 L
.12 .57002 L
.124 .57002 L
.128 .57002 L
.132 .57002 L
.136 .57002 L
.14 .57002 L
.144 .57002 L
.148 .57003 L
.152 .57002 L
.156 .57003 L
.16 .57002 L
.164 .57002 L
.168 .57001 L
.172 .57002 L
.176 .57002 L
.18 .57002 L
.184 .57002 L
.188 .57002 L
.192 .57002 L
.196 .57002 L
.2 .57002 L
Mistroke
.204 .57002 L
.208 .57002 L
.212 .57002 L
.216 .57002 L
.22 .57001 L
.224 .57001 L
.228 .57002 L
.232 .57002 L
.236 .57003 L
.24 .57003 L
.244 .57002 L
.248 .57002 L
.252 .57001 L
.256 .57001 L
.26 .57001 L
.264 .57001 L
.268 .57002 L
.272 .57003 L
.276 .57003 L
.28 .57002 L
.284 .57002 L
.288 .57001 L
.292 .57 L
.296 .57 L
.3 .57001 L
.304 .57002 L
.308 .57002 L
.312 .57002 L
.316 .57002 L
.32 .57002 L
.324 .57002 L
.328 .57002 L
.332 .57001 L
.336 .57 L
.34 .57 L
.344 .57 L
.348 .57001 L
.352 .57002 L
.356 .57003 L
.36 .57003 L
.364 .57003 L
.368 .57002 L
.372 .57 L
.376 .56999 L
.38 .56998 L
.384 .56999 L
.388 .57 L
.392 .57001 L
.396 .57002 L
.4 .57002 L
Mistroke
.404 .57002 L
.408 .57 L
.412 .56998 L
.416 .56996 L
.42 .56994 L
.424 .56993 L
.428 .56992 L
.432 .56991 L
.436 .5699 L
.44 .56988 L
.444 .56986 L
.448 .56982 L
.452 .56975 L
.456 .56967 L
.46 .56959 L
.464 .56949 L
.468 .56939 L
.472 .56926 L
.476 .56912 L
.48 .56897 L
.484 .56879 L
.488 .56858 L
.492 .56832 L
.496 .568 L
.5 .56764 L
.504 .56725 L
.508 .56681 L
.512 .56634 L
.516 .56582 L
.52 .56525 L
.524 .56464 L
.528 .56399 L
.532 .56331 L
.536 .56256 L
.54 .56176 L
.544 .5609 L
.548 .56001 L
.552 .55913 L
.556 .55823 L
.56 .55733 L
.564 .55642 L
.568 .55552 L
.572 .55467 L
.576 .55386 L
.58 .55307 L
.584 .55228 L
.588 .55149 L
.592 .55074 L
.596 .55003 L
.6 .54939 L
Mistroke
.604 .54877 L
.608 .54815 L
.612 .54751 L
.616 .54687 L
.62 .54625 L
.624 .54564 L
.628 .545 L
.632 .5443 L
.636 .54352 L
.64 .54269 L
.644 .54185 L
.648 .541 L
.652 .54011 L
.656 .53913 L
.66 .53806 L
.664 .53692 L
.668 .53576 L
.672 .53459 L
.676 .53339 L
.68 .53207 L
.684 .53059 L
.688 .52896 L
.692 .52719 L
.696 .52531 L
.7 .52332 L
.704 .52117 L
.708 .51882 L
.712 .51628 L
.716 .51363 L
.72 .51095 L
.724 .50831 L
.728 .50573 L
.732 .5032 L
.736 .50071 L
.74 .49829 L
.744 .49599 L
.748 .49385 L
.752 .49188 L
.756 .49003 L
.76 .48821 L
.764 .48634 L
.768 .48435 L
.772 .48223 L
.776 .47999 L
.78 .47766 L
.784 .47528 L
.788 .47289 L
.792 .47052 L
.796 .4682 L
.8 .46597 L
Mistroke
.804 .4639 L
.808 .46203 L
.812 .46037 L
.816 .45891 L
.82 .45756 L
.824 .45624 L
.828 .45484 L
.832 .45336 L
.836 .45185 L
.84 .45047 L
.844 .44934 L
.848 .44857 L
.852 .44817 L
.856 .44805 L
.86 .44812 L
.864 .44829 L
.868 .44857 L
.872 .449 L
.876 .44962 L
.88 .45041 L
.884 .45125 L
.888 .45199 L
.892 .45247 L
.896 .45261 L
.9 .45246 L
.904 .45214 L
.908 .4518 L
.912 .45156 L
.916 .4514 L
.92 .45131 L
.924 .45117 L
.928 .45098 L
.932 .45074 L
.936 .45058 L
.94 .45059 L
.944 .45082 L
.948 .45125 L
.952 .45178 L
.956 .45223 L
.96 .45252 L
.964 .45251 L
.968 .4523 L
.972 .45187 L
.976 .45144 L
.98 .45103 L
.984 .45078 L
.988 .4507 L
.992 .45084 L
.996 .45114 L
1 .45164 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43011 L
.012 .43014 L
.016 .42993 L
.02 .42964 L
.024 .42978 L
.028 .42985 L
.032 .42979 L
.036 .42967 L
.04 .42969 L
.044 .42965 L
.048 .42963 L
.052 .42956 L
.056 .42956 L
.06 .42952 L
.064 .42951 L
.068 .42946 L
.072 .42944 L
.076 .42939 L
.08 .42937 L
.084 .42933 L
.088 .42931 L
.092 .42927 L
.096 .42925 L
.1 .4292 L
.104 .42918 L
.108 .42914 L
.112 .42912 L
.116 .42908 L
.12 .42906 L
.124 .42902 L
.128 .42899 L
.132 .42895 L
.136 .42892 L
.14 .42889 L
.144 .42886 L
.148 .42883 L
.152 .4288 L
.156 .42877 L
.16 .42874 L
.164 .4287 L
.168 .42867 L
.172 .42864 L
.176 .4286 L
.18 .42857 L
.184 .42854 L
.188 .42851 L
.192 .42849 L
.196 .42846 L
.2 .42842 L
Mistroke
.204 .42839 L
.208 .42835 L
.212 .42832 L
.216 .42829 L
.22 .42826 L
.224 .42823 L
.228 .4282 L
.232 .42817 L
.236 .42814 L
.24 .42811 L
.244 .42807 L
.248 .42804 L
.252 .428 L
.256 .42796 L
.26 .42793 L
.264 .42791 L
.268 .42789 L
.272 .42786 L
.276 .42783 L
.28 .42779 L
.284 .42775 L
.288 .42772 L
.292 .42768 L
.296 .42765 L
.3 .42762 L
.304 .4276 L
.308 .42757 L
.312 .42754 L
.316 .42751 L
.32 .42748 L
.324 .42745 L
.328 .42741 L
.332 .42737 L
.336 .42733 L
.34 .42729 L
.344 .42727 L
.348 .42724 L
.352 .42722 L
.356 .42721 L
.36 .42718 L
.364 .42715 L
.368 .4271 L
.372 .42705 L
.376 .427 L
.38 .42697 L
.384 .42695 L
.388 .42693 L
.392 .42692 L
.396 .4269 L
.4 .42688 L
Mistroke
.404 .42685 L
.408 .42681 L
.412 .42677 L
.416 .42673 L
.42 .42671 L
.424 .4267 L
.428 .42669 L
.432 .42669 L
.436 .4267 L
.44 .42672 L
.444 .42674 L
.448 .42676 L
.452 .42678 L
.456 .4268 L
.46 .42685 L
.464 .42692 L
.468 .42702 L
.472 .42714 L
.476 .4273 L
.48 .4275 L
.484 .42774 L
.488 .42801 L
.492 .42831 L
.496 .42863 L
.5 .42899 L
.504 .42942 L
.508 .42991 L
.512 .43046 L
.516 .43108 L
.52 .43175 L
.524 .43251 L
.528 .43334 L
.532 .43423 L
.536 .43516 L
.54 .43611 L
.544 .43708 L
.548 .43809 L
.552 .43915 L
.556 .44024 L
.56 .44133 L
.564 .44241 L
.568 .44349 L
.572 .44457 L
.576 .44565 L
.58 .44668 L
.584 .44764 L
.588 .44851 L
.592 .44933 L
.596 .45015 L
.6 .45096 L
Mistroke
.604 .45175 L
.608 .4525 L
.612 .4532 L
.616 .45391 L
.62 .45467 L
.624 .4555 L
.628 .45637 L
.632 .45723 L
.636 .4581 L
.64 .45902 L
.644 .46003 L
.648 .46115 L
.652 .46233 L
.656 .46352 L
.66 .4647 L
.664 .46594 L
.668 .46729 L
.672 .4688 L
.676 .47045 L
.68 .47218 L
.684 .47399 L
.688 .4759 L
.692 .47799 L
.696 .48033 L
.7 .48291 L
.704 .48567 L
.708 .48856 L
.712 .49155 L
.716 .49464 L
.72 .49787 L
.724 .50121 L
.728 .50458 L
.732 .50787 L
.736 .51097 L
.74 .51386 L
.744 .51656 L
.748 .51915 L
.752 .52166 L
.756 .52413 L
.76 .52655 L
.764 .52894 L
.768 .53132 L
.772 .53378 L
.776 .53636 L
.78 .53912 L
.784 .54204 L
.788 .54507 L
.792 .5481 L
.796 .55104 L
.8 .55381 L
Mistroke
.804 .55637 L
.808 .55873 L
.812 .56093 L
.816 .56298 L
.82 .56489 L
.824 .56664 L
.828 .56821 L
.832 .56962 L
.836 .57091 L
.84 .5722 L
.844 .57349 L
.848 .57477 L
.852 .57588 L
.856 .5766 L
.86 .57679 L
.864 .5764 L
.868 .57555 L
.872 .57451 L
.876 .57352 L
.88 .57278 L
.884 .57229 L
.888 .57196 L
.892 .57162 L
.896 .57121 L
.9 .57073 L
.904 .57034 L
.908 .57019 L
.912 .57041 L
.916 .57095 L
.92 .57169 L
.924 .57238 L
.928 .57288 L
.932 .57304 L
.936 .57291 L
.94 .57257 L
.944 .57214 L
.948 .57177 L
.952 .57152 L
.956 .57139 L
.96 .57141 L
.964 .57145 L
.968 .57158 L
.972 .5716 L
.976 .57158 L
.98 .5714 L
.984 .57112 L
.988 .57078 L
.992 .5705 L
.996 .57035 L
1 .57048 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`03001oogoo0080009oo`07001oogooOol007oo00001Woo00@0
07ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@0
07ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`<00004Ool007ooOol400000goo000000030003
Ool20006Ool0029oo`03001oogoo059oo`03001oo`0000Aoo`8000=oo`8000aoo`008Woo0P0057oo
500000=oo`00Ool09goo00D007ooOol007oo00800004Ool007oo0002Ool00`00Oomoo`0;Ool0029o
of<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00@007ooOol000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol03P000Woo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool20002Ool01000Ool007oo0P000Woo0`0000=o
o`00Ool02goo000ROol2000nOol00`00Oomoo`0@Ool00`00Oomoo`0IOol0029oo`03001oogoo03eo
o`<000moo`03001oogoo01Yoo`008Woo0P00@7oo00<007ooOol02goo00<007oo000077oo000ROol2
0010Ool00`00Oomoo`0;Ool3000LOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03
001oogoo041oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo01eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20012Ool00`00Oomoo`02Ool00`00Ool00003Ool0
0`00Oomoo`0MOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00@Woo
00<007ooOol00Woo00<007oo00000`0087oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo049oo`04001oogoo000VOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P00@goo00@007oo000002Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool20004Ool20014Ool00`00Oomoo`0VOol000]oo`8000Yoo`8000Aoo`03001oogoo009o
o`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@0
07ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=o
o`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol0
06ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001o
o`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo
001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo
001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]
Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00
K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1Y
Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0
JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Mo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Io
o`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo
0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`80
00Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Io
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001X
Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo
001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo0080
00]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`80
00Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009o
o`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007oo
Ool03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002
Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo
00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00
:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool0
1000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00
Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo
0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00
Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1V
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00
J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo06Io
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Io
o`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0BGoo4@0037oo000XOol00`00Oomo
o`16Ool3000MOol002Qoo`03001oogoo04Eoo`8001moo`004Goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo00<007ooOol0@goo0P008Goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo045oo`8002=oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`0oOol2000UOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00?Woo0`009Woo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo03]oo`<002Qoo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004
Ool00`00Oomoo`0hOol4000ZOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo039o
o`H002ioo`00:7oo00<007ooOol0;Goo1@00=7oo000XOola000hOol002Qoo`03001oogoo06Ioo`00
2goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009o
o`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo
000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007oo
Ool017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<0
00Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`80
00Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000
Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo
00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool0
1000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol0
0`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eo
o`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002
Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eo
o`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D0
00=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo
009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo
009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00
Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<0
07ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol0
00]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1b
Ool001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo>000?Goo000GOol0
0`00Oomoo`02Ool00`00Oomoo`0eOol4000iOol001Moo`03001oogoo009oo`03001oogoo03Qoo`D0
03Eoo`005Woo0P0017oo0P00?Woo1@00<7oo000GOol00`00Oomoo`02Ool00`00Oomoo`11Ool3000^
Ool001aoo`03001oogoo04Aoo`8002aoo`0077oo0P00Agoo0P00:Woo000LOol00`00Oomoo`17Ool2
000YOol001aoo`8004Uoo`8002Qoo`0077oo00<007ooOol0BWoo0P009Woo000LOol00`00Oomoo`1;
Ool2000UOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8004ioo`8002=oo`002goo00<007oo
Ool01goo00D007ooOomoo`00009oo`03001oogoo04ioo`80029oo`002goo00<007ooOol02goo00@0
07ooOol0055oo`<0021oo`002goo00<007ooOol02goo00<007ooOol00P00DWoo0`007Woo000;Ool0
0`00Oomoo`07Ool40003Ool00`00Oomoo`1DOolB000<Ool000Yoo`8000Uoo`03001oogoo00Aoo`03
001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(33233\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29672 m
.008 .29849 L
.012 .30028 L
.016 .30053 L
.02 .29914 L
.024 .29876 L
.028 .29948 L
.032 .29967 L
.036 .29931 L
.04 .2992 L
.044 .29935 L
.048 .29941 L
.052 .29933 L
.056 .29926 L
.06 .29926 L
.064 .29926 L
.068 .29926 L
.072 .29927 L
.076 .29928 L
.08 .29924 L
.084 .2992 L
.088 .29918 L
.092 .29918 L
.096 .29919 L
.1 .29919 L
.104 .29916 L
.108 .29914 L
.112 .29912 L
.116 .29913 L
.12 .29913 L
.124 .29912 L
.128 .29909 L
.132 .29904 L
.136 .299 L
.14 .29901 L
.144 .29907 L
.148 .29911 L
.152 .29908 L
.156 .29901 L
.16 .29893 L
.164 .2989 L
.168 .29891 L
.172 .29896 L
.176 .29902 L
.18 .29905 L
.184 .29898 L
.188 .29886 L
.192 .29878 L
.196 .29879 L
.2 .29887 L
Mistroke
.204 .29892 L
.208 .29893 L
.212 .29892 L
.216 .29887 L
.22 .29877 L
.224 .29868 L
.228 .29867 L
.232 .29876 L
.236 .29887 L
.24 .29888 L
.244 .29882 L
.248 .29874 L
.252 .29866 L
.256 .29859 L
.26 .29856 L
.264 .29863 L
.268 .29879 L
.272 .29889 L
.276 .29879 L
.28 .29857 L
.284 .29843 L
.288 .29845 L
.292 .29856 L
.296 .29866 L
.3 .29871 L
.304 .29872 L
.308 .29865 L
.312 .29848 L
.316 .2983 L
.32 .29829 L
.324 .29851 L
.328 .29875 L
.332 .29878 L
.336 .29856 L
.34 .29831 L
.344 .29821 L
.348 .29827 L
.352 .29839 L
.356 .29852 L
.36 .29868 L
.364 .29879 L
.368 .29867 L
.372 .29832 L
.376 .29798 L
.38 .29798 L
.384 .29838 L
.388 .29889 L
.392 .29913 L
.396 .29901 L
.4 .29875 L
Mistroke
.404 .29857 L
.408 .29856 L
.412 .29871 L
.416 .29901 L
.42 .29951 L
.424 .30008 L
.428 .30047 L
.432 .3005 L
.436 .30034 L
.44 .30041 L
.444 .30102 L
.448 .30209 L
.452 .3032 L
.456 .30397 L
.46 .30439 L
.464 .30477 L
.468 .30541 L
.472 .30635 L
.476 .30749 L
.48 .30874 L
.484 .31012 L
.488 .31157 L
.492 .31283 L
.496 .31362 L
.5 .3139 L
.504 .31413 L
.508 .3149 L
.512 .31637 L
.516 .31801 L
.52 .31902 L
.524 .31902 L
.528 .31838 L
.532 .31781 L
.536 .31763 L
.54 .31752 L
.544 .31701 L
.548 .31612 L
.552 .31536 L
.556 .31511 L
.56 .31503 L
.564 .31432 L
.568 .31267 L
.572 .31082 L
.576 .31 L
.58 .31074 L
.584 .31223 L
.588 .31304 L
.592 .31255 L
.596 .31161 L
.6 .31173 L
Mistroke
.604 .31354 L
.608 .31616 L
.612 .31812 L
.616 .31896 L
.62 .31976 L
.624 .32202 L
.628 .32607 L
.632 .33062 L
.636 .33401 L
.64 .33609 L
.644 .33856 L
.648 .34355 L
.652 .35155 L
.656 .36086 L
.66 .36908 L
.664 .37523 L
.668 .38062 L
.672 .38737 L
.676 .3962 L
.68 .40544 L
.684 .41225 L
.688 .41496 L
.692 .41435 L
.696 .41274 L
.7 .41175 L
.704 .41083 L
.708 .40785 L
.712 .40126 L
.716 .39182 L
.72 .38241 L
.724 .37606 L
.728 .37394 L
.732 .37483 L
.736 .37654 L
.74 .3778 L
.744 .37913 L
.748 .38194 L
.752 .38693 L
.756 .39299 L
.76 .39764 L
.764 .39858 L
.768 .39504 L
.772 .38818 L
.776 .38014 L
.78 .37288 L
.784 .36732 L
.788 .36333 L
.792 .36023 L
.796 .35735 L
.8 .35427 L
Mistroke
.804 .35079 L
.808 .34689 L
.812 .34255 L
.816 .33763 L
.82 .33169 L
.824 .32385 L
.828 .31341 L
.832 .30033 L
.836 .28617 L
.84 .27382 L
.844 .26658 L
.848 .26647 L
.852 .27271 L
.856 .28203 L
.86 .28994 L
.864 .29337 L
.868 .29232 L
.872 .28973 L
.876 .28978 L
.88 .29496 L
.884 .30435 L
.888 .31413 L
.892 .31927 L
.896 .31701 L
.9 .30811 L
.904 .2965 L
.908 .28767 L
.912 .28452 L
.916 .28757 L
.92 .29355 L
.924 .29832 L
.928 .29977 L
.932 .29714 L
.936 .29377 L
.94 .29209 L
.944 .29385 L
.948 .29901 L
.952 .30384 L
.956 .3067 L
.96 .30506 L
.964 .29967 L
.968 .29344 L
.972 .28791 L
.976 .28621 L
.98 .28771 L
.984 .29145 L
.988 .29627 L
.992 .30025 L
.996 .30353 L
1 .30599 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .56853 m
.008 .5694 L
.012 .56987 L
.016 .56977 L
.02 .56958 L
.024 .56949 L
.028 .56963 L
.032 .56964 L
.036 .56962 L
.04 .56957 L
.044 .56961 L
.048 .5696 L
.052 .56962 L
.056 .5696 L
.06 .56962 L
.064 .5696 L
.068 .56961 L
.072 .56959 L
.076 .56961 L
.08 .5696 L
.084 .56961 L
.088 .56961 L
.092 .56961 L
.096 .5696 L
.1 .56961 L
.104 .5696 L
.108 .56961 L
.112 .5696 L
.116 .56961 L
.12 .5696 L
.124 .56961 L
.128 .5696 L
.132 .56961 L
.136 .5696 L
.14 .56961 L
.144 .5696 L
.148 .56961 L
.152 .5696 L
.156 .56961 L
.16 .5696 L
.164 .5696 L
.168 .5696 L
.172 .5696 L
.176 .5696 L
.18 .56961 L
.184 .56961 L
.188 .56961 L
.192 .5696 L
.196 .5696 L
.2 .5696 L
Mistroke
.204 .5696 L
.208 .5696 L
.212 .5696 L
.216 .5696 L
.22 .5696 L
.224 .5696 L
.228 .5696 L
.232 .5696 L
.236 .5696 L
.24 .5696 L
.244 .56959 L
.248 .5696 L
.252 .5696 L
.256 .56961 L
.26 .56961 L
.264 .56961 L
.268 .5696 L
.272 .5696 L
.276 .56959 L
.28 .56959 L
.284 .56959 L
.288 .5696 L
.292 .5696 L
.296 .56961 L
.3 .56961 L
.304 .56961 L
.308 .5696 L
.312 .56959 L
.316 .56959 L
.32 .56959 L
.324 .56959 L
.328 .56959 L
.332 .5696 L
.336 .5696 L
.34 .5696 L
.344 .5696 L
.348 .5696 L
.352 .5696 L
.356 .56959 L
.36 .56958 L
.364 .56957 L
.368 .56957 L
.372 .56957 L
.376 .56958 L
.38 .56959 L
.384 .56959 L
.388 .56958 L
.392 .56956 L
.396 .56953 L
.4 .56951 L
Mistroke
.404 .56949 L
.408 .56947 L
.412 .56945 L
.416 .56943 L
.42 .5694 L
.424 .56936 L
.428 .5693 L
.432 .56922 L
.436 .56912 L
.44 .56901 L
.444 .56889 L
.448 .56874 L
.452 .56858 L
.456 .5684 L
.46 .56819 L
.464 .56795 L
.468 .56768 L
.472 .56735 L
.476 .56697 L
.48 .56655 L
.484 .56608 L
.488 .56556 L
.492 .565 L
.496 .56439 L
.5 .56375 L
.504 .56306 L
.508 .56234 L
.512 .56157 L
.516 .56076 L
.52 .55989 L
.524 .559 L
.528 .5581 L
.532 .5572 L
.536 .55629 L
.54 .55538 L
.544 .5545 L
.548 .55365 L
.552 .55285 L
.556 .55208 L
.56 .55133 L
.564 .55058 L
.568 .54987 L
.572 .54918 L
.576 .54854 L
.58 .54791 L
.584 .54727 L
.588 .54664 L
.592 .54602 L
.596 .54541 L
.6 .54478 L
Mistroke
.604 .54411 L
.608 .54337 L
.612 .54256 L
.616 .54171 L
.62 .54084 L
.624 .53995 L
.628 .53899 L
.632 .53796 L
.636 .53687 L
.64 .53573 L
.644 .53457 L
.648 .53336 L
.652 .53205 L
.656 .5306 L
.66 .52901 L
.664 .5273 L
.668 .52548 L
.672 .52354 L
.676 .52143 L
.68 .51912 L
.684 .51663 L
.688 .51404 L
.692 .5114 L
.696 .50878 L
.7 .50619 L
.704 .5036 L
.708 .50105 L
.712 .49859 L
.716 .49627 L
.72 .49414 L
.724 .49215 L
.728 .49024 L
.732 .48832 L
.736 .48637 L
.74 .48437 L
.744 .48234 L
.748 .48027 L
.752 .47811 L
.756 .47584 L
.76 .47346 L
.764 .471 L
.768 .46858 L
.772 .46628 L
.776 .46418 L
.78 .46228 L
.784 .46057 L
.788 .45899 L
.792 .45749 L
.796 .45606 L
.8 .45467 L
Mistroke
.804 .45333 L
.808 .45206 L
.812 .45087 L
.816 .44978 L
.82 .44883 L
.824 .44808 L
.828 .4476 L
.832 .44744 L
.836 .44762 L
.84 .44813 L
.844 .44884 L
.848 .4496 L
.852 .45027 L
.856 .45077 L
.86 .45109 L
.864 .45131 L
.868 .45153 L
.872 .45178 L
.876 .45204 L
.88 .4522 L
.884 .45214 L
.888 .45183 L
.892 .45132 L
.896 .45078 L
.9 .45037 L
.904 .45022 L
.908 .45033 L
.912 .45062 L
.916 .45096 L
.92 .45122 L
.924 .45135 L
.928 .45139 L
.932 .45136 L
.936 .45138 L
.94 .45138 L
.944 .45142 L
.948 .45138 L
.952 .45131 L
.956 .45119 L
.96 .4511 L
.964 .45112 L
.968 .45127 L
.972 .45152 L
.976 .45186 L
.98 .45213 L
.984 .45235 L
.988 .45237 L
.992 .45231 L
.996 .45208 L
1 .45183 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42441 L
.012 .4299 L
.016 .43176 L
.02 .42981 L
.024 .4292 L
.028 .42976 L
.032 .42998 L
.036 .4297 L
.04 .42962 L
.044 .42963 L
.048 .42965 L
.052 .42957 L
.056 .42956 L
.06 .42952 L
.064 .42951 L
.068 .42946 L
.072 .42944 L
.076 .42939 L
.08 .42937 L
.084 .42932 L
.088 .42931 L
.092 .42927 L
.096 .42925 L
.1 .42921 L
.104 .42918 L
.108 .42914 L
.112 .42912 L
.116 .42908 L
.12 .42905 L
.124 .42901 L
.128 .42899 L
.132 .42895 L
.136 .42893 L
.14 .4289 L
.144 .42887 L
.148 .42883 L
.152 .4288 L
.156 .42876 L
.16 .42873 L
.164 .4287 L
.168 .42868 L
.172 .42865 L
.176 .42862 L
.18 .42858 L
.184 .42854 L
.188 .42851 L
.192 .42848 L
.196 .42845 L
.2 .42842 L
Mistroke
.204 .42839 L
.208 .42836 L
.212 .42832 L
.216 .42829 L
.22 .42826 L
.224 .42823 L
.228 .4282 L
.232 .42817 L
.236 .42813 L
.24 .4281 L
.244 .42807 L
.248 .42804 L
.252 .42801 L
.256 .42798 L
.26 .42795 L
.264 .42793 L
.268 .42789 L
.272 .42785 L
.276 .42781 L
.28 .42777 L
.284 .42774 L
.288 .42772 L
.292 .4277 L
.296 .42767 L
.3 .42764 L
.304 .42761 L
.308 .42757 L
.312 .42753 L
.316 .42749 L
.32 .42746 L
.324 .42743 L
.328 .42741 L
.332 .42738 L
.336 .42735 L
.34 .42733 L
.344 .4273 L
.348 .42726 L
.352 .42723 L
.356 .42719 L
.36 .42715 L
.364 .42712 L
.368 .42709 L
.372 .42706 L
.376 .42705 L
.38 .42704 L
.384 .42703 L
.388 .427 L
.392 .42697 L
.396 .42693 L
.4 .4269 L
Mistroke
.404 .42689 L
.408 .42688 L
.412 .4269 L
.416 .42692 L
.42 .42696 L
.424 .427 L
.428 .42704 L
.432 .42708 L
.436 .42714 L
.44 .42722 L
.444 .42733 L
.448 .42747 L
.452 .42764 L
.456 .42785 L
.46 .42811 L
.464 .42841 L
.468 .42875 L
.472 .42913 L
.476 .42954 L
.48 .43001 L
.484 .43053 L
.488 .43112 L
.492 .43177 L
.496 .43249 L
.5 .43328 L
.504 .43414 L
.508 .43506 L
.512 .43603 L
.516 .43702 L
.52 .43804 L
.524 .43908 L
.528 .44014 L
.532 .44123 L
.536 .44231 L
.54 .44338 L
.544 .44444 L
.548 .44549 L
.552 .44654 L
.556 .44754 L
.56 .44848 L
.564 .44935 L
.568 .45016 L
.572 .45095 L
.576 .45172 L
.58 .45247 L
.584 .45318 L
.588 .4539 L
.592 .45465 L
.596 .45546 L
.6 .45631 L
Mistroke
.604 .45719 L
.608 .45807 L
.612 .45897 L
.616 .45993 L
.62 .46099 L
.624 .46213 L
.628 .46332 L
.632 .46453 L
.636 .46579 L
.64 .46713 L
.644 .46861 L
.648 .4702 L
.652 .47188 L
.656 .47364 L
.66 .47551 L
.664 .47756 L
.668 .47984 L
.672 .48235 L
.676 .48503 L
.68 .48784 L
.684 .49077 L
.688 .49383 L
.692 .49706 L
.696 .5004 L
.7 .50377 L
.704 .50705 L
.708 .51017 L
.712 .51313 L
.716 .51594 L
.72 .51865 L
.724 .52125 L
.728 .52371 L
.732 .52603 L
.736 .52828 L
.74 .53058 L
.744 .53303 L
.748 .53568 L
.752 .53851 L
.756 .54145 L
.76 .54442 L
.764 .54735 L
.768 .55022 L
.772 .55302 L
.776 .55571 L
.78 .55823 L
.784 .56052 L
.788 .56256 L
.792 .56436 L
.796 .56599 L
.8 .56753 L
Mistroke
.804 .56906 L
.808 .5706 L
.812 .57212 L
.816 .57353 L
.82 .57474 L
.824 .57565 L
.828 .57621 L
.832 .57642 L
.836 .57633 L
.84 .57598 L
.844 .5754 L
.848 .57461 L
.852 .57365 L
.856 .5726 L
.86 .57159 L
.864 .57081 L
.868 .57036 L
.872 .57032 L
.876 .57057 L
.88 .57096 L
.884 .57133 L
.888 .57158 L
.892 .57173 L
.896 .57191 L
.9 .57217 L
.904 .57257 L
.908 .57298 L
.912 .57321 L
.916 .57311 L
.92 .57262 L
.924 .57186 L
.928 .57107 L
.932 .57048 L
.936 .57032 L
.94 .57053 L
.944 .57105 L
.948 .57158 L
.952 .57196 L
.956 .57204 L
.96 .57186 L
.964 .57152 L
.968 .5712 L
.972 .57096 L
.976 .57093 L
.98 .57098 L
.984 .57114 L
.988 .57122 L
.992 .57129 L
.996 .57119 L
1 .57104 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`800003Ool007oo009oo`07001oogooOol007oo00001Woo00@0
07ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@0
07ooOomoo`D000=oo`8000Aoo`<000Aoo`8000=oo`<000Eoo`<0009oo`D000=oo`8000Ioo`008Woo
00<007ooOol0Cgoo00<007oo000017oo00<007ooOol00goo0P003Woo000ROol3000COolC000YOol0
0`00Ool0000200000goo001oo`03000017oo001oo`003Woo000ROomS000<Ool0029oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`04001oogoo0003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`h00003Ool007oo009oo`05001oogooOol00003Ool01@00
Oomoogoo00000Woo0P000goo0P000Woo00D007ooOomoo`0000=oo`03001oogoo00Yoo`008Woo0P00
>goo00<007ooOol047oo00<007ooOol077oo000ROol00`00Oomoo`0kOol2000@Ool00`00Oomoo`0L
Ool0029oo`8003eoo`03001oogoo00eoo`03001oogoo01eoo`008Woo0P00?Woo00<007ooOol02Woo
0P0087oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0mOol00`00Oomo
o`0:Ool00`00Oomoo`0OOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00?goo00<007ooOol00goo0`000Woo00<007ooOol087oo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`80041oo`05001oogooOol00002Ool00`00Ool0000SOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0?goo00D007ooOomoo`00
00=oo`8002=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20010Ool0
1000Oomoo`00:Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`80045oo`8002Yo
o`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]
Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:
Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0
029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00
0Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo
0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P00
0goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool0
1@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001o
ogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0
009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2
000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000
Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo1000
0goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000
Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
o`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=o
o`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool5
0003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qo
o`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo011o
o`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=o
o`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool20002Ool50002Ool0
0`00Oomoo`16OolD000<Ool002Qoo`03001oogoo04Aoo`<001moo`00:7oo00<007ooOol0@Woo0P00
8Woo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`10Ool3000SOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0?Woo0`009Goo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo03eoo`8002Moo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000lOol2000YOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0>Goo0`00:Woo000@Ool0
1000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo03Eoo`@002eoo`004Goo0P002Woo
0P0017oo00<007ooOol00Woo00<007ooOol0;goo1`00<7oo000XOol00`00Oomoo`0ZOol6000fOol0
02Qoobh003]oo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003
Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomo
o`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
1Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eo
o`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo
0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P00
17oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`00
2Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03
001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`00
0goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=
Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eo
o`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001o
ogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003
Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H0
07ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool0
1000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04
Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L0
07ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomo
o`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`00
0Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo
000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo
00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol0
00Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`00
2goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol0
0`00Oomoo`02Oole0010Ool001Moo`03001oogoo009oo`03001oogoo039oo`@003aoo`005goo00<0
07ooOol00Woo00<007ooOol0=Goo1P00=goo000FOol20004Ool2000kOol5000cOol001Moo`03001o
ogoo009oo`03001oogoo03moo`<0031oo`0077oo00<007ooOol0@Goo0`00;Woo000LOol20014Ool2
000]Ool001aoo`03001oogoo04Aoo`8002aoo`0077oo0P00Agoo00<007ooOol0:Goo000LOol00`00
Oomoo`17Ool2000YOol001aoo`03001oogoo04Qoo`<002Moo`002Woo0`0017oo00<007ooOol00Woo
0`000goo0P00Bgoo0P009Woo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0
Bgoo0`0097oo000;Ool00`00Oomoo`0;Ool01000Oomoo`00Cgoo0P008goo000;Ool00`00Oomoo`0;
Ool00`00Oomoo`02001?Ool3000QOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo055ooaD0
00aoo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(33400\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29908 m
.008 .30005 L
.012 .29941 L
.016 .2993 L
.02 .29957 L
.024 .29949 L
.028 .29936 L
.032 .29942 L
.036 .29945 L
.04 .29934 L
.044 .29928 L
.048 .29934 L
.052 .29941 L
.056 .29941 L
.06 .29936 L
.064 .2993 L
.068 .29924 L
.072 .29922 L
.076 .29925 L
.08 .2993 L
.084 .29931 L
.088 .29929 L
.092 .29924 L
.096 .29919 L
.1 .29917 L
.104 .29915 L
.108 .29917 L
.112 .29919 L
.116 .29919 L
.12 .29918 L
.124 .29915 L
.128 .29912 L
.132 .29909 L
.136 .29906 L
.14 .29905 L
.144 .29908 L
.148 .29911 L
.152 .2991 L
.156 .29906 L
.16 .29901 L
.164 .29899 L
.168 .29897 L
.172 .29898 L
.176 .299 L
.18 .29901 L
.184 .29899 L
.188 .29893 L
.192 .29889 L
.196 .2989 L
.2 .29894 L
Mistroke
.204 .29894 L
.208 .29889 L
.212 .29885 L
.216 .29884 L
.22 .29884 L
.224 .29883 L
.228 .29884 L
.232 .29886 L
.236 .29886 L
.24 .29879 L
.244 .29871 L
.248 .29869 L
.252 .29875 L
.256 .2988 L
.26 .2988 L
.264 .29876 L
.268 .29874 L
.272 .29871 L
.276 .29863 L
.28 .29855 L
.284 .29857 L
.288 .2987 L
.292 .29881 L
.296 .29877 L
.3 .29863 L
.304 .29851 L
.308 .29849 L
.312 .29852 L
.316 .29855 L
.32 .29861 L
.324 .29871 L
.328 .29874 L
.332 .29861 L
.336 .29839 L
.34 .2983 L
.344 .29846 L
.348 .29873 L
.352 .29887 L
.356 .2988 L
.36 .29865 L
.364 .29856 L
.368 .29857 L
.372 .29863 L
.376 .2988 L
.38 .29913 L
.384 .29953 L
.388 .29975 L
.392 .29967 L
.396 .29946 L
.4 .29949 L
Mistroke
.404 .29995 L
.408 .30071 L
.412 .30147 L
.416 .30203 L
.42 .30247 L
.424 .30289 L
.428 .30335 L
.432 .30389 L
.436 .30461 L
.44 .30568 L
.444 .30706 L
.448 .30847 L
.452 .30956 L
.456 .31026 L
.46 .31087 L
.464 .31179 L
.468 .31316 L
.472 .31472 L
.476 .31606 L
.48 .31698 L
.484 .31755 L
.488 .31799 L
.492 .31838 L
.496 .31866 L
.5 .3188 L
.504 .31896 L
.508 .31925 L
.512 .31947 L
.516 .31919 L
.52 .31808 L
.524 .31639 L
.528 .31485 L
.532 .3141 L
.536 .3141 L
.54 .31419 L
.544 .31375 L
.548 .31281 L
.552 .31198 L
.556 .31174 L
.56 .31198 L
.564 .31223 L
.568 .31234 L
.572 .31281 L
.576 .31425 L
.58 .31658 L
.584 .31885 L
.588 .32021 L
.592 .32081 L
.596 .32188 L
.6 .32461 L
Mistroke
.604 .32898 L
.608 .33373 L
.612 .33765 L
.616 .34086 L
.62 .34478 L
.624 .35068 L
.628 .35842 L
.632 .36657 L
.636 .37386 L
.64 .38046 L
.644 .38766 L
.648 .39627 L
.652 .4053 L
.656 .41249 L
.66 .41612 L
.664 .41649 L
.668 .41554 L
.672 .41489 L
.676 .41424 L
.68 .41163 L
.684 .40552 L
.688 .39655 L
.692 .38746 L
.696 .38109 L
.7 .37833 L
.704 .37777 L
.708 .37743 L
.712 .37678 L
.716 .37725 L
.72 .38072 L
.724 .38738 L
.728 .39498 L
.732 .40011 L
.736 .40054 L
.74 .39661 L
.744 .39061 L
.748 .38483 L
.752 .37994 L
.756 .37499 L
.76 .36883 L
.764 .36159 L
.768 .35487 L
.772 .35059 L
.776 .34938 L
.78 .34986 L
.784 .34936 L
.788 .34544 L
.792 .33715 L
.796 .32538 L
.8 .31207 L
Mistroke
.804 .29937 L
.808 .28871 L
.812 .28084 L
.816 .27584 L
.82 .27338 L
.824 .27303 L
.828 .27431 L
.832 .27707 L
.836 .28131 L
.84 .28705 L
.844 .29383 L
.848 .30041 L
.852 .30524 L
.856 .30721 L
.86 .30647 L
.864 .30472 L
.868 .30397 L
.872 .3054 L
.876 .30807 L
.88 .3091 L
.884 .30584 L
.888 .29718 L
.892 .28581 L
.896 .27661 L
.9 .27437 L
.904 .28152 L
.908 .29506 L
.912 .30947 L
.916 .31785 L
.92 .31633 L
.924 .30652 L
.928 .29298 L
.932 .2832 L
.936 .28122 L
.94 .28725 L
.944 .29781 L
.948 .30633 L
.952 .30927 L
.956 .30528 L
.96 .2972 L
.964 .29006 L
.968 .28714 L
.972 .29001 L
.976 .29653 L
.98 .30303 L
.984 .30611 L
.988 .30474 L
.992 .29958 L
.996 .2936 L
1 .28998 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57676 m
.008 .56913 L
.012 .56667 L
.016 .5692 L
.02 .57007 L
.024 .56916 L
.028 .56891 L
.032 .56918 L
.036 .5693 L
.04 .56917 L
.044 .56916 L
.048 .56918 L
.052 .56921 L
.056 .56919 L
.06 .5692 L
.064 .56918 L
.068 .56919 L
.072 .56918 L
.076 .56919 L
.08 .56918 L
.084 .5692 L
.088 .56919 L
.092 .56919 L
.096 .56918 L
.1 .56919 L
.104 .56918 L
.108 .56919 L
.112 .56919 L
.116 .56919 L
.12 .56918 L
.124 .56919 L
.128 .56919 L
.132 .56919 L
.136 .56919 L
.14 .56919 L
.144 .56918 L
.148 .56918 L
.152 .56918 L
.156 .56919 L
.16 .56919 L
.164 .56919 L
.168 .56919 L
.172 .56919 L
.176 .56918 L
.18 .56918 L
.184 .56918 L
.188 .56919 L
.192 .56919 L
.196 .56919 L
.2 .56919 L
Mistroke
.204 .56919 L
.208 .56919 L
.212 .56919 L
.216 .56918 L
.22 .56918 L
.224 .56918 L
.228 .56919 L
.232 .56919 L
.236 .56919 L
.24 .56918 L
.244 .56918 L
.248 .56919 L
.252 .56919 L
.256 .56919 L
.26 .56919 L
.264 .56918 L
.268 .56918 L
.272 .56918 L
.276 .56918 L
.28 .56918 L
.284 .56919 L
.288 .56919 L
.292 .56919 L
.296 .56918 L
.3 .56917 L
.304 .56917 L
.308 .56917 L
.312 .56917 L
.316 .56918 L
.32 .56919 L
.324 .56919 L
.328 .56919 L
.332 .56918 L
.336 .56917 L
.34 .56916 L
.344 .56916 L
.348 .56916 L
.352 .56916 L
.356 .56915 L
.36 .56915 L
.364 .56915 L
.368 .56914 L
.372 .56912 L
.376 .5691 L
.38 .56908 L
.384 .56905 L
.388 .56901 L
.392 .56896 L
.396 .56892 L
.4 .56888 L
Mistroke
.404 .56883 L
.408 .56875 L
.412 .56865 L
.416 .56853 L
.42 .56839 L
.424 .56822 L
.428 .56803 L
.432 .56781 L
.436 .56758 L
.44 .56732 L
.444 .56702 L
.448 .56667 L
.452 .56627 L
.456 .56582 L
.46 .56532 L
.464 .56477 L
.468 .56417 L
.472 .56353 L
.476 .56284 L
.48 .56212 L
.484 .56136 L
.488 .56057 L
.492 .55974 L
.496 .55887 L
.5 .55798 L
.504 .55708 L
.508 .55617 L
.512 .55526 L
.516 .55436 L
.52 .55349 L
.524 .55266 L
.528 .55187 L
.532 .55111 L
.536 .55038 L
.54 .54967 L
.544 .54899 L
.548 .54833 L
.552 .5477 L
.556 .54707 L
.56 .54644 L
.564 .5458 L
.568 .54516 L
.572 .54452 L
.576 .54387 L
.58 .54317 L
.584 .54241 L
.588 .5416 L
.592 .54073 L
.596 .53983 L
.6 .53888 L
Mistroke
.604 .53786 L
.608 .53678 L
.612 .53566 L
.616 .5345 L
.62 .5333 L
.624 .53203 L
.628 .53063 L
.632 .5291 L
.636 .52742 L
.64 .52563 L
.644 .52371 L
.648 .52164 L
.652 .5194 L
.656 .51699 L
.66 .51446 L
.664 .51186 L
.668 .50925 L
.672 .50663 L
.676 .50402 L
.68 .50143 L
.684 .49893 L
.688 .49657 L
.692 .49439 L
.696 .49235 L
.7 .49039 L
.704 .48845 L
.708 .4865 L
.712 .48455 L
.716 .48258 L
.72 .48057 L
.724 .47846 L
.728 .4762 L
.732 .47383 L
.736 .4714 L
.74 .46901 L
.744 .46673 L
.748 .4646 L
.752 .46259 L
.756 .46071 L
.76 .45897 L
.764 .45739 L
.768 .45597 L
.772 .45469 L
.776 .45348 L
.78 .45229 L
.784 .45109 L
.788 .44992 L
.792 .44887 L
.796 .44803 L
.8 .44748 L
Mistroke
.804 .44725 L
.808 .44733 L
.812 .44765 L
.816 .44816 L
.82 .44877 L
.824 .44944 L
.828 .4501 L
.832 .4507 L
.836 .4512 L
.84 .45156 L
.844 .45175 L
.848 .45179 L
.852 .4517 L
.856 .45154 L
.86 .45137 L
.864 .45121 L
.868 .45103 L
.872 .45081 L
.876 .45051 L
.88 .45018 L
.884 .44991 L
.888 .44981 L
.892 .44998 L
.896 .45041 L
.9 .45099 L
.904 .45152 L
.908 .45181 L
.912 .45179 L
.916 .45147 L
.92 .45105 L
.924 .45072 L
.928 .45063 L
.932 .45079 L
.936 .45111 L
.94 .45143 L
.944 .45163 L
.948 .45163 L
.952 .45151 L
.956 .45134 L
.96 .45126 L
.964 .45127 L
.968 .45139 L
.972 .45148 L
.976 .45155 L
.98 .4515 L
.984 .45143 L
.988 .45133 L
.992 .45135 L
.996 .45146 L
1 .45169 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .4288 L
.012 .42963 L
.016 .4302 L
.02 .42999 L
.024 .42976 L
.028 .42967 L
.032 .42977 L
.036 .42973 L
.04 .42969 L
.044 .42963 L
.048 .42964 L
.052 .42959 L
.056 .42957 L
.06 .42951 L
.064 .42949 L
.068 .42945 L
.072 .42944 L
.076 .4294 L
.08 .42938 L
.084 .42934 L
.088 .42931 L
.092 .42927 L
.096 .42924 L
.1 .4292 L
.104 .42918 L
.108 .42914 L
.112 .42912 L
.116 .42908 L
.12 .42906 L
.124 .42902 L
.128 .42899 L
.132 .42895 L
.136 .42892 L
.14 .42889 L
.144 .42886 L
.148 .42883 L
.152 .4288 L
.156 .42877 L
.16 .42874 L
.164 .4287 L
.168 .42868 L
.172 .42864 L
.176 .42861 L
.18 .42858 L
.184 .42854 L
.188 .42851 L
.192 .42848 L
.196 .42845 L
.2 .42842 L
Mistroke
.204 .42839 L
.208 .42836 L
.212 .42833 L
.216 .42829 L
.22 .42826 L
.224 .42823 L
.228 .4282 L
.232 .42817 L
.236 .42814 L
.24 .42811 L
.244 .42808 L
.248 .42805 L
.252 .42801 L
.256 .42798 L
.26 .42794 L
.264 .42791 L
.268 .42788 L
.272 .42785 L
.276 .42782 L
.28 .42779 L
.284 .42777 L
.288 .42774 L
.292 .4277 L
.296 .42766 L
.3 .42762 L
.304 .42759 L
.308 .42756 L
.312 .42753 L
.316 .42751 L
.32 .42749 L
.324 .42746 L
.328 .42743 L
.332 .42739 L
.336 .42735 L
.34 .42732 L
.344 .42729 L
.348 .42726 L
.352 .42724 L
.356 .42722 L
.36 .4272 L
.364 .42719 L
.368 .42717 L
.372 .42715 L
.376 .42714 L
.38 .42713 L
.384 .42712 L
.388 .42712 L
.392 .42713 L
.396 .42716 L
.4 .42721 L
Mistroke
.404 .42728 L
.408 .42736 L
.412 .42745 L
.416 .42755 L
.42 .42767 L
.424 .42782 L
.428 .428 L
.432 .42823 L
.436 .42851 L
.44 .42884 L
.444 .42922 L
.448 .42964 L
.452 .43011 L
.456 .43062 L
.46 .43119 L
.464 .43182 L
.468 .43251 L
.472 .43326 L
.476 .43408 L
.48 .43497 L
.484 .43592 L
.488 .43692 L
.492 .43794 L
.496 .43899 L
.5 .44006 L
.504 .44114 L
.508 .44222 L
.512 .44329 L
.516 .44435 L
.52 .44538 L
.524 .44641 L
.528 .44741 L
.532 .44838 L
.536 .44929 L
.54 .45014 L
.544 .45095 L
.548 .45173 L
.552 .45248 L
.556 .45321 L
.56 .45392 L
.564 .45464 L
.568 .4554 L
.572 .45621 L
.576 .45708 L
.58 .45798 L
.584 .45891 L
.588 .45988 L
.592 .46091 L
.596 .46201 L
.6 .46316 L
Mistroke
.604 .46436 L
.608 .4656 L
.612 .46692 L
.616 .46836 L
.62 .46992 L
.624 .47159 L
.628 .47334 L
.632 .4752 L
.636 .47719 L
.64 .47937 L
.644 .48178 L
.648 .48437 L
.652 .48713 L
.656 .49003 L
.66 .49308 L
.664 .49628 L
.668 .49959 L
.672 .50294 L
.676 .50622 L
.68 .50938 L
.684 .51239 L
.688 .51528 L
.692 .51806 L
.696 .52071 L
.7 .52319 L
.704 .52552 L
.708 .52777 L
.712 .53006 L
.716 .53249 L
.72 .53509 L
.724 .53784 L
.728 .54067 L
.732 .54355 L
.736 .54648 L
.74 .54943 L
.744 .55236 L
.748 .55515 L
.752 .55771 L
.756 .55998 L
.76 .56197 L
.764 .56377 L
.768 .56547 L
.772 .56714 L
.776 .56879 L
.78 .57037 L
.784 .57185 L
.788 .57319 L
.792 .57437 L
.796 .57536 L
.8 .57611 L
Mistroke
.804 .57654 L
.808 .5766 L
.812 .57628 L
.816 .57562 L
.82 .57472 L
.824 .57371 L
.828 .57276 L
.832 .57196 L
.836 .57135 L
.84 .57095 L
.844 .57071 L
.848 .57061 L
.852 .57063 L
.856 .57081 L
.86 .57116 L
.864 .57168 L
.868 .57225 L
.872 .57277 L
.876 .57306 L
.88 .57307 L
.884 .57279 L
.888 .57235 L
.892 .57191 L
.896 .57158 L
.9 .5714 L
.904 .57133 L
.908 .57128 L
.912 .57123 L
.916 .57116 L
.92 .57119 L
.924 .57134 L
.928 .57163 L
.932 .57195 L
.936 .57215 L
.94 .57211 L
.944 .57179 L
.948 .57125 L
.952 .5707 L
.956 .57027 L
.96 .57015 L
.964 .57027 L
.968 .57061 L
.972 .57092 L
.976 .57116 L
.98 .57117 L
.984 .57107 L
.988 .57085 L
.992 .57069 L
.996 .57058 L
1 .57063 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool2000017oo000007oo0P000Woo0P0000Aoo`000000009oo`D0
00=oo`8000Ioo`008Woo00<007ooOol0C7oo00@007ooOol000Aoo`80009oo`800003Ool007oo00mo
o`008Woo0P005Woo3@00:Woo00@007ooOol000Aoo`04001oo`00Ool2000017oo000007oo0P0037oo
000ROomS000<Ool0029oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOomoo`l00005Ool007ooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00002Ool20002Ool20003
Ool00`00Oomoo`0:Ool0029oo`80031oo`03001oogoo00Aoo`<0019oo`03001oogoo01ioo`008Woo
00<007ooOol0>7oo0P0047oo00<007ooOol07goo000ROol2000jOol2000>Ool2000QOol0029oo`80
03]oo`03001oogoo00]oo`03001oogoo025oo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0>goo00<007ooOol02Goo0P008goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8003aoo`03001oogoo00=oo`<0009oo`8002Aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000mOol00`00Oomoo`02Ool01P00Oomoo`00Ool0
02Eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0lOol0
1@00Oomoogoo00000goo0P009Woo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8003ioo`04001oo`00000[Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
0P00?Woo0`00;7oo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`80
00Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo
0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=o
o`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eo
o`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool0
0`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^
Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0
029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04
001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo
06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
00Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool0
0`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004
Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004
Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03
001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004
Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001o
ogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uo
o`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04
001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001o
ogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03
001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo
00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`80
00Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
oed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo
00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo
00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80
009oo`D0009oo`03001oogoo04AooaH000aoo`00:7oo00<007ooOol0@Woo0P008Woo000XOol00`00
Oomoo`10Ool2000TOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo03io
o`8002Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0l
Ool2000XOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
>Woo0P00:Woo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8003Yoo`80
02]oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0fOol3
000]Ool0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0<goo1000;goo
000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0]Ool6000cOol002Qoo`03001oogoo
02Qoo`D003Uoo`00:7oo:`00?Woo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001o
ogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo
000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007oo
Ool00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@0
00=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P00
27oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004
Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006
Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=o
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@0
07ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo
00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0
009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo
10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03
001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=o
o`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`80
00Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004
Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04
001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:
Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol0
17oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool0
0`00Oomoo`1bOol001Moo`03001oogoo009ooc8004=oo`005goo00<007ooOol00Woo00<007ooOol0
;goo1000?goo000GOol00`00Oomoo`02Ool00`00Oomoo`0cOol5000jOol001Ioo`8000Aoo`8003Qo
o`D003Ioo`005goo00<007ooOol00Woo00<007ooOol0?7oo0`00<goo000LOol00`00Oomoo`0nOol3
000aOol001aoo`80045oo`80031oo`0077oo00<007ooOol0@Goo0P00;goo000LOol20014Ool00`00
Oomoo`0/Ool001aoo`03001oogoo04Aoo`8002aoo`0077oo00<007ooOol0AWoo0P00:Woo000:Ool3
0004Ool00`00Oomoo`02Ool30003Ool20018Ool2000YOol000]oo`03001oogoo00Moo`05001oogoo
Ool00002Ool00`00Oomoo`19Ool2000WOol000]oo`03001oogoo00]oo`04001oogoo001<Ool2000V
Ool000]oo`03001oogoo00]oo`03001oogoo008004eoo`8002Aoo`002goo00<007ooOol01goo1000
0goo00<007ooOol0CWoo600037oo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]o
o`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(33567\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30223 m
.008 .30059 L
.012 .29859 L
.016 .29828 L
.02 .29974 L
.024 .30013 L
.028 .29941 L
.032 .2992 L
.036 .29949 L
.04 .29951 L
.044 .29933 L
.048 .29929 L
.052 .29941 L
.056 .29946 L
.06 .29942 L
.064 .29935 L
.068 .2993 L
.072 .29927 L
.076 .29929 L
.08 .29932 L
.084 .29934 L
.088 .29931 L
.092 .29926 L
.096 .29922 L
.1 .29923 L
.104 .29924 L
.108 .29925 L
.112 .29923 L
.116 .29919 L
.12 .29915 L
.124 .29914 L
.128 .29916 L
.132 .2992 L
.136 .29919 L
.14 .29914 L
.144 .29908 L
.148 .29905 L
.152 .29905 L
.156 .29907 L
.16 .2991 L
.164 .29912 L
.168 .29909 L
.172 .29903 L
.176 .29897 L
.18 .29895 L
.184 .29897 L
.188 .29899 L
.192 .299 L
.196 .29901 L
.2 .29901 L
Mistroke
.204 .29896 L
.208 .29887 L
.212 .29882 L
.216 .29885 L
.22 .29891 L
.224 .29895 L
.228 .29894 L
.232 .2989 L
.236 .29884 L
.24 .29876 L
.244 .29871 L
.248 .29874 L
.252 .29885 L
.256 .29893 L
.26 .29888 L
.264 .29876 L
.268 .29866 L
.272 .29864 L
.276 .29866 L
.28 .2987 L
.284 .29877 L
.288 .29885 L
.292 .29885 L
.296 .29871 L
.3 .29853 L
.304 .29847 L
.308 .29859 L
.312 .29876 L
.316 .29885 L
.32 .29884 L
.324 .29879 L
.328 .29874 L
.332 .29866 L
.336 .29862 L
.34 .29873 L
.344 .29901 L
.348 .2993 L
.352 .29938 L
.356 .29927 L
.36 .2992 L
.364 .29938 L
.368 .29978 L
.372 .30023 L
.376 .30062 L
.38 .30098 L
.384 .30134 L
.388 .30168 L
.392 .30201 L
.396 .30251 L
.4 .30335 L
Mistroke
.404 .30449 L
.408 .30565 L
.412 .30654 L
.416 .30714 L
.42 .30775 L
.424 .30868 L
.428 .30997 L
.432 .31142 L
.436 .31285 L
.44 .31418 L
.444 .31537 L
.448 .31631 L
.452 .31698 L
.456 .3175 L
.46 .31814 L
.464 .31905 L
.468 .32005 L
.472 .3207 L
.476 .3207 L
.48 .32011 L
.484 .31936 L
.488 .3188 L
.492 .31846 L
.496 .31809 L
.5 .31746 L
.504 .31657 L
.508 .31559 L
.512 .31462 L
.516 .31366 L
.52 .31273 L
.524 .3121 L
.528 .31213 L
.532 .31285 L
.536 .31382 L
.54 .31444 L
.544 .31448 L
.548 .31447 L
.552 .3152 L
.556 .31703 L
.56 .31956 L
.564 .32206 L
.568 .32422 L
.572 .32644 L
.576 .32927 L
.58 .33282 L
.584 .33664 L
.588 .34045 L
.592 .34468 L
.596 .35023 L
.6 .35754 L
Mistroke
.604 .36589 L
.608 .37397 L
.612 .38102 L
.616 .38756 L
.62 .39474 L
.624 .40292 L
.628 .41095 L
.632 .41694 L
.636 .41981 L
.64 .42006 L
.644 .41903 L
.648 .41739 L
.652 .41441 L
.656 .40897 L
.66 .40109 L
.664 .3926 L
.668 .38587 L
.672 .38208 L
.676 .3804 L
.68 .37919 L
.684 .37788 L
.688 .37772 L
.692 .38058 L
.696 .38683 L
.7 .3944 L
.704 .40001 L
.708 .40145 L
.712 .39903 L
.716 .39484 L
.72 .39064 L
.724 .3864 L
.728 .38068 L
.732 .37256 L
.736 .36316 L
.74 .35524 L
.744 .35118 L
.748 .351 L
.752 .35219 L
.756 .35137 L
.76 .34655 L
.764 .3381 L
.768 .32789 L
.772 .31762 L
.776 .3076 L
.78 .29725 L
.784 .28635 L
.788 .27607 L
.792 .26871 L
.796 .2663 L
.8 .26932 L
Mistroke
.804 .27613 L
.808 .28403 L
.812 .29056 L
.816 .29464 L
.82 .29674 L
.824 .29816 L
.828 .30026 L
.832 .30364 L
.836 .30791 L
.84 .31188 L
.844 .31385 L
.848 .31241 L
.852 .30717 L
.856 .29907 L
.86 .29063 L
.864 .28444 L
.868 .28246 L
.872 .28478 L
.876 .28957 L
.88 .29478 L
.884 .29844 L
.888 .30067 L
.892 .30235 L
.896 .30421 L
.9 .30629 L
.904 .30648 L
.908 .30347 L
.912 .29677 L
.916 .28841 L
.92 .28263 L
.924 .28237 L
.928 .28906 L
.932 .29985 L
.936 .30956 L
.94 .31358 L
.944 .3094 L
.948 .29936 L
.952 .28846 L
.956 .28217 L
.96 .28352 L
.964 .2916 L
.968 .30198 L
.972 .30958 L
.976 .31128 L
.98 .30622 L
.984 .29824 L
.988 .29066 L
.992 .28633 L
.996 .28772 L
1 .29113 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57128 m
.008 .56893 L
.012 .56808 L
.016 .56858 L
.02 .56899 L
.024 .56885 L
.028 .56873 L
.032 .56872 L
.036 .56881 L
.04 .56879 L
.044 .56878 L
.048 .56876 L
.052 .56878 L
.056 .56876 L
.06 .56878 L
.064 .56876 L
.068 .56878 L
.072 .56877 L
.076 .56878 L
.08 .56877 L
.084 .56878 L
.088 .56877 L
.092 .56877 L
.096 .56877 L
.1 .56878 L
.104 .56877 L
.108 .56878 L
.112 .56878 L
.116 .56878 L
.12 .56877 L
.124 .56877 L
.128 .56877 L
.132 .56877 L
.136 .56877 L
.14 .56878 L
.144 .56877 L
.148 .56877 L
.152 .56877 L
.156 .56877 L
.16 .56877 L
.164 .56877 L
.168 .56877 L
.172 .56877 L
.176 .56877 L
.18 .56877 L
.184 .56877 L
.188 .56877 L
.192 .56877 L
.196 .56877 L
.2 .56877 L
Mistroke
.204 .56877 L
.208 .56877 L
.212 .56877 L
.216 .56877 L
.22 .56877 L
.224 .56877 L
.228 .56877 L
.232 .56877 L
.236 .56877 L
.24 .56877 L
.244 .56877 L
.248 .56877 L
.252 .56877 L
.256 .56877 L
.26 .56877 L
.264 .56877 L
.268 .56877 L
.272 .56877 L
.276 .56877 L
.28 .56877 L
.284 .56877 L
.288 .56876 L
.292 .56876 L
.296 .56876 L
.3 .56876 L
.304 .56876 L
.308 .56877 L
.312 .56877 L
.316 .56876 L
.32 .56875 L
.324 .56874 L
.328 .56873 L
.332 .56873 L
.336 .56872 L
.34 .56872 L
.344 .56871 L
.348 .5687 L
.352 .56868 L
.356 .56865 L
.36 .56861 L
.364 .56857 L
.368 .56853 L
.372 .56847 L
.376 .56841 L
.38 .56834 L
.384 .56825 L
.388 .56814 L
.392 .56802 L
.396 .56787 L
.4 .5677 L
Mistroke
.404 .56749 L
.408 .56724 L
.412 .56697 L
.416 .56666 L
.42 .56632 L
.424 .56595 L
.428 .56553 L
.432 .56506 L
.436 .56454 L
.44 .56396 L
.444 .56333 L
.448 .56264 L
.452 .56192 L
.456 .56115 L
.46 .56036 L
.464 .55955 L
.468 .5587 L
.472 .55783 L
.476 .55694 L
.48 .55604 L
.484 .55514 L
.488 .55424 L
.492 .55336 L
.496 .5525 L
.5 .55168 L
.504 .5509 L
.508 .55016 L
.512 .54946 L
.516 .54878 L
.52 .54812 L
.524 .54748 L
.528 .54686 L
.532 .54624 L
.536 .54561 L
.54 .54496 L
.544 .54431 L
.548 .54364 L
.552 .54295 L
.556 .54222 L
.56 .54143 L
.564 .54059 L
.568 .53971 L
.572 .53877 L
.576 .53779 L
.58 .53673 L
.584 .53562 L
.588 .53444 L
.592 .53323 L
.596 .53195 L
.6 .5306 L
Mistroke
.604 .52913 L
.608 .52752 L
.612 .52578 L
.616 .5239 L
.62 .52188 L
.624 .51969 L
.628 .51733 L
.632 .51484 L
.636 .51227 L
.64 .50966 L
.644 .50704 L
.648 .50444 L
.652 .50185 L
.656 .49933 L
.66 .49692 L
.664 .49466 L
.668 .49254 L
.672 .49053 L
.676 .48858 L
.68 .48665 L
.684 .48473 L
.688 .48281 L
.692 .48084 L
.696 .47877 L
.7 .47655 L
.704 .47421 L
.708 .47181 L
.712 .46943 L
.716 .46714 L
.72 .46494 L
.724 .46285 L
.728 .46089 L
.732 .45908 L
.736 .45747 L
.74 .45605 L
.744 .45477 L
.748 .45355 L
.752 .45233 L
.756 .45112 L
.76 .44997 L
.764 .44895 L
.768 .44812 L
.772 .44751 L
.776 .44713 L
.78 .44698 L
.784 .44709 L
.788 .44747 L
.792 .44807 L
.796 .44883 L
.8 .44962 L
Mistroke
.804 .45033 L
.808 .45088 L
.812 .45124 L
.816 .45144 L
.82 .45152 L
.824 .45151 L
.828 .45144 L
.832 .4513 L
.836 .45107 L
.84 .45076 L
.844 .4504 L
.848 .45006 L
.852 .4498 L
.856 .44968 L
.86 .44974 L
.864 .44994 L
.868 .45024 L
.872 .45056 L
.876 .45084 L
.88 .45107 L
.884 .45122 L
.888 .4513 L
.892 .45129 L
.896 .45118 L
.9 .45096 L
.904 .45069 L
.908 .45044 L
.912 .45032 L
.916 .45041 L
.92 .45071 L
.924 .45112 L
.928 .45149 L
.932 .45167 L
.936 .45163 L
.94 .45139 L
.944 .45111 L
.948 .45091 L
.952 .45092 L
.956 .4511 L
.96 .45138 L
.964 .45159 L
.968 .45168 L
.972 .45159 L
.976 .45142 L
.98 .45122 L
.984 .45116 L
.988 .45116 L
.992 .45133 L
.996 .45148 L
1 .45165 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43528 L
.012 .4298 L
.016 .42809 L
.02 .42986 L
.024 .43045 L
.028 .42975 L
.032 .42955 L
.036 .4297 L
.04 .42977 L
.044 .42964 L
.048 .42961 L
.052 .42958 L
.056 .42958 L
.06 .42951 L
.064 .42949 L
.068 .42945 L
.072 .42944 L
.076 .4294 L
.08 .42938 L
.084 .42933 L
.088 .42931 L
.092 .42926 L
.096 .42924 L
.1 .42921 L
.104 .42918 L
.108 .42914 L
.112 .42912 L
.116 .42908 L
.12 .42906 L
.124 .42902 L
.128 .42899 L
.132 .42895 L
.136 .42892 L
.14 .42889 L
.144 .42886 L
.148 .42883 L
.152 .42881 L
.156 .42877 L
.16 .42874 L
.164 .4287 L
.168 .42867 L
.172 .42864 L
.176 .42861 L
.18 .42858 L
.184 .42855 L
.188 .42852 L
.192 .42849 L
.196 .42845 L
.2 .42842 L
Mistroke
.204 .42838 L
.208 .42835 L
.212 .42832 L
.216 .4283 L
.22 .42827 L
.224 .42824 L
.228 .4282 L
.232 .42817 L
.236 .42814 L
.24 .4281 L
.244 .42807 L
.248 .42804 L
.252 .42801 L
.256 .42798 L
.26 .42795 L
.264 .42792 L
.268 .42789 L
.272 .42786 L
.276 .42783 L
.28 .4278 L
.284 .42776 L
.288 .42773 L
.292 .42769 L
.296 .42766 L
.3 .42763 L
.304 .42761 L
.308 .42759 L
.312 .42756 L
.316 .42753 L
.32 .4275 L
.324 .42746 L
.328 .42743 L
.332 .4274 L
.336 .42739 L
.34 .42738 L
.344 .42737 L
.348 .42736 L
.352 .42735 L
.356 .42734 L
.36 .42734 L
.364 .42735 L
.368 .42738 L
.372 .42741 L
.376 .42746 L
.38 .42753 L
.384 .42762 L
.388 .42772 L
.392 .42786 L
.396 .42801 L
.4 .4282 L
Mistroke
.404 .42841 L
.408 .42866 L
.412 .42895 L
.416 .42929 L
.42 .42969 L
.424 .43016 L
.428 .43068 L
.432 .43125 L
.436 .43188 L
.44 .43255 L
.444 .43329 L
.448 .43407 L
.452 .43492 L
.456 .43583 L
.46 .4368 L
.464 .43782 L
.468 .43888 L
.472 .43995 L
.476 .44104 L
.48 .44212 L
.484 .4432 L
.488 .44427 L
.492 .44531 L
.496 .44632 L
.5 .44731 L
.504 .44827 L
.508 .4492 L
.512 .45008 L
.516 .45092 L
.52 .45172 L
.524 .45248 L
.528 .45323 L
.532 .45395 L
.536 .45467 L
.54 .4554 L
.544 .45617 L
.548 .45699 L
.552 .45787 L
.556 .4588 L
.56 .45978 L
.564 .4608 L
.568 .46188 L
.572 .46302 L
.576 .46422 L
.58 .46547 L
.584 .46677 L
.588 .46815 L
.592 .46964 L
.596 .47125 L
.6 .47298 L
Mistroke
.604 .47483 L
.608 .47681 L
.612 .47896 L
.616 .48129 L
.62 .4838 L
.624 .48649 L
.628 .48933 L
.632 .49232 L
.636 .49546 L
.64 .49873 L
.644 .50207 L
.648 .50538 L
.652 .5086 L
.656 .51169 L
.66 .51463 L
.664 .51744 L
.668 .52011 L
.672 .52262 L
.676 .525 L
.68 .52729 L
.684 .52959 L
.688 .53199 L
.692 .53452 L
.696 .53718 L
.7 .53992 L
.704 .54275 L
.708 .54566 L
.712 .54862 L
.716 .55158 L
.72 .55443 L
.724 .55705 L
.728 .55939 L
.732 .56147 L
.736 .56337 L
.74 .56516 L
.744 .56685 L
.748 .56845 L
.752 .56996 L
.756 .57138 L
.76 .57274 L
.764 .57402 L
.768 .57517 L
.772 .57607 L
.776 .57659 L
.78 .57669 L
.784 .57638 L
.788 .57576 L
.792 .57496 L
.796 .57409 L
.8 .57323 L
Mistroke
.804 .57242 L
.808 .57171 L
.812 .57115 L
.816 .57078 L
.82 .57062 L
.824 .57068 L
.828 .5709 L
.832 .57124 L
.836 .57162 L
.84 .57199 L
.844 .57232 L
.848 .57259 L
.852 .57278 L
.856 .57288 L
.86 .57283 L
.864 .57261 L
.868 .57222 L
.872 .57172 L
.876 .57123 L
.88 .57091 L
.884 .57085 L
.888 .57109 L
.892 .57151 L
.896 .57196 L
.9 .57221 L
.904 .57218 L
.908 .57186 L
.912 .57141 L
.916 .571 L
.92 .57079 L
.924 .57077 L
.928 .5709 L
.932 .57099 L
.936 .571 L
.94 .57087 L
.944 .57074 L
.948 .57069 L
.952 .57082 L
.956 .57107 L
.96 .57136 L
.964 .57148 L
.968 .57138 L
.972 .57103 L
.976 .57059 L
.98 .57018 L
.984 .57002 L
.988 .57001 L
.992 .57024 L
.996 .57042 L
1 .57052 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007oo0000009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo04Yoo`03001oo`0000Aoo`8000=oo`80009oo`80009oo`03001oogoo00]oo`008Woo0`00
5Goo00D007oo000007oo00D002Yoo`03001oogoo008000=oo`<0009oo`04001oo`00Ool2000017oo
001oo`0037oo000ROomS000<Ool0029oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0100000=oo`00
00001`000goo00@007ooOol000=oo`05001oogooOol00003Ool20002Ool01000Oomoogoo0P000Woo
00@007ooOomoo`<00003Ool00000009oo`03001oogoo00Yoo`008Woo0P00;7oo0P001goo0P004Woo
00<007ooOol08Goo000ROol00`00Oomoo`0fOol00`00Oomoo`0?Ool00`00Oomoo`0QOol0029oo`80
03Moo`8000moo`03001oogoo029oo`008Woo0P00>7oo0P0037oo0`0097oo000;Ool20004Ool00`00
Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0hOol00`00Oomoo`0:Ool00`00Oomoo`0TOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00>Goo00<007ooOol017oo0`00
0Woo00<007ooOol09Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
03Yoo`03001oogoo009oo`800003Ool007oo008002Moo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`0jOol00`00Oomoo`020002Ool3000XOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00>goo00@007ooOol000Aoo`03001oogoo
02Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2000lOol3000^Ool000]oo`80
00Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P00
0Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2
001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo
000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001o
ogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol0
0`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P00
0goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo
0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00
Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001o
ogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomo
ogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03
001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
4Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004
Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`80
00=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo
00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=o
o`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomo
o`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05
001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool0
1000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000
Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P00
17oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo
00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001o
ogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo0000
0`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Io
o`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol0
07oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool0
1000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool2
0004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P00
1Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomo
o`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomo
o`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool2
0003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007oo
Ool007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol0
07oo00@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0
@Goo6@0037oo000XOol00`00Oomoo`0oOol3000TOol002Qoo`03001oogoo03eoo`<002Ioo`004Goo
0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0>goo0`00:7oo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo03Uoo`<002Yoo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0hOol2000/Ool0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00=goo0P00;Woo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo03Aoo`<002moo`0047oo00@007ooOol0
00Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0`Ool4000bOol0015oo`8000Yoo`8000Aoo`03
001oogoo009oo`03001oogoo02Yoo`H003Ioo`00:7oo00<007ooOol09Goo1P00>goo000XOolY0010
Ool002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo
00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool0
1000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001o
ogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04
001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001o
ogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1b
Ool001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Ao
o`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007oo
Oomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol0
0goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol0
07oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol0
00Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol0
07oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P00
17oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=o
o`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D0
07ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo
008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qo
o`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<0
07ooOol00Woo<000AGoo000GOol00`00Oomoo`02Ool2000]Ool40012Ool001Moo`03001oogoo009o
o`03001oogoo031oo`D003eoo`005Woo0P0017oo0P00=Goo1@00>Goo000GOol00`00Oomoo`02Ool0
0`00Oomoo`0iOol3000fOol001aoo`03001oogoo03aoo`8003Aoo`0077oo0P00?Woo0`00<Woo000L
Ool00`00Oomoo`0oOol2000aOol001aoo`80045oo`80031oo`0077oo00<007ooOol0@Goo0P00;goo
000LOol00`00Oomoo`13Ool2000]Ool000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8004Eoo`<0
02]oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo04Ioo`8002Yoo`002goo
00<007ooOol02goo00@007ooOol004Uoo`8002Uoo`002goo00<007ooOol02goo00<007ooOol00P00
BWoo0`009Woo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1;OolK000<Ool000Yoo`8000Uo
o`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(33734\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30054 m
.008 .29924 L
.012 .29941 L
.016 .29939 L
.02 .29937 L
.024 .29956 L
.028 .2996 L
.032 .29949 L
.036 .29945 L
.04 .29948 L
.044 .29946 L
.048 .2994 L
.052 .29939 L
.056 .29942 L
.06 .29942 L
.064 .29938 L
.068 .29936 L
.072 .29936 L
.076 .29938 L
.08 .29938 L
.084 .29935 L
.088 .29929 L
.092 .29924 L
.096 .29924 L
.1 .29928 L
.104 .29933 L
.108 .29934 L
.112 .29929 L
.116 .29921 L
.12 .29914 L
.124 .29913 L
.128 .29918 L
.132 .29924 L
.136 .29927 L
.14 .29922 L
.144 .29914 L
.148 .29908 L
.152 .29906 L
.156 .29909 L
.16 .29912 L
.164 .29915 L
.168 .29913 L
.172 .29908 L
.176 .29902 L
.18 .29901 L
.184 .29902 L
.188 .29903 L
.192 .29902 L
.196 .29901 L
.2 .29901 L
Mistroke
.204 .29899 L
.208 .29895 L
.212 .29892 L
.216 .29893 L
.22 .29895 L
.224 .29894 L
.228 .29891 L
.232 .29889 L
.236 .29889 L
.24 .29887 L
.244 .29884 L
.248 .29883 L
.252 .29886 L
.256 .29888 L
.26 .29884 L
.264 .29877 L
.268 .29875 L
.272 .2988 L
.276 .29885 L
.28 .29885 L
.284 .29882 L
.288 .29881 L
.292 .2988 L
.296 .29878 L
.3 .29878 L
.304 .29886 L
.308 .29902 L
.312 .29914 L
.316 .29915 L
.32 .29909 L
.324 .29911 L
.328 .29927 L
.332 .29951 L
.336 .29976 L
.34 .30002 L
.344 .30033 L
.348 .30065 L
.352 .3009 L
.356 .30115 L
.36 .30157 L
.364 .30226 L
.368 .3031 L
.372 .30387 L
.376 .30452 L
.38 .30517 L
.384 .30601 L
.388 .30703 L
.392 .30817 L
.396 .30936 L
.4 .31062 L
Mistroke
.404 .3119 L
.408 .31308 L
.412 .31405 L
.416 .31496 L
.42 .31604 L
.424 .31737 L
.428 .31875 L
.432 .31982 L
.436 .32039 L
.44 .3206 L
.444 .32066 L
.448 .32071 L
.452 .32072 L
.456 .32064 L
.46 .32046 L
.464 .32016 L
.468 .31959 L
.472 .31861 L
.476 .31727 L
.48 .31592 L
.484 .31496 L
.488 .31454 L
.492 .31439 L
.496 .31415 L
.5 .31367 L
.504 .31318 L
.508 .31306 L
.512 .31351 L
.516 .31442 L
.52 .31558 L
.524 .31691 L
.528 .31848 L
.532 .32028 L
.536 .32215 L
.54 .32395 L
.544 .32588 L
.548 .32847 L
.552 .33214 L
.556 .33678 L
.56 .34174 L
.564 .34648 L
.568 .35115 L
.572 .35649 L
.576 .36316 L
.58 .3711 L
.584 .37956 L
.588 .38783 L
.592 .39574 L
.596 .40347 L
.6 .41081 L
Mistroke
.604 .41689 L
.608 .42072 L
.612 .42204 L
.616 .42156 L
.62 .42017 L
.624 .41792 L
.628 .41391 L
.632 .40742 L
.636 .39905 L
.64 .39075 L
.644 .38456 L
.648 .38118 L
.652 .37982 L
.656 .3794 L
.66 .37989 L
.664 .38225 L
.668 .38711 L
.672 .39351 L
.676 .39909 L
.68 .40173 L
.684 .40105 L
.688 .39837 L
.692 .39511 L
.696 .3913 L
.7 .38569 L
.704 .37737 L
.708 .36738 L
.712 .35849 L
.716 .35324 L
.72 .35192 L
.724 .35223 L
.728 .35109 L
.732 .3468 L
.736 .3399 L
.74 .33201 L
.744 .32391 L
.748 .31482 L
.752 .30349 L
.756 .29006 L
.76 .27695 L
.764 .26775 L
.768 .26491 L
.772 .26813 L
.776 .27469 L
.78 .28135 L
.784 .2864 L
.788 .29017 L
.792 .294 L
.796 .2987 L
.8 .30368 L
Mistroke
.804 .30758 L
.808 .30942 L
.812 .30935 L
.816 .3084 L
.82 .30744 L
.824 .30638 L
.828 .30429 L
.832 .30013 L
.836 .29401 L
.84 .28718 L
.844 .28193 L
.848 .28043 L
.852 .28364 L
.856 .29119 L
.86 .30076 L
.864 .30945 L
.868 .31421 L
.872 .31308 L
.876 .30661 L
.88 .297 L
.884 .28838 L
.888 .28417 L
.892 .28565 L
.896 .29166 L
.9 .29832 L
.904 .30237 L
.908 .30213 L
.912 .29877 L
.916 .29568 L
.92 .29533 L
.924 .29845 L
.928 .30275 L
.932 .3047 L
.936 .30205 L
.94 .29548 L
.944 .2885 L
.948 .28553 L
.952 .28923 L
.956 .29792 L
.96 .30746 L
.964 .31208 L
.968 .30834 L
.972 .29834 L
.976 .28578 L
.98 .27822 L
.984 .27989 L
.988 .28921 L
.992 .30411 L
.996 .3153 L
1 .3183 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .56131 m
.008 .5684 L
.012 .57079 L
.016 .56828 L
.02 .56756 L
.024 .56837 L
.028 .56865 L
.032 .56833 L
.036 .56827 L
.04 .56835 L
.044 .56841 L
.048 .56835 L
.052 .56836 L
.056 .56835 L
.06 .56837 L
.064 .56835 L
.068 .56837 L
.072 .56835 L
.076 .56837 L
.08 .56835 L
.084 .56836 L
.088 .56835 L
.092 .56836 L
.096 .56836 L
.1 .56836 L
.104 .56836 L
.108 .56836 L
.112 .56836 L
.116 .56836 L
.12 .56836 L
.124 .56836 L
.128 .56836 L
.132 .56836 L
.136 .56836 L
.14 .56836 L
.144 .56836 L
.148 .56836 L
.152 .56836 L
.156 .56836 L
.16 .56835 L
.164 .56836 L
.168 .56836 L
.172 .56836 L
.176 .56836 L
.18 .56836 L
.184 .56836 L
.188 .56836 L
.192 .56835 L
.196 .56835 L
.2 .56835 L
Mistroke
.204 .56836 L
.208 .56836 L
.212 .56836 L
.216 .56836 L
.22 .56836 L
.224 .56835 L
.228 .56835 L
.232 .56835 L
.236 .56835 L
.24 .56835 L
.244 .56836 L
.248 .56836 L
.252 .56836 L
.256 .56835 L
.26 .56835 L
.264 .56835 L
.268 .56835 L
.272 .56835 L
.276 .56835 L
.28 .56835 L
.284 .56834 L
.288 .56834 L
.292 .56834 L
.296 .56834 L
.3 .56833 L
.304 .56833 L
.308 .56832 L
.312 .5683 L
.316 .56829 L
.32 .56827 L
.324 .56826 L
.328 .56824 L
.332 .56822 L
.336 .56818 L
.34 .56814 L
.344 .56808 L
.348 .56802 L
.352 .56794 L
.356 .56785 L
.36 .56775 L
.364 .56763 L
.368 .5675 L
.372 .56733 L
.376 .56713 L
.38 .56691 L
.384 .56665 L
.388 .56635 L
.392 .56601 L
.396 .56564 L
.4 .56522 L
Mistroke
.404 .56476 L
.408 .56426 L
.412 .5637 L
.416 .5631 L
.42 .56245 L
.424 .56175 L
.428 .561 L
.432 .5602 L
.436 .55937 L
.44 .55852 L
.444 .55765 L
.448 .55678 L
.452 .55589 L
.456 .555 L
.46 .55412 L
.464 .55324 L
.468 .55238 L
.472 .55153 L
.476 .55072 L
.48 .54995 L
.484 .54923 L
.488 .54855 L
.492 .54789 L
.496 .54725 L
.5 .54663 L
.504 .54602 L
.508 .54541 L
.512 .54477 L
.516 .54412 L
.52 .54344 L
.524 .54274 L
.528 .54201 L
.532 .54125 L
.536 .54043 L
.54 .53957 L
.544 .53865 L
.548 .53769 L
.552 .53666 L
.556 .53558 L
.56 .53442 L
.564 .5332 L
.568 .53192 L
.572 .53057 L
.576 .52913 L
.58 .52757 L
.584 .52588 L
.588 .52405 L
.592 .52208 L
.596 .51996 L
.6 .51768 L
Mistroke
.604 .51525 L
.608 .51271 L
.612 .51009 L
.616 .50745 L
.62 .50482 L
.624 .50223 L
.628 .4997 L
.632 .49726 L
.636 .49496 L
.64 .49279 L
.644 .49074 L
.648 .48876 L
.652 .48682 L
.656 .4849 L
.66 .48298 L
.664 .48104 L
.668 .47902 L
.672 .47688 L
.676 .47461 L
.68 .47226 L
.684 .46988 L
.688 .46754 L
.692 .46528 L
.696 .46313 L
.7 .4611 L
.704 .45924 L
.708 .45759 L
.712 .45614 L
.716 .45483 L
.72 .45359 L
.724 .45238 L
.728 .45118 L
.732 .45004 L
.736 .44902 L
.74 .44815 L
.744 .44745 L
.748 .44695 L
.752 .44668 L
.756 .44668 L
.76 .44699 L
.764 .44755 L
.768 .44829 L
.772 .44906 L
.776 .44977 L
.78 .45036 L
.784 .45081 L
.788 .45114 L
.792 .45135 L
.796 .45141 L
.8 .45132 L
Mistroke
.804 .45109 L
.808 .45078 L
.812 .45043 L
.816 .45011 L
.82 .44985 L
.824 .44967 L
.828 .44955 L
.832 .44952 L
.836 .44959 L
.84 .44979 L
.844 .45009 L
.848 .45046 L
.852 .45081 L
.856 .45106 L
.86 .45113 L
.864 .45103 L
.868 .45078 L
.872 .45049 L
.876 .45025 L
.88 .45016 L
.884 .45022 L
.888 .4504 L
.892 .45061 L
.896 .4508 L
.9 .45091 L
.904 .45099 L
.908 .45104 L
.912 .45113 L
.916 .45122 L
.92 .45128 L
.924 .45123 L
.928 .45107 L
.932 .45082 L
.936 .45062 L
.94 .45055 L
.944 .45069 L
.948 .45096 L
.952 .45127 L
.956 .45145 L
.96 .45148 L
.964 .45132 L
.968 .45114 L
.972 .45102 L
.976 .45111 L
.98 .45136 L
.984 .4517 L
.988 .45193 L
.992 .45202 L
.996 .45181 L
1 .45155 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43209 L
.012 .43011 L
.016 .42925 L
.02 .42966 L
.024 .43002 L
.028 .42985 L
.032 .42971 L
.036 .42966 L
.04 .42971 L
.044 .42965 L
.048 .42962 L
.052 .42957 L
.056 .42957 L
.06 .42952 L
.064 .42951 L
.068 .42946 L
.072 .42944 L
.076 .42939 L
.08 .42937 L
.084 .42932 L
.088 .4293 L
.092 .42927 L
.096 .42925 L
.1 .42922 L
.104 .42919 L
.108 .42914 L
.112 .42911 L
.116 .42907 L
.12 .42905 L
.124 .42902 L
.128 .429 L
.132 .42896 L
.136 .42893 L
.14 .42889 L
.144 .42886 L
.148 .42883 L
.152 .4288 L
.156 .42877 L
.16 .42874 L
.164 .42871 L
.168 .42868 L
.172 .42864 L
.176 .42861 L
.18 .42858 L
.184 .42855 L
.188 .42852 L
.192 .42848 L
.196 .42845 L
.2 .42842 L
Mistroke
.204 .42839 L
.208 .42836 L
.212 .42833 L
.216 .4283 L
.22 .42827 L
.224 .42824 L
.228 .4282 L
.232 .42817 L
.236 .42814 L
.24 .4281 L
.244 .42808 L
.248 .42805 L
.252 .42802 L
.256 .42799 L
.26 .42795 L
.264 .42792 L
.268 .42789 L
.272 .42786 L
.276 .42783 L
.28 .4278 L
.284 .42777 L
.288 .42774 L
.292 .42772 L
.296 .42769 L
.3 .42767 L
.304 .42764 L
.308 .42762 L
.312 .42759 L
.316 .42757 L
.32 .42756 L
.324 .42755 L
.328 .42756 L
.332 .42757 L
.336 .42758 L
.34 .4276 L
.344 .42763 L
.348 .42766 L
.352 .42772 L
.356 .42779 L
.36 .42789 L
.364 .42802 L
.368 .42818 L
.372 .42836 L
.376 .42857 L
.38 .42881 L
.384 .4291 L
.388 .42943 L
.392 .4298 L
.396 .43023 L
.4 .43072 L
Mistroke
.404 .43127 L
.408 .43188 L
.412 .43255 L
.416 .43328 L
.42 .43407 L
.424 .43492 L
.428 .43581 L
.432 .43674 L
.436 .43772 L
.44 .43874 L
.444 .4398 L
.448 .44089 L
.452 .44199 L
.456 .44309 L
.46 .44418 L
.464 .44524 L
.468 .44626 L
.472 .44725 L
.476 .4482 L
.48 .44911 L
.484 .45 L
.488 .45086 L
.492 .45167 L
.496 .45246 L
.5 .45322 L
.504 .45396 L
.508 .45469 L
.512 .45543 L
.516 .45618 L
.52 .45696 L
.524 .4578 L
.528 .4587 L
.532 .45966 L
.536 .46067 L
.54 .46174 L
.544 .46287 L
.548 .46406 L
.552 .46531 L
.556 .46662 L
.56 .46798 L
.564 .46943 L
.568 .47098 L
.572 .47266 L
.576 .47446 L
.58 .47641 L
.584 .47851 L
.588 .48078 L
.592 .48324 L
.596 .48588 L
.6 .48869 L
Mistroke
.604 .49164 L
.608 .49472 L
.612 .49791 L
.616 .50119 L
.62 .50449 L
.624 .50775 L
.628 .5109 L
.632 .51393 L
.636 .51681 L
.64 .51953 L
.644 .5221 L
.648 .52452 L
.652 .52683 L
.656 .52911 L
.66 .53145 L
.664 .53391 L
.668 .5365 L
.672 .53921 L
.676 .54201 L
.68 .5449 L
.684 .54784 L
.688 .55078 L
.692 .55365 L
.696 .55633 L
.7 .55877 L
.704 .56097 L
.708 .56297 L
.712 .56482 L
.716 .56654 L
.72 .56812 L
.724 .56959 L
.728 .57099 L
.732 .57235 L
.736 .57366 L
.74 .57487 L
.744 .57584 L
.748 .57646 L
.752 .57668 L
.756 .57653 L
.76 .57608 L
.764 .5754 L
.768 .57457 L
.772 .57366 L
.776 .57273 L
.78 .5719 L
.784 .57127 L
.788 .5709 L
.792 .57078 L
.796 .57083 L
.8 .57098 L
Mistroke
.804 .57117 L
.808 .5714 L
.812 .57169 L
.816 .57204 L
.82 .57243 L
.824 .57278 L
.828 .57299 L
.832 .57301 L
.836 .57281 L
.84 .57244 L
.844 .572 L
.848 .57158 L
.852 .57127 L
.856 .57112 L
.86 .57112 L
.864 .57126 L
.868 .57147 L
.872 .57169 L
.876 .57186 L
.88 .57194 L
.884 .57189 L
.888 .5717 L
.892 .57139 L
.896 .57102 L
.9 .57069 L
.904 .57052 L
.908 .57055 L
.912 .5708 L
.916 .57114 L
.92 .57145 L
.924 .57156 L
.928 .57143 L
.932 .57111 L
.936 .57074 L
.94 .57047 L
.944 .57042 L
.948 .57052 L
.952 .57071 L
.956 .5708 L
.96 .57077 L
.964 .57055 L
.968 .57033 L
.972 .57015 L
.976 .57015 L
.98 .57027 L
.984 .57047 L
.988 .57058 L
.992 .57061 L
.996 .57041 L
1 .57024 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01P00Oomo
ogoo001oo`80009oo`04001oogoo0002Ool01@00Oomoogoo00000goo00<007oo00001Woo00@007oo
Ool000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007oo
Oomoo`D000=oo`8000Aoo`<00003Ool0000000<000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`00
8Woo00<007ooOol0Agoo00@007oo000000Aoo`80009oo`8000Aoo`03001oogoo008000ioo`008Woo
0P0067oo00<007ooOol0;Goo00<007ooOol00P000goo00@007oo001oo`D00004Ool00000Ool2000>
Ool0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00@007ooOol000=oo`05001oogooOol00003Ool50002Ool70002Ool01@00Oomoogoo0000
0Woo00D007ooOomoo`0000=oo`03001oogoo008000=oo`80009oo`03001oo`00008000=oo`05001o
ogooOol00002Ool2000<Ool0029oo`8002Qoo`D000Eoo`<0019oo`03001oogoo02=oo`008Woo00<0
07ooOol0<goo00<007ooOol03goo00<007ooOol097oo000ROol2000eOol00`00Oomoo`0=Ool2000V
Ool0029oo`8003Eoo`8000eoo`8002Moo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo
00<007ooOol0=Goo00<007ooOol02Woo00<007ooOol09goo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8003Moo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo02Mo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000gOol00`00Oomoo`02
Ool200001Goo001oogoo0000:Woo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo03Moo`05001oogooOol00003Ool3000ZOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P00>7oo0P000Woo00D007ooOomoo`0002aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool20004Ool2000iOol3000aOol000]oo`8000Yoo`8000Aoo`03001o
ogoo009oo`03001oogoo03Uoo`03001oogoo031oo`002goo0P0017oo00<007ooOol00goo0P000Woo
1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:
Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008
Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo
001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00
Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007oo
Ool000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`00
0goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomo
o`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogoo
Ool00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo
10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001o
ogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo
0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool0
0`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=o
o`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00
Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<0
00Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00
009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001o
ogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
0Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomo
o`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo
0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@0
07ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo
001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`00
0goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`80
00Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo
0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000
Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004
Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?
Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003
Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo
00@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00
Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0?goo
6`0037oo000XOol00`00Oomoo`0lOol3000WOol002Qoo`03001oogoo03]oo`8002Uoo`004Goo0P00
17oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0>Goo0P00:goo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo03Moo`8002eoo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0eOol3000^Ool0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00=Goo0P00<7oo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo035oo`<0039oo`0047oo00@007ooOol000Qo
o`04001oogoo0002Ool20004Ool00`00Oomoo`0]Ool5000dOol0015oo`8000Yoo`8000Aoo`03001o
ogoo009oo`03001oogoo02Qoo`H003Qoo`00:7oo00<007ooOol08Woo1P00?Woo000XOolV0013Ool0
02Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<0
07ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000
Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1Y
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001o
ogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo
009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo
000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol0
01aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`80
00Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomo
o`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05
001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo
000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo
10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qo
o`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo
00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo
0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`80
00Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007oo
Oomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo0080
07=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0
009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000F
Ool30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007oo
Ool00Woo;@00B7oo000GOol00`00Oomoo`02Ool00`00Oomoo`0YOol40015Ool001Moo`03001oogoo
009oo`03001oogoo02eoo`D0041oo`005Woo0P0017oo0P00<Woo1@00?7oo000GOol00`00Oomoo`02
Ool00`00Oomoo`0fOol3000iOol001aoo`03001oogoo03Uoo`8003Moo`0077oo0P00>goo0`00=Goo
000LOol00`00Oomoo`0lOol2000dOol001aoo`8003ioo`8003=oo`0077oo00<007ooOol0?goo00<0
07ooOol0<7oo000LOol00`00Oomoo`10Ool2000`Ool000Yoo`<000Aoo`03001oogoo009oo`<000=o
o`80049oo`<002ioo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo04=oo`80
02eoo`002goo00<007ooOol02goo00@007ooOol004Ioo`<002]oo`002goo00<007ooOol02goo00<0
07ooOol00P00Agoo0`00:Goo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`18OolN000<Ool0
00Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(33901\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29712 m
.008 .2985 L
.012 .30047 L
.016 .30071 L
.02 .29923 L
.024 .29889 L
.028 .29963 L
.032 .29981 L
.036 .29946 L
.04 .29936 L
.044 .29951 L
.048 .29954 L
.052 .29946 L
.056 .29943 L
.06 .29943 L
.064 .29941 L
.068 .29939 L
.072 .29939 L
.076 .2994 L
.08 .29941 L
.084 .29939 L
.088 .29935 L
.092 .29932 L
.096 .2993 L
.1 .2993 L
.104 .29932 L
.108 .29932 L
.112 .29931 L
.116 .29928 L
.12 .29924 L
.124 .29922 L
.128 .29923 L
.132 .29924 L
.136 .29923 L
.14 .29921 L
.144 .29917 L
.148 .29917 L
.152 .29917 L
.156 .29917 L
.16 .29915 L
.164 .29913 L
.168 .2991 L
.172 .29908 L
.176 .29908 L
.18 .29911 L
.184 .29913 L
.188 .2991 L
.192 .29903 L
.196 .29898 L
.2 .29897 L
Mistroke
.204 .29901 L
.208 .29904 L
.212 .29905 L
.216 .29903 L
.22 .29899 L
.224 .29893 L
.228 .29888 L
.232 .29888 L
.236 .29895 L
.24 .299 L
.244 .29899 L
.248 .29894 L
.252 .2989 L
.256 .29889 L
.26 .29888 L
.264 .29889 L
.268 .29895 L
.272 .29905 L
.276 .29911 L
.28 .29909 L
.284 .29905 L
.288 .29907 L
.292 .29919 L
.296 .29936 L
.3 .29953 L
.304 .29971 L
.308 .29992 L
.312 .3001 L
.316 .30024 L
.32 .30045 L
.324 .30083 L
.328 .30141 L
.332 .30204 L
.336 .30259 L
.34 .30309 L
.344 .30366 L
.348 .30437 L
.352 .3052 L
.356 .30615 L
.36 .30724 L
.364 .30846 L
.368 .30969 L
.372 .3108 L
.376 .31179 L
.38 .31286 L
.384 .31416 L
.388 .31562 L
.392 .31699 L
.396 .31813 L
.4 .31906 L
Mistroke
.404 .31987 L
.408 .32057 L
.412 .32114 L
.416 .32158 L
.42 .32196 L
.424 .32222 L
.428 .32218 L
.432 .32165 L
.436 .32074 L
.44 .31975 L
.444 .31898 L
.448 .31842 L
.452 .31785 L
.456 .31706 L
.46 .31608 L
.464 .31509 L
.468 .31427 L
.472 .3137 L
.476 .31348 L
.48 .3137 L
.484 .31443 L
.488 .31549 L
.492 .31656 L
.496 .31748 L
.5 .31837 L
.504 .31965 L
.508 .32162 L
.512 .32424 L
.516 .32715 L
.52 .33006 L
.524 .33301 L
.528 .33632 L
.532 .34031 L
.536 .34505 L
.54 .35048 L
.544 .35658 L
.548 .36348 L
.552 .37115 L
.556 .37925 L
.56 .38722 L
.564 .39476 L
.568 .40196 L
.572 .40912 L
.576 .41606 L
.58 .4219 L
.584 .4255 L
.588 .42625 L
.592 .42447 L
.596 .42097 L
.6 .41632 L
Mistroke
.604 .41057 L
.608 .40372 L
.612 .39639 L
.616 .3898 L
.62 .385 L
.624 .38223 L
.628 .38096 L
.632 .38083 L
.636 .38225 L
.64 .38594 L
.644 .39184 L
.648 .39837 L
.652 .40318 L
.656 .40464 L
.66 .40283 L
.664 .39904 L
.668 .39432 L
.672 .38857 L
.676 .38117 L
.68 .37229 L
.684 .36354 L
.688 .35707 L
.692 .35375 L
.696 .35244 L
.7 .35077 L
.704 .34709 L
.708 .34146 L
.712 .33498 L
.716 .32814 L
.72 .31995 L
.724 .30898 L
.728 .2952 L
.732 .28102 L
.736 .27017 L
.74 .26533 L
.744 .26647 L
.748 .27112 L
.752 .27654 L
.756 .28153 L
.76 .28672 L
.764 .29299 L
.768 .29995 L
.772 .30579 L
.776 .30867 L
.78 .30842 L
.784 .30681 L
.788 .30613 L
.792 .30728 L
.796 .30887 L
.8 .30824 L
Mistroke
.804 .30366 L
.808 .29569 L
.812 .28724 L
.816 .28164 L
.82 .2809 L
.824 .28484 L
.828 .29146 L
.832 .29854 L
.836 .30424 L
.84 .3078 L
.844 .30894 L
.848 .3075 L
.852 .30386 L
.856 .29851 L
.86 .29285 L
.864 .28841 L
.868 .28638 L
.872 .28756 L
.876 .29134 L
.88 .29681 L
.884 .30235 L
.888 .30623 L
.892 .30734 L
.896 .30499 L
.9 .30002 L
.904 .29432 L
.908 .29028 L
.912 .28979 L
.916 .29293 L
.92 .29788 L
.924 .30181 L
.928 .30256 L
.932 .29967 L
.936 .2953 L
.94 .29229 L
.944 .29245 L
.948 .29615 L
.952 .30027 L
.956 .3024 L
.96 .30107 L
.964 .29633 L
.968 .29263 L
.972 .29165 L
.976 .29485 L
.98 .30156 L
.984 .30576 L
.988 .30657 L
.992 .30182 L
.996 .29266 L
1 .28643 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .5642 m
.008 .56776 L
.012 .56912 L
.016 .5681 L
.02 .56762 L
.024 .56784 L
.028 .56807 L
.032 .56797 L
.036 .56792 L
.04 .56791 L
.044 .56797 L
.048 .56795 L
.052 .56795 L
.056 .56794 L
.06 .56796 L
.064 .56794 L
.068 .56795 L
.072 .56794 L
.076 .56795 L
.08 .56794 L
.084 .56795 L
.088 .56795 L
.092 .56796 L
.096 .56795 L
.1 .56795 L
.104 .56794 L
.108 .56794 L
.112 .56794 L
.116 .56795 L
.12 .56795 L
.124 .56795 L
.128 .56795 L
.132 .56795 L
.136 .56794 L
.14 .56794 L
.144 .56794 L
.148 .56795 L
.152 .56795 L
.156 .56795 L
.16 .56795 L
.164 .56795 L
.168 .56794 L
.172 .56794 L
.176 .56794 L
.18 .56794 L
.184 .56794 L
.188 .56794 L
.192 .56794 L
.196 .56794 L
.2 .56794 L
Mistroke
.204 .56794 L
.208 .56794 L
.212 .56794 L
.216 .56794 L
.22 .56794 L
.224 .56794 L
.228 .56794 L
.232 .56794 L
.236 .56794 L
.24 .56794 L
.244 .56794 L
.248 .56794 L
.252 .56793 L
.256 .56793 L
.26 .56793 L
.264 .56793 L
.268 .56792 L
.272 .56792 L
.276 .56792 L
.28 .56791 L
.284 .5679 L
.288 .56789 L
.292 .56787 L
.296 .56785 L
.3 .56783 L
.304 .5678 L
.308 .56777 L
.312 .56773 L
.316 .56768 L
.32 .56763 L
.324 .56756 L
.328 .56747 L
.332 .56737 L
.336 .56725 L
.34 .56711 L
.344 .56695 L
.348 .56676 L
.352 .56655 L
.356 .56631 L
.36 .56603 L
.364 .56571 L
.368 .56535 L
.372 .56494 L
.376 .56448 L
.38 .56399 L
.384 .56344 L
.388 .56286 L
.392 .56222 L
.396 .56154 L
.4 .56081 L
Mistroke
.404 .56004 L
.408 .55923 L
.412 .55838 L
.416 .55751 L
.42 .55663 L
.424 .55574 L
.428 .55484 L
.432 .55395 L
.436 .55307 L
.44 .55222 L
.444 .55139 L
.448 .55058 L
.452 .5498 L
.456 .54905 L
.46 .54834 L
.464 .54766 L
.468 .54701 L
.472 .54638 L
.476 .54578 L
.48 .54517 L
.484 .54457 L
.488 .54393 L
.492 .54327 L
.496 .54257 L
.5 .54183 L
.504 .54107 L
.508 .54026 L
.512 .53941 L
.516 .53851 L
.52 .53756 L
.524 .53656 L
.528 .53551 L
.532 .53438 L
.536 .53319 L
.54 .53192 L
.544 .53057 L
.548 .52914 L
.552 .52761 L
.556 .52596 L
.56 .52418 L
.564 .52226 L
.568 .52019 L
.572 .51798 L
.576 .51562 L
.58 .51313 L
.584 .51054 L
.588 .5079 L
.592 .50525 L
.596 .50263 L
.6 .50007 L
Mistroke
.604 .4976 L
.608 .49524 L
.612 .49302 L
.616 .49093 L
.62 .48894 L
.624 .48701 L
.628 .48511 L
.632 .48319 L
.636 .48125 L
.64 .47924 L
.644 .47714 L
.648 .47493 L
.652 .47264 L
.656 .47029 L
.66 .46796 L
.664 .46567 L
.668 .46348 L
.672 .46139 L
.676 .45946 L
.68 .45773 L
.684 .45619 L
.688 .45483 L
.692 .45359 L
.696 .4524 L
.7 .45125 L
.704 .45014 L
.708 .4491 L
.712 .44819 L
.716 .44741 L
.72 .44681 L
.724 .44643 L
.728 .44634 L
.732 .44656 L
.736 .44705 L
.74 .44773 L
.744 .44849 L
.748 .44921 L
.752 .44986 L
.756 .4504 L
.76 .45081 L
.764 .45108 L
.768 .45117 L
.772 .45108 L
.776 .45086 L
.78 .45057 L
.784 .45028 L
.788 .45 L
.792 .44974 L
.796 .4495 L
.8 .44929 L
Mistroke
.804 .44918 L
.808 .44921 L
.812 .44941 L
.816 .44975 L
.82 .45014 L
.824 .45049 L
.828 .4507 L
.832 .45076 L
.836 .45068 L
.84 .45051 L
.844 .45031 L
.848 .45013 L
.852 .45 L
.856 .44996 L
.86 .45002 L
.864 .45017 L
.868 .45039 L
.872 .45063 L
.876 .45084 L
.88 .45097 L
.884 .45099 L
.888 .45092 L
.892 .45078 L
.896 .45063 L
.9 .45053 L
.904 .45051 L
.908 .45056 L
.912 .45064 L
.916 .4507 L
.92 .45073 L
.924 .45072 L
.928 .45074 L
.932 .45081 L
.936 .45098 L
.94 .45118 L
.944 .45136 L
.948 .45142 L
.952 .45136 L
.956 .4512 L
.96 .45103 L
.964 .45092 L
.968 .45097 L
.972 .45108 L
.976 .45126 L
.98 .45133 L
.984 .45134 L
.988 .45126 L
.992 .45117 L
.996 .45116 L
1 .4513 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42505 L
.012 .43 L
.016 .43158 L
.02 .42975 L
.024 .42925 L
.028 .42979 L
.032 .42996 L
.036 .42969 L
.04 .42963 L
.044 .42965 L
.048 .42966 L
.052 .42958 L
.056 .42956 L
.06 .42951 L
.064 .4295 L
.068 .42945 L
.072 .42944 L
.076 .42939 L
.08 .42938 L
.084 .42933 L
.088 .42931 L
.092 .42927 L
.096 .42925 L
.1 .42921 L
.104 .42918 L
.108 .42914 L
.112 .42912 L
.116 .42908 L
.12 .42906 L
.124 .42902 L
.128 .429 L
.132 .42896 L
.136 .42893 L
.14 .42889 L
.144 .42886 L
.148 .42883 L
.152 .4288 L
.156 .42877 L
.16 .42874 L
.164 .42871 L
.168 .42868 L
.172 .42864 L
.176 .42861 L
.18 .42858 L
.184 .42855 L
.188 .42851 L
.192 .42848 L
.196 .42846 L
.2 .42843 L
Mistroke
.204 .4284 L
.208 .42836 L
.212 .42833 L
.216 .42829 L
.22 .42826 L
.224 .42823 L
.228 .4282 L
.232 .42818 L
.236 .42815 L
.24 .42812 L
.244 .42808 L
.248 .42805 L
.252 .42802 L
.256 .42799 L
.26 .42796 L
.264 .42793 L
.268 .42791 L
.272 .42789 L
.276 .42786 L
.28 .42784 L
.284 .42782 L
.288 .4278 L
.292 .42778 L
.296 .42777 L
.3 .42777 L
.304 .42777 L
.308 .42778 L
.312 .4278 L
.316 .42783 L
.32 .42787 L
.324 .42793 L
.328 .42801 L
.332 .42809 L
.336 .4282 L
.34 .42834 L
.344 .4285 L
.348 .42871 L
.352 .42895 L
.356 .42923 L
.36 .42956 L
.364 .42993 L
.368 .43034 L
.372 .4308 L
.376 .43132 L
.38 .43191 L
.384 .43256 L
.388 .43327 L
.392 .43404 L
.396 .43487 L
.4 .43575 L
Mistroke
.404 .43668 L
.408 .43766 L
.412 .43867 L
.416 .43971 L
.42 .44078 L
.424 .44186 L
.428 .44295 L
.432 .44404 L
.436 .44511 L
.44 .44616 L
.444 .44718 L
.448 .44816 L
.452 .44909 L
.456 .44997 L
.46 .45081 L
.464 .45162 L
.468 .45241 L
.472 .45317 L
.476 .45393 L
.48 .45468 L
.484 .45543 L
.488 .45619 L
.492 .45697 L
.496 .45778 L
.5 .45863 L
.504 .45955 L
.508 .46054 L
.512 .46159 L
.516 .46271 L
.52 .46389 L
.524 .46513 L
.528 .46644 L
.532 .4678 L
.536 .46924 L
.54 .47075 L
.544 .47238 L
.548 .47413 L
.552 .47602 L
.556 .47807 L
.56 .48028 L
.564 .48268 L
.568 .48526 L
.572 .48802 L
.576 .49094 L
.58 .49399 L
.584 .49714 L
.588 .50037 L
.592 .50365 L
.596 .50691 L
.6 .5101 L
Mistroke
.604 .51317 L
.608 .5161 L
.612 .51888 L
.616 .52152 L
.62 .52402 L
.624 .52639 L
.628 .52869 L
.632 .53099 L
.636 .53337 L
.64 .53586 L
.644 .53849 L
.648 .54124 L
.652 .54409 L
.656 .54702 L
.66 .54998 L
.664 .55288 L
.668 .55563 L
.672 .55817 L
.676 .56046 L
.68 .56252 L
.684 .56441 L
.688 .56615 L
.692 .56776 L
.696 .56926 L
.7 .57066 L
.704 .57202 L
.708 .57332 L
.712 .57453 L
.716 .57554 L
.72 .57626 L
.724 .57663 L
.728 .57664 L
.732 .57635 L
.736 .57579 L
.74 .57502 L
.744 .5741 L
.748 .57312 L
.752 .57221 L
.756 .57151 L
.76 .57106 L
.764 .57086 L
.768 .57083 L
.772 .57091 L
.776 .57106 L
.78 .5713 L
.784 .57162 L
.788 .57201 L
.792 .5724 L
.796 .57272 L
.8 .5729 L
Mistroke
.804 .57295 L
.808 .57286 L
.812 .57267 L
.816 .57238 L
.82 .57202 L
.824 .57162 L
.828 .57127 L
.832 .57104 L
.836 .571 L
.84 .57118 L
.844 .57149 L
.848 .57182 L
.852 .57204 L
.856 .57207 L
.86 .57189 L
.864 .57158 L
.868 .57123 L
.872 .57096 L
.876 .57081 L
.88 .5708 L
.884 .57088 L
.888 .57099 L
.892 .57108 L
.896 .57113 L
.9 .57115 L
.904 .57115 L
.908 .57113 L
.912 .57107 L
.916 .57093 L
.92 .57073 L
.924 .5705 L
.928 .57035 L
.932 .57033 L
.936 .57049 L
.94 .57073 L
.944 .57095 L
.948 .57098 L
.952 .57078 L
.956 .57038 L
.96 .56997 L
.964 .56968 L
.968 .5697 L
.972 .5699 L
.976 .57027 L
.98 .57049 L
.984 .57051 L
.988 .57026 L
.992 .5699 L
.996 .56957 L
1 .56951 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`020002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007oo
Ool000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007oo
Oomoo`D000=oo`8000Aoo`@000=oo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<0
07ooOol0A7oo00@007ooOol000Aoo`8000=oo`8000aoo`03001oogoo00Yoo`008Woo0P00AGoo00D0
07ooOomoo`0000=oo`03001oo`00009oo`<00003Ool0000000<00005Ool00000Ool0000=Ool0029o
of<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00@007ooOol000=oo`04001oogooOol50003Ool700000goo001oo`02Ool01@00Oomoogoo00000Woo
00D007ooOomoo`0000=oo`80009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`03001oogoo00Yoo`008Woo0P009Woo10001Goo0P004goo00<007ooOol09Woo000R
Ool00`00Oomoo`0`Ool2000AOol00`00Oomoo`0VOol0029oo`80039oo`03001oogoo00ioo`03001o
ogoo02Moo`008Woo0P00<goo00<007ooOol02goo0P00:Woo000;Ool20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool00`00Oomoo`0cOol00`00Oomoo`0:Ool00`00Oomoo`0YOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00=7oo00<007ooOol01Goo00D007ooOomoo`00
02aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000eOol00`00Oomo
o`02Ool30003Ool00`00Oomoo`0ZOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0=7oo00<007ooOol00Woo00H007ooOol007oo000]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00=Goo0P000Woo00<007ooOol00Woo00<007oo
Ool0;7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8003Ioo`@003=oo`002goo
0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0=Woo0P00=7oo000;Ool20004Ool00`00Oomo
o`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]
Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:
Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0
029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00
0Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo
0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P00
0goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool0
1@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001o
ogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0
009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2
000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000
Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo1000
0goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000
Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
o`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=o
o`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool5
0003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qo
o`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo011o
o`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=o
o`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool20002Ool50002Ool0
0`00Oomoo`0lOolN000<Ool002Qoo`03001oogoo03Yoo`<002Uoo`00:7oo00<007ooOol0>7oo0P00
;7oo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0fOol3000]Ool0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0=7oo0`00;goo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo03=oo`80035oo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000bOol3000bOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0;Woo1000=7oo000@Ool0
1000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo02Yoo`D003Moo`004Goo0P002Woo
0P0017oo00<007ooOol00Woo00<007ooOol09Goo1P00>goo000XOol00`00Oomoo`0OOol60011Ool0
02Qoob<004Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003
Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomo
o`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
1Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eo
o`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo
0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P00
17oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`00
2Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03
001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`00
0goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=
Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eo
o`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001o
ogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003
Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H0
07ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool0
1000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04
Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L0
07ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomo
o`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`00
0Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo
000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo
00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol0
00Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`00
2goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo
000GOol00`00Oomoo`02OolZ001;Ool001Moo`03001oogoo009oo`03001oogoo02Ioo`D004Moo`00
5goo00<007ooOol00Woo00<007ooOol0:Woo1@00@goo000FOol20004Ool2000_Ool6000nOol001Mo
o`03001oogoo009oo`03001oogoo03=oo`<003aoo`0077oo00<007ooOol0=Woo0`00>Goo000LOol2
000iOol2000hOol001aoo`03001oogoo03Uoo`8003Moo`0077oo0P00>goo0P00=Woo000LOol00`00
Oomoo`0lOol00`00Oomoo`0cOol001aoo`03001oogoo03eoo`<0039oo`002Woo0`0017oo00<007oo
Ool00Woo0`000goo0P00@7oo0P00<Goo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<0
07ooOol0@7oo0P00<7oo000;Ool00`00Oomoo`0;Ool01000Oomoo`00A7oo0P00;Woo000;Ool00`00
Oomoo`0;Ool00`00Oomoo`020014Ool3000KOol00`00Oomoo`02000<Ool000]oo`03001oogoo00Mo
o`@000=oo`03001oogoo04Iooa/00004Ool00000000=Ool000Yoo`8000Uoo`03001oogoo00Aoo`03
001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(34068\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .2982 m
.008 .29975 L
.012 .29992 L
.016 .29995 L
.02 .29966 L
.024 .29939 L
.028 .29948 L
.032 .29961 L
.036 .29958 L
.04 .29949 L
.044 .2995 L
.048 .29954 L
.052 .29952 L
.056 .29949 L
.06 .29947 L
.064 .29947 L
.068 .29945 L
.072 .29942 L
.076 .2994 L
.08 .29939 L
.084 .29941 L
.088 .29942 L
.092 .29942 L
.096 .29939 L
.1 .29935 L
.104 .29931 L
.108 .29928 L
.112 .29929 L
.116 .29932 L
.12 .29935 L
.124 .29934 L
.128 .2993 L
.132 .29925 L
.136 .2992 L
.14 .29918 L
.144 .29919 L
.148 .29923 L
.152 .29926 L
.156 .29926 L
.16 .29921 L
.164 .29914 L
.168 .2991 L
.172 .29909 L
.176 .29911 L
.18 .29915 L
.184 .29918 L
.188 .29916 L
.192 .29909 L
.196 .29903 L
.2 .29901 L
Mistroke
.204 .29905 L
.208 .29908 L
.212 .29909 L
.216 .29908 L
.22 .29905 L
.224 .29902 L
.228 .29899 L
.232 .29901 L
.236 .29907 L
.24 .29913 L
.244 .29914 L
.248 .29912 L
.252 .29913 L
.256 .29919 L
.26 .29927 L
.264 .29936 L
.268 .29947 L
.272 .29962 L
.276 .29979 L
.28 .29993 L
.284 .30009 L
.288 .30034 L
.292 .3007 L
.296 .30111 L
.3 .30152 L
.304 .30195 L
.308 .30248 L
.312 .30309 L
.316 .30376 L
.32 .3045 L
.324 .30539 L
.328 .30641 L
.332 .30746 L
.336 .30847 L
.34 .30948 L
.344 .31063 L
.348 .31195 L
.352 .31335 L
.356 .31471 L
.36 .31599 L
.364 .31722 L
.368 .31837 L
.372 .31938 L
.376 .32027 L
.38 .32112 L
.384 .32197 L
.388 .32269 L
.392 .32305 L
.396 .32301 L
.4 .3227 L
Mistroke
.404 .32231 L
.408 .32188 L
.412 .32134 L
.416 .3206 L
.42 .31972 L
.424 .31877 L
.428 .31775 L
.432 .3167 L
.436 .31574 L
.44 .3151 L
.444 .31487 L
.448 .31492 L
.452 .31501 L
.456 .31505 L
.46 .31526 L
.464 .31593 L
.468 .31717 L
.472 .31885 L
.476 .32077 L
.48 .32281 L
.484 .32497 L
.488 .32728 L
.492 .32978 L
.496 .33258 L
.5 .33594 L
.504 .34012 L
.508 .34519 L
.512 .35089 L
.516 .35689 L
.52 .36311 L
.524 .36978 L
.528 .37723 L
.532 .38549 L
.536 .39414 L
.54 .40252 L
.544 .41013 L
.548 .41667 L
.552 .42196 L
.556 .42568 L
.56 .42746 L
.564 .42714 L
.568 .42492 L
.572 .42114 L
.576 .41601 L
.58 .40953 L
.584 .40194 L
.588 .3941 L
.592 .38743 L
.596 .38316 L
.6 .38166 L
Mistroke
.604 .38238 L
.608 .38454 L
.612 .38777 L
.616 .39204 L
.62 .39704 L
.624 .40175 L
.628 .40477 L
.632 .40518 L
.636 .40306 L
.64 .39907 L
.644 .39359 L
.648 .38646 L
.652 .37766 L
.656 .36814 L
.66 .35982 L
.664 .35437 L
.668 .35192 L
.672 .35082 L
.676 .34884 L
.68 .34474 L
.684 .33872 L
.688 .33145 L
.692 .32294 L
.696 .31245 L
.7 .29971 L
.704 .28608 L
.708 .27444 L
.712 .26745 L
.716 .26583 L
.72 .26817 L
.724 .27232 L
.728 .2772 L
.732 .28309 L
.736 .29052 L
.74 .29874 L
.744 .30557 L
.748 .30899 L
.752 .30883 L
.756 .30713 L
.76 .30646 L
.764 .30778 L
.768 .30954 L
.772 .30901 L
.776 .30456 L
.78 .29714 L
.784 .28963 L
.788 .28485 L
.792 .28381 L
.796 .28564 L
.8 .28892 L
Mistroke
.804 .29287 L
.808 .29776 L
.812 .30355 L
.816 .30905 L
.82 .31191 L
.824 .30999 L
.828 .3033 L
.832 .29418 L
.836 .28655 L
.84 .28357 L
.844 .28595 L
.848 .29204 L
.852 .29864 L
.856 .30319 L
.86 .30464 L
.864 .30346 L
.868 .3012 L
.872 .29905 L
.876 .2977 L
.88 .29707 L
.884 .29656 L
.888 .29577 L
.892 .29455 L
.896 .29343 L
.9 .2933 L
.904 .29493 L
.908 .2982 L
.912 .30197 L
.916 .3042 L
.92 .30302 L
.924 .29862 L
.928 .29254 L
.932 .28835 L
.936 .28897 L
.94 .29426 L
.944 .30245 L
.948 .3084 L
.952 .30844 L
.956 .30269 L
.96 .29281 L
.964 .28551 L
.968 .2846 L
.972 .29011 L
.976 .30066 L
.98 .3083 L
.984 .30956 L
.988 .30435 L
.992 .29365 L
.996 .28645 L
1 .28569 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57392 m
.008 .56741 L
.012 .56536 L
.016 .56761 L
.02 .56831 L
.024 .56747 L
.028 .56728 L
.032 .56754 L
.036 .56764 L
.04 .56752 L
.044 .56752 L
.048 .56753 L
.052 .56755 L
.056 .56752 L
.06 .56753 L
.064 .56753 L
.068 .56754 L
.072 .56753 L
.076 .56754 L
.08 .56753 L
.084 .56753 L
.088 .56753 L
.092 .56754 L
.096 .56753 L
.1 .56754 L
.104 .56753 L
.108 .56753 L
.112 .56753 L
.116 .56754 L
.12 .56753 L
.124 .56754 L
.128 .56753 L
.132 .56753 L
.136 .56753 L
.14 .56753 L
.144 .56753 L
.148 .56754 L
.152 .56753 L
.156 .56753 L
.16 .56753 L
.164 .56753 L
.168 .56753 L
.172 .56753 L
.176 .56753 L
.18 .56753 L
.184 .56753 L
.188 .56753 L
.192 .56753 L
.196 .56753 L
.2 .56753 L
Mistroke
.204 .56753 L
.208 .56752 L
.212 .56753 L
.216 .56753 L
.22 .56753 L
.224 .56753 L
.228 .56753 L
.232 .56752 L
.236 .56752 L
.24 .56751 L
.244 .56751 L
.248 .5675 L
.252 .5675 L
.256 .56749 L
.26 .56748 L
.264 .56747 L
.268 .56745 L
.272 .56743 L
.276 .5674 L
.28 .56737 L
.284 .56733 L
.288 .56728 L
.292 .56723 L
.296 .56716 L
.3 .56708 L
.304 .56699 L
.308 .56688 L
.312 .56674 L
.316 .56659 L
.32 .56641 L
.324 .5662 L
.328 .56596 L
.332 .56569 L
.336 .56538 L
.34 .56503 L
.344 .56465 L
.348 .56421 L
.352 .56373 L
.356 .5632 L
.36 .56262 L
.364 .56199 L
.368 .56132 L
.372 .5606 L
.376 .55985 L
.38 .55906 L
.384 .55823 L
.388 .55738 L
.392 .5565 L
.396 .5556 L
.4 .5547 L
Mistroke
.404 .5538 L
.408 .55292 L
.412 .55206 L
.416 .55122 L
.42 .55041 L
.424 .54963 L
.428 .54887 L
.432 .54815 L
.436 .54746 L
.44 .5468 L
.444 .54616 L
.448 .54554 L
.452 .54493 L
.456 .54431 L
.46 .54369 L
.464 .54306 L
.468 .54239 L
.472 .54168 L
.476 .54093 L
.48 .54012 L
.484 .53927 L
.488 .53837 L
.492 .53743 L
.496 .53644 L
.5 .5354 L
.504 .53431 L
.508 .53315 L
.512 .53192 L
.516 .5306 L
.52 .52918 L
.524 .52767 L
.528 .52605 L
.532 .5243 L
.536 .52242 L
.54 .5204 L
.544 .51824 L
.548 .51594 L
.552 .51352 L
.556 .51098 L
.56 .50836 L
.564 .50571 L
.568 .50307 L
.572 .50047 L
.576 .49796 L
.58 .49556 L
.584 .49328 L
.588 .49114 L
.592 .48911 L
.596 .48718 L
.6 .48528 L
Mistroke
.604 .48339 L
.608 .48147 L
.612 .47948 L
.616 .47742 L
.62 .47526 L
.624 .47301 L
.628 .47068 L
.632 .46834 L
.636 .46603 L
.64 .46381 L
.644 .4617 L
.648 .45973 L
.652 .45794 L
.656 .45632 L
.66 .45489 L
.664 .45359 L
.668 .45239 L
.672 .45125 L
.676 .45016 L
.68 .44914 L
.684 .44822 L
.688 .44741 L
.692 .44675 L
.696 .44629 L
.7 .44608 L
.704 .44617 L
.708 .44654 L
.712 .44714 L
.716 .44787 L
.72 .44864 L
.724 .44936 L
.728 .44998 L
.732 .45046 L
.736 .45078 L
.74 .4509 L
.744 .45084 L
.748 .45065 L
.752 .45039 L
.756 .45012 L
.76 .44985 L
.764 .44959 L
.768 .44932 L
.772 .44908 L
.776 .44893 L
.78 .44892 L
.784 .44907 L
.788 .44935 L
.792 .44969 L
.796 .45001 L
.8 .45026 L
Mistroke
.804 .45042 L
.808 .45047 L
.812 .4504 L
.816 .45023 L
.82 .44999 L
.824 .44975 L
.828 .4496 L
.832 .44961 L
.836 .44978 L
.84 .45007 L
.844 .45037 L
.848 .4506 L
.852 .4507 L
.856 .45067 L
.86 .45057 L
.864 .45045 L
.868 .45036 L
.872 .45031 L
.876 .45029 L
.88 .4503 L
.884 .45031 L
.888 .45034 L
.892 .4504 L
.896 .4505 L
.9 .45062 L
.904 .45074 L
.908 .45082 L
.912 .45085 L
.916 .45082 L
.92 .45078 L
.924 .45077 L
.928 .45082 L
.932 .45092 L
.936 .45101 L
.94 .45102 L
.944 .45096 L
.948 .4508 L
.952 .45069 L
.956 .45066 L
.96 .45081 L
.964 .45109 L
.968 .4514 L
.972 .45158 L
.976 .4516 L
.98 .45137 L
.984 .45113 L
.988 .4509 L
.992 .45089 L
.996 .45106 L
1 .45135 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42694 L
.012 .42967 L
.016 .43084 L
.02 .42997 L
.024 .42953 L
.028 .42968 L
.032 .42985 L
.036 .42974 L
.04 .42967 L
.044 .42963 L
.048 .42964 L
.052 .42958 L
.056 .42956 L
.06 .42951 L
.064 .4295 L
.068 .42945 L
.072 .42944 L
.076 .42939 L
.08 .42938 L
.084 .42934 L
.088 .42931 L
.092 .42927 L
.096 .42924 L
.1 .4292 L
.104 .42918 L
.108 .42915 L
.112 .42913 L
.116 .42909 L
.12 .42906 L
.124 .42902 L
.128 .42899 L
.132 .42895 L
.136 .42893 L
.14 .42889 L
.144 .42887 L
.148 .42884 L
.152 .42881 L
.156 .42877 L
.16 .42874 L
.164 .4287 L
.168 .42867 L
.172 .42864 L
.176 .42862 L
.18 .42859 L
.184 .42856 L
.188 .42852 L
.192 .42849 L
.196 .42845 L
.2 .42843 L
Mistroke
.204 .42839 L
.208 .42836 L
.212 .42833 L
.216 .4283 L
.22 .42827 L
.224 .42824 L
.228 .42821 L
.232 .42819 L
.236 .42816 L
.24 .42813 L
.244 .4281 L
.248 .42808 L
.252 .42805 L
.256 .42803 L
.26 .42802 L
.264 .428 L
.268 .42799 L
.272 .42799 L
.276 .42799 L
.28 .42799 L
.284 .428 L
.288 .42803 L
.292 .42807 L
.296 .42813 L
.3 .4282 L
.304 .42828 L
.308 .42839 L
.312 .42852 L
.316 .42868 L
.32 .42887 L
.324 .4291 L
.328 .42936 L
.332 .42967 L
.336 .43002 L
.34 .43043 L
.344 .43089 L
.348 .4314 L
.352 .43197 L
.356 .43259 L
.36 .43328 L
.364 .43402 L
.368 .43482 L
.372 .43569 L
.376 .43661 L
.38 .43758 L
.384 .43859 L
.388 .43963 L
.392 .44068 L
.396 .44175 L
.4 .44283 L
Mistroke
.404 .44392 L
.408 .44499 L
.412 .44605 L
.416 .44707 L
.42 .44807 L
.424 .44902 L
.428 .44993 L
.432 .45079 L
.436 .45161 L
.44 .4524 L
.444 .45316 L
.448 .45391 L
.452 .45464 L
.456 .45538 L
.46 .45615 L
.464 .45693 L
.468 .45775 L
.472 .45861 L
.476 .45951 L
.48 .46047 L
.484 .46148 L
.488 .46256 L
.492 .4637 L
.496 .46492 L
.5 .46622 L
.504 .46758 L
.508 .46903 L
.512 .47054 L
.516 .47214 L
.52 .47384 L
.524 .47568 L
.528 .47766 L
.532 .47981 L
.536 .48214 L
.54 .48465 L
.544 .48735 L
.548 .49022 L
.552 .49325 L
.556 .49638 L
.56 .49959 L
.564 .50284 L
.568 .50609 L
.572 .50929 L
.576 .5124 L
.58 .51538 L
.584 .51822 L
.588 .52091 L
.592 .52346 L
.596 .52589 L
.6 .52823 L
Mistroke
.604 .53054 L
.608 .53288 L
.612 .5353 L
.616 .53785 L
.62 .54053 L
.624 .54332 L
.628 .5462 L
.632 .54913 L
.636 .55204 L
.64 .55487 L
.644 .55751 L
.648 .55993 L
.652 .5621 L
.656 .56405 L
.66 .56581 L
.664 .56741 L
.668 .5689 L
.672 .5703 L
.676 .57165 L
.68 .57295 L
.684 .57418 L
.688 .57526 L
.692 .57608 L
.696 .57658 L
.7 .57674 L
.704 .57656 L
.708 .57609 L
.712 .57538 L
.716 .5745 L
.72 .57353 L
.724 .5726 L
.728 .57182 L
.732 .57127 L
.736 .57095 L
.74 .57082 L
.744 .57084 L
.748 .57097 L
.752 .57121 L
.756 .57155 L
.76 .57195 L
.764 .57234 L
.768 .57265 L
.772 .57285 L
.776 .57295 L
.78 .57295 L
.784 .57285 L
.788 .57263 L
.792 .57227 L
.796 .57183 L
.8 .57141 L
Mistroke
.804 .57111 L
.808 .57103 L
.812 .57116 L
.816 .57142 L
.82 .5717 L
.824 .57191 L
.828 .57199 L
.832 .57195 L
.836 .57181 L
.84 .57159 L
.844 .57133 L
.848 .57108 L
.852 .57088 L
.856 .57077 L
.86 .57077 L
.864 .57089 L
.868 .57105 L
.872 .57121 L
.876 .57128 L
.88 .57126 L
.884 .57114 L
.888 .57098 L
.892 .57082 L
.896 .57072 L
.9 .57067 L
.904 .57067 L
.908 .57068 L
.912 .57067 L
.916 .57062 L
.92 .57056 L
.924 .57048 L
.928 .57042 L
.932 .57036 L
.936 .57029 L
.94 .57019 L
.944 .57008 L
.948 .56996 L
.952 .56995 L
.956 .57001 L
.96 .57018 L
.964 .57036 L
.968 .57047 L
.972 .57041 L
.976 .57021 L
.98 .56985 L
.984 .5696 L
.988 .56939 L
.992 .56942 L
.996 .56954 L
1 .56967 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool20002Ool0
1000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00003Ool00`00Ool00006Ool01000Oomo
o`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomo
ogoo1@000goo0P000goo100017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00
Oomoo`12Ool00`00Ool00005Ool20003Ool00`00Oomoo`06Ool01000Oomoo`000Woo0P0037oo000R
Ool20013Ool01000Oomoo`000goo100000Eoo`00Ool007oo00P00005Ool00000Ool0000=Ool0029o
of<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00@007ooOol000=oo`03001oo`0000<0009oo`03001oo`0000H000=oo`05001oogooOol00003Ool0
1000Oomoo`000goo00D007oo001oo`0000=oo`80009oo`05001oo`00Ool00003Ool01@00Oomoogoo
00000goo00D007oo001oo`0000aoo`008Woo0P008Woo1P001Goo0P004goo00<007ooOol0:7oo000R
Ool00`00Oomoo`0]Ool2000AOol00`00Oomoo`0YOol0029oo`8002moo`8000moo`03001oogoo02Yo
o`008Woo0P00<7oo00<007ooOol02goo0`00;7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool00`00Oomoo`0`Ool00`00Oomoo`0:Ool00`00Oomoo`0/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P00<Woo00<007ooOol02Goo00<007ooOol0;7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80039oo`03001oogoo00=oo`<0009o
o`03001oogoo02eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`0aOol00`00Oomoo`02Ool00`00Oomoo`04000_Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P00<goo00D007ooOomoo`0000=oo`80031oo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool20004Ool2000dOol00`00Ool0000fOol000]oo`8000Yoo`8000Aoo`03
001oogoo009oo`03001oogoo03=oo`8003Moo`002goo0P0017oo00<007ooOol00goo0P000Woo1@00
0Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool0
1P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001o
o`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomo
o`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol0
00Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007oo
Ool000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo
0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo
0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol0
0003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eo
o`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000
0goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo
00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P00
17oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00
Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool0
00=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Ao
o`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009o
o`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogoo
Ool00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo
00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`00
17oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P00
0Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009o
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001o
o`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo
00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Ao
o`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomo
o`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool0
1000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool0
0`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool3
0003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005
Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool0
0`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool0
00Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0>Goo8@00
37oo000XOol00`00Oomoo`0gOol3000/Ool002Qoo`03001oogoo03Eoo`<002ioo`004Goo0P0017oo
00<007ooOol00goo0P000goo0`000goo00<007ooOol0=7oo0P00<7oo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo039oo`80039oo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0`Ool2000dOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P00;goo0`00=Goo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo02aoo`<003Moo`0047oo00@007ooOol000Qoo`04
001oogoo0002Ool20004Ool00`00Oomoo`0XOol5000iOol0015oo`8000Yoo`8000Aoo`03001oogoo
009oo`03001oogoo029oo`L003eoo`00:7oo00<007ooOol07Goo1P00@goo000XOolP0019Ool002Qo
o`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomo
o`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo0080
06Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogoo
Ool5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009o
o`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;
Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001ao
o`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eo
o`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00
009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001o
ogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000L
Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Ao
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo1000
0goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`80
00Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Ao
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo0000
1Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P00
1Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Io
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=o
o`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009o
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol3
0003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol0
0Woo9`00CWoo000GOol00`00Oomoo`02Ool00`00Oomoo`0SOol5001:Ool001Moo`03001oogoo009o
o`03001oogoo02Moo`D004Ioo`005Woo0P0017oo0P00;Goo1@00@Goo000GOol00`00Oomoo`02Ool0
0`00Oomoo`0`Ool4000nOol001aoo`03001oogoo03=oo`<003aoo`0077oo0P00=Woo0P00>goo000L
Ool00`00Oomoo`0fOol2000jOol001aoo`8003Uoo`03001oogoo03Moo`0077oo00<007ooOol0>Goo
0P00=goo000LOol00`00Oomoo`0jOol3000eOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`80
03eoo`8003Aoo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo03ioo`80039o
o`002goo00<007ooOol02goo00@007ooOol0045oo`80035oo`002goo00<007ooOol02goo00<007oo
Ool00P00@Woo0P007goo100037oo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`13OolP000?
Ool000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(34235\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30187 m
.008 .30077 L
.012 .29885 L
.016 .29859 L
.02 .29996 L
.024 .30021 L
.028 .29945 L
.032 .29929 L
.036 .29965 L
.04 .29973 L
.044 .29956 L
.048 .29948 L
.052 .2995 L
.056 .2995 L
.06 .2995 L
.064 .29952 L
.068 .29954 L
.072 .29951 L
.076 .29945 L
.08 .2994 L
.084 .29939 L
.088 .29941 L
.092 .29945 L
.096 .29945 L
.1 .29943 L
.104 .29937 L
.108 .29933 L
.112 .29932 L
.116 .29934 L
.12 .29936 L
.124 .29936 L
.128 .29933 L
.132 .29929 L
.136 .29926 L
.14 .29926 L
.144 .29926 L
.148 .29927 L
.152 .29926 L
.156 .29924 L
.16 .29921 L
.164 .29919 L
.168 .29919 L
.172 .2992 L
.176 .29919 L
.18 .29918 L
.184 .29917 L
.188 .29916 L
.192 .29916 L
.196 .29915 L
.2 .29916 L
Mistroke
.204 .29918 L
.208 .29918 L
.212 .29917 L
.216 .29918 L
.22 .29923 L
.224 .29929 L
.228 .29935 L
.232 .29941 L
.236 .29948 L
.24 .29956 L
.244 .29966 L
.248 .29979 L
.252 .3 L
.256 .30027 L
.26 .30056 L
.264 .30083 L
.268 .30113 L
.272 .3015 L
.276 .30198 L
.28 .30253 L
.284 .30316 L
.288 .30387 L
.292 .30468 L
.296 .30553 L
.3 .30639 L
.304 .30734 L
.308 .30843 L
.312 .30966 L
.316 .31094 L
.32 .31223 L
.324 .31352 L
.328 .31483 L
.332 .31614 L
.336 .3174 L
.34 .31861 L
.344 .31983 L
.348 .32101 L
.352 .32203 L
.356 .32275 L
.36 .3232 L
.364 .3235 L
.368 .32369 L
.372 .32373 L
.376 .32355 L
.38 .32316 L
.384 .32258 L
.388 .3218 L
.392 .32079 L
.396 .31964 L
.4 .31855 L
Mistroke
.404 .31769 L
.408 .31704 L
.412 .31645 L
.416 .31585 L
.42 .31536 L
.424 .31516 L
.428 .31535 L
.432 .31589 L
.436 .31674 L
.44 .3179 L
.444 .31937 L
.448 .32104 L
.452 .3228 L
.456 .32471 L
.46 .327 L
.464 .32986 L
.468 .33326 L
.472 .33698 L
.476 .34087 L
.48 .34505 L
.484 .34983 L
.488 .35545 L
.492 .36195 L
.496 .3692 L
.5 .37706 L
.504 .38533 L
.508 .39373 L
.512 .40186 L
.516 .40936 L
.52 .41603 L
.524 .42179 L
.528 .42648 L
.532 .42965 L
.536 .4307 L
.54 .42922 L
.544 .42535 L
.548 .41973 L
.552 .41311 L
.556 .4061 L
.56 .39915 L
.564 .39275 L
.568 .38758 L
.572 .38429 L
.576 .38321 L
.58 .3842 L
.584 .38694 L
.588 .39114 L
.592 .3964 L
.596 .40194 L
.6 .40642 L
Mistroke
.604 .4084 L
.608 .4071 L
.612 .40282 L
.616 .3966 L
.62 .38939 L
.624 .38161 L
.628 .37345 L
.632 .36544 L
.636 .35858 L
.64 .35368 L
.644 .3506 L
.648 .34818 L
.652 .34505 L
.656 .34045 L
.66 .33438 L
.664 .32687 L
.668 .31749 L
.672 .30577 L
.676 .29223 L
.68 .27898 L
.684 .26894 L
.688 .26418 L
.692 .26467 L
.696 .26874 L
.7 .27451 L
.704 .28112 L
.708 .28852 L
.712 .29636 L
.716 .30329 L
.72 .30764 L
.724 .30883 L
.728 .30812 L
.732 .30764 L
.736 .30856 L
.74 .30992 L
.744 .3095 L
.748 .30576 L
.752 .29928 L
.756 .29246 L
.76 .28765 L
.764 .28561 L
.768 .28558 L
.772 .28664 L
.776 .28897 L
.78 .29352 L
.784 .30054 L
.788 .30823 L
.792 .31319 L
.796 .31258 L
.8 .30611 L
Mistroke
.804 .29677 L
.808 .2888 L
.812 .28532 L
.816 .2867 L
.82 .29088 L
.824 .2954 L
.828 .29878 L
.832 .3011 L
.836 .30289 L
.84 .30407 L
.844 .30398 L
.848 .30184 L
.852 .29799 L
.856 .29395 L
.86 .29149 L
.864 .29169 L
.868 .29412 L
.872 .29729 L
.876 .29965 L
.88 .30044 L
.884 .29985 L
.888 .29866 L
.892 .29755 L
.896 .29673 L
.9 .29635 L
.904 .29613 L
.908 .29617 L
.912 .29662 L
.916 .29707 L
.92 .29789 L
.924 .29855 L
.928 .29893 L
.932 .29943 L
.936 .29897 L
.94 .2981 L
.944 .29655 L
.948 .29427 L
.952 .29351 L
.956 .29396 L
.96 .29651 L
.964 .30074 L
.968 .30301 L
.972 .30332 L
.976 .30009 L
.98 .2941 L
.984 .29036 L
.988 .28905 L
.992 .29244 L
.996 .29969 L
1 .30451 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57207 m
.008 .56724 L
.012 .56559 L
.016 .56696 L
.02 .56762 L
.024 .56719 L
.028 .56698 L
.032 .56707 L
.036 .56718 L
.04 .56713 L
.044 .56712 L
.048 .5671 L
.052 .56713 L
.056 .56711 L
.06 .56712 L
.064 .56711 L
.068 .56713 L
.072 .56712 L
.076 .56713 L
.08 .56711 L
.084 .56712 L
.088 .56711 L
.092 .56712 L
.096 .56712 L
.1 .56713 L
.104 .56712 L
.108 .56712 L
.112 .56712 L
.116 .56712 L
.12 .56712 L
.124 .56712 L
.128 .56711 L
.132 .56712 L
.136 .56712 L
.14 .56713 L
.144 .56712 L
.148 .56712 L
.152 .56711 L
.156 .56711 L
.16 .56711 L
.164 .56712 L
.168 .56712 L
.172 .56712 L
.176 .56712 L
.18 .56712 L
.184 .56711 L
.188 .56711 L
.192 .56711 L
.196 .56711 L
.2 .56711 L
Mistroke
.204 .56711 L
.208 .56711 L
.212 .5671 L
.216 .5671 L
.22 .56709 L
.224 .56709 L
.228 .56708 L
.232 .56707 L
.236 .56705 L
.24 .56704 L
.244 .56702 L
.248 .567 L
.252 .56697 L
.256 .56693 L
.26 .56689 L
.264 .56683 L
.268 .56677 L
.272 .56669 L
.276 .5666 L
.28 .56649 L
.284 .56637 L
.288 .56622 L
.292 .56605 L
.296 .56585 L
.3 .56562 L
.304 .56536 L
.308 .56506 L
.312 .56472 L
.316 .56435 L
.32 .56393 L
.324 .56346 L
.328 .56295 L
.332 .56238 L
.336 .56177 L
.34 .56111 L
.344 .56041 L
.348 .55967 L
.352 .55888 L
.356 .55806 L
.36 .55721 L
.364 .55635 L
.368 .55546 L
.372 .55457 L
.376 .55368 L
.38 .55279 L
.384 .55191 L
.388 .55106 L
.392 .55023 L
.396 .54944 L
.4 .54868 L
Mistroke
.404 .54796 L
.408 .54727 L
.412 .5466 L
.416 .54596 L
.42 .54533 L
.424 .54471 L
.428 .54409 L
.432 .54347 L
.436 .54283 L
.44 .54217 L
.444 .54148 L
.448 .54075 L
.452 .53997 L
.456 .53914 L
.46 .53826 L
.464 .53733 L
.468 .53635 L
.472 .53531 L
.476 .53421 L
.48 .53307 L
.484 .53186 L
.488 .53058 L
.492 .52921 L
.496 .52774 L
.5 .52615 L
.504 .52444 L
.508 .52259 L
.512 .52061 L
.516 .51848 L
.52 .51622 L
.524 .51384 L
.528 .51136 L
.532 .50879 L
.536 .50617 L
.54 .50353 L
.544 .50091 L
.548 .49836 L
.552 .49591 L
.556 .49357 L
.56 .49137 L
.564 .48929 L
.568 .48732 L
.572 .48543 L
.576 .48356 L
.58 .48167 L
.584 .47972 L
.588 .4777 L
.592 .47558 L
.596 .47337 L
.6 .47107 L
Mistroke
.604 .46874 L
.608 .46641 L
.612 .46415 L
.616 .462 L
.62 .45999 L
.624 .45814 L
.628 .45647 L
.632 .45498 L
.636 .45364 L
.64 .45242 L
.644 .45128 L
.648 .45019 L
.652 .44916 L
.656 .44821 L
.66 .44737 L
.664 .44668 L
.668 .44617 L
.672 .44589 L
.676 .44587 L
.68 .44612 L
.684 .44662 L
.688 .44728 L
.692 .44803 L
.696 .44878 L
.7 .44946 L
.704 .45003 L
.708 .45043 L
.712 .45064 L
.716 .45065 L
.72 .4505 L
.724 .45024 L
.728 .44995 L
.732 .44966 L
.736 .44938 L
.74 .44912 L
.744 .44888 L
.748 .44872 L
.752 .44868 L
.756 .44877 L
.76 .44898 L
.764 .44925 L
.768 .44954 L
.772 .44982 L
.776 .45005 L
.78 .45019 L
.784 .45021 L
.788 .4501 L
.792 .44986 L
.796 .44959 L
.8 .44939 L
Mistroke
.804 .44933 L
.808 .44945 L
.812 .44968 L
.816 .44994 L
.82 .45017 L
.824 .45032 L
.828 .45039 L
.832 .45038 L
.836 .45031 L
.84 .45021 L
.844 .45008 L
.848 .44996 L
.852 .4499 L
.856 .44993 L
.86 .45003 L
.864 .45018 L
.868 .45032 L
.872 .45043 L
.876 .45047 L
.88 .45047 L
.884 .45045 L
.888 .45045 L
.892 .45047 L
.896 .45052 L
.9 .45057 L
.904 .45061 L
.908 .45064 L
.912 .45065 L
.916 .45065 L
.92 .45066 L
.924 .45066 L
.928 .45068 L
.932 .4507 L
.936 .45073 L
.94 .45078 L
.944 .45085 L
.948 .45093 L
.952 .45103 L
.956 .45107 L
.96 .45109 L
.964 .45101 L
.968 .45092 L
.972 .45083 L
.976 .45082 L
.98 .45091 L
.984 .45114 L
.988 .45134 L
.992 .45156 L
.996 .45156 L
1 .45147 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43431 L
.012 .42972 L
.016 .42839 L
.02 .42991 L
.024 .43035 L
.028 .42972 L
.032 .42958 L
.036 .42972 L
.04 .42976 L
.044 .42963 L
.048 .4296 L
.052 .42958 L
.056 .42958 L
.06 .42952 L
.064 .42951 L
.068 .42946 L
.072 .42944 L
.076 .42939 L
.08 .42937 L
.084 .42933 L
.088 .42931 L
.092 .42927 L
.096 .42925 L
.1 .42921 L
.104 .42918 L
.108 .42915 L
.112 .42912 L
.116 .42908 L
.12 .42906 L
.124 .42902 L
.128 .42899 L
.132 .42896 L
.136 .42893 L
.14 .4289 L
.144 .42887 L
.148 .42883 L
.152 .4288 L
.156 .42877 L
.16 .42874 L
.164 .42871 L
.168 .42868 L
.172 .42865 L
.176 .42862 L
.18 .42859 L
.184 .42856 L
.188 .42852 L
.192 .42849 L
.196 .42846 L
.2 .42843 L
Mistroke
.204 .42841 L
.208 .42838 L
.212 .42835 L
.216 .42832 L
.22 .4283 L
.224 .42827 L
.228 .42825 L
.232 .42823 L
.236 .42822 L
.24 .42821 L
.244 .4282 L
.248 .4282 L
.252 .42821 L
.256 .42822 L
.26 .42824 L
.264 .42827 L
.268 .42832 L
.272 .42838 L
.276 .42847 L
.28 .42857 L
.284 .4287 L
.288 .42885 L
.292 .42903 L
.296 .42925 L
.3 .4295 L
.304 .42979 L
.308 .43013 L
.312 .43052 L
.316 .43096 L
.32 .43146 L
.324 .43201 L
.328 .43262 L
.332 .43329 L
.336 .43402 L
.34 .43481 L
.344 .43565 L
.348 .43655 L
.352 .43749 L
.356 .43848 L
.36 .43951 L
.364 .44057 L
.368 .44165 L
.372 .44273 L
.376 .44382 L
.38 .44489 L
.384 .44594 L
.388 .44697 L
.392 .44797 L
.396 .44893 L
.4 .44986 L
Mistroke
.404 .45074 L
.408 .45159 L
.412 .45239 L
.416 .45316 L
.42 .45391 L
.424 .45464 L
.428 .45537 L
.432 .45612 L
.436 .45689 L
.44 .4577 L
.444 .45854 L
.448 .45944 L
.452 .46038 L
.456 .46138 L
.46 .46245 L
.464 .46358 L
.468 .46477 L
.472 .46602 L
.476 .46735 L
.48 .46876 L
.484 .47026 L
.488 .47186 L
.492 .47355 L
.496 .47537 L
.5 .47731 L
.504 .4794 L
.508 .48166 L
.512 .48409 L
.516 .4867 L
.52 .4895 L
.524 .49247 L
.528 .49558 L
.532 .49879 L
.536 .50204 L
.54 .5053 L
.544 .50851 L
.548 .51165 L
.552 .51467 L
.556 .51755 L
.56 .52028 L
.564 .52287 L
.568 .52534 L
.572 .52773 L
.576 .53006 L
.58 .5324 L
.584 .53478 L
.588 .53726 L
.592 .53987 L
.596 .5426 L
.6 .54542 L
Mistroke
.604 .54831 L
.608 .55122 L
.612 .55406 L
.616 .55678 L
.62 .55931 L
.624 .56159 L
.628 .56364 L
.632 .56546 L
.636 .5671 L
.64 .56861 L
.644 .57 L
.648 .57133 L
.652 .57259 L
.656 .5738 L
.66 .5749 L
.664 .57581 L
.668 .57646 L
.672 .57678 L
.676 .57675 L
.68 .5764 L
.684 .57577 L
.688 .57492 L
.692 .57395 L
.696 .57297 L
.7 .57211 L
.704 .57146 L
.708 .57105 L
.712 .57086 L
.716 .57084 L
.72 .57095 L
.724 .57117 L
.728 .57148 L
.732 .57184 L
.736 .57222 L
.74 .57255 L
.744 .5728 L
.748 .57296 L
.752 .57303 L
.756 .573 L
.76 .57282 L
.764 .57249 L
.768 .57205 L
.772 .57161 L
.776 .57126 L
.78 .5711 L
.784 .57114 L
.788 .57132 L
.792 .57157 L
.796 .5718 L
.8 .57197 L
Mistroke
.804 .57205 L
.808 .57201 L
.812 .57184 L
.816 .57155 L
.82 .57121 L
.824 .57093 L
.828 .57077 L
.832 .57078 L
.836 .57091 L
.84 .57108 L
.844 .5712 L
.848 .57124 L
.852 .57121 L
.856 .57115 L
.86 .5711 L
.864 .57105 L
.868 .57099 L
.872 .5709 L
.876 .57077 L
.88 .57064 L
.884 .57055 L
.888 .57052 L
.892 .57053 L
.896 .57056 L
.9 .57055 L
.904 .57048 L
.908 .57034 L
.912 .5702 L
.916 .5701 L
.92 .57011 L
.924 .57019 L
.928 .57033 L
.932 .57041 L
.936 .5704 L
.94 .57027 L
.944 .57008 L
.948 .56989 L
.952 .56982 L
.956 .56981 L
.96 .5699 L
.964 .56988 L
.968 .56978 L
.972 .56956 L
.976 .56933 L
.98 .56919 L
.984 .56929 L
.988 .56949 L
.992 .56986 L
.996 .57002 L
1 .57002 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`03001oogoo00@000=oo`04001o
ogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`0000=oo`03001oo`0000Ioo`04001oogoo0005
Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool2000017oo000007oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol0
0`00Oomoo`0oOol01000Oomoo`0017oo0P000goo0P007Woo000ROol3000oOol00`00Oomoo`020003
Ool01000Ool007oo0`000Woo0`0000=oo`0000000P0000Eoo`00000007oo008000eoo`008WooH`00
37oo000ROol01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000
Oomoo`000goo0`0000=oo`00Ool00Woo1@000goo00D007ooOomoo`0000=oo`05001oogooOol00002
Ool00`00Oomoo`020003Ool00`00Ool000020002Ool20003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`03001oogoo00Yoo`008Woo0P0087oo1P000goo0`004goo00<007ooOol0:goo000R
Ool00`00Oomoo`0ZOol2000AOol00`00Oomoo`0/Ool0029oo`8002eoo`03001oogoo00eoo`8002io
o`008Woo0P00;Woo00<007ooOol02goo0P00;goo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool00`00Oomoo`0]Ool00`00Oomoo`0;Ool00`00Oomoo`0^Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P00;goo00<007ooOol02Goo00<007ooOol0;goo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8002moo`03001oogoo00=oo`<000=o
o`03001oogoo02moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`0_Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0039oo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2000`Ool01@00Oomoogoo00000goo0`00<Woo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000Aoo`80035oo`04001oogoo000hOol000]oo`8000Yoo`8000Ao
o`03001oogoo009oo`03001oogoo035oo`8003Uoo`002goo0P0017oo00<007ooOol00goo0P000Woo
1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:
Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008
Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo
001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00
Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007oo
Ool000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`00
0goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomo
o`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogoo
Ool00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo
10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001o
ogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo
0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool0
0`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=o
o`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00
Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<0
00Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00
009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001o
ogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
0Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomo
o`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo
0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@0
07ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo
001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`00
0goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`80
00Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo
0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000
Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004
Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?
Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003
Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo
00@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00
Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0=goo
8`0037oo000XOol00`00Oomoo`0eOol3000^Ool002Qoo`03001oogoo03=oo`80035oo`004Goo0P00
17oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0<Goo0`00<Woo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo02moo`<003Aoo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0^Ool2000fOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00;Goo0P00>7oo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo02Uoo`@003Uoo`0047oo00@007ooOol000Qo
o`04001oogoo0002Ool20004Ool00`00Oomoo`0UOol5000lOol0015oo`8000Yoo`8000Aoo`03001o
ogoo009oo`03001oogoo01moo`L0041oo`00:7oo00<007ooOol06Woo1P00AWoo000XOolM001<Ool0
02Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<0
07ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000
Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1Y
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001o
ogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo
009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo
000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol0
01aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`80
00Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomo
o`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05
001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo
000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo
10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qo
o`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo
00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo
0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`80
00Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D007oo
Oomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo0080
07=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0
009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000F
Ool30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007oo
Ool00Woo9000DGoo000GOol00`00Oomoo`02Ool00`00Oomoo`0POol5001=Ool001Moo`03001oogoo
009oo`03001oogoo02Aoo`D004Uoo`005Woo0P0017oo0P00:Woo1@00A7oo000GOol00`00Oomoo`02
Ool00`00Oomoo`0]Ool40011Ool001aoo`03001oogoo031oo`<003moo`0077oo0P00<goo0P00?Woo
000LOol00`00Oomoo`0cOol3000lOol001aoo`8003Ioo`8003]oo`0077oo00<007ooOol0=Woo0P00
>Woo000LOol00`00Oomoo`0hOol2000hOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8003Yo
o`8003Moo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo03]oo`8003Eoo`00
2goo00<007ooOol02goo00@007ooOol003ioo`8003Aoo`002goo00<007ooOol02goo00<007ooOol0
0P00?goo0P0087oo10003Woo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`10OolR0002Ool2
000<Ool000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@00
0Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(34402\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3015 m
.008 .29975 L
.012 .29925 L
.016 .29919 L
.02 .29969 L
.024 .29993 L
.028 .29966 L
.032 .29947 L
.036 .29959 L
.04 .29971 L
.044 .29966 L
.048 .29956 L
.052 .29952 L
.056 .29951 L
.06 .29952 L
.064 .29955 L
.068 .29957 L
.072 .29956 L
.076 .29951 L
.08 .29946 L
.084 .29943 L
.088 .29944 L
.092 .29946 L
.096 .29946 L
.1 .29946 L
.104 .29943 L
.108 .29941 L
.112 .29939 L
.116 .29938 L
.12 .29937 L
.124 .29935 L
.128 .29932 L
.132 .29933 L
.136 .29935 L
.14 .29937 L
.144 .29935 L
.148 .29931 L
.152 .29926 L
.156 .29923 L
.16 .29923 L
.164 .29928 L
.168 .29933 L
.172 .29935 L
.176 .29932 L
.18 .29926 L
.184 .29923 L
.188 .29926 L
.192 .29933 L
.196 .29942 L
.2 .2995 L
Mistroke
.204 .29956 L
.208 .29959 L
.212 .29963 L
.216 .29973 L
.22 .2999 L
.224 .30013 L
.228 .30037 L
.232 .30062 L
.236 .30088 L
.24 .3012 L
.244 .30159 L
.248 .30205 L
.252 .30261 L
.256 .30326 L
.26 .30397 L
.264 .3047 L
.268 .30549 L
.272 .3064 L
.276 .30744 L
.28 .30858 L
.284 .30978 L
.288 .31103 L
.292 .31233 L
.296 .31366 L
.3 .31498 L
.304 .3163 L
.308 .31768 L
.312 .31906 L
.316 .32035 L
.32 .32147 L
.324 .32242 L
.328 .32323 L
.332 .32391 L
.336 .32439 L
.34 .32466 L
.344 .32473 L
.348 .3246 L
.352 .32423 L
.356 .32357 L
.36 .3227 L
.364 .32178 L
.368 .3209 L
.372 .32001 L
.376 .31904 L
.38 .31804 L
.384 .31715 L
.388 .31646 L
.392 .31601 L
.396 .31584 L
.4 .31601 L
Mistroke
.404 .31656 L
.408 .31742 L
.412 .31842 L
.416 .31954 L
.42 .32093 L
.424 .32276 L
.428 .32505 L
.432 .32764 L
.436 .33042 L
.44 .33341 L
.444 .33675 L
.448 .34053 L
.452 .34481 L
.456 .34969 L
.46 .35532 L
.464 .36174 L
.468 .36883 L
.472 .37633 L
.476 .3841 L
.48 .39212 L
.484 .4004 L
.488 .4087 L
.492 .41647 L
.496 .42307 L
.5 .42803 L
.504 .43113 L
.508 .43228 L
.512 .43145 L
.516 .42867 L
.52 .42417 L
.524 .41833 L
.528 .41162 L
.532 .40447 L
.536 .39737 L
.54 .39104 L
.544 .38638 L
.548 .38417 L
.552 .38469 L
.556 .38753 L
.56 .39186 L
.564 .39678 L
.568 .4016 L
.572 .40573 L
.576 .40847 L
.58 .40904 L
.584 .40693 L
.588 .40216 L
.592 .39526 L
.596 .38699 L
.6 .37801 L
Mistroke
.604 .36906 L
.608 .36102 L
.612 .35485 L
.616 .351 L
.62 .34886 L
.624 .34693 L
.628 .34355 L
.632 .33783 L
.636 .32982 L
.64 .32004 L
.644 .3089 L
.648 .29678 L
.652 .28452 L
.656 .27378 L
.66 .26646 L
.664 .26372 L
.668 .2653 L
.672 .27001 L
.676 .27662 L
.68 .28446 L
.684 .29305 L
.688 .30129 L
.692 .30754 L
.696 .3105 L
.7 .31037 L
.704 .30888 L
.708 .30796 L
.712 .30819 L
.716 .30837 L
.72 .30672 L
.724 .30254 L
.728 .29684 L
.732 .29144 L
.736 .28758 L
.74 .28539 L
.744 .28465 L
.748 .28576 L
.752 .28976 L
.756 .29697 L
.76 .30573 L
.764 .31257 L
.768 .31414 L
.772 .30961 L
.776 .30119 L
.78 .29289 L
.784 .28781 L
.788 .2867 L
.792 .28837 L
.796 .29121 L
.8 .29464 L
Mistroke
.804 .29876 L
.808 .30329 L
.812 .30679 L
.816 .30725 L
.82 .30389 L
.824 .29803 L
.828 .29266 L
.832 .2905 L
.836 .29209 L
.84 .29569 L
.844 .29861 L
.848 .29928 L
.852 .29819 L
.856 .29712 L
.86 .29749 L
.864 .29913 L
.868 .30049 L
.872 .29992 L
.876 .29727 L
.88 .29388 L
.884 .29198 L
.888 .29312 L
.892 .2968 L
.896 .3014 L
.9 .30432 L
.904 .30391 L
.908 .30055 L
.912 .29537 L
.916 .29127 L
.92 .29022 L
.924 .2925 L
.928 .29772 L
.932 .30257 L
.936 .30468 L
.94 .30308 L
.944 .29757 L
.948 .29214 L
.952 .28952 L
.956 .29109 L
.96 .29729 L
.964 .30323 L
.968 .30591 L
.972 .30401 L
.976 .29709 L
.98 .29109 L
.984 .28906 L
.988 .2918 L
.992 .29953 L
.996 .30529 L
1 .30607 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .56128 m
.008 .56681 L
.012 .56863 L
.016 .56657 L
.02 .56606 L
.024 .56676 L
.028 .56696 L
.032 .56667 L
.036 .56664 L
.04 .56671 L
.044 .56675 L
.048 .5667 L
.052 .56671 L
.056 .56671 L
.06 .56672 L
.064 .5667 L
.068 .56671 L
.072 .5667 L
.076 .56671 L
.08 .5667 L
.084 .56672 L
.088 .56671 L
.092 .56672 L
.096 .56671 L
.1 .56671 L
.104 .5667 L
.108 .56671 L
.112 .56671 L
.116 .56671 L
.12 .56671 L
.124 .56671 L
.128 .56671 L
.132 .56671 L
.136 .56671 L
.14 .56671 L
.144 .56671 L
.148 .56671 L
.152 .5667 L
.156 .56671 L
.16 .5667 L
.164 .56671 L
.168 .5667 L
.172 .5667 L
.176 .5667 L
.18 .56669 L
.184 .56669 L
.188 .56669 L
.192 .56669 L
.196 .56668 L
.2 .56667 L
Mistroke
.204 .56666 L
.208 .56665 L
.212 .56663 L
.216 .56661 L
.22 .56659 L
.224 .56656 L
.228 .56653 L
.232 .56649 L
.236 .56644 L
.24 .56638 L
.244 .5663 L
.248 .56622 L
.252 .56611 L
.256 .56599 L
.26 .56585 L
.264 .56568 L
.268 .5655 L
.272 .56528 L
.276 .56503 L
.28 .56474 L
.284 .56441 L
.288 .56404 L
.292 .56363 L
.296 .56318 L
.3 .56268 L
.304 .56214 L
.308 .56154 L
.312 .5609 L
.316 .56021 L
.32 .55948 L
.324 .55871 L
.328 .5579 L
.332 .55706 L
.336 .5562 L
.34 .55532 L
.344 .55443 L
.348 .55353 L
.352 .55265 L
.356 .55177 L
.36 .55091 L
.364 .55008 L
.368 .54927 L
.372 .5485 L
.376 .54776 L
.38 .54705 L
.384 .54638 L
.388 .54573 L
.392 .5451 L
.396 .54449 L
.4 .54388 L
Mistroke
.404 .54326 L
.408 .54262 L
.412 .54196 L
.416 .54128 L
.42 .54056 L
.424 .5398 L
.428 .53899 L
.432 .53813 L
.436 .53722 L
.44 .53625 L
.444 .53523 L
.448 .53415 L
.452 .53301 L
.456 .53181 L
.46 .53054 L
.464 .5292 L
.468 .52776 L
.472 .52621 L
.476 .52455 L
.48 .52275 L
.484 .52082 L
.488 .51875 L
.492 .51653 L
.496 .51418 L
.5 .51172 L
.504 .50918 L
.508 .50657 L
.512 .50395 L
.516 .50134 L
.52 .49878 L
.524 .4963 L
.528 .49392 L
.532 .49166 L
.536 .48951 L
.54 .48749 L
.544 .48556 L
.548 .48368 L
.552 .48182 L
.556 .47992 L
.56 .47795 L
.564 .47589 L
.568 .47373 L
.572 .47147 L
.576 .46915 L
.58 .46682 L
.584 .46452 L
.588 .46231 L
.592 .46025 L
.596 .45835 L
.6 .45663 L
Mistroke
.604 .45508 L
.608 .4537 L
.612 .45245 L
.616 .4513 L
.62 .45022 L
.624 .44919 L
.628 .44822 L
.632 .44736 L
.636 .44662 L
.64 .44605 L
.644 .4457 L
.648 .44558 L
.652 .44573 L
.656 .44614 L
.66 .44674 L
.664 .44747 L
.668 .44823 L
.672 .44895 L
.676 .44956 L
.68 .45002 L
.684 .4503 L
.688 .45039 L
.692 .45031 L
.696 .45011 L
.7 .44983 L
.704 .44953 L
.708 .44923 L
.712 .44894 L
.716 .44868 L
.72 .44849 L
.724 .4484 L
.728 .44845 L
.732 .44861 L
.736 .44885 L
.74 .44913 L
.744 .44942 L
.748 .44968 L
.752 .44987 L
.756 .44995 L
.76 .44989 L
.764 .4497 L
.768 .44945 L
.772 .44923 L
.776 .44912 L
.78 .44915 L
.784 .44929 L
.788 .44951 L
.792 .44973 L
.796 .44993 L
.8 .45008 L
Mistroke
.804 .45015 L
.808 .45013 L
.812 .45002 L
.816 .44986 L
.82 .44971 L
.824 .44963 L
.828 .44965 L
.832 .44975 L
.836 .44988 L
.84 .44999 L
.844 .45007 L
.848 .45012 L
.852 .45016 L
.856 .45021 L
.86 .45025 L
.864 .45026 L
.868 .45025 L
.872 .45022 L
.876 .45021 L
.88 .45025 L
.884 .45034 L
.888 .45045 L
.892 .45052 L
.896 .45054 L
.9 .45048 L
.904 .4504 L
.908 .45034 L
.912 .45036 L
.916 .45046 L
.92 .45061 L
.924 .45073 L
.928 .4508 L
.932 .45077 L
.936 .4507 L
.94 .45062 L
.944 .45062 L
.948 .45071 L
.952 .45085 L
.956 .45099 L
.96 .45108 L
.964 .45104 L
.968 .45098 L
.972 .45088 L
.976 .45088 L
.98 .45094 L
.984 .45106 L
.988 .45114 L
.992 .45117 L
.996 .45107 L
1 .45102 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43378 L
.012 .43007 L
.016 .42868 L
.02 .42968 L
.024 .43021 L
.028 .42983 L
.032 .42964 L
.036 .42967 L
.04 .42974 L
.044 .42965 L
.048 .42961 L
.052 .42957 L
.056 .42957 L
.06 .42953 L
.064 .42951 L
.068 .42946 L
.072 .42944 L
.076 .42939 L
.08 .42937 L
.084 .42933 L
.088 .42932 L
.092 .42928 L
.096 .42925 L
.1 .42921 L
.104 .42918 L
.108 .42914 L
.112 .42912 L
.116 .42908 L
.12 .42906 L
.124 .42902 L
.128 .429 L
.132 .42896 L
.136 .42894 L
.14 .4289 L
.144 .42887 L
.148 .42883 L
.152 .4288 L
.156 .42877 L
.16 .42875 L
.164 .42872 L
.168 .42869 L
.172 .42865 L
.176 .42862 L
.18 .42859 L
.184 .42857 L
.188 .42854 L
.192 .42852 L
.196 .4285 L
.2 .42848 L
Mistroke
.204 .42845 L
.208 .42843 L
.212 .42842 L
.216 .42841 L
.22 .42841 L
.224 .42842 L
.228 .42843 L
.232 .42845 L
.236 .42848 L
.24 .42852 L
.244 .42858 L
.248 .42866 L
.252 .42876 L
.256 .42887 L
.26 .42902 L
.264 .42919 L
.268 .4294 L
.272 .42965 L
.276 .42993 L
.28 .43026 L
.284 .43063 L
.288 .43105 L
.292 .43153 L
.296 .43206 L
.3 .43265 L
.304 .43331 L
.308 .43402 L
.312 .43479 L
.316 .43562 L
.32 .4365 L
.324 .43743 L
.328 .4384 L
.332 .43941 L
.336 .44046 L
.34 .44153 L
.344 .44261 L
.348 .4437 L
.352 .44478 L
.356 .44584 L
.36 .44688 L
.364 .44789 L
.368 .44886 L
.372 .4498 L
.376 .45069 L
.38 .45154 L
.384 .45235 L
.388 .45314 L
.392 .4539 L
.396 .45464 L
.4 .45538 L
Mistroke
.404 .45612 L
.408 .45688 L
.412 .45766 L
.416 .45848 L
.42 .45935 L
.424 .46028 L
.428 .46128 L
.432 .46233 L
.436 .46344 L
.44 .46462 L
.444 .46586 L
.448 .46717 L
.452 .46855 L
.456 .47002 L
.46 .47158 L
.464 .47324 L
.468 .47502 L
.472 .47693 L
.476 .47898 L
.48 .48119 L
.484 .48358 L
.488 .48613 L
.492 .48886 L
.496 .49175 L
.5 .49479 L
.504 .49795 L
.508 .50118 L
.512 .50445 L
.516 .5077 L
.52 .51088 L
.524 .51396 L
.528 .51689 L
.532 .51967 L
.536 .52229 L
.54 .52479 L
.544 .52719 L
.548 .52954 L
.552 .53188 L
.556 .53425 L
.56 .5367 L
.564 .53925 L
.568 .54192 L
.572 .54469 L
.576 .54754 L
.58 .55041 L
.584 .55326 L
.588 .55602 L
.592 .55862 L
.596 .56101 L
.6 .56317 L
Mistroke
.604 .56508 L
.608 .56679 L
.612 .56832 L
.616 .56973 L
.62 .57104 L
.624 .57228 L
.628 .57346 L
.632 .57456 L
.636 .57551 L
.64 .57626 L
.644 .57672 L
.648 .57684 L
.652 .57663 L
.656 .57611 L
.66 .57535 L
.664 .57442 L
.668 .57342 L
.672 .57248 L
.676 .57171 L
.68 .57116 L
.684 .57087 L
.688 .5708 L
.692 .5709 L
.696 .57112 L
.7 .57144 L
.704 .5718 L
.708 .57216 L
.712 .57248 L
.716 .57274 L
.72 .57292 L
.724 .57302 L
.728 .57304 L
.732 .57294 L
.736 .57269 L
.74 .57232 L
.744 .57189 L
.748 .5715 L
.752 .57123 L
.756 .57114 L
.76 .57122 L
.764 .57141 L
.768 .57167 L
.772 .57192 L
.776 .5721 L
.78 .57216 L
.784 .57204 L
.788 .57176 L
.792 .5714 L
.796 .57106 L
.8 .57085 L
Mistroke
.804 .5708 L
.808 .57089 L
.812 .57103 L
.816 .57116 L
.82 .57124 L
.824 .57127 L
.828 .57128 L
.832 .57126 L
.836 .57119 L
.84 .57107 L
.844 .57092 L
.848 .57078 L
.852 .57068 L
.856 .57065 L
.86 .57064 L
.864 .57064 L
.868 .5706 L
.872 .57052 L
.876 .57043 L
.88 .57035 L
.884 .57031 L
.888 .57031 L
.892 .57033 L
.896 .57035 L
.9 .57035 L
.904 .57035 L
.908 .57031 L
.912 .57025 L
.916 .57017 L
.92 .57007 L
.924 .56996 L
.928 .56987 L
.932 .56979 L
.936 .56977 L
.94 .56974 L
.944 .56975 L
.948 .56973 L
.952 .5697 L
.956 .56963 L
.96 .56957 L
.964 .5695 L
.968 .56952 L
.972 .56955 L
.976 .56963 L
.98 .56966 L
.984 .5696 L
.988 .56941 L
.992 .56916 L
.996 .56883 L
1 .5687 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`@0009oo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eo
o`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D0
00=oo`<000=oo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol0
?Goo00<007oo00001Goo0P000goo00<007ooOol07goo000ROol2000mOol01@00Oomoogoo00000goo
00T007oo000007oo001oo`00Ool0200000=oo`0000001P003Woo000ROomS000<Ool0029oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo00D000=oo`03
001oo`0000<0009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00P000Woo
00D007oo001oo`0000=oo`80009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000aoo`008Woo0P007Goo1P0017oo0P004goo00<007ooOol0;Woo000ROol00`00Oomoo`0X
Ool00`00Oomoo`0@Ool00`00Oomoo`0^Ool0029oo`8002Yoo`8000moo`03001oogoo02moo`008Woo
0P00:goo00<007ooOol037oo00<007ooOol0<7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool00`00Oomoo`0ZOol2000<Ool00`00Oomoo`0aOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P00;7oo00<007ooOol02Woo00<007ooOol0<Goo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8002eoo`03001oogoo00=oo`8000=oo`03001o
ogoo039oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0/
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007ooOol0<Woo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8002ioo`05001oogooOol00002Ool3000eOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo0P0017oo0P00;Woo00@007ooOol003]oo`002goo0P002Woo0P00
17oo00<007ooOol00Woo00<007ooOol0;Goo1000>goo000;Ool20004Ool00`00Oomoo`03Ool20002
Ool50002Ool2000`Ool00`00Oomoo`0jOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2
001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04
001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol0
0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2
000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]
Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo
1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol0
0goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo
0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09
Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03
001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007oo
Ool0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;
Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool0
1000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo
10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003
Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool0
1000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04
Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03
001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo
00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002
Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool0
02Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo
011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo
00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool20002Ool50002
Ool00`00Oomoo`0dOolV000<Ool002Qoo`03001oogoo03=oo`80035oo`00:7oo00<007ooOol0<Goo
0P00<goo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0^Ool3000eOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0;Goo0P00=goo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo02]oo`8003Uo
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000ZOol3000jOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol09goo0`00?7oo000@
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo029oo`D003moo`004Goo0P00
2Woo0P0017oo00<007ooOol00Woo00<007ooOol07Goo1P00@goo000XOol00`00Oomoo`0GOol70018
Ool002QooaX004moo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007oo
Oomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000
K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P00
2Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo
0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007oo
Oomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=o
o`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009o
o`03001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo
0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2
000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo
00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04
001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol4
0003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04
Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomo
o`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00
Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo
0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@00
37oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2
001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`00
2goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007oo
Ool000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=o
o`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0
LWoo000GOol00`00Oomoo`02OolQ001DOol001Moo`03001oogoo009oo`03001oogoo01eoo`D0051o
o`005goo00<007ooOol00Woo00<007ooOol08Woo1000C7oo000FOol20004Ool2000WOol50017Ool0
01Moo`03001oogoo009oo`03001oogoo02Yoo`@004Aoo`0077oo00<007ooOol0;Goo0`00@Woo000L
Ool2000`Ool20011Ool001aoo`03001oogoo035oo`8003moo`0077oo0P00<goo0P00?Woo000LOol0
0`00Oomoo`0cOol2000mOol001aoo`03001oogoo03Eoo`8003]oo`002Woo0`0017oo00<007ooOol0
0Woo0`000goo0P00=goo0`00>Goo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007oo
Ool0>7oo0P00>7oo000;Ool00`00Oomoo`0;Ool01000Oomoo`00?7oo00<007ooOol0=Goo000;Ool0
0`00Oomoo`0;Ool00`00Oomoo`02000lOol3000POol8000<Ool000]oo`03001oogoo00Moo`@000=o
o`03001oogoo03eoob4001Aoo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool0
0`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(34569\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29784 m
.008 .2986 L
.012 .30044 L
.016 .3007 L
.02 .29941 L
.024 .29916 L
.028 .29981 L
.032 .2999 L
.036 .29956 L
.04 .29951 L
.044 .29967 L
.048 .29969 L
.052 .29962 L
.056 .29958 L
.06 .29958 L
.064 .29957 L
.068 .29954 L
.072 .29953 L
.076 .29953 L
.08 .29953 L
.084 .29953 L
.088 .29953 L
.092 .29951 L
.096 .29947 L
.1 .29944 L
.104 .29942 L
.108 .29944 L
.112 .29946 L
.116 .29947 L
.12 .29945 L
.124 .29941 L
.128 .29937 L
.132 .29936 L
.136 .29938 L
.14 .29942 L
.144 .29944 L
.148 .29942 L
.152 .29939 L
.156 .29938 L
.16 .29941 L
.164 .29947 L
.168 .29953 L
.172 .29959 L
.176 .29962 L
.18 .29966 L
.184 .29973 L
.188 .29987 L
.192 .30005 L
.196 .30025 L
.2 .30045 L
Mistroke
.204 .30067 L
.208 .30094 L
.212 .30126 L
.216 .30167 L
.22 .30215 L
.224 .30271 L
.228 .30331 L
.232 .30396 L
.236 .30471 L
.24 .30556 L
.244 .30651 L
.248 .30753 L
.252 .30863 L
.256 .30982 L
.26 .31108 L
.264 .31239 L
.268 .31375 L
.272 .31516 L
.276 .3166 L
.28 .31802 L
.284 .31935 L
.288 .32061 L
.292 .32181 L
.296 .32292 L
.3 .32387 L
.304 .32462 L
.308 .32519 L
.312 .32555 L
.316 .32567 L
.32 .32551 L
.324 .32513 L
.328 .3246 L
.332 .32394 L
.336 .32312 L
.34 .32213 L
.344 .32106 L
.348 .32 L
.352 .31901 L
.356 .31812 L
.36 .31738 L
.364 .31689 L
.368 .31671 L
.372 .31678 L
.376 .31706 L
.38 .31759 L
.384 .31848 L
.388 .31979 L
.392 .32145 L
.396 .32334 L
.4 .32545 L
Mistroke
.404 .32782 L
.408 .33047 L
.412 .3334 L
.416 .33666 L
.42 .34041 L
.424 .3448 L
.428 .34981 L
.432 .35533 L
.436 .36131 L
.44 .36786 L
.444 .3751 L
.448 .38304 L
.452 .39142 L
.456 .39992 L
.46 .40823 L
.464 .41602 L
.468 .42288 L
.472 .4284 L
.476 .43225 L
.48 .4343 L
.484 .43449 L
.488 .4327 L
.492 .42887 L
.496 .42313 L
.5 .41604 L
.504 .40845 L
.508 .40122 L
.512 .39503 L
.516 .3903 L
.52 .38739 L
.524 .38655 L
.528 .38784 L
.532 .39101 L
.536 .39551 L
.54 .40063 L
.544 .40559 L
.548 .40954 L
.552 .41152 L
.556 .4107 L
.56 .40671 L
.564 .39993 L
.568 .39135 L
.572 .38217 L
.576 .37333 L
.58 .36537 L
.584 .35862 L
.588 .35328 L
.592 .34935 L
.596 .34639 L
.6 .34341 L
Mistroke
.604 .33928 L
.608 .33317 L
.612 .32481 L
.616 .31441 L
.62 .30243 L
.624 .28967 L
.628 .27748 L
.632 .2678 L
.636 .26245 L
.64 .26227 L
.644 .26665 L
.648 .27389 L
.652 .28224 L
.656 .29054 L
.66 .29818 L
.664 .30455 L
.668 .30893 L
.672 .31089 L
.676 .31088 L
.68 .31004 L
.684 .30933 L
.688 .30869 L
.692 .30711 L
.696 .30372 L
.7 .29872 L
.704 .29342 L
.708 .28919 L
.712 .28661 L
.716 .28548 L
.72 .28574 L
.724 .28802 L
.728 .29312 L
.732 .30062 L
.736 .30827 L
.74 .31286 L
.744 .31226 L
.748 .30684 L
.752 .29918 L
.756 .29233 L
.76 .28803 L
.764 .28647 L
.768 .28723 L
.772 .29013 L
.776 .29525 L
.78 .30174 L
.784 .30739 L
.788 .30953 L
.792 .3068 L
.796 .3006 L
.8 .29427 L
Mistroke
.804 .291 L
.808 .2917 L
.812 .29459 L
.816 .29707 L
.82 .29769 L
.824 .29715 L
.828 .29721 L
.832 .29878 L
.836 .30097 L
.84 .30181 L
.844 .30005 L
.848 .29631 L
.852 .29287 L
.856 .29189 L
.86 .29396 L
.864 .29782 L
.868 .30115 L
.872 .30255 L
.876 .30178 L
.88 .29969 L
.884 .29758 L
.888 .29575 L
.892 .29457 L
.896 .29411 L
.9 .29438 L
.904 .29604 L
.908 .29835 L
.912 .30044 L
.916 .30144 L
.92 .30012 L
.924 .29765 L
.928 .29513 L
.932 .29366 L
.936 .29473 L
.94 .29689 L
.944 .29933 L
.948 .30123 L
.952 .30081 L
.956 .29951 L
.96 .29739 L
.964 .2948 L
.968 .29396 L
.972 .2938 L
.976 .29511 L
.98 .29816 L
.984 .30013 L
.988 .30156 L
.992 .30096 L
.996 .2975 L
1 .29474 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .56042 m
.008 .56616 L
.012 .56821 L
.016 .5664 L
.02 .56571 L
.024 .56621 L
.028 .56651 L
.032 .56632 L
.036 .56625 L
.04 .56627 L
.044 .56633 L
.048 .5663 L
.052 .56631 L
.056 .56629 L
.06 .56631 L
.064 .56629 L
.068 .5663 L
.072 .56629 L
.076 .5663 L
.08 .5663 L
.084 .56631 L
.088 .5663 L
.092 .5663 L
.096 .56629 L
.1 .5663 L
.104 .56629 L
.108 .5663 L
.112 .5663 L
.116 .5663 L
.12 .5663 L
.124 .5663 L
.128 .56629 L
.132 .5663 L
.136 .56629 L
.14 .56629 L
.144 .56629 L
.148 .56629 L
.152 .56629 L
.156 .56629 L
.16 .56628 L
.164 .56628 L
.168 .56627 L
.172 .56626 L
.176 .56625 L
.18 .56624 L
.184 .56623 L
.188 .56621 L
.192 .56619 L
.196 .56616 L
.2 .56612 L
Mistroke
.204 .56608 L
.208 .56604 L
.212 .56598 L
.216 .56591 L
.22 .56583 L
.224 .56573 L
.228 .56562 L
.232 .56548 L
.236 .56532 L
.24 .56514 L
.244 .56493 L
.248 .56468 L
.252 .56441 L
.256 .56409 L
.26 .56374 L
.264 .56334 L
.268 .56291 L
.272 .56242 L
.276 .56189 L
.28 .5613 L
.284 .56068 L
.288 .56 L
.292 .55929 L
.296 .55853 L
.3 .55773 L
.304 .55691 L
.308 .55605 L
.312 .55517 L
.316 .55429 L
.32 .55339 L
.324 .5525 L
.328 .55162 L
.332 .55076 L
.336 .54992 L
.34 .54911 L
.344 .54833 L
.348 .54758 L
.352 .54686 L
.356 .54617 L
.36 .54552 L
.364 .54488 L
.368 .54426 L
.372 .54365 L
.376 .54303 L
.38 .54241 L
.384 .54176 L
.388 .54109 L
.392 .54038 L
.396 .53963 L
.4 .53883 L
Mistroke
.404 .53799 L
.408 .53709 L
.412 .53614 L
.416 .53514 L
.42 .53408 L
.424 .53297 L
.428 .53178 L
.432 .53053 L
.436 .52919 L
.44 .52777 L
.444 .52626 L
.448 .52463 L
.452 .52289 L
.456 .521 L
.46 .51898 L
.464 .51682 L
.468 .51452 L
.472 .5121 L
.476 .50958 L
.48 .50699 L
.484 .50437 L
.488 .50176 L
.492 .49917 L
.496 .49666 L
.5 .49425 L
.504 .49196 L
.508 .48978 L
.512 .48772 L
.516 .48574 L
.52 .48384 L
.524 .48196 L
.528 .48008 L
.532 .47815 L
.536 .47614 L
.54 .47403 L
.544 .47184 L
.548 .46957 L
.552 .46725 L
.556 .46494 L
.56 .46268 L
.564 .46054 L
.568 .45857 L
.572 .45677 L
.576 .45517 L
.58 .45375 L
.584 .45247 L
.588 .45131 L
.592 .45024 L
.596 .44922 L
.6 .44826 L
Mistroke
.604 .44736 L
.608 .44658 L
.612 .44595 L
.616 .44552 L
.62 .44532 L
.624 .44538 L
.628 .44569 L
.632 .44622 L
.636 .4469 L
.64 .44767 L
.644 .44842 L
.648 .44908 L
.652 .4496 L
.656 .44995 L
.66 .45011 L
.664 .4501 L
.668 .44994 L
.672 .44968 L
.676 .44938 L
.68 .44907 L
.684 .44878 L
.688 .44852 L
.692 .44831 L
.696 .44817 L
.7 .44815 L
.704 .44824 L
.708 .44843 L
.712 .44869 L
.716 .449 L
.72 .44929 L
.724 .44954 L
.728 .44968 L
.732 .44969 L
.736 .44955 L
.74 .44932 L
.744 .44907 L
.748 .44889 L
.752 .44884 L
.756 .44892 L
.76 .4491 L
.764 .44933 L
.768 .44957 L
.772 .44976 L
.776 .44988 L
.78 .44989 L
.784 .4498 L
.788 .44965 L
.792 .44949 L
.796 .44939 L
.8 .44939 L
Mistroke
.804 .44945 L
.808 .44956 L
.812 .44965 L
.816 .44973 L
.82 .44979 L
.824 .44986 L
.828 .44993 L
.832 .44998 L
.836 .44999 L
.84 .44997 L
.844 .44993 L
.848 .44994 L
.852 .44999 L
.856 .45008 L
.86 .45016 L
.864 .45021 L
.868 .45021 L
.872 .45018 L
.876 .45014 L
.88 .45013 L
.884 .45015 L
.888 .4502 L
.892 .45026 L
.896 .45032 L
.9 .45037 L
.904 .45043 L
.908 .45046 L
.912 .45049 L
.916 .45051 L
.92 .45053 L
.924 .45055 L
.928 .4506 L
.932 .45064 L
.936 .4507 L
.94 .4507 L
.944 .45071 L
.948 .45067 L
.952 .45064 L
.956 .45063 L
.96 .45067 L
.964 .45074 L
.968 .45087 L
.972 .45095 L
.976 .45105 L
.98 .45105 L
.984 .45104 L
.988 .45099 L
.992 .45098 L
.996 .451 L
1 .45111 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42633 L
.012 .43007 L
.016 .43118 L
.02 .4297 L
.024 .42937 L
.028 .42981 L
.032 .42992 L
.036 .42967 L
.04 .42964 L
.044 .42965 L
.048 .42965 L
.052 .42958 L
.056 .42956 L
.06 .42952 L
.064 .4295 L
.068 .42945 L
.072 .42944 L
.076 .4294 L
.08 .42938 L
.084 .42934 L
.088 .42931 L
.092 .42927 L
.096 .42924 L
.1 .4292 L
.104 .42918 L
.108 .42915 L
.112 .42913 L
.116 .42909 L
.12 .42906 L
.124 .42902 L
.128 .42899 L
.132 .42896 L
.136 .42894 L
.14 .4289 L
.144 .42888 L
.148 .42884 L
.152 .42882 L
.156 .42879 L
.16 .42877 L
.164 .42874 L
.168 .42871 L
.172 .42869 L
.176 .42867 L
.18 .42865 L
.184 .42864 L
.188 .42863 L
.192 .42863 L
.196 .42863 L
.2 .42864 L
Mistroke
.204 .42865 L
.208 .42868 L
.212 .42872 L
.216 .42878 L
.22 .42885 L
.224 .42895 L
.228 .42906 L
.232 .42919 L
.236 .42936 L
.24 .42955 L
.244 .42979 L
.248 .43006 L
.252 .43037 L
.256 .43073 L
.26 .43114 L
.264 .43161 L
.268 .43212 L
.272 .43269 L
.276 .43333 L
.28 .43402 L
.284 .43477 L
.288 .43558 L
.292 .43645 L
.296 .43736 L
.3 .43833 L
.304 .43933 L
.308 .44036 L
.312 .44142 L
.316 .44249 L
.32 .44358 L
.324 .44466 L
.328 .44573 L
.332 .44678 L
.336 .4478 L
.34 .44878 L
.344 .44973 L
.348 .45063 L
.352 .4515 L
.356 .45232 L
.36 .45311 L
.364 .45388 L
.368 .45463 L
.372 .45536 L
.376 .4561 L
.38 .45686 L
.384 .45763 L
.388 .45845 L
.392 .4593 L
.396 .46021 L
.4 .46117 L
Mistroke
.404 .4622 L
.408 .46329 L
.412 .46445 L
.416 .46568 L
.42 .46698 L
.424 .46835 L
.428 .4698 L
.432 .47133 L
.436 .47295 L
.44 .47469 L
.444 .47655 L
.448 .47856 L
.452 .48073 L
.456 .48306 L
.46 .48556 L
.464 .48824 L
.468 .49107 L
.472 .49405 L
.476 .49716 L
.48 .50036 L
.484 .50361 L
.488 .50686 L
.492 .51007 L
.496 .51319 L
.5 .51618 L
.504 .51903 L
.508 .52173 L
.512 .52427 L
.516 .5267 L
.52 .52905 L
.524 .53136 L
.528 .5337 L
.532 .53611 L
.536 .53861 L
.54 .54123 L
.544 .54397 L
.548 .5468 L
.552 .54966 L
.556 .5525 L
.56 .55527 L
.564 .55791 L
.568 .56037 L
.572 .56262 L
.576 .56463 L
.58 .56642 L
.584 .56802 L
.588 .56946 L
.592 .57078 L
.596 .57202 L
.6 .57318 L
Mistroke
.604 .57425 L
.608 .57522 L
.612 .57601 L
.616 .57658 L
.62 .57684 L
.624 .57678 L
.628 .5764 L
.632 .57574 L
.636 .57487 L
.64 .57389 L
.644 .57291 L
.648 .57204 L
.652 .57137 L
.656 .57095 L
.66 .57078 L
.664 .57082 L
.668 .57103 L
.672 .57134 L
.676 .57171 L
.68 .57209 L
.684 .57244 L
.688 .57273 L
.692 .57293 L
.696 .57305 L
.7 .57307 L
.704 .57299 L
.708 .5728 L
.712 .5725 L
.716 .57213 L
.72 .57175 L
.724 .57144 L
.728 .57126 L
.732 .57123 L
.736 .57134 L
.74 .57154 L
.744 .57179 L
.748 .57202 L
.752 .57216 L
.756 .57215 L
.76 .57197 L
.764 .57166 L
.768 .57131 L
.772 .57102 L
.776 .57087 L
.78 .57085 L
.784 .57094 L
.788 .57107 L
.792 .5712 L
.796 .57132 L
.8 .57139 L
Mistroke
.804 .57139 L
.808 .57132 L
.812 .57117 L
.816 .57099 L
.82 .57084 L
.824 .57075 L
.828 .57071 L
.832 .5707 L
.836 .57068 L
.84 .57062 L
.844 .57056 L
.848 .57051 L
.852 .57048 L
.856 .57046 L
.86 .57043 L
.864 .57038 L
.868 .57032 L
.872 .5703 L
.876 .57032 L
.88 .57038 L
.884 .5704 L
.888 .57035 L
.892 .5702 L
.896 .57001 L
.9 .56983 L
.904 .56974 L
.908 .56976 L
.912 .56986 L
.916 .56994 L
.92 .56996 L
.924 .56987 L
.928 .56971 L
.932 .56954 L
.936 .56946 L
.94 .56946 L
.944 .56957 L
.948 .56965 L
.952 .56968 L
.956 .56959 L
.96 .56941 L
.964 .5692 L
.968 .56907 L
.972 .569 L
.976 .56908 L
.98 .56913 L
.984 .56919 L
.988 .56915 L
.992 .56908 L
.996 .56898 L
1 .56898 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00=oo`80009oo`04001oogoo0003Ool0
1000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00003Ool00`00Ool00006Ool01000Oomo
o`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomo
ogoo1P0000Aoo`00000000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo
00<007ooOol0>Woo00@007ooOol000Eoo`80009oo`8002=oo`008Woo0P00>goo00@007ooOol000=o
o`800004Ool007ooOol300000goo00000002000017oo000007oo1`0000=oo`0000000`0037oo000R
OomS000<Ool0029oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`@000=oo`03001oogoo00H000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo0P0000=o
o`00Ool00Woo0P000Woo00<007oo00000P000Woo0P000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool00`00Oomoo`0:Ool0029oo`8001Yoo`L000=oo`<001=oo`03001oogoo031oo`008Woo
00<007ooOol09Goo0P004Goo00<007ooOol0<Goo000ROol2000WOol2000?Ool2000cOol0029oo`80
02Qoo`03001oogoo00aoo`03001oogoo03=oo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0:7oo00<007ooOol02goo00<007ooOol0<goo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8002Uoo`03001oogoo00Yoo`03001oogoo03Aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000ZOol00`00Oomoo`03Ool30003Ool0
0`00Oomoo`0dOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0:Goo0P0017oo00H007oo000007oo000gOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00:goo00D007ooOomoo`0000=oo`<003Moo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool20004Ool2000[Ool01@00Oomoogoo0000?Goo000;Ool2000:Ool20004Ool00`00
Oomoo`02Ool00`00Oomoo`0[Ool00`00Ool0000nOol000]oo`8000Aoo`03001oogoo00=oo`80009o
o`D0009oo`8002eoo`8003ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
0Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000
Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool0
1P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`00
8Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool0
00Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`80
00=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo
00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@0
07ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003
Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo
0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004
Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool3
0003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001o
ogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol0
0goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0
3Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo
00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yo
o`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo
00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo
0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
o`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo
0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001o
ogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo0000
1Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P00
17oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=o
o`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<0
07ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<0
07ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P00
17oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06
001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001o
ogoo001oo`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001o
ogoo039oobP000aoo`00:7oo00<007ooOol0<7oo0P00=7oo000XOol00`00Oomoo`0^Ool3000eOol0
015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo02aoo`<003Moo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol3000iOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0:Goo0P00>goo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8002Qoo`8003eoo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0TOol3000oOol0011oo`04001o
ogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol07goo1P00@Goo000AOol2000:Ool20004
Ool00`00Oomoo`02Ool00`00Oomoo`0JOol60016Ool002Qoo`03001oogoo01Aoo`L004]oo`00:7oo
5`00DWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo0000
0goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool0
0`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<0
07ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004
Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool0
0`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool0
1000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007oo
Ool0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool3
0004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05
001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001o
ogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol0
00Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomo
ogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001o
ogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomo
ogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=o
o`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool5
0003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001ao
o`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00
Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo
10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool2
0008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Mo
o`03001oogoo009ooah005Moo`005goo00<007ooOol00Woo00<007ooOol06goo1000Dgoo000GOol0
0`00Oomoo`02Ool00`00Oomoo`0OOol4001?Ool001Ioo`8000Aoo`8002Aoo`D004Yoo`005goo00<0
07ooOol00Woo00<007ooOol0:7oo0`00Agoo000LOol00`00Oomoo`0[Ool20015Ool001aoo`8002eo
o`<004=oo`0077oo00<007ooOol0;Woo0P00@Woo000LOol2000`Ool20011Ool001aoo`03001oogoo
031oo`80041oo`0077oo00<007ooOol0<Woo0P00?Woo000:Ool30004Ool00`00Oomoo`02Ool30003
Ool2000dOol3000lOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`0eOol2
000kOol000]oo`03001oogoo00]oo`04001oogoo000iOol2000iOol000]oo`03001oogoo00]oo`03
001oogoo008003Uoo`<001moo`800003Ool0000000L000aoo`002goo00<007ooOol01goo10000goo
00<007ooOol0>Woo900057oo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03
001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(34736\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29764 m
.008 .2995 L
.012 .30031 L
.016 .30042 L
.02 .29967 L
.024 .29935 L
.028 .29971 L
.032 .29989 L
.036 .2997 L
.04 .29956 L
.044 .29962 L
.048 .29969 L
.052 .29969 L
.056 .29966 L
.06 .29964 L
.064 .29961 L
.068 .29957 L
.072 .29955 L
.076 .29956 L
.08 .29958 L
.084 .29959 L
.088 .29959 L
.092 .29956 L
.096 .29951 L
.1 .29948 L
.104 .29948 L
.108 .2995 L
.112 .29953 L
.116 .29955 L
.12 .29955 L
.124 .29953 L
.128 .29951 L
.132 .29952 L
.136 .29956 L
.14 .29961 L
.144 .29967 L
.148 .29973 L
.152 .2998 L
.156 .2999 L
.16 .3 L
.164 .30013 L
.168 .30029 L
.172 .30049 L
.176 .30073 L
.18 .30103 L
.184 .30139 L
.188 .30181 L
.192 .30226 L
.196 .30274 L
.2 .30329 L
Mistroke
.204 .30395 L
.208 .30473 L
.212 .30562 L
.216 .30659 L
.22 .30762 L
.224 .30871 L
.228 .30985 L
.232 .31108 L
.236 .31242 L
.24 .31387 L
.244 .31535 L
.248 .31681 L
.252 .31823 L
.256 .3196 L
.26 .32094 L
.264 .32222 L
.268 .32339 L
.272 .32443 L
.276 .32529 L
.28 .32593 L
.284 .32632 L
.288 .32647 L
.292 .32644 L
.296 .32623 L
.3 .32579 L
.304 .32511 L
.308 .32424 L
.312 .32325 L
.316 .32218 L
.32 .32109 L
.324 .32004 L
.328 .31914 L
.332 .3184 L
.336 .31783 L
.34 .31743 L
.344 .31728 L
.348 .31748 L
.352 .31807 L
.356 .31899 L
.36 .32021 L
.364 .32172 L
.368 .32354 L
.372 .32562 L
.376 .32794 L
.38 .33053 L
.384 .3335 L
.388 .33691 L
.392 .34072 L
.396 .34489 L
.4 .3495 L
Mistroke
.404 .3547 L
.408 .36062 L
.412 .36725 L
.416 .37451 L
.42 .38235 L
.424 .39063 L
.428 .39911 L
.432 .40743 L
.436 .41529 L
.44 .42243 L
.444 .42861 L
.448 .43346 L
.452 .4365 L
.456 .43735 L
.46 .43595 L
.464 .43249 L
.468 .42732 L
.472 .42084 L
.476 .41358 L
.48 .4062 L
.484 .39941 L
.488 .39383 L
.492 .38989 L
.496 .38795 L
.5 .38827 L
.504 .39087 L
.508 .39531 L
.512 .40071 L
.516 .40595 L
.52 .41003 L
.524 .41228 L
.528 .41225 L
.532 .4097 L
.536 .4046 L
.54 .39725 L
.544 .38835 L
.548 .37881 L
.552 .36957 L
.556 .36137 L
.56 .35473 L
.564 .34989 L
.568 .34664 L
.572 .34417 L
.576 .34117 L
.58 .33629 L
.584 .32873 L
.588 .31854 L
.592 .30655 L
.596 .29393 L
.6 .28191 L
Mistroke
.604 .27175 L
.608 .26467 L
.612 .26171 L
.616 .26325 L
.62 .26875 L
.624 .27691 L
.628 .28619 L
.632 .2953 L
.636 .30321 L
.64 .30909 L
.644 .31228 L
.648 .31272 L
.652 .31119 L
.656 .30908 L
.66 .30746 L
.664 .30638 L
.668 .30492 L
.672 .30204 L
.676 .29758 L
.68 .29242 L
.684 .28787 L
.688 .28491 L
.692 .28407 L
.696 .28572 L
.7 .29017 L
.704 .29717 L
.708 .30516 L
.712 .31147 L
.716 .31352 L
.72 .31041 L
.724 .30362 L
.728 .29595 L
.732 .28995 L
.736 .28675 L
.74 .28628 L
.744 .28825 L
.748 .29247 L
.752 .29845 L
.756 .30461 L
.76 .30851 L
.764 .30829 L
.768 .30409 L
.772 .29829 L
.776 .29386 L
.78 .29242 L
.784 .29336 L
.788 .29481 L
.792 .29554 L
.796 .29585 L
.8 .29694 L
Mistroke
.804 .29927 L
.808 .30175 L
.812 .30252 L
.816 .30061 L
.82 .29697 L
.824 .29384 L
.828 .29304 L
.832 .29461 L
.836 .29709 L
.84 .2989 L
.844 .29953 L
.848 .29979 L
.852 .30041 L
.856 .30104 L
.86 .30056 L
.864 .29792 L
.868 .29393 L
.872 .29091 L
.876 .29101 L
.88 .29502 L
.884 .30066 L
.888 .30458 L
.892 .30451 L
.896 .30016 L
.9 .29466 L
.904 .29131 L
.908 .29188 L
.912 .29623 L
.916 .30103 L
.92 .30355 L
.924 .30266 L
.928 .29851 L
.932 .29431 L
.936 .29216 L
.94 .29282 L
.944 .29646 L
.948 .30005 L
.952 .30185 L
.956 .30129 L
.96 .29782 L
.964 .29456 L
.968 .29325 L
.972 .2943 L
.976 .29842 L
.98 .3021 L
.984 .30317 L
.988 .30144 L
.992 .29629 L
.996 .29175 L
1 .29054 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57027 m
.008 .56573 L
.012 .56436 L
.016 .56601 L
.02 .56645 L
.024 .5658 L
.028 .56571 L
.032 .56591 L
.036 .56598 L
.04 .56587 L
.044 .56587 L
.048 .56588 L
.052 .56591 L
.056 .56588 L
.06 .56589 L
.064 .56588 L
.068 .5659 L
.072 .56588 L
.076 .5659 L
.08 .56589 L
.084 .56589 L
.088 .56588 L
.092 .56589 L
.096 .56588 L
.1 .56589 L
.104 .56589 L
.108 .56589 L
.112 .56588 L
.116 .56588 L
.12 .56587 L
.124 .56588 L
.128 .56587 L
.132 .56588 L
.136 .56587 L
.14 .56587 L
.144 .56585 L
.148 .56585 L
.152 .56583 L
.156 .56582 L
.16 .5658 L
.164 .56578 L
.168 .56576 L
.172 .56573 L
.176 .56569 L
.18 .56565 L
.184 .56559 L
.188 .56552 L
.192 .56544 L
.196 .56535 L
.2 .56524 L
Mistroke
.204 .56511 L
.208 .56496 L
.212 .56478 L
.216 .56458 L
.22 .56434 L
.224 .56408 L
.228 .56377 L
.232 .56343 L
.236 .56305 L
.24 .56262 L
.244 .56215 L
.248 .56164 L
.252 .56107 L
.256 .56045 L
.26 .55979 L
.264 .55909 L
.268 .55834 L
.272 .55756 L
.276 .55674 L
.28 .5559 L
.284 .55503 L
.288 .55415 L
.292 .55326 L
.296 .55237 L
.3 .55148 L
.304 .55061 L
.308 .54976 L
.312 .54894 L
.316 .54815 L
.32 .54739 L
.324 .54667 L
.328 .54597 L
.332 .54531 L
.336 .54466 L
.34 .54404 L
.344 .54342 L
.348 .54281 L
.352 .54219 L
.356 .54155 L
.36 .54089 L
.364 .5402 L
.368 .53946 L
.372 .53868 L
.376 .53785 L
.38 .53696 L
.384 .53603 L
.388 .53504 L
.392 .534 L
.396 .5329 L
.4 .53173 L
Mistroke
.404 .5305 L
.408 .52919 L
.412 .5278 L
.416 .52631 L
.42 .52472 L
.424 .523 L
.428 .52116 L
.432 .51918 L
.436 .51707 L
.44 .51483 L
.444 .51246 L
.448 .50998 L
.452 .50742 L
.456 .50481 L
.46 .50218 L
.464 .49958 L
.468 .49704 L
.472 .49459 L
.476 .49226 L
.48 .49004 L
.484 .48794 L
.488 .48594 L
.492 .48402 L
.496 .48213 L
.5 .48025 L
.504 .47835 L
.508 .47637 L
.512 .47431 L
.516 .47216 L
.52 .46993 L
.524 .46764 L
.528 .46534 L
.532 .46308 L
.536 .4609 L
.54 .45886 L
.544 .45699 L
.548 .4553 L
.552 .4538 L
.556 .45248 L
.56 .45129 L
.564 .45022 L
.568 .44922 L
.572 .44828 L
.576 .4474 L
.58 .44659 L
.584 .4459 L
.588 .44539 L
.592 .44509 L
.596 .44504 L
.6 .44525 L
Mistroke
.604 .4457 L
.608 .44634 L
.612 .44709 L
.616 .44787 L
.62 .44859 L
.624 .44917 L
.628 .44959 L
.632 .44981 L
.636 .44986 L
.64 .44975 L
.644 .44952 L
.648 .44922 L
.652 .44891 L
.656 .44861 L
.66 .44834 L
.664 .44812 L
.668 .44797 L
.672 .44789 L
.676 .44792 L
.68 .44806 L
.684 .44828 L
.688 .44857 L
.692 .44887 L
.696 .44914 L
.7 .44934 L
.704 .44943 L
.708 .44938 L
.712 .44921 L
.716 .44897 L
.72 .44874 L
.724 .44859 L
.728 .44857 L
.732 .44868 L
.736 .44889 L
.74 .44915 L
.744 .4494 L
.748 .44959 L
.752 .44967 L
.756 .44963 L
.76 .44949 L
.764 .44931 L
.768 .44916 L
.772 .44909 L
.776 .44911 L
.78 .4492 L
.784 .44931 L
.788 .44942 L
.792 .44952 L
.796 .4496 L
.8 .44966 L
Mistroke
.804 .4497 L
.808 .4497 L
.812 .44967 L
.816 .44966 L
.82 .44967 L
.824 .44973 L
.828 .4498 L
.832 .44986 L
.836 .4499 L
.84 .4499 L
.844 .4499 L
.848 .4499 L
.852 .4499 L
.856 .4499 L
.86 .4499 L
.864 .44991 L
.868 .44996 L
.872 .45006 L
.876 .45016 L
.88 .45025 L
.884 .45028 L
.888 .45025 L
.892 .45021 L
.896 .45019 L
.9 .45025 L
.904 .45035 L
.908 .45045 L
.912 .45051 L
.916 .45047 L
.92 .45039 L
.924 .45029 L
.928 .45026 L
.932 .45033 L
.936 .45047 L
.94 .45064 L
.944 .45077 L
.948 .4508 L
.952 .45079 L
.956 .45071 L
.96 .45067 L
.964 .45067 L
.968 .45074 L
.972 .45081 L
.976 .45088 L
.98 .45087 L
.984 .45086 L
.988 .45081 L
.992 .45085 L
.996 .4509 L
1 .45102 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42549 L
.012 .42973 L
.016 .43134 L
.02 .42993 L
.024 .42936 L
.028 .4297 L
.032 .42991 L
.036 .42973 L
.04 .42965 L
.044 .42963 L
.048 .42965 L
.052 .42958 L
.056 .42956 L
.06 .42951 L
.064 .4295 L
.068 .42946 L
.072 .42944 L
.076 .4294 L
.08 .42938 L
.084 .42933 L
.088 .42931 L
.092 .42927 L
.096 .42925 L
.1 .42921 L
.104 .42919 L
.108 .42916 L
.112 .42913 L
.116 .42909 L
.12 .42907 L
.124 .42903 L
.128 .42901 L
.132 .42898 L
.136 .42896 L
.14 .42893 L
.144 .42891 L
.148 .42889 L
.152 .42887 L
.156 .42885 L
.16 .42884 L
.164 .42884 L
.168 .42884 L
.172 .42885 L
.176 .42887 L
.18 .42889 L
.184 .42893 L
.188 .42898 L
.192 .42904 L
.196 .42912 L
.2 .42923 L
Mistroke
.204 .42937 L
.208 .42953 L
.212 .42972 L
.216 .42994 L
.22 .43019 L
.224 .43049 L
.228 .43084 L
.232 .43123 L
.236 .43168 L
.24 .43219 L
.244 .43274 L
.248 .43336 L
.252 .43403 L
.256 .43476 L
.26 .43555 L
.264 .4364 L
.268 .4373 L
.272 .43825 L
.276 .43924 L
.28 .44026 L
.284 .44131 L
.288 .44239 L
.292 .44347 L
.296 .44455 L
.3 .44562 L
.304 .44667 L
.308 .4477 L
.312 .44869 L
.316 .44965 L
.32 .45057 L
.324 .45145 L
.328 .45229 L
.332 .45309 L
.336 .45386 L
.34 .45461 L
.344 .45535 L
.348 .45609 L
.352 .45684 L
.356 .45761 L
.36 .45841 L
.364 .45925 L
.368 .46014 L
.372 .46108 L
.376 .46209 L
.38 .46316 L
.384 .4643 L
.388 .46551 L
.392 .46678 L
.396 .46813 L
.4 .46956 L
Mistroke
.404 .47107 L
.408 .47268 L
.412 .47439 L
.416 .47622 L
.42 .47818 L
.424 .48029 L
.428 .48255 L
.432 .48499 L
.436 .48761 L
.44 .49039 L
.444 .49333 L
.448 .4964 L
.452 .49957 L
.456 .50279 L
.46 .50604 L
.464 .50925 L
.468 .5124 L
.472 .51544 L
.476 .51835 L
.48 .52111 L
.484 .52372 L
.488 .52619 L
.492 .52857 L
.496 .53088 L
.5 .5332 L
.504 .53556 L
.508 .53801 L
.512 .54057 L
.516 .54324 L
.52 .54602 L
.524 .54887 L
.528 .55173 L
.532 .55454 L
.536 .55723 L
.54 .55975 L
.544 .56207 L
.548 .56415 L
.552 .56601 L
.556 .56766 L
.56 .56914 L
.564 .57049 L
.568 .57175 L
.572 .57292 L
.576 .574 L
.58 .57497 L
.584 .5758 L
.588 .57641 L
.592 .57678 L
.596 .57684 L
.6 .5766 L
Mistroke
.604 .57605 L
.608 .57528 L
.612 .57435 L
.616 .57337 L
.62 .57244 L
.624 .57166 L
.628 .57111 L
.632 .57081 L
.636 .57076 L
.64 .57092 L
.644 .57121 L
.648 .57159 L
.652 .57199 L
.656 .57238 L
.66 .5727 L
.664 .57294 L
.668 .57308 L
.672 .57313 L
.676 .57307 L
.68 .57292 L
.684 .57266 L
.688 .57233 L
.692 .57196 L
.696 .57162 L
.7 .57138 L
.704 .57128 L
.708 .57132 L
.712 .57148 L
.716 .57171 L
.72 .57195 L
.724 .57213 L
.728 .57219 L
.732 .57209 L
.736 .57185 L
.74 .57153 L
.744 .57122 L
.748 .571 L
.752 .57091 L
.756 .57093 L
.76 .57103 L
.764 .57116 L
.768 .57129 L
.772 .57139 L
.776 .57144 L
.78 .5714 L
.784 .57129 L
.788 .57113 L
.792 .57098 L
.796 .57086 L
.8 .57079 L
Mistroke
.804 .57074 L
.808 .57069 L
.812 .57064 L
.816 .57059 L
.82 .57058 L
.824 .57058 L
.828 .57057 L
.832 .57053 L
.836 .57045 L
.84 .57036 L
.844 .57032 L
.848 .57034 L
.852 .5704 L
.856 .57044 L
.86 .5704 L
.864 .57029 L
.868 .57013 L
.872 .56997 L
.876 .56988 L
.88 .56986 L
.884 .56988 L
.888 .56991 L
.892 .56991 L
.896 .56988 L
.9 .56981 L
.904 .56973 L
.908 .56965 L
.912 .5696 L
.916 .56955 L
.92 .56955 L
.924 .56954 L
.928 .56955 L
.932 .56953 L
.936 .56947 L
.94 .56936 L
.944 .56925 L
.948 .56914 L
.952 .5691 L
.956 .56907 L
.96 .56911 L
.964 .56913 L
.968 .56914 L
.972 .56909 L
.976 .56903 L
.98 .56889 L
.984 .56882 L
.988 .56871 L
.992 .5687 L
.996 .56868 L
1 .5687 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo0080009oo`04001oogoo0002Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04
001oogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04
001oogooOol60002Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029o
o`03001oogoo03Qoo`03001oo`0000Eoo`8000=oo`8002Eoo`008Woo0P00>7oo00D007ooOomoo`00
00=oo`09001oo`00001oo`00Ool007oo00@00005Ool00000001oo`03000017oo000007oo0P0000Ao
o`00001oo`8000aoo`008WooH`0037oo000ROol01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`06001oogooOol007oo100000=oo`00Ool00Woo1@000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Ool007oo00000Woo0`0000=oo`00Ool00Woo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000aoo`008Woo0P005goo20000Woo
0`004goo00<007ooOol0<goo000ROol00`00Oomoo`0ROol2000BOol00`00Oomoo`0cOol0029oo`80
02Aoo`8000moo`8003Ioo`008Woo0P009Woo00<007ooOol037oo00<007ooOol0=Goo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0UOol00`00Oomoo`0;Ool00`00Oomoo`0f
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P009goo00<007ooOol0
2Woo00<007ooOol0=Woo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
02Moo`03001oogoo00Aoo`8000=oo`03001oogoo03Moo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`02Ool200001Goo001oogoo0000>Goo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8002Qoo`03001oogoo009o
o`03001oogoo00<003Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2000YOol0
0`00Oomoo`020003Ool2000jOol000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo02Qo
o`04001oogoo0010Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8002Yoo`80045o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04
001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool0
1000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool0
1P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`00
8Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<0
07ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03
001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00
Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo
000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00
Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000
Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool0
1000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool5
0003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogoo
Ool00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo
00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009o
o`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool0
0`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo
0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomo
o`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00
:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomo
o`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol0
47oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<0
07ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@0
07ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Ool006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
0P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00
Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00
Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo02moob/000aoo`00:7oo
00<007ooOol0;Goo0`00=Woo000XOol00`00Oomoo`0/Ool2000hOol0015oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`03001oogoo02Uoo`<003Yoo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`0XOol2000lOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol09Woo0`00?Goo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8002Eoo`<003moo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`0ROol30011Ool0011oo`04001oogoo0008Ool01000Oomoo`00
0Woo0P0017oo00<007ooOol07Goo1@00A7oo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00
Oomoo`0HOol60018Ool002Qoo`80015oo`P004ioo`00:7oo5000EGoo000XOol00`00Oomoo`1VOol0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002
Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Ao
o`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool3
0004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool2
0005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`00
2Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@0
07ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eo
o`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo
00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03
001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005
Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03
001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo
000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0
LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009ooa/005Yoo`005goo
00<007ooOol00Woo00<007ooOol067oo1000EWoo000GOol00`00Oomoo`02Ool00`00Oomoo`0LOol5
001AOol001Ioo`8000Aoo`80025oo`D004eoo`005goo00<007ooOol00Woo00<007ooOol09Goo0`00
BWoo000LOol00`00Oomoo`0XOol20018Ool001aoo`8002]oo`8004Ioo`0077oo00<007ooOol0:goo
0P00AGoo000LOol2000]Ool20014Ool001aoo`03001oogoo02ioo`80049oo`0077oo00<007ooOol0
;goo0P00@Goo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2000bOol2000oOol000]oo`03001o
ogoo00Moo`05001oogooOol00002Ool00`00Oomoo`0cOol00`00Oomoo`0lOol000]oo`03001oogoo
00]oo`04001oogoo000fOol2000lOol000]oo`03001oogoo00]oo`03001oogoo008003Ioo`<0029o
o``000aoo`002goo00<007ooOol01goo10000goo00<007ooOol0>7oo8`005goo000:Ool20009Ool0
0`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(34903\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30134 m
.008 .30089 L
.012 .29917 L
.016 .2989 L
.02 .30004 L
.024 .30022 L
.028 .29962 L
.032 .29954 L
.036 .29982 L
.04 .29982 L
.044 .29966 L
.048 .29962 L
.052 .29968 L
.056 .29969 L
.06 .29967 L
.064 .29966 L
.068 .29966 L
.072 .29965 L
.076 .29964 L
.08 .29962 L
.084 .29962 L
.088 .29961 L
.092 .29962 L
.096 .29964 L
.1 .29967 L
.104 .29969 L
.108 .29971 L
.112 .29972 L
.116 .29974 L
.12 .29979 L
.124 .29989 L
.128 .3 L
.132 .30013 L
.136 .30026 L
.14 .30041 L
.144 .30058 L
.148 .3008 L
.152 .3011 L
.156 .30146 L
.16 .30186 L
.164 .3023 L
.168 .30279 L
.172 .30336 L
.176 .30403 L
.18 .3048 L
.184 .30566 L
.188 .30661 L
.192 .30762 L
.196 .3087 L
.2 .30987 L
Mistroke
.204 .31116 L
.208 .31255 L
.212 .314 L
.216 .31547 L
.22 .31694 L
.224 .31839 L
.228 .31982 L
.232 .32123 L
.236 .32259 L
.24 .32387 L
.244 .32499 L
.248 .3259 L
.252 .32658 L
.256 .32706 L
.26 .32734 L
.264 .32741 L
.268 .32724 L
.272 .32684 L
.276 .32621 L
.28 .32539 L
.284 .32441 L
.288 .32334 L
.292 .32225 L
.296 .3212 L
.3 .32021 L
.304 .31932 L
.308 .3186 L
.312 .31815 L
.316 .31799 L
.32 .31814 L
.324 .3186 L
.328 .3194 L
.332 .32054 L
.336 .32198 L
.34 .32371 L
.344 .32573 L
.348 .32809 L
.352 .33079 L
.356 .33378 L
.36 .33704 L
.364 .34065 L
.368 .34473 L
.372 .34932 L
.376 .35448 L
.38 .36025 L
.384 .3667 L
.388 .37383 L
.392 .38153 L
.396 .38963 L
.4 .39798 L
Mistroke
.404 .40642 L
.408 .41471 L
.412 .42241 L
.416 .42907 L
.42 .43428 L
.424 .43778 L
.428 .43935 L
.432 .43883 L
.436 .43621 L
.44 .43172 L
.444 .42576 L
.448 .41876 L
.452 .41124 L
.456 .40383 L
.46 .39733 L
.464 .39252 L
.468 .38993 L
.472 .38968 L
.476 .39157 L
.48 .39519 L
.484 .4 L
.488 .4052 L
.492 .40989 L
.496 .41317 L
.5 .41436 L
.504 .41303 L
.508 .40899 L
.512 .40235 L
.516 .39359 L
.52 .38367 L
.524 .37378 L
.528 .36497 L
.532 .3578 L
.536 .35231 L
.54 .34815 L
.544 .34474 L
.548 .34131 L
.552 .33697 L
.556 .33089 L
.56 .32254 L
.564 .312 L
.568 .29991 L
.572 .2874 L
.576 .27581 L
.58 .2666 L
.584 .26113 L
.588 .26038 L
.592 .26444 L
.596 .27237 L
.6 .28235 L
Mistroke
.604 .29241 L
.608 .30103 L
.612 .30742 L
.616 .3114 L
.62 .3131 L
.624 .31288 L
.628 .31136 L
.632 .30928 L
.636 .30716 L
.64 .30499 L
.644 .30228 L
.648 .29864 L
.652 .29427 L
.656 .29001 L
.66 .28682 L
.664 .28535 L
.668 .28584 L
.672 .28843 L
.676 .29317 L
.68 .29969 L
.684 .30662 L
.688 .31172 L
.692 .3129 L
.696 .30944 L
.7 .30256 L
.704 .29472 L
.708 .28833 L
.712 .28489 L
.716 .28493 L
.72 .28834 L
.724 .29446 L
.728 .30177 L
.732 .30784 L
.736 .31023 L
.74 .30794 L
.744 .30227 L
.748 .29615 L
.752 .2923 L
.756 .2916 L
.76 .29299 L
.764 .2948 L
.768 .29619 L
.772 .29747 L
.776 .29913 L
.78 .30084 L
.784 .30151 L
.788 .30036 L
.792 .2979 L
.796 .29568 L
.8 .29499 L
Mistroke
.804 .29583 L
.808 .29697 L
.812 .29736 L
.816 .29719 L
.82 .29763 L
.824 .29951 L
.828 .30202 L
.832 .303 L
.836 .30083 L
.84 .29595 L
.844 .29119 L
.848 .28977 L
.852 .29277 L
.856 .29854 L
.86 .30333 L
.864 .30431 L
.868 .30143 L
.872 .29679 L
.876 .29368 L
.88 .29366 L
.884 .29599 L
.888 .29899 L
.892 .30053 L
.896 .30017 L
.9 .29881 L
.904 .29705 L
.908 .29607 L
.912 .29577 L
.916 .29578 L
.92 .29658 L
.924 .29751 L
.928 .29858 L
.932 .29962 L
.936 .29937 L
.94 .29851 L
.944 .29728 L
.948 .29604 L
.952 .29625 L
.956 .29701 L
.96 .29792 L
.964 .2989 L
.968 .29857 L
.972 .29795 L
.976 .29733 L
.98 .29624 L
.984 .29604 L
.988 .29601 L
.992 .29635 L
.996 .29801 L
1 .29954 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57219 m
.008 .56555 L
.012 .56333 L
.016 .56536 L
.02 .5662 L
.024 .56552 L
.028 .56526 L
.032 .56544 L
.036 .56557 L
.04 .56548 L
.044 .56546 L
.048 .56546 L
.052 .5655 L
.056 .56547 L
.06 .56548 L
.064 .56547 L
.068 .56549 L
.072 .56547 L
.076 .56548 L
.08 .56547 L
.084 .56548 L
.088 .56547 L
.092 .56548 L
.096 .56547 L
.1 .56548 L
.104 .56547 L
.108 .56547 L
.112 .56545 L
.116 .56545 L
.12 .56543 L
.124 .56543 L
.128 .56542 L
.132 .56541 L
.136 .56538 L
.14 .56536 L
.144 .56532 L
.148 .56529 L
.152 .56524 L
.156 .5652 L
.16 .56513 L
.164 .56506 L
.168 .56497 L
.172 .56486 L
.176 .56474 L
.18 .56459 L
.184 .56442 L
.188 .56422 L
.192 .564 L
.196 .56374 L
.2 .56345 L
Mistroke
.204 .56313 L
.208 .56275 L
.212 .56234 L
.216 .56188 L
.22 .56137 L
.224 .56082 L
.228 .56023 L
.232 .55959 L
.236 .5589 L
.24 .55816 L
.244 .55739 L
.248 .55658 L
.252 .55574 L
.256 .55488 L
.26 .554 L
.264 .55312 L
.268 .55223 L
.272 .55134 L
.276 .55047 L
.28 .54961 L
.284 .54878 L
.288 .54798 L
.292 .54721 L
.296 .54648 L
.3 .54577 L
.304 .5451 L
.308 .54445 L
.312 .54382 L
.316 .5432 L
.32 .54259 L
.324 .54197 L
.328 .54134 L
.332 .54069 L
.336 .54 L
.34 .53928 L
.344 .53852 L
.348 .5377 L
.352 .53684 L
.356 .53592 L
.36 .53495 L
.364 .53391 L
.368 .53283 L
.372 .53168 L
.376 .53046 L
.38 .52918 L
.384 .52781 L
.388 .52636 L
.392 .52479 L
.396 .52312 L
.4 .52132 L
Mistroke
.404 .51939 L
.408 .51732 L
.412 .51512 L
.416 .51279 L
.42 .51035 L
.424 .50782 L
.428 .50523 L
.432 .50262 L
.436 .50001 L
.44 .49745 L
.444 .49497 L
.448 .49258 L
.452 .49031 L
.456 .48816 L
.46 .48613 L
.464 .48418 L
.468 .4823 L
.472 .48043 L
.476 .47855 L
.48 .4766 L
.484 .47458 L
.488 .47247 L
.492 .47027 L
.496 .46802 L
.5 .46573 L
.504 .46346 L
.508 .46126 L
.512 .45917 L
.516 .45723 L
.52 .45548 L
.524 .45391 L
.528 .45252 L
.532 .4513 L
.536 .45019 L
.54 .44918 L
.544 .44825 L
.548 .44738 L
.552 .44658 L
.556 .44588 L
.56 .44532 L
.564 .44494 L
.568 .44479 L
.572 .44488 L
.576 .44522 L
.58 .44577 L
.584 .44648 L
.588 .44727 L
.592 .44804 L
.596 .44871 L
.6 .44922 L
Mistroke
.604 .44952 L
.608 .44963 L
.612 .44956 L
.616 .44935 L
.62 .44906 L
.624 .44874 L
.628 .44842 L
.632 .44815 L
.636 .44793 L
.64 .44776 L
.644 .44767 L
.648 .44766 L
.652 .44774 L
.656 .44791 L
.66 .44815 L
.664 .44844 L
.668 .44872 L
.672 .44896 L
.676 .44912 L
.68 .44915 L
.684 .44906 L
.688 .44886 L
.692 .44862 L
.696 .44842 L
.7 .44831 L
.704 .44833 L
.708 .44848 L
.712 .44871 L
.716 .44897 L
.72 .44921 L
.724 .44936 L
.728 .4494 L
.732 .44933 L
.736 .44917 L
.74 .449 L
.744 .44887 L
.748 .44882 L
.752 .44885 L
.756 .44894 L
.76 .44905 L
.764 .44918 L
.768 .4493 L
.772 .44939 L
.776 .44945 L
.78 .44946 L
.784 .44943 L
.788 .4494 L
.792 .44939 L
.796 .44942 L
.8 .44947 L
Mistroke
.804 .44954 L
.808 .44959 L
.812 .44963 L
.816 .44965 L
.82 .44966 L
.824 .44966 L
.828 .44964 L
.832 .4496 L
.836 .44959 L
.84 .44963 L
.844 .44973 L
.848 .44987 L
.852 .44997 L
.856 .45002 L
.86 .45 L
.864 .44995 L
.868 .44992 L
.872 .44995 L
.876 .45003 L
.88 .45012 L
.884 .45018 L
.888 .45018 L
.892 .45014 L
.896 .45009 L
.9 .45007 L
.904 .45009 L
.908 .45016 L
.912 .45026 L
.916 .45036 L
.92 .45045 L
.924 .45051 L
.928 .45054 L
.932 .45051 L
.936 .45048 L
.94 .45044 L
.944 .45043 L
.948 .45043 L
.952 .45049 L
.956 .45055 L
.96 .45064 L
.964 .45069 L
.968 .45074 L
.972 .45074 L
.976 .45077 L
.98 .45077 L
.984 .45082 L
.988 .45084 L
.992 .45091 L
.996 .45093 L
1 .45096 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43276 L
.012 .42965 L
.016 .42888 L
.02 .42996 L
.024 .4302 L
.028 .4297 L
.032 .42963 L
.036 .42973 L
.04 .42974 L
.044 .42962 L
.048 .42961 L
.052 .42958 L
.056 .42958 L
.06 .42952 L
.064 .42951 L
.068 .42946 L
.072 .42944 L
.076 .4294 L
.08 .42938 L
.084 .42934 L
.088 .42932 L
.092 .42928 L
.096 .42926 L
.1 .42923 L
.104 .42921 L
.108 .42917 L
.112 .42915 L
.116 .42912 L
.12 .42911 L
.124 .42909 L
.128 .42908 L
.132 .42906 L
.136 .42906 L
.14 .42905 L
.144 .42906 L
.148 .42907 L
.152 .4291 L
.156 .42913 L
.16 .42918 L
.164 .42924 L
.168 .42932 L
.172 .42942 L
.176 .42954 L
.18 .42969 L
.184 .42987 L
.188 .43008 L
.192 .43033 L
.196 .43062 L
.2 .43096 L
Mistroke
.204 .43134 L
.208 .43177 L
.212 .43225 L
.216 .43279 L
.22 .43338 L
.224 .43404 L
.228 .43476 L
.232 .43553 L
.236 .43637 L
.24 .43725 L
.244 .43818 L
.248 .43915 L
.252 .44016 L
.256 .4412 L
.26 .44227 L
.264 .44335 L
.268 .44443 L
.272 .44551 L
.276 .44657 L
.28 .4476 L
.284 .44861 L
.288 .44958 L
.292 .45051 L
.296 .4514 L
.3 .45225 L
.304 .45306 L
.308 .45385 L
.312 .4546 L
.316 .45534 L
.32 .45608 L
.324 .45682 L
.328 .45758 L
.332 .45837 L
.336 .45919 L
.34 .46007 L
.344 .461 L
.348 .46199 L
.352 .46304 L
.356 .46416 L
.36 .46534 L
.364 .4666 L
.368 .46793 L
.372 .46933 L
.376 .47082 L
.38 .4724 L
.384 .47409 L
.388 .47588 L
.392 .4778 L
.396 .47986 L
.4 .48208 L
Mistroke
.404 .48446 L
.408 .48702 L
.412 .48974 L
.416 .49262 L
.42 .49564 L
.424 .49877 L
.428 .50198 L
.432 .50522 L
.436 .50845 L
.44 .51162 L
.444 .5147 L
.448 .51765 L
.452 .52046 L
.456 .52311 L
.46 .52564 L
.464 .52806 L
.468 .5304 L
.472 .53272 L
.476 .53506 L
.48 .53745 L
.484 .53995 L
.488 .54256 L
.492 .54528 L
.496 .54808 L
.5 .55093 L
.504 .55376 L
.508 .5565 L
.512 .5591 L
.516 .56149 L
.52 .56366 L
.524 .5656 L
.528 .56731 L
.532 .56884 L
.536 .5702 L
.54 .57146 L
.544 .57262 L
.548 .57372 L
.552 .57471 L
.556 .57558 L
.56 .57627 L
.564 .57672 L
.568 .57689 L
.572 .57676 L
.576 .57632 L
.58 .57562 L
.584 .57475 L
.588 .57379 L
.592 .57284 L
.596 .57201 L
.6 .57136 L
Mistroke
.604 .57094 L
.608 .57078 L
.612 .57084 L
.616 .57108 L
.62 .57144 L
.624 .57185 L
.628 .57226 L
.632 .57263 L
.636 .57292 L
.64 .57312 L
.644 .5732 L
.648 .57317 L
.652 .57304 L
.656 .57281 L
.66 .5725 L
.664 .57215 L
.668 .5718 L
.672 .57152 L
.676 .57135 L
.68 .57133 L
.684 .57143 L
.688 .57164 L
.692 .57188 L
.696 .57209 L
.7 .57221 L
.704 .57219 L
.708 .57203 L
.712 .57174 L
.716 .57142 L
.72 .57114 L
.724 .57097 L
.728 .57093 L
.732 .571 L
.736 .57114 L
.74 .5713 L
.744 .57142 L
.748 .57149 L
.752 .57147 L
.756 .57137 L
.76 .57122 L
.764 .57107 L
.768 .57095 L
.772 .57087 L
.776 .57082 L
.78 .57077 L
.784 .57071 L
.788 .57066 L
.792 .57062 L
.796 .5706 L
.8 .5706 L
Mistroke
.804 .57057 L
.808 .57052 L
.812 .57046 L
.816 .57042 L
.82 .57041 L
.824 .57043 L
.828 .57044 L
.832 .57041 L
.836 .57034 L
.84 .57023 L
.844 .57012 L
.848 .57003 L
.852 .56996 L
.856 .56992 L
.86 .56989 L
.864 .5699 L
.868 .5699 L
.872 .56991 L
.876 .56987 L
.88 .56978 L
.884 .56966 L
.888 .56956 L
.892 .56952 L
.896 .56956 L
.9 .56962 L
.904 .56967 L
.908 .56962 L
.912 .56948 L
.916 .5693 L
.92 .56916 L
.924 .56909 L
.928 .56914 L
.932 .5692 L
.936 .56925 L
.94 .56921 L
.944 .56911 L
.948 .56898 L
.952 .56889 L
.956 .56883 L
.96 .56886 L
.964 .56888 L
.968 .56889 L
.972 .56882 L
.976 .56873 L
.98 .5686 L
.984 .56856 L
.988 .56851 L
.992 .56856 L
.996 .56855 L
1 .56855 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`<000Aoo`04001oogoo0002Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo
03Eoo`04001oogoo0004Ool30002Ool2000XOol0029oo`8003Ioo`04001oogoo0003Ool2000027oo
001oogoo001oo`00Ool300000goo0000000200000goo0000000300000goo00000008000=Ool0029o
of<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoogoo0`0000Eo
o`00Oomoo`00009oo`<0009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`@000=oo`<00006Ool007oo001oo`000goo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo000037oo000ROol2000DOol9000017oo0000000057oo00<007ooOol0=Goo
000ROol00`00Oomoo`0OOol2000BOol00`00Oomoo`0fOol0029oo`80029oo`03001oogoo00ioo`80
03Qoo`008Woo0P008goo00<007ooOol037oo00<007ooOol0>7oo000;Ool20004Ool00`00Oomoo`03
Ool20003Ool30003Ool00`00Oomoo`0SOol00`00Oomoo`0;Ool00`00Oomoo`0hOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0097oo00<007ooOol02Woo00<007ooOol0
>Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8002Aoo`8000Ioo`03
001oogoo009oo`03001oogoo03Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`0TOol00`00Oomoo`03Ool00`00Ool00002Ool00`00Oomoo`0jOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P009Woo00@007ooOomoo`80009oo`03
001oo`0003aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2000VOol01@00Oomo
ogoo00000goo0P00?Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0UOol20000
0goo001oo`12Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8002Moo`<004=oo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qo
o`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo
0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001o
ogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000
Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@0
07ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo
0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007oo
Ool0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001o
ogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02
001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo
06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomo
o`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000A
Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomo
o`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomo
o`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000
Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003
Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`00
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol0
0002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001o
ogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@0
07ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03
001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00
Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001o
ogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005
Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`00
0Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo
00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D0
00=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo
00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007oo
Ool006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0
06Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00
Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomo
o`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomo
o`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo02eoobd000aoo`00:7oo00<0
07ooOol0:goo0P00>Goo000XOol00`00Oomoo`0YOol2000kOol0015oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`03001oogoo02Moo`<003aoo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`0UOol2000oOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol097oo0P00@7oo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8002=oo`<0045oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`0OOol40013Ool0011oo`04001oogoo0008Ool01000Oomoo`000Woo
0P0017oo00<007ooOol06Woo1P00AWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomo
o`0EOol6001;Ool002Qoo`8000ioo`T0051oo`00:7oo4000FGoo000XOol00`00Oomoo`1VOol000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool0
1000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`00
2Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo
00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004
Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005
Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007oo
Ool0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06
001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<0
07ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001o
ogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool0
01aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo
00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0
01aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003
Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo
Ool00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;
Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo
000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009ooaP005eoo`005goo00<0
07ooOol00Woo00<007ooOol05Goo1@00F7oo000GOol00`00Oomoo`02Ool00`00Oomoo`0IOol5001D
Ool001Ioo`8000Aoo`8001ioo`H004moo`005goo00<007ooOol00Woo00<007ooOol08Woo0`00CGoo
000LOol00`00Oomoo`0UOol3001:Ool001aoo`8002Qoo`8004Uoo`0077oo00<007ooOol0:7oo0P00
B7oo000LOol2000[Ool20016Ool001aoo`03001oogoo02]oo`8004Eoo`0077oo00<007ooOol0;7oo
0`00@goo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2000_Ool20012Ool000]oo`03001oogoo
00Moo`05001oogooOol00002Ool00`00Oomoo`0`Ool00`00Oomoo`0oOol000]oo`03001oogoo00]o
o`04001oogoo000cOol2000oOol000]oo`03001oogoo00]oo`03001oogoo008003Aoo`8002=oo`h0
00aoo`002goo00<007ooOol01goo10000goo00<007ooOol0=Goo90006Goo000:Ool20009Ool00`00
Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(35070\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30228 m
.008 .30032 L
.012 .29916 L
.016 .29898 L
.02 .29993 L
.024 .30027 L
.028 .29979 L
.032 .29957 L
.036 .29977 L
.04 .29988 L
.044 .29977 L
.048 .2997 L
.052 .29972 L
.056 .29975 L
.06 .29974 L
.064 .29974 L
.068 .29976 L
.072 .29978 L
.076 .2998 L
.08 .29981 L
.084 .29982 L
.088 .29984 L
.092 .29991 L
.096 .3 L
.1 .30012 L
.104 .30024 L
.108 .30036 L
.112 .30048 L
.116 .30064 L
.12 .30087 L
.124 .30118 L
.128 .30155 L
.132 .30195 L
.136 .30238 L
.14 .30285 L
.144 .30339 L
.148 .30404 L
.152 .30481 L
.156 .30569 L
.16 .30664 L
.164 .30766 L
.168 .30875 L
.172 .30993 L
.176 .31121 L
.18 .31258 L
.184 .31403 L
.188 .31552 L
.192 .31705 L
.196 .31857 L
.2 .32008 L
Mistroke
.204 .32156 L
.208 .32296 L
.212 .32426 L
.216 .3254 L
.22 .32639 L
.224 .32721 L
.228 .32784 L
.232 .32823 L
.236 .32837 L
.24 .32825 L
.244 .32787 L
.248 .32726 L
.252 .32647 L
.256 .32555 L
.26 .32455 L
.264 .32348 L
.268 .32236 L
.272 .32126 L
.276 .32027 L
.28 .31949 L
.284 .31896 L
.288 .3187 L
.292 .31875 L
.296 .31913 L
.3 .31983 L
.304 .32084 L
.308 .3222 L
.312 .32392 L
.316 .32599 L
.32 .32833 L
.324 .33093 L
.328 .33382 L
.332 .33705 L
.336 .34067 L
.34 .3447 L
.344 .34921 L
.348 .35427 L
.352 .35994 L
.356 .36621 L
.36 .37308 L
.364 .38055 L
.368 .38859 L
.372 .39706 L
.376 .40566 L
.38 .41406 L
.384 .42195 L
.388 .42899 L
.392 .43479 L
.396 .43897 L
.4 .44127 L
Mistroke
.404 .44156 L
.408 .43979 L
.412 .43601 L
.416 .43043 L
.42 .42349 L
.424 .4159 L
.428 .40838 L
.432 .40162 L
.436 .39618 L
.44 .39259 L
.444 .39119 L
.448 .39206 L
.452 .39493 L
.456 .3993 L
.46 .40448 L
.464 .40967 L
.468 .41392 L
.472 .41622 L
.476 .41586 L
.48 .41258 L
.484 .40662 L
.488 .39854 L
.492 .3891 L
.496 .37914 L
.5 .36956 L
.504 .36116 L
.508 .35438 L
.512 .34923 L
.516 .34528 L
.52 .34188 L
.524 .33816 L
.528 .33319 L
.532 .32613 L
.536 .31656 L
.54 .30482 L
.544 .29201 L
.548 .27972 L
.552 .26956 L
.556 .26279 L
.56 .2602 L
.564 .26203 L
.568 .26788 L
.572 .27671 L
.576 .28697 L
.58 .29699 L
.584 .30541 L
.588 .31137 L
.592 .31457 L
.596 .31512 L
.6 .31354 L
Mistroke
.604 .31064 L
.608 .30742 L
.612 .30458 L
.616 .30224 L
.62 .29988 L
.624 .29687 L
.628 .29304 L
.632 .28901 L
.636 .2859 L
.64 .28479 L
.644 .2863 L
.648 .29044 L
.652 .29662 L
.656 .30363 L
.66 .30968 L
.664 .31279 L
.668 .31168 L
.672 .30648 L
.676 .29895 L
.68 .29162 L
.684 .28662 L
.688 .28502 L
.692 .28676 L
.696 .2912 L
.7 .2973 L
.704 .30355 L
.708 .30807 L
.712 .30922 L
.716 .3066 L
.72 .30146 L
.724 .29614 L
.728 .29261 L
.732 .2915 L
.736 .2922 L
.74 .2938 L
.744 .29585 L
.748 .29829 L
.752 .30078 L
.756 .30234 L
.76 .30202 L
.764 .2998 L
.768 .29692 L
.772 .29503 L
.776 .2949 L
.78 .29592 L
.784 .29691 L
.788 .29734 L
.792 .29782 L
.796 .2992 L
.8 .30133 L
Mistroke
.804 .30269 L
.808 .30155 L
.812 .29778 L
.816 .29325 L
.82 .29085 L
.824 .29222 L
.828 .29641 L
.832 .30081 L
.836 .30279 L
.84 .30173 L
.844 .29906 L
.848 .29663 L
.852 .29567 L
.856 .29594 L
.86 .29656 L
.864 .29737 L
.868 .29831 L
.872 .29951 L
.876 .30047 L
.88 .29985 L
.884 .29754 L
.888 .29449 L
.892 .29261 L
.896 .29389 L
.9 .29768 L
.904 .30182 L
.908 .30372 L
.912 .30163 L
.916 .29727 L
.92 .29344 L
.924 .29242 L
.928 .29519 L
.932 .29924 L
.936 .30184 L
.94 .30165 L
.944 .29845 L
.948 .29501 L
.952 .29355 L
.956 .29443 L
.96 .29754 L
.964 .30034 L
.968 .30117 L
.972 .30026 L
.976 .29766 L
.98 .29543 L
.984 .29484 L
.988 .2956 L
.992 .29778 L
.996 .29969 L
1 .30016 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .56198 m
.008 .56521 L
.012 .56624 L
.016 .5649 L
.02 .56467 L
.024 .56514 L
.028 .56524 L
.032 .56502 L
.036 .56502 L
.04 .56507 L
.044 .5651 L
.048 .56506 L
.052 .56507 L
.056 .56507 L
.06 .56508 L
.064 .56506 L
.068 .56507 L
.072 .56505 L
.076 .56506 L
.08 .56505 L
.084 .56506 L
.088 .56504 L
.092 .56504 L
.096 .56502 L
.1 .56502 L
.104 .56499 L
.108 .56498 L
.112 .56495 L
.116 .56493 L
.12 .56489 L
.124 .56486 L
.128 .5648 L
.132 .56474 L
.136 .56466 L
.14 .56458 L
.144 .56448 L
.148 .56436 L
.152 .56423 L
.156 .56406 L
.16 .56387 L
.164 .56366 L
.168 .56341 L
.172 .56313 L
.176 .56281 L
.18 .56245 L
.184 .56205 L
.188 .56161 L
.192 .56112 L
.196 .56058 L
.2 .56 L
Mistroke
.204 .55937 L
.208 .55869 L
.212 .55797 L
.216 .55721 L
.22 .55641 L
.224 .55559 L
.228 .55474 L
.232 .55387 L
.236 .55298 L
.24 .55209 L
.244 .5512 L
.248 .55032 L
.252 .54947 L
.256 .54863 L
.26 .54782 L
.264 .54704 L
.268 .54629 L
.272 .54558 L
.276 .54489 L
.28 .54423 L
.284 .5436 L
.288 .54298 L
.292 .54237 L
.296 .54176 L
.3 .54113 L
.304 .54048 L
.308 .53981 L
.312 .5391 L
.316 .53835 L
.32 .53755 L
.324 .5367 L
.328 .5358 L
.332 .53484 L
.336 .53383 L
.34 .53276 L
.344 .53163 L
.348 .53043 L
.352 .52916 L
.356 .52782 L
.36 .52638 L
.364 .52485 L
.368 .52322 L
.372 .52146 L
.376 .51957 L
.38 .51755 L
.384 .5154 L
.388 .51311 L
.392 .51071 L
.396 .50821 L
.4 .50565 L
Mistroke
.404 .50305 L
.408 .50044 L
.412 .49786 L
.416 .49535 L
.42 .49293 L
.424 .49061 L
.428 .48842 L
.432 .48635 L
.436 .48437 L
.44 .48246 L
.444 .48059 L
.448 .47872 L
.452 .47681 L
.456 .47483 L
.46 .47277 L
.464 .47062 L
.468 .4684 L
.472 .46612 L
.476 .46385 L
.48 .46162 L
.484 .45948 L
.488 .45749 L
.492 .45568 L
.496 .45405 L
.5 .4526 L
.504 .45132 L
.508 .45018 L
.512 .44916 L
.516 .44822 L
.52 .44734 L
.524 .44655 L
.528 .44583 L
.532 .44524 L
.536 .44481 L
.54 .44457 L
.544 .44457 L
.548 .44481 L
.552 .44528 L
.556 .44592 L
.56 .44667 L
.564 .44745 L
.568 .44818 L
.572 .44877 L
.576 .44917 L
.58 .44938 L
.584 .44938 L
.588 .44922 L
.592 .44895 L
.596 .44861 L
.6 .44826 L
Mistroke
.604 .44795 L
.608 .44769 L
.612 .44752 L
.616 .44742 L
.62 .4474 L
.624 .44746 L
.628 .44759 L
.632 .44779 L
.636 .44804 L
.64 .44831 L
.644 .44856 L
.648 .44875 L
.652 .44885 L
.656 .44883 L
.66 .44871 L
.664 .44851 L
.668 .44829 L
.672 .44812 L
.676 .44806 L
.68 .44812 L
.684 .44829 L
.688 .44854 L
.692 .44879 L
.696 .44901 L
.7 .44912 L
.704 .44912 L
.708 .44902 L
.712 .44885 L
.716 .44869 L
.72 .44857 L
.724 .44855 L
.728 .4486 L
.732 .4487 L
.736 .44883 L
.74 .44896 L
.744 .44907 L
.748 .44915 L
.752 .44919 L
.756 .44919 L
.76 .44918 L
.764 .44916 L
.768 .44916 L
.772 .44919 L
.776 .44922 L
.78 .44926 L
.784 .4493 L
.788 .44934 L
.792 .44938 L
.796 .44941 L
.8 .44941 L
Mistroke
.804 .44938 L
.808 .44935 L
.812 .44935 L
.816 .4494 L
.82 .44951 L
.824 .44962 L
.828 .4497 L
.832 .44974 L
.836 .44973 L
.84 .44971 L
.844 .44971 L
.848 .44973 L
.852 .44978 L
.856 .44982 L
.86 .44985 L
.864 .44988 L
.868 .44988 L
.872 .44987 L
.876 .44986 L
.88 .44987 L
.884 .44991 L
.888 .44999 L
.892 .45011 L
.896 .45023 L
.9 .45029 L
.904 .45029 L
.908 .45022 L
.912 .45015 L
.916 .45011 L
.92 .45014 L
.924 .45022 L
.928 .45032 L
.932 .45038 L
.936 .45041 L
.94 .45039 L
.944 .45041 L
.948 .45045 L
.952 .45052 L
.956 .45059 L
.96 .45064 L
.964 .45063 L
.968 .45061 L
.972 .45056 L
.976 .45057 L
.98 .45061 L
.984 .4507 L
.988 .45077 L
.992 .45085 L
.996 .45084 L
1 .45086 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43494 L
.012 .42999 L
.016 .42826 L
.02 .42974 L
.024 .43037 L
.028 .42981 L
.032 .42959 L
.036 .42968 L
.04 .42975 L
.044 .42965 L
.048 .42962 L
.052 .42958 L
.056 .42958 L
.06 .42953 L
.064 .42951 L
.068 .42947 L
.072 .42945 L
.076 .42941 L
.08 .4294 L
.084 .42936 L
.088 .42935 L
.092 .42932 L
.096 .42931 L
.1 .42929 L
.104 .42928 L
.108 .42926 L
.112 .42926 L
.116 .42926 L
.12 .42929 L
.124 .4293 L
.128 .42934 L
.132 .42937 L
.136 .42943 L
.14 .4295 L
.144 .4296 L
.148 .42972 L
.152 .42987 L
.156 .43004 L
.16 .43024 L
.164 .43047 L
.168 .43075 L
.172 .43107 L
.176 .43144 L
.18 .43185 L
.184 .43232 L
.188 .43285 L
.192 .43343 L
.196 .43406 L
.2 .43476 L
Mistroke
.204 .43551 L
.208 .43632 L
.212 .43719 L
.216 .43811 L
.22 .43907 L
.224 .44007 L
.228 .44111 L
.232 .44217 L
.236 .44324 L
.24 .44431 L
.244 .44539 L
.248 .44645 L
.252 .4475 L
.256 .44852 L
.26 .4495 L
.264 .45044 L
.268 .45134 L
.272 .4522 L
.276 .45303 L
.28 .45382 L
.284 .45458 L
.288 .45533 L
.292 .45607 L
.296 .45681 L
.3 .45756 L
.304 .45834 L
.308 .45915 L
.312 .46001 L
.316 .46092 L
.32 .46188 L
.324 .46292 L
.328 .46402 L
.332 .46518 L
.336 .46642 L
.34 .46773 L
.344 .46912 L
.348 .47058 L
.352 .47213 L
.356 .47379 L
.36 .47555 L
.364 .47743 L
.368 .47945 L
.372 .48162 L
.376 .48395 L
.38 .48645 L
.384 .48911 L
.388 .49193 L
.392 .4949 L
.396 .49798 L
.4 .50116 L
Mistroke
.404 .50439 L
.408 .50763 L
.412 .51082 L
.416 .51394 L
.42 .51694 L
.424 .5198 L
.428 .52251 L
.432 .52509 L
.436 .52754 L
.44 .5299 L
.444 .53222 L
.448 .53454 L
.452 .5369 L
.456 .53936 L
.46 .54191 L
.464 .54458 L
.468 .54734 L
.472 .55015 L
.476 .55297 L
.48 .55574 L
.484 .55839 L
.488 .56087 L
.492 .56313 L
.496 .56516 L
.5 .56696 L
.504 .56854 L
.508 .56994 L
.512 .5712 L
.516 .57236 L
.52 .57344 L
.524 .57444 L
.528 .57533 L
.532 .57607 L
.536 .57661 L
.54 .57689 L
.544 .57688 L
.548 .57656 L
.552 .57597 L
.556 .57516 L
.56 .57421 L
.564 .57324 L
.568 .57234 L
.572 .57161 L
.576 .5711 L
.58 .57084 L
.584 .57083 L
.588 .57101 L
.592 .57133 L
.596 .57173 L
.6 .57214 L
Mistroke
.604 .57252 L
.608 .57285 L
.612 .57309 L
.616 .57323 L
.62 .57325 L
.624 .57317 L
.628 .57298 L
.632 .5727 L
.636 .57236 L
.64 .572 L
.644 .57167 L
.648 .57144 L
.652 .57134 L
.656 .57139 L
.66 .57156 L
.664 .5718 L
.668 .57204 L
.672 .57222 L
.676 .57227 L
.68 .57217 L
.684 .57194 L
.688 .57163 L
.692 .57131 L
.696 .57107 L
.7 .57096 L
.704 .57098 L
.708 .5711 L
.712 .57126 L
.716 .57142 L
.72 .57153 L
.724 .57155 L
.728 .57148 L
.732 .57135 L
.736 .57118 L
.74 .57102 L
.744 .57091 L
.748 .57085 L
.752 .57082 L
.756 .57079 L
.76 .57075 L
.764 .57072 L
.768 .57069 L
.772 .57066 L
.776 .57061 L
.78 .57056 L
.784 .5705 L
.788 .57046 L
.792 .57046 L
.796 .57048 L
.8 .5705 L
Mistroke
.804 .57048 L
.808 .57043 L
.812 .57034 L
.816 .57023 L
.82 .57012 L
.824 .57003 L
.828 .56995 L
.832 .56991 L
.836 .56991 L
.84 .56995 L
.844 .56999 L
.848 .56997 L
.852 .56989 L
.856 .56975 L
.86 .56961 L
.864 .56955 L
.868 .56956 L
.872 .56965 L
.876 .56971 L
.88 .5697 L
.884 .5696 L
.888 .56944 L
.892 .56928 L
.896 .56919 L
.9 .56916 L
.904 .56919 L
.908 .56921 L
.912 .56921 L
.916 .56917 L
.92 .56912 L
.924 .56905 L
.928 .569 L
.932 .56893 L
.936 .56889 L
.94 .56884 L
.944 .56881 L
.948 .56878 L
.952 .56877 L
.956 .56872 L
.96 .56868 L
.964 .56859 L
.968 .56853 L
.972 .56843 L
.976 .5684 L
.98 .56837 L
.984 .56838 L
.988 .56835 L
.992 .56836 L
.996 .56827 L
1 .56824 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`800004Ool000000006Ool01000Oomoo`000Woo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Ool0
07oo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00
Oomoo`0cOol00`00Ool00005Ool20003Ool2000ZOol0029oo`8003=oo`05001oogooOol00003Ool4
000017oo001oo`000Woo0`0000Eoo`00000007oo00<00003Ool0000000d000eoo`008WooH`0037oo
000ROol01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`D000=oo`03001oogoo00<00003Ool0
07oo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo0P000Woo00<007oo00000P000Woo
00<007oo00000P000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000aoo`008Woo0P004Woo200000Aoo`00000001Aoo`03001oogoo03Qoo`00
8Woo00<007ooOol07Goo00<007ooOol047oo0P00>Woo000ROol2000OOol2000?Ool2000kOol0029o
o`80021oo`03001oogoo00eoo`03001oogoo03Yoo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo00<007ooOol087oo00<007ooOol02goo00<007ooOol0>goo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`80025oo`8000]oo`03001oogoo03aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000ROol00`00Oomoo`09Ool00`00Oomoo`0l
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol08Goo00<0
07ooOol017oo0`000Woo00<007ooOol0?7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8002=oo`03001oogoo009oo`06001oogoo001oo`00?goo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`8000Aoo`8002=oo`80009oo`03001oogoo009oo`8003moo`002goo0P00
2Woo0P0017oo00<007ooOol00Woo00<007ooOol08goo00@007ooOol004Eoo`002goo0P0017oo00<0
07ooOol00goo0P000Woo1@000Woo0P0097oo0`00AWoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2
001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo
0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03
001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006io
o`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`00
8Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@0
07ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
2Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03
001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Ao
o`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Ao
o`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<0
07ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Ao
o`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo
10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@0
07ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007oo
Ool017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<0
07ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool0
0`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P00
17oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
G@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool0
0`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool0
0`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo02ioo`8003Ioo`002goo0P002Woo0P00
17oo0P000Woo1@000Woo00<007ooOol0:Woo<00037oo000XOol00`00Oomoo`0XOol3000kOol002Qo
o`03001oogoo02Ioo`<003eoo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007oo
Ool09Goo0P00?goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo02=oo`80045oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`0QOol20013Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
87oo0`00A7oo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
01eoo`<004Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0GOol6
0019Ool0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo019oo`H004ioo`00:7oo00<0
07oo000027oo2`00Dgoo000XOol<001MOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomo
o`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool0
0`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`00
1goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;
Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Ao
o`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Ao
o`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007oo
Ool00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003
Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<0
07ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000
Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo
0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2
000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol0
37oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo
0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@00
0goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Ao
o`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomo
o`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001d
Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00
Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo
009oo`03001oogoo079oo`005goo00<007ooOol00Woo5@00H7oo000GOol00`00Oomoo`02Ool2000C
Ool5001KOol001Moo`03001oogoo009oo`03001oogoo01Ioo`D005Moo`005Woo0P0017oo0P006goo
1P00DWoo000GOol00`00Oomoo`02Ool00`00Oomoo`0OOol4001?Ool001aoo`03001oogoo029oo`<0
04eoo`0077oo0P009Goo0P00C7oo000LOol00`00Oomoo`0VOol2001:Ool001aoo`8002Qoo`8004Uo
o`0077oo00<007ooOol0:7oo0P00B7oo000LOol00`00Oomoo`0YOol30016Ool000Yoo`<000Aoo`03
001oogoo009oo`<000=oo`8002aoo`8004Eoo`002goo00<007ooOol01goo00D007ooOomoo`00009o
o`03001oogoo02eoo`8004=oo`002goo00<007ooOol02goo00@007ooOol0031oo`80049oo`002goo
00<007ooOol02goo00<007ooOol00P00<Goo0P0097oo400037oo000;Ool00`00Oomoo`07Ool40003
Ool00`00Oomoo`0bOolT000LOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo
00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(35237\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29884 m
.008 .2989 L
.012 .30038 L
.016 .30058 L
.02 .29961 L
.024 .2995 L
.028 .3 L
.032 .30003 L
.036 .29977 L
.04 .29976 L
.044 .29991 L
.048 .29995 L
.052 .29993 L
.056 .29995 L
.06 .29999 L
.064 .30002 L
.068 .30008 L
.072 .30018 L
.076 .30032 L
.08 .30046 L
.084 .30061 L
.088 .30078 L
.092 .30099 L
.096 .30125 L
.1 .30158 L
.104 .30197 L
.108 .30241 L
.112 .30291 L
.116 .30347 L
.12 .30413 L
.124 .30487 L
.128 .30571 L
.132 .30663 L
.136 .30763 L
.14 .30874 L
.144 .30995 L
.148 .31127 L
.152 .31266 L
.156 .31411 L
.16 .3156 L
.164 .31713 L
.168 .31868 L
.172 .32025 L
.176 .3218 L
.18 .32328 L
.184 .32464 L
.188 .32586 L
.192 .32693 L
.196 .32783 L
.2 .32854 L
Mistroke
.204 .32901 L
.208 .32923 L
.212 .32919 L
.216 .32888 L
.22 .32835 L
.224 .32765 L
.228 .32678 L
.232 .32577 L
.236 .32463 L
.24 .32344 L
.244 .3223 L
.248 .32128 L
.252 .32044 L
.256 .31984 L
.26 .3195 L
.264 .31944 L
.268 .31965 L
.272 .3202 L
.276 .32114 L
.28 .32248 L
.284 .32418 L
.288 .32619 L
.292 .32849 L
.296 .33106 L
.3 .33393 L
.304 .33711 L
.308 .34067 L
.312 .34466 L
.316 .34912 L
.32 .35408 L
.324 .35956 L
.328 .36564 L
.332 .37239 L
.336 .3798 L
.34 .38776 L
.344 .39611 L
.348 .40468 L
.352 .41321 L
.356 .42136 L
.36 .42877 L
.364 .43507 L
.368 .43993 L
.372 .44305 L
.376 .44412 L
.38 .44301 L
.384 .4398 L
.388 .43476 L
.392 .42831 L
.396 .42094 L
.4 .41327 L
Mistroke
.404 .40602 L
.408 .3999 L
.412 .39546 L
.416 .39307 L
.42 .39293 L
.424 .39501 L
.428 .39896 L
.432 .40407 L
.436 .40939 L
.44 .41398 L
.444 .41699 L
.448 .41777 L
.452 .41585 L
.456 .41111 L
.46 .40383 L
.464 .39469 L
.468 .38455 L
.472 .37432 L
.476 .36484 L
.48 .35684 L
.484 .35071 L
.488 .34629 L
.492 .34288 L
.496 .33941 L
.5 .33487 L
.504 .32851 L
.508 .31996 L
.512 .30933 L
.516 .29722 L
.52 .28481 L
.524 .27358 L
.528 .265 L
.532 .26022 L
.536 .25983 L
.54 .26384 L
.544 .27163 L
.548 .28193 L
.552 .29297 L
.556 .30288 L
.56 .31026 L
.564 .31452 L
.568 .31583 L
.572 .31489 L
.576 .31254 L
.58 .30953 L
.584 .3064 L
.588 .3034 L
.592 .30047 L
.596 .29735 L
.6 .29388 L
Mistroke
.604 .29029 L
.608 .28726 L
.612 .2857 L
.616 .28627 L
.62 .28914 L
.624 .29392 L
.628 .29983 L
.632 .30577 L
.636 .31034 L
.64 .31211 L
.644 .31015 L
.648 .30463 L
.652 .29706 L
.656 .2898 L
.66 .28508 L
.664 .28422 L
.668 .28726 L
.672 .2932 L
.676 .30033 L
.68 .30658 L
.684 .30999 L
.688 .3094 L
.692 .30513 L
.696 .29905 L
.7 .29368 L
.704 .2909 L
.708 .29104 L
.712 .29311 L
.716 .29572 L
.72 .29802 L
.724 .29978 L
.728 .30089 L
.732 .3011 L
.736 .30022 L
.74 .29859 L
.744 .29705 L
.748 .29633 L
.752 .29645 L
.756 .29673 L
.76 .29667 L
.764 .2966 L
.768 .29742 L
.772 .29952 L
.776 .30197 L
.78 .30291 L
.784 .30103 L
.788 .29692 L
.792 .29288 L
.796 .29133 L
.8 .29311 L
Mistroke
.804 .29688 L
.808 .30044 L
.812 .30215 L
.816 .30182 L
.82 .3003 L
.824 .2983 L
.828 .29632 L
.832 .29473 L
.836 .2942 L
.84 .29565 L
.844 .29879 L
.848 .30203 L
.852 .30311 L
.856 .30059 L
.86 .29576 L
.864 .29168 L
.868 .29118 L
.872 .29504 L
.876 .30055 L
.88 .30409 L
.884 .30351 L
.888 .2993 L
.892 .29484 L
.896 .29309 L
.9 .29466 L
.904 .29818 L
.908 .30057 L
.912 .30032 L
.916 .29827 L
.92 .29591 L
.924 .29532 L
.928 .29665 L
.932 .29834 L
.936 .29947 L
.94 .29908 L
.944 .29776 L
.948 .29703 L
.952 .29692 L
.956 .2976 L
.96 .29833 L
.964 .29811 L
.968 .29752 L
.972 .29683 L
.976 .29656 L
.98 .29727 L
.984 .2981 L
.988 .29876 L
.992 .29884 L
.996 .29805 L
1 .29728 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .55744 m
.008 .56458 L
.012 .56706 L
.016 .56472 L
.02 .5639 L
.024 .56461 L
.028 .56493 L
.032 .56467 L
.036 .56458 L
.04 .56464 L
.044 .56469 L
.048 .56465 L
.052 .56465 L
.056 .56463 L
.06 .56465 L
.064 .56462 L
.068 .56462 L
.072 .5646 L
.076 .5646 L
.08 .56457 L
.084 .56456 L
.088 .56452 L
.092 .5645 L
.096 .56445 L
.1 .56441 L
.104 .56434 L
.108 .56428 L
.112 .5642 L
.116 .56411 L
.12 .56399 L
.124 .56386 L
.128 .5637 L
.132 .56352 L
.136 .56331 L
.14 .56307 L
.144 .5628 L
.148 .5625 L
.152 .56215 L
.156 .56176 L
.16 .56132 L
.164 .56085 L
.168 .56033 L
.172 .55976 L
.176 .55915 L
.18 .55849 L
.184 .55778 L
.188 .55703 L
.192 .55624 L
.196 .55543 L
.2 .55458 L
Mistroke
.204 .55372 L
.208 .55284 L
.212 .55195 L
.216 .55107 L
.22 .55019 L
.224 .54932 L
.228 .54848 L
.232 .54765 L
.236 .54687 L
.24 .54611 L
.244 .54539 L
.248 .54469 L
.252 .54403 L
.256 .54339 L
.26 .54276 L
.264 .54214 L
.268 .54153 L
.272 .54091 L
.276 .54027 L
.28 .53961 L
.284 .53892 L
.288 .53818 L
.292 .5374 L
.296 .53656 L
.3 .53568 L
.304 .53474 L
.308 .53374 L
.312 .53269 L
.316 .53157 L
.32 .53039 L
.324 .52914 L
.328 .52782 L
.332 .52641 L
.336 .52491 L
.34 .5233 L
.344 .52158 L
.348 .51974 L
.352 .51776 L
.356 .51566 L
.36 .51342 L
.364 .51106 L
.368 .5086 L
.372 .50606 L
.376 .50347 L
.38 .50086 L
.384 .49827 L
.388 .49574 L
.392 .49328 L
.396 .49093 L
.4 .4887 L
Mistroke
.404 .48658 L
.408 .48456 L
.412 .48263 L
.416 .48075 L
.42 .47888 L
.424 .477 L
.428 .47506 L
.432 .47304 L
.436 .47094 L
.44 .46875 L
.444 .46651 L
.448 .46424 L
.452 .462 L
.456 .45983 L
.46 .45778 L
.464 .4559 L
.468 .45419 L
.472 .45268 L
.476 .45135 L
.48 .45018 L
.484 .44914 L
.488 .44819 L
.492 .44732 L
.496 .44651 L
.5 .44579 L
.504 .44516 L
.508 .44468 L
.512 .44438 L
.516 .44429 L
.52 .44444 L
.524 .44482 L
.528 .44539 L
.532 .4461 L
.536 .44687 L
.54 .44762 L
.544 .44828 L
.548 .44877 L
.552 .44907 L
.556 .44916 L
.56 .44906 L
.564 .44882 L
.568 .4485 L
.572 .44814 L
.576 .4478 L
.58 .4475 L
.584 .44729 L
.588 .44715 L
.592 .44711 L
.596 .44714 L
.6 .44726 L
Mistroke
.604 .44744 L
.608 .44768 L
.612 .44794 L
.616 .44819 L
.62 .4484 L
.624 .44853 L
.628 .44856 L
.632 .44849 L
.636 .44834 L
.64 .44814 L
.644 .44795 L
.648 .44784 L
.652 .44783 L
.656 .44794 L
.66 .44813 L
.664 .44838 L
.668 .44861 L
.672 .44878 L
.676 .44885 L
.68 .44881 L
.684 .44869 L
.688 .44853 L
.692 .44838 L
.696 .4483 L
.7 .44829 L
.704 .44836 L
.708 .44848 L
.712 .44861 L
.716 .44874 L
.72 .44884 L
.724 .44891 L
.728 .44893 L
.732 .44893 L
.736 .44892 L
.74 .44891 L
.744 .44892 L
.748 .44894 L
.752 .44897 L
.756 .449 L
.76 .44904 L
.764 .44907 L
.768 .44911 L
.772 .44913 L
.776 .44913 L
.78 .44911 L
.784 .44911 L
.788 .44914 L
.792 .44921 L
.796 .4493 L
.8 .44938 L
Mistroke
.804 .44943 L
.808 .44945 L
.812 .44945 L
.816 .44945 L
.82 .44946 L
.824 .44949 L
.828 .44953 L
.832 .44957 L
.836 .4496 L
.84 .44962 L
.844 .44962 L
.848 .4496 L
.852 .44957 L
.856 .44959 L
.86 .44966 L
.864 .44979 L
.868 .44992 L
.872 .45002 L
.876 .45003 L
.88 .44998 L
.884 .44989 L
.888 .44984 L
.892 .44986 L
.896 .44992 L
.9 .45001 L
.904 .45008 L
.908 .45011 L
.912 .45013 L
.916 .45014 L
.92 .45019 L
.924 .45023 L
.928 .45028 L
.932 .4503 L
.936 .45032 L
.94 .45031 L
.944 .45033 L
.948 .45035 L
.952 .45039 L
.956 .45042 L
.96 .45046 L
.964 .45047 L
.968 .45052 L
.972 .45055 L
.976 .45061 L
.98 .45064 L
.984 .45069 L
.988 .45069 L
.992 .4507 L
.996 .45068 L
1 .45072 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42807 L
.012 .43012 L
.016 .43061 L
.02 .42967 L
.024 .42957 L
.028 .42984 L
.032 .42986 L
.036 .42967 L
.04 .42967 L
.044 .42967 L
.048 .42967 L
.052 .4296 L
.056 .42959 L
.06 .42955 L
.064 .42955 L
.068 .42951 L
.072 .42951 L
.076 .42949 L
.08 .42949 L
.084 .42947 L
.088 .42948 L
.092 .42948 L
.096 .42951 L
.1 .42953 L
.104 .42958 L
.108 .42963 L
.112 .4297 L
.116 .42979 L
.12 .42991 L
.124 .43003 L
.128 .4302 L
.132 .43039 L
.136 .43062 L
.14 .43089 L
.144 .4312 L
.148 .43155 L
.152 .43195 L
.156 .4324 L
.16 .4329 L
.164 .43346 L
.168 .43409 L
.172 .43477 L
.176 .43551 L
.18 .4363 L
.184 .43715 L
.188 .43804 L
.192 .43899 L
.196 .43998 L
.2 .441 L
Mistroke
.204 .44205 L
.208 .44312 L
.212 .4442 L
.216 .44528 L
.22 .44634 L
.224 .4474 L
.228 .44842 L
.232 .44941 L
.236 .45036 L
.24 .45128 L
.244 .45216 L
.248 .453 L
.252 .4538 L
.256 .45457 L
.26 .45532 L
.264 .45606 L
.268 .45679 L
.272 .45754 L
.276 .45831 L
.28 .45911 L
.284 .45996 L
.288 .46085 L
.292 .46179 L
.296 .4628 L
.3 .46388 L
.304 .46502 L
.308 .46624 L
.312 .46753 L
.316 .4689 L
.32 .47035 L
.324 .47188 L
.328 .4735 L
.332 .47523 L
.336 .47708 L
.34 .47905 L
.344 .48117 L
.348 .48345 L
.352 .48589 L
.356 .4885 L
.36 .49126 L
.364 .49418 L
.368 .49722 L
.372 .50037 L
.376 .50357 L
.38 .5068 L
.384 .51001 L
.388 .51316 L
.392 .5162 L
.396 .51912 L
.4 .52189 L
Mistroke
.404 .52451 L
.408 .52701 L
.412 .5294 L
.416 .53172 L
.42 .53403 L
.424 .53637 L
.428 .53878 L
.432 .54128 L
.436 .54389 L
.44 .54661 L
.444 .54939 L
.448 .5522 L
.452 .55498 L
.456 .55767 L
.46 .56021 L
.464 .56256 L
.468 .56467 L
.472 .56655 L
.476 .5682 L
.48 .56966 L
.484 .57095 L
.488 .57213 L
.492 .5732 L
.496 .57419 L
.5 .57508 L
.504 .57585 L
.508 .57645 L
.512 .57683 L
.516 .57694 L
.52 .57675 L
.524 .57628 L
.528 .57555 L
.532 .57465 L
.536 .57367 L
.54 .57272 L
.544 .5719 L
.548 .57129 L
.552 .57092 L
.556 .57081 L
.56 .57093 L
.564 .57121 L
.568 .57161 L
.572 .57204 L
.576 .57245 L
.58 .57279 L
.584 .57306 L
.588 .57322 L
.592 .57328 L
.596 .57324 L
.6 .5731 L
Mistroke
.604 .57287 L
.608 .57257 L
.612 .57223 L
.616 .57189 L
.62 .5716 L
.624 .57142 L
.628 .57137 L
.632 .57147 L
.636 .57168 L
.64 .57194 L
.644 .57217 L
.648 .57231 L
.652 .5723 L
.656 .57215 L
.66 .57187 L
.664 .57153 L
.668 .57122 L
.672 .57102 L
.676 .57095 L
.68 .57103 L
.684 .57119 L
.688 .57139 L
.692 .57155 L
.696 .57162 L
.7 .5716 L
.704 .57149 L
.708 .57131 L
.712 .57113 L
.716 .57098 L
.72 .57089 L
.724 .57084 L
.728 .57082 L
.732 .57081 L
.736 .57079 L
.74 .57077 L
.744 .57073 L
.748 .57069 L
.752 .57064 L
.756 .57057 L
.76 .57052 L
.764 .57049 L
.768 .57048 L
.772 .5705 L
.776 .57051 L
.78 .57049 L
.784 .57045 L
.788 .57037 L
.792 .57027 L
.796 .57015 L
.8 .57003 L
Mistroke
.804 .56993 L
.808 .5699 L
.812 .56992 L
.816 .56998 L
.82 .57003 L
.824 .57001 L
.828 .56991 L
.832 .56978 L
.836 .56965 L
.84 .5696 L
.844 .56961 L
.848 .56966 L
.852 .5697 L
.856 .56967 L
.86 .56959 L
.864 .56947 L
.868 .56935 L
.872 .56925 L
.876 .56919 L
.88 .56917 L
.884 .56918 L
.888 .56921 L
.892 .56922 L
.896 .5692 L
.9 .56912 L
.904 .56903 L
.908 .56892 L
.912 .56887 L
.916 .56885 L
.92 .56887 L
.924 .56885 L
.928 .56881 L
.932 .56871 L
.936 .56862 L
.94 .56854 L
.944 .56852 L
.948 .56851 L
.952 .56852 L
.956 .56848 L
.96 .56842 L
.964 .56832 L
.968 .56828 L
.972 .56825 L
.976 .56828 L
.98 .56826 L
.984 .56825 L
.988 .56814 L
.992 .56804 L
.996 .56789 L
1 .56786 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`<0009oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Eoo`<0009o
o`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007oo
Ool0<7oo00@007ooOol000Aoo`8000=oo`8002eoo`008Woo0P00<7oo00D007ooOomoo`0000=oo`80
0008Ool007ooOol007oo001oo`<00003Ool0000000800004Ool00000Ool3000017oo000007oo3000
37oo000ROomS000<Ool0029oo`05001oogooOol00003Ool01P00Oomoogoo001oo`@0009oo`05001o
ogooOol00002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00002Ool2
0003Ool3000017oo001oogoo0P000Woo0P000Woo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000aoo`008Woo0P003goo3@004goo0P00?7oo000R
Ool00`00Oomoo`0JOol2000AOol2000mOol0029oo`8001aoo`80011oo`03001oogoo03aoo`008Woo
0P007Goo0P003Woo00<007ooOol0?Goo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool0
0`00Oomoo`0MOol00`00Oomoo`0<Ool00`00Oomoo`0mOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P007Woo0P0037oo00<007ooOol0?Woo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8001moo`03001oogoo00Yoo`03001oogoo03ioo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0OOol00`00Oomoo`03
Ool30002Ool00`00Oomoo`0oOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P0087oo00<007ooOol00goo00H007oo000007oo0011Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo0P0017oo0P0087oo0P000goo00@007ooOomoo`80049oo`002goo0P002Woo0P0017oo
00<007ooOol00Woo00<007ooOol087oo00@007ooOol004Qoo`002goo0P0017oo00<007ooOol00goo
0P000Woo1@000Woo0P008Woo00<007oo0000B7oo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0002Ool2000ROol20019Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogoo
Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P00
0goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eo
o`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol0
06ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06ao
o`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo
00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007oo
Ool0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Io
o`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo
009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Ao
o`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<0
00Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<0
00Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo
00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`00
00Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009o
o`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<0
07ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol0
2Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<0
07ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo
00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008
Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo
0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?
Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004
Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo02aoo`8003Qoo`002goo0P002Woo
0P0017oo0P000Woo1@000Woo00<007ooOol0:7oo<P0037oo000XOol00`00Oomoo`0VOol3000mOol0
02Qoo`03001oogoo02Aoo`80041oo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<0
07ooOol08Woo0`00@Goo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo021oo`<004=oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`0OOol20015Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P007Woo0P00Agoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo01Yoo`@004Qoo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0E
Ool6001;Ool0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo011oo`H0051oo`00:7oo
4`00EWoo000XOol200000goo001oo`1TOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomo
o`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool0
0`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`00
1goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;
Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Ao
o`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Ao
o`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007oo
Ool00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003
Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<0
07ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000
Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo
0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2
000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol0
37oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo
0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@00
0goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Ao
o`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomo
o`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001d
Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00
Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo
009oo`03001oogoo079oo`005goo00<007ooOol00Woo4`00HWoo000GOol00`00Oomoo`02Ool00`00
Oomoo`0?Ool5001NOol001Moo`03001oogoo009oo`03001oogoo01=oo`D005Yoo`005Woo0P0017oo
0P0067oo1P00EGoo000GOol00`00Oomoo`02Ool00`00Oomoo`0LOol4001BOol001aoo`03001oogoo
01moo`<0051oo`0077oo0P008Woo0P00Cgoo000LOol00`00Oomoo`0SOol2001=Ool001aoo`8002Eo
o`8004aoo`0077oo00<007ooOol09Goo0P00Bgoo000LOol00`00Oomoo`0WOol20019Ool000Yoo`<0
00Aoo`03001oogoo009oo`<000=oo`8002Uoo`8004Qoo`002goo00<007ooOol01goo00D007ooOomo
o`00009oo`03001oogoo02Yoo`8004Ioo`002goo00<007ooOol02goo00@007ooOol002ioo`03001o
ogoo04=oo`002goo00<007ooOol02goo00<007ooOol00P00;Woo0`008goo4`0037oo000;Ool00`00
Oomoo`07Ool40003Ool00`00Oomoo`0_OolU000NOol000Yoo`8000Uoo`03001oogoo00Aoo`03001o
ogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03
001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(35404\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29739 m
.008 .29935 L
.012 .30076 L
.016 .30096 L
.02 .29984 L
.024 .29949 L
.028 .3001 L
.032 .30036 L
.036 .30014 L
.04 .30008 L
.044 .30028 L
.048 .30046 L
.052 .30056 L
.056 .30068 L
.06 .30086 L
.064 .30107 L
.068 .30133 L
.072 .30164 L
.076 .30203 L
.08 .30248 L
.084 .30297 L
.088 .30353 L
.092 .30416 L
.096 .30488 L
.1 .3057 L
.104 .30662 L
.108 .30765 L
.112 .30877 L
.116 .30999 L
.12 .3113 L
.124 .31268 L
.128 .31412 L
.132 .31563 L
.136 .31719 L
.14 .31881 L
.144 .32044 L
.148 .32205 L
.152 .32356 L
.156 .32497 L
.16 .32624 L
.164 .32739 L
.168 .32839 L
.172 .32921 L
.176 .3298 L
.18 .33012 L
.184 .33014 L
.188 .32989 L
.192 .32942 L
.196 .32875 L
.2 .32792 L
Mistroke
.204 .32693 L
.208 .32582 L
.212 .32464 L
.216 .32346 L
.22 .32236 L
.224 .32142 L
.228 .32071 L
.232 .32024 L
.236 .32005 L
.24 .32019 L
.244 .32069 L
.248 .32158 L
.252 .32283 L
.256 .32442 L
.26 .32634 L
.264 .32857 L
.268 .33111 L
.272 .33397 L
.276 .33718 L
.28 .34076 L
.284 .3447 L
.288 .34903 L
.292 .35382 L
.296 .35917 L
.3 .36515 L
.304 .37178 L
.308 .37904 L
.312 .38688 L
.316 .39517 L
.32 .40373 L
.324 .41231 L
.328 .42064 L
.332 .4284 L
.336 .43523 L
.34 .44069 L
.344 .44442 L
.348 .44619 L
.352 .44588 L
.356 .44347 L
.36 .4391 L
.364 .43308 L
.368 .42591 L
.372 .4182 L
.376 .41063 L
.38 .40387 L
.384 .39859 L
.388 .39533 L
.392 .39436 L
.396 .39563 L
.4 .39884 L
Mistroke
.404 .40344 L
.408 .40871 L
.412 .41374 L
.416 .41758 L
.42 .4194 L
.424 .41864 L
.428 .41507 L
.432 .40875 L
.436 .40011 L
.44 .38994 L
.444 .3793 L
.448 .36918 L
.452 .36035 L
.456 .35318 L
.46 .34768 L
.464 .34349 L
.468 .33988 L
.472 .33588 L
.476 .33054 L
.48 .3232 L
.484 .3137 L
.488 .30238 L
.492 .29005 L
.496 .27798 L
.5 .26775 L
.504 .26091 L
.508 .25854 L
.512 .26093 L
.516 .2675 L
.52 .27707 L
.524 .28805 L
.528 .29877 L
.532 .3077 L
.536 .31381 L
.54 .31676 L
.544 .31688 L
.548 .31491 L
.552 .31169 L
.556 .30793 L
.56 .30419 L
.564 .3008 L
.568 .29781 L
.572 .29502 L
.576 .29219 L
.58 .28933 L
.584 .28697 L
.588 .28597 L
.592 .28715 L
.596 .29081 L
.6 .29647 L
Mistroke
.604 .30297 L
.608 .30874 L
.612 .31215 L
.616 .31201 L
.62 .30804 L
.624 .30115 L
.628 .29334 L
.632 .28704 L
.636 .28417 L
.64 .28541 L
.644 .2901 L
.648 .29666 L
.652 .30317 L
.656 .30792 L
.66 .30966 L
.664 .30799 L
.668 .30353 L
.672 .29788 L
.676 .29304 L
.68 .29053 L
.684 .29073 L
.688 .29293 L
.692 .29598 L
.696 .29891 L
.7 .30109 L
.704 .30214 L
.708 .30179 L
.712 .30012 L
.716 .2978 L
.72 .29591 L
.724 .29525 L
.728 .29583 L
.732 .29695 L
.736 .29788 L
.74 .29852 L
.744 .29927 L
.748 .30033 L
.752 .30114 L
.756 .30072 L
.76 .29861 L
.764 .29565 L
.768 .29346 L
.772 .29335 L
.776 .29531 L
.78 .29808 L
.784 .30029 L
.788 .30122 L
.792 .30098 L
.796 .3 L
.8 .29837 L
Mistroke
.804 .29636 L
.808 .29468 L
.812 .29448 L
.816 .2965 L
.82 .29988 L
.824 .30246 L
.828 .3022 L
.832 .29876 L
.836 .29436 L
.84 .29204 L
.844 .2934 L
.848 .2976 L
.852 .30157 L
.856 .30274 L
.86 .30084 L
.864 .29753 L
.868 .29542 L
.872 .29556 L
.876 .29705 L
.88 .29851 L
.884 .2987 L
.888 .29798 L
.892 .29749 L
.896 .29749 L
.9 .29791 L
.904 .29799 L
.908 .29733 L
.912 .29689 L
.916 .29724 L
.92 .29846 L
.924 .29989 L
.928 .29988 L
.932 .29827 L
.936 .29601 L
.94 .29449 L
.944 .29524 L
.948 .29769 L
.952 .30013 L
.956 .3011 L
.96 .29969 L
.964 .29711 L
.968 .2952 L
.972 .29499 L
.976 .29677 L
.98 .29898 L
.984 .30014 L
.988 .29973 L
.992 .29776 L
.996 .29594 L
1 .29536 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .56606 m
.008 .56406 L
.012 .56356 L
.016 .5644 L
.02 .56454 L
.024 .56413 L
.028 .56414 L
.032 .56426 L
.036 .56428 L
.04 .56419 L
.044 .5642 L
.048 .56419 L
.052 .56419 L
.056 .56414 L
.06 .56413 L
.064 .56409 L
.068 .56407 L
.072 .56401 L
.076 .56396 L
.08 .56389 L
.084 .56382 L
.088 .56372 L
.092 .56362 L
.096 .56348 L
.1 .56334 L
.104 .56316 L
.108 .56297 L
.112 .56273 L
.116 .56247 L
.12 .56217 L
.124 .56184 L
.128 .56146 L
.132 .56105 L
.136 .56058 L
.14 .56008 L
.144 .55952 L
.148 .55892 L
.152 .55827 L
.156 .55758 L
.16 .55684 L
.164 .55608 L
.168 .55527 L
.172 .55444 L
.176 .55358 L
.18 .5527 L
.184 .55181 L
.188 .55093 L
.192 .55004 L
.196 .54918 L
.2 .54833 L
Mistroke
.204 .5475 L
.208 .5467 L
.212 .54593 L
.216 .5452 L
.22 .54449 L
.224 .54382 L
.228 .54317 L
.232 .54254 L
.236 .54193 L
.24 .54131 L
.244 .5407 L
.248 .54007 L
.252 .53941 L
.256 .53872 L
.26 .538 L
.264 .53723 L
.268 .53642 L
.272 .53555 L
.276 .53463 L
.28 .53365 L
.284 .53261 L
.288 .53151 L
.292 .53034 L
.296 .52911 L
.3 .52781 L
.304 .52643 L
.308 .52496 L
.312 .52339 L
.316 .5217 L
.32 .51989 L
.324 .51796 L
.328 .5159 L
.332 .51371 L
.336 .51139 L
.34 .50897 L
.344 .50646 L
.348 .50389 L
.352 .50129 L
.356 .4987 L
.36 .49614 L
.364 .49365 L
.368 .49126 L
.372 .48899 L
.376 .48682 L
.38 .48477 L
.384 .48281 L
.388 .48092 L
.392 .47906 L
.396 .47718 L
.4 .47527 L
Mistroke
.404 .47329 L
.408 .47123 L
.412 .46909 L
.416 .46688 L
.42 .46463 L
.424 .46238 L
.428 .46019 L
.432 .4581 L
.436 .45615 L
.44 .45438 L
.444 .4528 L
.448 .4514 L
.452 .45018 L
.456 .44911 L
.46 .44815 L
.464 .44727 L
.468 .44647 L
.472 .44574 L
.476 .4451 L
.48 .44458 L
.484 .44422 L
.488 .44405 L
.492 .4441 L
.496 .44439 L
.5 .44488 L
.504 .44554 L
.508 .4463 L
.512 .44707 L
.516 .44777 L
.52 .44834 L
.524 .44871 L
.528 .44889 L
.532 .44886 L
.536 .44868 L
.54 .44838 L
.544 .44802 L
.548 .44766 L
.552 .44734 L
.556 .44709 L
.56 .44691 L
.564 .44683 L
.568 .44684 L
.572 .44693 L
.576 .44709 L
.58 .4473 L
.584 .44756 L
.588 .44782 L
.592 .44805 L
.596 .44822 L
.6 .4483 L
Mistroke
.604 .44827 L
.608 .44815 L
.612 .44797 L
.616 .44777 L
.62 .44762 L
.624 .44755 L
.628 .4476 L
.632 .44776 L
.636 .44799 L
.64 .44823 L
.644 .44844 L
.648 .44855 L
.652 .44857 L
.656 .44848 L
.66 .44834 L
.664 .44818 L
.668 .44807 L
.672 .44802 L
.676 .44806 L
.68 .44816 L
.684 .44828 L
.688 .44841 L
.692 .44852 L
.696 .4486 L
.7 .44864 L
.704 .44866 L
.708 .44866 L
.712 .44866 L
.716 .44866 L
.72 .44867 L
.724 .4487 L
.728 .44872 L
.732 .44874 L
.736 .44877 L
.74 .4488 L
.744 .44883 L
.748 .44885 L
.752 .44885 L
.756 .44886 L
.76 .44887 L
.764 .44892 L
.768 .44899 L
.772 .44907 L
.776 .44914 L
.78 .44918 L
.784 .44919 L
.788 .44918 L
.792 .44918 L
.796 .44919 L
.8 .44921 L
Mistroke
.804 .44926 L
.808 .44932 L
.812 .44937 L
.816 .44939 L
.82 .44937 L
.824 .44933 L
.828 .4493 L
.832 .44932 L
.836 .44941 L
.84 .44955 L
.844 .44969 L
.848 .44977 L
.852 .44977 L
.856 .44971 L
.86 .44964 L
.864 .4496 L
.868 .4496 L
.872 .44965 L
.876 .44972 L
.88 .4498 L
.884 .44986 L
.888 .44992 L
.892 .44995 L
.896 .44997 L
.9 .44997 L
.904 .44998 L
.908 .44999 L
.912 .45003 L
.916 .45007 L
.92 .45011 L
.924 .45012 L
.928 .45014 L
.932 .45014 L
.936 .45018 L
.94 .45023 L
.944 .4503 L
.948 .45034 L
.952 .45037 L
.956 .45036 L
.96 .45037 L
.964 .45037 L
.968 .45043 L
.972 .45047 L
.976 .45053 L
.98 .45054 L
.984 .45055 L
.988 .45053 L
.992 .45057 L
.996 .4506 L
1 .4507 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42465 L
.012 .42982 L
.016 .43166 L
.02 .42989 L
.024 .42926 L
.028 .42975 L
.032 .42999 L
.036 .42976 L
.04 .42969 L
.044 .4297 L
.048 .42974 L
.052 .42969 L
.056 .42969 L
.06 .42968 L
.064 .42971 L
.068 .42971 L
.072 .42975 L
.076 .42977 L
.08 .42983 L
.084 .42989 L
.088 .42998 L
.092 .43008 L
.096 .43021 L
.1 .43036 L
.104 .43056 L
.108 .43077 L
.112 .43103 L
.116 .43131 L
.12 .43166 L
.124 .43204 L
.128 .43248 L
.132 .43297 L
.136 .43352 L
.14 .43412 L
.144 .43478 L
.148 .4355 L
.152 .43627 L
.156 .4371 L
.16 .43799 L
.164 .43892 L
.168 .4399 L
.172 .44091 L
.176 .44195 L
.18 .44301 L
.184 .44408 L
.188 .44516 L
.192 .44623 L
.196 .44729 L
.2 .44832 L
Mistroke
.204 .44932 L
.208 .45029 L
.212 .45122 L
.216 .4521 L
.22 .45295 L
.224 .45377 L
.228 .45455 L
.232 .4553 L
.236 .45605 L
.24 .45678 L
.244 .45753 L
.248 .45829 L
.252 .45907 L
.256 .4599 L
.26 .46077 L
.264 .4617 L
.268 .4627 L
.272 .46376 L
.276 .46488 L
.28 .46608 L
.284 .46734 L
.288 .46869 L
.292 .47011 L
.296 .47162 L
.3 .47322 L
.304 .47492 L
.308 .47673 L
.312 .47867 L
.316 .48075 L
.32 .48297 L
.324 .48535 L
.328 .4879 L
.332 .49061 L
.336 .49348 L
.34 .49647 L
.344 .49958 L
.348 .50277 L
.352 .50599 L
.356 .5092 L
.36 .51237 L
.364 .51545 L
.368 .51841 L
.372 .52123 L
.376 .52391 L
.38 .52646 L
.384 .52889 L
.388 .53123 L
.392 .53354 L
.396 .53586 L
.4 .53822 L
Mistroke
.404 .54068 L
.408 .54323 L
.412 .54589 L
.416 .54864 L
.42 .55143 L
.424 .55422 L
.428 .55694 L
.432 .55954 L
.436 .56195 L
.44 .56415 L
.444 .56611 L
.448 .56784 L
.452 .56936 L
.456 .57069 L
.46 .57188 L
.464 .57297 L
.468 .57396 L
.472 .57486 L
.476 .57565 L
.48 .57629 L
.484 .57674 L
.488 .57694 L
.492 .57687 L
.496 .57651 L
.5 .57589 L
.504 .57507 L
.508 .57412 L
.512 .57315 L
.516 .57226 L
.52 .57155 L
.524 .57106 L
.528 .57083 L
.532 .57085 L
.536 .57109 L
.54 .57146 L
.544 .57191 L
.548 .57235 L
.552 .57274 L
.556 .57304 L
.56 .57323 L
.564 .57332 L
.568 .57331 L
.572 .5732 L
.576 .573 L
.58 .57273 L
.584 .57242 L
.588 .57209 L
.592 .57179 L
.596 .57156 L
.6 .57144 L
Mistroke
.604 .57146 L
.608 .5716 L
.612 .57182 L
.616 .57206 L
.62 .57226 L
.624 .57234 L
.628 .57229 L
.632 .57209 L
.636 .57179 L
.64 .57146 L
.644 .57118 L
.648 .57101 L
.652 .57098 L
.656 .57109 L
.66 .57128 L
.664 .57149 L
.668 .57164 L
.672 .57169 L
.676 .57164 L
.68 .5715 L
.684 .5713 L
.688 .5711 L
.692 .57094 L
.696 .57085 L
.7 .57082 L
.704 .57082 L
.708 .57083 L
.712 .57084 L
.716 .57082 L
.72 .57078 L
.724 .57073 L
.728 .57066 L
.732 .57059 L
.736 .57054 L
.74 .57051 L
.744 .57051 L
.748 .57052 L
.752 .57053 L
.756 .57051 L
.76 .57046 L
.764 .57038 L
.768 .57028 L
.772 .57016 L
.776 .57004 L
.78 .56996 L
.784 .56993 L
.788 .56996 L
.792 .57 L
.796 .57003 L
.8 .57 L
Mistroke
.804 .56991 L
.808 .56981 L
.812 .56972 L
.816 .56968 L
.82 .56968 L
.824 .56969 L
.828 .56968 L
.832 .56964 L
.836 .56957 L
.84 .56947 L
.844 .56936 L
.848 .56927 L
.852 .56922 L
.856 .56921 L
.86 .56924 L
.864 .56927 L
.868 .56926 L
.872 .5692 L
.876 .56909 L
.88 .56899 L
.884 .56893 L
.888 .56892 L
.892 .56893 L
.896 .56893 L
.9 .56887 L
.904 .56878 L
.908 .56867 L
.912 .56861 L
.916 .56858 L
.92 .56859 L
.924 .56858 L
.928 .56855 L
.932 .56847 L
.936 .56841 L
.94 .56836 L
.944 .56835 L
.948 .56832 L
.952 .56831 L
.956 .56824 L
.96 .56817 L
.964 .56808 L
.968 .56803 L
.972 .56797 L
.976 .56797 L
.98 .56791 L
.984 .5679 L
.988 .56783 L
.992 .56782 L
.996 .56778 L
1 .56779 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol0009oo`@000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`80009oo`03001o
ogoo008000=oo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`00
8Woo00<007ooOol0;Goo00@007ooOol000Eoo`8000=oo`03001oogoo02ioo`008Woo0P00;Woo00@0
07ooOol000=oo`D00004Ool007oo0002Ool300001Goo00000000Ool00`0000=oo`0000003@0000Ao
o`00001oo`8000aoo`008WooH`0037oo000ROol01@00Oomoogoo00000goo00<007ooOol0100000=o
o`00Ool00Woo00D007ooOomoo`00009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`D000=oo`800006Ool007oo001oo`000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000aoo`008Woo0P0037oo100000=o
o`0000001P0057oo00<007ooOol0?Goo000ROol00`00Oomoo`0>Ool20007Ool2000BOol2000oOol0
029oo`8001Uoo`80011oo`80041oo`008Woo0P006goo00<007ooOol037oo0P00@Goo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0JOol00`00Oomoo`0<Ool00`00Oomoo`10
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0077oo00<007ooOol0
2Woo00<007ooOol0@Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
01eoo`03001oogoo00Uoo`03001oogoo045oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`0LOol00`00Oomoo`04Ool20003Ool00`00Oomoo`11Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P007Goo00<007ooOol00goo00H007oo
Ool007oo0014Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P007Woo00D007oo
Oomoo`0000=oo`<004Aoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol07Goo00D0
07ooOomoo`0004Yoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P007goo00@007oo
000004Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P0087oo0P00
Bgoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<0
07ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=o
o`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<0
00=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomo
ogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomo
o`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00
Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003
Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04
001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool3
0004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol0
0002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00
Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Ao
o`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04
001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<0
00=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool2
0004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001o
o`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@0
07ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P00
17oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol0
3goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol0
2Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P00
0goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001o
o`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0006Ool00`00Oomoo`0YOol2000kOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001o
ogoo02Eoo`D00003Ool0000002d000aoo`00:7oo00<007ooOol097oo0P00@7oo000XOol00`00Oomo
o`0QOol30012Ool0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo01moo`<0
04Aoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0NOol2
0016Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol077oo
0P00B7oo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8001]oo`<004Uo
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0GOol4001;
Ool0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol04Woo1P00CWoo000A
Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool6001COol002Qooa4005Qoo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomo
ogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
1Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:
Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool2
0004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo
000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo
00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool3
0003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`80
00eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009o
o`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001o
ogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@0
07ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@0
00=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool0
1P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Ao
o`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo
00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool0
1`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001o
ogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool3
0002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<
Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo000;
Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomo
o`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo
000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Mo
o`03001oogoo009ooa0006Eoo`005goo00<007ooOol00Woo00<007ooOol037oo1@00HGoo000GOol0
0`00Oomoo`02Ool00`00Oomoo`0@Ool5001MOol001Ioo`8000Aoo`8001Eoo`H005Qoo`005goo00<0
07ooOol00Woo00<007ooOol06Goo1000EGoo000LOol00`00Oomoo`0LOol3001COol001aoo`8001mo
o`<0055oo`0077oo00<007ooOol087oo0P00D7oo000LOol2000ROol2001?Ool001aoo`03001oogoo
029oo`<004eoo`0077oo00<007ooOol097oo0P00C7oo000:Ool30004Ool00`00Oomoo`02Ool30003
Ool2000VOol3001:Ool000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`0WOol2
0019Ool000]oo`03001oogoo00]oo`04001oogoo000[Ool20017Ool000]oo`03001oogoo00]oo`03
001oogoo008002]oo`<002AooaD000aoo`002goo00<007ooOol01goo10000goo00<007ooOol0;7oo
9@008Goo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0
009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(35571\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30089 m
.008 .30121 L
.012 .30003 L
.016 .29992 L
.02 .30075 L
.024 .30091 L
.028 .30066 L
.032 .30085 L
.036 .30127 L
.04 .30151 L
.044 .3017 L
.048 .30205 L
.052 .30251 L
.056 .303 L
.06 .30356 L
.064 .30421 L
.068 .30495 L
.072 .30575 L
.076 .30664 L
.08 .30764 L
.084 .30875 L
.088 .30996 L
.092 .31129 L
.096 .3127 L
.1 .31417 L
.104 .3157 L
.108 .31728 L
.112 .3189 L
.116 .32055 L
.12 .32219 L
.124 .32378 L
.128 .32527 L
.132 .32665 L
.136 .32789 L
.14 .32896 L
.144 .32984 L
.148 .33049 L
.152 .33088 L
.156 .33101 L
.16 .33088 L
.164 .33051 L
.168 .32991 L
.172 .3291 L
.176 .32812 L
.18 .32699 L
.184 .32578 L
.188 .32457 L
.192 .32344 L
.196 .32246 L
.2 .32165 L
Mistroke
.204 .32107 L
.208 .32077 L
.212 .32079 L
.216 .32118 L
.22 .32195 L
.224 .32311 L
.228 .32464 L
.232 .32651 L
.236 .3287 L
.24 .33122 L
.244 .33408 L
.248 .33726 L
.252 .34076 L
.256 .34461 L
.26 .34887 L
.264 .3536 L
.268 .35889 L
.272 .36476 L
.276 .37125 L
.28 .37835 L
.284 .38601 L
.288 .39415 L
.292 .40264 L
.296 .41132 L
.3 .41989 L
.304 .42799 L
.308 .43521 L
.312 .44116 L
.316 .44553 L
.32 .44803 L
.324 .44848 L
.328 .44682 L
.332 .44315 L
.336 .43771 L
.34 .43086 L
.344 .42318 L
.348 .41535 L
.352 .40814 L
.356 .40221 L
.36 .39808 L
.364 .3961 L
.368 .39639 L
.372 .39883 L
.376 .40297 L
.38 .40809 L
.384 .41334 L
.388 .41781 L
.392 .4206 L
.396 .42097 L
.4 .41848 L
Mistroke
.404 .4131 L
.408 .40522 L
.412 .39552 L
.416 .38484 L
.42 .37413 L
.424 .36429 L
.428 .35597 L
.432 .34944 L
.436 .34447 L
.44 .34049 L
.444 .33669 L
.448 .33212 L
.452 .3259 L
.456 .31748 L
.46 .30691 L
.464 .29488 L
.468 .28261 L
.472 .27156 L
.476 .26318 L
.48 .25868 L
.484 .25878 L
.488 .26345 L
.492 .27187 L
.496 .28263 L
.5 .29402 L
.504 .30443 L
.508 .31248 L
.512 .31731 L
.516 .31869 L
.52 .31715 L
.524 .31371 L
.528 .30953 L
.532 .30545 L
.536 .30186 L
.54 .29877 L
.544 .29597 L
.548 .29323 L
.552 .29049 L
.556 .28803 L
.56 .28648 L
.564 .28666 L
.568 .28912 L
.572 .29379 L
.576 .29982 L
.58 .30583 L
.584 .31032 L
.588 .31207 L
.592 .31043 L
.596 .30556 L
.6 .29854 L
Mistroke
.604 .29122 L
.608 .28574 L
.612 .28381 L
.616 .28606 L
.62 .29174 L
.624 .29908 L
.628 .30586 L
.632 .31011 L
.636 .31065 L
.64 .30743 L
.644 .30164 L
.648 .29532 L
.652 .29068 L
.656 .28914 L
.66 .29076 L
.664 .29436 L
.668 .29822 L
.672 .30102 L
.676 .30219 L
.68 .30187 L
.684 .30054 L
.688 .29876 L
.692 .29712 L
.696 .29613 L
.7 .29602 L
.704 .29657 L
.708 .29729 L
.712 .29789 L
.716 .2985 L
.72 .29944 L
.724 .30065 L
.728 .30137 L
.732 .30067 L
.736 .29828 L
.74 .29513 L
.744 .29292 L
.748 .29293 L
.752 .29521 L
.756 .29856 L
.76 .30144 L
.764 .30277 L
.768 .30226 L
.772 .30022 L
.776 .29725 L
.78 .29443 L
.784 .2931 L
.788 .29428 L
.792 .29781 L
.796 .30184 L
.8 .3038 L
Mistroke
.804 .30218 L
.808 .29771 L
.812 .29324 L
.816 .29164 L
.82 .29379 L
.824 .29814 L
.828 .30178 L
.832 .30274 L
.836 .30115 L
.84 .29843 L
.844 .29636 L
.848 .29557 L
.852 .29575 L
.856 .29658 L
.86 .29773 L
.864 .29904 L
.868 .30007 L
.872 .29981 L
.876 .29813 L
.88 .29586 L
.884 .29456 L
.888 .29568 L
.892 .29865 L
.896 .30143 L
.9 .30202 L
.904 .29958 L
.908 .2959 L
.912 .29365 L
.916 .29425 L
.92 .29732 L
.924 .30037 L
.928 .30116 L
.932 .29956 L
.936 .2969 L
.94 .29544 L
.944 .2962 L
.948 .29812 L
.952 .29965 L
.956 .29942 L
.96 .2977 L
.964 .29612 L
.968 .29573 L
.972 .29699 L
.976 .29883 L
.98 .2997 L
.984 .2994 L
.988 .29797 L
.992 .29647 L
.996 .29629 L
1 .29674 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .57138 m
.008 .56381 L
.012 .56132 L
.016 .56374 L
.02 .56463 L
.024 .56377 L
.028 .56348 L
.032 .5637 L
.036 .5638 L
.04 .56366 L
.044 .5636 L
.048 .56355 L
.052 .56352 L
.056 .56342 L
.06 .56335 L
.064 .56323 L
.068 .56312 L
.072 .56297 L
.076 .56281 L
.08 .5626 L
.084 .56239 L
.088 .56214 L
.092 .56186 L
.096 .56153 L
.1 .56117 L
.104 .56076 L
.108 .56031 L
.112 .55981 L
.116 .55928 L
.12 .55869 L
.124 .55806 L
.128 .55738 L
.132 .55666 L
.136 .5559 L
.14 .55511 L
.144 .55428 L
.148 .55343 L
.152 .55255 L
.156 .55168 L
.16 .55079 L
.164 .54991 L
.168 .54904 L
.172 .54818 L
.176 .54734 L
.18 .54653 L
.184 .54576 L
.188 .54501 L
.192 .5443 L
.196 .54362 L
.2 .54296 L
Mistroke
.204 .54233 L
.208 .5417 L
.212 .54109 L
.216 .54048 L
.22 .53985 L
.224 .53921 L
.228 .53854 L
.232 .53783 L
.236 .53707 L
.24 .53627 L
.244 .53542 L
.248 .53451 L
.252 .53355 L
.256 .53253 L
.26 .53145 L
.264 .5303 L
.268 .52909 L
.272 .52781 L
.276 .52645 L
.28 .525 L
.284 .52345 L
.288 .5218 L
.292 .52004 L
.296 .51815 L
.3 .51613 L
.304 .51399 L
.308 .51171 L
.312 .50933 L
.316 .50685 L
.32 .5043 L
.324 .50171 L
.328 .49912 L
.332 .49655 L
.336 .49404 L
.34 .49162 L
.344 .48929 L
.348 .48709 L
.352 .485 L
.356 .483 L
.36 .48109 L
.364 .47922 L
.368 .47736 L
.372 .47547 L
.376 .47353 L
.38 .47151 L
.384 .46941 L
.388 .46723 L
.392 .465 L
.396 .46276 L
.4 .46056 L
Mistroke
.404 .45843 L
.408 .45643 L
.412 .45459 L
.416 .45294 L
.42 .45148 L
.424 .4502 L
.428 .44909 L
.432 .4481 L
.436 .44722 L
.44 .44642 L
.444 .44569 L
.448 .44504 L
.452 .44449 L
.456 .44408 L
.46 .44384 L
.464 .44381 L
.468 .444 L
.472 .44441 L
.476 .445 L
.48 .44572 L
.484 .44649 L
.488 .44723 L
.492 .44787 L
.496 .44833 L
.5 .4486 L
.504 .44865 L
.508 .44853 L
.512 .44826 L
.516 .4479 L
.52 .44753 L
.524 .44718 L
.528 .44689 L
.532 .44669 L
.536 .44658 L
.54 .44656 L
.544 .44662 L
.548 .44675 L
.552 .44694 L
.556 .44717 L
.56 .44742 L
.564 .44767 L
.568 .44787 L
.572 .448 L
.576 .44803 L
.58 .44796 L
.584 .44781 L
.588 .44761 L
.592 .44743 L
.596 .44731 L
.6 .44729 L
Mistroke
.604 .44739 L
.608 .44758 L
.612 .44783 L
.616 .44807 L
.62 .44825 L
.624 .44832 L
.628 .44829 L
.632 .44816 L
.636 .448 L
.64 .44785 L
.644 .44775 L
.648 .44774 L
.652 .44782 L
.656 .44795 L
.66 .44809 L
.664 .44823 L
.668 .44832 L
.672 .44837 L
.676 .44839 L
.68 .44838 L
.684 .44837 L
.688 .44837 L
.692 .44839 L
.696 .44842 L
.7 .44846 L
.704 .44849 L
.708 .44851 L
.712 .44853 L
.716 .44854 L
.72 .44855 L
.724 .44856 L
.728 .44857 L
.732 .4486 L
.736 .44864 L
.74 .4487 L
.744 .44877 L
.748 .44884 L
.752 .4489 L
.756 .44892 L
.76 .44892 L
.764 .44891 L
.768 .44891 L
.772 .44892 L
.776 .44895 L
.78 .44901 L
.784 .44907 L
.788 .44912 L
.792 .44914 L
.796 .44912 L
.8 .44908 L
Mistroke
.804 .44906 L
.808 .44909 L
.812 .44918 L
.816 .44931 L
.82 .44942 L
.824 .44949 L
.828 .44949 L
.832 .44945 L
.836 .4494 L
.84 .44936 L
.844 .44936 L
.848 .4494 L
.852 .44946 L
.856 .44954 L
.86 .44961 L
.864 .44967 L
.868 .4497 L
.872 .44971 L
.876 .44972 L
.88 .44973 L
.884 .44976 L
.888 .4498 L
.892 .44982 L
.896 .44983 L
.9 .44983 L
.904 .44985 L
.908 .44989 L
.912 .44996 L
.916 .45003 L
.92 .45008 L
.924 .45008 L
.928 .45007 L
.932 .45006 L
.936 .45009 L
.94 .45014 L
.944 .4502 L
.948 .45024 L
.952 .45027 L
.956 .45026 L
.96 .45028 L
.964 .45029 L
.968 .45035 L
.972 .4504 L
.976 .45045 L
.98 .45046 L
.984 .45049 L
.988 .45048 L
.992 .45052 L
.996 .45054 L
1 .4506 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43089 L
.012 .42966 L
.016 .42955 L
.02 .43005 L
.024 .43008 L
.028 .4298 L
.032 .42985 L
.036 .42992 L
.04 .42995 L
.044 .42991 L
.048 .42998 L
.052 .43002 L
.056 .4301 L
.06 .43016 L
.064 .43027 L
.068 .43038 L
.072 .43054 L
.076 .4307 L
.08 .43092 L
.084 .43116 L
.088 .43145 L
.092 .43177 L
.096 .43215 L
.1 .43256 L
.104 .43304 L
.108 .43356 L
.112 .43415 L
.116 .43479 L
.12 .4355 L
.124 .43625 L
.128 .43707 L
.132 .43793 L
.136 .43885 L
.14 .43981 L
.144 .44082 L
.148 .44184 L
.152 .4429 L
.156 .44397 L
.16 .44505 L
.164 .44612 L
.168 .44718 L
.172 .44822 L
.176 .44923 L
.18 .4502 L
.184 .45115 L
.188 .45205 L
.192 .45291 L
.196 .45374 L
.2 .45453 L
Mistroke
.204 .45529 L
.208 .45603 L
.212 .45677 L
.216 .45751 L
.22 .45826 L
.224 .45904 L
.228 .45986 L
.232 .46072 L
.236 .46162 L
.24 .4626 L
.244 .46363 L
.248 .46473 L
.252 .46591 L
.256 .46716 L
.26 .46848 L
.264 .46989 L
.268 .47137 L
.272 .47295 L
.276 .47462 L
.28 .47639 L
.284 .47829 L
.288 .48033 L
.292 .48251 L
.296 .48484 L
.3 .48733 L
.304 .48999 L
.308 .49279 L
.312 .49574 L
.316 .4988 L
.32 .50196 L
.324 .50517 L
.328 .50839 L
.332 .51157 L
.336 .51469 L
.34 .51769 L
.344 .52056 L
.348 .52329 L
.352 .52589 L
.356 .52835 L
.36 .53073 L
.364 .53305 L
.368 .53535 L
.372 .53769 L
.376 .5401 L
.38 .5426 L
.384 .54521 L
.388 .54791 L
.392 .55067 L
.396 .55345 L
.4 .55619 L
Mistroke
.404 .55883 L
.408 .56132 L
.412 .5636 L
.416 .56565 L
.42 .56746 L
.424 .56904 L
.428 .57042 L
.432 .57164 L
.436 .57274 L
.44 .57373 L
.444 .57464 L
.448 .57544 L
.452 .57612 L
.456 .57662 L
.46 .57691 L
.464 .57694 L
.468 .5767 L
.472 .57619 L
.476 .57544 L
.48 .57454 L
.484 .57358 L
.488 .57265 L
.492 .57185 L
.496 .57126 L
.5 .57092 L
.504 .57084 L
.508 .57099 L
.512 .57131 L
.516 .57174 L
.52 .57221 L
.524 .57264 L
.528 .57299 L
.532 .57324 L
.536 .57337 L
.54 .57339 L
.544 .5733 L
.548 .57313 L
.552 .57288 L
.556 .57258 L
.56 .57226 L
.564 .57196 L
.568 .57171 L
.572 .57155 L
.576 .5715 L
.58 .57157 L
.584 .57174 L
.588 .57196 L
.592 .57218 L
.596 .57233 L
.6 .57235 L
Mistroke
.604 .57224 L
.608 .572 L
.612 .57169 L
.616 .57138 L
.62 .57114 L
.624 .57103 L
.628 .57106 L
.632 .5712 L
.636 .57139 L
.64 .57158 L
.644 .5717 L
.648 .57172 L
.652 .57164 L
.656 .57147 L
.66 .57128 L
.664 .57109 L
.668 .57094 L
.672 .57086 L
.676 .57083 L
.68 .57083 L
.684 .57085 L
.688 .57085 L
.692 .57085 L
.696 .57082 L
.7 .57077 L
.704 .57071 L
.708 .57064 L
.712 .57058 L
.716 .57054 L
.72 .57053 L
.724 .57053 L
.728 .57053 L
.732 .57051 L
.736 .57047 L
.74 .5704 L
.744 .57029 L
.748 .57017 L
.752 .57006 L
.756 .56999 L
.76 .56996 L
.764 .56999 L
.768 .57002 L
.772 .57004 L
.776 .57 L
.78 .56993 L
.784 .56983 L
.788 .56976 L
.792 .56972 L
.796 .56972 L
.8 .56972 L
Mistroke
.804 .56971 L
.808 .56966 L
.812 .56957 L
.816 .56945 L
.82 .56933 L
.824 .56925 L
.828 .56923 L
.832 .56927 L
.836 .56932 L
.84 .56935 L
.844 .56932 L
.848 .56922 L
.852 .56908 L
.856 .56898 L
.86 .56892 L
.864 .56893 L
.868 .56895 L
.872 .56894 L
.876 .56889 L
.88 .56881 L
.884 .56873 L
.888 .56866 L
.892 .56861 L
.896 .56858 L
.9 .56855 L
.904 .56853 L
.908 .5685 L
.912 .56848 L
.916 .56845 L
.92 .56841 L
.924 .56834 L
.928 .56827 L
.932 .5682 L
.936 .56816 L
.94 .56812 L
.944 .56809 L
.948 .56803 L
.952 .56798 L
.956 .56791 L
.96 .5679 L
.964 .56788 L
.968 .5679 L
.972 .56786 L
.976 .56782 L
.98 .56771 L
.984 .56765 L
.988 .56756 L
.992 .56755 L
.996 .56751 L
1 .5675 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00<007ooOol00`000Woo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@0
07ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0`0000=oo`00
Ool00Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`80
00Ioo`008Woo00<007ooOol0:goo00<007oo00001Goo0P000goo0P00<Woo000ROol2000[Ool01@00
Oomoogoo00000goo10000Woo00@007oo001oo`<00003Ool0000000800005Ool00000001oo`020000
17oo000007oo1P0000=oo`0000000P0000=oo`0000000`0037oo000ROomS000<Ool0029oo`05001o
ogooOol00003Ool50003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00003
Ool02@00Oomoogoo001oo`00Ool00002Ool30002Ool00`00Ool000020002Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000aoo`008Woo0P002Goo10000Woo1`0057oo00<007ooOol0@7oo000ROol00`00Oomoo`0;Ool4
0006Ool00`00Oomoo`0@Ool20012Ool0029oo`8001Moo`03001oogoo00ioo`8004=oo`008Woo0P00
67oo00<007ooOol03Goo00<007ooOol0@Woo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003
Ool00`00Oomoo`0HOol00`00Oomoo`0;Ool00`00Oomoo`13Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P006Goo00<007ooOol02goo00<007ooOol0@goo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8001Yoo`03001oogoo00Yoo`03001oogoo
04=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0IOol0
0`00Oomoo`04Ool20003Ool00`00Oomoo`14Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P006goo00<007ooOol00Woo0P0000Eoo`00Oomoo`0004Ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool20004Ool2000KOol00`00Oomoo`02Ool01000Oomoogoo0`00AWoo
000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0KOol00`00Oomoo`02001<Ool000]o
o`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8001aoo`800003Ool007oo04aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P007Goo0P00CWoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qo
o`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo
0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001o
ogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000
Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@0
07ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo
0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007oo
Ool0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001o
ogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02
001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo
06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomo
o`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000A
Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomo
o`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomo
o`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000
Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003
Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`00
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol0
0002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001o
ogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@0
07ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03
001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00
Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001o
ogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005
Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`00
0Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo
00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D0
00=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo
00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007oo
Ool006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0
06Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00
Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomo
o`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomo
o`0VOol3000mOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo02=oo`@0009ooc40
00aoo`00:7oo00<007ooOol08Goo0P00@goo000XOol00`00Oomoo`0OOol30014Ool0015oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo01eoo`8004Moo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0KOol30018Ool0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol06Woo0P00BWoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`8001Uoo`8004aoo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0EOol3001>Ool0011oo`04001oogoo0008Ool0
1000Oomoo`000Woo0P0017oo00<007ooOol03goo1`00D7oo000AOol2000:Ool20004Ool00`00Oomo
o`02Ool00`00Oomoo`0;Ool5001FOol002Qoo`h005]oo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Io
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00
Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo
0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@0
07ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00
Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003
Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool0
1000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<0
07ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eo
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04
001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04
001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04
001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001ao
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol00003
Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol000]o
o`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yo
o`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00
Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo
00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`d0
06Qoo`005goo00<007ooOol00Woo00<007ooOol02Goo1@00I7oo000GOol00`00Oomoo`02Ool00`00
Oomoo`0>Ool4001POol001Ioo`8000Aoo`80019oo`H005]oo`005goo00<007ooOol00Woo00<007oo
Ool05Woo1000F7oo000LOol00`00Oomoo`0JOol2001FOol001aoo`8001eoo`8005Aoo`0077oo00<0
07ooOol07Goo0P00Dgoo000LOol2000POol2001AOol001aoo`03001oogoo021oo`80051oo`0077oo
00<007ooOol08Goo0P00Cgoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2000TOol2001=Ool0
00]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`0TOol2001<Ool000]oo`03001o
ogoo00]oo`04001oogoo000XOol2001:Ool000]oo`03001oogoo00]oo`03001oogoo008002Qoo`<0
02AooaP000aoo`002goo00<007ooOol01goo10000goo00<007ooOol0:Goo9P008goo000:Ool20009
Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(35738\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30415 m
.008 .30239 L
.012 .30095 L
.016 .30098 L
.02 .30255 L
.024 .3033 L
.028 .30309 L
.032 .3034 L
.036 .30432 L
.04 .30514 L
.044 .3058 L
.048 .30662 L
.052 .30765 L
.056 .30878 L
.06 .30998 L
.064 .31129 L
.068 .31271 L
.072 .31419 L
.076 .31572 L
.08 .31731 L
.084 .31897 L
.088 .32066 L
.092 .32235 L
.096 .324 L
.1 .32556 L
.104 .327 L
.108 .3283 L
.112 .32945 L
.116 .33042 L
.12 .33117 L
.124 .33167 L
.128 .33191 L
.132 .33187 L
.136 .33156 L
.14 .331 L
.144 .33022 L
.148 .32926 L
.152 .32816 L
.156 .32698 L
.16 .32577 L
.164 .3246 L
.168 .32352 L
.172 .32259 L
.176 .32188 L
.18 .32147 L
.184 .3214 L
.188 .32171 L
.192 .32241 L
.196 .32348 L
.2 .3249 L
Mistroke
.204 .32666 L
.208 .32878 L
.212 .33126 L
.216 .33411 L
.22 .33729 L
.224 .34078 L
.228 .3446 L
.232 .3488 L
.236 .35343 L
.24 .35858 L
.244 .36432 L
.248 .37068 L
.252 .37764 L
.256 .38517 L
.26 .39322 L
.264 .40169 L
.268 .41039 L
.272 .41905 L
.276 .42734 L
.28 .43491 L
.284 .44137 L
.288 .44637 L
.292 .44961 L
.296 .45087 L
.3 .45001 L
.304 .44703 L
.308 .4421 L
.312 .4356 L
.316 .4281 L
.32 .42024 L
.324 .4127 L
.328 .40615 L
.332 .40119 L
.336 .39826 L
.34 .39758 L
.344 .39913 L
.348 .4026 L
.352 .40743 L
.356 .41281 L
.36 .41775 L
.364 .4213 L
.368 .42268 L
.372 .42138 L
.376 .41719 L
.38 .41024 L
.384 .40105 L
.388 .39042 L
.392 .37934 L
.396 .36873 L
.4 .35936 L
Mistroke
.404 .3517 L
.408 .34584 L
.412 .34138 L
.416 .33752 L
.42 .33329 L
.424 .3278 L
.428 .32043 L
.432 .31098 L
.436 .29975 L
.44 .28761 L
.444 .2759 L
.448 .26615 L
.452 .25974 L
.456 .25763 L
.46 .26019 L
.464 .26706 L
.468 .2772 L
.472 .28896 L
.476 .30045 L
.48 .31 L
.484 .31649 L
.488 .3195 L
.492 .31924 L
.496 .31644 L
.5 .31216 L
.504 .30748 L
.508 .30315 L
.512 .29948 L
.516 .29639 L
.52 .29367 L
.524 .29123 L
.528 .28913 L
.532 .28766 L
.536 .28725 L
.54 .28841 L
.544 .2915 L
.548 .29639 L
.552 .30229 L
.556 .30783 L
.56 .31146 L
.564 .31201 L
.568 .30903 L
.572 .30305 L
.576 .29553 L
.58 .28854 L
.584 .28421 L
.588 .28395 L
.592 .2879 L
.596 .29476 L
.6 .30233 L
Mistroke
.604 .30828 L
.608 .31097 L
.612 .30985 L
.616 .30554 L
.62 .29954 L
.624 .29377 L
.628 .28999 L
.632 .28917 L
.636 .29118 L
.64 .29493 L
.644 .29889 L
.648 .30181 L
.652 .30304 L
.656 .3026 L
.66 .30092 L
.664 .29865 L
.668 .29651 L
.672 .29521 L
.676 .29511 L
.68 .29612 L
.684 .29769 L
.688 .29915 L
.692 .30016 L
.696 .30069 L
.7 .30076 L
.704 .30025 L
.708 .29891 L
.712 .29685 L
.716 .29477 L
.72 .2937 L
.724 .29433 L
.728 .29649 L
.732 .29922 L
.736 .3014 L
.74 .30229 L
.744 .30169 L
.748 .29984 L
.752 .29726 L
.756 .29486 L
.76 .2938 L
.764 .29488 L
.768 .29786 L
.772 .30117 L
.776 .30273 L
.78 .30142 L
.784 .29794 L
.788 .29453 L
.792 .29329 L
.796 .29477 L
.8 .29781 L
Mistroke
.804 .30044 L
.808 .30142 L
.812 .30079 L
.816 .29924 L
.82 .29762 L
.824 .29636 L
.828 .2957 L
.832 .29605 L
.836 .29742 L
.84 .29923 L
.844 .30033 L
.848 .29964 L
.852 .2975 L
.856 .29544 L
.86 .29516 L
.864 .29722 L
.868 .30011 L
.872 .30155 L
.876 .30041 L
.88 .29741 L
.884 .29494 L
.888 .29487 L
.892 .29693 L
.896 .29942 L
.9 .30026 L
.904 .29896 L
.908 .29705 L
.912 .29618 L
.916 .2971 L
.92 .29885 L
.924 .29964 L
.928 .29883 L
.932 .29713 L
.936 .29603 L
.94 .2966 L
.944 .29813 L
.948 .2993 L
.952 .29909 L
.956 .29766 L
.96 .29657 L
.964 .29674 L
.968 .29807 L
.972 .29955 L
.976 .29946 L
.98 .29792 L
.984 .29621 L
.988 .29525 L
.992 .29642 L
.996 .29869 L
1 .29993 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .56284 m
.008 .56336 L
.012 .56346 L
.016 .56298 L
.02 .56303 L
.024 .56316 L
.028 .56308 L
.032 .56288 L
.036 .56283 L
.04 .56274 L
.044 .56262 L
.048 .56242 L
.052 .56226 L
.056 .56204 L
.06 .56181 L
.064 .56152 L
.068 .56122 L
.072 .56086 L
.076 .56048 L
.08 .56003 L
.084 .55956 L
.088 .55903 L
.092 .55846 L
.096 .55784 L
.1 .55718 L
.104 .55646 L
.108 .55572 L
.112 .55494 L
.116 .55413 L
.12 .55328 L
.124 .55242 L
.128 .55153 L
.132 .55065 L
.136 .54977 L
.14 .5489 L
.144 .54803 L
.148 .54719 L
.152 .54637 L
.156 .54559 L
.16 .54483 L
.164 .54411 L
.168 .54342 L
.172 .54275 L
.176 .54211 L
.18 .54149 L
.184 .54088 L
.188 .54026 L
.192 .53964 L
.196 .539 L
.2 .53834 L
Mistroke
.204 .53764 L
.208 .5369 L
.212 .53612 L
.216 .53528 L
.22 .5344 L
.224 .53345 L
.228 .53244 L
.232 .53137 L
.236 .53025 L
.24 .52905 L
.244 .52779 L
.248 .52645 L
.252 .52503 L
.256 .52352 L
.26 .5219 L
.264 .52017 L
.268 .51832 L
.272 .51634 L
.276 .51424 L
.28 .51201 L
.284 .50967 L
.288 .50723 L
.292 .50471 L
.296 .50214 L
.3 .49954 L
.304 .49696 L
.308 .49443 L
.312 .49197 L
.316 .48962 L
.32 .48737 L
.324 .48524 L
.328 .48321 L
.332 .48127 L
.336 .47938 L
.34 .47752 L
.344 .47566 L
.348 .47374 L
.352 .47177 L
.356 .46971 L
.36 .46757 L
.364 .46537 L
.368 .46314 L
.372 .46093 L
.376 .45877 L
.38 .45673 L
.384 .45483 L
.388 .45311 L
.392 .45158 L
.396 .45025 L
.4 .44908 L
Mistroke
.404 .44806 L
.408 .44716 L
.412 .44636 L
.416 .44562 L
.42 .44497 L
.424 .4444 L
.428 .44396 L
.432 .44366 L
.436 .44356 L
.44 .44366 L
.444 .44398 L
.448 .44449 L
.452 .44516 L
.456 .44591 L
.46 .44667 L
.464 .44736 L
.468 .44791 L
.472 .44826 L
.476 .44841 L
.48 .44835 L
.484 .44813 L
.488 .4478 L
.492 .44742 L
.496 .44704 L
.5 .44672 L
.504 .44647 L
.508 .44633 L
.512 .44628 L
.516 .44631 L
.52 .44642 L
.524 .4466 L
.528 .44681 L
.532 .44706 L
.536 .4473 L
.54 .44751 L
.544 .44767 L
.548 .44775 L
.552 .44773 L
.556 .44763 L
.56 .44746 L
.564 .44728 L
.568 .44712 L
.572 .44704 L
.576 .44706 L
.58 .44719 L
.584 .44741 L
.588 .44766 L
.592 .44789 L
.596 .44803 L
.6 .44806 L
Mistroke
.604 .44799 L
.608 .44784 L
.612 .44767 L
.616 .44753 L
.62 .44746 L
.624 .44748 L
.628 .44758 L
.632 .44773 L
.636 .44789 L
.64 .44802 L
.644 .44811 L
.648 .44814 L
.652 .44814 L
.656 .44812 L
.66 .4481 L
.664 .4481 L
.668 .44811 L
.672 .44815 L
.676 .44819 L
.68 .44824 L
.684 .44827 L
.688 .44829 L
.692 .44829 L
.696 .4483 L
.7 .4483 L
.704 .44831 L
.708 .44833 L
.712 .44838 L
.716 .44845 L
.72 .44854 L
.724 .44861 L
.728 .44867 L
.732 .44868 L
.736 .44867 L
.74 .44865 L
.744 .44863 L
.748 .44864 L
.752 .44868 L
.756 .44874 L
.76 .44882 L
.764 .44887 L
.768 .44889 L
.772 .44887 L
.776 .44883 L
.78 .44882 L
.784 .44886 L
.788 .44895 L
.792 .44906 L
.796 .44916 L
.8 .44922 L
Mistroke
.804 .44922 L
.808 .44918 L
.812 .44913 L
.816 .4491 L
.82 .44911 L
.824 .44916 L
.828 .44923 L
.832 .44931 L
.836 .44937 L
.84 .44941 L
.844 .44942 L
.848 .44942 L
.852 .44944 L
.856 .44948 L
.86 .44953 L
.864 .44958 L
.868 .44959 L
.872 .44958 L
.876 .44956 L
.88 .44958 L
.884 .44962 L
.888 .4497 L
.892 .44976 L
.896 .44981 L
.9 .44983 L
.904 .44984 L
.908 .44984 L
.912 .44986 L
.916 .44989 L
.92 .44992 L
.924 .44994 L
.928 .44998 L
.932 .45001 L
.936 .45006 L
.94 .45009 L
.944 .45013 L
.948 .45014 L
.952 .45016 L
.956 .45017 L
.96 .45022 L
.964 .45024 L
.968 .45029 L
.972 .4503 L
.976 .45032 L
.98 .45033 L
.984 .45037 L
.988 .4504 L
.992 .45048 L
.996 .45049 L
1 .45054 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43549 L
.012 .43003 L
.016 .42827 L
.02 .43007 L
.024 .4308 L
.028 .43024 L
.032 .43014 L
.036 .4304 L
.04 .43063 L
.044 .43068 L
.048 .43085 L
.052 .43105 L
.056 .43132 L
.06 .43157 L
.064 .43189 L
.068 .43224 L
.072 .43266 L
.076 .4331 L
.08 .43363 L
.084 .43419 L
.088 .43482 L
.092 .4355 L
.096 .43625 L
.1 .43703 L
.104 .43789 L
.108 .43878 L
.112 .43974 L
.116 .44072 L
.12 .44175 L
.124 .44279 L
.128 .44386 L
.132 .44493 L
.136 .446 L
.14 .44706 L
.144 .44811 L
.148 .44913 L
.152 .45012 L
.156 .45107 L
.16 .45199 L
.164 .45286 L
.168 .4537 L
.172 .45449 L
.176 .45527 L
.18 .45602 L
.184 .45676 L
.188 .4575 L
.192 .45825 L
.196 .45901 L
.2 .45981 L
Mistroke
.204 .46065 L
.208 .46155 L
.212 .4625 L
.216 .46352 L
.22 .4646 L
.224 .46576 L
.228 .46698 L
.232 .46828 L
.236 .46966 L
.24 .47112 L
.244 .47268 L
.248 .47432 L
.252 .47607 L
.256 .47793 L
.26 .47993 L
.264 .48206 L
.268 .48434 L
.272 .48678 L
.276 .48937 L
.28 .49213 L
.284 .49503 L
.288 .49805 L
.292 .50118 L
.296 .50436 L
.3 .50757 L
.304 .51076 L
.308 .5139 L
.312 .51695 L
.316 .51987 L
.32 .52266 L
.324 .5253 L
.328 .52782 L
.332 .53022 L
.336 .53255 L
.34 .53485 L
.344 .53717 L
.348 .53954 L
.352 .54199 L
.356 .54455 L
.36 .5472 L
.364 .54993 L
.368 .55269 L
.372 .55544 L
.376 .55811 L
.38 .56065 L
.384 .56301 L
.388 .56515 L
.392 .56704 L
.396 .5687 L
.4 .57015 L
Mistroke
.404 .57141 L
.408 .57252 L
.412 .57352 L
.416 .57442 L
.42 .57523 L
.424 .57593 L
.428 .57649 L
.432 .57685 L
.436 .57698 L
.44 .57684 L
.444 .57644 L
.448 .57579 L
.452 .57495 L
.456 .574 L
.46 .57305 L
.464 .57219 L
.468 .5715 L
.472 .57105 L
.476 .57086 L
.48 .57092 L
.484 .57118 L
.488 .57159 L
.492 .57206 L
.496 .57252 L
.5 .57292 L
.504 .57321 L
.508 .57339 L
.512 .57345 L
.516 .5734 L
.52 .57325 L
.524 .57303 L
.528 .57275 L
.532 .57244 L
.536 .57213 L
.54 .57185 L
.544 .57165 L
.548 .57155 L
.552 .57156 L
.556 .57169 L
.56 .57189 L
.564 .57212 L
.568 .5723 L
.572 .57239 L
.576 .57234 L
.58 .57217 L
.584 .57189 L
.588 .57159 L
.592 .57131 L
.596 .57113 L
.6 .57108 L
Mistroke
.604 .57115 L
.608 .57132 L
.612 .57152 L
.616 .57168 L
.62 .57176 L
.624 .57173 L
.628 .57161 L
.632 .57143 L
.636 .57123 L
.64 .57105 L
.644 .57093 L
.648 .57087 L
.652 .57086 L
.656 .57087 L
.66 .57088 L
.664 .57088 L
.668 .57086 L
.672 .57082 L
.676 .57078 L
.68 .57073 L
.684 .57068 L
.688 .57063 L
.692 .57059 L
.696 .57057 L
.7 .57055 L
.704 .57053 L
.708 .5705 L
.712 .57045 L
.716 .57038 L
.72 .57029 L
.724 .57019 L
.728 .5701 L
.732 .57004 L
.736 .57002 L
.74 .57002 L
.744 .57004 L
.748 .57004 L
.752 .57 L
.756 .56993 L
.76 .56986 L
.764 .5698 L
.768 .56977 L
.772 .56976 L
.776 .56975 L
.78 .56972 L
.784 .56966 L
.788 .56956 L
.792 .56944 L
.796 .56933 L
.8 .56927 L
Mistroke
.804 .56926 L
.808 .56931 L
.812 .56937 L
.816 .56939 L
.82 .56935 L
.824 .56924 L
.828 .56911 L
.832 .56901 L
.836 .56894 L
.84 .56893 L
.844 .56893 L
.848 .56892 L
.852 .5689 L
.856 .56885 L
.86 .56879 L
.864 .56872 L
.868 .56866 L
.872 .56861 L
.876 .56856 L
.88 .56853 L
.884 .56851 L
.888 .56849 L
.892 .56846 L
.896 .56841 L
.9 .56836 L
.904 .56831 L
.908 .56826 L
.912 .56822 L
.916 .56815 L
.92 .56808 L
.924 .568 L
.928 .56796 L
.932 .56794 L
.936 .56797 L
.94 .56797 L
.944 .56795 L
.948 .56787 L
.952 .56779 L
.956 .56769 L
.96 .56765 L
.964 .5676 L
.968 .5676 L
.972 .56755 L
.976 .5675 L
.98 .56742 L
.984 .56739 L
.988 .56734 L
.992 .56737 L
.996 .56733 L
1 .56732 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Ool0
00001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo100017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eo
o`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P000goo10001Goo00@007ooOomoo`D0
00=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol0
:7oo00@007ooOol000Eoo`8000=oo`8003Aoo`008Woo0P00:Goo00@007ooOol000=oo`D00004Ool0
00000002Ool20002Ool30002Ool200001Goo00000000Ool00P0000=oo`0000000`0000Ioo`00001o
o`00Ool400000goo0000000=Ool0029oof<000aoo`008Woo00H007ooOomoo`00Ool30003Ool01@00
Oomoogoo00000goo00D007ooOomoo`00009oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo
0P000goo0`0000=oo`00Ool00Woo00@007ooOomoo`800003Ool007oo009oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`0:
Ool0029oo`8000Moo`<000=oo`H001Aoo`8000Eoo`03001oogoo03aoo`008Woo00<007ooOol027oo
10001Woo0P004Woo00<007ooOol0@goo000ROol2000DOol2000@Ool00`00Oomoo`14Ool0029oo`80
01Eoo`8000ioo`8004Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0
5Goo00<007ooOol037oo00<007ooOol0AGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8001Ioo`8000aoo`03001oogoo04Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool2000GOol00`00Oomoo`0:Ool00`00Oomoo`16Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol05Woo00<007ooOol017oo0`000goo
00<007ooOol0AWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8001Qo
o`03001oogoo00=oo`03001oo`00009oo`03001oogoo04Moo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool20004Ool2000IOol01000Oomoogoo0P000Woo0`00BGoo000;Ool2000:Ool20004Ool0
0`00Oomoo`02Ool00`00Oomoo`0HOol01@00Oomoogoo000017oo00<007ooOol0B7oo000;Ool20004
Ool00`00Oomoo`03Ool20002Ool50002Ool2000IOol200000goo0000001?Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8001Yoo`<0051oo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000
Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00
KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo
00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo
0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol0
06ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eo
o`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uo
o`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1Y
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo
000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P00
2Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qo
o`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0
06Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00
2goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P00
17oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05
001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo
00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo
0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomo
o`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009o
o`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol0
0goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000X
Ool00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04
001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001o
ogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool2
0003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001o
ogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Io
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001X
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol097oo
0`00?goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0POol500000goo0000000b
000<Ool002Qoo`03001oogoo01ioo`<004Eoo`00:7oo00<007ooOol07Goo0P00Agoo000AOol20004
Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0JOol30019Ool0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol06Goo0P00Bgoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo01Moo`<004aoo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000FOol3001>Ool0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol04Woo1000D7oo000@Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`03001oogoo00eoo`H005=oo`004Goo0P002Woo0P0017oo00<007oo
Ool00Woo00<007ooOol027oo1@00FGoo000XOol<001MOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1V
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001X
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D0
06]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00
0goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079o
o`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04
001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<0
07ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@00
0goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo
00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomo
o`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03
001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool0
1000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo
00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool0
1000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo0000
0goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000;
Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:
Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2
001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Ioo`<000=o
o`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool:
001[Ool001Moo`03001oogoo009oo`8000Moo`D006Moo`005goo00<007ooOol00Woo00<007ooOol0
2goo1@00HWoo000FOol20004Ool2000@Ool5001NOol001Moo`03001oogoo009oo`03001oogoo01Ao
o`<005]oo`0077oo00<007ooOol05goo0`00F7oo000LOol2000JOol2001GOol001aoo`03001oogoo
01]oo`03001oogoo05Aoo`0077oo0P007Goo0P00E7oo000LOol00`00Oomoo`0MOol2001COol001ao
o`03001oogoo01ioo`<0055oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P008Goo0P00D7oo
000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol08Woo0P00CWoo000;Ool00`00
Oomoo`0;Ool01000Oomoo`009Goo0P00CGoo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02000UOol3
000UOolJ000<Ool000]oo`03001oogoo00Moo`@000=oo`03001oogoo02MoobH002Eoo`002Woo0P00
2Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001ao
o`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(35905\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .305 m
.008 .30475 L
.012 .30618 L
.016 .30694 L
.02 .30717 L
.024 .30806 L
.028 .30933 L
.032 .31039 L
.036 .31148 L
.04 .31287 L
.044 .3144 L
.048 .31592 L
.052 .31748 L
.056 .31914 L
.06 .32084 L
.064 .32253 L
.068 .32419 L
.072 .32581 L
.076 .32733 L
.08 .32873 L
.084 .32997 L
.088 .33101 L
.092 .33184 L
.096 .33241 L
.1 .33272 L
.104 .33277 L
.108 .33256 L
.112 .3321 L
.116 .33139 L
.12 .33047 L
.124 .32937 L
.128 .32817 L
.132 .32693 L
.136 .32571 L
.14 .32458 L
.144 .32359 L
.148 .3228 L
.152 .32228 L
.156 .32209 L
.16 .32227 L
.164 .32283 L
.168 .32378 L
.172 .32512 L
.176 .32683 L
.18 .32892 L
.184 .33137 L
.188 .33418 L
.192 .3373 L
.196 .34074 L
.2 .34451 L
Mistroke
.204 .34865 L
.208 .35324 L
.212 .35834 L
.216 .36398 L
.22 .37019 L
.224 .37698 L
.228 .38435 L
.232 .39228 L
.236 .40067 L
.24 .40937 L
.244 .41813 L
.248 .42664 L
.252 .43453 L
.256 .44144 L
.26 .44701 L
.264 .45092 L
.268 .45292 L
.272 .45281 L
.276 .45055 L
.28 .44629 L
.284 .44033 L
.288 .43312 L
.292 .42527 L
.296 .41744 L
.3 .41033 L
.304 .40458 L
.308 .40072 L
.312 .39909 L
.316 .39979 L
.32 .4026 L
.324 .40699 L
.328 .4122 L
.332 .41735 L
.336 .42153 L
.34 .4239 L
.344 .42378 L
.348 .42079 L
.352 .41491 L
.356 .40648 L
.36 .39615 L
.364 .38484 L
.368 .37358 L
.372 .36329 L
.376 .3546 L
.38 .34772 L
.384 .34244 L
.388 .33819 L
.392 .33413 L
.396 .32933 L
.4 .32296 L
Mistroke
.404 .31456 L
.408 .30421 L
.412 .29251 L
.416 .28056 L
.42 .26976 L
.424 .26164 L
.428 .25748 L
.432 .258 L
.436 .26313 L
.44 .27206 L
.444 .28342 L
.448 .29547 L
.452 .30643 L
.456 .3148 L
.46 .31969 L
.464 .32096 L
.468 .31913 L
.472 .31513 L
.476 .31004 L
.48 .30488 L
.484 .30037 L
.488 .29684 L
.492 .29415 L
.496 .29197 L
.5 .29005 L
.504 .28849 L
.508 .28764 L
.512 .28804 L
.516 .29012 L
.52 .29401 L
.524 .29933 L
.528 .30508 L
.532 .30981 L
.536 .31207 L
.54 .31095 L
.544 .30651 L
.548 .29979 L
.552 .29254 L
.556 .28672 L
.56 .28401 L
.564 .28527 L
.568 .29023 L
.572 .29744 L
.576 .30472 L
.58 .30989 L
.584 .31149 L
.588 .30924 L
.592 .30403 L
.596 .29758 L
.6 .2919 L
Mistroke
.604 .28869 L
.608 .28879 L
.612 .29182 L
.616 .2964 L
.62 .30072 L
.624 .30334 L
.628 .30372 L
.632 .30224 L
.636 .29983 L
.64 .29747 L
.644 .2959 L
.648 .2954 L
.652 .2959 L
.656 .29701 L
.66 .29826 L
.664 .29928 L
.668 .29998 L
.672 .30041 L
.676 .30057 L
.68 .3002 L
.684 .29898 L
.688 .29692 L
.692 .29471 L
.696 .29347 L
.7 .29406 L
.704 .29648 L
.708 .29974 L
.712 .30243 L
.716 .30338 L
.72 .30223 L
.724 .29946 L
.728 .29618 L
.732 .29376 L
.736 .29338 L
.74 .29539 L
.744 .29895 L
.748 .30215 L
.752 .30307 L
.756 .30104 L
.76 .29718 L
.764 .29385 L
.768 .29305 L
.772 .29509 L
.776 .29862 L
.78 .30152 L
.784 .30239 L
.788 .30117 L
.792 .29871 L
.796 .29629 L
.8 .29489 L
Mistroke
.804 .29503 L
.808 .29675 L
.812 .29925 L
.816 .30113 L
.82 .30112 L
.824 .29888 L
.828 .2958 L
.832 .29403 L
.836 .29497 L
.84 .2982 L
.844 .30141 L
.848 .30232 L
.852 .30041 L
.856 .29712 L
.86 .29489 L
.864 .29503 L
.868 .29686 L
.872 .29877 L
.876 .29942 L
.88 .29884 L
.884 .29818 L
.888 .29807 L
.892 .29837 L
.896 .29833 L
.9 .29754 L
.904 .29671 L
.908 .29677 L
.912 .29796 L
.916 .29946 L
.92 .2998 L
.924 .29849 L
.928 .29649 L
.932 .29543 L
.936 .29647 L
.94 .29883 L
.944 .30062 L
.948 .30043 L
.952 .29813 L
.956 .29564 L
.96 .29497 L
.964 .2964 L
.968 .29902 L
.972 .30061 L
.976 .29974 L
.98 .29769 L
.984 .2958 L
.988 .2956 L
.992 .29775 L
.996 .29973 L
1 .30018 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .55454 m
.008 .56208 L
.012 .56462 L
.016 .56197 L
.02 .56104 L
.024 .56172 L
.028 .56187 L
.032 .56135 L
.036 .56103 L
.04 .56082 L
.044 .56055 L
.048 .56013 L
.052 .55972 L
.056 .55926 L
.06 .55877 L
.064 .5582 L
.068 .55761 L
.072 .55695 L
.076 .55627 L
.08 .55553 L
.084 .55477 L
.088 .55396 L
.092 .55313 L
.096 .55226 L
.1 .5514 L
.104 .55051 L
.108 .54964 L
.112 .54876 L
.116 .54789 L
.12 .54704 L
.124 .54622 L
.128 .54542 L
.132 .54466 L
.136 .54392 L
.14 .54323 L
.144 .54255 L
.148 .5419 L
.152 .54127 L
.156 .54066 L
.16 .54004 L
.164 .53943 L
.168 .53879 L
.172 .53814 L
.176 .53745 L
.18 .53673 L
.184 .53596 L
.188 .53514 L
.192 .53427 L
.196 .53334 L
.2 .53235 L
Mistroke
.204 .5313 L
.208 .5302 L
.212 .52902 L
.216 .52778 L
.22 .52646 L
.224 .52505 L
.228 .52357 L
.232 .52198 L
.236 .52029 L
.24 .51848 L
.244 .51655 L
.248 .51449 L
.252 .5123 L
.256 .51 L
.26 .50759 L
.264 .5051 L
.268 .50255 L
.272 .49997 L
.276 .49739 L
.28 .49484 L
.284 .49235 L
.288 .48996 L
.292 .48767 L
.296 .48549 L
.3 .48343 L
.304 .48146 L
.308 .47956 L
.312 .4777 L
.316 .47584 L
.32 .47395 L
.324 .47201 L
.328 .46998 L
.332 .46789 L
.336 .46572 L
.34 .46352 L
.344 .46131 L
.348 .45914 L
.352 .45705 L
.356 .4551 L
.36 .45331 L
.364 .45171 L
.368 .45031 L
.372 .44909 L
.376 .44803 L
.38 .44711 L
.384 .44629 L
.388 .44555 L
.392 .44489 L
.396 .44432 L
.4 .44384 L
Mistroke
.404 .4435 L
.408 .44333 L
.412 .44335 L
.416 .44358 L
.42 .44402 L
.424 .44462 L
.428 .44534 L
.432 .4461 L
.436 .44683 L
.44 .44744 L
.444 .44788 L
.448 .44812 L
.452 .44815 L
.456 .44799 L
.46 .4477 L
.464 .44732 L
.468 .44693 L
.472 .44656 L
.476 .44628 L
.48 .44609 L
.484 .446 L
.488 .44601 L
.492 .4461 L
.496 .44626 L
.5 .44646 L
.504 .44669 L
.508 .44693 L
.512 .44715 L
.516 .44733 L
.52 .44745 L
.524 .44747 L
.528 .44742 L
.532 .44728 L
.536 .44711 L
.54 .44694 L
.544 .44681 L
.548 .44678 L
.552 .44686 L
.556 .44702 L
.56 .44725 L
.564 .44749 L
.568 .44768 L
.572 .44778 L
.576 .44777 L
.58 .44767 L
.584 .44751 L
.588 .44735 L
.592 .44723 L
.596 .44719 L
.6 .44724 L
Mistroke
.604 .44736 L
.608 .44752 L
.612 .44768 L
.616 .44781 L
.62 .44788 L
.624 .4479 L
.628 .44789 L
.632 .44786 L
.636 .44783 L
.64 .44783 L
.644 .44785 L
.648 .44789 L
.652 .44793 L
.656 .44798 L
.66 .44801 L
.664 .44803 L
.668 .44804 L
.672 .44805 L
.676 .44805 L
.68 .44806 L
.684 .44809 L
.688 .44814 L
.692 .44821 L
.696 .44829 L
.7 .44836 L
.704 .44841 L
.708 .44843 L
.712 .44843 L
.716 .4484 L
.72 .44838 L
.724 .44838 L
.728 .44842 L
.732 .44847 L
.736 .44854 L
.74 .4486 L
.744 .44862 L
.748 .44862 L
.752 .4486 L
.756 .4486 L
.76 .44864 L
.764 .44872 L
.768 .44881 L
.772 .44889 L
.776 .44894 L
.78 .44894 L
.784 .44891 L
.788 .44887 L
.792 .44885 L
.796 .44887 L
.8 .44892 L
Mistroke
.804 .449 L
.808 .44907 L
.812 .44912 L
.816 .44915 L
.82 .44915 L
.824 .44916 L
.828 .44918 L
.832 .44923 L
.836 .44928 L
.84 .44932 L
.844 .44933 L
.848 .44933 L
.852 .44933 L
.856 .44935 L
.86 .44938 L
.864 .44943 L
.868 .44948 L
.872 .44952 L
.876 .44956 L
.88 .44959 L
.884 .44961 L
.888 .44964 L
.892 .44965 L
.896 .44967 L
.9 .44968 L
.904 .44971 L
.908 .44975 L
.912 .44979 L
.916 .44982 L
.92 .44985 L
.924 .44988 L
.928 .44992 L
.932 .44996 L
.936 .44999 L
.94 .45 L
.944 .45001 L
.948 .45 L
.952 .45004 L
.956 .45008 L
.96 .45015 L
.964 .4502 L
.968 .45024 L
.972 .45023 L
.976 .45024 L
.98 .45024 L
.984 .45029 L
.988 .45033 L
.992 .45039 L
.996 .45039 L
1 .45042 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43028 L
.012 .43058 L
.016 .43063 L
.02 .43058 L
.024 .43098 L
.028 .43134 L
.032 .43161 L
.036 .43185 L
.04 .43227 L
.044 .43268 L
.048 .43315 L
.052 .43362 L
.056 .43421 L
.06 .43481 L
.064 .4355 L
.068 .43621 L
.072 .43701 L
.076 .43783 L
.08 .43873 L
.084 .43965 L
.088 .44064 L
.092 .44164 L
.096 .44269 L
.1 .44374 L
.104 .44482 L
.108 .44589 L
.112 .44696 L
.116 .448 L
.12 .44903 L
.124 .45003 L
.128 .451 L
.132 .45192 L
.136 .45281 L
.14 .45366 L
.144 .45447 L
.148 .45525 L
.152 .456 L
.156 .45674 L
.16 .45748 L
.164 .45822 L
.168 .45899 L
.172 .45978 L
.176 .46061 L
.18 .46148 L
.184 .46242 L
.188 .46341 L
.192 .46447 L
.196 .4656 L
.2 .46681 L
Mistroke
.204 .46809 L
.208 .46945 L
.212 .47089 L
.216 .47242 L
.22 .47403 L
.224 .47575 L
.228 .47758 L
.232 .47953 L
.236 .48162 L
.24 .48386 L
.244 .48624 L
.248 .48879 L
.252 .49148 L
.256 .49433 L
.26 .49731 L
.264 .50039 L
.268 .50356 L
.272 .50676 L
.276 .50996 L
.28 .51312 L
.284 .51619 L
.288 .51916 L
.292 .522 L
.296 .52469 L
.3 .52725 L
.304 .52969 L
.308 .53205 L
.312 .53436 L
.316 .53666 L
.32 .539 L
.324 .54141 L
.328 .54391 L
.332 .54651 L
.336 .54919 L
.34 .55194 L
.344 .55468 L
.348 .55738 L
.352 .55997 L
.356 .56239 L
.36 .56461 L
.364 .56659 L
.368 .56833 L
.372 .56985 L
.376 .57116 L
.38 .57231 L
.384 .57332 L
.388 .57423 L
.392 .57504 L
.396 .57575 L
.4 .57634 L
Mistroke
.404 .57676 L
.408 .57697 L
.412 .57693 L
.416 .57664 L
.42 .57609 L
.424 .57534 L
.428 .57443 L
.432 .57347 L
.436 .57256 L
.44 .57179 L
.444 .57123 L
.448 .57093 L
.452 .57088 L
.456 .57107 L
.46 .57144 L
.464 .5719 L
.468 .57238 L
.472 .57282 L
.476 .57317 L
.48 .5734 L
.484 .5735 L
.488 .57349 L
.492 .57337 L
.496 .57317 L
.5 .57291 L
.504 .57261 L
.508 .5723 L
.512 .57202 L
.516 .57178 L
.52 .57163 L
.524 .57159 L
.528 .57166 L
.532 .57182 L
.536 .57203 L
.54 .57224 L
.544 .57238 L
.548 .57242 L
.552 .57232 L
.556 .5721 L
.56 .5718 L
.564 .57149 L
.568 .57125 L
.572 .57112 L
.576 .57113 L
.58 .57125 L
.584 .57145 L
.588 .57164 L
.592 .57178 L
.596 .57181 L
.6 .57174 L
Mistroke
.604 .57157 L
.608 .57137 L
.612 .57117 L
.616 .57102 L
.62 .57093 L
.624 .57089 L
.628 .5709 L
.632 .57092 L
.636 .57093 L
.64 .57092 L
.644 .57089 L
.648 .57084 L
.652 .57079 L
.656 .57074 L
.66 .57069 L
.664 .57066 L
.668 .57064 L
.672 .57062 L
.676 .57059 L
.68 .57056 L
.684 .57051 L
.688 .57044 L
.692 .57036 L
.696 .57027 L
.7 .57018 L
.704 .57012 L
.708 .57008 L
.712 .57007 L
.716 .57008 L
.72 .57008 L
.724 .57006 L
.728 .57 L
.732 .56993 L
.736 .56986 L
.74 .56981 L
.744 .56979 L
.748 .5698 L
.752 .56979 L
.756 .56976 L
.76 .56968 L
.764 .56956 L
.768 .56943 L
.772 .56932 L
.776 .56927 L
.78 .56929 L
.784 .56935 L
.788 .56942 L
.792 .56944 L
.796 .56938 L
.8 .56926 L
Mistroke
.804 .56913 L
.808 .56902 L
.812 .56895 L
.816 .56893 L
.82 .56894 L
.824 .56894 L
.828 .56892 L
.832 .56887 L
.836 .56881 L
.84 .56874 L
.844 .56868 L
.848 .56864 L
.852 .56861 L
.856 .56858 L
.86 .56855 L
.864 .5685 L
.868 .56844 L
.872 .56839 L
.876 .56835 L
.88 .56834 L
.884 .56831 L
.888 .56827 L
.892 .56819 L
.896 .5681 L
.9 .56802 L
.904 .56798 L
.908 .56797 L
.912 .56798 L
.916 .56798 L
.92 .56795 L
.924 .56789 L
.928 .56783 L
.932 .56775 L
.936 .5677 L
.94 .56763 L
.944 .56758 L
.948 .56751 L
.952 .56749 L
.956 .56746 L
.96 .56746 L
.964 .56743 L
.968 .56742 L
.972 .56734 L
.976 .5673 L
.98 .56722 L
.984 .56718 L
.988 .56712 L
.992 .56711 L
.996 .56702 L
1 .567 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`05001oogoo001oo`020002Ool0
0`00Oomoo`03Ool01000Oomoogoo10000goo00@007ooOol0009oo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000=oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo
0P002Woo0P0017oo00<007ooOol00Woo0P0037oo00<007ooOol017oo00@007ooOol000Ioo`8000Ao
o`03001oogoo00@0009oo`03001oogoo009oo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Io
o`04001oogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`800003Ool007oo
00<000Ioo`04001oogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool2
0006Ool0029oo`03001oogoo02Ioo`03001oo`0000Eoo`8000=oo`8003Moo`008Woo0P009Woo00D0
07ooOomoo`0000=oo`@0009oo`<00005Ool00000001oo`030002Ool3000017oo000007oo1P0000Ao
o`00001oo`P00004Ool00000Ool2000=Ool0029oof<000aoo`008Woo00<007ooOol0100000=oo`00
Ool00Woo00D007ooOomoo`0000=oo`05001oogooOol00002Ool01@00Oomoogoo00000goo00@007oo
Oomoo`80009oo`03001oo`00008000=oo`<00006Ool007oo001oo`000Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
000<Ool0029oo`8000Aoo`<000=oo`L001Aoo`03001oogoo00=oo`03001oogoo03moo`008Woo00<0
07ooOol01Goo1@001Goo0P004Woo00<007ooOol0AWoo000ROol2000AOol2000@Ool20018Ool0029o
o`80019oo`8000moo`03001oogoo04Moo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo
00<007ooOol04Woo0P003Goo00<007ooOol0B7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8001Aoo`03001oogoo00]oo`03001oogoo04Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2000DOol00`00Oomoo`0;Ool00`00Oomoo`18Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol057oo00<007ooOol0
17oo0P000goo00<007ooOol0BGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8001Ioo`03001oogoo009oo`@0009oo`03001oogoo04Uoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool20004Ool2000FOol00`00Oomoo`02Ool00`00Oomoo`03001<Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`03001oogoo01Eoo`03001oogoo009oo`04001oogooOol2001<Ool0
00]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8001Moo`04001oogoo001BOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8001Moo`<005=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0GOol2001COol000Yoo`04001o
ogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001o
ogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06ao
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
1Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]
Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003
Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=o
o`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05
Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<0
07ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool0
0`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo
00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo
06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo
00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo
00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P00
0Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@0
07ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`00
00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00
Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo
00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool5
0002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D0
07ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`00
0Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000
Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@0
07ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005
Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001o
ogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo00moo`03001o
ogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=o
o`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=o
o`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04
001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo
00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo
00<007ooOol08Goo1000@Goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0NOol4
0002Oolf000<Ool002Qoo`03001oogoo01aoo`8004Qoo`00:7oo00<007ooOol06Woo0P00BWoo000A
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0HOol3001;Ool0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol05Woo0P00CWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo01Eoo`8004moo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000DOol2001AOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol047oo0`00Dgoo000@Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00Yoo`H005Ioo`004Goo0P002Woo0P0017oo
00<007ooOol00Woo00<007ooOol01Goo1P00Fgoo000XOol9001POol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00
Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001o
ogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0
0P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007oo
Oomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol0
0Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol0
00]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`00
77oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P00
1Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo
00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D0
07ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool0
01aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Ao
o`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool4
0003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo
0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool0
0006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool2
0006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P00
1Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomo
ogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2
001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00
Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@00
0Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Io
o`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomo
o`02Ool7001^Ool001Moo`03001oogoo009oo`03001oogoo00=oo`H006Uoo`005goo00<007ooOol0
0Woo00<007ooOol027oo1@00IGoo000FOol20004Ool2000=Ool5001QOol001Moo`03001oogoo009o
o`03001oogoo015oo`@005eoo`0077oo00<007ooOol057oo0`00Fgoo000LOol2000GOol2001JOol0
01aoo`03001oogoo01Qoo`8005Qoo`0077oo0P006Woo0P00Egoo000LOol00`00Oomoo`0JOol2001F
Ool001aoo`03001oogoo01]oo`<005Aoo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P007Woo
0P00Dgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol07goo0P00DGoo000;
Ool00`00Oomoo`0;Ool01000Oomoo`008Woo0`00Cgoo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02
000SOol3000UOolL000<Ool000]oo`03001oogoo00Moo`@000=oo`03001oogoo02AoobH002Qoo`00
2Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001c
Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(36072\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31126 m
.008 .31379 L
.012 .31651 L
.016 .31782 L
.02 .31767 L
.024 .31862 L
.028 .32073 L
.032 .32243 L
.036 .32364 L
.04 .32507 L
.044 .32675 L
.048 .32827 L
.052 .32958 L
.056 .33078 L
.06 .33185 L
.064 .3327 L
.068 .33332 L
.072 .33369 L
.076 .33382 L
.08 .33368 L
.084 .33326 L
.088 .33258 L
.092 .33168 L
.096 .3306 L
.1 .3294 L
.104 .32815 L
.108 .3269 L
.112 .32571 L
.116 .32464 L
.12 .32374 L
.124 .3231 L
.128 .32278 L
.132 .32284 L
.136 .3233 L
.14 .32417 L
.144 .32542 L
.148 .32704 L
.152 .32904 L
.156 .33142 L
.16 .33416 L
.164 .33726 L
.168 .34069 L
.172 .34446 L
.176 .34858 L
.18 .35311 L
.184 .3581 L
.188 .3636 L
.192 .36966 L
.196 .37631 L
.2 .38357 L
Mistroke
.204 .3914 L
.208 .39973 L
.212 .4084 L
.216 .41718 L
.22 .4258 L
.224 .43394 L
.228 .44125 L
.232 .44739 L
.236 .45199 L
.24 .45473 L
.244 .45539 L
.248 .45388 L
.252 .45027 L
.256 .44483 L
.26 .43798 L
.264 .43026 L
.268 .42231 L
.272 .41478 L
.276 .40837 L
.28 .40365 L
.284 .40107 L
.288 .40082 L
.292 .40277 L
.296 .40655 L
.3 .4115 L
.304 .4168 L
.308 .42153 L
.312 .42476 L
.316 .42574 L
.32 .42393 L
.324 .41914 L
.328 .41153 L
.332 .4017 L
.336 .3905 L
.34 .37891 L
.344 .36788 L
.348 .35814 L
.352 .35011 L
.356 .34386 L
.36 .33899 L
.364 .3348 L
.368 .3304 L
.372 .3249 L
.376 .31762 L
.38 .30829 L
.384 .29721 L
.388 .2853 L
.392 .27388 L
.396 .26447 L
.4 .25845 L
Mistroke
.404 .25678 L
.408 .25983 L
.412 .26723 L
.416 .27786 L
.42 .29007 L
.424 .30204 L
.428 .31209 L
.432 .31897 L
.436 .32207 L
.44 .3215 L
.444 .31805 L
.448 .3129 L
.452 .30726 L
.456 .30205 L
.46 .29777 L
.464 .29456 L
.468 .29223 L
.472 .29048 L
.476 .28909 L
.48 .28817 L
.484 .28812 L
.488 .28944 L
.492 .29241 L
.496 .29688 L
.5 .30219 L
.504 .30728 L
.508 .31085 L
.512 .31176 L
.516 .30939 L
.52 .30403 L
.524 .29694 L
.528 .29001 L
.532 .2852 L
.536 .28395 L
.54 .28671 L
.544 .29281 L
.548 .3005 L
.552 .30747 L
.556 .31156 L
.56 .31161 L
.564 .30779 L
.568 .30155 L
.572 .29498 L
.576 .29009 L
.58 .28819 L
.584 .28954 L
.588 .29333 L
.592 .29803 L
.596 .30196 L
.6 .30396 L
Mistroke
.604 .30374 L
.608 .30187 L
.612 .29932 L
.616 .29704 L
.62 .29562 L
.624 .29528 L
.628 .29592 L
.632 .29722 L
.636 .29875 L
.64 .30004 L
.644 .30078 L
.648 .30086 L
.652 .30033 L
.656 .29924 L
.66 .29772 L
.664 .29602 L
.668 .29469 L
.672 .29438 L
.676 .29547 L
.68 .29777 L
.684 .30039 L
.688 .30226 L
.692 .30259 L
.696 .30126 L
.7 .29882 L
.704 .29623 L
.708 .29452 L
.712 .29445 L
.716 .29616 L
.72 .29894 L
.724 .30137 L
.728 .30205 L
.732 .30048 L
.736 .29746 L
.74 .29479 L
.744 .29405 L
.748 .2956 L
.752 .29849 L
.756 .30106 L
.76 .30205 L
.764 .30117 L
.768 .29901 L
.772 .29663 L
.776 .29506 L
.78 .29499 L
.784 .29656 L
.788 .29899 L
.792 .30092 L
.796 .3011 L
.8 .29925 L
Mistroke
.804 .29659 L
.808 .29497 L
.812 .29554 L
.816 .29791 L
.82 .30028 L
.824 .301 L
.828 .29983 L
.832 .29784 L
.836 .29655 L
.84 .29659 L
.844 .29735 L
.848 .29797 L
.852 .29805 L
.856 .29796 L
.86 .29828 L
.864 .29884 L
.868 .29905 L
.872 .29849 L
.876 .29746 L
.88 .29693 L
.884 .29745 L
.888 .29855 L
.892 .29918 L
.896 .29856 L
.9 .29718 L
.904 .29636 L
.908 .29696 L
.912 .29869 L
.916 .30006 L
.92 .29977 L
.924 .29801 L
.928 .29611 L
.932 .29574 L
.936 .29724 L
.94 .29924 L
.944 .3002 L
.948 .29926 L
.952 .29715 L
.956 .29591 L
.96 .29631 L
.964 .29802 L
.968 .29985 L
.972 .2999 L
.976 .29842 L
.98 .29685 L
.984 .2959 L
.988 .29672 L
.992 .29855 L
.996 .29926 L
1 .29907 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .55865 m
.008 .5594 L
.012 .55973 L
.016 .5595 L
.02 .5591 L
.024 .55872 L
.028 .5585 L
.032 .55812 L
.036 .55764 L
.04 .55706 L
.044 .55652 L
.048 .55588 L
.052 .5552 L
.056 .55445 L
.06 .5537 L
.064 .55289 L
.068 .55207 L
.072 .5512 L
.076 .55034 L
.08 .54946 L
.084 .5486 L
.088 .54772 L
.092 .54688 L
.096 .54605 L
.1 .54525 L
.104 .54448 L
.108 .54374 L
.112 .54302 L
.116 .54235 L
.12 .54169 L
.124 .54106 L
.128 .54044 L
.132 .53983 L
.136 .53921 L
.14 .53859 L
.144 .53794 L
.148 .53726 L
.152 .53655 L
.156 .5358 L
.16 .535 L
.164 .53414 L
.168 .53323 L
.172 .53226 L
.176 .53123 L
.18 .53014 L
.184 .52898 L
.188 .52775 L
.192 .52645 L
.196 .52508 L
.2 .52362 L
Mistroke
.204 .52206 L
.208 .5204 L
.212 .51863 L
.216 .51673 L
.22 .51471 L
.224 .51257 L
.228 .51032 L
.232 .50795 L
.236 .50549 L
.24 .50296 L
.244 .50039 L
.248 .4978 L
.252 .49524 L
.256 .49274 L
.26 .49031 L
.264 .48799 L
.268 .48577 L
.272 .48367 L
.276 .48166 L
.28 .47973 L
.284 .47786 L
.288 .47601 L
.292 .47414 L
.296 .47223 L
.3 .47025 L
.304 .46819 L
.308 .46606 L
.312 .46388 L
.316 .46168 L
.32 .4595 L
.324 .45738 L
.328 .45538 L
.332 .45354 L
.336 .45187 L
.34 .4504 L
.344 .44912 L
.348 .44801 L
.352 .44705 L
.356 .44621 L
.36 .44547 L
.364 .44481 L
.368 .44423 L
.372 .44374 L
.376 .44336 L
.38 .44313 L
.384 .44308 L
.388 .44322 L
.392 .44358 L
.396 .44411 L
.4 .44479 L
Mistroke
.404 .44553 L
.408 .44628 L
.412 .44695 L
.416 .44747 L
.42 .44779 L
.424 .44791 L
.428 .44783 L
.432 .44758 L
.436 .44722 L
.44 .44682 L
.444 .44643 L
.448 .44611 L
.452 .44587 L
.456 .44574 L
.46 .44571 L
.464 .44578 L
.468 .44591 L
.472 .44611 L
.476 .44633 L
.48 .44657 L
.484 .4468 L
.488 .44699 L
.492 .44713 L
.496 .4472 L
.5 .44718 L
.504 .44709 L
.508 .44693 L
.512 .44676 L
.516 .44661 L
.52 .44653 L
.524 .44655 L
.528 .44666 L
.532 .44686 L
.536 .44709 L
.54 .44732 L
.544 .44747 L
.548 .44753 L
.552 .44748 L
.556 .44734 L
.56 .44718 L
.564 .44702 L
.568 .44694 L
.572 .44693 L
.576 .44702 L
.58 .44716 L
.584 .44733 L
.588 .44748 L
.592 .44759 L
.596 .44764 L
.6 .44764 L
Mistroke
.604 .44762 L
.608 .44759 L
.612 .44757 L
.616 .44758 L
.62 .4476 L
.624 .44763 L
.628 .44768 L
.632 .44771 L
.636 .44775 L
.64 .44777 L
.644 .44778 L
.648 .44779 L
.652 .4478 L
.656 .44782 L
.66 .44786 L
.664 .44791 L
.668 .44797 L
.672 .44804 L
.676 .44811 L
.68 .44815 L
.684 .44817 L
.688 .44816 L
.692 .44814 L
.696 .44813 L
.7 .44814 L
.704 .44818 L
.708 .44823 L
.712 .44828 L
.716 .44833 L
.72 .44835 L
.724 .44835 L
.728 .44835 L
.732 .44837 L
.736 .44842 L
.74 .4485 L
.744 .44858 L
.748 .44865 L
.752 .44867 L
.756 .44865 L
.76 .44862 L
.764 .44858 L
.768 .44858 L
.772 .44862 L
.776 .44869 L
.78 .44878 L
.784 .44885 L
.788 .44889 L
.792 .44889 L
.796 .44888 L
.8 .44888 L
Mistroke
.804 .44891 L
.808 .44896 L
.812 .44902 L
.816 .44907 L
.82 .44909 L
.824 .44909 L
.828 .44909 L
.832 .4491 L
.836 .44913 L
.84 .44917 L
.844 .44922 L
.848 .44927 L
.852 .4493 L
.856 .44934 L
.86 .44936 L
.864 .44938 L
.868 .4494 L
.872 .44943 L
.876 .44945 L
.88 .44948 L
.884 .4495 L
.888 .44952 L
.892 .44953 L
.896 .44957 L
.9 .44961 L
.904 .44968 L
.908 .44973 L
.912 .44976 L
.916 .44976 L
.92 .44976 L
.924 .44975 L
.928 .44978 L
.932 .44982 L
.936 .44988 L
.94 .44992 L
.944 .44996 L
.948 .44998 L
.952 .45001 L
.956 .45003 L
.96 .45007 L
.964 .45008 L
.968 .4501 L
.972 .45009 L
.976 .45014 L
.98 .45016 L
.984 .45024 L
.988 .45027 L
.992 .45033 L
.996 .45032 L
1 .45035 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .42513 L
.012 .43111 L
.016 .43356 L
.02 .43229 L
.024 .43235 L
.028 .4336 L
.032 .43455 L
.036 .43506 L
.04 .4358 L
.044 .43667 L
.048 .4376 L
.052 .43846 L
.056 .43943 L
.06 .44041 L
.064 .44146 L
.068 .44249 L
.072 .44358 L
.076 .44464 L
.08 .44574 L
.084 .4468 L
.088 .44787 L
.092 .4489 L
.096 .44993 L
.1 .4509 L
.104 .45185 L
.108 .45274 L
.112 .45361 L
.116 .45442 L
.12 .45522 L
.124 .45598 L
.128 .45673 L
.132 .45747 L
.136 .45821 L
.14 .45896 L
.144 .45974 L
.148 .46055 L
.152 .46142 L
.156 .46233 L
.16 .46331 L
.164 .46435 L
.168 .46546 L
.172 .46664 L
.176 .4679 L
.18 .46923 L
.184 .47065 L
.188 .47215 L
.192 .47375 L
.196 .47544 L
.2 .47724 L
Mistroke
.204 .47916 L
.208 .4812 L
.212 .48339 L
.216 .48572 L
.22 .48821 L
.224 .49086 L
.228 .49365 L
.232 .49659 L
.236 .49963 L
.24 .50277 L
.244 .50595 L
.248 .50914 L
.252 .51231 L
.256 .51542 L
.26 .51843 L
.264 .52132 L
.268 .52407 L
.272 .52668 L
.276 .52916 L
.28 .53154 L
.284 .53386 L
.288 .53615 L
.292 .53847 L
.296 .54084 L
.3 .5433 L
.304 .54585 L
.308 .54849 L
.312 .5512 L
.316 .55393 L
.32 .55664 L
.324 .55926 L
.328 .56174 L
.332 .56404 L
.336 .56611 L
.34 .56794 L
.344 .56953 L
.348 .5709 L
.352 .57208 L
.356 .57312 L
.36 .57404 L
.364 .57486 L
.368 .57558 L
.372 .57619 L
.376 .57665 L
.38 .57693 L
.384 .57699 L
.388 .57679 L
.392 .57635 L
.396 .57568 L
.4 .57484 L
Mistroke
.404 .5739 L
.408 .57296 L
.412 .57212 L
.416 .57147 L
.42 .57105 L
.424 .57089 L
.428 .57099 L
.432 .57129 L
.436 .57172 L
.44 .57222 L
.444 .5727 L
.448 .5731 L
.452 .57339 L
.456 .57354 L
.46 .57357 L
.464 .57348 L
.468 .5733 L
.472 .57305 L
.476 .57277 L
.48 .57247 L
.484 .57218 L
.488 .57193 L
.492 .57174 L
.496 .57165 L
.5 .57166 L
.504 .57177 L
.508 .57195 L
.512 .57216 L
.516 .57234 L
.52 .57244 L
.524 .57242 L
.528 .57227 L
.532 .57201 L
.536 .57171 L
.54 .57142 L
.544 .57122 L
.548 .57115 L
.552 .5712 L
.556 .57136 L
.56 .57156 L
.564 .57175 L
.568 .57185 L
.572 .57185 L
.576 .57173 L
.58 .57154 L
.584 .57132 L
.588 .57112 L
.592 .57098 L
.596 .57092 L
.6 .57091 L
Mistroke
.604 .57094 L
.608 .57097 L
.612 .57099 L
.616 .57097 L
.62 .57092 L
.624 .57086 L
.628 .5708 L
.632 .57075 L
.636 .57071 L
.64 .57068 L
.644 .57067 L
.648 .57065 L
.652 .57062 L
.656 .57058 L
.66 .57052 L
.664 .57044 L
.668 .57035 L
.672 .57026 L
.676 .57018 L
.68 .57013 L
.684 .57011 L
.688 .57011 L
.692 .57013 L
.696 .57013 L
.7 .5701 L
.704 .57003 L
.708 .56995 L
.712 .56987 L
.716 .56982 L
.72 .5698 L
.724 .5698 L
.728 .5698 L
.732 .56977 L
.736 .5697 L
.74 .56958 L
.744 .56946 L
.748 .56935 L
.752 .5693 L
.756 .56932 L
.76 .56938 L
.764 .56944 L
.768 .56945 L
.772 .5694 L
.776 .5693 L
.78 .56916 L
.784 .56905 L
.788 .56897 L
.792 .56894 L
.796 .56894 L
.8 .56894 L
Mistroke
.804 .56893 L
.808 .56889 L
.812 .56884 L
.816 .56878 L
.82 .56872 L
.824 .56867 L
.828 .56864 L
.832 .56861 L
.836 .56856 L
.84 .56851 L
.844 .56845 L
.848 .5684 L
.852 .56837 L
.856 .56835 L
.86 .56833 L
.864 .56828 L
.868 .56821 L
.872 .56814 L
.876 .56807 L
.88 .56803 L
.884 .56801 L
.888 .56799 L
.892 .56796 L
.896 .56793 L
.9 .56789 L
.904 .56785 L
.908 .5678 L
.912 .56774 L
.916 .56767 L
.92 .56761 L
.924 .56755 L
.928 .56751 L
.932 .56748 L
.936 .56747 L
.94 .56743 L
.944 .56741 L
.948 .56737 L
.952 .56734 L
.956 .56729 L
.96 .56724 L
.964 .56715 L
.968 .56708 L
.972 .56699 L
.976 .56698 L
.98 .56695 L
.984 .56697 L
.988 .56693 L
.992 .56691 L
.996 .56682 L
1 .56679 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Ool000000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`800004Ool007ooOol20006
Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo
000ROol00`00Oomoo`0SOol01000Oomoo`001Goo00<007ooOol00Woo0P000goo00<007ooOol0<goo
000ROol2000TOol01000Oomoo`000goo10000Woo0`000Woo0`0000Eoo`00000007oo00<0009oo`80
0004Ool00000OolA00000goo00000003000=Ool0029oof<000aoo`008Woo0`0000=oo`00Ool00Woo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoo`000goo00T007ooOomoo`00Ool0
07oo00000Woo0`000Woo00<007ooOol00P000Woo0P000goo00@007ooOol000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomo
o`0:Ool0029oo`800004Ool000000004Ool6000DOol00`00Oomoo`04Ool00`00Oomoo`11Ool0029o
o`03001oogoo009oo`H000Aoo`80019oo`8004Yoo`008Woo0P003goo00<007ooOol03goo00<007oo
Ool0BGoo000ROol2000@Ool00`00Oomoo`0=Ool00`00Oomoo`1:Ool000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`03001oogoo00moo`8000ioo`03001oogoo04Yoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000AOol00`00Oomoo`0;Ool00`00Oomoo`1;Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P004Woo00<007ooOol02Woo
00<007ooOol0Bgoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo015oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo04]oo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2000COol00`00Oomoo`03Ool00`00Ool00002Ool00`00
Oomoo`1<Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P004goo00<007ooOol0
0goo00H007ooOol007oo001>Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo01=o
o`05001oogooOol00004Ool00`00Oomoo`1=Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0
009oo`8001Aoo`04001oogoo001EOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool0009oo`8001Eoo`03001oo`0005Eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`0EOol00`00Oomoo`1DOol000Yoo`04001oogoo0008Ool01000Oomoo`00
17oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007oo
Ool00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;
Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
0`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo
00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo
1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2
000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P00
17oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo
1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`00
17oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P00
0goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo
001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo
00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool0
1@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool0
1000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001o
ogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000X
Ool00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00
Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo
0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomo
o`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uo
o`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool3
0004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00mo
o`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol07goo0`00A7oo
000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0KOol40003Oolh000<Ool002Qoo`03
001oogoo01Uoo`<004Yoo`00:7oo00<007ooOol05goo0`00C7oo000AOol20004Ool00`00Oomoo`03
Ool20003Ool30003Ool00`00Oomoo`0EOol3001>Ool0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol057oo0P00D7oo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo019oo`80059oo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool2000AOol3001COol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol03Goo1000EGoo000@Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`03001oogoo00Moo`L005Qoo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007oo
Ool00goo1@00GWoo000XOol6001SOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo
00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol0
00Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomo
o`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol03Goo0`00
17oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P00
1Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04
001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03
001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00
Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009o
o`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo
000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@00
0goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1b
Ool001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol0
0Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol0
0Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001o
ogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000;Ool20004Ool00`00
Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`00
2goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Ioo`<000=oo`03001oogoo079o
o`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool4001aOol001Moo`03
001oogoo009oo`04001oogooOol5001/Ool001Moo`03001oogoo009oo`03001oogoo00Eoo`D006Qo
o`005Woo0P0017oo0P002Woo1P00Hgoo000GOol00`00Oomoo`02Ool00`00Oomoo`0>Ool4001POol0
01aoo`03001oogoo015oo`<005ioo`0077oo0P0057oo0P00GGoo000LOol00`00Oomoo`0EOol2001K
Ool001aoo`8001Moo`8005Yoo`0077oo00<007ooOol05goo0`00F7oo000LOol00`00Oomoo`0IOol2
001GOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8001]oo`8005Ioo`002goo00<007ooOol0
1goo00D007ooOomoo`00009oo`03001oogoo01aoo`8005Aoo`002goo00<007ooOol02goo00@007oo
Ool001moo`<0059oo`002goo00<007ooOol02goo00<007ooOol00P0087oo0`009Goo7`0037oo000;
Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`0QOolW000ZOol000Yoo`8000Uoo`03001oogoo00Ao
o`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(36239\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32903 m
.008 .33093 L
.012 .33132 L
.016 .3322 L
.02 .33342 L
.024 .33422 L
.028 .33488 L
.032 .33564 L
.036 .33625 L
.04 .33652 L
.044 .33659 L
.048 .33651 L
.052 .3362 L
.056 .3356 L
.06 .33479 L
.064 .33378 L
.068 .3326 L
.072 .33128 L
.076 .32989 L
.08 .3285 L
.084 .32717 L
.088 .32596 L
.092 .32494 L
.096 .32417 L
.1 .32371 L
.104 .32361 L
.108 .32391 L
.112 .32461 L
.116 .32573 L
.12 .32726 L
.124 .3292 L
.128 .33152 L
.132 .33422 L
.136 .33727 L
.14 .34066 L
.144 .34437 L
.148 .34845 L
.152 .35292 L
.156 .35784 L
.16 .36326 L
.164 .36922 L
.168 .37574 L
.172 .38285 L
.176 .39054 L
.18 .39875 L
.184 .40735 L
.188 .41615 L
.192 .4249 L
.196 .4333 L
.2 .44099 L
Mistroke
.204 .44761 L
.208 .4528 L
.212 .45621 L
.216 .45761 L
.22 .45686 L
.224 .454 L
.228 .44921 L
.232 .44283 L
.236 .43533 L
.24 .42729 L
.244 .41941 L
.248 .41239 L
.252 .40689 L
.256 .4034 L
.26 .40221 L
.264 .40331 L
.268 .4064 L
.272 .41093 L
.276 .41616 L
.28 .4212 L
.284 .42514 L
.288 .42714 L
.292 .42651 L
.296 .42291 L
.3 .41635 L
.304 .40724 L
.308 .39633 L
.312 .38452 L
.316 .37283 L
.32 .36212 L
.324 .353 L
.328 .34572 L
.332 .34009 L
.336 .33559 L
.34 .33135 L
.344 .32644 L
.348 .32002 L
.352 .31166 L
.356 .30145 L
.36 .29 L
.364 .2784 L
.368 .26804 L
.372 .26039 L
.376 .25665 L
.38 .25752 L
.384 .263 L
.388 .27239 L
.392 .28431 L
.396 .29697 L
.4 .30847 L
Mistroke
.404 .31721 L
.408 .32223 L
.412 .32333 L
.416 .32099 L
.42 .31619 L
.424 .31021 L
.428 .30421 L
.432 .29907 L
.436 .29515 L
.44 .29241 L
.444 .29058 L
.448 .28938 L
.452 .28867 L
.456 .28853 L
.46 .28927 L
.464 .29128 L
.468 .29477 L
.472 .2995 L
.476 .30467 L
.48 .30908 L
.484 .3115 L
.488 .31102 L
.492 .30737 L
.496 .30119 L
.5 .29396 L
.504 .28768 L
.508 .28421 L
.512 .28466 L
.516 .28898 L
.52 .29594 L
.524 .30355 L
.528 .30959 L
.532 .31229 L
.536 .31091 L
.54 .30601 L
.544 .29927 L
.548 .29288 L
.552 .28874 L
.556 .28787 L
.56 .29018 L
.564 .29463 L
.568 .29959 L
.572 .30341 L
.576 .30497 L
.58 .30408 L
.584 .30145 L
.588 .29833 L
.592 .2959 L
.596 .29484 L
.6 .2952 L
Mistroke
.604 .29656 L
.608 .29829 L
.612 .29979 L
.616 .30067 L
.62 .30083 L
.624 .30038 L
.628 .29955 L
.632 .2985 L
.636 .29728 L
.64 .29603 L
.644 .29508 L
.648 .29494 L
.652 .29602 L
.656 .29822 L
.66 .3008 L
.664 .30264 L
.668 .30283 L
.672 .30116 L
.676 .29831 L
.68 .29548 L
.684 .29394 L
.688 .29442 L
.692 .29677 L
.696 .29989 L
.7 .30219 L
.704 .30236 L
.708 .30016 L
.712 .29672 L
.716 .29401 L
.72 .29363 L
.724 .29585 L
.728 .29942 L
.732 .30234 L
.736 .30307 L
.74 .30138 L
.744 .29825 L
.748 .29531 L
.752 .29396 L
.756 .29479 L
.76 .29734 L
.764 .30026 L
.768 .30192 L
.772 .30134 L
.776 .29879 L
.78 .29588 L
.784 .29453 L
.788 .29562 L
.792 .2984 L
.796 .3009 L
.8 .30149 L
Mistroke
.804 .3 L
.808 .29762 L
.812 .29599 L
.816 .29592 L
.82 .297 L
.824 .29833 L
.828 .29918 L
.832 .29936 L
.836 .29907 L
.84 .29841 L
.844 .29753 L
.848 .29685 L
.852 .29686 L
.856 .29789 L
.86 .29939 L
.864 .30021 L
.868 .29956 L
.872 .29765 L
.876 .29586 L
.88 .29561 L
.884 .29711 L
.888 .29926 L
.892 .30039 L
.896 .29974 L
.9 .29808 L
.904 .29679 L
.908 .29681 L
.912 .29781 L
.916 .2986 L
.92 .29853 L
.924 .29784 L
.928 .29737 L
.932 .29785 L
.936 .29869 L
.94 .29901 L
.944 .29847 L
.948 .29725 L
.952 .29665 L
.956 .29738 L
.96 .29857 L
.964 .29948 L
.968 .29915 L
.972 .29752 L
.976 .29641 L
.98 .29657 L
.984 .29761 L
.988 .29931 L
.992 .2998 L
.996 .29857 L
1 .29751 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .56173 m
.008 .5542 L
.012 .55165 L
.016 .5539 L
.02 .55445 L
.024 .55317 L
.028 .55246 L
.032 .55218 L
.036 .55171 L
.04 .55093 L
.044 .55022 L
.048 .5495 L
.052 .54877 L
.056 .54797 L
.06 .54719 L
.064 .5464 L
.068 .54564 L
.072 .54486 L
.076 .54413 L
.08 .5434 L
.084 .54272 L
.088 .54205 L
.092 .54141 L
.096 .54078 L
.1 .54018 L
.104 .53957 L
.108 .53897 L
.112 .53834 L
.116 .53772 L
.12 .53705 L
.124 .53636 L
.128 .53562 L
.132 .53484 L
.136 .534 L
.14 .53311 L
.144 .53215 L
.148 .53114 L
.152 .53007 L
.156 .52893 L
.16 .52773 L
.164 .52645 L
.168 .52509 L
.172 .52366 L
.176 .52213 L
.18 .5205 L
.184 .51876 L
.188 .51691 L
.192 .51493 L
.196 .51284 L
.2 .51062 L
Mistroke
.204 .50829 L
.208 .50586 L
.212 .50336 L
.216 .5008 L
.22 .49823 L
.224 .49566 L
.228 .49314 L
.232 .49068 L
.236 .48832 L
.24 .48606 L
.244 .48391 L
.248 .48187 L
.252 .47992 L
.256 .47804 L
.26 .47618 L
.264 .47433 L
.268 .47244 L
.272 .47049 L
.276 .46847 L
.28 .46638 L
.284 .46423 L
.288 .46205 L
.292 .45987 L
.296 .45773 L
.3 .45569 L
.304 .45379 L
.308 .45205 L
.312 .45051 L
.316 .44916 L
.32 .448 L
.324 .447 L
.328 .44614 L
.332 .44539 L
.336 .44472 L
.34 .44413 L
.344 .44362 L
.348 .44322 L
.352 .44295 L
.356 .44283 L
.36 .44291 L
.364 .44318 L
.368 .44364 L
.372 .44425 L
.376 .44497 L
.38 .44571 L
.384 .44642 L
.388 .44701 L
.392 .44743 L
.396 .44764 L
.4 .44764 L
Mistroke
.404 .44745 L
.408 .44713 L
.412 .44673 L
.416 .44632 L
.42 .44595 L
.424 .44567 L
.428 .44549 L
.432 .44543 L
.436 .44546 L
.44 .44558 L
.444 .44576 L
.448 .44597 L
.452 .44621 L
.456 .44644 L
.46 .44664 L
.464 .44681 L
.468 .44691 L
.472 .44693 L
.476 .44687 L
.48 .44675 L
.484 .44659 L
.488 .44643 L
.492 .44631 L
.496 .44627 L
.5 .44633 L
.504 .44648 L
.508 .4467 L
.512 .44693 L
.516 .44713 L
.52 .44724 L
.524 .44725 L
.528 .44716 L
.532 .44701 L
.536 .44684 L
.54 .44671 L
.544 .44666 L
.548 .44669 L
.552 .44681 L
.556 .44697 L
.56 .44714 L
.564 .44728 L
.568 .44736 L
.572 .44739 L
.576 .44738 L
.58 .44734 L
.584 .44731 L
.588 .4473 L
.592 .44731 L
.596 .44735 L
.6 .44739 L
Mistroke
.604 .44743 L
.608 .44747 L
.612 .44749 L
.616 .4475 L
.62 .44751 L
.624 .44753 L
.628 .44755 L
.632 .44758 L
.636 .44763 L
.64 .44768 L
.644 .44774 L
.648 .4478 L
.652 .44785 L
.656 .44788 L
.66 .44789 L
.664 .44789 L
.668 .44788 L
.672 .44788 L
.676 .4479 L
.68 .44793 L
.684 .44799 L
.688 .44804 L
.692 .44807 L
.696 .44809 L
.7 .44809 L
.704 .4481 L
.708 .44813 L
.712 .44818 L
.716 .44827 L
.72 .44835 L
.724 .4484 L
.728 .44842 L
.732 .44839 L
.736 .44834 L
.74 .44831 L
.744 .44831 L
.748 .44836 L
.752 .44845 L
.756 .44854 L
.76 .44862 L
.764 .44866 L
.768 .44866 L
.772 .44864 L
.776 .44863 L
.78 .44864 L
.784 .44869 L
.788 .44875 L
.792 .4488 L
.796 .44884 L
.8 .44885 L
Mistroke
.804 .44886 L
.808 .44887 L
.812 .44888 L
.816 .44892 L
.82 .44896 L
.824 .449 L
.828 .44904 L
.832 .44908 L
.836 .44911 L
.84 .44913 L
.844 .44916 L
.848 .44918 L
.852 .44921 L
.856 .44923 L
.86 .44924 L
.864 .44926 L
.868 .44928 L
.872 .44931 L
.876 .44936 L
.88 .44942 L
.884 .44947 L
.888 .4495 L
.892 .44951 L
.896 .44952 L
.9 .44953 L
.904 .44955 L
.908 .44958 L
.912 .44961 L
.916 .44964 L
.92 .44968 L
.924 .44971 L
.928 .44976 L
.932 .4498 L
.936 .44983 L
.94 .44984 L
.944 .44986 L
.948 .44986 L
.952 .44989 L
.956 .44991 L
.96 .44996 L
.964 .44999 L
.968 .45004 L
.972 .45007 L
.976 .45012 L
.98 .45013 L
.984 .45016 L
.988 .45015 L
.992 .45018 L
.996 .45018 L
1 .45024 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42994 m
.008 .43014 L
.012 .43216 L
.016 .43398 L
.02 .43507 L
.024 .43612 L
.028 .43732 L
.032 .43871 L
.036 .43996 L
.04 .4412 L
.044 .44241 L
.048 .44369 L
.052 .44489 L
.056 .44611 L
.06 .44725 L
.064 .44841 L
.068 .44948 L
.072 .45055 L
.076 .45153 L
.08 .4525 L
.084 .4534 L
.088 .45428 L
.092 .45509 L
.096 .45589 L
.1 .45665 L
.104 .45741 L
.108 .45815 L
.112 .45891 L
.116 .45968 L
.12 .4605 L
.124 .46134 L
.128 .46225 L
.132 .4632 L
.136 .46422 L
.14 .46531 L
.144 .46647 L
.148 .46771 L
.152 .46903 L
.156 .47042 L
.16 .47191 L
.164 .47347 L
.168 .47514 L
.172 .4769 L
.176 .47878 L
.18 .48079 L
.184 .48293 L
.188 .48522 L
.192 .48766 L
.196 .49025 L
.2 .493 L
Mistroke
.204 .49588 L
.208 .49888 L
.212 .50198 L
.216 .50514 L
.22 .50834 L
.224 .51152 L
.228 .51465 L
.232 .51769 L
.236 .52062 L
.24 .52342 L
.244 .52607 L
.248 .5286 L
.252 .53102 L
.256 .53336 L
.26 .53566 L
.264 .53796 L
.268 .5403 L
.272 .5427 L
.276 .5452 L
.28 .5478 L
.284 .55047 L
.288 .55319 L
.292 .5559 L
.296 .55855 L
.3 .56108 L
.304 .56344 L
.308 .56559 L
.312 .5675 L
.316 .56918 L
.32 .57062 L
.324 .57186 L
.328 .57293 L
.332 .57386 L
.336 .57469 L
.34 .57541 L
.344 .57603 L
.348 .57653 L
.352 .57686 L
.356 .577 L
.36 .57691 L
.364 .57657 L
.368 .57599 L
.372 .57521 L
.376 .57431 L
.38 .57337 L
.384 .57248 L
.388 .57174 L
.392 .57122 L
.396 .57096 L
.4 .57095 L
Mistroke
.404 .57117 L
.408 .57156 L
.412 .57204 L
.416 .57255 L
.42 .573 L
.424 .57335 L
.428 .57356 L
.432 .57364 L
.436 .57359 L
.44 .57344 L
.444 .57321 L
.448 .57293 L
.452 .57263 L
.456 .57233 L
.46 .57207 L
.464 .57186 L
.468 .57173 L
.472 .5717 L
.476 .57176 L
.48 .5719 L
.484 .5721 L
.488 .57229 L
.492 .57243 L
.496 .57247 L
.5 .57239 L
.504 .57219 L
.508 .57192 L
.512 .57162 L
.516 .57137 L
.52 .57122 L
.524 .5712 L
.528 .57129 L
.532 .57148 L
.536 .57168 L
.54 .57184 L
.544 .5719 L
.548 .57186 L
.552 .57171 L
.556 .57149 L
.56 .57127 L
.564 .57109 L
.568 .57097 L
.572 .57093 L
.576 .57094 L
.58 .57098 L
.584 .57101 L
.588 .57102 L
.592 .571 L
.596 .57095 L
.6 .57089 L
Mistroke
.604 .57082 L
.608 .57077 L
.612 .57073 L
.616 .5707 L
.62 .57068 L
.624 .57067 L
.628 .57064 L
.632 .5706 L
.636 .57054 L
.64 .57045 L
.644 .57036 L
.648 .57027 L
.652 .57019 L
.656 .57015 L
.66 .57013 L
.664 .57014 L
.668 .57016 L
.672 .57016 L
.676 .57013 L
.68 .57006 L
.684 .56998 L
.688 .5699 L
.692 .56984 L
.696 .56982 L
.7 .56981 L
.704 .56981 L
.708 .56977 L
.712 .5697 L
.716 .56959 L
.72 .56948 L
.724 .56939 L
.728 .56935 L
.732 .56937 L
.736 .56942 L
.74 .56946 L
.744 .56946 L
.748 .5694 L
.752 .56929 L
.756 .56917 L
.76 .56907 L
.764 .56901 L
.768 .56898 L
.772 .56898 L
.776 .56897 L
.78 .56894 L
.784 .5689 L
.788 .56884 L
.792 .56878 L
.796 .56874 L
.8 .56871 L
Mistroke
.804 .56869 L
.808 .56865 L
.812 .5686 L
.816 .56853 L
.82 .56845 L
.824 .5684 L
.828 .56837 L
.832 .56836 L
.836 .56834 L
.84 .56831 L
.844 .56825 L
.848 .56818 L
.852 .56811 L
.856 .56806 L
.86 .56803 L
.864 .56801 L
.868 .56798 L
.872 .56795 L
.876 .56791 L
.88 .56786 L
.884 .5678 L
.888 .56775 L
.892 .56769 L
.896 .56765 L
.9 .56761 L
.904 .56757 L
.908 .56752 L
.912 .56748 L
.916 .56742 L
.92 .56739 L
.924 .56737 L
.928 .56736 L
.932 .56733 L
.936 .56728 L
.94 .56719 L
.944 .56712 L
.948 .56704 L
.952 .56701 L
.956 .56697 L
.96 .56696 L
.964 .56692 L
.968 .5669 L
.972 .56685 L
.976 .56684 L
.98 .56679 L
.984 .56676 L
.988 .56667 L
.992 .5666 L
.996 .56649 L
1 .56647 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20003Ool30000
1Goo001oogoo00000Woo00<007ooOol00Woo0P000goo00<007ooOol017oo00@007ooOol0009oo`05
001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo
00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00H007ooOomoo`00Ool20004Ool20006
Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo
000ROol00`00Oomoo`0QOol00`00Ool0000:Ool20003Ool00`00Oomoo`0fOol0029oo`80025oo`05
001oogooOol00003Ool40002Ool30002Ool2000017oo000000000Woo0`0000Eoo`00000007oo0080
0004Ool00000Ool2000017oo000007oo1@0000=oo`0000002@0037oo000ROomS000<Ool0029oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`04001oogoo0003Ool0
0`00Oomoo`020003Ool300000goo001oo`02Ool20002Ool20002Ool01@00Oomoogoo00000Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol0000<Ool0029oo`8000Ioo`D001Eoo`03001oogoo00=oo`8004Eoo`008Woo2@00
17oo00<007ooOol04Goo00<007ooOol0Bgoo000ROol2000<Ool2000@Ool00`00Oomoo`1<Ool0029o
o`8000eoo`03001oogoo00ioo`03001oogoo04aoo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol0CGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8000moo`03001oogoo00]oo`03001oogoo04eoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000?Ool00`00Oomoo`0;Ool00`00
Oomoo`1=Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
3goo00<007ooOol02Goo00<007ooOol0CWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`80011oo`03001oogoo00Aoo`<0009oo`03001oogoo04ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool20004Ool2000@Ool00`00Oomoo`03Ool01P00Oomoo`00Ool0055oo`00
2goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol047oo00<007ooOol00Woo00@007ooOomo
o`80055oo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P004Goo0P000Woo00<007oo
Ool0EGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2000BOol01000
Ool00000Egoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
015oo`<005Qoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`80
06eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]
Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@0
07ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02
001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`80
00Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eo
o`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol5
0002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03
Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool2
0003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uo
o`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<0
07ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomo
o`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]o
o`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03
001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04
001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol4
0003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=o
o`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04
001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Ao
o`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<0
07oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol0
0goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009o
o`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00
:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol0
47oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol0
0goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`05001oogoo001oo`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00H007ooOol007oo0006Ool00`00Oomoo`0LOol40016Ool000]oo`8000Yoo`8000Aoo`80009o
o`D0009oo`03001oogoo01Uoo`@0009ooc/000aoo`00:7oo00<007ooOol05goo0`00C7oo000XOol0
0`00Oomoo`0EOol2001?Ool0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo
01=oo`<0051oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`0AOol2001COol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool047oo0P00E7oo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000mo
o`8005Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0;
Ool3001HOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol01Goo1P00
Fgoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool8001QOol002Qoo`<006Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo0000
0goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool0
0`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<0
07ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004
Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool0
0`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool0
1000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007oo
Ool0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool3
0004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05
001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001o
ogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol0
00Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomo
ogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001o
ogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomo
ogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=o
o`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool5
0003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001ao
o`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00
Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo
10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool2
0008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Mo
o`03001oogoo009oo`<0079oo`005goo00<007ooOol00Woo00<007oo00000`00Kgoo000GOol00`00
Oomoo`02Ool00`00Oomoo`03Ool4001[Ool001Ioo`8000Aoo`8000Moo`H006Ioo`005goo00<007oo
Ool00Woo00<007ooOol02goo1000Hgoo000LOol00`00Oomoo`0>Ool3001QOol001aoo`80015oo`80
061oo`0077oo00<007ooOol04Woo0P00GWoo000LOol2000EOol00`00Oomoo`1KOol001aoo`03001o
ogoo01Eoo`8005]oo`0077oo00<007ooOol05Woo0P00FWoo000:Ool30004Ool00`00Oomoo`02Ool3
0003Ool2000IOol2001HOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`0I
Ool3001FOol000]oo`03001oogoo00]oo`04001oogoo000MOol2001EOol000]oo`03001oogoo00]o
o`03001oogoo008001eoo`<002Ioob4000aoo`002goo00<007ooOol01goo10000goo00<007ooOol0
7Woo9`00;Goo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Mo
o`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(36406\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .34887 m
.008 .34676 L
.012 .34496 L
.016 .34464 L
.02 .34582 L
.024 .34552 L
.028 .34376 L
.032 .34226 L
.036 .34107 L
.04 .33944 L
.044 .33744 L
.048 .33546 L
.052 .33361 L
.056 .33178 L
.06 .33007 L
.064 .32856 L
.068 .32735 L
.072 .32645 L
.076 .32593 L
.08 .32584 L
.084 .32621 L
.088 .32703 L
.092 .32832 L
.096 .33004 L
.1 .33218 L
.104 .3347 L
.108 .3376 L
.112 .34087 L
.116 .34451 L
.12 .34852 L
.124 .35293 L
.128 .35776 L
.132 .36305 L
.136 .36886 L
.14 .37522 L
.144 .38217 L
.148 .38973 L
.152 .39783 L
.156 .40638 L
.16 .41517 L
.164 .42399 L
.168 .43255 L
.172 .44053 L
.176 .44757 L
.18 .45333 L
.184 .45743 L
.188 .4596 L
.192 .45964 L
.196 .45753 L
.2 .45337 L
Mistroke
.204 .44747 L
.208 .44025 L
.212 .43228 L
.216 .42421 L
.22 .41675 L
.224 .41055 L
.228 .40618 L
.232 .40401 L
.236 .40414 L
.24 .40641 L
.244 .4104 L
.248 .41546 L
.252 .42073 L
.256 .42527 L
.26 .42815 L
.264 .42861 L
.268 .42617 L
.272 .4207 L
.276 .41246 L
.28 .40206 L
.284 .39034 L
.288 .37825 L
.292 .36673 L
.296 .35653 L
.3 .34812 L
.304 .34154 L
.308 .33644 L
.312 .33207 L
.316 .32752 L
.32 .32191 L
.324 .3146 L
.328 .30537 L
.332 .29456 L
.336 .28303 L
.34 .27205 L
.344 .26306 L
.348 .25742 L
.352 .25615 L
.356 .25965 L
.36 .26753 L
.364 .27867 L
.368 .29141 L
.372 .30386 L
.376 .31428 L
.38 .32133 L
.384 .32439 L
.388 .32356 L
.392 .31961 L
.396 .3137 L
.4 .30712 L
Mistroke
.404 .30098 L
.408 .29604 L
.412 .29261 L
.416 .29053 L
.42 .2894 L
.424 .28887 L
.428 .28879 L
.432 .28931 L
.436 .29076 L
.44 .29342 L
.444 .29733 L
.448 .30209 L
.452 .30683 L
.456 .31033 L
.46 .31146 L
.464 .30958 L
.468 .30483 L
.472 .2982 L
.476 .29132 L
.48 .28608 L
.484 .28404 L
.488 .28598 L
.492 .29148 L
.496 .29899 L
.5 .30633 L
.504 .31136 L
.508 .31263 L
.512 .30985 L
.516 .30395 L
.52 .29682 L
.524 .29072 L
.528 .28749 L
.532 .28787 L
.536 .29137 L
.54 .29652 L
.544 .30148 L
.548 .30471 L
.552 .30541 L
.556 .30373 L
.56 .30061 L
.564 .2974 L
.568 .29524 L
.572 .29466 L
.576 .2955 L
.58 .29714 L
.584 .2989 L
.588 .30026 L
.592 .30099 L
.596 .30101 L
.6 .30039 L
Mistroke
.604 .2993 L
.608 .29794 L
.612 .29657 L
.616 .29548 L
.62 .29501 L
.624 .29551 L
.628 .29709 L
.632 .29941 L
.636 .30164 L
.64 .30283 L
.644 .30232 L
.648 .30024 L
.652 .29742 L
.656 .29507 L
.66 .29423 L
.664 .29524 L
.668 .29764 L
.672 .30033 L
.676 .30201 L
.68 .30177 L
.684 .29964 L
.688 .29667 L
.692 .29447 L
.696 .29431 L
.7 .29634 L
.704 .29952 L
.708 .30212 L
.712 .30279 L
.716 .30126 L
.72 .29839 L
.724 .29565 L
.728 .29433 L
.732 .29497 L
.736 .29719 L
.74 .2998 L
.744 .30143 L
.748 .30121 L
.752 .29927 L
.756 .29686 L
.76 .29549 L
.764 .29601 L
.768 .29798 L
.772 .29999 L
.776 .30072 L
.78 .29986 L
.784 .29817 L
.788 .29683 L
.792 .29651 L
.796 .2971 L
.8 .29804 L
Mistroke
.804 .29882 L
.808 .29921 L
.812 .29919 L
.816 .2987 L
.82 .29789 L
.824 .2972 L
.828 .29711 L
.832 .29787 L
.836 .299 L
.84 .29959 L
.844 .29914 L
.848 .29793 L
.852 .29694 L
.856 .29696 L
.86 .29786 L
.864 .29877 L
.868 .29888 L
.872 .29823 L
.876 .29765 L
.88 .2978 L
.884 .29858 L
.888 .29917 L
.892 .2988 L
.896 .29775 L
.9 .29691 L
.904 .29702 L
.908 .29802 L
.912 .29888 L
.916 .29885 L
.92 .29816 L
.924 .29752 L
.928 .2978 L
.932 .29874 L
.936 .29913 L
.94 .29851 L
.944 .29715 L
.948 .29617 L
.952 .29689 L
.956 .2987 L
.96 .30002 L
.964 .29997 L
.968 .29814 L
.972 .29607 L
.976 .29597 L
.98 .29747 L
.984 .29949 L
.988 .30066 L
.992 .29914 L
.996 .29664 L
1 .29555 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .52887 m
.008 .53542 L
.012 .54018 L
.016 .543 L
.02 .54446 L
.024 .5443 L
.028 .54395 L
.032 .54358 L
.036 .54328 L
.04 .54285 L
.044 .54241 L
.048 .54194 L
.052 .54151 L
.056 .54103 L
.06 .54059 L
.064 .5401 L
.068 .53965 L
.072 .53917 L
.076 .5387 L
.08 .53819 L
.084 .53768 L
.088 .53712 L
.092 .53655 L
.096 .53591 L
.1 .53524 L
.104 .53451 L
.108 .53373 L
.112 .53287 L
.116 .53196 L
.12 .53098 L
.124 .52995 L
.128 .52883 L
.132 .52766 L
.136 .52641 L
.14 .52508 L
.144 .52367 L
.148 .52218 L
.152 .52058 L
.156 .51888 L
.16 .51706 L
.164 .51513 L
.168 .51307 L
.172 .5109 L
.176 .50861 L
.18 .50622 L
.184 .50375 L
.188 .50121 L
.192 .49865 L
.196 .49608 L
.2 .49354 L
Mistroke
.204 .49106 L
.208 .48866 L
.212 .48637 L
.216 .48418 L
.22 .4821 L
.224 .48012 L
.228 .47821 L
.232 .47635 L
.236 .4745 L
.24 .47263 L
.244 .47072 L
.248 .46874 L
.252 .46669 L
.256 .46457 L
.26 .46241 L
.264 .46023 L
.268 .45808 L
.272 .45601 L
.276 .45406 L
.28 .45227 L
.284 .45066 L
.288 .44924 L
.292 .44802 L
.296 .44697 L
.3 .44607 L
.304 .44529 L
.308 .44462 L
.312 .44403 L
.316 .44351 L
.32 .44309 L
.324 .44278 L
.328 .44261 L
.332 .44262 L
.336 .44281 L
.34 .44319 L
.344 .44374 L
.348 .44442 L
.352 .44516 L
.356 .44588 L
.36 .44653 L
.364 .44702 L
.368 .44732 L
.372 .4474 L
.376 .44729 L
.38 .44702 L
.384 .44665 L
.388 .44623 L
.392 .44583 L
.396 .4455 L
.4 .44527 L
Mistroke
.404 .44515 L
.408 .44515 L
.412 .44524 L
.416 .44541 L
.42 .44562 L
.424 .44585 L
.428 .44609 L
.432 .4463 L
.436 .44648 L
.44 .4466 L
.444 .44665 L
.448 .44663 L
.452 .44655 L
.456 .44641 L
.46 .44625 L
.464 .44611 L
.468 .44603 L
.472 .44603 L
.476 .44613 L
.48 .44631 L
.484 .44654 L
.488 .44675 L
.492 .44692 L
.496 .44699 L
.5 .44696 L
.504 .44684 L
.508 .44668 L
.512 .44652 L
.516 .44641 L
.52 .44639 L
.524 .44646 L
.528 .4466 L
.532 .44678 L
.536 .44695 L
.54 .44707 L
.544 .44714 L
.548 .44714 L
.552 .44711 L
.556 .44707 L
.56 .44703 L
.564 .44703 L
.568 .44705 L
.572 .44709 L
.576 .44714 L
.58 .44718 L
.584 .44722 L
.588 .44724 L
.592 .44725 L
.596 .44726 L
.6 .44727 L
Mistroke
.604 .4473 L
.608 .44733 L
.612 .44739 L
.616 .44745 L
.62 .44751 L
.624 .44757 L
.628 .44761 L
.632 .44763 L
.636 .44763 L
.64 .44762 L
.644 .44761 L
.648 .44761 L
.652 .44764 L
.656 .44769 L
.66 .44774 L
.664 .44779 L
.668 .44783 L
.672 .44784 L
.676 .44784 L
.68 .44785 L
.684 .44788 L
.688 .44794 L
.692 .44802 L
.696 .4481 L
.7 .44815 L
.704 .44816 L
.708 .44812 L
.712 .44808 L
.716 .44805 L
.72 .44806 L
.724 .44811 L
.728 .4482 L
.732 .4483 L
.736 .44838 L
.74 .44841 L
.744 .44841 L
.748 .44839 L
.752 .44838 L
.756 .44839 L
.76 .44843 L
.764 .44849 L
.768 .44854 L
.772 .44857 L
.776 .44859 L
.78 .44861 L
.784 .44862 L
.788 .44865 L
.792 .44868 L
.796 .44872 L
.8 .44875 L
Mistroke
.804 .44878 L
.808 .44881 L
.812 .44883 L
.816 .44886 L
.82 .4489 L
.824 .44894 L
.828 .44898 L
.832 .449 L
.836 .449 L
.84 .449 L
.844 .44901 L
.848 .44905 L
.852 .4491 L
.856 .44916 L
.86 .44921 L
.864 .44925 L
.868 .44927 L
.872 .44928 L
.876 .44928 L
.88 .4493 L
.884 .44932 L
.888 .44935 L
.892 .44938 L
.896 .44943 L
.9 .44946 L
.904 .4495 L
.908 .44953 L
.912 .44956 L
.916 .44958 L
.92 .44962 L
.924 .44964 L
.928 .44966 L
.932 .44967 L
.936 .4497 L
.94 .44971 L
.944 .44976 L
.948 .4498 L
.952 .44986 L
.956 .44988 L
.96 .44992 L
.964 .44992 L
.968 .44994 L
.972 .44995 L
.976 .44999 L
.98 .45001 L
.984 .45006 L
.988 .45006 L
.992 .45011 L
.996 .45013 L
1 .4502 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .41032 m
.008 .42428 L
.012 .42805 L
.016 .43236 L
.02 .43704 L
.024 .43996 L
.028 .44114 L
.032 .44271 L
.036 .44453 L
.04 .44618 L
.044 .44755 L
.048 .44895 L
.052 .45025 L
.056 .45151 L
.06 .45262 L
.064 .45371 L
.068 .4547 L
.072 .45567 L
.076 .45656 L
.08 .45746 L
.084 .45832 L
.088 .4592 L
.092 .46006 L
.096 .46097 L
.1 .4619 L
.104 .4629 L
.108 .46393 L
.112 .46504 L
.116 .4662 L
.12 .46745 L
.124 .46876 L
.128 .47015 L
.132 .47161 L
.136 .47317 L
.14 .47481 L
.144 .47655 L
.148 .47841 L
.152 .48038 L
.156 .48248 L
.16 .48473 L
.164 .48711 L
.168 .48966 L
.172 .49235 L
.176 .49518 L
.18 .49814 L
.184 .50121 L
.188 .50435 L
.192 .50753 L
.196 .51071 L
.2 .51386 L
Mistroke
.204 .51693 L
.208 .51991 L
.212 .52275 L
.216 .52546 L
.22 .52804 L
.224 .53049 L
.228 .53285 L
.232 .53516 L
.236 .53745 L
.24 .53976 L
.244 .54214 L
.248 .54459 L
.252 .54714 L
.256 .54977 L
.26 .55245 L
.264 .55515 L
.268 .55781 L
.272 .56039 L
.276 .56281 L
.28 .56504 L
.284 .56704 L
.288 .5688 L
.292 .57031 L
.296 .57161 L
.3 .57272 L
.304 .57368 L
.308 .57452 L
.312 .57526 L
.316 .57589 L
.32 .57641 L
.324 .57679 L
.328 .57699 L
.332 .57697 L
.336 .57673 L
.34 .57625 L
.344 .57556 L
.348 .57471 L
.352 .57379 L
.356 .57288 L
.36 .57207 L
.364 .57144 L
.368 .57106 L
.372 .57094 L
.376 .57107 L
.38 .5714 L
.384 .57187 L
.388 .57238 L
.392 .57288 L
.396 .57328 L
.4 .57355 L
Mistroke
.404 .57369 L
.408 .57368 L
.412 .57356 L
.416 .57335 L
.42 .57309 L
.424 .57279 L
.428 .57249 L
.432 .57221 L
.436 .57198 L
.44 .57182 L
.444 .57175 L
.448 .57177 L
.452 .57187 L
.456 .57204 L
.46 .57223 L
.464 .5724 L
.468 .57249 L
.472 .57247 L
.476 .57234 L
.48 .57211 L
.484 .57182 L
.488 .57154 L
.492 .57133 L
.496 .57124 L
.5 .57127 L
.504 .57141 L
.508 .5716 L
.512 .57179 L
.516 .57192 L
.52 .57193 L
.524 .57184 L
.528 .57166 L
.532 .57144 L
.536 .57122 L
.54 .57106 L
.544 .57097 L
.548 .57095 L
.552 .57098 L
.556 .57103 L
.56 .57106 L
.564 .57106 L
.568 .57103 L
.572 .57097 L
.576 .57091 L
.58 .57084 L
.584 .57079 L
.588 .57076 L
.592 .57073 L
.596 .57071 L
.6 .57069 L
Mistroke
.604 .57065 L
.608 .5706 L
.612 .57053 L
.616 .57045 L
.62 .57036 L
.624 .57029 L
.628 .57022 L
.632 .57019 L
.636 .57017 L
.64 .57017 L
.644 .57018 L
.648 .57017 L
.652 .57014 L
.656 .57008 L
.66 .57 L
.664 .56993 L
.668 .56988 L
.672 .56985 L
.676 .56983 L
.68 .56981 L
.684 .56977 L
.688 .56969 L
.692 .56959 L
.696 .56949 L
.7 .56942 L
.704 .5694 L
.708 .56942 L
.712 .56946 L
.716 .56949 L
.72 .56947 L
.724 .5694 L
.728 .56929 L
.732 .56917 L
.736 .56907 L
.74 .56903 L
.744 .56902 L
.748 .56902 L
.752 .56901 L
.756 .56898 L
.76 .56892 L
.764 .56885 L
.768 .56879 L
.772 .56874 L
.776 .56872 L
.78 .56871 L
.784 .56869 L
.788 .56864 L
.792 .56857 L
.796 .56849 L
.8 .56843 L
Mistroke
.804 .56838 L
.808 .56836 L
.812 .56834 L
.816 .56831 L
.82 .56827 L
.824 .56822 L
.828 .56817 L
.832 .56812 L
.836 .56807 L
.84 .56803 L
.844 .56799 L
.848 .56795 L
.852 .56791 L
.856 .56787 L
.86 .56782 L
.864 .56777 L
.868 .56772 L
.872 .56769 L
.876 .56764 L
.88 .5676 L
.884 .56755 L
.888 .56749 L
.892 .56745 L
.896 .56742 L
.9 .56739 L
.904 .56737 L
.908 .56733 L
.912 .56728 L
.916 .56721 L
.92 .56715 L
.924 .5671 L
.928 .56706 L
.932 .56701 L
.936 .56698 L
.94 .56692 L
.944 .56689 L
.948 .56686 L
.952 .56686 L
.956 .56682 L
.96 .56679 L
.964 .56671 L
.968 .56664 L
.972 .56655 L
.976 .56651 L
.98 .56645 L
.984 .56645 L
.988 .5664 L
.992 .56641 L
.996 .56636 L
1 .56636 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oo`00009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool200001Goo0000
07oo00000Woo00@007ooOol0009oo`03001oogoo009oo`8000=oo`03001oogoo00Aoo`04001oogoo
0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001o
o`0000Ioo`04001oogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`800004Ool007ooOol20004
Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo
0P001Woo000ROol00`00Oomoo`0NOol01000Oomoo`002Woo0P000goo00<007ooOol0>7oo000ROol2
000NOol01@00Oomoogoo00000goo10000Woo0`000Woo0`0000Eoo`00000007oo00<0009oo`800004
Ool00000Ool3000017oo000007oo0P0000Aoo`00001ooa0000aoo`008WooH`0037oo000ROol01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoo`000goo0P00
0Woo00D007oo001oo`0000=oo`06001oo`00Ool007oo0`000goo00D007ooOomoo`00009oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo000037oo000ROol20004Ool4000EOol00`00Oomoo`03Ool20018Ool0029oo`04001o
ogooOol30003Ool2000BOol2001?Ool0029oo`D000Ioo`80011oo`80051oo`008Woo0P002Woo0P00
3goo00<007ooOol0Cgoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0:
Ool00`00Oomoo`0=Ool00`00Oomoo`1?Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P0037oo00<007ooOol02goo00<007ooOol0D7oo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8000aoo`8000aoo`03001oogoo051oo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomo
o`1@Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo00<007oo
Ool017oo0`000Woo00<007ooOol0DGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Ao
o`8000ioo`03001oogoo00=oo`06001oo`00001oo`00Dgoo000;Ool2000:Ool20004Ool00`00Oomo
o`02Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool01000Oomoogoo0P00E7oo000;Ool20004Ool00`00
Oomoo`03Ool20002Ool50002Ool2000?Ool00`00Oomoo`02001IOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol0009oo`8000moo`04001oogoo001JOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol03goo0`00FWoo000:Ool01000Oomoo`00
27oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@0
07ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001o
ogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04
001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000R
Ool2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00
Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<0
07ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001o
ogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0
015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001o
ogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04
001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D0
00=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo
0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomo
o`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo
00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03
001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol0
00Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo
0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000X
Ool00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo
1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@
Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00
Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000
Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomo
o`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02
001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001o
ogoo01Uoo`D004Qoo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol05Woo10000goo
?@0037oo000XOol00`00Oomoo`0EOol2001?Ool002Qoo`03001oogoo019oo`<0055oo`004Goo0P00
17oo00<007ooOol00goo0P000goo0`000goo00<007ooOol047oo0`00Dgoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00moo`8005Eoo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool2001GOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0037oo0`00F7oo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00Qoo`@005Yoo`0047oo00@007ooOol000Qo
o`04001oogoo0002Ool20004Ool300000goo00000005001NOol0015oo`8000Yoo`8000Aoo`03001o
ogoo009oo`04001oo`00001UOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo
06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0
06Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001W
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo
1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3
0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo
00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002
Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomo
ogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo
00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@0
07ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=o
o`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004
Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Io
o`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Io
o`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol0
0003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
00]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol0
00Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`005Woo0`00
0goo0P00Lgoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo009oo`<0079oo`005goo
00<007ooOol00Woo00<007oo00000P00L7oo000GOol00`00Oomoo`02Ool01000Oomoogoo1000KGoo
000FOol20004Ool20005Ool5001YOol001Moo`03001oogoo009oo`03001oogoo00Qoo`@006Ioo`00
77oo00<007ooOol02goo0`00I7oo000LOol2000?Ool2001ROol001aoo`03001oogoo00moo`80065o
o`0077oo0P004Woo00<007ooOol0GWoo000LOol00`00Oomoo`0BOol2001NOol001aoo`03001oogoo
01=oo`8005eoo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P005Woo0P00Fgoo000;Ool00`00
Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol05Woo0`00FGoo000;Ool00`00Oomoo`0;Ool0
1000Oomoo`006Woo0P00F7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02000JOol3000WOolS000<
Ool000]oo`03001oogoo00Moo`@000=oo`03001oogoo01]oobP002moo`002Woo0P002Goo00<007oo
Ool017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(36573\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3533 m
.008 .35127 L
.012 .35011 L
.016 .34796 L
.02 .34491 L
.024 .34137 L
.028 .33747 L
.032 .33503 L
.036 .33427 L
.04 .33398 L
.044 .33385 L
.048 .33354 L
.052 .33326 L
.056 .3332 L
.06 .33345 L
.064 .33409 L
.068 .33519 L
.072 .33673 L
.076 .33871 L
.08 .34111 L
.084 .34392 L
.088 .34712 L
.092 .35073 L
.096 .35476 L
.1 .35924 L
.104 .3642 L
.108 .36969 L
.112 .37575 L
.116 .38241 L
.12 .38969 L
.124 .39754 L
.128 .40586 L
.132 .41453 L
.136 .42331 L
.14 .43197 L
.144 .44018 L
.148 .44759 L
.152 .45383 L
.156 .45853 L
.16 .46137 L
.164 .46215 L
.168 .46078 L
.172 .45733 L
.176 .452 L
.18 .44518 L
.184 .43737 L
.188 .42919 L
.192 .42132 L
.196 .41448 L
.2 .40928 L
Mistroke
.204 .40616 L
.208 .40534 L
.212 .40678 L
.216 .41014 L
.22 .41485 L
.224 .42012 L
.228 .42503 L
.232 .42866 L
.236 .43016 L
.24 .42892 L
.244 .42467 L
.248 .41746 L
.252 .40775 L
.256 .39626 L
.26 .38392 L
.264 .37171 L
.268 .36055 L
.272 .35106 L
.276 .34348 L
.28 .33761 L
.284 .33287 L
.288 .32842 L
.292 .32335 L
.296 .3169 L
.3 .30867 L
.304 .29872 L
.308 .28762 L
.312 .27641 L
.316 .26645 L
.32 .2592 L
.324 .25588 L
.328 .25722 L
.332 .26321 L
.336 .27312 L
.34 .28553 L
.344 .2986 L
.348 .31044 L
.352 .31945 L
.356 .3246 L
.36 .32558 L
.364 .32281 L
.368 .31731 L
.372 .31043 L
.376 .30352 L
.38 .29763 L
.384 .2933 L
.388 .29058 L
.392 .28919 L
.396 .28869 L
.4 .28874 L
Mistroke
.404 .28927 L
.408 .29044 L
.412 .29257 L
.416 .29581 L
.42 .3 L
.424 .30454 L
.428 .30852 L
.432 .31088 L
.436 .31071 L
.44 .30765 L
.444 .3021 L
.448 .29531 L
.452 .28901 L
.456 .28498 L
.46 .2845 L
.464 .2879 L
.468 .29436 L
.472 .30211 L
.476 .30888 L
.48 .31264 L
.484 .31231 L
.488 .30811 L
.492 .30141 L
.496 .29432 L
.5 .28898 L
.504 .2869 L
.508 .28847 L
.512 .29286 L
.516 .29838 L
.52 .30314 L
.524 .30571 L
.528 .30562 L
.532 .30329 L
.536 .29983 L
.54 .29656 L
.544 .29458 L
.548 .29437 L
.552 .29568 L
.556 .29777 L
.56 .29976 L
.564 .30105 L
.568 .30143 L
.572 .30097 L
.576 .29991 L
.58 .29856 L
.584 .29721 L
.588 .29612 L
.592 .29553 L
.596 .29559 L
.6 .29641 L
Mistroke
.604 .29797 L
.608 .29996 L
.612 .30178 L
.616 .30264 L
.62 .30201 L
.624 .29993 L
.628 .29719 L
.632 .29494 L
.636 .29422 L
.64 .29537 L
.644 .29791 L
.648 .30066 L
.652 .30228 L
.656 .30191 L
.66 .29963 L
.664 .29656 L
.668 .29434 L
.672 .29426 L
.676 .29649 L
.68 .2999 L
.684 .30264 L
.688 .30322 L
.692 .30133 L
.696 .29801 L
.7 .29501 L
.704 .29384 L
.708 .29499 L
.712 .29776 L
.716 .30063 L
.72 .30205 L
.724 .30132 L
.728 .29891 L
.732 .2963 L
.736 .29511 L
.74 .29605 L
.744 .29848 L
.748 .30076 L
.752 .30143 L
.756 .30013 L
.76 .29779 L
.764 .29594 L
.768 .29562 L
.772 .2968 L
.776 .29865 L
.78 .30008 L
.784 .30043 L
.788 .29966 L
.792 .29821 L
.796 .29684 L
.8 .29631 L
Mistroke
.804 .29694 L
.808 .29846 L
.812 .29992 L
.816 .3003 L
.82 .29933 L
.824 .29765 L
.828 .29648 L
.832 .29661 L
.836 .29778 L
.84 .299 L
.844 .29939 L
.848 .29887 L
.852 .29811 L
.856 .29778 L
.86 .29797 L
.864 .29825 L
.868 .29827 L
.872 .29815 L
.876 .29823 L
.88 .29854 L
.884 .29871 L
.888 .29822 L
.892 .29726 L
.896 .29671 L
.9 .29726 L
.904 .29884 L
.908 .30029 L
.912 .30022 L
.916 .29863 L
.92 .29661 L
.924 .29572 L
.928 .29678 L
.932 .29869 L
.936 .29978 L
.94 .29939 L
.944 .29785 L
.948 .29682 L
.952 .29747 L
.956 .29886 L
.96 .2997 L
.964 .29915 L
.968 .29711 L
.972 .29576 L
.976 .29646 L
.98 .29826 L
.984 .30026 L
.988 .30059 L
.992 .29841 L
.996 .29638 L
1 .29586 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .47497 m
.008 .48694 L
.012 .4945 L
.016 .49753 L
.02 .50209 L
.024 .50821 L
.028 .51461 L
.032 .52096 L
.036 .52613 L
.04 .5298 L
.044 .53205 L
.048 .53303 L
.052 .53353 L
.056 .53364 L
.06 .53361 L
.064 .53342 L
.068 .53318 L
.072 .53284 L
.076 .53243 L
.08 .53191 L
.084 .53132 L
.088 .53062 L
.092 .52985 L
.096 .52898 L
.1 .52804 L
.104 .52699 L
.108 .52587 L
.112 .52465 L
.116 .52334 L
.12 .52193 L
.124 .52042 L
.128 .51879 L
.132 .51705 L
.136 .51519 L
.14 .5132 L
.144 .51109 L
.148 .50886 L
.152 .50652 L
.156 .50408 L
.16 .50158 L
.164 .49903 L
.168 .49647 L
.172 .49393 L
.176 .49143 L
.18 .48901 L
.184 .48668 L
.188 .48445 L
.192 .48234 L
.196 .48033 L
.2 .47839 L
Mistroke
.204 .47652 L
.208 .47468 L
.212 .47282 L
.216 .47093 L
.22 .46899 L
.224 .46697 L
.228 .46489 L
.232 .46276 L
.236 .46059 L
.24 .45844 L
.244 .45635 L
.248 .45435 L
.252 .4525 L
.256 .45082 L
.26 .44934 L
.264 .44805 L
.268 .44695 L
.272 .44601 L
.276 .44521 L
.28 .44452 L
.284 .44392 L
.288 .44339 L
.292 .44296 L
.296 .44262 L
.3 .44242 L
.304 .44236 L
.308 .44248 L
.312 .44279 L
.316 .44326 L
.32 .44388 L
.324 .44459 L
.328 .44533 L
.332 .44601 L
.336 .44657 L
.34 .44696 L
.344 .44714 L
.348 .44711 L
.352 .4469 L
.356 .44656 L
.36 .44614 L
.364 .44572 L
.368 .44535 L
.372 .44507 L
.376 .44491 L
.38 .44486 L
.384 .44492 L
.388 .44506 L
.392 .44526 L
.396 .44549 L
.4 .44573 L
Mistroke
.404 .44595 L
.408 .44614 L
.412 .44629 L
.416 .44637 L
.42 .44638 L
.424 .44632 L
.428 .44621 L
.432 .44606 L
.436 .44591 L
.44 .44581 L
.444 .44577 L
.448 .44581 L
.452 .44595 L
.456 .44615 L
.46 .44637 L
.464 .44657 L
.468 .44669 L
.472 .44672 L
.476 .44665 L
.48 .44651 L
.484 .44635 L
.488 .44621 L
.492 .44613 L
.496 .44615 L
.5 .44625 L
.504 .44641 L
.508 .44659 L
.512 .44675 L
.516 .44685 L
.52 .44689 L
.524 .44688 L
.528 .44684 L
.532 .44679 L
.536 .44676 L
.54 .44676 L
.544 .44679 L
.548 .44684 L
.552 .44689 L
.556 .44694 L
.56 .44697 L
.564 .44699 L
.568 .447 L
.572 .44701 L
.576 .44702 L
.58 .44705 L
.584 .44709 L
.588 .44715 L
.592 .44721 L
.596 .44727 L
.6 .44732 L
Mistroke
.604 .44736 L
.608 .44737 L
.612 .44737 L
.616 .44736 L
.62 .44735 L
.624 .44736 L
.628 .44739 L
.632 .44744 L
.636 .44749 L
.64 .44754 L
.644 .44757 L
.648 .44759 L
.652 .4476 L
.656 .44761 L
.66 .44764 L
.664 .4477 L
.668 .44777 L
.672 .44784 L
.676 .44789 L
.68 .44789 L
.684 .44786 L
.688 .44782 L
.692 .4478 L
.696 .44781 L
.7 .44787 L
.704 .44796 L
.708 .44805 L
.712 .44812 L
.716 .44816 L
.72 .44816 L
.724 .44814 L
.728 .44813 L
.732 .44815 L
.736 .44818 L
.74 .44824 L
.744 .44828 L
.748 .44832 L
.752 .44833 L
.756 .44835 L
.76 .44837 L
.764 .4484 L
.768 .44844 L
.772 .44848 L
.776 .44852 L
.78 .44854 L
.784 .44856 L
.788 .44858 L
.792 .4486 L
.796 .44863 L
.8 .44868 L
Mistroke
.804 .44872 L
.808 .44875 L
.812 .44876 L
.816 .44877 L
.82 .44878 L
.824 .44881 L
.828 .44884 L
.832 .44889 L
.836 .44894 L
.84 .44898 L
.844 .44901 L
.848 .44903 L
.852 .44905 L
.856 .44907 L
.86 .44908 L
.864 .4491 L
.868 .44913 L
.872 .44916 L
.876 .4492 L
.88 .44924 L
.884 .44927 L
.888 .44931 L
.892 .44934 L
.896 .44937 L
.9 .44939 L
.904 .44941 L
.908 .44942 L
.912 .44944 L
.916 .44946 L
.92 .44951 L
.924 .44955 L
.928 .44959 L
.932 .44962 L
.936 .44965 L
.94 .44966 L
.944 .4497 L
.948 .44973 L
.952 .44977 L
.956 .44977 L
.96 .44979 L
.964 .44979 L
.968 .44983 L
.972 .44987 L
.976 .44993 L
.98 .44997 L
.984 .45002 L
.988 .45002 L
.992 .45005 L
.996 .45004 L
1 .45008 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .36545 m
.008 .374 L
.012 .38353 L
.016 .39207 L
.02 .39978 L
.024 .4088 L
.028 .4188 L
.032 .42818 L
.036 .43651 L
.04 .44278 L
.044 .44688 L
.048 .44982 L
.052 .45184 L
.056 .45356 L
.06 .45501 L
.064 .45641 L
.068 .45773 L
.072 .45908 L
.076 .4604 L
.08 .46176 L
.084 .46312 L
.088 .46453 L
.092 .46596 L
.096 .46746 L
.1 .46899 L
.104 .47059 L
.108 .47224 L
.112 .47398 L
.116 .47578 L
.12 .47769 L
.124 .47969 L
.128 .48181 L
.132 .48405 L
.136 .48643 L
.14 .48895 L
.144 .49162 L
.148 .49442 L
.152 .49736 L
.156 .50039 L
.16 .50352 L
.164 .50669 L
.168 .50988 L
.172 .51305 L
.176 .51615 L
.18 .51916 L
.184 .52206 L
.188 .52481 L
.192 .52744 L
.196 .52994 L
.2 .53234 L
Mistroke
.204 .53466 L
.208 .53695 L
.212 .53924 L
.216 .54158 L
.22 .54399 L
.224 .54649 L
.228 .54908 L
.232 .55173 L
.236 .55441 L
.24 .55709 L
.244 .55969 L
.248 .56216 L
.252 .56446 L
.256 .56654 L
.26 .56838 L
.264 .56998 L
.268 .57135 L
.272 .57252 L
.276 .57351 L
.28 .57437 L
.284 .57511 L
.288 .57575 L
.292 .57628 L
.296 .57669 L
.3 .57695 L
.304 .57702 L
.308 .57686 L
.312 .57647 L
.316 .57587 L
.32 .57509 L
.324 .57419 L
.328 .57327 L
.332 .57242 L
.336 .57171 L
.34 .57122 L
.344 .57099 L
.348 .57102 L
.352 .57127 L
.356 .57169 L
.36 .5722 L
.364 .57272 L
.368 .57317 L
.372 .57352 L
.376 .57372 L
.38 .57377 L
.384 .57369 L
.388 .5735 L
.392 .57324 L
.396 .57295 L
.4 .57264 L
Mistroke
.404 .57236 L
.408 .57212 L
.412 .57193 L
.416 .57182 L
.42 .5718 L
.424 .57186 L
.428 .57199 L
.432 .57217 L
.436 .57235 L
.44 .57248 L
.444 .57253 L
.448 .57246 L
.452 .57228 L
.456 .57202 L
.46 .57174 L
.464 .57148 L
.468 .57132 L
.472 .57128 L
.476 .57136 L
.48 .57152 L
.484 .57173 L
.488 .57189 L
.492 .57198 L
.496 .57195 L
.5 .57182 L
.504 .57161 L
.508 .57138 L
.512 .57117 L
.516 .57104 L
.52 .57098 L
.524 .57099 L
.528 .57103 L
.532 .57108 L
.536 .57111 L
.54 .5711 L
.544 .57105 L
.548 .57099 L
.552 .57092 L
.556 .57086 L
.56 .57081 L
.564 .57078 L
.568 .57076 L
.572 .57074 L
.576 .57071 L
.58 .57066 L
.584 .5706 L
.588 .57053 L
.592 .57045 L
.596 .57037 L
.6 .5703 L
Mistroke
.604 .57025 L
.608 .57022 L
.612 .57021 L
.616 .57022 L
.62 .57022 L
.624 .5702 L
.628 .57015 L
.632 .57009 L
.636 .57001 L
.64 .56995 L
.644 .5699 L
.648 .56987 L
.652 .56986 L
.656 .56983 L
.66 .56977 L
.664 .56969 L
.668 .56959 L
.672 .5695 L
.676 .56945 L
.68 .56944 L
.684 .56948 L
.688 .56951 L
.692 .56953 L
.696 .56949 L
.7 .5694 L
.704 .56928 L
.708 .56916 L
.712 .56908 L
.716 .56904 L
.72 .56904 L
.724 .56905 L
.728 .56905 L
.732 .56902 L
.736 .56895 L
.74 .56887 L
.744 .5688 L
.748 .56876 L
.752 .56873 L
.756 .56872 L
.76 .5687 L
.764 .56866 L
.768 .5686 L
.772 .56853 L
.776 .56846 L
.78 .56841 L
.784 .56838 L
.788 .56835 L
.792 .56831 L
.796 .56827 L
.8 .56823 L
Mistroke
.804 .56818 L
.808 .56815 L
.812 .56811 L
.816 .56808 L
.82 .56803 L
.824 .56798 L
.828 .56792 L
.832 .56786 L
.836 .56781 L
.84 .56777 L
.844 .56774 L
.848 .56772 L
.852 .56769 L
.856 .56765 L
.86 .56759 L
.864 .56752 L
.868 .56746 L
.872 .56742 L
.876 .56739 L
.88 .56737 L
.884 .56734 L
.888 .5673 L
.892 .56724 L
.896 .56719 L
.9 .56713 L
.904 .56709 L
.908 .56704 L
.912 .567 L
.916 .56695 L
.92 .56692 L
.924 .56689 L
.928 .56686 L
.932 .56682 L
.936 .56678 L
.94 .56672 L
.944 .56667 L
.948 .56661 L
.952 .56656 L
.956 .5665 L
.96 .56646 L
.964 .56641 L
.968 .5664 L
.972 .56637 L
.976 .56637 L
.98 .56631 L
.984 .56628 L
.988 .56619 L
.992 .56614 L
.996 .56605 L
1 .56603 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Moo`<000Aoo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo
01]oo`04001oogoo000;Ool01000Oomoogoo0P00?7oo000ROol2000LOol01@00Oomoogoo00000Woo
1@000Woo00@007oo001oo`<0009oo`80009oo`<00005Ool00000001oo`0200000goo0000000M000<
Ool0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00P007ooOol007oo001oo`000Woo0`000Woo00<007ooOol00P000goo00D007ooOomoo`00
00=oo`05001oogooOol00002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000aoo`008Woo0P006Woo0P0017oo0`00
BWoo000ROol00`00Oomoo`06000BOol2001BOol0029oo`<000Eoo`80015oo`03001oogoo055oo`00
8Woo0P001goo0P0047oo00<007ooOol0DGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003
Ool00`00Oomoo`07Ool2000>Ool00`00Oomoo`1BOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P002Goo00<007ooOol037oo00<007ooOol0DWoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`8000Uoo`8000aoo`03001oogoo05=oo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool0
0`00Oomoo`1COol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P002goo
00<007ooOol017oo0P000goo00<007ooOol0Dgoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`8000]oo`03001oogoo00=oo`06001oogoo001oo`00EWoo000;Ool2000:Ool20004Ool0
0`00Oomoo`02Ool00`00Oomoo`0:Ool20003Ool01000Oomoogoo0`00EWoo000;Ool20004Ool00`00
Oomoo`03Ool20002Ool50002Ool2000<Ool01@00Oomoogoo0000G7oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0002Ool2000=Ool01000Ool00000G7oo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00aoo`<005eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04
001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool0
1000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool0
1P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`00
8Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<0
07ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03
001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00
Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo
000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00
Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000
Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool0
1000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool5
0003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogoo
Ool00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo
00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009o
o`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool0
0`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo
0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomo
o`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00
:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomo
o`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol0
47oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<0
07ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@0
07ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Ool006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
0P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00
Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00
Oomoo`0GOol5001:Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo01Aoo`<000Ao
ocl000aoo`00:7oo00<007ooOol04Woo0P00DWoo000XOol00`00Oomoo`0@Ool3001COol0015oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`8000moo`8005Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool3000<Ool3001GOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007oo00002goo0P00FGoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`800003Ool007oo00Ioo`<005]oo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`020002Ool5001MOol0011oo`04001oogoo0008
Ool01000Oomoo`000Woo0P0017oo00@007ooOomoo`@0065oo`004Goo0P002Woo0P0017oo00<007oo
Ool00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1V
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001X
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D0
06]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00
0goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079o
o`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04
001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<0
07ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@00
0goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo
00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomo
o`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03
001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool0
1000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo
00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool0
1000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo0000
0goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000;
Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:
Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo0P00Lgoo000LOol2001cOol0
01aoo`8007=oo`0077oo00<007oo0000LWoo000LOol3001bOol001Ioo`<000=oo`04001oogoo001a
Ool001Moo`03001oogoo009oo`04001oogoo001aOol001Moo`03001oogoo009oo`80009oo`03001o
ogoo06ioo`005goo00<007ooOol00Woo00D007ooOomoo`00071oo`005goo00<007ooOol00Woo00<0
07ooOol00Woo0P00KWoo000FOol20004Ool20004Ool4001[Ool001Moo`03001oogoo009oo`03001o
ogoo00Ioo`<006Uoo`0077oo00<007ooOol02Goo0P00Igoo000LOol2000<Ool2001UOol001aoo`03
001oogoo00eoo`03001oogoo069oo`0077oo0P003goo0P00HWoo000LOol00`00Oomoo`0?Ool2001Q
Ool001aoo`03001oogoo011oo`80061oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P004goo
0P00GWoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol057oo0P00G7oo000;
Ool00`00Oomoo`0;Ool01000Oomoo`005goo0P00Fgoo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02
000HOol2000XOolU000<Ool000]oo`03001oogoo00Moo`@000=oo`03001oogoo01UoobT0031oo`00
2Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001c
Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(36740\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .34425 m
.008 .34399 L
.012 .34354 L
.016 .34239 L
.02 .34043 L
.024 .33886 L
.028 .33798 L
.032 .33844 L
.036 .33994 L
.04 .34045 L
.044 .33977 L
.048 .33924 L
.052 .33966 L
.056 .34225 L
.06 .34685 L
.064 .3523 L
.068 .35817 L
.072 .36392 L
.076 .36955 L
.08 .37519 L
.084 .38101 L
.088 .38721 L
.092 .39391 L
.096 .40116 L
.1 .40893 L
.104 .4171 L
.108 .4255 L
.112 .43388 L
.116 .44195 L
.12 .44936 L
.124 .45575 L
.128 .46077 L
.132 .46409 L
.136 .46544 L
.14 .46469 L
.144 .46182 L
.148 .45698 L
.152 .45049 L
.156 .44281 L
.16 .43454 L
.164 .42635 L
.168 .41895 L
.172 .41297 L
.176 .40891 L
.18 .40708 L
.184 .40756 L
.188 .41013 L
.192 .41433 L
.196 .41946 L
.2 .42464 L
Mistroke
.204 .42889 L
.208 .43133 L
.212 .43123 L
.216 .42815 L
.22 .42203 L
.224 .41315 L
.228 .40212 L
.232 .3898 L
.236 .37718 L
.24 .36521 L
.244 .35465 L
.248 .34593 L
.252 .33909 L
.256 .33373 L
.26 .32913 L
.264 .32442 L
.268 .31876 L
.272 .31153 L
.276 .30251 L
.28 .292 L
.284 .28083 L
.288 .27025 L
.292 .2617 L
.296 .25656 L
.3 .25581 L
.304 .2598 L
.308 .26814 L
.312 .2797 L
.316 .29284 L
.32 .30567 L
.324 .31642 L
.328 .32369 L
.332 .32674 L
.336 .3256 L
.34 .32103 L
.344 .31429 L
.348 .3068 L
.352 .29987 L
.356 .2944 L
.36 .29077 L
.364 .28885 L
.368 .28822 L
.372 .28843 L
.376 .28916 L
.38 .29036 L
.384 .29214 L
.388 .29472 L
.392 .29819 L
.396 .30232 L
.4 .30647 L
Mistroke
.404 .30967 L
.408 .31093 L
.412 .30953 L
.416 .30542 L
.42 .29928 L
.424 .29254 L
.428 .28703 L
.432 .28441 L
.436 .28558 L
.44 .2904 L
.444 .2976 L
.448 .30517 L
.452 .31095 L
.456 .31323 L
.46 .31136 L
.464 .30597 L
.468 .29875 L
.472 .29194 L
.476 .28756 L
.48 .28674 L
.484 .28948 L
.488 .29463 L
.492 .30037 L
.496 .30478 L
.5 .3066 L
.504 .30558 L
.508 .30249 L
.512 .29868 L
.516 .29556 L
.52 .29407 L
.524 .29445 L
.528 .29626 L
.532 .29861 L
.536 .30059 L
.54 .30159 L
.544 .30151 L
.548 .30063 L
.552 .29935 L
.556 .298 L
.56 .29681 L
.564 .29595 L
.568 .29563 L
.572 .296 L
.576 .2971 L
.58 .29879 L
.584 .30068 L
.588 .30216 L
.592 .30257 L
.596 .30153 L
.6 .29925 L
Mistroke
.604 .29657 L
.608 .29466 L
.612 .29443 L
.616 .29602 L
.62 .2987 L
.624 .3012 L
.628 .30229 L
.632 .30143 L
.636 .29901 L
.64 .29623 L
.644 .29455 L
.648 .29495 L
.652 .29732 L
.656 .30047 L
.66 .30272 L
.664 .30283 L
.668 .30073 L
.672 .29753 L
.676 .2949 L
.68 .29416 L
.684 .29556 L
.688 .29828 L
.692 .30083 L
.696 .30191 L
.7 .30104 L
.704 .29881 L
.708 .29653 L
.712 .29554 L
.716 .29638 L
.72 .29849 L
.724 .3005 L
.728 .30116 L
.732 .30011 L
.736 .29808 L
.74 .29637 L
.744 .29593 L
.748 .29686 L
.752 .29846 L
.756 .29979 L
.76 .30023 L
.764 .29971 L
.768 .29859 L
.772 .29748 L
.776 .29695 L
.78 .29724 L
.784 .29818 L
.788 .29917 L
.792 .29953 L
.796 .29907 L
.8 .29816 L
Mistroke
.804 .29751 L
.808 .29757 L
.812 .29814 L
.816 .29863 L
.82 .29864 L
.824 .29827 L
.828 .29803 L
.832 .29821 L
.836 .29861 L
.84 .29878 L
.844 .29849 L
.848 .29807 L
.852 .29795 L
.856 .2982 L
.86 .29848 L
.864 .29831 L
.868 .29778 L
.872 .29749 L
.876 .29788 L
.88 .29882 L
.884 .29949 L
.888 .29915 L
.892 .29808 L
.896 .29717 L
.9 .29724 L
.904 .29828 L
.908 .29918 L
.912 .29898 L
.916 .29785 L
.92 .29673 L
.924 .29686 L
.928 .29842 L
.932 .29997 L
.936 .3003 L
.94 .29909 L
.944 .29703 L
.948 .29602 L
.952 .2967 L
.956 .2981 L
.96 .29936 L
.964 .29937 L
.968 .2982 L
.972 .29761 L
.976 .29786 L
.98 .29844 L
.984 .29916 L
.988 .2986 L
.992 .29715 L
.996 .29676 L
1 .29715 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .43443 m
.008 .43971 L
.012 .44524 L
.016 .45094 L
.02 .45635 L
.024 .46169 L
.028 .46754 L
.032 .47355 L
.036 .4789 L
.04 .48364 L
.044 .48895 L
.048 .49495 L
.052 .50141 L
.056 .50786 L
.06 .51324 L
.064 .5172 L
.068 .51977 L
.072 .52106 L
.076 .52155 L
.08 .52139 L
.084 .52089 L
.088 .52011 L
.092 .51916 L
.096 .51803 L
.1 .51676 L
.104 .51534 L
.108 .51377 L
.112 .51204 L
.116 .51017 L
.12 .50815 L
.124 .50601 L
.128 .50374 L
.132 .50138 L
.136 .49894 L
.14 .49648 L
.144 .494 L
.148 .49155 L
.152 .48914 L
.156 .48682 L
.16 .4846 L
.164 .48247 L
.168 .48045 L
.172 .47851 L
.176 .47663 L
.18 .47479 L
.184 .47296 L
.188 .4711 L
.192 .4692 L
.196 .46723 L
.2 .46518 L
Mistroke
.204 .46308 L
.208 .46094 L
.212 .45879 L
.216 .45668 L
.22 .45466 L
.224 .45276 L
.228 .45102 L
.232 .44947 L
.236 .44811 L
.24 .44695 L
.244 .44596 L
.248 .44512 L
.252 .44441 L
.256 .4438 L
.26 .44327 L
.264 .44283 L
.268 .44247 L
.272 .44223 L
.276 .44212 L
.28 .44218 L
.284 .44241 L
.288 .44282 L
.292 .44338 L
.296 .44405 L
.3 .44478 L
.304 .44549 L
.308 .4461 L
.312 .44656 L
.316 .44683 L
.32 .44689 L
.324 .44676 L
.328 .44646 L
.332 .44607 L
.336 .44563 L
.34 .44523 L
.344 .44489 L
.348 .44467 L
.352 .44458 L
.356 .4446 L
.36 .44472 L
.364 .4449 L
.368 .44513 L
.372 .44537 L
.376 .4456 L
.38 .44581 L
.384 .44597 L
.388 .44607 L
.392 .44611 L
.396 .44609 L
.4 .446 L
Mistroke
.404 .44587 L
.408 .44573 L
.412 .4456 L
.416 .44552 L
.42 .44552 L
.424 .44561 L
.428 .44577 L
.432 .44599 L
.436 .4462 L
.44 .44637 L
.444 .44645 L
.448 .44644 L
.452 .44633 L
.456 .44618 L
.46 .44602 L
.464 .4459 L
.468 .44586 L
.472 .44592 L
.476 .44605 L
.48 .44622 L
.484 .4464 L
.488 .44654 L
.492 .44662 L
.496 .44664 L
.5 .44661 L
.504 .44656 L
.508 .44651 L
.512 .44649 L
.516 .4465 L
.52 .44654 L
.524 .44659 L
.528 .44665 L
.532 .44669 L
.536 .44671 L
.54 .44673 L
.544 .44674 L
.548 .44675 L
.552 .44678 L
.556 .44681 L
.56 .44686 L
.564 .44691 L
.568 .44697 L
.572 .44703 L
.576 .44707 L
.58 .4471 L
.584 .44711 L
.588 .44711 L
.592 .4471 L
.596 .44709 L
.6 .44711 L
Mistroke
.604 .44714 L
.608 .44719 L
.612 .44724 L
.616 .44729 L
.62 .44732 L
.624 .44734 L
.628 .44735 L
.632 .44737 L
.636 .44741 L
.64 .44747 L
.644 .44753 L
.648 .44759 L
.652 .44762 L
.656 .44762 L
.66 .44759 L
.664 .44755 L
.668 .44754 L
.672 .44758 L
.676 .44764 L
.68 .44774 L
.684 .44782 L
.688 .44788 L
.692 .4479 L
.696 .44789 L
.7 .44788 L
.704 .44787 L
.708 .44789 L
.712 .44794 L
.716 .44799 L
.72 .44804 L
.724 .44807 L
.728 .44808 L
.732 .44809 L
.736 .44811 L
.74 .44814 L
.744 .44819 L
.748 .44823 L
.752 .44827 L
.756 .4483 L
.76 .44832 L
.764 .44833 L
.768 .44835 L
.772 .44838 L
.776 .44842 L
.78 .44845 L
.784 .44849 L
.788 .44851 L
.792 .44853 L
.796 .44854 L
.8 .44857 L
Mistroke
.804 .44861 L
.808 .44865 L
.812 .44868 L
.816 .44872 L
.82 .44874 L
.824 .44877 L
.828 .44879 L
.832 .44881 L
.836 .44884 L
.84 .44887 L
.844 .4489 L
.848 .44892 L
.852 .44894 L
.856 .44897 L
.86 .449 L
.864 .44904 L
.868 .44908 L
.872 .44913 L
.876 .44916 L
.88 .44918 L
.884 .44918 L
.888 .44919 L
.892 .44921 L
.896 .44924 L
.9 .44928 L
.904 .44933 L
.908 .44936 L
.912 .4494 L
.916 .44942 L
.92 .44946 L
.924 .44948 L
.928 .44951 L
.932 .44952 L
.936 .44954 L
.94 .44955 L
.944 .44959 L
.948 .44962 L
.952 .44967 L
.956 .4497 L
.96 .44974 L
.964 .44976 L
.968 .44981 L
.972 .44982 L
.976 .44985 L
.98 .44985 L
.984 .44987 L
.988 .44987 L
.992 .44992 L
.996 .44995 L
1 .45003 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32057 m
.008 .32434 L
.012 .33753 L
.016 .34749 L
.02 .35408 L
.024 .36211 L
.028 .37154 L
.032 .38041 L
.036 .38842 L
.04 .39633 L
.044 .40445 L
.048 .41372 L
.052 .42393 L
.056 .43386 L
.06 .44284 L
.064 .45019 L
.068 .45582 L
.072 .46021 L
.076 .46358 L
.08 .46646 L
.084 .46899 L
.088 .47143 L
.092 .47381 L
.096 .47625 L
.1 .47872 L
.104 .48129 L
.108 .48393 L
.112 .48669 L
.116 .48954 L
.12 .49252 L
.124 .49559 L
.128 .49876 L
.132 .50199 L
.136 .50527 L
.14 .50856 L
.144 .51182 L
.148 .51502 L
.152 .51813 L
.156 .52111 L
.16 .52397 L
.164 .52668 L
.168 .52925 L
.172 .53171 L
.176 .53407 L
.18 .53638 L
.184 .53868 L
.188 .541 L
.192 .54339 L
.196 .54585 L
.2 .54839 L
Mistroke
.204 .55101 L
.208 .55367 L
.212 .55634 L
.216 .55896 L
.22 .56148 L
.224 .56385 L
.228 .56601 L
.232 .56794 L
.236 .56962 L
.24 .57106 L
.244 .57229 L
.248 .57333 L
.252 .57421 L
.256 .57496 L
.26 .57561 L
.264 .57616 L
.268 .5766 L
.272 .5769 L
.276 .57702 L
.28 .57695 L
.284 .57665 L
.288 .57614 L
.292 .57543 L
.296 .57459 L
.3 .57368 L
.304 .57279 L
.308 .57202 L
.312 .57143 L
.316 .57108 L
.32 .571 L
.324 .57117 L
.328 .57153 L
.332 .57201 L
.336 .57255 L
.34 .57304 L
.344 .57345 L
.348 .57371 L
.352 .57383 L
.356 .5738 L
.36 .57365 L
.364 .57341 L
.368 .57312 L
.372 .57281 L
.376 .57251 L
.38 .57225 L
.384 .57204 L
.388 .5719 L
.392 .57184 L
.396 .57187 L
.4 .57197 L
Mistroke
.404 .57213 L
.408 .5723 L
.412 .57245 L
.416 .57254 L
.42 .57253 L
.424 .57241 L
.428 .5722 L
.432 .57194 L
.436 .57167 L
.44 .57145 L
.444 .57133 L
.448 .57134 L
.452 .57146 L
.456 .57164 L
.46 .57184 L
.464 .57198 L
.468 .57202 L
.472 .57195 L
.476 .57178 L
.48 .57155 L
.484 .57132 L
.488 .57113 L
.492 .57102 L
.496 .57099 L
.5 .57103 L
.504 .57108 L
.508 .57114 L
.512 .57116 L
.516 .57114 L
.52 .57108 L
.524 .57101 L
.528 .57093 L
.532 .57087 L
.536 .57083 L
.54 .57081 L
.544 .57079 L
.548 .57076 L
.552 .57073 L
.556 .57068 L
.56 .57061 L
.564 .57053 L
.568 .57045 L
.572 .57037 L
.576 .57031 L
.58 .57027 L
.584 .57026 L
.588 .57025 L
.592 .57026 L
.596 .57025 L
.6 .57022 L
Mistroke
.604 .57017 L
.608 .5701 L
.612 .57003 L
.616 .56996 L
.62 .56992 L
.624 .56989 L
.628 .56987 L
.632 .56984 L
.636 .56978 L
.64 .5697 L
.644 .56961 L
.648 .56953 L
.652 .56948 L
.656 .56948 L
.66 .56951 L
.664 .56955 L
.668 .56955 L
.672 .56951 L
.676 .56942 L
.68 .56929 L
.684 .56917 L
.688 .56909 L
.692 .56905 L
.696 .56906 L
.7 .56908 L
.704 .56908 L
.708 .56905 L
.712 .56898 L
.716 .5689 L
.72 .56883 L
.724 .56878 L
.728 .56875 L
.732 .56873 L
.736 .56871 L
.74 .56867 L
.744 .56862 L
.748 .56855 L
.752 .56849 L
.756 .56844 L
.76 .56841 L
.764 .56837 L
.768 .56834 L
.772 .56829 L
.776 .56824 L
.78 .5682 L
.784 .56816 L
.788 .56813 L
.792 .5681 L
.796 .56806 L
.8 .56802 L
Mistroke
.804 .56795 L
.808 .56789 L
.812 .56782 L
.816 .56778 L
.82 .56775 L
.824 .56773 L
.828 .56771 L
.832 .56768 L
.836 .56763 L
.84 .56757 L
.844 .56751 L
.848 .56746 L
.852 .56741 L
.856 .56737 L
.86 .56733 L
.864 .5673 L
.868 .56726 L
.872 .56722 L
.876 .56718 L
.88 .56713 L
.884 .56708 L
.888 .56703 L
.892 .56698 L
.896 .56693 L
.9 .56689 L
.904 .56687 L
.908 .56683 L
.912 .5668 L
.916 .56675 L
.92 .56671 L
.924 .56664 L
.928 .56659 L
.932 .56652 L
.936 .56649 L
.94 .56645 L
.944 .56644 L
.948 .5664 L
.952 .56637 L
.956 .56631 L
.96 .56627 L
.964 .5662 L
.968 .56617 L
.972 .56611 L
.976 .56608 L
.98 .56601 L
.984 .56598 L
.988 .56591 L
.992 .56591 L
.996 .56586 L
1 .56586 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Aoo`04001oogoo0004Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogooOol40003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:
Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`0017oo100017oo00@0
07ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D007oo
Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006Ool01000
Oomoo`001Goo000ROol2000<Ool50003Ool20004Ool01@00Ool007oo00001Goo0P0017oo0P001Woo
00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`00
8Woo00<007ooOol06Goo00@007ooOol000Aoo`03001oogoo00=oo`8000=oo`03001oogoo03eoo`00
8Woo0P006Goo00D007ooOomoo`0000=oo`@0009oo`03001oo`00009oo`<00005Ool00000001oo`03
0002Ool6000017oo000007oo0P0000Aoo`00001oo`/00003Ool0000000X000aoo`008WooH`0037oo
000ROol01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Ool0
00000goo0P0000=oo`0000000goo0P000Woo0`0000=oo`00Ool00Woo00D007ooOomoo`0000=oo`04
001oogoo0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00<007ooOol02Woo000ROol2000GOol20005Ool2001=Ool0029oo`03001o
o`0000<001=oo`03001oogoo05=oo`008Woo0`0000Aoo`00Ool0015oo`03001oogoo05Aoo`008Woo
0P0017oo0P0047oo00<007ooOol0E7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool0
0`00Oomoo`04Ool2000?Ool00`00Oomoo`1DOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P001Woo00<007ooOol037oo00<007ooOol0EGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8000Ioo`8000eoo`03001oogoo05Eoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`06Ool2000<Ool00`00Oomoo`1E
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0027oo00<007ooOol0
17oo0P000goo00<007ooOol0EWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`80
00Qoo`03001oogoo00Aoo`03001oo`00009oo`03001oogoo05Ioo`002goo0P002Woo0P0017oo00<0
07ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00@007ooOomoo`<005Qoo`002goo0P0017oo
00<007ooOol00goo0P000Woo1@000Woo0P002Goo00<007ooOol00Woo00<007ooOol0G7oo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2000:Ool01000Oomoo`00Ggoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00Uoo`@005moo`00
2Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P002goo0P00H7oo000:Ool01000
Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool0
1P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`00
8Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool0
00Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`80
00=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo
00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@0
07ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003
Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo
0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004
Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool3
0003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001o
ogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol0
0goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0
3Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo
00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yo
o`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo
00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo
0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
o`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo
0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001o
ogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo0000
1Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P00
17oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=o
o`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<0
07ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<0
07ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P00
17oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06
001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001o
ogoo001oo`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0006Ool2000EOol50004Ool20017Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009o
o`<0015oo`@000Aood4000aoo`00:7oo00<007oo00003goo0`00E7oo000XOol01000Oomoo`0037oo
0`00EWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`020009Ool3001H
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00D007ooOomoo`0000Qo
o`8005Yoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool2001LOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P0017oo1@00GWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo05moo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool0
0`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomo
o`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool0
0`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`00
1goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;
Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Ao
o`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Ao
o`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007oo
Ool00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003
Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<0
07ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000
Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo
0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2
000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol0
37oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo
0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@00
0goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Ao
o`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomo
o`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001d
Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00
Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`8007=oo`0077oo0P00Lgoo000LOol3001bOol0
01aoo`04001oogoo001aOol001aoo`800003Ool007oo071oo`0077oo00D007ooOomoo`00071oo`00
77oo00D007ooOomoo`00071oo`0077oo0P000Woo0P00Kgoo000FOol30003Ool00`00Oomoo`02Ool0
0`00Oomoo`1]Ool001Moo`03001oogoo009oo`03001oogoo00=oo`03001oogoo06aoo`005goo00<0
07ooOol00Woo0P0017oo00<007ooOol0K7oo000GOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`1/Ool001Moo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo06]oo`005Woo0P0017oo
0P001Goo0P00K7oo000GOol00`00Oomoo`02Ool00`00Oomoo`05Ool2001[Ool001aoo`03001oogoo
00Moo`8006Uoo`0077oo0P002Goo0P00J7oo000LOol00`00Oomoo`0:Ool2001VOol001aoo`8000ao
o`8006Eoo`0077oo00<007ooOol037oo0P00I7oo000LOol00`00Oomoo`0>Ool2001ROol000Yoo`<0
00Aoo`03001oogoo009oo`<000=oo`80011oo`80065oo`002goo00<007ooOol01goo00D007ooOomo
o`00009oo`03001oogoo015oo`8005moo`002goo00<007ooOol02goo00@007ooOol001Aoo`<005eo
o`002goo00<007ooOol02goo00<007ooOol00P005Goo0`00:7oo9`0037oo000;Ool00`00Oomoo`07
Ool40003Ool00`00Oomoo`0FOolY000cOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079o
o`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo
079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(36907\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .34604 m
.008 .3463 L
.012 .34561 L
.016 .34653 L
.02 .34887 L
.024 .35059 L
.028 .35199 L
.032 .35518 L
.036 .35981 L
.04 .36338 L
.044 .36584 L
.048 .36937 L
.052 .37466 L
.056 .3813 L
.06 .38834 L
.064 .3939 L
.068 .39809 L
.072 .40271 L
.076 .40871 L
.08 .41695 L
.084 .42706 L
.088 .43786 L
.092 .44839 L
.096 .45756 L
.1 .46482 L
.104 .46979 L
.108 .47231 L
.112 .47236 L
.116 .47003 L
.12 .46552 L
.124 .45917 L
.128 .45143 L
.132 .44287 L
.136 .43414 L
.14 .42594 L
.144 .41894 L
.148 .41371 L
.152 .41066 L
.156 .40996 L
.16 .41151 L
.164 .41495 L
.168 .41964 L
.172 .42475 L
.176 .42934 L
.18 .43247 L
.184 .43336 L
.188 .43143 L
.192 .42644 L
.196 .41851 L
.2 .4081 L
Mistroke
.204 .39596 L
.208 .38305 L
.212 .37036 L
.216 .35879 L
.22 .34896 L
.224 .34107 L
.228 .33493 L
.232 .32995 L
.236 .32534 L
.24 .3202 L
.244 .3138 L
.248 .30571 L
.252 .296 L
.256 .28522 L
.26 .27442 L
.264 .26494 L
.268 .25821 L
.272 .25543 L
.276 .25727 L
.28 .26372 L
.284 .27403 L
.288 .28683 L
.292 .3003 L
.296 .31249 L
.3 .32175 L
.304 .32693 L
.308 .32769 L
.312 .32444 L
.316 .31825 L
.32 .31057 L
.324 .30286 L
.328 .29628 L
.332 .29151 L
.336 .2887 L
.34 .28761 L
.344 .28776 L
.348 .28867 L
.352 .29003 L
.356 .29178 L
.36 .29406 L
.364 .297 L
.368 .3006 L
.372 .30451 L
.376 .30805 L
.38 .31028 L
.384 .31033 L
.388 .30774 L
.392 .30276 L
.396 .29638 L
.4 .29016 L
Mistroke
.404 .28582 L
.408 .28469 L
.412 .28732 L
.416 .29317 L
.42 .30071 L
.424 .30783 L
.428 .31248 L
.432 .31327 L
.436 .30998 L
.44 .3036 L
.444 .29608 L
.448 .28972 L
.452 .2864 L
.456 .28695 L
.46 .29091 L
.464 .29675 L
.468 .30246 L
.472 .30625 L
.476 .30714 L
.48 .3052 L
.484 .30147 L
.488 .29748 L
.492 .29464 L
.496 .29373 L
.5 .29472 L
.504 .29695 L
.508 .29944 L
.512 .30132 L
.516 .30206 L
.52 .3016 L
.524 .30031 L
.528 .29872 L
.532 .2973 L
.536 .29629 L
.54 .29581 L
.544 .29592 L
.548 .29668 L
.552 .29801 L
.556 .29969 L
.56 .30127 L
.564 .30223 L
.568 .30213 L
.572 .30082 L
.576 .29861 L
.58 .29627 L
.584 .29477 L
.588 .29485 L
.592 .29657 L
.596 .29916 L
.6 .30142 L
Mistroke
.604 .30223 L
.608 .30119 L
.612 .29877 L
.616 .29618 L
.62 .29475 L
.624 .29531 L
.628 .29769 L
.632 .30075 L
.636 .30287 L
.64 .30286 L
.644 .30063 L
.648 .2973 L
.652 .29461 L
.656 .29393 L
.66 .29556 L
.664 .29857 L
.668 .30134 L
.672 .30245 L
.676 .3014 L
.68 .29887 L
.684 .29632 L
.688 .2952 L
.692 .29611 L
.696 .29845 L
.7 .30077 L
.704 .30163 L
.708 .30056 L
.712 .29825 L
.716 .29615 L
.72 .2955 L
.724 .29656 L
.728 .29858 L
.732 .30033 L
.736 .30087 L
.74 .30005 L
.744 .29846 L
.748 .29703 L
.752 .29655 L
.756 .29721 L
.76 .29857 L
.764 .29977 L
.768 .30004 L
.772 .29922 L
.776 .29789 L
.78 .29696 L
.784 .29705 L
.788 .29801 L
.792 .2991 L
.796 .29957 L
.8 .29922 L
Mistroke
.804 .29846 L
.808 .29783 L
.812 .29764 L
.816 .29784 L
.82 .29822 L
.824 .29865 L
.828 .29903 L
.832 .29915 L
.836 .2988 L
.84 .29796 L
.844 .29712 L
.848 .29697 L
.852 .2978 L
.856 .29913 L
.86 .29998 L
.864 .29964 L
.868 .29842 L
.872 .29726 L
.876 .29703 L
.88 .29781 L
.884 .29873 L
.888 .29897 L
.892 .29848 L
.896 .2978 L
.9 .2977 L
.904 .29829 L
.908 .29886 L
.912 .29893 L
.916 .29847 L
.92 .29787 L
.924 .29785 L
.928 .29827 L
.932 .29846 L
.936 .29829 L
.94 .29774 L
.944 .29734 L
.948 .29789 L
.952 .29879 L
.956 .29931 L
.96 .2993 L
.964 .29839 L
.968 .29743 L
.972 .29745 L
.976 .29771 L
.98 .29806 L
.984 .29835 L
.988 .29787 L
.992 .29773 L
.996 .29851 L
1 .29908 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .39621 m
.008 .39494 L
.012 .39809 L
.016 .40558 L
.02 .41155 L
.024 .41594 L
.028 .42098 L
.032 .4266 L
.036 .43174 L
.04 .43638 L
.044 .44139 L
.048 .44685 L
.052 .45221 L
.056 .45715 L
.06 .4615 L
.064 .46549 L
.068 .47002 L
.072 .47523 L
.076 .48087 L
.08 .48644 L
.084 .49115 L
.088 .49464 L
.092 .49675 L
.096 .49756 L
.1 .49738 L
.104 .49642 L
.108 .49497 L
.112 .49319 L
.116 .49125 L
.12 .48921 L
.124 .48715 L
.128 .48511 L
.132 .48313 L
.136 .48121 L
.14 .47937 L
.144 .47758 L
.148 .47586 L
.152 .47416 L
.156 .47246 L
.16 .47072 L
.164 .46894 L
.168 .46708 L
.172 .46514 L
.176 .46313 L
.18 .46106 L
.184 .45897 L
.188 .45689 L
.192 .45486 L
.196 .45294 L
.2 .45116 L
Mistroke
.204 .44956 L
.208 .44814 L
.212 .44693 L
.216 .44589 L
.22 .44502 L
.224 .44429 L
.228 .44367 L
.232 .44313 L
.236 .44268 L
.24 .44231 L
.244 .44205 L
.248 .4419 L
.252 .4419 L
.256 .44207 L
.26 .4424 L
.264 .4429 L
.268 .44352 L
.272 .44423 L
.276 .44494 L
.28 .4456 L
.284 .44613 L
.288 .44648 L
.292 .44664 L
.296 .44658 L
.3 .44635 L
.304 .44598 L
.308 .44555 L
.312 .44512 L
.316 .44475 L
.32 .44448 L
.324 .44432 L
.328 .4443 L
.332 .44438 L
.336 .44454 L
.34 .44476 L
.344 .44501 L
.348 .44525 L
.352 .44547 L
.356 .44565 L
.36 .44577 L
.364 .44584 L
.368 .44584 L
.372 .44578 L
.376 .44567 L
.38 .44553 L
.384 .4454 L
.388 .4453 L
.392 .44526 L
.396 .4453 L
.4 .44542 L
Mistroke
.404 .44561 L
.408 .44582 L
.412 .44601 L
.416 .44614 L
.42 .44619 L
.424 .44614 L
.428 .44601 L
.432 .44585 L
.436 .4457 L
.44 .44561 L
.444 .44561 L
.448 .4457 L
.452 .44585 L
.456 .44604 L
.46 .44621 L
.464 .44633 L
.468 .44639 L
.472 .44638 L
.476 .44634 L
.48 .44628 L
.484 .44623 L
.488 .44622 L
.492 .44624 L
.496 .44629 L
.5 .44635 L
.504 .4464 L
.508 .44644 L
.512 .44646 L
.516 .44648 L
.52 .44649 L
.524 .4465 L
.528 .44653 L
.532 .44657 L
.536 .44662 L
.54 .44668 L
.544 .44674 L
.548 .44678 L
.552 .44682 L
.556 .44684 L
.56 .44684 L
.564 .44684 L
.568 .44683 L
.572 .44684 L
.576 .44686 L
.58 .4469 L
.584 .44695 L
.588 .447 L
.592 .44704 L
.596 .44707 L
.6 .44709 L
Mistroke
.604 .4471 L
.608 .44713 L
.612 .44717 L
.616 .44723 L
.62 .44729 L
.624 .44734 L
.628 .44736 L
.632 .44735 L
.636 .44732 L
.64 .44729 L
.644 .44729 L
.648 .44733 L
.652 .44741 L
.656 .4475 L
.66 .44758 L
.664 .44764 L
.668 .44765 L
.672 .44763 L
.676 .44761 L
.68 .44761 L
.684 .44763 L
.688 .44768 L
.692 .44774 L
.696 .4478 L
.7 .44783 L
.704 .44784 L
.708 .44784 L
.712 .44786 L
.716 .44788 L
.72 .44793 L
.724 .44798 L
.728 .44802 L
.732 .44805 L
.736 .44807 L
.74 .44809 L
.744 .4481 L
.748 .44813 L
.752 .44816 L
.756 .44819 L
.76 .44823 L
.764 .44825 L
.768 .44827 L
.772 .4483 L
.776 .44833 L
.78 .44837 L
.784 .44841 L
.788 .44844 L
.792 .44847 L
.796 .44849 L
.8 .44851 L
Mistroke
.804 .44853 L
.808 .44855 L
.812 .44858 L
.816 .44862 L
.82 .44865 L
.824 .44868 L
.828 .44871 L
.832 .44873 L
.836 .44875 L
.84 .44878 L
.844 .44882 L
.848 .44886 L
.852 .44889 L
.856 .44892 L
.86 .44894 L
.864 .44896 L
.868 .44898 L
.872 .449 L
.876 .44903 L
.88 .44906 L
.884 .44909 L
.888 .44913 L
.892 .44916 L
.896 .44921 L
.9 .44924 L
.904 .44927 L
.908 .44928 L
.912 .44929 L
.916 .4493 L
.92 .44932 L
.924 .44935 L
.928 .4494 L
.932 .44944 L
.936 .44949 L
.94 .44953 L
.944 .44956 L
.948 .44957 L
.952 .44959 L
.956 .44959 L
.96 .44962 L
.964 .44963 L
.968 .44968 L
.972 .44971 L
.976 .44976 L
.98 .44978 L
.984 .44984 L
.988 .44985 L
.992 .4499 L
.996 .4499 L
1 .44994 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .2757 m
.008 .28364 L
.012 .29203 L
.016 .30058 L
.02 .3089 L
.024 .31724 L
.028 .32586 L
.032 .33465 L
.036 .34328 L
.04 .35187 L
.044 .36066 L
.048 .37013 L
.052 .37997 L
.056 .38927 L
.06 .39787 L
.064 .40659 L
.068 .41591 L
.072 .42637 L
.076 .43775 L
.08 .44913 L
.084 .45985 L
.088 .4693 L
.092 .47729 L
.096 .484 L
.1 .48964 L
.104 .49458 L
.108 .49901 L
.112 .50315 L
.116 .50706 L
.12 .51082 L
.124 .5144 L
.128 .51783 L
.132 .52107 L
.136 .52414 L
.14 .52703 L
.144 .52976 L
.148 .53236 L
.152 .53487 L
.156 .53733 L
.16 .53977 L
.164 .54223 L
.168 .54475 L
.172 .54734 L
.176 .54999 L
.18 .55268 L
.184 .55539 L
.188 .55806 L
.192 .56065 L
.196 .5631 L
.2 .56535 L
Mistroke
.204 .56738 L
.208 .56916 L
.212 .5707 L
.216 .57201 L
.22 .57311 L
.224 .57403 L
.228 .57481 L
.232 .57547 L
.236 .57603 L
.24 .57649 L
.244 .57682 L
.248 .577 L
.252 .577 L
.256 .57679 L
.26 .57637 L
.264 .57574 L
.268 .57496 L
.272 .57408 L
.276 .57318 L
.28 .57235 L
.284 .57168 L
.288 .57124 L
.292 .57104 L
.296 .5711 L
.3 .57138 L
.304 .57183 L
.308 .57235 L
.312 .57288 L
.316 .57334 L
.32 .57368 L
.324 .57387 L
.328 .57389 L
.332 .57378 L
.336 .57356 L
.34 .57328 L
.344 .57297 L
.348 .57266 L
.352 .57239 L
.356 .57216 L
.36 .572 L
.364 .57191 L
.368 .5719 L
.372 .57196 L
.376 .57209 L
.38 .57225 L
.384 .57241 L
.388 .57254 L
.392 .57258 L
.396 .57252 L
.4 .57236 L
Mistroke
.404 .57212 L
.408 .57185 L
.412 .5716 L
.416 .57143 L
.42 .57137 L
.424 .57143 L
.428 .57158 L
.432 .57177 L
.436 .57194 L
.44 .57204 L
.444 .57204 L
.448 .57192 L
.452 .57172 L
.456 .57149 L
.46 .57127 L
.464 .57111 L
.468 .57103 L
.472 .57102 L
.476 .57107 L
.48 .57114 L
.484 .57119 L
.488 .5712 L
.492 .57117 L
.496 .5711 L
.5 .57102 L
.504 .57095 L
.508 .57089 L
.512 .57085 L
.516 .57083 L
.52 .57081 L
.524 .57078 L
.528 .57074 L
.532 .57069 L
.536 .57061 L
.54 .57053 L
.544 .57045 L
.548 .57039 L
.552 .57033 L
.556 .5703 L
.56 .57029 L
.564 .57029 L
.568 .57029 L
.572 .57028 L
.576 .57025 L
.58 .57019 L
.584 .57012 L
.588 .57004 L
.592 .56998 L
.596 .56994 L
.6 .56991 L
Mistroke
.604 .56988 L
.608 .56985 L
.612 .56979 L
.616 .56971 L
.62 .56962 L
.624 .56955 L
.628 .56952 L
.632 .56952 L
.636 .56955 L
.64 .56958 L
.644 .56957 L
.648 .56952 L
.652 .56941 L
.656 .56929 L
.66 .56918 L
.664 .56911 L
.668 .56908 L
.672 .56909 L
.676 .56911 L
.68 .5691 L
.684 .56907 L
.688 .569 L
.692 .56892 L
.696 .56885 L
.7 .56881 L
.704 .56878 L
.708 .56876 L
.712 .56873 L
.716 .56868 L
.72 .56863 L
.724 .56856 L
.728 .56851 L
.732 .56847 L
.736 .56844 L
.74 .56841 L
.744 .56837 L
.748 .56832 L
.752 .56827 L
.756 .56822 L
.76 .56818 L
.764 .56815 L
.768 .56812 L
.772 .56809 L
.776 .56804 L
.78 .56798 L
.784 .56791 L
.788 .56785 L
.792 .5678 L
.796 .56777 L
.8 .56775 L
Mistroke
.804 .56772 L
.808 .56769 L
.812 .56765 L
.816 .5676 L
.82 .56754 L
.824 .56749 L
.828 .56745 L
.832 .5674 L
.836 .56735 L
.84 .56731 L
.844 .56726 L
.848 .56722 L
.852 .56719 L
.856 .56716 L
.86 .56712 L
.864 .56708 L
.868 .56703 L
.872 .56698 L
.876 .56692 L
.88 .56687 L
.884 .56682 L
.888 .5668 L
.892 .56676 L
.896 .56673 L
.9 .56668 L
.904 .56663 L
.908 .56657 L
.912 .56653 L
.916 .56648 L
.92 .56645 L
.924 .56641 L
.928 .56638 L
.932 .56633 L
.936 .56629 L
.94 .56624 L
.944 .5662 L
.948 .56615 L
.952 .5661 L
.956 .56604 L
.96 .56601 L
.964 .56596 L
.968 .56594 L
.972 .56589 L
.976 .56586 L
.98 .5658 L
.984 .56577 L
.988 .5657 L
.992 .56569 L
.996 .56563 L
1 .56561 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005
Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`05001oogoo001o
o`020003Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04
001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomo
ogoo001oo`0000Ioo`04001oogoo0005Ool0029oo`8000aoo`D000=oo`800005Ool007ooOol00003
Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo
0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`0FOol01000Oomoo`0017oo0P001Goo
00@007ooOomoo`80045oo`008Woo0P005goo00@007ooOol000=oo`D0009oo`04001oo`00Ool30002
Ool20002Ool300001Goo00000000Ool00P0000Eoo`00000007oo00800004Ool00000Ool200000goo
00000003000017oo000007oo200000=oo`0000000P003Goo000ROomS000<Ool0029oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`08001oogoo001oo`00Ool000=o
o`03001oo`000080009oo`8000=oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol0000<Ool0029oo`8001Eoo`8000Aoo`<004moo`008Woo00<007ooOol04goo0P00Egoo
000ROol3000COol00`00Oomoo`1FOol0029oo`D0011oo`03001oogoo05Moo`002goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo00@007ooOomoo`8000moo`03001oogoo05Moo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`0=Ool00`00Oomoo`1G
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0017oo00<007ooOol0
2goo00<007ooOol0F7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo00=oo`8000aoo`03001oogoo05Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool20005Ool20006Ool20003Ool00`00Oomoo`1HOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo0P0017oo0P001Woo00<007ooOol00goo100000=oo`00Ool0FWoo000;Ool2000:
Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03001KOol0
00]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8000Moo`05001oogooOol00004Ool00`00
Oomoo`1JOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8000Moo`05
001oogooOol0001QOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol01goo00<007oo0000HWoo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogoo
Ool20008Ool3001ROol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo0080
06eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P00
2Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007oo
Ool00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@0
07ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001o
ogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo
0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo
00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001W
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03
001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]o
o`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009o
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`80
00Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0
009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool0
10000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007oo
Oomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007oo
Ool0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`00
0Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<0
07ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol0
2Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo
0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003
Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo
0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00
Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;
Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool00`00Oomoo`02001WOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`00IWoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`04001UOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`04001oogoo001UOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool01@00Oomoogoo000047oo
1@000goo0`00BGoo000;Ool2000:Ool20004Ool20002Ool50002Ool01000Oomoogoo0P0037oo0`00
17oo1@0000=oo`000000?00037oo000XOol00`00Oomoo`02Ool20009Ool2001GOol002Qoo`03001o
ogoo00=oo`8000Ioo`8005Uoo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007oo
Ool017oo00@007ooOomoo`<005]oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`05Ool4001MOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:
Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo0000
0goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool0
0`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<0
07ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004
Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool0
0`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo0000
0Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool0
1000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007oo
Ool0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool3
0004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05
001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001o
ogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol0
00Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomo
ogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001o
ogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomo
ogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=o
o`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool5
0003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001ao
o`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`8007=oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool2001cOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol0
00Yoo`04001oogoo000;Ool01P00Oomoo`00Ool0079oo`002Woo00@007ooOol000Moo`@000=oo`04
001oo`00001aOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool200000goo001oo`1`Ool000]o
o`8000Qoo`D0009oo`05001oogooOol0001`Ool001aoo`05001oogooOol0001`Ool001aoo`80009o
o`03001oogoo06ioo`0077oo00<007ooOol00Woo00<007ooOol0KGoo000LOol20003Ool00`00Oomo
o`1]Ool001aoo`03001oogoo00=oo`03001oogoo06aoo`0077oo00<007ooOol00goo00<007ooOol0
K7oo000LOol20004Ool00`00Oomoo`1/Ool001Ioo`<000=oo`03001oogoo00Aoo`03001oogoo06]o
o`005goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0Jgoo000GOol00`00Oomoo`02Ool2
0006Ool00`00Oomoo`1ZOol001Moo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo06Yoo`00
5goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0JWoo000FOol20004Ool20007Ool00`00
Oomoo`1YOol001Moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo06Uoo`0077oo00<007oo
Ool01goo00<007ooOol0J7oo000LOol20008Ool2001YOol001aoo`03001oogoo00Qoo`03001oogoo
06Moo`0077oo0P002Woo0P00Igoo000LOol00`00Oomoo`0:Ool2001VOol001aoo`03001oogoo00]o
o`8006Eoo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P003Woo0P00Hgoo000;Ool00`00Oomo
o`07Ool01@00Oomoogoo00000Woo00<007ooOol03Woo0P00HWoo000;Ool00`00Oomoo`0;Ool01000
Oomoo`004Woo0P00H7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02000BOol3000XOolZ000<Ool0
00]oo`03001oogoo00Moo`@000=oo`03001oogoo01=oobX003Eoo`002Woo0P002Goo00<007ooOol0
17oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(37074\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .37381 m
.008 .3735 L
.012 .37345 L
.016 .37571 L
.02 .38039 L
.024 .38416 L
.028 .38706 L
.032 .39196 L
.036 .39893 L
.04 .40549 L
.044 .41134 L
.048 .41835 L
.052 .42703 L
.056 .43636 L
.06 .44504 L
.064 .45159 L
.068 .45641 L
.072 .46157 L
.076 .46716 L
.08 .47143 L
.084 .47276 L
.088 .46964 L
.092 .46242 L
.096 .45303 L
.1 .4431 L
.104 .43421 L
.108 .42698 L
.112 .42137 L
.116 .41734 L
.12 .41467 L
.124 .41345 L
.128 .41372 L
.132 .41558 L
.136 .41889 L
.14 .42331 L
.144 .42824 L
.148 .4329 L
.152 .4364 L
.156 .43792 L
.16 .43681 L
.164 .43268 L
.168 .42549 L
.172 .41559 L
.176 .4036 L
.18 .39043 L
.184 .37708 L
.188 .36449 L
.192 .35342 L
.196 .34426 L
.2 .33703 L
Mistroke
.204 .33133 L
.208 .32647 L
.212 .32159 L
.216 .31586 L
.22 .30868 L
.224 .29982 L
.228 .28958 L
.232 .27879 L
.236 .26867 L
.24 .26064 L
.244 .25603 L
.248 .25577 L
.252 .26021 L
.256 .26896 L
.26 .28093 L
.264 .29446 L
.268 .30765 L
.272 .31864 L
.276 .32599 L
.28 .3289 L
.284 .32741 L
.288 .32228 L
.292 .31481 L
.296 .30652 L
.3 .29883 L
.304 .29277 L
.308 .28884 L
.312 .28703 L
.316 .28691 L
.32 .28792 L
.324 .28952 L
.328 .29142 L
.332 .29356 L
.336 .29611 L
.34 .29921 L
.344 .30277 L
.348 .30635 L
.352 .30918 L
.356 .31035 L
.36 .30921 L
.364 .30557 L
.368 .29998 L
.372 .29364 L
.376 .28817 L
.38 .28514 L
.384 .28557 L
.388 .28958 L
.392 .29626 L
.396 .30385 L
.4 .31021 L
Mistroke
.404 .31348 L
.408 .31263 L
.412 .30793 L
.416 .30079 L
.42 .29338 L
.424 .28791 L
.428 .28593 L
.432 .28783 L
.436 .29276 L
.44 .29894 L
.444 .30433 L
.448 .30733 L
.452 .30727 L
.456 .30456 L
.46 .30041 L
.464 .2964 L
.468 .29387 L
.472 .29348 L
.476 .29505 L
.48 .29771 L
.484 .30035 L
.488 .30206 L
.492 .30242 L
.496 .30152 L
.5 .29985 L
.504 .29804 L
.508 .29663 L
.512 .2959 L
.516 .29587 L
.52 .29642 L
.524 .29745 L
.528 .29884 L
.532 .30037 L
.536 .30167 L
.54 .30225 L
.544 .30176 L
.548 .30021 L
.552 .298 L
.556 .29591 L
.56 .29479 L
.564 .29523 L
.568 .29714 L
.572 .29974 L
.576 .3018 L
.58 .3023 L
.584 .30093 L
.588 .29836 L
.592 .29589 L
.596 .29482 L
.6 .29577 L
Mistroke
.604 .29834 L
.608 .30128 L
.612 .30305 L
.616 .30265 L
.62 .30016 L
.624 .29682 L
.628 .29435 L
.632 .29405 L
.636 .29602 L
.64 .29917 L
.644 .3018 L
.648 .30258 L
.652 .30123 L
.656 .29861 L
.66 .29622 L
.664 .29537 L
.668 .29644 L
.672 .29873 L
.676 .30083 L
.68 .30148 L
.684 .30033 L
.688 .29813 L
.692 .29626 L
.696 .29581 L
.7 .29695 L
.704 .2989 L
.708 .30044 L
.712 .30075 L
.716 .2998 L
.72 .29828 L
.724 .29711 L
.728 .29689 L
.732 .29764 L
.736 .29883 L
.74 .29972 L
.744 .29977 L
.748 .299 L
.752 .29793 L
.756 .29728 L
.76 .29744 L
.764 .29823 L
.768 .29906 L
.772 .29938 L
.776 .29907 L
.78 .2985 L
.784 .2981 L
.788 .29807 L
.792 .29825 L
.796 .29841 L
.8 .29848 L
Mistroke
.804 .29853 L
.808 .2986 L
.812 .29858 L
.816 .29837 L
.82 .29808 L
.824 .29799 L
.828 .29827 L
.832 .29876 L
.836 .299 L
.84 .29873 L
.844 .29817 L
.848 .29783 L
.852 .29804 L
.856 .29864 L
.86 .29898 L
.864 .29868 L
.868 .29798 L
.872 .29746 L
.876 .29766 L
.88 .29845 L
.884 .29914 L
.888 .29928 L
.892 .29883 L
.896 .29815 L
.9 .29781 L
.904 .29781 L
.908 .29793 L
.912 .29814 L
.916 .29833 L
.92 .29853 L
.924 .29882 L
.928 .29869 L
.932 .29818 L
.936 .2978 L
.94 .29774 L
.944 .29832 L
.948 .29923 L
.952 .29927 L
.956 .29842 L
.96 .29729 L
.964 .29647 L
.968 .29709 L
.972 .29875 L
.976 .29983 L
.98 .29994 L
.984 .29897 L
.988 .29745 L
.992 .29702 L
.996 .29771 L
1 .29819 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .34478 m
.008 .34898 L
.012 .35373 L
.016 .35896 L
.02 .36413 L
.024 .36891 L
.028 .37361 L
.032 .37837 L
.036 .38295 L
.04 .38721 L
.044 .39156 L
.048 .39607 L
.052 .40047 L
.056 .40452 L
.06 .40825 L
.064 .41191 L
.068 .41597 L
.072 .42035 L
.076 .42443 L
.08 .42791 L
.084 .43091 L
.088 .43379 L
.092 .43727 L
.096 .44154 L
.1 .44646 L
.104 .4516 L
.108 .45635 L
.112 .4603 L
.116 .46321 L
.12 .46505 L
.124 .46596 L
.128 .46611 L
.132 .4657 L
.136 .46485 L
.14 .46371 L
.144 .46233 L
.148 .46079 L
.152 .4591 L
.156 .45733 L
.16 .45552 L
.164 .45372 L
.168 .45197 L
.172 .45033 L
.176 .44882 L
.18 .44749 L
.184 .44632 L
.188 .44534 L
.192 .4445 L
.196 .44381 L
.2 .44323 L
Mistroke
.204 .44274 L
.208 .44233 L
.212 .44199 L
.216 .44174 L
.22 .44158 L
.224 .44156 L
.228 .44168 L
.232 .44196 L
.236 .4424 L
.24 .44298 L
.244 .44366 L
.248 .44438 L
.252 .44506 L
.256 .44565 L
.26 .44609 L
.264 .44633 L
.268 .44636 L
.272 .4462 L
.276 .44589 L
.28 .44548 L
.284 .44504 L
.288 .44463 L
.292 .4443 L
.296 .44409 L
.3 .44401 L
.304 .44405 L
.308 .44419 L
.312 .4444 L
.316 .44465 L
.32 .4449 L
.324 .44513 L
.328 .44532 L
.332 .44546 L
.336 .44555 L
.34 .44558 L
.344 .44554 L
.348 .44546 L
.352 .44534 L
.356 .4452 L
.36 .44508 L
.364 .44501 L
.368 .44501 L
.372 .44509 L
.376 .44525 L
.38 .44544 L
.384 .44565 L
.388 .44581 L
.392 .44591 L
.396 .44591 L
.4 .44582 L
Mistroke
.404 .44568 L
.408 .44552 L
.412 .4454 L
.416 .44534 L
.42 .44538 L
.424 .4455 L
.428 .44567 L
.432 .44585 L
.436 .44601 L
.44 .44611 L
.444 .44614 L
.448 .44612 L
.452 .44606 L
.456 .446 L
.46 .44596 L
.464 .44596 L
.468 .44599 L
.472 .44604 L
.476 .44611 L
.48 .44616 L
.484 .4462 L
.488 .44622 L
.492 .44623 L
.496 .44624 L
.5 .44625 L
.504 .44629 L
.508 .44633 L
.512 .44639 L
.516 .44645 L
.52 .4465 L
.524 .44654 L
.528 .44657 L
.532 .44658 L
.536 .44658 L
.54 .44657 L
.544 .44657 L
.548 .44658 L
.552 .44661 L
.556 .44665 L
.56 .44671 L
.564 .44676 L
.568 .4468 L
.572 .44682 L
.576 .44684 L
.58 .44686 L
.584 .44689 L
.588 .44693 L
.592 .44698 L
.596 .44704 L
.6 .44708 L
Mistroke
.604 .44709 L
.608 .44708 L
.612 .44705 L
.616 .44703 L
.62 .44705 L
.624 .44709 L
.628 .44718 L
.632 .44727 L
.636 .44735 L
.64 .44739 L
.644 .44739 L
.648 .44738 L
.652 .44736 L
.656 .44735 L
.66 .44738 L
.664 .44743 L
.668 .44749 L
.672 .44755 L
.676 .44758 L
.68 .44759 L
.684 .4476 L
.688 .44761 L
.692 .44764 L
.696 .44768 L
.7 .44773 L
.704 .44777 L
.708 .4478 L
.712 .44782 L
.716 .44784 L
.72 .44786 L
.724 .44788 L
.728 .44792 L
.732 .44795 L
.736 .44797 L
.74 .448 L
.744 .44802 L
.748 .44804 L
.752 .44808 L
.756 .44812 L
.76 .44816 L
.764 .4482 L
.768 .44822 L
.772 .44824 L
.776 .44825 L
.78 .44827 L
.784 .44829 L
.788 .44833 L
.792 .44837 L
.796 .44841 L
.8 .44844 L
Mistroke
.804 .44846 L
.808 .44849 L
.812 .44851 L
.816 .44853 L
.82 .44857 L
.824 .4486 L
.828 .44863 L
.832 .44866 L
.836 .44868 L
.84 .44871 L
.844 .44873 L
.848 .44876 L
.852 .44879 L
.856 .44882 L
.86 .44884 L
.864 .44887 L
.868 .4489 L
.872 .44894 L
.876 .44898 L
.88 .44901 L
.884 .44904 L
.888 .44906 L
.892 .44907 L
.896 .44909 L
.9 .44911 L
.904 .44914 L
.908 .44917 L
.912 .44922 L
.916 .44926 L
.92 .44931 L
.924 .44933 L
.928 .44935 L
.932 .44936 L
.936 .44938 L
.94 .44939 L
.944 .44942 L
.948 .44944 L
.952 .44949 L
.956 .44953 L
.96 .44958 L
.964 .44961 L
.968 .44965 L
.972 .44965 L
.976 .44968 L
.98 .44967 L
.984 .44971 L
.988 .44972 L
.992 .44978 L
.996 .44979 L
1 .44985 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .23082 m
.008 .24446 L
.012 .24865 L
.016 .25602 L
.02 .26652 L
.024 .27605 L
.028 .28461 L
.032 .2936 L
.036 .30294 L
.04 .31217 L
.044 .32139 L
.048 .33112 L
.052 .34119 L
.056 .351 L
.06 .36051 L
.064 .37049 L
.068 .38116 L
.072 .39234 L
.076 .40354 L
.08 .41413 L
.084 .42408 L
.088 .43413 L
.092 .44474 L
.096 .45626 L
.1 .46846 L
.104 .48064 L
.108 .49214 L
.112 .50234 L
.116 .511 L
.12 .51813 L
.124 .52392 L
.128 .5287 L
.132 .53274 L
.136 .53634 L
.14 .53967 L
.144 .54287 L
.148 .54601 L
.152 .54912 L
.156 .55219 L
.16 .55521 L
.164 .55811 L
.168 .56087 L
.172 .56342 L
.176 .56573 L
.18 .56778 L
.184 .56955 L
.188 .57106 L
.192 .57233 L
.196 .57339 L
.2 .57428 L
Mistroke
.204 .57503 L
.208 .57566 L
.212 .57618 L
.216 .57658 L
.22 .57683 L
.224 .57692 L
.228 .5768 L
.232 .57648 L
.236 .57596 L
.24 .57525 L
.244 .57443 L
.248 .57354 L
.252 .57269 L
.256 .57196 L
.26 .57142 L
.264 .57111 L
.268 .57107 L
.272 .57127 L
.276 .57165 L
.28 .57216 L
.284 .57271 L
.288 .57321 L
.292 .57361 L
.296 .57387 L
.3 .57396 L
.304 .5739 L
.308 .57372 L
.312 .57346 L
.316 .57315 L
.32 .57283 L
.324 .57253 L
.328 .57228 L
.332 .57209 L
.336 .57197 L
.34 .57194 L
.344 .57197 L
.348 .57208 L
.352 .57222 L
.356 .57238 L
.36 .57251 L
.364 .57259 L
.368 .57258 L
.372 .57248 L
.376 .57229 L
.38 .57204 L
.384 .57178 L
.388 .57156 L
.392 .57143 L
.396 .57142 L
.4 .57152 L
Mistroke
.404 .57169 L
.408 .57188 L
.412 .57203 L
.416 .57209 L
.42 .57204 L
.424 .57189 L
.428 .57167 L
.432 .57143 L
.436 .57122 L
.44 .57109 L
.444 .57104 L
.448 .57107 L
.452 .57114 L
.456 .5712 L
.46 .57124 L
.464 .57124 L
.468 .57119 L
.472 .57111 L
.476 .57103 L
.48 .57096 L
.484 .57091 L
.488 .57088 L
.492 .57085 L
.496 .57083 L
.5 .5708 L
.504 .57075 L
.508 .57069 L
.512 .57061 L
.516 .57054 L
.52 .57046 L
.524 .5704 L
.528 .57036 L
.532 .57034 L
.536 .57033 L
.54 .57033 L
.544 .57032 L
.548 .5703 L
.552 .57026 L
.556 .5702 L
.56 .57013 L
.564 .57006 L
.568 .57 L
.572 .56996 L
.576 .56992 L
.58 .5699 L
.584 .56985 L
.588 .5698 L
.592 .56972 L
.596 .56965 L
.6 .56959 L
Mistroke
.604 .56956 L
.608 .56957 L
.612 .56959 L
.616 .56961 L
.62 .56958 L
.624 .56952 L
.628 .56941 L
.632 .56929 L
.636 .56919 L
.64 .56913 L
.644 .56911 L
.648 .56912 L
.652 .56914 L
.656 .56913 L
.66 .56909 L
.664 .56902 L
.668 .56894 L
.672 .56887 L
.676 .56882 L
.68 .5688 L
.684 .56878 L
.688 .56875 L
.692 .56871 L
.696 .56865 L
.7 .56858 L
.704 .56852 L
.708 .56848 L
.712 .56845 L
.716 .56843 L
.72 .56839 L
.724 .56835 L
.728 .5683 L
.732 .56825 L
.736 .5682 L
.74 .56816 L
.744 .56813 L
.748 .5681 L
.752 .56805 L
.756 .568 L
.76 .56794 L
.764 .56788 L
.768 .56783 L
.772 .5678 L
.776 .56777 L
.78 .56774 L
.784 .56771 L
.788 .56766 L
.792 .56761 L
.796 .56756 L
.8 .56752 L
Mistroke
.804 .56747 L
.808 .56743 L
.812 .56738 L
.816 .56733 L
.82 .56728 L
.824 .56724 L
.828 .5672 L
.832 .56717 L
.836 .56713 L
.84 .5671 L
.844 .56706 L
.848 .56701 L
.852 .56696 L
.856 .5669 L
.86 .56685 L
.864 .56681 L
.868 .56677 L
.872 .56673 L
.876 .56669 L
.88 .56665 L
.884 .56661 L
.888 .56658 L
.892 .56653 L
.896 .56649 L
.9 .56644 L
.904 .56638 L
.908 .56632 L
.912 .56628 L
.916 .56624 L
.92 .56622 L
.924 .56618 L
.928 .56615 L
.932 .56609 L
.936 .56605 L
.94 .56599 L
.944 .56595 L
.948 .56589 L
.952 .56586 L
.956 .56581 L
.96 .56579 L
.964 .56574 L
.968 .56572 L
.972 .56566 L
.976 .56562 L
.98 .56555 L
.984 .56552 L
.988 .56545 L
.992 .56544 L
.996 .56537 L
1 .56536 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`03001oogoo008000Eoo`8000Aoo`04
001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@0
07ooOol000Eoo`008Woo0P0037oo1@000goo0P0000=oo`00Ool01Goo00<007ooOol00goo0P0017oo
0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`80
00Ioo`008Woo00<007ooOol057oo00<007oo00001Goo00<007ooOol00goo0P000Woo0P00A7oo000R
Ool2000DOol01@00Oomoogoo00000goo00@007oo0000009oo`03001oo`00009oo`04001oo`00Ool3
000017oo000000000Woo0P0000Eoo`00000007oo00800003Ool0000000<00004Ool00000OolJ000<
Ool0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoogoo
0P000Woo00P007ooOol007oo001oo`000Woo0P000goo0P000Woo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo00Yoo`008Woo0P004Woo0P001Goo0P00
DWoo000ROol00`00Oomoo`0AOol00`00Oomoo`1HOol0029oo`80015oo`03001oogoo05Uoo`008Woo
0P004Goo00<007ooOol0FGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomo
o`0?Ool00`00Oomoo`1JOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0`003goo00<007ooOol0FWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`@000ioo`03001oogoo05Yoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`02000=Ool00`00Oomoo`1JOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P000Woo00<007ooOol02Woo00<007ooOol0Fgoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`8000=oo`03001oogoo00=oo`<000=oo`03001oogoo05]oo`002goo
0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00@007ooOol0009o
o`03001oogoo05]oo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P0017oo00D007oo
Oomoo`0000Aoo`8005ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo
0P0017oo00D007ooOomoo`0006Aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`04Ool01000Ool00000I7oo000:Ool01000Oomoo`0027oo00@007ooOol000Ao
o`04001oogooOol20006Ool2001UOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006io
o`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`00
0goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001o
o`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0
029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol0
00=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`00
2goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Io
o`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yo
o`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol0
00=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001X
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]o
o`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Ao
o`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00
Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03
001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0
3Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool0
1000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=o
o`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo
00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000
Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomo
o`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P00
0goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomo
o`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol2001WOol002Qoo`03001oo`0006Ioo`00:7oo00@007oo000006Eo
o`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol00P00I7oo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol000=oo`80
06=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol000Ao
o`80069oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
0P0017oo0P00HGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003
Ool00`00Oomoo`04Ool2001POol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0006Ool00`00Oomoo`05Ool20008Ool60002Ool4001;Ool000]oo`8000Yoo`8000Aoo`80009o
o`D0009oo`03001oogoo00Ioo`8000Aoo`<000Eoo`@0009ood0000aoo`00:7oo00<007ooOol01goo
1@00FWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003
Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007oo
Ool007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomo
o`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool2
0004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000
Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo0000
0goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007oo
Ool047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=o
o`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0
009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001o
ogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo0P00Lgoo000LOol2001c
Ool001aoo`8007=oo`0077oo00<007oo0000LWoo000LOol3001bOol000]oo`8000Aoo`03001oogoo
009oo`<000=oo`04001oogoo001aOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00@0
07ooOol0075oo`002Woo00@007ooOol000]oo`03001oogoo0080009oo`03001oogoo06ioo`002Woo
00@007ooOol000]oo`04001oogoo0003Ool00`00Oomoo`1^Ool000Yoo`04001oogoo0007Ool40003
Ool01@00Oomoogoo0000L7oo000:Ool01000Oomoo`001goo00<007ooOol017oo0P000goo00<007oo
Ool0KGoo000;Ool20008Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`1]Ool001aoo`03001oogoo
00=oo`03001oogoo06aoo`0077oo0P0017oo00<007ooOol0K7oo000LOol00`00Oomoo`03Ool00`00
Oomoo`1/Ool001aoo`8000Eoo`03001oogoo06]oo`0077oo00<007ooOol017oo00<007ooOol0Jgoo
000LOol00`00Oomoo`05Ool00`00Oomoo`1ZOol001aoo`8000Ioo`03001oogoo06Yoo`005Woo0`00
0goo00<007ooOol01Goo00<007ooOol0JWoo000GOol00`00Oomoo`02Ool00`00Oomoo`06Ool00`00
Oomoo`1YOol001Moo`03001oogoo009oo`8000Moo`03001oogoo06Uoo`005goo00<007ooOol00Woo
00<007ooOol01Woo00<007ooOol0JGoo000GOol00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomo
o`1XOol001Ioo`8000Aoo`8000Qoo`03001oogoo06Qoo`005goo00<007ooOol00Woo00<007ooOol0
27oo00<007ooOol0Igoo000LOol00`00Oomoo`08Ool00`00Oomoo`1WOol001aoo`8000Uoo`03001o
ogoo06Moo`0077oo00<007ooOol027oo00<007ooOol0Igoo000LOol2000:Ool00`00Oomoo`1VOol0
01aoo`03001oogoo00Yoo`03001oogoo06Eoo`0077oo00<007ooOol02Woo00<007ooOol0IGoo000:
Ool30004Ool00`00Oomoo`02Ool30003Ool2000<Ool2001UOol000]oo`03001oogoo00Moo`05001o
ogooOol00002Ool00`00Oomoo`0<Ool2001TOol000]oo`03001oogoo00]oo`04001oogoo000?Ool2
001SOol000]oo`03001oogoo00]oo`03001oogoo0080011oo`8002Uoob`000aoo`002goo00<007oo
Ool01goo10000goo00<007ooOol04Goo:@00>7oo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomo
o`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(37241\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .42367 m
.008 .42569 L
.012 .42969 L
.016 .4344 L
.02 .43989 L
.024 .44568 L
.028 .4513 L
.032 .45746 L
.036 .46417 L
.04 .46988 L
.044 .47385 L
.048 .47677 L
.052 .47901 L
.056 .47994 L
.06 .4785 L
.064 .47371 L
.068 .46651 L
.072 .45936 L
.076 .45265 L
.08 .44473 L
.084 .43509 L
.088 .42469 L
.092 .4156 L
.096 .41039 L
.1 .40944 L
.104 .41115 L
.108 .41374 L
.112 .41558 L
.116 .41638 L
.12 .41688 L
.124 .41758 L
.128 .41878 L
.132 .41992 L
.136 .41997 L
.14 .41799 L
.144 .41324 L
.148 .40566 L
.152 .39566 L
.156 .38416 L
.16 .37221 L
.164 .36086 L
.168 .35086 L
.172 .34257 L
.176 .33592 L
.18 .33043 L
.184 .32534 L
.188 .31981 L
.192 .31312 L
.196 .30487 L
.2 .29512 L
Mistroke
.204 .28445 L
.208 .27387 L
.212 .26473 L
.216 .25839 L
.22 .256 L
.224 .2582 L
.228 .26499 L
.232 .27563 L
.236 .28872 L
.24 .30245 L
.244 .31484 L
.248 .32417 L
.252 .32927 L
.256 .32976 L
.26 .32604 L
.264 .3192 L
.268 .31073 L
.272 .3022 L
.276 .2949 L
.28 .28967 L
.284 .28679 L
.288 .28603 L
.292 .28684 L
.296 .28858 L
.3 .29073 L
.304 .29305 L
.308 .29554 L
.312 .29833 L
.316 .30148 L
.32 .3048 L
.324 .30778 L
.328 .30967 L
.332 .30972 L
.336 .3075 L
.34 .30309 L
.344 .29726 L
.348 .29132 L
.352 .28682 L
.356 .28514 L
.36 .287 L
.364 .29218 L
.368 .29942 L
.372 .30677 L
.376 .31211 L
.38 .31385 L
.384 .31142 L
.388 .30551 L
.392 .2979 L
.396 .29086 L
.4 .28647 L
Mistroke
.404 .28591 L
.408 .28912 L
.412 .29487 L
.416 .30123 L
.42 .30616 L
.424 .30825 L
.428 .30714 L
.432 .30357 L
.436 .29902 L
.44 .29516 L
.444 .2932 L
.448 .29354 L
.452 .29574 L
.456 .29873 L
.46 .30132 L
.464 .30265 L
.468 .30246 L
.472 .30109 L
.476 .29919 L
.48 .29742 L
.484 .29623 L
.488 .2958 L
.492 .29609 L
.496 .29696 L
.5 .29819 L
.504 .29961 L
.508 .30097 L
.512 .30194 L
.516 .30214 L
.52 .30132 L
.524 .29957 L
.528 .29741 L
.532 .29562 L
.536 .29495 L
.54 .29576 L
.544 .2978 L
.548 .30024 L
.552 .30198 L
.556 .30216 L
.56 .30063 L
.564 .29809 L
.568 .29584 L
.572 .29507 L
.576 .29625 L
.58 .29885 L
.584 .30157 L
.588 .30301 L
.592 .30234 L
.596 .29979 L
.6 .29659 L
Mistroke
.604 .29434 L
.608 .29423 L
.612 .29633 L
.616 .29951 L
.62 .30209 L
.624 .30276 L
.628 .30129 L
.632 .29859 L
.636 .29618 L
.64 .29535 L
.644 .29645 L
.648 .29876 L
.652 .30089 L
.656 .30161 L
.66 .30051 L
.664 .29829 L
.668 .2963 L
.672 .29571 L
.676 .29683 L
.68 .29891 L
.684 .30069 L
.688 .30115 L
.692 .30016 L
.696 .29841 L
.7 .29696 L
.704 .29658 L
.708 .29739 L
.712 .29881 L
.716 .29998 L
.72 .30022 L
.724 .29944 L
.728 .29815 L
.732 .29718 L
.736 .29709 L
.74 .29788 L
.744 .29899 L
.748 .29971 L
.752 .29966 L
.756 .299 L
.76 .29823 L
.764 .2978 L
.768 .29783 L
.772 .2982 L
.776 .29864 L
.78 .29896 L
.784 .29901 L
.788 .29875 L
.792 .29827 L
.796 .29785 L
.8 .29782 L
Mistroke
.804 .2983 L
.808 .29904 L
.812 .29947 L
.816 .29923 L
.82 .29843 L
.824 .29766 L
.828 .29746 L
.832 .29795 L
.836 .29868 L
.84 .29911 L
.844 .29902 L
.848 .29859 L
.852 .2982 L
.856 .29807 L
.86 .29813 L
.864 .29831 L
.868 .29852 L
.872 .2987 L
.876 .29882 L
.88 .29867 L
.884 .29825 L
.888 .29789 L
.892 .29783 L
.896 .29817 L
.9 .2987 L
.904 .29883 L
.908 .29852 L
.912 .2982 L
.916 .29814 L
.92 .29855 L
.924 .29902 L
.928 .29874 L
.932 .29794 L
.936 .29727 L
.94 .29727 L
.944 .29832 L
.948 .2995 L
.952 .29958 L
.956 .29873 L
.96 .29754 L
.964 .29701 L
.968 .29794 L
.972 .29927 L
.976 .29955 L
.98 .29876 L
.984 .29731 L
.988 .29635 L
.992 .29731 L
.996 .29907 L
1 .29991 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .28612 m
.008 .29781 L
.012 .30506 L
.016 .30785 L
.02 .31194 L
.024 .31725 L
.028 .32196 L
.032 .32608 L
.036 .3301 L
.04 .33399 L
.044 .33778 L
.048 .34152 L
.052 .34517 L
.056 .3486 L
.06 .35185 L
.064 .35511 L
.068 .35872 L
.072 .36259 L
.076 .36626 L
.08 .36966 L
.084 .37315 L
.088 .37704 L
.092 .38153 L
.096 .38635 L
.1 .39092 L
.104 .39496 L
.108 .39857 L
.112 .4021 L
.116 .40608 L
.12 .41071 L
.124 .41591 L
.128 .42132 L
.132 .42645 L
.136 .4309 L
.14 .43443 L
.144 .43697 L
.148 .43864 L
.152 .43961 L
.156 .44009 L
.16 .44026 L
.164 .44028 L
.168 .44021 L
.172 .44012 L
.176 .44003 L
.18 .43997 L
.184 .43992 L
.188 .43992 L
.192 .43997 L
.196 .44011 L
.2 .44036 L
Mistroke
.204 .44073 L
.208 .44125 L
.212 .44188 L
.216 .44262 L
.22 .4434 L
.224 .44417 L
.228 .44487 L
.232 .44542 L
.236 .44579 L
.24 .44595 L
.244 .4459 L
.248 .44567 L
.252 .44531 L
.256 .44489 L
.26 .44447 L
.264 .44411 L
.268 .44385 L
.272 .44372 L
.276 .44372 L
.28 .44382 L
.284 .44402 L
.288 .44426 L
.292 .44452 L
.296 .44477 L
.3 .44499 L
.304 .44515 L
.308 .44526 L
.312 .44531 L
.316 .4453 L
.32 .44523 L
.324 .44513 L
.328 .445 L
.332 .44488 L
.336 .44479 L
.34 .44476 L
.344 .44479 L
.348 .4449 L
.352 .44507 L
.356 .44527 L
.36 .44546 L
.364 .4456 L
.368 .44565 L
.372 .44562 L
.376 .44551 L
.38 .44535 L
.384 .4452 L
.388 .4451 L
.392 .44509 L
.396 .44516 L
.4 .44531 L
Mistroke
.404 .44549 L
.408 .44567 L
.412 .44581 L
.416 .44588 L
.42 .44589 L
.424 .44584 L
.428 .44578 L
.432 .44572 L
.436 .44569 L
.44 .4457 L
.444 .44574 L
.448 .4458 L
.452 .44587 L
.456 .44592 L
.46 .44595 L
.464 .44596 L
.468 .44597 L
.472 .44599 L
.476 .44601 L
.48 .44605 L
.484 .4461 L
.488 .44615 L
.492 .44621 L
.496 .44625 L
.5 .44629 L
.504 .44631 L
.508 .44632 L
.512 .44632 L
.516 .44632 L
.52 .44632 L
.524 .44633 L
.528 .44636 L
.532 .44641 L
.536 .44646 L
.54 .44651 L
.544 .44655 L
.548 .44658 L
.552 .4466 L
.556 .44662 L
.56 .44664 L
.564 .44669 L
.568 .44674 L
.572 .44679 L
.576 .44682 L
.58 .44683 L
.584 .44682 L
.588 .44679 L
.592 .44679 L
.596 .44681 L
.6 .44686 L
Mistroke
.604 .44694 L
.608 .44703 L
.612 .4471 L
.616 .44714 L
.62 .44714 L
.624 .44712 L
.628 .4471 L
.632 .4471 L
.636 .44713 L
.64 .44718 L
.644 .44725 L
.648 .4473 L
.652 .44733 L
.656 .44734 L
.66 .44735 L
.664 .44736 L
.668 .44739 L
.672 .44743 L
.676 .44748 L
.68 .44752 L
.684 .44755 L
.688 .44757 L
.692 .44758 L
.696 .4476 L
.7 .44763 L
.704 .44766 L
.708 .4477 L
.712 .44773 L
.716 .44775 L
.72 .44777 L
.724 .44779 L
.728 .44783 L
.732 .44786 L
.736 .44791 L
.74 .44795 L
.744 .44798 L
.748 .44799 L
.752 .44801 L
.756 .44802 L
.76 .44804 L
.764 .44807 L
.768 .44811 L
.772 .44815 L
.776 .44819 L
.78 .44822 L
.784 .44824 L
.788 .44827 L
.792 .44829 L
.796 .44832 L
.8 .44835 L
Mistroke
.804 .44838 L
.808 .4484 L
.812 .44843 L
.816 .44845 L
.82 .44848 L
.824 .44852 L
.828 .44855 L
.832 .44858 L
.836 .4486 L
.84 .44863 L
.844 .44865 L
.848 .44869 L
.852 .44872 L
.856 .44875 L
.86 .44878 L
.864 .4488 L
.868 .44882 L
.872 .44885 L
.876 .44887 L
.88 .4489 L
.884 .44893 L
.888 .44897 L
.892 .449 L
.896 .44904 L
.9 .44906 L
.904 .44909 L
.908 .44911 L
.912 .44914 L
.916 .44916 L
.92 .44919 L
.924 .4492 L
.928 .44924 L
.932 .44926 L
.936 .44931 L
.94 .44934 L
.944 .44939 L
.948 .44941 L
.952 .44944 L
.956 .44944 L
.96 .44947 L
.964 .44948 L
.968 .44952 L
.972 .44953 L
.976 .44958 L
.98 .44961 L
.984 .44967 L
.988 .44969 L
.992 .44974 L
.996 .44973 L
1 .44977 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .18595 m
.008 .19722 L
.012 .20628 L
.016 .2158 L
.02 .22609 L
.024 .23647 L
.028 .24667 L
.032 .2569 L
.036 .26725 L
.04 .27763 L
.044 .288 L
.048 .29863 L
.052 .30944 L
.056 .32002 L
.06 .3303 L
.064 .34079 L
.068 .3516 L
.072 .36244 L
.076 .37295 L
.08 .38291 L
.084 .39257 L
.088 .4026 L
.092 .41314 L
.096 .42383 L
.1 .43417 L
.104 .4438 L
.108 .45285 L
.112 .462 L
.116 .47178 L
.12 .48255 L
.124 .49418 L
.128 .50614 L
.132 .5178 L
.136 .52853 L
.14 .53793 L
.144 .54582 L
.148 .55223 L
.152 .55733 L
.156 .56132 L
.16 .56444 L
.164 .56689 L
.168 .56884 L
.172 .57041 L
.176 .57171 L
.18 .5728 L
.184 .5737 L
.188 .57445 L
.192 .57503 L
.196 .57541 L
.2 .57559 L
Mistroke
.204 .57555 L
.208 .57528 L
.212 .57479 L
.216 .57414 L
.22 .57339 L
.224 .57262 L
.228 .57191 L
.232 .57135 L
.236 .571 L
.24 .57089 L
.244 .57103 L
.248 .57137 L
.252 .57186 L
.256 .57242 L
.26 .57298 L
.264 .57345 L
.268 .5738 L
.272 .57397 L
.276 .57398 L
.28 .57385 L
.284 .57361 L
.288 .57331 L
.292 .57298 L
.296 .57267 L
.3 .5724 L
.304 .57219 L
.308 .57205 L
.312 .57199 L
.316 .57199 L
.32 .57207 L
.324 .57219 L
.328 .57234 L
.332 .57249 L
.336 .57259 L
.34 .57263 L
.344 .57258 L
.348 .57243 L
.352 .57221 L
.356 .57195 L
.36 .57171 L
.364 .57154 L
.368 .57146 L
.372 .5715 L
.376 .57163 L
.38 .57181 L
.384 .57199 L
.388 .5721 L
.392 .57212 L
.396 .57202 L
.4 .57184 L
Mistroke
.404 .5716 L
.408 .57137 L
.412 .57119 L
.416 .57109 L
.42 .57107 L
.424 .57112 L
.428 .57119 L
.432 .57126 L
.436 .57129 L
.44 .57128 L
.444 .57121 L
.448 .57113 L
.452 .57104 L
.456 .57097 L
.46 .57092 L
.464 .57089 L
.468 .57087 L
.472 .57085 L
.476 .57082 L
.48 .57077 L
.484 .5707 L
.488 .57062 L
.492 .57054 L
.496 .57047 L
.5 .57042 L
.504 .57039 L
.508 .57037 L
.512 .57037 L
.516 .57036 L
.52 .57035 L
.524 .57032 L
.528 .57027 L
.532 .57021 L
.536 .57014 L
.54 .57007 L
.544 .57002 L
.548 .56998 L
.552 .56994 L
.556 .56991 L
.56 .56987 L
.564 .5698 L
.568 .56973 L
.572 .56967 L
.576 .56962 L
.58 .5696 L
.584 .56961 L
.588 .56963 L
.592 .56963 L
.596 .5696 L
.6 .56952 L
Mistroke
.604 .56941 L
.608 .56929 L
.612 .5692 L
.616 .56915 L
.62 .56914 L
.624 .56916 L
.628 .56917 L
.632 .56916 L
.636 .56911 L
.64 .56904 L
.644 .56895 L
.648 .56888 L
.652 .56884 L
.656 .56882 L
.66 .5688 L
.664 .56878 L
.668 .56873 L
.672 .56867 L
.676 .5686 L
.68 .56854 L
.684 .5685 L
.688 .56847 L
.692 .56844 L
.696 .56841 L
.7 .56837 L
.704 .56832 L
.708 .56827 L
.712 .56823 L
.716 .56819 L
.72 .56815 L
.724 .56811 L
.728 .56807 L
.732 .56801 L
.736 .56795 L
.74 .5679 L
.744 .56786 L
.748 .56783 L
.752 .5678 L
.756 .56777 L
.76 .56773 L
.764 .56768 L
.768 .56763 L
.772 .56757 L
.776 .56753 L
.78 .56749 L
.784 .56746 L
.788 .56741 L
.792 .56737 L
.796 .56731 L
.8 .56726 L
Mistroke
.804 .56722 L
.808 .56718 L
.812 .56715 L
.816 .56712 L
.82 .56708 L
.824 .56704 L
.828 .56699 L
.832 .56693 L
.836 .56688 L
.84 .56683 L
.844 .56679 L
.848 .56675 L
.852 .5667 L
.856 .56666 L
.86 .56663 L
.864 .5666 L
.868 .56656 L
.872 .56653 L
.876 .56647 L
.88 .56642 L
.884 .56635 L
.888 .5663 L
.892 .56625 L
.896 .56622 L
.9 .56619 L
.904 .56617 L
.908 .56613 L
.912 .5661 L
.916 .56604 L
.92 .56599 L
.924 .56593 L
.928 .56587 L
.932 .56581 L
.936 .56578 L
.94 .56575 L
.944 .56573 L
.948 .56569 L
.952 .56567 L
.956 .5656 L
.96 .56556 L
.964 .56549 L
.968 .56545 L
.972 .56538 L
.976 .56536 L
.98 .56531 L
.984 .5653 L
.988 .56524 L
.992 .56523 L
.996 .56515 L
1 .56513 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo0P0000=oo`00Ool01Woo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool01000Oomoogoo10000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomo
o`000Woo00@007ooOol000=oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P00
2Woo0P0017oo00<007ooOol00Woo0P0037oo00<007ooOol017oo0P0000=oo`00Ool01Goo0P0017oo
00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006Ool0
1000Oomoo`001Goo000ROol2000<Ool500000goo001oo`020008Ool00`00Oomoo`03Ool20004Ool2
0006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P00
1Woo000ROol00`00Oomoo`0AOol01000Oomoo`0017oo0P0017oo0P000goo0P00AWoo000ROol2000B
Ool01000Oomoo`000goo00<007oo00000P000Woo00@007oo001oo`<0009oo`<00004Ool000000002
Ool200000goo00000002Ool2000017oo000007oo0P0000Aoo`00001oo`800003Ool0000000<00003
Ool0000000d00003Ool0000000eoo`008WooH`0037oo000ROol01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`03001oogoo008000=oo`04001oo`000003Ool20002Ool00`00Ool000020003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`04001oogoo0003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol02Woo
000ROol2000@Ool00`00Oomoo`03Ool2001EOol0029oo`03001oogoo00ioo`8000Ioo`03001oogoo
05=oo`008Woo0P003goo00<007ooOol0Fgoo000ROol2000?Ool00`00Oomoo`1KOol000]oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo00eoo`03001oogoo05aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000>Ool00`00Oomoo`1LOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo00<007ooOol0GGoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00aoo`03001oogoo05eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20008Ool00`00Oomoo`02Ool0
0`00Oomoo`1MOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P001goo00<007oo
00000`00H7oo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool20007Ool00`00Oomoo`1SOol000]o
o`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`<000Eoo`03001oogoo06Aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`000Woo100017oo00<007ooOol0I7oo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`1UOol0
00Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`80009oo`04001oogoo001WOol0
00Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo0080009oo`<006Qoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo
0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03
001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006io
o`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`00
8Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@0
07ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
2Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03
001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Ao
o`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Ao
o`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<0
07ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Ao
o`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo
10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@0
07ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007oo
Ool017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<0
07ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool0
0`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P00
17oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`8006Moo`00:7ooG@0037oo
000XOol01000Ool000003Woo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007oo
Ool047oo00<007ooOol02Woo000XOol00`00Oomoo`02001TOol002Qoo`04001oogooOol2001SOol0
02Qoo`03001oogoo009oo`80069oo`00:7oo00<007ooOol00goo0P00HGoo000XOol00`00Oomoo`04
Ool2001POol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo00Eo
o`8005moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001o
ogoo0008Ool2001NOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04
001oogoo0009Ool2001MOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo008000Uoo`8005aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomo
o`00Ool010000goo00<007ooOol02Goo0P00Fgoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`001Woo00<007ooOol02Woo2@000Woo1000CGoo000;Ool2000:Ool20004Ool2
0002Ool50002Ool00`00Oomoo`0BOol40002Oom2000<Ool002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=o
o`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007oo
Ool000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04
001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2
001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P00
2Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@00
0Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo
0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo
011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03
Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol0
0`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001o
ogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2
000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P00
1Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Ao
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009o
o`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`8007=oo`0077oo0P00
Lgoo000LOol3001bOol001aoo`03001oo`00079oo`0077oo00@007ooOol0075oo`0077oo0P0000=o
o`00Ool0L7oo000LOol01@00Oomoogoo0000L7oo000LOol20002Ool00`00Oomoo`1^Ool000]oo`80
00Aoo`03001oogoo009oo`<000=oo`05001oogooOol0001`Ool000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol0KGoo000:Ool01000Oomoo`002goo00<007oo
Ool00P000goo00<007ooOol0KGoo000:Ool01000Oomoo`002goo00@007ooOol000Aoo`03001oogoo
06eoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo00=oo`03001oogoo06aoo`002Woo00@0
07ooOol000Moo`03001oogoo00Aoo`8000Aoo`03001oogoo06aoo`002goo0P0027oo1@000Woo00<0
07ooOol00goo00<007ooOol0K7oo000LOol00`00Oomoo`04Ool00`00Oomoo`1[Ool001aoo`8000Eo
o`03001oogoo06]oo`0077oo00<007ooOol01Goo00<007ooOol0JWoo000LOol20006Ool00`00Oomo
o`1ZOol001aoo`03001oogoo00Eoo`03001oogoo06Yoo`0077oo00<007ooOol01Woo00<007ooOol0
JGoo000LOol20007Ool00`00Oomoo`1YOol001Ioo`<000=oo`03001oogoo00Moo`03001oogoo06Qo
o`005goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0J7oo000GOol00`00Oomoo`02Ool2
0009Ool00`00Oomoo`1WOol001Moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo06Moo`00
5goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0Igoo000FOol20004Ool2000:Ool00`00
Oomoo`1VOol001Moo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo06Ioo`0077oo00<007oo
Ool02Woo00<007ooOol0IGoo000LOol2000;Ool00`00Oomoo`1UOol001aoo`03001oogoo00Yoo`03
001oogoo06Eoo`0077oo0P002goo00<007ooOol0IGoo000LOol00`00Oomoo`0;Ool00`00Oomoo`1T
Ool001aoo`03001oogoo00]oo`03001oogoo06Aoo`002Woo0`0017oo00<007ooOol00Woo0`000goo
0P003Goo00<007ooOol0Hgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0
37oo00<007ooOol0Hgoo000;Ool00`00Oomoo`0;Ool01000Oomoo`003goo00<007ooOol0HWoo000;
Ool00`00Oomoo`0;Ool00`00Oomoo`02000>Ool3000XOol^000<Ool000]oo`03001oogoo00Moo`@0
00=oo`03001oogoo00moobT003Yoo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;
Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(37408\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .50239 m
.008 .50808 L
.012 .51283 L
.016 .51529 L
.02 .51537 L
.024 .51475 L
.028 .5132 L
.032 .50968 L
.036 .5043 L
.04 .49699 L
.044 .48766 L
.048 .47693 L
.052 .46587 L
.056 .45527 L
.06 .44508 L
.064 .43494 L
.068 .42613 L
.072 .42101 L
.076 .41968 L
.08 .41991 L
.084 .42056 L
.088 .42212 L
.092 .42532 L
.096 .43029 L
.1 .43512 L
.104 .43649 L
.108 .43293 L
.112 .42517 L
.116 .415 L
.12 .40443 L
.124 .39397 L
.128 .38271 L
.132 .36988 L
.136 .35523 L
.14 .33977 L
.144 .32534 L
.148 .31351 L
.152 .30527 L
.156 .30042 L
.16 .29785 L
.164 .29605 L
.168 .29353 L
.172 .28936 L
.176 .2833 L
.18 .27595 L
.184 .26845 L
.188 .2623 L
.192 .25895 L
.196 .25948 L
.2 .26438 L
Mistroke
.204 .27338 L
.208 .28546 L
.212 .29902 L
.216 .31215 L
.22 .32297 L
.224 .33003 L
.228 .33252 L
.232 .33044 L
.236 .32456 L
.24 .31621 L
.244 .30699 L
.248 .29842 L
.252 .29168 L
.256 .28739 L
.26 .28561 L
.264 .28591 L
.268 .2876 L
.272 .28997 L
.276 .29255 L
.28 .29513 L
.284 .29775 L
.288 .30056 L
.292 .30355 L
.296 .30646 L
.3 .30874 L
.304 .30968 L
.308 .30869 L
.312 .30552 L
.316 .30052 L
.32 .29464 L
.324 .28928 L
.328 .28595 L
.332 .28577 L
.336 .28908 L
.34 .29522 L
.344 .30267 L
.348 .30936 L
.352 .31335 L
.356 .31343 L
.36 .30953 L
.364 .30275 L
.368 .29508 L
.372 .28877 L
.376 .28562 L
.38 .28644 L
.384 .2908 L
.388 .29717 L
.392 .30344 L
.396 .3077 L
.4 .30878 L
Mistroke
.404 .30666 L
.408 .30238 L
.412 .29762 L
.416 .29404 L
.42 .29273 L
.424 .2938 L
.428 .29654 L
.432 .29972 L
.436 .30217 L
.44 .30313 L
.444 .30249 L
.448 .3007 L
.452 .29853 L
.456 .29673 L
.46 .29574 L
.464 .2957 L
.468 .29643 L
.472 .29768 L
.476 .29913 L
.48 .30049 L
.484 .30152 L
.488 .30199 L
.492 .30171 L
.496 .30062 L
.5 .2989 L
.504 .29699 L
.508 .29559 L
.512 .2953 L
.516 .29635 L
.52 .29841 L
.524 .30064 L
.528 .30205 L
.532 .30196 L
.536 .30032 L
.54 .29789 L
.544 .29586 L
.548 .29534 L
.552 .2967 L
.556 .29933 L
.56 .30189 L
.564 .30301 L
.568 .30202 L
.572 .29933 L
.576 .29622 L
.58 .29427 L
.584 .29449 L
.588 .29681 L
.592 .30004 L
.596 .3025 L
.6 .30293 L
Mistroke
.604 .30119 L
.608 .29832 L
.612 .29593 L
.616 .2953 L
.62 .29664 L
.624 .29908 L
.628 .30118 L
.632 .30173 L
.636 .30046 L
.64 .29816 L
.644 .2962 L
.648 .29574 L
.652 .29702 L
.656 .29922 L
.66 .301 L
.664 .30134 L
.668 .30016 L
.672 .29826 L
.676 .29681 L
.68 .29659 L
.684 .29759 L
.688 .2991 L
.692 .30018 L
.696 .30024 L
.7 .29931 L
.704 .29805 L
.708 .29722 L
.712 .29732 L
.716 .2982 L
.72 .29926 L
.724 .29981 L
.728 .29957 L
.732 .29881 L
.736 .29809 L
.74 .29784 L
.744 .29813 L
.748 .29863 L
.752 .29897 L
.756 .29899 L
.76 .29873 L
.764 .29839 L
.768 .29814 L
.772 .29813 L
.776 .29837 L
.78 .2988 L
.784 .29918 L
.788 .29925 L
.792 .29888 L
.796 .29827 L
.8 .29781 L
Mistroke
.804 .29783 L
.808 .2983 L
.812 .29883 L
.816 .29904 L
.82 .29883 L
.824 .29843 L
.828 .29822 L
.832 .29833 L
.836 .2986 L
.84 .29881 L
.844 .29878 L
.848 .29853 L
.852 .29824 L
.856 .29802 L
.86 .29799 L
.864 .29828 L
.868 .29877 L
.872 .2992 L
.876 .29921 L
.88 .29859 L
.884 .29773 L
.888 .29734 L
.892 .29776 L
.896 .29886 L
.9 .29975 L
.904 .29955 L
.908 .29845 L
.912 .2973 L
.916 .29697 L
.92 .29788 L
.924 .29911 L
.928 .29955 L
.932 .29908 L
.936 .29813 L
.94 .29762 L
.944 .29812 L
.948 .2988 L
.952 .29883 L
.956 .29829 L
.96 .29756 L
.964 .29751 L
.968 .29858 L
.972 .29952 L
.976 .29937 L
.98 .29846 L
.984 .29715 L
.988 .2968 L
.992 .29821 L
.996 .29958 L
1 .29988 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .25082 m
.008 .2496 L
.012 .24974 L
.016 .25128 L
.02 .25412 L
.024 .25839 L
.028 .26272 L
.032 .26692 L
.036 .27096 L
.04 .27493 L
.044 .27894 L
.048 .28303 L
.052 .28715 L
.056 .29123 L
.06 .29526 L
.064 .29932 L
.068 .30362 L
.072 .30805 L
.076 .31226 L
.08 .31616 L
.084 .32008 L
.088 .3242 L
.092 .32849 L
.096 .33268 L
.1 .33646 L
.104 .33989 L
.108 .34346 L
.112 .34749 L
.116 .35209 L
.12 .35699 L
.124 .36174 L
.128 .36614 L
.132 .37034 L
.136 .37466 L
.14 .37959 L
.144 .38535 L
.148 .39188 L
.152 .39889 L
.156 .4059 L
.16 .4125 L
.164 .41834 L
.168 .42327 L
.172 .42731 L
.176 .43056 L
.18 .43318 L
.184 .43535 L
.188 .4372 L
.192 .43881 L
.196 .44023 L
.2 .44146 L
Mistroke
.204 .44249 L
.208 .44328 L
.212 .44382 L
.216 .44412 L
.22 .44418 L
.224 .44407 L
.228 .44384 L
.232 .44355 L
.236 .44328 L
.24 .44308 L
.244 .44299 L
.248 .44301 L
.252 .44314 L
.256 .44337 L
.26 .44366 L
.264 .44396 L
.268 .44426 L
.272 .44452 L
.276 .44473 L
.28 .44488 L
.284 .44497 L
.288 .44499 L
.292 .44496 L
.296 .44488 L
.3 .44477 L
.304 .44465 L
.308 .44455 L
.312 .4445 L
.316 .4445 L
.32 .44458 L
.324 .44472 L
.328 .4449 L
.332 .4451 L
.336 .44526 L
.34 .44536 L
.344 .44538 L
.348 .44531 L
.352 .44518 L
.356 .44502 L
.36 .4449 L
.364 .44483 L
.368 .44485 L
.372 .44495 L
.376 .44512 L
.38 .4453 L
.384 .44547 L
.388 .44559 L
.392 .44564 L
.396 .44563 L
.4 .44557 L
Mistroke
.404 .44549 L
.408 .44544 L
.412 .44542 L
.416 .44544 L
.42 .44549 L
.424 .44556 L
.428 .44563 L
.432 .44568 L
.436 .4457 L
.44 .44572 L
.444 .44572 L
.448 .44574 L
.452 .44576 L
.456 .44581 L
.46 .44586 L
.464 .44592 L
.468 .44597 L
.472 .44601 L
.476 .44604 L
.48 .44605 L
.484 .44606 L
.488 .44605 L
.492 .44605 L
.496 .44606 L
.5 .44609 L
.504 .44612 L
.508 .44617 L
.512 .44622 L
.516 .44627 L
.52 .4463 L
.524 .44633 L
.528 .44635 L
.532 .44637 L
.536 .44641 L
.54 .44645 L
.544 .44649 L
.548 .44653 L
.552 .44656 L
.556 .44656 L
.56 .44655 L
.564 .44654 L
.568 .44654 L
.572 .44657 L
.576 .44663 L
.58 .44671 L
.584 .4468 L
.588 .44686 L
.592 .44688 L
.596 .44688 L
.6 .44686 L
Mistroke
.604 .44684 L
.608 .44685 L
.612 .44688 L
.616 .44694 L
.62 .447 L
.624 .44705 L
.628 .44708 L
.632 .44709 L
.636 .4471 L
.64 .44711 L
.644 .44714 L
.648 .44719 L
.652 .44723 L
.656 .44727 L
.66 .4473 L
.664 .44732 L
.668 .44733 L
.672 .44735 L
.676 .44738 L
.68 .44741 L
.684 .44745 L
.688 .44748 L
.692 .4475 L
.696 .44753 L
.7 .44755 L
.704 .44758 L
.708 .44762 L
.712 .44766 L
.716 .44769 L
.72 .44772 L
.724 .44774 L
.728 .44775 L
.732 .44777 L
.736 .4478 L
.74 .44783 L
.744 .44787 L
.748 .4479 L
.752 .44793 L
.756 .44796 L
.76 .44799 L
.764 .44801 L
.768 .44804 L
.772 .44807 L
.776 .44811 L
.78 .44813 L
.784 .44815 L
.788 .44817 L
.792 .4482 L
.796 .44822 L
.8 .44826 L
Mistroke
.804 .4483 L
.808 .44833 L
.812 .44836 L
.816 .44839 L
.82 .44841 L
.824 .44844 L
.828 .44846 L
.832 .44849 L
.836 .44852 L
.84 .44855 L
.844 .44857 L
.848 .4486 L
.852 .44863 L
.856 .44866 L
.86 .44869 L
.864 .44873 L
.868 .44875 L
.872 .44878 L
.876 .4488 L
.88 .44883 L
.884 .44885 L
.888 .44888 L
.892 .44891 L
.896 .44894 L
.9 .44897 L
.904 .449 L
.908 .44903 L
.912 .44906 L
.916 .44908 L
.92 .44911 L
.924 .44914 L
.928 .44917 L
.932 .4492 L
.936 .44923 L
.94 .44926 L
.944 .44929 L
.948 .4493 L
.952 .44933 L
.956 .44935 L
.96 .44939 L
.964 .44942 L
.968 .44947 L
.972 .44949 L
.976 .44953 L
.98 .44953 L
.984 .44957 L
.988 .44957 L
.992 .44961 L
.996 .44962 L
1 .44968 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16187 L
.012 .17061 L
.016 .17945 L
.02 .18841 L
.024 .19902 L
.028 .21108 L
.032 .22279 L
.036 .23412 L
.04 .24536 L
.044 .25651 L
.048 .26759 L
.052 .27855 L
.056 .28915 L
.06 .29934 L
.064 .30947 L
.068 .31968 L
.072 .3298 L
.076 .33963 L
.08 .34916 L
.084 .35864 L
.088 .36856 L
.092 .37889 L
.096 .38915 L
.1 .39904 L
.104 .40861 L
.108 .41822 L
.112 .42833 L
.116 .43891 L
.12 .44947 L
.124 .45947 L
.128 .46855 L
.132 .47683 L
.136 .48485 L
.14 .49314 L
.144 .5021 L
.148 .51172 L
.152 .52165 L
.156 .5314 L
.16 .5404 L
.164 .54824 L
.168 .55469 L
.172 .55971 L
.176 .56339 L
.18 .5659 L
.184 .56748 L
.188 .56834 L
.192 .5687 L
.196 .56874 L
.2 .56864 L
Mistroke
.204 .56853 L
.208 .56851 L
.212 .56867 L
.216 .56902 L
.22 .56955 L
.224 .57024 L
.228 .571 L
.232 .57176 L
.236 .57244 L
.24 .57299 L
.244 .57336 L
.248 .57355 L
.252 .57356 L
.256 .57343 L
.26 .5732 L
.264 .57293 L
.268 .57264 L
.272 .57238 L
.276 .57218 L
.28 .57203 L
.284 .57196 L
.288 .57196 L
.292 .57202 L
.296 .57214 L
.3 .57228 L
.304 .57243 L
.308 .57256 L
.312 .57263 L
.316 .57263 L
.32 .57253 L
.324 .57236 L
.328 .57212 L
.332 .57188 L
.336 .57167 L
.34 .57154 L
.344 .57151 L
.348 .57159 L
.352 .57174 L
.356 .57193 L
.36 .57208 L
.364 .57216 L
.368 .57213 L
.372 .57199 L
.376 .57178 L
.38 .57153 L
.384 .57131 L
.388 .57116 L
.392 .5711 L
.396 .57111 L
.4 .57118 L
Mistroke
.404 .57126 L
.408 .57132 L
.412 .57133 L
.416 .5713 L
.42 .57123 L
.424 .57114 L
.428 .57105 L
.432 .57098 L
.436 .57094 L
.44 .57091 L
.444 .5709 L
.448 .57087 L
.452 .57083 L
.456 .57077 L
.46 .5707 L
.464 .57062 L
.468 .57055 L
.472 .57049 L
.476 .57045 L
.48 .57042 L
.484 .57041 L
.488 .5704 L
.492 .5704 L
.496 .57038 L
.5 .57035 L
.504 .57029 L
.508 .57022 L
.512 .57015 L
.516 .57008 L
.52 .57003 L
.524 .56999 L
.528 .56996 L
.532 .56993 L
.536 .56988 L
.54 .56982 L
.544 .56975 L
.548 .56969 L
.552 .56965 L
.556 .56964 L
.56 .56965 L
.564 .56966 L
.568 .56965 L
.572 .56961 L
.576 .56952 L
.58 .56941 L
.584 .5693 L
.588 .56921 L
.592 .56917 L
.596 .56917 L
.6 .56919 L
Mistroke
.604 .56921 L
.608 .56919 L
.612 .56914 L
.616 .56906 L
.62 .56897 L
.624 .5689 L
.628 .56886 L
.632 .56883 L
.636 .56882 L
.64 .5688 L
.644 .56875 L
.648 .56869 L
.652 .56863 L
.656 .56857 L
.66 .56852 L
.664 .56849 L
.668 .56846 L
.672 .56844 L
.676 .5684 L
.68 .56835 L
.684 .5683 L
.688 .56825 L
.692 .56821 L
.696 .56817 L
.7 .56813 L
.704 .56808 L
.708 .56803 L
.712 .56797 L
.716 .56792 L
.72 .56788 L
.724 .56785 L
.728 .56783 L
.732 .5678 L
.736 .56776 L
.74 .56771 L
.744 .56765 L
.748 .5676 L
.752 .56755 L
.756 .56751 L
.76 .56747 L
.764 .56743 L
.768 .56739 L
.772 .56735 L
.776 .5673 L
.78 .56725 L
.784 .56721 L
.788 .56717 L
.792 .56713 L
.796 .56709 L
.8 .56705 L
Mistroke
.804 .56701 L
.808 .56696 L
.812 .56691 L
.816 .56687 L
.82 .56682 L
.824 .56677 L
.828 .56673 L
.832 .56668 L
.836 .56664 L
.84 .56662 L
.844 .56658 L
.848 .56655 L
.852 .5665 L
.856 .56645 L
.86 .56638 L
.864 .56633 L
.868 .56628 L
.872 .56624 L
.876 .56621 L
.88 .56618 L
.884 .56615 L
.888 .56611 L
.892 .56607 L
.896 .56602 L
.9 .56596 L
.904 .56591 L
.908 .56585 L
.912 .56581 L
.916 .56576 L
.92 .56573 L
.924 .5657 L
.928 .56567 L
.932 .56563 L
.936 .5656 L
.94 .56554 L
.944 .56549 L
.948 .56542 L
.952 .56538 L
.956 .56532 L
.96 .5653 L
.964 .56525 L
.968 .56524 L
.972 .56519 L
.976 .56517 L
.98 .5651 L
.984 .56507 L
.988 .56499 L
.992 .56496 L
.996 .56487 L
1 .56486 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`04001oogooOol40002Ool00`00Oomoo`04Ool20004Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04
001oogoo0005Ool0029oo`8000aoo`D00003Ool007oo008000Qoo`03001oogoo00=oo`8000Aoo`80
00Ioo`04001oogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006
Ool0029oo`03001oogoo00ioo`04001oogoo0004Ool20005Ool00`00Oomoo`02Ool00`00Oomoo`17
Ool0029oo`8000ioo`80009oo`04001oogooOol200000goo00000002Ool30002Ool01000Ool007oo
0`0000Aoo`000000009oo`<00004Ool00000Ool200000goo00000004000017oo000007oo0P0000=o
o`0000000`0000=oo`0000001@0000Aoo`00001oo`H00003Ool0000000eoo`008WooH`0037oo000R
Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`8000=oo`80009oo`04001oogoo0002Ool2
0002Ool20003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00002Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000aoo`008Woo0P0037oo00<007ooOol01Goo0P00Egoo000ROol00`00Oomo
o`0;Ool00`00Oomoo`05Ool2001GOol0029oo`8000aoo`03001oogoo05ioo`008Woo0P002goo00<0
07ooOol0Ggoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0:Ool00`00
Oomoo`1OOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P002goo00<0
07ooOol0Ggoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000]oo`03
001oogoo05moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`09Ool00`00Oomoo`1POol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P002Woo00<007ooOol0H7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8000Eo
o`80009oo`03001oogoo065oo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol017oo
00<007oo00000P00Hgoo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool20004Ool01000
Oomoogoo0P00Hgoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool20004
Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogoo
Ool20003Ool00`00Oomoo`1WOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001o
ogoo008000=oo`03001oogoo06Moo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@0
07ooOol000=oo`03001oogoo06Qoo`002goo0P002Woo0P000goo0`000goo0P000Woo00<007ooOol0
J7oo000ROol200000goo0000001ZOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<0
06aoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo
008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo
0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00
KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo
0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomo
o`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@00
0Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo
00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Ao
o`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Io
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0
2Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool0
0`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001o
ogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`00
2goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo
00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo
00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo0`002Goo10000goo00@007oo
Ool000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=o
o`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<0
07oo00000`000goo00@007ooOol000Eoo`00:7oo00@007ooOol000Qoo`03001oogoo00Aoo`04001o
ogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06
001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo
00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol00P001goo1@000goo0P0027oo00<007ooOol0
0goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009o
o`D000=oo`8000Ioo`00:7oo00@007ooOomoo`8006=oo`00:7oo00<007ooOol00goo00<007ooOol0
H7oo000XOomM000<Ool002Qoo`03001oogoo00Aoo`8000Uoo`03001oogoo011oo`03001oogoo00mo
o`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol01Goo0P00Ggoo
000XOol00`00Oomoo`06Ool2001NOol002Qoo`03001oogoo00Moo`8005eoo`00:7oo00<007ooOol0
27oo0P00G7oo000XOol00`00Oomoo`09Ool2001KOol000]oo`8000Aoo`03001oogoo00=oo`8000Ao
o`8000=oo`<000=oo`03001oogoo00Yoo`03001oogoo05Uoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000=Ool00`00Oomoo`1HOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000=Ool00`00Oomoo`1HOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000eoo`03
001oogoo05Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo
00<007ooOol037oo0`00Egoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`001Woo00<007ooOol03Woo2@000Woo0P00Bgoo000;Ool2000:Ool20004Ool20002Ool50002Ool0
0`00Oomoo`0FOol400000goo0000000m000<Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Ao
o`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00
Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001o
ogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]o
o`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo
0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol0
00]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`00
17oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`00
17oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool0
00=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04
001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001ao
o`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002
Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomo
o`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004
Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002
Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool5
0003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`00
17oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`0077ooJ@0037oo000LOol20002Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yo
o`0077oo00<007oo0000LWoo000LOol3001bOol001aoo`04001oogoo001aOol001aoo`04001oogoo
001aOol001aoo`800003Ool007oo071oo`0077oo00D007ooOomoo`00071oo`0077oo00D007ooOomo
o`00071oo`0077oo0P000Woo00<007ooOol0KWoo000LOol00`00Oomoo`02Ool00`00Oomoo`1]Ool0
01aoo`8000=oo`03001oogoo06eoo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0
0goo00<007ooOol0K7oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo00=o
o`03001oogoo06aoo`002Woo00@007ooOol000]oo`03001oogoo008000Aoo`03001oogoo06aoo`00
2Woo00@007ooOol000]oo`04001oogoo0005Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0007Ool4
0003Ool00`00Oomoo`04Ool00`00Oomoo`1[Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2
0005Ool00`00Oomoo`1[Ool000]oo`8000Qoo`D0009oo`03001oogoo00Eoo`03001oogoo06Yoo`00
77oo00<007ooOol01Goo00<007ooOol0JWoo000LOol20006Ool00`00Oomoo`1ZOol001aoo`03001o
ogoo00Ioo`03001oogoo06Uoo`0077oo0P001goo00<007ooOol0JGoo000LOol00`00Oomoo`07Ool0
0`00Oomoo`1XOol001aoo`03001oogoo00Moo`03001oogoo06Qoo`0077oo0P002Goo00<007ooOol0
Igoo000FOol30003Ool00`00Oomoo`08Ool00`00Oomoo`1WOol001Moo`03001oogoo009oo`03001o
ogoo00Qoo`03001oogoo06Moo`005goo00<007ooOol00Woo0P002Woo00<007ooOol0IWoo000GOol0
0`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`1VOol001Moo`03001oogoo009oo`03001oogoo
00Yoo`03001oogoo06Eoo`005Woo0P0017oo0P002goo00<007ooOol0IGoo000GOol00`00Oomoo`02
Ool00`00Oomoo`0:Ool00`00Oomoo`1UOol001aoo`03001oogoo00]oo`03001oogoo06Aoo`0077oo
0P0037oo00<007ooOol0I7oo000LOol00`00Oomoo`0<Ool00`00Oomoo`1SOol001aoo`8000ioo`03
001oogoo069oo`0077oo00<007ooOol03Goo00<007ooOol0HWoo000LOol00`00Oomoo`0=Ool00`00
Oomoo`1ROol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8000ioo`8006=oo`002goo00<007oo
Ool01goo00D007ooOomoo`00009oo`03001oogoo00ioo`03001oogoo065oo`002goo00<007ooOol0
2goo00@007ooOol0015oo`03001oogoo061oo`002goo00<007ooOol02goo00<007ooOol00P0047oo
1P0087oo<@0037oo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`0DOolR000lOol000Yoo`80
00Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000L
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(37575\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .56082 m
.008 .55878 L
.012 .55291 L
.016 .54492 L
.02 .5354 L
.024 .52457 L
.028 .51324 L
.032 .50042 L
.036 .48714 L
.04 .47494 L
.044 .46463 L
.048 .45694 L
.052 .45241 L
.056 .45102 L
.06 .45172 L
.064 .45261 L
.068 .45324 L
.072 .45436 L
.076 .45501 L
.08 .45252 L
.084 .44569 L
.088 .43555 L
.092 .4237 L
.096 .41114 L
.1 .39743 L
.104 .38149 L
.108 .36435 L
.112 .34894 L
.116 .3374 L
.12 .32989 L
.124 .32459 L
.128 .31869 L
.132 .31095 L
.136 .302 L
.14 .29309 L
.144 .28529 L
.148 .27834 L
.152 .271 L
.156 .2624 L
.16 .25253 L
.164 .24281 L
.168 .23563 L
.172 .23325 L
.176 .23716 L
.18 .24738 L
.184 .26255 L
.188 .28028 L
.192 .29774 L
.196 .31233 L
.2 .3222 L
Mistroke
.204 .3265 L
.208 .32547 L
.212 .32022 L
.216 .31243 L
.22 .30393 L
.224 .29635 L
.228 .29079 L
.232 .28775 L
.236 .28709 L
.24 .28825 L
.244 .29051 L
.248 .29319 L
.252 .29588 L
.256 .29846 L
.26 .301 L
.264 .30357 L
.268 .30611 L
.272 .30831 L
.276 .30965 L
.28 .30952 L
.284 .30748 L
.288 .30352 L
.292 .29817 L
.296 .29252 L
.3 .28799 L
.304 .28592 L
.308 .28715 L
.312 .29165 L
.316 .29842 L
.32 .30571 L
.324 .31148 L
.328 .31402 L
.332 .31251 L
.336 .3073 L
.34 .29985 L
.344 .29234 L
.348 .28695 L
.352 .2852 L
.356 .28749 L
.36 .29295 L
.364 .29973 L
.368 .30567 L
.372 .30897 L
.376 .30885 L
.38 .30569 L
.384 .30087 L
.388 .29617 L
.392 .29315 L
.396 .29259 L
.4 .29436 L
Mistroke
.404 .29751 L
.408 .30074 L
.412 .30291 L
.416 .3034 L
.42 .30227 L
.424 .30014 L
.428 .29784 L
.432 .29614 L
.436 .29546 L
.44 .29584 L
.444 .29697 L
.448 .29846 L
.452 .29993 L
.456 .30112 L
.46 .30185 L
.464 .30195 L
.468 .30134 L
.472 .30005 L
.476 .29831 L
.48 .2966 L
.484 .29552 L
.488 .29558 L
.492 .2969 L
.496 .29906 L
.5 .30117 L
.504 .30226 L
.508 .30179 L
.512 .29992 L
.516 .29752 L
.52 .29578 L
.524 .29563 L
.528 .29724 L
.532 .29988 L
.536 .30222 L
.54 .30297 L
.544 .30164 L
.548 .2988 L
.552 .29584 L
.556 .29425 L
.56 .29486 L
.564 .29738 L
.568 .30058 L
.572 .30282 L
.576 .30299 L
.58 .30106 L
.584 .29812 L
.588 .29578 L
.592 .29527 L
.596 .29676 L
.6 .29928 L
Mistroke
.604 .30135 L
.608 .30182 L
.612 .30049 L
.616 .29819 L
.62 .29628 L
.624 .29584 L
.628 .2971 L
.632 .29928 L
.636 .30109 L
.64 .30148 L
.644 .30031 L
.648 .29838 L
.652 .29685 L
.656 .29657 L
.66 .29756 L
.664 .29911 L
.668 .30025 L
.672 .30037 L
.676 .29949 L
.68 .29822 L
.684 .29733 L
.688 .29733 L
.692 .29815 L
.696 .29923 L
.7 .29991 L
.704 .29981 L
.708 .29909 L
.712 .29826 L
.716 .29781 L
.72 .29794 L
.724 .29845 L
.728 .29896 L
.732 .29918 L
.736 .29906 L
.74 .29871 L
.744 .29835 L
.748 .29815 L
.752 .29823 L
.756 .29859 L
.76 .29906 L
.764 .29934 L
.768 .29922 L
.772 .29872 L
.776 .29812 L
.78 .2978 L
.784 .29797 L
.788 .29847 L
.792 .29895 L
.796 .29915 L
.8 .29899 L
Mistroke
.804 .29869 L
.808 .29844 L
.812 .29837 L
.816 .29845 L
.82 .29859 L
.824 .29868 L
.828 .29864 L
.832 .29846 L
.836 .29824 L
.84 .29821 L
.844 .29845 L
.848 .29886 L
.852 .29913 L
.856 .29894 L
.86 .29843 L
.864 .29801 L
.868 .29803 L
.872 .29851 L
.876 .29896 L
.88 .29884 L
.884 .29831 L
.888 .29786 L
.892 .298 L
.896 .29879 L
.9 .29944 L
.904 .29926 L
.908 .29841 L
.912 .29748 L
.916 .29736 L
.92 .29826 L
.924 .29925 L
.928 .2995 L
.932 .29889 L
.936 .29789 L
.94 .2975 L
.944 .29809 L
.948 .29885 L
.952 .29907 L
.956 .29872 L
.96 .29797 L
.964 .29775 L
.968 .29842 L
.972 .29893 L
.976 .29893 L
.98 .29851 L
.984 .2977 L
.988 .2977 L
.992 .29858 L
.996 .29902 L
1 .29892 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .22438 m
.008 .21914 L
.012 .21738 L
.016 .21921 L
.02 .21984 L
.024 .21922 L
.028 .21824 L
.032 .21713 L
.036 .21718 L
.04 .21861 L
.044 .22146 L
.048 .22553 L
.052 .23006 L
.056 .2348 L
.06 .23943 L
.064 .24399 L
.068 .24858 L
.072 .25314 L
.076 .25746 L
.08 .26153 L
.084 .26563 L
.088 .26997 L
.092 .27449 L
.096 .27901 L
.1 .2834 L
.104 .2878 L
.108 .29259 L
.112 .29788 L
.116 .30343 L
.12 .30892 L
.124 .31412 L
.128 .31919 L
.132 .32453 L
.136 .33041 L
.14 .33681 L
.144 .34345 L
.148 .34991 L
.152 .35599 L
.156 .3618 L
.16 .36764 L
.164 .37392 L
.168 .38087 L
.172 .38848 L
.176 .39649 L
.18 .40446 L
.184 .41194 L
.188 .41855 L
.192 .42407 L
.196 .42844 L
.2 .43173 L
Mistroke
.204 .43413 L
.208 .43584 L
.212 .43707 L
.216 .43801 L
.22 .4388 L
.224 .43952 L
.228 .44021 L
.232 .44088 L
.236 .44152 L
.24 .44212 L
.244 .44265 L
.248 .4431 L
.252 .44347 L
.256 .44374 L
.26 .44393 L
.264 .44404 L
.268 .44409 L
.272 .44408 L
.276 .44405 L
.28 .44401 L
.284 .444 L
.288 .44402 L
.292 .4441 L
.296 .44424 L
.3 .44442 L
.304 .44463 L
.308 .44483 L
.312 .44498 L
.316 .44506 L
.32 .44505 L
.324 .44496 L
.328 .44483 L
.332 .44469 L
.336 .44459 L
.34 .44456 L
.344 .44462 L
.348 .44475 L
.352 .44493 L
.356 .44512 L
.36 .44528 L
.364 .44537 L
.368 .44539 L
.372 .44535 L
.376 .44528 L
.38 .44521 L
.384 .44516 L
.388 .44516 L
.392 .44519 L
.396 .44525 L
.4 .44533 L
Mistroke
.404 .44539 L
.408 .44543 L
.412 .44546 L
.416 .44547 L
.42 .44548 L
.424 .44549 L
.428 .44552 L
.432 .44557 L
.436 .44562 L
.44 .44568 L
.444 .44573 L
.448 .44577 L
.452 .44579 L
.456 .4458 L
.46 .4458 L
.464 .44579 L
.468 .4458 L
.472 .44581 L
.476 .44584 L
.48 .44588 L
.484 .44593 L
.488 .44598 L
.492 .44603 L
.496 .44606 L
.5 .44609 L
.504 .4461 L
.508 .44613 L
.512 .44616 L
.516 .4462 L
.52 .44624 L
.524 .44628 L
.528 .4463 L
.532 .4463 L
.536 .44629 L
.54 .44628 L
.544 .44629 L
.548 .44633 L
.552 .4464 L
.556 .44648 L
.56 .44656 L
.564 .44661 L
.568 .44663 L
.572 .44662 L
.576 .44659 L
.58 .44658 L
.584 .44659 L
.588 .44664 L
.592 .4467 L
.596 .44676 L
.6 .44681 L
Mistroke
.604 .44683 L
.608 .44684 L
.612 .44685 L
.616 .44686 L
.62 .44689 L
.624 .44694 L
.628 .44698 L
.632 .44703 L
.636 .44705 L
.64 .44707 L
.644 .44708 L
.648 .4471 L
.652 .44712 L
.656 .44716 L
.66 .44719 L
.664 .44723 L
.668 .44726 L
.672 .44728 L
.676 .44731 L
.68 .44734 L
.684 .44737 L
.688 .44741 L
.692 .44744 L
.696 .44747 L
.7 .44749 L
.704 .4475 L
.708 .44752 L
.712 .44755 L
.716 .44758 L
.72 .44762 L
.724 .44766 L
.728 .44769 L
.732 .44771 L
.736 .44774 L
.74 .44776 L
.744 .44779 L
.748 .44782 L
.752 .44785 L
.756 .44788 L
.76 .44791 L
.764 .44793 L
.768 .44795 L
.772 .44798 L
.776 .44801 L
.78 .44804 L
.784 .44808 L
.788 .44811 L
.792 .44814 L
.796 .44817 L
.8 .44819 L
Mistroke
.804 .44822 L
.808 .44824 L
.812 .44827 L
.816 .44829 L
.82 .44831 L
.824 .44834 L
.828 .44838 L
.832 .44841 L
.836 .44845 L
.84 .44849 L
.844 .44851 L
.848 .44853 L
.852 .44855 L
.856 .44857 L
.86 .44859 L
.864 .44862 L
.868 .44866 L
.872 .4487 L
.876 .44873 L
.88 .44876 L
.884 .44879 L
.888 .44881 L
.892 .44883 L
.896 .44886 L
.9 .44888 L
.904 .44891 L
.908 .44894 L
.912 .44898 L
.916 .449 L
.92 .44904 L
.924 .44906 L
.928 .44909 L
.932 .44911 L
.936 .44914 L
.94 .44916 L
.944 .4492 L
.948 .44922 L
.952 .44926 L
.956 .44928 L
.96 .44933 L
.964 .44934 L
.968 .44938 L
.972 .44939 L
.976 .44942 L
.98 .44943 L
.984 .44948 L
.988 .4495 L
.992 .44955 L
.996 .44956 L
1 .44962 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .1678 L
.012 .17343 L
.016 .17981 L
.02 .18674 L
.024 .19218 L
.028 .19631 L
.032 .20066 L
.036 .20558 L
.04 .21223 L
.044 .22067 L
.048 .23021 L
.052 .24058 L
.056 .25106 L
.06 .26154 L
.064 .27212 L
.068 .28288 L
.072 .29366 L
.076 .30427 L
.08 .3146 L
.084 .3248 L
.088 .33512 L
.092 .34541 L
.096 .35526 L
.1 .36446 L
.104 .37326 L
.108 .38199 L
.112 .39088 L
.116 .39974 L
.12 .40812 L
.124 .41586 L
.128 .42325 L
.132 .43071 L
.136 .43865 L
.14 .44703 L
.144 .45539 L
.148 .46322 L
.152 .47022 L
.156 .47649 L
.16 .48249 L
.164 .48876 L
.168 .49575 L
.172 .50357 L
.176 .51205 L
.18 .52083 L
.184 .52943 L
.188 .53745 L
.192 .5446 L
.196 .55072 L
.2 .5558 L
Mistroke
.204 .5599 L
.208 .56312 L
.212 .56558 L
.216 .56739 L
.22 .56868 L
.224 .56955 L
.228 .57008 L
.232 .57039 L
.236 .57054 L
.24 .5706 L
.244 .57063 L
.248 .57067 L
.252 .57074 L
.256 .57085 L
.26 .571 L
.264 .5712 L
.268 .57142 L
.272 .57167 L
.276 .57191 L
.28 .57214 L
.284 .57231 L
.288 .5724 L
.292 .5724 L
.296 .5723 L
.3 .57213 L
.304 .57192 L
.308 .57172 L
.312 .57157 L
.316 .5715 L
.32 .57153 L
.324 .57165 L
.328 .57183 L
.332 .57201 L
.336 .57214 L
.34 .57217 L
.344 .5721 L
.348 .57193 L
.352 .5717 L
.356 .57147 L
.36 .57127 L
.364 .57115 L
.368 .57112 L
.372 .57116 L
.376 .57124 L
.38 .57132 L
.384 .57138 L
.388 .57138 L
.392 .57133 L
.396 .57124 L
.4 .57114 L
Mistroke
.404 .57105 L
.408 .57099 L
.412 .57095 L
.416 .57094 L
.42 .57092 L
.424 .57089 L
.428 .57084 L
.432 .57078 L
.436 .5707 L
.44 .57063 L
.444 .57056 L
.448 .57051 L
.452 .57047 L
.456 .57045 L
.46 .57045 L
.464 .57044 L
.468 .57043 L
.472 .5704 L
.476 .57036 L
.48 .5703 L
.484 .57023 L
.488 .57016 L
.492 .5701 L
.496 .57005 L
.5 .57001 L
.504 .56997 L
.508 .56994 L
.512 .56989 L
.516 .56983 L
.52 .56978 L
.524 .56972 L
.528 .56969 L
.532 .56968 L
.536 .56969 L
.54 .56969 L
.544 .56967 L
.548 .56961 L
.552 .56952 L
.556 .56941 L
.56 .56931 L
.564 .56923 L
.568 .5692 L
.572 .56921 L
.576 .56923 L
.58 .56923 L
.584 .56921 L
.588 .56915 L
.592 .56907 L
.596 .56899 L
.6 .56892 L
Mistroke
.604 .56888 L
.608 .56886 L
.612 .56884 L
.616 .56882 L
.62 .56877 L
.624 .56871 L
.628 .56865 L
.632 .56859 L
.636 .56854 L
.64 .56851 L
.644 .56849 L
.648 .56846 L
.652 .56842 L
.656 .56837 L
.66 .56832 L
.664 .56827 L
.668 .56823 L
.672 .56819 L
.676 .56815 L
.68 .56811 L
.684 .56805 L
.688 .568 L
.692 .56794 L
.696 .5679 L
.7 .56788 L
.704 .56785 L
.708 .56782 L
.712 .56778 L
.716 .56773 L
.72 .56767 L
.724 .56762 L
.728 .56757 L
.732 .56753 L
.736 .56749 L
.74 .56745 L
.744 .56741 L
.748 .56737 L
.752 .56732 L
.756 .56728 L
.76 .56724 L
.764 .5672 L
.768 .56716 L
.772 .56712 L
.776 .56707 L
.78 .56702 L
.784 .56697 L
.788 .56693 L
.792 .56689 L
.796 .56685 L
.8 .56681 L
Mistroke
.804 .56676 L
.808 .56671 L
.812 .56667 L
.816 .56663 L
.82 .5666 L
.824 .56656 L
.828 .56652 L
.832 .56647 L
.836 .56641 L
.84 .56636 L
.844 .56631 L
.848 .56627 L
.852 .56623 L
.856 .5662 L
.86 .56617 L
.864 .56613 L
.868 .56609 L
.872 .56604 L
.876 .56599 L
.88 .56594 L
.884 .56588 L
.888 .56584 L
.892 .56579 L
.896 .56576 L
.9 .56572 L
.904 .56569 L
.908 .56565 L
.912 .56561 L
.916 .56556 L
.92 .56552 L
.924 .56546 L
.928 .56542 L
.932 .56536 L
.936 .56532 L
.94 .56527 L
.944 .56524 L
.948 .56519 L
.952 .56518 L
.956 .56513 L
.96 .56511 L
.964 .56505 L
.968 .565 L
.972 .56492 L
.976 .56488 L
.98 .56481 L
.984 .5648 L
.988 .56475 L
.992 .56475 L
.996 .5647 L
1 .56469 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000?Ool20002Ool01000Oomoo`001goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8000ioo`03001oo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0002
Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0
2goo1@000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04
001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Ao
o`03001oogoo009oo`8000aoo`80009oo`04001oogoo0002Ool00`00Oomoo`04Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo00]oo`80009oo`03001oogoo009oo`8000Aoo`8000=oo`8004]oo`008Woo0P0037oo00<0
07ooOol00Woo00D007ooOol007oo008000=oo`03001oo`00009oo`80009oo`<00004Ool000000002
Ool200001Goo00000000Ool00P0000Aoo`00001oo`800004Ool00000Ool300000goo0000000;0000
0goo0000000200000goo0000000400000goo0000000=Ool0029oof<000aoo`008Woo00D007ooOomo
o`0000=oo`04001oogooOol20002Ool00`00Oomoo`030002Ool01000Oomoo`000goo0P000Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool00`00Oomoo`0:Ool0029oo`8000Yoo`03001oogoo00Eoo`8005Uoo`008Woo00<007ooOol027oo
0P00HWoo000ROol20009Ool00`00Oomoo`1QOol0029oo`8000Uoo`03001oogoo065oo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo00<007ooOol027oo00<007ooOol0HGoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Uoo`03001oogoo065oo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20008Ool00`00Oomoo`1ROol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0HWoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Qoo`03001oogoo069o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool20008Ool00`00Oomoo`1ROol000]o
o`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo06=oo`002goo0P0017oo
00<007ooOol00goo0P000Woo1@000Woo0P001goo00<007ooOol0Hgoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0002Ool20003Ool200000goo001oo`1UOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol00Woo00@007oo000006Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P000Woo00<007ooOol0J7oo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`020002Ool00`00Oomoo`1XOol000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo0003Ool00`00Oomoo`1XOol000]o
o`8000Yoo`8000=oo`<000=oo`800003Ool007oo06Yoo`008Woo00@007ooOol006]oo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`03001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00H007oo
Ool007oo001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000R
Ool2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00
Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<0
07ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001o
ogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0
015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001o
ogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04
001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D0
00=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01@00Oomoo`00Ool010000goo1@001goo00D007ooOomoo`00009oo`04001oogoo0007Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009o
o`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01000Oomoo`00
0Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo
1@000Woo00<007ooOol00goo00<007ooOol01goo00@007ooOol0009oo`03001oogoo00Eoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol0
17oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol00goo0P0017oo10000goo00@0
07ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@0
00=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol017oo0P000goo00<007ooOol0
17oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007oo
Ool017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003
Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`05Ool20002Ool50003Ool20008
Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo
0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`06Ool2001NOol002Qoo`03001oogoo
00Moo`03001oogoo05aoo`00:7ooG@0037oo000XOol00`00Oomoo`08Ool20005Ool00`00Oomoo`0@
Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001o
ogoo00Uoo`8005]oo`00:7oo00<007ooOol02Woo00<007ooOol0FGoo000XOol00`00Oomoo`0;Ool0
0`00Oomoo`1HOol002Qoo`03001oogoo00]oo`8005Uoo`00:7oo00<007ooOol037oo00<007ooOol0
Egoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0<Ool2001H
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00
3goo00<007ooOol0EWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool0
1000Oomoo`0047oo00<007ooOol0EGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0005Ool00`00Oomoo`02000?Ool00`00Oomoo`1EOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00D007ooOol007oo00@000=oo`03001oogoo00moo`03001oogoo05Aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo011oo`X0009oo`8004Qo
o`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol06Goo0`0000=oo`000000>`0037oo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Ao
o`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<0
07ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000
Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1Y
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001o
ogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo
009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00
Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo
000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol0
01aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`80
00Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomo
o`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05
001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo
000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo
10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qo
o`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo
00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo
0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`80
00Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo0P000Woo
00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`<0079oo`0077oo1000LGoo000LOol0
0`00Oomoo`02001`Ool001aoo`05001oogooOol0001`Ool001aoo`80009oo`8006moo`0077oo00<0
07ooOol00Woo00<007ooOol0KGoo000LOol00`00Oomoo`03Ool00`00Oomoo`1/Ool001aoo`8000Ao
o`03001oogoo06aoo`0077oo00<007ooOol00goo00<007ooOol0K7oo000LOol20004Ool00`00Oomo
o`1/Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo00Aoo`03001oogoo06]oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`04Ool00`00Oomoo`1[Ool000Yo
o`04001oogoo000;Ool00`00Oomoo`020006Ool00`00Oomoo`1ZOol000Yoo`04001oogoo000;Ool0
1000Oomoo`001goo00<007ooOol0JWoo000:Ool01000Oomoo`001goo10000goo00<007ooOol01Goo
00<007ooOol0JWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P001goo00<007ooOol0JGoo
000;Ool20008Ool50002Ool00`00Oomoo`06Ool00`00Oomoo`1YOol001aoo`03001oogoo00Moo`03
001oogoo06Qoo`0077oo0P0027oo00<007ooOol0J7oo000LOol00`00Oomoo`08Ool00`00Oomoo`1W
Ool001aoo`8000Uoo`03001oogoo06Moo`0077oo00<007ooOol027oo00<007ooOol0Igoo000LOol0
0`00Oomoo`09Ool00`00Oomoo`1VOol001aoo`8000Yoo`03001oogoo06Ioo`005Woo0`000goo00<0
07ooOol02Woo00<007ooOol0IGoo000GOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`1U
Ool001Moo`03001oogoo009oo`8000aoo`03001oogoo06Aoo`005goo00<007ooOol00Woo00<007oo
Ool02goo00<007ooOol0I7oo000GOol00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`1SOol0
01Ioo`8000Aoo`8000eoo`8006Aoo`005goo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol0
HWoo000LOol00`00Oomoo`0=Ool2001SOol001aoo`8000moo`03001oogoo065oo`0077oo00<007oo
Ool03goo00<007ooOol0H7oo000LOol2000@Ool00`00Oomoo`1POol001aoo`03001oogoo00moo`80
065oo`0077oo00<007ooOol047oo00<007ooOol0Ggoo000:Ool30004Ool00`00Oomoo`02Ool30003
Ool2000BOol00`00Oomoo`1NOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomo
o`0AOol00`00Oomoo`1NOol000]oo`03001oogoo00]oo`04001oogoo000COol2001OOol000]oo`03
001oogoo00]oo`03001oogoo008001Aoo`8001iooc<000aoo`002goo00<007ooOol01goo10000goo
00<007ooOol05Goo7P00?goo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03
001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(37742\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .51343 m
.008 .50696 L
.012 .50182 L
.016 .49889 L
.02 .49818 L
.024 .4993 L
.028 .50157 L
.032 .50377 L
.036 .50565 L
.04 .50868 L
.044 .5121 L
.048 .51343 L
.052 .51163 L
.056 .50543 L
.06 .49454 L
.064 .479 L
.068 .46016 L
.072 .44085 L
.076 .42229 L
.08 .4038 L
.084 .38557 L
.088 .36914 L
.092 .35604 L
.096 .34641 L
.1 .33858 L
.104 .33017 L
.108 .32076 L
.112 .31175 L
.116 .30356 L
.12 .29498 L
.124 .28444 L
.128 .27152 L
.132 .25831 L
.136 .24854 L
.14 .24469 L
.144 .24689 L
.148 .25346 L
.152 .26197 L
.156 .27118 L
.16 .2811 L
.164 .29187 L
.168 .30298 L
.172 .31264 L
.176 .31827 L
.18 .31786 L
.184 .31071 L
.188 .29803 L
.192 .28255 L
.196 .26751 L
.2 .25587 L
Mistroke
.204 .2494 L
.208 .24855 L
.212 .25256 L
.216 .25988 L
.22 .26881 L
.224 .27788 L
.228 .28614 L
.232 .29319 L
.236 .29903 L
.24 .3038 L
.244 .30755 L
.248 .31014 L
.252 .31123 L
.256 .31044 L
.26 .30761 L
.264 .303 L
.268 .29741 L
.272 .29208 L
.276 .28843 L
.28 .2876 L
.284 .29008 L
.288 .29544 L
.292 .3024 L
.296 .30907 L
.3 .31353 L
.304 .31438 L
.308 .31125 L
.312 .30492 L
.316 .29712 L
.32 .2901 L
.324 .28585 L
.328 .28557 L
.332 .28919 L
.336 .29545 L
.34 .3023 L
.344 .30761 L
.348 .30985 L
.352 .30859 L
.356 .30456 L
.36 .29936 L
.364 .29482 L
.368 .29238 L
.372 .29258 L
.376 .29503 L
.38 .29858 L
.384 .30184 L
.388 .30368 L
.392 .30362 L
.396 .30192 L
.4 .29939 L
Mistroke
.404 .29701 L
.408 .29555 L
.412 .29533 L
.416 .2962 L
.42 .29772 L
.424 .29937 L
.428 .30075 L
.432 .30164 L
.436 .30196 L
.44 .30169 L
.444 .30081 L
.448 .29942 L
.452 .29778 L
.456 .29635 L
.46 .29566 L
.464 .29608 L
.468 .29756 L
.472 .29964 L
.476 .30147 L
.48 .30223 L
.484 .30151 L
.488 .29959 L
.492 .29736 L
.496 .29592 L
.5 .29604 L
.504 .29774 L
.508 .30023 L
.512 .30228 L
.516 .30276 L
.52 .30129 L
.524 .29848 L
.528 .29569 L
.532 .29436 L
.536 .2952 L
.54 .29786 L
.544 .301 L
.548 .30307 L
.552 .30303 L
.556 .30096 L
.56 .29797 L
.564 .29567 L
.568 .29525 L
.572 .29683 L
.576 .29945 L
.58 .30155 L
.584 .30196 L
.588 .30053 L
.592 .29816 L
.596 .29626 L
.6 .29591 L
Mistroke
.604 .29726 L
.608 .29948 L
.612 .30127 L
.616 .30161 L
.62 .30037 L
.624 .29833 L
.628 .29675 L
.632 .2965 L
.636 .29763 L
.64 .29932 L
.644 .30052 L
.648 .30056 L
.652 .29953 L
.656 .29813 L
.66 .29723 L
.664 .29733 L
.668 .29829 L
.672 .29948 L
.676 .30018 L
.68 .3 L
.684 .29912 L
.688 .29814 L
.692 .29765 L
.696 .29789 L
.7 .29858 L
.704 .29924 L
.708 .29946 L
.712 .29917 L
.716 .29865 L
.72 .29823 L
.724 .29815 L
.728 .29844 L
.732 .2989 L
.736 .29929 L
.74 .29937 L
.744 .29907 L
.748 .29852 L
.752 .29805 L
.756 .29794 L
.76 .29827 L
.764 .29882 L
.768 .29922 L
.772 .29922 L
.776 .29886 L
.78 .29845 L
.784 .29829 L
.788 .29845 L
.792 .29879 L
.796 .29903 L
.8 .29897 L
Mistroke
.804 .29863 L
.808 .2982 L
.812 .29797 L
.816 .29814 L
.82 .29867 L
.824 .29926 L
.828 .29949 L
.832 .29912 L
.836 .29837 L
.84 .2978 L
.844 .29784 L
.848 .2985 L
.852 .29919 L
.856 .29928 L
.86 .29871 L
.864 .29797 L
.868 .29773 L
.872 .2983 L
.876 .29914 L
.88 .29952 L
.884 .29918 L
.888 .29836 L
.892 .29778 L
.896 .29788 L
.9 .29831 L
.904 .29868 L
.908 .29874 L
.912 .29857 L
.916 .29863 L
.92 .29895 L
.924 .29906 L
.928 .29871 L
.932 .29807 L
.936 .29748 L
.94 .29764 L
.944 .29851 L
.948 .29924 L
.952 .29945 L
.956 .29905 L
.96 .29819 L
.964 .29785 L
.968 .29808 L
.972 .29827 L
.976 .29851 L
.98 .29855 L
.984 .29833 L
.988 .29859 L
.992 .29892 L
.996 .29869 L
1 .29837 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .187 m
.008 .18726 L
.012 .18751 L
.016 .18779 L
.02 .18848 L
.024 .18938 L
.028 .18983 L
.032 .19009 L
.036 .1909 L
.04 .19219 L
.044 .1928 L
.048 .19255 L
.052 .19168 L
.056 .19057 L
.06 .1903 L
.064 .19126 L
.068 .19369 L
.072 .19745 L
.076 .20195 L
.08 .20695 L
.084 .21236 L
.088 .21817 L
.092 .22419 L
.096 .23021 L
.1 .23608 L
.104 .24191 L
.108 .24796 L
.112 .25427 L
.116 .26059 L
.12 .26672 L
.124 .27271 L
.128 .2788 L
.132 .2853 L
.136 .29219 L
.14 .29914 L
.144 .30581 L
.148 .31205 L
.152 .31802 L
.156 .32406 L
.16 .33036 L
.164 .33688 L
.168 .34333 L
.172 .34936 L
.176 .35481 L
.18 .35979 L
.184 .36466 L
.188 .36987 L
.192 .37574 L
.196 .38242 L
.2 .38977 L
Mistroke
.204 .39747 L
.208 .40511 L
.212 .41228 L
.216 .41869 L
.22 .42414 L
.224 .42859 L
.228 .4321 L
.232 .43477 L
.236 .43676 L
.24 .43821 L
.244 .43926 L
.248 .44003 L
.252 .4406 L
.256 .44105 L
.26 .44145 L
.264 .44183 L
.268 .44222 L
.272 .44262 L
.276 .44303 L
.28 .44342 L
.284 .44375 L
.288 .444 L
.292 .44416 L
.296 .44421 L
.3 .44419 L
.304 .44413 L
.308 .44407 L
.312 .44406 L
.316 .44411 L
.32 .44424 L
.324 .44443 L
.328 .44464 L
.332 .44484 L
.336 .44499 L
.34 .44507 L
.344 .44508 L
.348 .44503 L
.352 .44496 L
.356 .4449 L
.36 .44487 L
.364 .44488 L
.368 .44493 L
.372 .44501 L
.376 .44509 L
.38 .44515 L
.384 .44519 L
.388 .44521 L
.392 .44522 L
.396 .44522 L
.4 .44524 L
Mistroke
.404 .44528 L
.408 .44533 L
.412 .44539 L
.416 .44544 L
.42 .44549 L
.424 .44551 L
.428 .44553 L
.432 .44553 L
.436 .44553 L
.44 .44554 L
.444 .44554 L
.448 .44556 L
.452 .4456 L
.456 .44564 L
.46 .44569 L
.464 .44574 L
.468 .44578 L
.472 .44582 L
.476 .44584 L
.48 .44586 L
.484 .44589 L
.488 .44592 L
.492 .44595 L
.496 .44599 L
.5 .44602 L
.504 .44604 L
.508 .44604 L
.512 .44603 L
.516 .44603 L
.52 .44605 L
.524 .4461 L
.528 .44617 L
.532 .44625 L
.536 .44632 L
.54 .44636 L
.544 .44637 L
.548 .44636 L
.552 .44634 L
.556 .44633 L
.56 .44635 L
.564 .44639 L
.568 .44645 L
.572 .44652 L
.576 .44656 L
.58 .44659 L
.584 .4466 L
.588 .4466 L
.592 .44662 L
.596 .44664 L
.6 .44669 L
Mistroke
.604 .44673 L
.608 .44678 L
.612 .4468 L
.616 .44682 L
.62 .44684 L
.624 .44685 L
.628 .44688 L
.632 .44691 L
.636 .44694 L
.64 .44698 L
.644 .44701 L
.648 .44703 L
.652 .44706 L
.656 .44709 L
.66 .44713 L
.664 .44716 L
.668 .44719 L
.672 .44722 L
.676 .44723 L
.68 .44725 L
.684 .44727 L
.688 .4473 L
.692 .44733 L
.696 .44737 L
.7 .44741 L
.704 .44744 L
.708 .44747 L
.712 .44749 L
.716 .44751 L
.72 .44754 L
.724 .44757 L
.728 .4476 L
.732 .44763 L
.736 .44766 L
.74 .44768 L
.744 .4477 L
.748 .44773 L
.752 .44776 L
.756 .44779 L
.76 .44783 L
.764 .44786 L
.768 .44789 L
.772 .44791 L
.776 .44794 L
.78 .44797 L
.784 .44799 L
.788 .44802 L
.792 .44804 L
.796 .44807 L
.8 .44809 L
Mistroke
.804 .44812 L
.808 .44816 L
.812 .4482 L
.816 .44824 L
.82 .44827 L
.824 .44829 L
.828 .4483 L
.832 .44832 L
.836 .44834 L
.84 .44837 L
.844 .4484 L
.848 .44844 L
.852 .44848 L
.856 .44851 L
.86 .44854 L
.864 .44857 L
.868 .44859 L
.872 .44861 L
.876 .44863 L
.88 .44865 L
.884 .44868 L
.888 .44872 L
.892 .44875 L
.896 .44879 L
.9 .44882 L
.904 .44885 L
.908 .44887 L
.912 .4489 L
.916 .44892 L
.92 .44894 L
.924 .44897 L
.928 .449 L
.932 .44903 L
.936 .44906 L
.94 .44909 L
.944 .44913 L
.948 .44915 L
.952 .44919 L
.956 .4492 L
.96 .44923 L
.964 .44924 L
.968 .44928 L
.972 .44929 L
.976 .44934 L
.98 .44937 L
.984 .44942 L
.988 .44943 L
.992 .44948 L
.996 .44947 L
1 .44952 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .17022 L
.012 .17178 L
.016 .17596 L
.02 .18289 L
.024 .18865 L
.028 .1933 L
.032 .19849 L
.036 .20453 L
.04 .21073 L
.044 .21676 L
.048 .22169 L
.052 .22562 L
.056 .22959 L
.06 .23413 L
.064 .24009 L
.068 .24757 L
.072 .25609 L
.076 .26522 L
.08 .27442 L
.084 .28362 L
.088 .29288 L
.092 .3021 L
.096 .31093 L
.1 .31931 L
.104 .32748 L
.108 .33569 L
.112 .34397 L
.116 .35206 L
.12 .35961 L
.124 .3666 L
.128 .37343 L
.132 .38039 L
.136 .38755 L
.14 .39463 L
.144 .40129 L
.148 .40752 L
.152 .41369 L
.156 .42031 L
.16 .42775 L
.164 .43596 L
.168 .44452 L
.172 .45292 L
.176 .46081 L
.18 .46816 L
.184 .47527 L
.188 .48254 L
.192 .49034 L
.196 .49879 L
.2 .50776 L
Mistroke
.204 .5169 L
.208 .5258 L
.212 .53405 L
.216 .54136 L
.22 .54758 L
.224 .55268 L
.228 .55676 L
.232 .55996 L
.236 .56244 L
.24 .56438 L
.244 .56591 L
.248 .56714 L
.252 .56812 L
.256 .56891 L
.26 .56953 L
.264 .56998 L
.268 .57028 L
.272 .57045 L
.276 .57053 L
.28 .57055 L
.284 .57057 L
.288 .57063 L
.292 .57075 L
.296 .57095 L
.3 .57121 L
.304 .57148 L
.308 .57172 L
.312 .57188 L
.316 .57193 L
.32 .57186 L
.324 .5717 L
.328 .57149 L
.332 .5713 L
.336 .57115 L
.34 .57109 L
.344 .5711 L
.348 .57118 L
.352 .57128 L
.356 .57136 L
.36 .5714 L
.364 .57139 L
.368 .57133 L
.372 .57123 L
.376 .57114 L
.38 .57106 L
.384 .571 L
.388 .57097 L
.392 .57095 L
.396 .57093 L
.4 .5709 L
Mistroke
.404 .57085 L
.408 .57079 L
.412 .57071 L
.416 .57064 L
.42 .57057 L
.424 .57053 L
.428 .5705 L
.432 .57049 L
.436 .57048 L
.44 .57048 L
.444 .57046 L
.448 .57043 L
.452 .57038 L
.456 .57031 L
.46 .57024 L
.464 .57017 L
.468 .57011 L
.472 .57006 L
.476 .57003 L
.48 .56999 L
.484 .56996 L
.488 .56991 L
.492 .56985 L
.496 .5698 L
.5 .56975 L
.504 .56972 L
.508 .56972 L
.512 .56972 L
.516 .56972 L
.52 .56968 L
.524 .56962 L
.528 .56952 L
.532 .56941 L
.536 .56931 L
.54 .56925 L
.544 .56923 L
.548 .56925 L
.552 .56927 L
.556 .56927 L
.56 .56924 L
.564 .56917 L
.568 .56908 L
.572 .569 L
.576 .56894 L
.58 .5689 L
.584 .56888 L
.588 .56887 L
.592 .56884 L
.596 .56879 L
.6 .56873 L
Mistroke
.604 .56866 L
.608 .56861 L
.612 .56856 L
.616 .56854 L
.62 .56851 L
.624 .56849 L
.628 .56845 L
.632 .5684 L
.636 .56834 L
.64 .56829 L
.644 .56825 L
.648 .56821 L
.652 .56817 L
.656 .56812 L
.66 .56807 L
.664 .56802 L
.668 .56797 L
.672 .56793 L
.676 .5679 L
.68 .56787 L
.684 .56784 L
.688 .5678 L
.692 .56775 L
.696 .5677 L
.7 .56764 L
.704 .56759 L
.708 .56755 L
.712 .56751 L
.716 .56747 L
.72 .56743 L
.724 .56739 L
.728 .56734 L
.732 .5673 L
.736 .56726 L
.74 .56722 L
.744 .56719 L
.748 .56714 L
.752 .56709 L
.756 .56704 L
.76 .56699 L
.764 .56695 L
.768 .56691 L
.772 .56687 L
.776 .56683 L
.78 .56679 L
.784 .56674 L
.788 .5667 L
.792 .56666 L
.796 .56662 L
.8 .56658 L
Mistroke
.804 .56653 L
.808 .56648 L
.812 .56643 L
.816 .56638 L
.82 .56634 L
.824 .5663 L
.828 .56627 L
.832 .56623 L
.836 .56619 L
.84 .56615 L
.844 .5661 L
.848 .56605 L
.852 .566 L
.856 .56596 L
.86 .56591 L
.864 .56587 L
.868 .56583 L
.872 .56579 L
.876 .56574 L
.88 .56571 L
.884 .56567 L
.888 .56563 L
.892 .56558 L
.896 .56554 L
.9 .56549 L
.904 .56545 L
.908 .5654 L
.912 .56536 L
.916 .5653 L
.92 .56527 L
.924 .56522 L
.928 .56519 L
.932 .56515 L
.936 .56512 L
.94 .56506 L
.944 .56502 L
.948 .56496 L
.952 .56492 L
.956 .56486 L
.96 .56483 L
.964 .56477 L
.968 .56475 L
.972 .5647 L
.976 .56469 L
.98 .56463 L
.984 .56461 L
.988 .56453 L
.992 .5645 L
.996 .56442 L
1 .5644 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8000aoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool00goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Ao
o`03001oogoo00Yoo`D0009oo`80009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool0
00]oo`8000Yoo`8000Aoo`03001oogoo009oo`8000]oo`<000=oo`03001oo`00009oo`03001oogoo
00Aoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007oo
Ool0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol0
07oo00001Woo00@007ooOol000Eoo`008Woo0P002goo1`000Woo0P0027oo00<007ooOol00goo0P00
17oo0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=o
o`8000Ioo`008Woo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0004Ool00`00Oomo
o`02Ool00`00Oomoo`1<Ool0029oo`8000Yoo`07001oogooOol007oo000017oo00<007ooOol00`00
0Woo0`000Woo0P000Woo0P000Woo0`0000Aoo`00001oo`<00004Ool00000Ool2000017oo000007oo
0P0000Aoo`00001oo`800004Ool00000Ool500000goo0000000200001Goo00000000Ool00P0000=o
o`0000000`0037oo000ROomS000<Ool0029oo`05001oogooOol00003Ool00`00Oomoo`020003Ool3
00000goo001oo`02Ool200000goo001oo`030002Ool20003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000aoo`008Woo0P002Goo00<0
07ooOol0HGoo000ROol00`00Oomoo`07Ool00`00Oomoo`1ROol0029oo`8000Qoo`03001oogoo069o
o`008Woo0P001goo00<007ooOol0Hgoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool0
0`00Oomoo`06Ool00`00Oomoo`1SOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P001goo00<007ooOol0Hgoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`8000Ioo`03001oogoo06Aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`1TOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P001Woo00<007ooOol0I7oo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000Aoo`8000Ioo`03001oogoo06Aoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<0
07ooOol01Goo00<007ooOol0I7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool20005
Ool00`00Oomoo`1UOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`80
00Eoo`03001oogoo06Eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`04Ool00`00Oomoo`1UOol000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007oo
Oomoo`8000Eoo`03001oogoo06Eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<0
07ooOol00P0017oo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
1000Oomoo`001Goo00<007ooOol0IWoo000;Ool2000:Ool20003Ool30003Ool40002Ool00`00Oomo
o`1VOol0029oo`80009oo`<006Qoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04
001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol0
0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2
000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]
Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo
1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol0
0goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`06001oogoo001oo`000goo00<007ooOol01`00HWoo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`001Goo0P00HGoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`020005Ool20004Ool30004Ool20007
Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002
Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@0
00=oo`03001oogoo00Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool0
0`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`001Woo00<007ooOol01Woo00<007ooOol017oo00@007ooOol0009o
o`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol0
1Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0
009oo`03001oogoo00Moo`03001oogoo00=oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Ao
o`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Moo`03001oo`0000<000=oo`04
001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol4
0003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=o
o`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Qoo`8000Ioo`04001oogoo
0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001o
ogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo0000
1Woo00@007ooOol000Eoo`00:7oo00<007ooOol027oo1P000goo0P0027oo00<007ooOol00goo0P00
17oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=o
o`8000Ioo`00:7oo00<007ooOol02Goo00<007ooOol0FWoo000XOol00`00Oomoo`0:Ool00`00Oomo
o`1IOol002Qooed000aoo`00:7oo00<007ooOol02goo00D007ooOomoo`00019oo`03001oogoo00mo
o`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol037oo00<007oo
Ool0Egoo000XOol00`00Oomoo`0<Ool00`00Oomoo`1GOol002Qoo`03001oogoo00eoo`03001oogoo
05Ioo`00:7oo00<007ooOol03Woo00<007ooOol0EGoo000XOol00`00Oomoo`0>Ool2001FOol000]o
o`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo00moo`03001oogoo05Ao
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000B
Ool00`00Oomoo`1COol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04
001oogoo000BOol00`00Oomoo`1COol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo0080015oo`8005Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1@00Oomoo`00Ool010000goo00<007ooOol04Goo0P00Dgoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`001Woo00<007ooOol04Woo2P00BWoo000;Ool2000:Ool20004Ool2
0002Ool50002Ool00`00Oomoo`0KOolo000<Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Ao
o`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00
Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001o
ogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]o
o`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo
0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol0
00]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`00
17oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`00
17oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool0
00=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04
001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001ao
o`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002
Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomo
o`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004
Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002
Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool5
0003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`00
17oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`0077ooJ@0037oo000LOol20002Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yo
o`0077oo00<007oo0000LWoo000LOol4001aOol001aoo`03001oogoo0080071oo`0077oo00D007oo
Oomoo`00071oo`0077oo0P000goo00<007ooOol0KGoo000LOol00`00Oomoo`02Ool2001^Ool001ao
o`03001oogoo00=oo`8006eoo`0077oo0P001Goo00<007ooOol0Jgoo000LOol00`00Oomoo`05Ool0
0`00Oomoo`1ZOol001aoo`8000Ioo`03001oogoo06Yoo`002goo0P0017oo00<007ooOol00Woo0`00
0goo00<007ooOol01Goo00<007ooOol0JWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo00Ioo`03001oogoo06Uoo`002Woo00@007ooOol000]oo`03001oogoo008000Moo`03
001oogoo06Uoo`002Woo00@007ooOol000]oo`04001oogoo0009Ool00`00Oomoo`1XOol000Yoo`04
001oogoo0007Ool40003Ool00`00Oomoo`07Ool00`00Oomoo`1XOol000Yoo`04001oogoo0007Ool0
0`00Oomoo`04Ool20009Ool00`00Oomoo`1WOol000]oo`8000Qoo`D0009oo`03001oogoo00Qoo`03
001oogoo06Moo`0077oo00<007ooOol02Goo00<007ooOol0IWoo000LOol2000:Ool00`00Oomoo`1V
Ool001aoo`03001oogoo00Yoo`03001oogoo06Eoo`0077oo0P002goo00<007ooOol0IGoo000LOol0
0`00Oomoo`0;Ool00`00Oomoo`1TOol001aoo`03001oogoo00]oo`8006Eoo`0077oo0P003Goo00<0
07ooOol0Hgoo000FOol30003Ool00`00Oomoo`0=Ool00`00Oomoo`1ROol001Moo`03001oogoo009o
o`03001oogoo00eoo`03001oogoo069oo`005goo00<007ooOol00Woo0P003goo00<007ooOol0HGoo
000GOol00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`1QOol001Moo`03001oogoo009oo`03
001oogoo00moo`03001oogoo061oo`005Woo0P0017oo0P0047oo00<007ooOol0H7oo000GOol00`00
Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`1OOol001aoo`03001oogoo011oo`80061oo`0077oo
0P004Woo00<007ooOol0GWoo000LOol00`00Oomoo`0AOol00`00Oomoo`1NOol001aoo`8001=oo`03
001oogoo05eoo`0077oo00<007ooOol04Woo00<007ooOol0GGoo000LOol00`00Oomoo`0COol00`00
Oomoo`1LOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8001Aoo`03001oogoo05aoo`002goo
00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo01Aoo`03001oogoo05]oo`002goo00<0
07ooOol02goo00@007ooOol001Ioo`8005aoo`002goo00<007ooOol02goo00<007ooOol00P005goo
0`005goo=P0037oo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`0IOolH0011Ool000Yoo`80
00Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000L
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(37909\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .48719 m
.008 .48927 L
.012 .49453 L
.016 .49939 L
.02 .5033 L
.024 .50713 L
.028 .50964 L
.032 .50796 L
.036 .50189 L
.04 .4944 L
.044 .4856 L
.048 .47378 L
.052 .45921 L
.056 .44396 L
.06 .42957 L
.064 .41754 L
.068 .40819 L
.072 .40093 L
.076 .39454 L
.08 .38599 L
.084 .37407 L
.088 .3597 L
.092 .34441 L
.096 .32931 L
.1 .31417 L
.104 .29863 L
.108 .28442 L
.112 .27467 L
.116 .27098 L
.12 .27241 L
.124 .27717 L
.128 .2841 L
.132 .29325 L
.136 .30485 L
.14 .31707 L
.144 .3262 L
.148 .32915 L
.152 .3251 L
.156 .31601 L
.16 .30536 L
.164 .29562 L
.168 .28734 L
.172 .27985 L
.176 .27242 L
.18 .26551 L
.184 .2607 L
.188 .25952 L
.192 .26253 L
.196 .26871 L
.2 .27579 L
Mistroke
.204 .28144 L
.208 .28397 L
.212 .28306 L
.216 .27954 L
.22 .27479 L
.224 .27023 L
.228 .26669 L
.232 .26445 L
.236 .26334 L
.24 .26313 L
.244 .26388 L
.248 .26592 L
.252 .2698 L
.256 .2759 L
.26 .28413 L
.264 .2937 L
.268 .30316 L
.272 .31078 L
.276 .31498 L
.28 .31488 L
.284 .31066 L
.288 .30359 L
.292 .29574 L
.296 .28941 L
.3 .28641 L
.304 .28753 L
.308 .29227 L
.312 .29901 L
.316 .30555 L
.32 .30988 L
.324 .3108 L
.328 .30828 L
.332 .30342 L
.336 .29799 L
.34 .2938 L
.344 .29207 L
.348 .29308 L
.352 .29613 L
.356 .29989 L
.36 .30293 L
.364 .30424 L
.368 .30357 L
.372 .30139 L
.376 .29865 L
.38 .29636 L
.384 .29523 L
.388 .29543 L
.392 .29669 L
.396 .29845 L
.4 .30016 L
Mistroke
.404 .30145 L
.408 .3021 L
.412 .30207 L
.416 .30141 L
.42 .30023 L
.424 .29873 L
.428 .29722 L
.432 .29614 L
.436 .29589 L
.44 .29667 L
.444 .29831 L
.448 .30026 L
.452 .30175 L
.456 .30212 L
.46 .30116 L
.464 .29922 L
.468 .29718 L
.472 .29604 L
.476 .29643 L
.48 .29826 L
.484 .30066 L
.488 .30242 L
.492 .30255 L
.496 .30084 L
.5 .29802 L
.504 .29546 L
.508 .29448 L
.512 .29567 L
.516 .29851 L
.52 .3016 L
.524 .30338 L
.528 .30296 L
.532 .30061 L
.536 .29758 L
.54 .29547 L
.544 .29533 L
.548 .29714 L
.552 .2998 L
.556 .30181 L
.56 .30205 L
.564 .30045 L
.568 .29802 L
.572 .29619 L
.576 .29601 L
.58 .29751 L
.584 .29978 L
.588 .30148 L
.592 .30169 L
.596 .30034 L
.6 .29827 L
Mistroke
.604 .2967 L
.608 .2965 L
.612 .29769 L
.616 .29946 L
.62 .30071 L
.624 .30073 L
.628 .29963 L
.632 .29816 L
.636 .29724 L
.64 .29736 L
.644 .29836 L
.648 .29958 L
.652 .30028 L
.656 .30011 L
.66 .29925 L
.664 .29825 L
.668 .29771 L
.672 .29789 L
.676 .29857 L
.68 .29925 L
.684 .29953 L
.688 .29929 L
.692 .2988 L
.696 .2984 L
.7 .29832 L
.704 .29856 L
.708 .29894 L
.712 .29924 L
.716 .29929 L
.72 .29906 L
.724 .29865 L
.728 .29827 L
.732 .29814 L
.736 .29834 L
.74 .29876 L
.744 .29915 L
.748 .29928 L
.752 .29909 L
.756 .29876 L
.76 .2985 L
.764 .29846 L
.768 .29862 L
.772 .29881 L
.776 .29888 L
.78 .29878 L
.784 .29857 L
.788 .29841 L
.792 .29844 L
.796 .29868 L
.8 .29899 L
Mistroke
.804 .29916 L
.808 .29899 L
.812 .2986 L
.816 .29828 L
.82 .29829 L
.824 .29865 L
.828 .29901 L
.832 .29899 L
.836 .29857 L
.84 .29809 L
.844 .29805 L
.848 .29861 L
.852 .29932 L
.856 .29957 L
.86 .29912 L
.864 .29827 L
.868 .29771 L
.872 .29787 L
.876 .29849 L
.88 .29905 L
.884 .29914 L
.888 .29876 L
.892 .29841 L
.896 .29842 L
.9 .29864 L
.904 .29885 L
.908 .2988 L
.912 .29847 L
.916 .29823 L
.92 .29823 L
.924 .29833 L
.928 .29855 L
.932 .29874 L
.936 .29879 L
.94 .29894 L
.944 .29894 L
.948 .29858 L
.952 .29823 L
.956 .29796 L
.96 .29792 L
.964 .29843 L
.968 .29888 L
.972 .29892 L
.976 .29884 L
.98 .29856 L
.984 .29834 L
.988 .29855 L
.992 .29861 L
.996 .29828 L
1 .29809 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15623 m
.008 .16144 L
.012 .16304 L
.016 .16112 L
.02 .16039 L
.024 .16094 L
.028 .161 L
.032 .16069 L
.036 .16099 L
.04 .16197 L
.044 .16279 L
.048 .1634 L
.052 .1643 L
.056 .16579 L
.06 .16793 L
.064 .17047 L
.068 .17259 L
.072 .17402 L
.076 .17483 L
.08 .1754 L
.084 .17664 L
.088 .17901 L
.092 .18267 L
.096 .18744 L
.1 .19298 L
.104 .19919 L
.108 .206 L
.112 .21324 L
.116 .2205 L
.12 .22754 L
.124 .23434 L
.128 .24106 L
.132 .24779 L
.136 .25441 L
.14 .26061 L
.144 .2663 L
.148 .27167 L
.152 .27707 L
.156 .28279 L
.16 .28879 L
.164 .29483 L
.168 .30065 L
.172 .30624 L
.176 .31181 L
.18 .31771 L
.184 .3241 L
.188 .3309 L
.192 .3378 L
.196 .34441 L
.2 .3505 L
Mistroke
.204 .35605 L
.208 .36133 L
.212 .36669 L
.216 .37246 L
.22 .37885 L
.224 .38582 L
.228 .39317 L
.232 .4006 L
.236 .40777 L
.24 .41438 L
.244 .42023 L
.248 .42523 L
.252 .42936 L
.256 .43266 L
.26 .43522 L
.264 .43715 L
.268 .43855 L
.272 .43955 L
.276 .44026 L
.28 .44078 L
.284 .44121 L
.288 .4416 L
.292 .44201 L
.296 .44244 L
.3 .44287 L
.304 .44329 L
.308 .44365 L
.312 .44392 L
.316 .4441 L
.32 .4442 L
.324 .44423 L
.328 .44425 L
.332 .44427 L
.336 .44431 L
.34 .44439 L
.344 .4445 L
.348 .44461 L
.352 .44472 L
.356 .4448 L
.36 .44486 L
.364 .44489 L
.368 .44491 L
.372 .44494 L
.376 .44497 L
.38 .44501 L
.384 .44507 L
.388 .44513 L
.392 .44519 L
.396 .44523 L
.4 .44526 L
Mistroke
.404 .44527 L
.408 .44527 L
.412 .44527 L
.416 .44527 L
.42 .44529 L
.424 .44531 L
.428 .44535 L
.432 .4454 L
.436 .44546 L
.44 .4455 L
.444 .44554 L
.448 .44557 L
.452 .44559 L
.456 .44561 L
.46 .44564 L
.464 .44567 L
.468 .44571 L
.472 .44574 L
.476 .44577 L
.48 .44578 L
.484 .44578 L
.488 .44578 L
.492 .44578 L
.496 .44581 L
.5 .44587 L
.504 .44594 L
.508 .44602 L
.512 .44608 L
.516 .44611 L
.52 .44611 L
.524 .4461 L
.528 .44608 L
.532 .44607 L
.536 .4461 L
.54 .44615 L
.544 .44622 L
.548 .44628 L
.552 .44632 L
.556 .44634 L
.56 .44634 L
.564 .44635 L
.568 .44637 L
.572 .4464 L
.576 .44644 L
.58 .44649 L
.584 .44653 L
.588 .44655 L
.592 .44657 L
.596 .44658 L
.6 .4466 L
Mistroke
.604 .44663 L
.608 .44666 L
.612 .4467 L
.616 .44673 L
.62 .44676 L
.624 .44679 L
.628 .44681 L
.632 .44684 L
.636 .44688 L
.64 .44691 L
.644 .44694 L
.648 .44697 L
.652 .44699 L
.656 .447 L
.66 .44702 L
.664 .44705 L
.668 .44708 L
.672 .44712 L
.676 .44716 L
.68 .4472 L
.684 .44722 L
.688 .44724 L
.692 .44727 L
.696 .44729 L
.7 .44732 L
.704 .44735 L
.708 .44738 L
.712 .44741 L
.716 .44743 L
.72 .44746 L
.724 .44748 L
.728 .44752 L
.732 .44755 L
.736 .44758 L
.74 .44761 L
.744 .44764 L
.748 .44766 L
.752 .44769 L
.756 .44772 L
.76 .44774 L
.764 .44777 L
.768 .4478 L
.772 .44782 L
.776 .44785 L
.78 .44788 L
.784 .44791 L
.788 .44795 L
.792 .44798 L
.796 .44801 L
.8 .44803 L
Mistroke
.804 .44805 L
.808 .44807 L
.812 .4481 L
.816 .44813 L
.82 .44816 L
.824 .44819 L
.828 .44822 L
.832 .44826 L
.836 .44829 L
.84 .44832 L
.844 .44834 L
.848 .44837 L
.852 .44839 L
.856 .44841 L
.86 .44843 L
.864 .44847 L
.868 .4485 L
.872 .44853 L
.876 .44856 L
.88 .4486 L
.884 .44863 L
.888 .44865 L
.892 .44867 L
.896 .4487 L
.9 .44872 L
.904 .44875 L
.908 .44877 L
.912 .44881 L
.916 .44884 L
.92 .44888 L
.924 .4489 L
.928 .44894 L
.932 .44896 L
.936 .44899 L
.94 .449 L
.944 .44903 L
.948 .44905 L
.952 .44909 L
.956 .44911 L
.96 .44916 L
.964 .44918 L
.968 .44922 L
.972 .44924 L
.976 .44928 L
.98 .44928 L
.984 .44932 L
.988 .44932 L
.992 .44936 L
.996 .44938 L
1 .44944 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16607 L
.012 .17077 L
.016 .17543 L
.02 .18036 L
.024 .18545 L
.028 .19045 L
.032 .19548 L
.036 .20079 L
.04 .2062 L
.044 .21143 L
.048 .21597 L
.052 .22008 L
.056 .22457 L
.06 .22957 L
.064 .23435 L
.068 .23852 L
.072 .24146 L
.076 .2433 L
.08 .24484 L
.084 .2468 L
.088 .25003 L
.092 .25465 L
.096 .26025 L
.1 .26652 L
.104 .2733 L
.108 .28053 L
.112 .28802 L
.116 .29548 L
.12 .3027 L
.124 .30978 L
.128 .31713 L
.132 .32493 L
.136 .33303 L
.14 .34113 L
.144 .34899 L
.148 .35671 L
.152 .36462 L
.156 .37286 L
.16 .38128 L
.164 .38945 L
.168 .39701 L
.172 .40392 L
.176 .41053 L
.18 .41732 L
.184 .42461 L
.188 .43241 L
.192 .44039 L
.196 .44813 L
.2 .45537 L
Mistroke
.204 .46212 L
.208 .46867 L
.212 .47545 L
.216 .48286 L
.22 .49108 L
.224 .50005 L
.228 .50947 L
.232 .5189 L
.236 .52788 L
.24 .53602 L
.244 .54307 L
.248 .54892 L
.252 .55362 L
.256 .55731 L
.26 .56017 L
.264 .5624 L
.268 .56418 L
.272 .56562 L
.276 .56682 L
.28 .56781 L
.284 .5686 L
.288 .56918 L
.292 .56958 L
.296 .56981 L
.3 .56992 L
.304 .56997 L
.308 .57 L
.312 .57008 L
.316 .57021 L
.32 .57039 L
.324 .57061 L
.328 .57082 L
.332 .57098 L
.336 .57109 L
.34 .57112 L
.344 .57109 L
.348 .57103 L
.352 .57097 L
.356 .57093 L
.36 .5709 L
.364 .5709 L
.368 .57091 L
.372 .5709 L
.376 .57088 L
.38 .57083 L
.384 .57077 L
.388 .57069 L
.392 .57063 L
.396 .57058 L
.4 .57054 L
Mistroke
.404 .57053 L
.408 .57052 L
.412 .57051 L
.416 .5705 L
.42 .57048 L
.424 .57044 L
.428 .57038 L
.432 .57032 L
.436 .57025 L
.44 .57019 L
.444 .57013 L
.448 .57008 L
.452 .57004 L
.456 .57001 L
.46 .56997 L
.464 .56993 L
.468 .56988 L
.472 .56983 L
.476 .56978 L
.48 .56976 L
.484 .56975 L
.488 .56975 L
.492 .56973 L
.496 .56969 L
.5 .56962 L
.504 .56952 L
.508 .56942 L
.512 .56933 L
.516 .56928 L
.52 .56927 L
.524 .56928 L
.528 .5693 L
.532 .56929 L
.536 .56926 L
.54 .56919 L
.544 .5691 L
.548 .56902 L
.552 .56895 L
.556 .56892 L
.56 .5689 L
.564 .56889 L
.568 .56886 L
.572 .56882 L
.576 .56875 L
.58 .56869 L
.584 .56863 L
.588 .56858 L
.592 .56856 L
.596 .56853 L
.6 .56851 L
Mistroke
.604 .56847 L
.608 .56842 L
.612 .56837 L
.616 .56831 L
.62 .56827 L
.624 .56823 L
.628 .56818 L
.632 .56814 L
.636 .56809 L
.64 .56804 L
.644 .568 L
.648 .56796 L
.652 .56793 L
.656 .5679 L
.66 .56787 L
.664 .56782 L
.668 .56777 L
.672 .56771 L
.676 .56766 L
.68 .56761 L
.684 .56757 L
.688 .56754 L
.692 .5675 L
.696 .56746 L
.7 .56741 L
.704 .56737 L
.708 .56732 L
.712 .56728 L
.716 .56725 L
.72 .56721 L
.724 .56717 L
.728 .56712 L
.732 .56707 L
.736 .56702 L
.74 .56697 L
.744 .56693 L
.748 .56689 L
.752 .56685 L
.756 .56681 L
.76 .56677 L
.764 .56673 L
.768 .56669 L
.772 .56665 L
.776 .5666 L
.78 .56656 L
.784 .5665 L
.788 .56645 L
.792 .5664 L
.796 .56636 L
.8 .56633 L
Mistroke
.804 .56629 L
.808 .56626 L
.812 .56622 L
.816 .56618 L
.82 .56613 L
.824 .56607 L
.828 .56602 L
.832 .56597 L
.836 .56593 L
.84 .5659 L
.844 .56586 L
.848 .56582 L
.852 .56578 L
.856 .56574 L
.86 .56569 L
.864 .56564 L
.868 .56559 L
.872 .56555 L
.876 .5655 L
.88 .56547 L
.884 .56543 L
.888 .56539 L
.892 .56534 L
.896 .5653 L
.9 .56525 L
.904 .56521 L
.908 .56516 L
.912 .56513 L
.916 .56508 L
.92 .56504 L
.924 .56499 L
.928 .56495 L
.932 .5649 L
.936 .56486 L
.94 .56481 L
.944 .56478 L
.948 .56473 L
.952 .5647 L
.956 .56465 L
.96 .56461 L
.964 .56455 L
.968 .56452 L
.972 .56446 L
.976 .56444 L
.98 .56438 L
.984 .56435 L
.988 .56428 L
.992 .56426 L
.996 .56419 L
1 .56418 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`04001oogooOol200000goo000000020006Ool20004Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04
001oogoo0005Ool0029oo`8000Uoo`800003Ool0000000D00005Ool00000Ool00006Ool00`00Oomo
o`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`00
0Woo1@000goo0P001Woo000ROol00`00Oomoo`08Ool00`00Ool00003Ool00`00Oomoo`020003Ool0
1000Oomoogoo0P00D7oo000ROol20008Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol0
0P000Woo0P000Woo0`0000Aoo`000000009oo`800004Ool00000Ool6000017oo000007oo0P0000Ao
o`00001oo`800004Ool00000Ool200000goo0000000200000goo0000000200000goo000000060000
17oo0000000037oo000ROomS000<Ool0029oo`05001oogooOol00003Ool01P00Ool007oo001oo`<0
00=oo`05001oogooOol00002Ool20002Ool20002Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo00Yoo`008Woo0P0027oo
00@007ooOomoo`8005moo`008Woo00<007ooOol01goo00<007ooOol0HWoo000ROol20007Ool00`00
Oomoo`1SOol0029oo`8000Moo`03001oogoo06=oo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo00<007ooOol01Woo00<007ooOol0Hgoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8000Ioo`03001oogoo06Aoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool20006Ool00`00Oomoo`1TOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol017oo0P00IWoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8000Eoo`03001oogoo06Eoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool20004Ool20004Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00
17oo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2
0004Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol0Igoo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001o
ogooOol20003Ool00`00Oomoo`1WOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008000=oo`03001oogoo06Moo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00<007ooOol00P000Woo00<007ooOol0J7oo000;Ool2000:Ool20003Ool30003Ool300000goo001o
o`1YOol0029oo`04001oo`00001[Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`80
06eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo
008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo
0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00
KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo
0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomo
o`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@00
0Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001o
ogoo06Ioo`00:7oo00<007oo0000IWoo000XOol7001ROol000]oo`8000Aoo`03001oogoo00=oo`80
00Aoo`8000=oo`<000=oo`03001oogoo00=oo`<0061oo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01P00Oomoo`00Ool000=oo`04001oogoo0007Ool2001OOol000=oo`D0009oo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo0009Ool00`00Oomoo`1LOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000Qoo`03001o
ogoo00<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`80
00Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1@00Oomoo`00Ool010000goo00<007ooOol027oo0P000goo00@007ooOol0009oo`03001oogoo00Eo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001o
ogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo0000
0Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00Qoo`03001oogoo009oo`04001oogoo
0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
ogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002
Ool50002Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@0
07ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo
001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`00
0goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo0P001Goo00@007ooOol000Ioo`8000Aoo`04
001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`00
1Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000
Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol0
0`00Oomoo`0;Ool2001IOol002Qoo`03001oogoo00aoo`03001oogoo05Moo`00:7ooG@0037oo000X
Ool00`00Oomoo`0>Ool2000BOol00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00
Oomoo`0:Ool002Qoo`03001oogoo00ioo`03001oogoo05Eoo`00:7oo00<007ooOol03goo00<007oo
Ool0E7oo000XOol00`00Oomoo`0?Ool2001EOol002Qoo`03001oogoo011oo`03001oogoo05=oo`00
:7oo00<007ooOol04Goo00<007ooOol0DWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003
Ool30003Ool00`00Oomoo`0BOol00`00Oomoo`1AOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00H007ooOol007oo0003Ool01000Oomoo`0057oo00<007ooOol0DGoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`005Goo00<007ooOol0D7oo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000DOol00`00Oomo
o`1@Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001o
ogoo01Aoo`80051oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Io
o`03001oogoo01Eoo`T004Qoo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol07Goo
?@0037oo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Io
o`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yo
o`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00
0goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003
Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03
001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00
Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Ao
o`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03
001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04
001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomo
o`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<0
00Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D0
07ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007oo
Ool00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
17oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`00
2Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@0
07ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogoo
Ool007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007oo
Ool000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@0
07ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogoo
Ool007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo
0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D0
00=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo
0P000Woo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oo`00079oo`0077oo
0P0000=oo`00Ool0L7oo000LOol01@00Oomoogoo0000L7oo000LOol01000Oomoogoo0P00Kgoo000L
Ool20003Ool2001^Ool001aoo`03001oogoo00=oo`03001oogoo06aoo`0077oo00<007ooOol017oo
00<007ooOol0Jgoo000LOol20006Ool2001[Ool001aoo`03001oogoo00Moo`03001oogoo06Qoo`00
77oo0P0027oo0P00JGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`08Ool00`00
Oomoo`1WOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol027oo0P00J7oo
000:Ool01000Oomoo`002goo00<007ooOol00P002Woo00<007ooOol0IWoo000:Ool01000Oomoo`00
2goo00@007ooOol000aoo`03001oogoo06Eoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo
00Yoo`03001oogoo06Eoo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8000aoo`03001oogoo
06Aoo`002goo0P0027oo1@000Woo00<007ooOol02goo00<007ooOol0I7oo000LOol00`00Oomoo`0<
Ool00`00Oomoo`1SOol001aoo`8000eoo`8006Aoo`0077oo00<007ooOol03Goo00<007ooOol0HWoo
000LOol2000>Ool00`00Oomoo`1ROol001aoo`03001oogoo00ioo`03001oogoo065oo`0077oo00<0
07ooOol03Woo00<007ooOol0HGoo000LOol2000@Ool00`00Oomoo`1POol001Ioo`<000=oo`03001o
ogoo00moo`03001oogoo061oo`005goo00<007ooOol00Woo00<007ooOol047oo00<007ooOol0Ggoo
000GOol00`00Oomoo`02Ool2000BOol00`00Oomoo`1NOol001Moo`03001oogoo009oo`03001oogoo
015oo`03001oogoo05ioo`005goo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol0GWoo000F
Ool20004Ool2000COol00`00Oomoo`1MOol001Moo`03001oogoo009oo`03001oogoo01=oo`03001o
ogoo05aoo`0077oo00<007ooOol04goo00<007ooOol0G7oo000LOol2000EOol00`00Oomoo`1KOol0
01aoo`03001oogoo01Aoo`03001oogoo05]oo`0077oo0P005Woo00<007ooOol0FWoo000LOol00`00
Oomoo`0EOol00`00Oomoo`1JOol001aoo`03001oogoo01Ioo`03001oogoo05Uoo`002Woo0`0017oo
00<007ooOol00Woo0`000goo0P005goo00<007ooOol0FGoo000;Ool00`00Oomoo`07Ool01@00Oomo
ogoo00000Woo00<007ooOol05Woo0P00FWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`006Goo0P00
FGoo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02000JOol4000AOolh000<Ool000]oo`03001oogoo
00Moo`@000=oo`03001oogoo01aooa<004=oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0
LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(38076\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .5117 m
.008 .50762 L
.012 .49951 L
.016 .48615 L
.02 .46884 L
.024 .4516 L
.028 .43625 L
.032 .42072 L
.036 .40635 L
.04 .39606 L
.044 .39027 L
.048 .386 L
.052 .38188 L
.056 .3783 L
.06 .37513 L
.064 .37198 L
.068 .36755 L
.072 .36062 L
.076 .35153 L
.08 .34184 L
.084 .33349 L
.088 .32957 L
.092 .3317 L
.096 .33896 L
.1 .34887 L
.104 .35797 L
.108 .36516 L
.112 .37105 L
.116 .3751 L
.12 .37528 L
.124 .36984 L
.128 .35909 L
.132 .34541 L
.136 .33162 L
.14 .31881 L
.144 .30636 L
.148 .29434 L
.152 .28438 L
.156 .27864 L
.16 .27813 L
.164 .28128 L
.168 .28478 L
.172 .28615 L
.176 .28515 L
.18 .28359 L
.184 .28374 L
.188 .28631 L
.192 .28989 L
.196 .29201 L
.2 .29061 L
Mistroke
.204 .28537 L
.208 .27778 L
.212 .27017 L
.216 .26466 L
.22 .26223 L
.224 .26263 L
.228 .26485 L
.232 .26764 L
.236 .27002 L
.24 .27138 L
.244 .2714 L
.248 .26995 L
.252 .26706 L
.256 .26305 L
.26 .25861 L
.264 .25489 L
.268 .25326 L
.272 .25493 L
.276 .26052 L
.28 .2697 L
.284 .28113 L
.288 .29275 L
.292 .30235 L
.296 .30822 L
.3 .30967 L
.304 .30724 L
.308 .30247 L
.312 .2974 L
.316 .29389 L
.32 .29301 L
.324 .29479 L
.328 .29831 L
.332 .3021 L
.336 .30473 L
.34 .30535 L
.344 .30393 L
.348 .30118 L
.352 .29821 L
.356 .29604 L
.36 .29526 L
.364 .29591 L
.368 .29754 L
.372 .2995 L
.376 .30118 L
.38 .30219 L
.384 .30242 L
.388 .30194 L
.392 .30093 L
.396 .29959 L
.4 .29816 L
Mistroke
.404 .29693 L
.408 .29623 L
.412 .29631 L
.416 .29727 L
.42 .2989 L
.424 .30068 L
.428 .30192 L
.432 .30204 L
.436 .30092 L
.44 .29897 L
.444 .29708 L
.448 .29616 L
.452 .29676 L
.456 .29867 L
.46 .30099 L
.464 .30252 L
.468 .30236 L
.472 .30045 L
.476 .29764 L
.48 .29531 L
.484 .29468 L
.488 .29616 L
.492 .29909 L
.496 .30206 L
.5 .30357 L
.504 .30287 L
.508 .30035 L
.512 .29732 L
.516 .29535 L
.52 .2954 L
.524 .29733 L
.528 .30002 L
.532 .30198 L
.536 .30215 L
.54 .30052 L
.544 .29808 L
.548 .29624 L
.552 .29605 L
.556 .29757 L
.56 .29988 L
.564 .30162 L
.568 .30182 L
.572 .30044 L
.576 .29833 L
.58 .29672 L
.584 .29648 L
.588 .29767 L
.592 .29949 L
.596 .30083 L
.6 .30093 L
Mistroke
.604 .29982 L
.608 .29827 L
.612 .29726 L
.616 .29735 L
.62 .2984 L
.624 .29969 L
.628 .30043 L
.632 .30025 L
.636 .29932 L
.64 .29826 L
.644 .29768 L
.648 .29787 L
.652 .29861 L
.656 .2994 L
.66 .29974 L
.664 .29948 L
.668 .29888 L
.672 .29838 L
.676 .29828 L
.68 .2986 L
.684 .29909 L
.688 .29944 L
.692 .29945 L
.696 .29911 L
.7 .29862 L
.704 .29821 L
.708 .29812 L
.712 .29841 L
.716 .29893 L
.72 .29938 L
.724 .29951 L
.728 .29924 L
.732 .29877 L
.736 .2984 L
.74 .29835 L
.744 .29861 L
.748 .29895 L
.752 .29911 L
.756 .29898 L
.76 .29866 L
.764 .29839 L
.768 .29839 L
.772 .29869 L
.776 .29914 L
.78 .29939 L
.784 .29923 L
.788 .29873 L
.792 .29822 L
.796 .29808 L
.8 .29843 L
Mistroke
.804 .299 L
.808 .29931 L
.812 .2991 L
.816 .29856 L
.82 .29817 L
.824 .2983 L
.828 .29883 L
.832 .2993 L
.836 .29932 L
.84 .29883 L
.844 .29828 L
.848 .29808 L
.852 .2983 L
.856 .2987 L
.86 .29895 L
.864 .29891 L
.868 .29879 L
.872 .29875 L
.876 .29879 L
.88 .29881 L
.884 .29866 L
.888 .29838 L
.892 .29826 L
.896 .29836 L
.9 .29861 L
.904 .29892 L
.908 .29902 L
.912 .29885 L
.916 .29865 L
.92 .29841 L
.924 .29826 L
.928 .29843 L
.932 .2987 L
.936 .2989 L
.94 .29898 L
.944 .29863 L
.948 .29811 L
.952 .29796 L
.956 .29822 L
.96 .29883 L
.964 .29949 L
.968 .29941 L
.972 .29869 L
.976 .29797 L
.98 .29758 L
.984 .29784 L
.988 .29863 L
.992 .29909 L
.996 .29898 L
1 .29882 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13391 m
.008 .13478 L
.012 .13527 L
.016 .13556 L
.02 .1359 L
.024 .13664 L
.028 .13745 L
.032 .13828 L
.036 .13937 L
.04 .14081 L
.044 .14222 L
.048 .14351 L
.052 .145 L
.056 .14694 L
.06 .14925 L
.064 .15175 L
.068 .15401 L
.072 .15614 L
.076 .15863 L
.08 .16175 L
.084 .16544 L
.088 .1694 L
.092 .17285 L
.096 .17539 L
.1 .17702 L
.104 .17816 L
.108 .17958 L
.112 .18165 L
.116 .18447 L
.12 .18801 L
.124 .19227 L
.128 .19731 L
.132 .20302 L
.136 .20916 L
.14 .21539 L
.144 .22161 L
.148 .22796 L
.152 .23458 L
.156 .24145 L
.16 .24831 L
.164 .25486 L
.168 .26102 L
.172 .267 L
.176 .27305 L
.18 .27934 L
.184 .28572 L
.188 .29193 L
.192 .29773 L
.196 .30315 L
.2 .30846 L
Mistroke
.204 .31402 L
.208 .32006 L
.212 .32655 L
.216 .33326 L
.22 .33983 L
.224 .34601 L
.228 .35173 L
.232 .35714 L
.236 .36254 L
.24 .36823 L
.244 .37443 L
.248 .38119 L
.252 .38838 L
.256 .39578 L
.26 .40308 L
.264 .41 L
.268 .41631 L
.272 .42185 L
.276 .42654 L
.28 .43038 L
.284 .43343 L
.288 .43577 L
.292 .43751 L
.296 .4388 L
.3 .43975 L
.304 .44047 L
.308 .44106 L
.312 .44157 L
.316 .44203 L
.32 .44245 L
.324 .44284 L
.328 .44317 L
.332 .44344 L
.336 .44366 L
.34 .44383 L
.344 .44398 L
.348 .44411 L
.352 .44424 L
.356 .44437 L
.36 .4445 L
.364 .44462 L
.368 .44472 L
.372 .44479 L
.376 .44485 L
.38 .44488 L
.384 .44491 L
.388 .44493 L
.392 .44495 L
.396 .44499 L
.4 .44503 L
Mistroke
.404 .44508 L
.408 .44514 L
.412 .44519 L
.416 .44524 L
.42 .44528 L
.424 .44532 L
.428 .44534 L
.432 .44537 L
.436 .44539 L
.44 .44542 L
.444 .44545 L
.448 .44549 L
.452 .44551 L
.456 .44552 L
.46 .44552 L
.464 .44553 L
.468 .44554 L
.472 .44558 L
.476 .44563 L
.48 .44571 L
.484 .44578 L
.488 .44583 L
.492 .44586 L
.496 .44586 L
.5 .44584 L
.504 .44582 L
.508 .44582 L
.512 .44585 L
.516 .44591 L
.52 .44597 L
.524 .44603 L
.528 .44607 L
.532 .44609 L
.536 .4461 L
.54 .4461 L
.544 .44612 L
.548 .44615 L
.552 .44619 L
.556 .44624 L
.56 .44628 L
.564 .44631 L
.568 .44633 L
.572 .44634 L
.576 .44635 L
.58 .44638 L
.584 .44641 L
.588 .44645 L
.592 .44649 L
.596 .44652 L
.6 .44655 L
Mistroke
.604 .44657 L
.608 .4466 L
.612 .44663 L
.616 .44666 L
.62 .44669 L
.624 .44672 L
.628 .44674 L
.632 .44675 L
.636 .44678 L
.64 .4468 L
.644 .44684 L
.648 .44688 L
.652 .44692 L
.656 .44695 L
.66 .44697 L
.664 .44699 L
.668 .44702 L
.672 .44704 L
.676 .44707 L
.68 .4471 L
.684 .44713 L
.688 .44716 L
.692 .44718 L
.696 .44721 L
.7 .44724 L
.704 .44727 L
.708 .4473 L
.712 .44734 L
.716 .44737 L
.72 .44739 L
.724 .44741 L
.728 .44744 L
.732 .44746 L
.736 .44749 L
.74 .44752 L
.744 .44755 L
.748 .44757 L
.752 .4476 L
.756 .44763 L
.76 .44767 L
.764 .4477 L
.768 .44773 L
.772 .44776 L
.776 .44778 L
.78 .4478 L
.784 .44782 L
.788 .44785 L
.792 .44788 L
.796 .44791 L
.8 .44795 L
Mistroke
.804 .44798 L
.808 .44801 L
.812 .44804 L
.816 .44806 L
.82 .44809 L
.824 .44811 L
.828 .44813 L
.832 .44816 L
.836 .44819 L
.84 .44822 L
.844 .44825 L
.848 .44829 L
.852 .44831 L
.856 .44834 L
.86 .44837 L
.864 .4484 L
.868 .44842 L
.872 .44845 L
.876 .44848 L
.88 .4485 L
.884 .44853 L
.888 .44856 L
.892 .44858 L
.896 .44862 L
.9 .44865 L
.904 .44869 L
.908 .44871 L
.912 .44874 L
.916 .44876 L
.92 .44878 L
.924 .4488 L
.928 .44883 L
.932 .44886 L
.936 .4489 L
.94 .44893 L
.944 .44897 L
.948 .44899 L
.952 .44903 L
.956 .44904 L
.96 .44907 L
.964 .44908 L
.968 .44912 L
.972 .44914 L
.976 .44918 L
.98 .4492 L
.984 .44925 L
.988 .44926 L
.992 .44931 L
.996 .44932 L
1 .44936 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16239 L
.012 .17109 L
.016 .177 L
.02 .18026 L
.024 .18396 L
.028 .18815 L
.032 .19174 L
.036 .19489 L
.04 .19803 L
.044 .20112 L
.048 .20379 L
.052 .20627 L
.056 .20918 L
.06 .21254 L
.064 .21564 L
.068 .21825 L
.072 .22048 L
.076 .2227 L
.08 .22543 L
.084 .22872 L
.088 .23201 L
.092 .23482 L
.096 .23655 L
.1 .23735 L
.104 .23808 L
.108 .2395 L
.112 .24226 L
.116 .2464 L
.12 .25176 L
.124 .25822 L
.128 .26567 L
.132 .27387 L
.136 .28231 L
.14 .29055 L
.144 .29843 L
.148 .30613 L
.152 .31392 L
.156 .32187 L
.16 .32972 L
.164 .33723 L
.168 .34437 L
.172 .35141 L
.176 .35873 L
.18 .3665 L
.184 .37453 L
.188 .38246 L
.192 .38995 L
.196 .39701 L
.2 .40391 L
Mistroke
.204 .41106 L
.208 .4187 L
.212 .42678 L
.216 .43498 L
.22 .44288 L
.224 .45019 L
.228 .4569 L
.232 .46328 L
.236 .46977 L
.24 .4768 L
.244 .48464 L
.248 .49333 L
.252 .50263 L
.256 .51216 L
.26 .52146 L
.264 .5301 L
.268 .53777 L
.272 .54431 L
.276 .5497 L
.28 .55404 L
.284 .55748 L
.288 .56019 L
.292 .56235 L
.296 .56407 L
.3 .56545 L
.304 .56654 L
.308 .56738 L
.312 .56802 L
.316 .56849 L
.32 .56884 L
.324 .5691 L
.328 .56933 L
.332 .56953 L
.336 .56972 L
.34 .56991 L
.344 .57007 L
.348 .5702 L
.352 .57029 L
.356 .57034 L
.36 .57036 L
.364 .57036 L
.368 .57036 L
.372 .57036 L
.376 .57038 L
.38 .5704 L
.384 .57043 L
.388 .57045 L
.392 .57045 L
.396 .57044 L
.4 .5704 L
Mistroke
.404 .57035 L
.408 .57029 L
.412 .57023 L
.416 .57017 L
.42 .57012 L
.424 .57009 L
.428 .57006 L
.432 .57002 L
.436 .56999 L
.44 .56994 L
.444 .56989 L
.448 .56985 L
.452 .56981 L
.456 .5698 L
.46 .56979 L
.464 .56978 L
.468 .56975 L
.472 .56969 L
.476 .56961 L
.48 .56952 L
.484 .56942 L
.488 .56935 L
.492 .56931 L
.496 .56931 L
.5 .56932 L
.504 .56933 L
.508 .56932 L
.512 .56927 L
.516 .5692 L
.52 .56911 L
.524 .56903 L
.528 .56897 L
.532 .56894 L
.536 .56893 L
.54 .56891 L
.544 .56888 L
.548 .56883 L
.552 .56877 L
.556 .5687 L
.56 .56865 L
.564 .56861 L
.568 .56858 L
.572 .56856 L
.576 .56853 L
.58 .56849 L
.584 .56844 L
.588 .56838 L
.592 .56833 L
.596 .56829 L
.6 .56825 L
Mistroke
.604 .56821 L
.608 .56816 L
.612 .56811 L
.616 .56806 L
.62 .56802 L
.624 .56798 L
.628 .56795 L
.632 .56792 L
.636 .56789 L
.64 .56784 L
.644 .56779 L
.648 .56773 L
.652 .56768 L
.656 .56763 L
.66 .56759 L
.664 .56756 L
.668 .56752 L
.672 .56749 L
.676 .56744 L
.68 .56739 L
.684 .56735 L
.688 .5673 L
.692 .56727 L
.696 .56723 L
.7 .56719 L
.704 .56714 L
.708 .56709 L
.712 .56704 L
.716 .56699 L
.72 .56695 L
.724 .56691 L
.728 .56687 L
.732 .56683 L
.736 .56679 L
.74 .56675 L
.744 .56671 L
.748 .56667 L
.752 .56663 L
.756 .56658 L
.76 .56653 L
.764 .56647 L
.768 .56642 L
.772 .56638 L
.776 .56635 L
.78 .56632 L
.784 .56629 L
.788 .56625 L
.792 .5662 L
.796 .56615 L
.8 .5661 L
Mistroke
.804 .56604 L
.808 .566 L
.812 .56595 L
.816 .56592 L
.82 .56588 L
.824 .56585 L
.828 .56581 L
.832 .56577 L
.836 .56572 L
.84 .56567 L
.844 .56562 L
.848 .56557 L
.852 .56552 L
.856 .56548 L
.86 .56544 L
.864 .56541 L
.868 .56537 L
.872 .56533 L
.876 .56528 L
.88 .56524 L
.884 .56519 L
.888 .56515 L
.892 .5651 L
.896 .56506 L
.9 .56501 L
.904 .56497 L
.908 .56493 L
.912 .56489 L
.916 .56485 L
.92 .56481 L
.924 .56476 L
.928 .56472 L
.932 .56467 L
.936 .56463 L
.94 .56457 L
.944 .56454 L
.948 .56449 L
.952 .56447 L
.956 .56441 L
.96 .56438 L
.964 .56432 L
.968 .56429 L
.972 .56423 L
.976 .5642 L
.98 .56413 L
.984 .56411 L
.988 .56405 L
.992 .56404 L
.996 .56397 L
1 .56396 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00D007ooOol007oo008000Aoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]o
o`8000Yoo`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`D00003Ool007oo009oo`80
00Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0009o
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo0000
1Woo00@007ooOol000Eoo`008Woo0P0037oo1@0000=oo`0000000`000Woo00<007ooOol00Woo00<0
07ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eo
o`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol037oo100000=oo`00Ool01Woo00<007ooOol0
D7oo000ROol2000=Ool01000Oomoogoo0P001goo00<007ooOol00P0000Aoo`000000009oo`<00005
Ool00000001oo`02000017oo000007oo0P0000Aoo`00001oo`H00003Ool007oo00<00003Ool00000
00800006Ool00000Ool007oo300000=oo`0000003Woo000ROomS000<Ool0029oo`05001oogooOol0
0003Ool02@00Oomoogoo001oo`00Ool00003Ool01@00Oomoogoo00000Woo00D007oo001oo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`04001oogoo0003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00<007ooOol02Woo000ROol2000<Ool00`00Oomoo`1NOol0029oo`03001oogoo00Eoo`<0
009oo`03001oogoo05moo`008Woo0P001Woo00<007oo00000Woo00<007ooOol0Ggoo000ROol20006
Ool00`00Ool00002Ool00`00Oomoo`1OOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`03001oogoo00Aoo`04001oogooOol2001ROol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P0017oo00<007ooOol00Woo0P00HWoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`80009oo`8006Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool01@00Oomoogoo0000JWoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`80009oo`03001oogoo06Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool200000goo001oo`1ZOol000]oo`8000Yoo`8000Aoo`03001oogoo009oo`04001oogoo
001[Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`800003Ool007oo06Yoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0`00K7oo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oo`0006aoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01000Oomoogoo0`00K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`03001/Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`06001oogoo
001oo`00K7oo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`002goo0P0017oo
00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo
0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol0
06ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eo
o`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uo
o`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1Y
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo
000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`@006Eoo`004Goo0P002Woo0P00
17oo00<007ooOol00Woo00<007ooOol01000HWoo000XOol00`00Oomoo`03Ool2001QOol002Qoo`03
001oogoo00Aoo`80061oo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<0
07ooOol01Goo0`00GWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`00
0goo00@007ooOol000Yoo`03001oogoo05]oo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOol000]oo`03001oogoo05Yoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo
0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo
0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00
Oomoo`09Ool20002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`001Woo00<007ooOol02goo00<007oo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004
Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00]oo`03001oo`00009oo`04
001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001o
ogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uo
o`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04
001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001o
ogoo0080009oo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=o
o`03001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1P000Woo0P00
27oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Ao
o`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol03Woo00<007ooOol0EGoo000XOol0
0`00Oomoo`0>Ool2001FOol002Qooed000aoo`00:7oo00<007ooOol03goo0P004Goo00<007ooOol0
3goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`0@Ool2001D
Ool002Qoo`03001oogoo015oo`8005=oo`00:7oo00<007ooOol04Woo00<007ooOol0DGoo000XOol0
0`00Oomoo`0COol00`00Oomoo`1@Ool002Qoo`03001oogoo01=oo`03001oogoo051oo`002goo0P00
17oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol057oo00<007ooOol0Cgoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol001Moo`03
001oogoo04ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Ool001Moo`03001oogoo04ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol00P005goo00<007ooOol0CGoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`05001oogoo001oo`040003Ool00`00Oomoo`0FOol2001>Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0GOol80017Ool000]oo`8000Yoo`8000Ao
o`80009oo`D0009oo`03001oogoo01mooc/000aoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P00
17oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<0
07ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`00
2goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007oo
Ool000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=o
o`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool3
0004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool3
0004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03
001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001o
o`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009o
o`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00
77oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001o
ogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol0
00Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eo
o`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool3
0004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo000LOomY000<Ool001aoo`80009oo`05001oogooOol00004Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol0
2Woo000LOol00`00Ool0001bOol001aoo`800003Ool00000071oo`0077oo00@007ooOomoo`8006mo
o`0077oo00<007ooOol00Woo0P00KWoo000LOol20004Ool3001/Ool001aoo`03001oogoo00Eoo`80
06]oo`0077oo00<007ooOol01Woo0`00JGoo000LOol2000:Ool00`00Oomoo`1VOol001aoo`03001o
ogoo00Yoo`03001oogoo06Eoo`0077oo0P002goo00<007ooOol0IGoo000;Ool20004Ool00`00Oomo
o`02Ool30003Ool00`00Oomoo`0;Ool00`00Oomoo`1TOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol02goo00<007ooOol0I7oo000:Ool01000Oomoo`002goo00<007ooOol0
0P003Goo00<007ooOol0Hgoo000:Ool01000Oomoo`002goo00@007ooOol000moo`03001oogoo069o
o`002Woo00@007ooOol000Moo`@000=oo`03001oogoo00eoo`03001oogoo069oo`002Woo00@007oo
Ool000Moo`03001oogoo00Aoo`8000ioo`03001oogoo069oo`002goo0P0027oo1@000Woo00<007oo
Ool03Woo00<007ooOol0HGoo000LOol00`00Oomoo`0?Ool00`00Oomoo`1POol001aoo`80011oo`03
001oogoo061oo`0077oo00<007ooOol03goo0P00HGoo000LOol2000AOol00`00Oomoo`1OOol001ao
o`03001oogoo015oo`03001oogoo05ioo`0077oo00<007ooOol04Goo00<007ooOol0GWoo000LOol2
000BOol2001OOol001Ioo`<000=oo`03001oogoo019oo`03001oogoo05eoo`005goo00<007ooOol0
0Woo00<007ooOol04goo00<007ooOol0G7oo000GOol00`00Oomoo`02Ool2000DOol00`00Oomoo`1L
Ool001Moo`03001oogoo009oo`03001oogoo01Aoo`03001oogoo05]oo`005goo00<007ooOol00Woo
00<007ooOol057oo00<007ooOol0Fgoo000FOol20004Ool2000FOol00`00Oomoo`1JOol001Moo`03
001oogoo009oo`03001oogoo01Ioo`03001oogoo05Uoo`0077oo00<007ooOol05Woo00<007ooOol0
FGoo000LOol2000GOol00`00Oomoo`1IOol001aoo`03001oogoo01Moo`03001oogoo05Qoo`0077oo
0P0067oo00<007ooOol0F7oo000LOol00`00Oomoo`0HOol00`00Oomoo`1GOol001aoo`03001oogoo
01Uoo`03001oogoo05Ioo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P006Woo00<007ooOol0
EWoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol06Goo0P00Egoo000;Ool0
0`00Oomoo`0;Ool01000Oomoo`0077oo0P00EWoo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02000L
Ool6000;Oolj000<Ool000]oo`03001oogoo00Moo`@000=oo`03001oogoo021oo``004Ioo`002Woo
0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(38243\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .40576 m
.008 .39913 L
.012 .39363 L
.016 .39014 L
.02 .38747 L
.024 .38587 L
.028 .38412 L
.032 .38038 L
.036 .37356 L
.04 .36512 L
.044 .35587 L
.048 .34497 L
.052 .3333 L
.056 .32308 L
.06 .31706 L
.064 .31659 L
.068 .32151 L
.072 .33011 L
.076 .34195 L
.08 .35707 L
.084 .37396 L
.088 .39039 L
.092 .40369 L
.096 .41097 L
.1 .41065 L
.104 .40344 L
.108 .39229 L
.112 .38169 L
.116 .37369 L
.12 .36715 L
.124 .36071 L
.128 .35394 L
.132 .34808 L
.136 .34418 L
.14 .34132 L
.144 .33749 L
.148 .33195 L
.152 .32615 L
.156 .32199 L
.16 .32001 L
.164 .31871 L
.168 .31578 L
.172 .31053 L
.176 .30428 L
.18 .29877 L
.184 .29461 L
.188 .29062 L
.192 .28502 L
.196 .27752 L
.2 .27005 L
Mistroke
.204 .26573 L
.208 .26694 L
.212 .2735 L
.216 .28249 L
.22 .28975 L
.224 .29183 L
.228 .28756 L
.232 .27844 L
.236 .26764 L
.24 .25866 L
.244 .25391 L
.248 .25407 L
.252 .25814 L
.256 .26397 L
.26 .26912 L
.264 .27158 L
.268 .2703 L
.272 .2654 L
.276 .25809 L
.28 .25036 L
.284 .24443 L
.288 .24216 L
.292 .24455 L
.296 .25144 L
.3 .26157 L
.304 .27294 L
.308 .2834 L
.312 .29131 L
.316 .2959 L
.32 .29744 L
.324 .29696 L
.328 .29578 L
.332 .29507 L
.336 .29547 L
.34 .29697 L
.344 .29913 L
.348 .30129 L
.352 .30286 L
.356 .30354 L
.36 .30329 L
.364 .30232 L
.368 .30092 L
.372 .29939 L
.376 .298 L
.38 .29699 L
.384 .29661 L
.388 .29699 L
.392 .29813 L
.396 .29972 L
.4 .30127 L
Mistroke
.404 .30214 L
.408 .30192 L
.412 .30058 L
.416 .29865 L
.42 .29699 L
.424 .29641 L
.428 .29728 L
.432 .29923 L
.436 .30133 L
.44 .30248 L
.444 .30199 L
.448 .29994 L
.452 .29728 L
.456 .2953 L
.46 .29508 L
.464 .29681 L
.468 .29973 L
.472 .30244 L
.476 .3036 L
.48 .30263 L
.484 .3 L
.488 .29706 L
.492 .29528 L
.496 .29554 L
.5 .29762 L
.504 .30033 L
.508 .30218 L
.512 .3022 L
.516 .30046 L
.52 .29799 L
.524 .29623 L
.528 .29616 L
.532 .29779 L
.536 .30014 L
.54 .30183 L
.544 .3019 L
.548 .30037 L
.552 .29818 L
.556 .29661 L
.56 .29652 L
.564 .29786 L
.568 .29975 L
.572 .30105 L
.576 .30104 L
.58 .29982 L
.584 .2982 L
.588 .2972 L
.592 .29739 L
.596 .29856 L
.6 .29994 L
Mistroke
.604 .30066 L
.608 .30035 L
.612 .29929 L
.616 .29815 L
.62 .29761 L
.624 .2979 L
.628 .29874 L
.632 .29959 L
.636 .29993 L
.64 .29964 L
.644 .29897 L
.648 .2984 L
.652 .29828 L
.656 .29863 L
.66 .29918 L
.664 .29954 L
.668 .29952 L
.672 .29914 L
.676 .29864 L
.68 .2983 L
.684 .29827 L
.688 .29856 L
.692 .29902 L
.696 .29941 L
.7 .29952 L
.704 .2993 L
.708 .2989 L
.712 .29856 L
.716 .29848 L
.72 .29866 L
.724 .29893 L
.728 .29906 L
.732 .29898 L
.736 .29875 L
.74 .29859 L
.744 .29863 L
.748 .29889 L
.752 .2992 L
.756 .29934 L
.76 .29915 L
.764 .29872 L
.768 .29833 L
.772 .29826 L
.776 .29859 L
.78 .29906 L
.784 .2993 L
.788 .29912 L
.792 .29865 L
.796 .29832 L
.8 .29845 L
Mistroke
.804 .29896 L
.808 .29941 L
.812 .29938 L
.816 .29883 L
.82 .29818 L
.824 .29794 L
.828 .29829 L
.832 .29896 L
.836 .29943 L
.84 .29937 L
.844 .29895 L
.848 .29848 L
.852 .29831 L
.856 .29848 L
.86 .29876 L
.864 .2989 L
.868 .29887 L
.872 .29869 L
.876 .29854 L
.88 .29858 L
.884 .29872 L
.888 .29886 L
.892 .29893 L
.896 .29879 L
.9 .29856 L
.904 .29846 L
.908 .29852 L
.912 .2987 L
.916 .2989 L
.92 .29879 L
.924 .29853 L
.928 .29843 L
.932 .29851 L
.936 .2988 L
.94 .29904 L
.944 .29884 L
.948 .29844 L
.952 .29826 L
.956 .29837 L
.96 .29879 L
.964 .29912 L
.968 .29884 L
.972 .29827 L
.976 .29802 L
.98 .29823 L
.984 .29885 L
.988 .29946 L
.992 .29922 L
.996 .29842 L
1 .29795 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .11987 m
.008 .11496 L
.012 .11377 L
.016 .11639 L
.02 .11812 L
.024 .11907 L
.028 .12048 L
.032 .12245 L
.036 .12448 L
.04 .12668 L
.044 .12888 L
.048 .13107 L
.052 .13332 L
.056 .13578 L
.06 .1384 L
.064 .14099 L
.068 .14326 L
.072 .14532 L
.076 .14756 L
.08 .15005 L
.084 .15249 L
.088 .15464 L
.092 .15631 L
.096 .1577 L
.1 .15931 L
.104 .16154 L
.108 .16442 L
.112 .16761 L
.116 .17039 L
.12 .17243 L
.124 .17384 L
.128 .17504 L
.132 .17654 L
.136 .17859 L
.14 .18128 L
.144 .18474 L
.148 .18909 L
.152 .19431 L
.156 .20014 L
.16 .20623 L
.164 .21229 L
.168 .21831 L
.172 .22449 L
.176 .23093 L
.18 .23754 L
.184 .24408 L
.188 .25035 L
.192 .25636 L
.196 .26235 L
.2 .26855 L
Mistroke
.204 .27502 L
.208 .28159 L
.212 .28793 L
.216 .29381 L
.22 .29927 L
.224 .30456 L
.228 .31003 L
.232 .31595 L
.236 .32233 L
.24 .32898 L
.244 .33558 L
.248 .34184 L
.252 .34766 L
.256 .35312 L
.26 .35847 L
.264 .364 L
.268 .36999 L
.272 .37653 L
.276 .38359 L
.28 .39098 L
.284 .39844 L
.288 .40565 L
.292 .41234 L
.296 .41832 L
.3 .42346 L
.304 .42773 L
.308 .43119 L
.312 .43391 L
.316 .43603 L
.32 .43767 L
.324 .43894 L
.328 .43995 L
.332 .44077 L
.336 .44143 L
.34 .44198 L
.344 .44243 L
.348 .4428 L
.352 .44311 L
.356 .44336 L
.36 .44357 L
.364 .44375 L
.368 .44392 L
.372 .44408 L
.376 .44424 L
.38 .44438 L
.384 .44452 L
.388 .44464 L
.392 .44474 L
.396 .44482 L
.4 .44489 L
Mistroke
.404 .44495 L
.408 .445 L
.412 .44505 L
.416 .4451 L
.42 .44514 L
.424 .44518 L
.428 .44521 L
.432 .44523 L
.436 .44524 L
.44 .44526 L
.444 .44528 L
.448 .44533 L
.452 .4454 L
.456 .44547 L
.46 .44554 L
.464 .44558 L
.468 .4456 L
.472 .44559 L
.476 .44557 L
.48 .44556 L
.484 .44558 L
.488 .44561 L
.492 .44567 L
.496 .44573 L
.5 .44579 L
.504 .44583 L
.508 .44584 L
.512 .44585 L
.516 .44586 L
.52 .44587 L
.524 .44591 L
.528 .44595 L
.532 .446 L
.536 .44603 L
.54 .44606 L
.544 .44608 L
.548 .44609 L
.552 .4461 L
.556 .44613 L
.56 .44617 L
.564 .4462 L
.568 .44624 L
.572 .44627 L
.576 .4463 L
.58 .44632 L
.584 .44635 L
.588 .44638 L
.592 .44641 L
.596 .44644 L
.6 .44646 L
Mistroke
.604 .44648 L
.608 .4465 L
.612 .44653 L
.616 .44656 L
.62 .4466 L
.624 .44664 L
.628 .44667 L
.632 .4467 L
.636 .44673 L
.64 .44674 L
.644 .44677 L
.648 .44679 L
.652 .44682 L
.656 .44685 L
.66 .44689 L
.664 .44691 L
.668 .44694 L
.672 .44696 L
.676 .44699 L
.68 .44702 L
.684 .44705 L
.688 .44709 L
.692 .44712 L
.696 .44715 L
.7 .44717 L
.704 .44719 L
.708 .44722 L
.712 .44724 L
.716 .44727 L
.72 .4473 L
.724 .44733 L
.728 .44736 L
.732 .44739 L
.736 .44742 L
.74 .44746 L
.744 .44749 L
.748 .44751 L
.752 .44753 L
.756 .44755 L
.76 .44757 L
.764 .4476 L
.768 .44763 L
.772 .44767 L
.776 .4477 L
.78 .44774 L
.784 .44777 L
.788 .44779 L
.792 .44781 L
.796 .44784 L
.8 .44786 L
Mistroke
.804 .44788 L
.808 .44791 L
.812 .44794 L
.816 .44798 L
.82 .44801 L
.824 .44804 L
.828 .44807 L
.832 .44809 L
.836 .44812 L
.84 .44815 L
.844 .44817 L
.848 .4482 L
.852 .44823 L
.856 .44826 L
.86 .44828 L
.864 .44831 L
.868 .44834 L
.872 .44837 L
.876 .4484 L
.88 .44843 L
.884 .44846 L
.888 .44849 L
.892 .44851 L
.896 .44854 L
.9 .44856 L
.904 .44859 L
.908 .44862 L
.912 .44865 L
.916 .44868 L
.92 .44871 L
.924 .44874 L
.928 .44877 L
.932 .44879 L
.936 .44882 L
.94 .44884 L
.944 .44887 L
.948 .44889 L
.952 .44893 L
.956 .44895 L
.96 .44899 L
.964 .44901 L
.968 .44905 L
.972 .44907 L
.976 .44911 L
.98 .44912 L
.984 .44916 L
.988 .44917 L
.992 .44922 L
.996 .44922 L
1 .44928 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16256 L
.012 .16562 L
.016 .16839 L
.02 .1708 L
.024 .17316 L
.028 .17584 L
.032 .1785 L
.036 .18114 L
.04 .18369 L
.044 .18618 L
.048 .18822 L
.052 .18994 L
.056 .19172 L
.06 .19364 L
.064 .19526 L
.068 .19657 L
.072 .19795 L
.076 .1998 L
.08 .20234 L
.084 .20543 L
.088 .20852 L
.092 .21141 L
.096 .21427 L
.1 .21744 L
.104 .22135 L
.108 .22594 L
.112 .23049 L
.116 .23429 L
.12 .23679 L
.124 .23815 L
.128 .23911 L
.132 .24029 L
.136 .24216 L
.14 .24493 L
.144 .24879 L
.148 .25392 L
.152 .26031 L
.156 .26764 L
.16 .27539 L
.164 .2832 L
.168 .29102 L
.172 .29902 L
.176 .3073 L
.18 .31573 L
.184 .32394 L
.188 .33168 L
.192 .33896 L
.196 .3461 L
.2 .35345 L
Mistroke
.204 .36115 L
.208 .36905 L
.212 .3768 L
.216 .38417 L
.22 .39117 L
.224 .39807 L
.228 .40524 L
.232 .41289 L
.236 .42099 L
.24 .42922 L
.244 .43719 L
.248 .44461 L
.252 .45141 L
.256 .45781 L
.26 .46419 L
.264 .47099 L
.268 .4785 L
.272 .48682 L
.276 .49584 L
.28 .50524 L
.284 .51462 L
.288 .52358 L
.292 .53178 L
.296 .53903 L
.3 .54522 L
.304 .55037 L
.308 .55455 L
.312 .55789 L
.316 .5605 L
.32 .56253 L
.324 .56407 L
.328 .56525 L
.332 .56614 L
.336 .56683 L
.34 .56738 L
.344 .56783 L
.348 .56821 L
.352 .56855 L
.356 .56885 L
.36 .56911 L
.364 .56933 L
.368 .5695 L
.372 .56963 L
.376 .56973 L
.38 .56979 L
.384 .56982 L
.388 .56984 L
.392 .56986 L
.396 .56987 L
.4 .56988 L
Mistroke
.404 .56989 L
.408 .56989 L
.412 .56988 L
.416 .56986 L
.42 .56984 L
.424 .56981 L
.428 .5698 L
.432 .56979 L
.436 .56978 L
.44 .56977 L
.444 .56974 L
.448 .56968 L
.452 .56961 L
.456 .56951 L
.46 .56943 L
.464 .56936 L
.468 .56933 L
.472 .56933 L
.476 .56935 L
.48 .56936 L
.484 .56934 L
.488 .56929 L
.492 .56921 L
.496 .56912 L
.5 .56904 L
.504 .56899 L
.508 .56896 L
.512 .56895 L
.516 .56894 L
.52 .56891 L
.524 .56886 L
.528 .56879 L
.532 .56872 L
.536 .56867 L
.54 .56863 L
.544 .5686 L
.548 .56858 L
.552 .56856 L
.556 .56852 L
.56 .56846 L
.564 .56841 L
.568 .56835 L
.572 .5683 L
.576 .56826 L
.58 .56822 L
.584 .56818 L
.588 .56814 L
.592 .56809 L
.596 .56805 L
.6 .56801 L
Mistroke
.604 .56797 L
.608 .56794 L
.612 .56791 L
.616 .56786 L
.62 .56781 L
.624 .56776 L
.628 .5677 L
.632 .56765 L
.636 .56761 L
.64 .56758 L
.644 .56754 L
.648 .56751 L
.652 .56746 L
.656 .56742 L
.66 .56737 L
.664 .56733 L
.668 .56729 L
.672 .56725 L
.676 .5672 L
.68 .56716 L
.684 .56711 L
.688 .56706 L
.692 .56702 L
.696 .56698 L
.7 .56694 L
.704 .5669 L
.708 .56686 L
.712 .56682 L
.716 .56677 L
.72 .56673 L
.724 .56669 L
.728 .56665 L
.732 .5666 L
.736 .56655 L
.74 .5665 L
.744 .56645 L
.748 .56641 L
.752 .56638 L
.756 .56634 L
.76 .56631 L
.764 .56627 L
.768 .56622 L
.772 .56617 L
.776 .56612 L
.78 .56607 L
.784 .56602 L
.788 .56598 L
.792 .56594 L
.796 .56591 L
.8 .56587 L
Mistroke
.804 .56583 L
.808 .56579 L
.812 .56574 L
.816 .5657 L
.82 .56564 L
.824 .5656 L
.828 .56555 L
.832 .56551 L
.836 .56547 L
.84 .56543 L
.844 .56539 L
.848 .56535 L
.852 .56531 L
.856 .56527 L
.86 .56522 L
.864 .56518 L
.868 .56513 L
.872 .56508 L
.876 .56503 L
.88 .56499 L
.884 .56495 L
.888 .56491 L
.892 .56487 L
.896 .56484 L
.9 .5648 L
.904 .56475 L
.908 .5647 L
.912 .56465 L
.916 .56459 L
.92 .56455 L
.924 .56451 L
.928 .56449 L
.932 .56444 L
.936 .56441 L
.94 .56436 L
.944 .56432 L
.948 .56426 L
.952 .56422 L
.956 .56416 L
.96 .56413 L
.964 .56407 L
.968 .56406 L
.972 .564 L
.976 .56398 L
.98 .56392 L
.984 .56389 L
.988 .56381 L
.992 .56379 L
.996 .56372 L
1 .56371 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool01000Oomoogoo0P000Woo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool00goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Ao
o`03001oogoo00]oo`@000=oo`04001oogoo0002Ool00`00Ool00002Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`000Woo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000Oomo
o`001Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`03Ool200002Goo
00000000Ool007oo001oo`020004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001o
ogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003
Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0029oo`8000aoo`X00003Ool0000000=o
o`03001oo`0000Eoo`8000Aoo`8000Ioo`04001oogooOol50003Ool20004Ool30004Ool20004Ool2
0005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo011oo`03001oo`00008000Ioo`03001o
ogoo04ioo`008Woo0P0047oo00D007ooOomoo`0000Qoo`<000=oo`80009oo`800003Ool00000009o
o`800004Ool00000Ool2000017oo000007oo0P0000Aoo`00001oo`80009oo`05001oo`00001oo`04
000017oo000007oo100000=oo`000000100000=oo`0000000P0037oo000ROomS000<Ool0029oo`09
001oogooOol007oo001oo`0000=oo`04001oogooOol20002Ool01@00Oomoogoo00000Woo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`04
001oogoo0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00<007ooOol02Woo000ROol20004Ool20007Ool2001NOol0029oo`03001o
ogoo009oo`03001oo`0000Ioo`8005moo`008Woo0P000goo00@007ooOol000Aoo`80061oo`008Woo
0P000Woo00D007ooOomoo`0000Aoo`03001oogoo05moo`002goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo00D007ooOomoo`0000=oo`05001oogooOol0001ROol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P0000=oo`0000000goo00@007ooOol006=oo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool40005Ool00`00Ool0001SOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P001goo00<007oo0000Hgoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Moo`8006Aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009o
o`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@0
07ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=o
o`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol0
06ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001o
o`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo
001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo
001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]
Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00
K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1Y
Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0
JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Mo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Io
o`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo
0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0`00
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oo`00008006Ao
o`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool01000Oomoogoo0`00HWoo000AOol2
000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool2001QOol002Qoo`03001oogoo00Aoo`<0
05moo`00:7oo00<007ooOol01goo0P00GGoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003
Ool30003Ool00`00Oomoo`08Ool3001KOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0003Ool01000Oomoo`0037oo0P00FWoo0003Ool50002Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool01000Oomoo`003Goo00<007ooOol0F7oo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool3
0004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool3
0004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=o
o`03001oogoo00Uoo`03001oogoo0080009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`00
00Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo0P0000Eoo`00Oomo
o`0000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0
0goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo1000
00Aoo`000000009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo
00<007ooOol00goo0P000Woo00<007ooOol017oo0P0017oo00@007ooOol0009oo`04001oogoo0002
Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D0
009oo`<000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004
Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo011oo`03001oogoo05=o
o`00:7oo00<007ooOol04Goo00<007ooOol0DWoo000XOomM000<Ool002Qoo`03001oogoo00moo`03
001oogoo008000ioo`03001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yo
o`00:7oo00<007ooOol04goo00<007ooOol0D7oo000XOol00`00Oomoo`0COol2001AOol002Qoo`03
001oogoo01Aoo`80051oo`00:7oo00<007ooOol05Goo00<007ooOol0CWoo000XOol00`00Oomoo`0F
Ool00`00Oomoo`1=Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001o
ogoo01Ioo`03001oogoo04eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00
Ool000=oo`04001oogoo000IOol00`00Oomoo`1<Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogoo000IOol00`00Oomoo`1<Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008001Uoo`03001oogoo04]oo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol06Goo00<007oo
Ool0BWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007oo
Ool06Woo2000A7oo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0QOoli000<Ool0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003
Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo
00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00
Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001o
ogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0
0P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007oo
Oomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol0
0Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001o
ogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol0
00]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`00
77oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P00
1Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo
00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D0
07ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool0
01aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Ao
o`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool4
0003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo
0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool0
0006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool2
0006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P00
1Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol300000goo
001oo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`02001`Ool001ao
o`80009oo`<006ioo`0077oo00<007ooOol00goo0`00K7oo000LOol00`00Oomoo`05Ool3001ZOol0
01aoo`8000Qoo`8006Uoo`0077oo00<007ooOol027oo0P00J7oo000LOol00`00Oomoo`09Ool3001V
Ool001aoo`8000aoo`8006Eoo`0077oo00<007ooOol03Goo00<007ooOol0HWoo000LOol2000>Ool0
0`00Oomoo`1ROol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo00ioo`03001oogoo
065oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0>Ool00`00Oomoo`1Q
Ool000Yoo`04001oogoo000;Ool00`00Oomoo`02000@Ool00`00Oomoo`1POol000Yoo`04001oogoo
000;Ool01000Oomoo`004Goo00<007ooOol0H7oo000:Ool01000Oomoo`001goo10000goo00<007oo
Ool047oo00<007ooOol0Ggoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P004Goo00<007oo
Ool0Ggoo000;Ool20008Ool50002Ool00`00Oomoo`0AOol00`00Oomoo`1NOol001aoo`03001oogoo
015oo`03001oogoo05ioo`0077oo0P004goo00<007ooOol0GGoo000LOol00`00Oomoo`0BOol00`00
Oomoo`1MOol001aoo`8001Aoo`03001oogoo05aoo`0077oo00<007ooOol04goo0P00GGoo000LOol0
0`00Oomoo`0DOol00`00Oomoo`1KOol001aoo`8001Eoo`8005aoo`005Woo0`000goo00<007ooOol0
5Goo00<007ooOol0FWoo000GOol00`00Oomoo`02Ool00`00Oomoo`0FOol00`00Oomoo`1IOol001Mo
o`03001oogoo009oo`8001Moo`03001oogoo05Uoo`005goo00<007ooOol00Woo00<007ooOol05Woo
00<007ooOol0FGoo000GOol00`00Oomoo`02Ool00`00Oomoo`0GOol00`00Oomoo`1HOol001Ioo`80
00Aoo`8001Uoo`03001oogoo05Moo`005goo00<007ooOol00Woo00<007ooOol067oo0P00F7oo000L
Ool00`00Oomoo`0IOol00`00Oomoo`1FOol001aoo`8001Yoo`03001oogoo05Ioo`0077oo00<007oo
Ool06Woo00<007ooOol0EGoo000LOol2000KOol00`00Oomoo`1EOol001aoo`03001oogoo01]oo`03
001oogoo05Aoo`0077oo00<007ooOol06goo00<007ooOol0E7oo000:Ool30004Ool00`00Oomoo`02
Ool30003Ool2000LOol2001EOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomo
o`0LOol2001DOol000]oo`03001oogoo00]oo`04001oogoo000OOol00`00Oomoo`1BOol000]oo`03
001oogoo00]oo`03001oogoo008001moo`P000=oocd000aoo`002goo00<007ooOol01goo10000goo
00<007ooOol09Woo0`00BGoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03
001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(38410\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .33356 m
.008 .32906 L
.012 .32356 L
.016 .3178 L
.02 .31279 L
.024 .30788 L
.028 .30452 L
.032 .30382 L
.036 .30648 L
.04 .31368 L
.044 .32537 L
.048 .34037 L
.052 .35639 L
.056 .37211 L
.06 .38625 L
.064 .39772 L
.068 .40433 L
.072 .40384 L
.076 .39715 L
.08 .38717 L
.084 .37615 L
.088 .36481 L
.092 .35436 L
.096 .34576 L
.1 .34031 L
.104 .33937 L
.108 .34337 L
.112 .35162 L
.116 .36148 L
.12 .36897 L
.124 .37212 L
.128 .37242 L
.132 .37283 L
.136 .37576 L
.14 .38033 L
.144 .38345 L
.148 .38318 L
.152 .37952 L
.156 .37336 L
.16 .36483 L
.164 .35337 L
.168 .33918 L
.172 .32466 L
.176 .31357 L
.18 .30832 L
.184 .30832 L
.188 .31057 L
.192 .31169 L
.196 .31016 L
.2 .30652 L
Mistroke
.204 .30182 L
.208 .29631 L
.212 .28933 L
.216 .28038 L
.22 .27056 L
.224 .26265 L
.228 .25968 L
.232 .26308 L
.236 .2714 L
.24 .28075 L
.244 .28665 L
.248 .28605 L
.252 .27886 L
.256 .26779 L
.26 .25705 L
.264 .25049 L
.268 .25 L
.272 .25497 L
.276 .26274 L
.28 .26973 L
.284 .27291 L
.288 .27074 L
.292 .26363 L
.296 .25359 L
.3 .24345 L
.304 .23589 L
.308 .23274 L
.312 .23451 L
.316 .24054 L
.32 .24934 L
.324 .25918 L
.328 .26855 L
.332 .27651 L
.336 .28268 L
.34 .28713 L
.344 .29019 L
.348 .29224 L
.352 .29368 L
.356 .29482 L
.36 .29598 L
.364 .29738 L
.368 .29906 L
.372 .30082 L
.376 .30223 L
.38 .30283 L
.384 .30231 L
.388 .3008 L
.392 .29888 L
.396 .29738 L
.4 .297 L
Mistroke
.404 .29798 L
.408 .29987 L
.412 .30174 L
.416 .30257 L
.42 .30181 L
.424 .29967 L
.428 .29712 L
.432 .2954 L
.436 .29545 L
.44 .29737 L
.444 .30032 L
.448 .30286 L
.452 .30374 L
.456 .30247 L
.46 .29967 L
.464 .29673 L
.468 .29512 L
.472 .29563 L
.476 .29791 L
.48 .30071 L
.484 .3025 L
.488 .30235 L
.492 .30042 L
.496 .29786 L
.5 .29615 L
.504 .29622 L
.508 .29798 L
.512 .30038 L
.516 .30203 L
.52 .30201 L
.524 .30037 L
.528 .29812 L
.532 .29655 L
.536 .29652 L
.54 .29794 L
.544 .29989 L
.548 .30121 L
.552 .30119 L
.556 .29995 L
.56 .2983 L
.564 .29726 L
.568 .2974 L
.572 .29855 L
.576 .29997 L
.58 .30077 L
.584 .30051 L
.588 .29944 L
.592 .29825 L
.596 .29763 L
.6 .29787 L
Mistroke
.604 .29873 L
.608 .29962 L
.612 .30004 L
.616 .29982 L
.62 .29917 L
.624 .29856 L
.628 .29835 L
.632 .29862 L
.636 .29915 L
.64 .29955 L
.644 .29957 L
.648 .29921 L
.652 .29872 L
.656 .29839 L
.66 .29838 L
.664 .29869 L
.668 .29914 L
.672 .29949 L
.676 .29959 L
.68 .29937 L
.684 .29896 L
.688 .2986 L
.692 .29849 L
.696 .29867 L
.7 .29898 L
.704 .29919 L
.708 .29915 L
.712 .29891 L
.716 .29868 L
.72 .29865 L
.724 .29887 L
.728 .2992 L
.732 .29941 L
.736 .29931 L
.74 .29893 L
.744 .2985 L
.748 .2983 L
.752 .29848 L
.756 .29892 L
.76 .2993 L
.764 .29933 L
.768 .29901 L
.772 .29864 L
.776 .29855 L
.78 .29881 L
.784 .29918 L
.788 .2993 L
.792 .29899 L
.796 .2985 L
.8 .29821 L
Mistroke
.804 .29838 L
.808 .29888 L
.812 .29933 L
.816 .2994 L
.82 .29911 L
.824 .29871 L
.828 .2985 L
.832 .29858 L
.836 .29875 L
.84 .29883 L
.844 .29877 L
.848 .29865 L
.852 .29866 L
.856 .29886 L
.86 .29909 L
.864 .29917 L
.868 .299 L
.872 .29859 L
.876 .29824 L
.88 .29826 L
.884 .29861 L
.888 .2991 L
.892 .29937 L
.896 .29912 L
.9 .29858 L
.904 .2982 L
.908 .29823 L
.912 .29871 L
.916 .29921 L
.92 .29922 L
.924 .29883 L
.928 .29838 L
.932 .29821 L
.936 .29851 L
.94 .29893 L
.944 .29899 L
.948 .2988 L
.952 .2986 L
.956 .29855 L
.96 .29874 L
.964 .29887 L
.968 .29859 L
.972 .29826 L
.976 .29833 L
.98 .29867 L
.984 .29923 L
.988 .29946 L
.992 .29876 L
.996 .29795 L
1 .2977 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .11095 m
.008 .10935 L
.012 .10891 L
.016 .10978 L
.02 .11071 L
.024 .11158 L
.028 .11261 L
.032 .11399 L
.036 .11568 L
.04 .11763 L
.044 .11963 L
.048 .12166 L
.052 .12364 L
.056 .12568 L
.06 .12768 L
.064 .12957 L
.068 .1311 L
.072 .13245 L
.076 .13395 L
.08 .13569 L
.084 .13742 L
.088 .13901 L
.092 .14054 L
.096 .14222 L
.1 .14436 L
.104 .14693 L
.108 .14962 L
.112 .15208 L
.116 .15411 L
.12 .15592 L
.124 .15802 L
.128 .16076 L
.132 .16404 L
.136 .1674 L
.14 .17021 L
.144 .17223 L
.148 .17362 L
.152 .1747 L
.156 .17582 L
.16 .17722 L
.164 .17921 L
.168 .18205 L
.172 .18597 L
.176 .1909 L
.18 .19648 L
.184 .20233 L
.188 .20822 L
.192 .2142 L
.196 .22039 L
.2 .22685 L
Mistroke
.204 .23342 L
.208 .23987 L
.212 .24604 L
.216 .25202 L
.22 .25804 L
.224 .26432 L
.228 .27088 L
.232 .27749 L
.236 .28387 L
.24 .28979 L
.244 .29529 L
.248 .3006 L
.252 .30608 L
.256 .31197 L
.26 .31832 L
.264 .32495 L
.268 .33155 L
.272 .33783 L
.276 .34365 L
.28 .34906 L
.284 .35429 L
.288 .35966 L
.292 .36543 L
.296 .37179 L
.3 .37873 L
.304 .38611 L
.308 .39367 L
.312 .40111 L
.316 .40813 L
.32 .41451 L
.324 .4201 L
.328 .42485 L
.332 .42877 L
.336 .43194 L
.34 .43447 L
.344 .43646 L
.348 .43803 L
.352 .43927 L
.356 .44025 L
.36 .44103 L
.364 .44167 L
.368 .44219 L
.372 .44261 L
.376 .44297 L
.38 .44327 L
.384 .44353 L
.388 .44376 L
.392 .44397 L
.396 .44415 L
.4 .4443 L
Mistroke
.404 .44443 L
.408 .44454 L
.412 .44463 L
.416 .44471 L
.42 .4448 L
.424 .44489 L
.428 .44499 L
.432 .4451 L
.436 .44518 L
.44 .44524 L
.444 .44527 L
.448 .44527 L
.452 .44527 L
.456 .44527 L
.46 .4453 L
.464 .44535 L
.468 .44541 L
.472 .44548 L
.476 .44554 L
.48 .44558 L
.484 .44559 L
.488 .44559 L
.492 .4456 L
.496 .44562 L
.5 .44566 L
.504 .4457 L
.508 .44575 L
.512 .44579 L
.516 .44581 L
.52 .44583 L
.524 .44584 L
.528 .44585 L
.532 .44588 L
.536 .44592 L
.54 .44596 L
.544 .446 L
.548 .44603 L
.552 .44606 L
.556 .44608 L
.56 .4461 L
.564 .44613 L
.568 .44616 L
.572 .44619 L
.576 .44622 L
.58 .44624 L
.584 .44626 L
.588 .44628 L
.592 .44631 L
.596 .44635 L
.6 .44639 L
Mistroke
.604 .44642 L
.608 .44646 L
.612 .44648 L
.616 .4465 L
.62 .44652 L
.624 .44654 L
.628 .44657 L
.632 .4466 L
.636 .44663 L
.64 .44666 L
.644 .44669 L
.648 .44672 L
.652 .44674 L
.656 .44677 L
.66 .44681 L
.664 .44684 L
.668 .44687 L
.672 .4469 L
.676 .44692 L
.68 .44694 L
.684 .44697 L
.688 .447 L
.692 .44702 L
.696 .44705 L
.7 .44708 L
.704 .44711 L
.708 .44714 L
.712 .44718 L
.716 .44721 L
.72 .44724 L
.724 .44726 L
.728 .44728 L
.732 .4473 L
.736 .44732 L
.74 .44735 L
.744 .44738 L
.748 .44742 L
.752 .44746 L
.756 .44749 L
.76 .44752 L
.764 .44754 L
.768 .44757 L
.772 .44759 L
.776 .44761 L
.78 .44763 L
.784 .44766 L
.788 .4477 L
.792 .44773 L
.796 .44776 L
.8 .44779 L
Mistroke
.804 .44782 L
.808 .44785 L
.812 .44787 L
.816 .4479 L
.82 .44792 L
.824 .44795 L
.828 .44798 L
.832 .44801 L
.836 .44804 L
.84 .44807 L
.844 .4481 L
.848 .44813 L
.852 .44815 L
.856 .44818 L
.86 .44821 L
.864 .44823 L
.868 .44826 L
.872 .44828 L
.876 .44831 L
.88 .44834 L
.884 .44837 L
.888 .44841 L
.892 .44844 L
.896 .44847 L
.9 .44849 L
.904 .44851 L
.908 .44853 L
.912 .44856 L
.916 .44859 L
.92 .44863 L
.924 .44866 L
.928 .44869 L
.932 .44871 L
.936 .44874 L
.94 .44876 L
.944 .44879 L
.948 .44881 L
.952 .44885 L
.956 .44887 L
.96 .44891 L
.964 .44893 L
.968 .44897 L
.972 .44898 L
.976 .44902 L
.98 .44903 L
.984 .44908 L
.988 .44909 L
.992 .44914 L
.996 .44915 L
1 .4492 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16505 L
.012 .16176 L
.016 .16084 L
.02 .16235 L
.024 .16298 L
.028 .16288 L
.032 .16311 L
.036 .1638 L
.04 .1647 L
.044 .16594 L
.048 .16736 L
.052 .16913 L
.056 .17142 L
.06 .17429 L
.064 .17723 L
.068 .18012 L
.072 .18302 L
.076 .1861 L
.08 .18926 L
.084 .19226 L
.088 .19471 L
.092 .19667 L
.096 .19857 L
.1 .20074 L
.104 .20327 L
.108 .20596 L
.112 .20836 L
.116 .21035 L
.12 .21228 L
.124 .2147 L
.128 .21811 L
.132 .22238 L
.136 .22677 L
.14 .23059 L
.144 .23344 L
.148 .23545 L
.152 .23703 L
.156 .23855 L
.16 .24031 L
.164 .24264 L
.168 .24594 L
.172 .2505 L
.176 .25627 L
.18 .26293 L
.184 .27002 L
.188 .27732 L
.192 .2849 L
.196 .29288 L
.2 .30127 L
Mistroke
.204 .3098 L
.208 .31806 L
.212 .32583 L
.216 .33315 L
.22 .34036 L
.224 .34779 L
.228 .35553 L
.232 .36344 L
.236 .37118 L
.24 .37854 L
.244 .38552 L
.248 .39237 L
.252 .39943 L
.256 .40695 L
.26 .41493 L
.264 .42313 L
.268 .4312 L
.272 .43883 L
.276 .44588 L
.28 .45248 L
.284 .45891 L
.288 .46557 L
.292 .47277 L
.296 .48068 L
.3 .48929 L
.304 .49841 L
.308 .50771 L
.312 .51685 L
.316 .52548 L
.32 .53333 L
.324 .54024 L
.328 .54614 L
.332 .55102 L
.336 .55497 L
.34 .5581 L
.344 .56053 L
.348 .5624 L
.352 .56383 L
.356 .56493 L
.36 .56577 L
.364 .56644 L
.368 .56698 L
.372 .56743 L
.376 .56781 L
.38 .56813 L
.384 .56839 L
.388 .56861 L
.392 .56879 L
.396 .56893 L
.4 .56906 L
Mistroke
.404 .56917 L
.408 .56927 L
.412 .56935 L
.416 .56941 L
.42 .56944 L
.424 .56943 L
.428 .56939 L
.432 .56934 L
.436 .5693 L
.44 .56927 L
.444 .56928 L
.448 .5693 L
.452 .56933 L
.456 .56934 L
.46 .56932 L
.464 .56927 L
.468 .56919 L
.472 .56911 L
.476 .56904 L
.48 .569 L
.484 .56898 L
.488 .56897 L
.492 .56895 L
.496 .56892 L
.5 .56887 L
.504 .56881 L
.508 .56875 L
.512 .56869 L
.516 .56865 L
.52 .56863 L
.524 .5686 L
.528 .56857 L
.532 .56853 L
.536 .56848 L
.54 .56843 L
.544 .56837 L
.548 .56832 L
.552 .56828 L
.556 .56824 L
.56 .5682 L
.564 .56816 L
.568 .56812 L
.572 .56807 L
.576 .56804 L
.58 .568 L
.584 .56797 L
.588 .56793 L
.592 .56788 L
.596 .56783 L
.6 .56777 L
Mistroke
.604 .56772 L
.608 .56767 L
.612 .56764 L
.616 .56761 L
.62 .56757 L
.624 .56753 L
.628 .56749 L
.632 .56744 L
.636 .56739 L
.64 .56735 L
.644 .56731 L
.648 .56727 L
.652 .56723 L
.656 .56718 L
.66 .56713 L
.664 .56708 L
.668 .56704 L
.672 .567 L
.676 .56696 L
.68 .56693 L
.684 .56689 L
.688 .56685 L
.692 .5668 L
.696 .56675 L
.7 .56671 L
.704 .56666 L
.708 .56662 L
.712 .56657 L
.716 .56652 L
.72 .56648 L
.724 .56644 L
.728 .5664 L
.732 .56637 L
.736 .56633 L
.74 .56629 L
.744 .56624 L
.748 .56619 L
.752 .56614 L
.756 .56609 L
.76 .56605 L
.764 .56601 L
.768 .56597 L
.772 .56593 L
.776 .5659 L
.78 .56585 L
.784 .56581 L
.788 .56576 L
.792 .56572 L
.796 .56567 L
.8 .56562 L
Mistroke
.804 .56558 L
.808 .56554 L
.812 .5655 L
.816 .56546 L
.82 .56541 L
.824 .56537 L
.828 .56533 L
.832 .56529 L
.836 .56525 L
.84 .5652 L
.844 .56515 L
.848 .56511 L
.852 .56506 L
.856 .56502 L
.86 .56497 L
.864 .56494 L
.868 .5649 L
.872 .56486 L
.876 .56482 L
.88 .56478 L
.884 .56473 L
.888 .56468 L
.892 .56462 L
.896 .56458 L
.9 .56454 L
.904 .5645 L
.908 .56446 L
.912 .56443 L
.916 .56438 L
.92 .56434 L
.924 .56429 L
.928 .56425 L
.932 .56419 L
.936 .56415 L
.94 .5641 L
.944 .56407 L
.948 .56402 L
.952 .564 L
.956 .56395 L
.96 .56392 L
.964 .56385 L
.968 .56382 L
.972 .56376 L
.976 .56373 L
.98 .56366 L
.984 .56364 L
.988 .56358 L
.992 .56357 L
.996 .5635 L
1 .56349 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
0goo0`0017oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`02Ool01000Ool0000017oo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo00D0
07ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`00
0Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo
00]oo`@000=oo`03001oogoo00@00003Ool007oo008000Aoo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`80
00Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`D00005Ool007oo001oo`020004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`800003Ool007oo008000=oo`03001oogoo00=oo`8000Ao
o`8000Ioo`04001oogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool2
0006Ool0029oo`03001oogoo019oo`03001oogoo008000Moo`03001oogoo04]oo`008Woo0P004Woo
0P0037oo0`000Woo0P0000Aoo`00001oo`H00004Ool00000Ool2000017oo000007oo0P0000Aoo`00
001oo`800006Ool007ooOol007oo0P0000=oo`00Ool0100000Aoo`00001oo`800003Ool007oo00H0
00aoo`008WooH`0037oo000ROol01@00Ool007oo00000goo00D007ooOomoo`0000=oo`D000=oo`04
001oogoo0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol0000<Ool0029oo`80009oo`03001oogoo00Yoo`03
001oogoo05]oo`008Woo0P000Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol0Fgoo000R
Ool20003Ool00`00Oomoo`02Ool20005Ool00`00Oomoo`1KOol0029oo`8000=oo`07001oogooOol0
07oo000017oo00<007ooOol0G7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00
Oomoo`02Ool01P00Oomoogoo001oo`8000=oo`03001oogoo05aoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool20004Ool00`00Ool00003Ool4001OOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0017oo00<007oo00001Goo0P00Ggoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00=oo`03001oo`0006Io
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20005Ool00`00Oomoo`1U
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004
Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009o
o`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0
00=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0
K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008
Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo
0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eo
o`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`80
06eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo0000
0goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool0
0`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=o
o`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04
Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`@006Eoo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
1000Oomoogoo0P00Hgoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo
00=oo`<0061oo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol01Goo0`00GWoo000X
Ool00`00Oomoo`07Ool2001MOol002Qoo`03001oogoo00Uoo`8005]oo`002goo0P0017oo00<007oo
Ool00goo0P0017oo0P000goo0`000goo00<007ooOol02Woo0`00FGoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol000moo`03001oogoo05Ioo`000goo
1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0011oo`03
001oogoo05Eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool00P002goo0`0000Aoo`00001oo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80
009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00H007ooOomoo`00Ool20002
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogoo
Ool00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo
00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Ool0
00000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`00
17oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P00
0Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009o
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo0P0000=oo`00Ool01Woo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol0
07oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003
Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Ool000001Woo0P00
17oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool0
00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04001o
ogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ao
o`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool0
02Qoo`03001oogoo01=oo`03001oogoo051oo`00:7oo00<007ooOol04goo0P00DGoo000XOomM000<
Ool002Qoo`03001oogoo00moo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo00moo`03001o
ogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol05Goo0P00Cgoo000XOol0
0`00Oomoo`0FOol00`00Oomoo`1=Ool002Qoo`03001oogoo01Moo`03001oogoo04aoo`00:7oo00<0
07ooOol05goo0P00CGoo000XOol00`00Oomoo`0HOol2001<Ool000]oo`8000Aoo`03001oogoo00=o
o`8000Aoo`8000=oo`<000=oo`03001oogoo01Uoo`03001oogoo04Yoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000KOol00`00Oomoo`1:Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000LOol00`00Oomo
o`19Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo0080
01]oo`8004Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo
00<007ooOol06goo0P00BGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`001Woo00<007ooOol077oo2000@Woo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomo
o`0SOolg000<Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00
Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo
0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003
Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomo
o`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
1Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eo
o`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo
0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P00
17oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`00
2Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03
001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`00
0goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=
Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eo
o`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001o
ogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003
Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H0
07ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool0
1000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04
Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L0
07ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomo
o`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`00
0Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo
000LOol20002Ool300000goo001oo`03Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`03Ool2
001]Ool001aoo`8000Ioo`8006]oo`0077oo00<007ooOol01Woo0`00JGoo000LOol00`00Oomoo`08
Ool2001XOol001aoo`8000]oo`03001oogoo06Eoo`0077oo00<007ooOol02goo0P00IGoo000LOol0
0`00Oomoo`0<Ool3001SOol001aoo`8000moo`80069oo`0077oo00<007ooOol03goo00<007ooOol0
H7oo000LOol2000AOol00`00Oomoo`1OOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001o
ogoo011oo`80061oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0AOol0
0`00Oomoo`1NOol000Yoo`04001oogoo000;Ool00`00Oomoo`02000BOol00`00Oomoo`1NOol000Yo
o`04001oogoo000;Ool01000Oomoo`0057oo00<007ooOol0GGoo000:Ool01000Oomoo`001goo1000
0goo00<007ooOol04Woo0P00GWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P0057oo00<0
07ooOol0G7oo000;Ool20008Ool50002Ool00`00Oomoo`0DOol00`00Oomoo`1KOol001aoo`03001o
ogoo01Aoo`03001oogoo05]oo`0077oo0P005Goo0P00G7oo000LOol00`00Oomoo`0EOol00`00Oomo
o`1JOol001aoo`8001Moo`03001oogoo05Uoo`0077oo00<007ooOol05Woo00<007ooOol0FGoo000L
Ool00`00Oomoo`0GOol00`00Oomoo`1HOol001aoo`8001Qoo`03001oogoo05Qoo`005Woo0`000goo
00<007ooOol067oo00<007ooOol0Egoo000GOol00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomo
o`1FOol001Moo`03001oogoo009oo`8001Yoo`03001oogoo05Ioo`005goo00<007ooOol00Woo00<0
07ooOol06Goo00<007ooOol0EWoo000GOol00`00Oomoo`02Ool00`00Oomoo`0JOol00`00Oomoo`1E
Ool001Ioo`8000Aoo`8001aoo`03001oogoo05Aoo`005goo00<007ooOol00Woo00<007ooOol06goo
00<007ooOol0E7oo000LOol00`00Oomoo`0LOol00`00Oomoo`1COol001aoo`8001eoo`03001oogoo
05=oo`0077oo00<007ooOol07Goo00<007ooOol0DWoo000LOol2000NOol00`00Oomoo`1BOol001ao
o`03001oogoo01eoo`03001oogoo059oo`0077oo00<007ooOol07Woo00<007ooOol0DGoo000:Ool3
0004Ool00`00Oomoo`02Ool30003Ool2000OOol2001BOol000]oo`03001oogoo00Moo`05001oogoo
Ool00002Ool00`00Oomoo`0OOol00`00Oomoo`1@Ool000]oo`03001oogoo00]oo`04001oogoo000R
Ool00`00Oomoo`1?Ool000]oo`03001oogoo00]oo`03001oogoo0080029oodD000aoo`002goo00<0
07ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1b
Ool000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(38577\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .26542 m
.008 .26373 L
.012 .2672 L
.016 .27524 L
.02 .28676 L
.024 .30182 L
.028 .31848 L
.032 .33469 L
.036 .34877 L
.04 .3596 L
.044 .36676 L
.048 .36942 L
.052 .36775 L
.056 .36249 L
.06 .35587 L
.064 .35045 L
.068 .34675 L
.072 .34425 L
.076 .3434 L
.08 .34602 L
.084 .35149 L
.088 .35741 L
.092 .3618 L
.096 .36412 L
.1 .36507 L
.104 .36576 L
.108 .3667 L
.112 .36741 L
.116 .3673 L
.12 .36549 L
.124 .36248 L
.128 .36032 L
.132 .36048 L
.136 .3624 L
.14 .36361 L
.144 .36161 L
.148 .35719 L
.152 .35427 L
.156 .3562 L
.16 .36345 L
.164 .37322 L
.168 .38166 L
.172 .38649 L
.176 .38699 L
.18 .38273 L
.184 .37294 L
.188 .3578 L
.192 .33968 L
.196 .32299 L
.2 .3121 L
Mistroke
.204 .30843 L
.208 .30974 L
.212 .31182 L
.216 .31115 L
.22 .30682 L
.224 .30026 L
.228 .29343 L
.232 .2873 L
.236 .28164 L
.24 .27588 L
.244 .27033 L
.248 .26635 L
.252 .26539 L
.256 .26786 L
.26 .27233 L
.264 .27606 L
.268 .27641 L
.272 .2722 L
.276 .2644 L
.28 .25573 L
.284 .24934 L
.288 .24745 L
.292 .25039 L
.296 .25664 L
.3 .26349 L
.304 .26817 L
.308 .26882 L
.312 .26497 L
.316 .25749 L
.32 .24818 L
.324 .23911 L
.328 .23212 L
.332 .2285 L
.336 .2288 L
.34 .23288 L
.344 .23999 L
.348 .24894 L
.352 .25836 L
.356 .26702 L
.36 .27413 L
.364 .27949 L
.368 .28352 L
.372 .28694 L
.376 .29039 L
.38 .2941 L
.384 .29773 L
.388 .30057 L
.392 .30187 L
.396 .30137 L
.4 .29949 L
Mistroke
.404 .29727 L
.408 .29595 L
.412 .29633 L
.416 .29839 L
.42 .30122 L
.424 .30344 L
.428 .30391 L
.432 .30232 L
.436 .29939 L
.44 .29656 L
.444 .29522 L
.448 .29598 L
.452 .29839 L
.456 .30111 L
.46 .30269 L
.464 .30233 L
.468 .30031 L
.472 .2978 L
.476 .29621 L
.48 .29642 L
.484 .29823 L
.488 .30057 L
.492 .3021 L
.496 .30196 L
.5 .3003 L
.504 .2981 L
.508 .2966 L
.512 .29663 L
.516 .29807 L
.52 .30002 L
.524 .30134 L
.528 .30129 L
.532 .30001 L
.536 .29834 L
.54 .2973 L
.544 .29746 L
.548 .29865 L
.552 .30009 L
.556 .3009 L
.56 .30061 L
.564 .29947 L
.568 .2982 L
.572 .29757 L
.576 .29788 L
.58 .29887 L
.584 .29987 L
.588 .30028 L
.592 .29995 L
.596 .29918 L
.6 .29849 L
Mistroke
.604 .2983 L
.608 .29866 L
.612 .29929 L
.616 .29975 L
.62 .29974 L
.624 .29928 L
.628 .29868 L
.632 .29831 L
.636 .29839 L
.64 .29884 L
.644 .29938 L
.648 .29972 L
.652 .29972 L
.656 .29939 L
.66 .29893 L
.664 .29857 L
.668 .2985 L
.672 .29872 L
.676 .29907 L
.68 .29932 L
.684 .2993 L
.688 .29906 L
.692 .29879 L
.696 .29873 L
.7 .29892 L
.704 .29923 L
.708 .29943 L
.712 .29934 L
.716 .29899 L
.72 .29859 L
.724 .29842 L
.728 .29859 L
.732 .29901 L
.736 .29937 L
.74 .29941 L
.744 .29911 L
.748 .29872 L
.752 .29858 L
.756 .29881 L
.76 .29922 L
.764 .29942 L
.768 .29918 L
.772 .29864 L
.776 .29823 L
.78 .29829 L
.784 .29882 L
.788 .29943 L
.792 .29968 L
.796 .29942 L
.8 .29887 L
Mistroke
.804 .29842 L
.808 .29836 L
.812 .29861 L
.816 .29894 L
.82 .2991 L
.824 .29901 L
.828 .29886 L
.832 .2988 L
.836 .29889 L
.84 .29903 L
.844 .29905 L
.848 .29886 L
.852 .29862 L
.856 .29851 L
.86 .29863 L
.864 .29891 L
.868 .29912 L
.872 .29903 L
.876 .29878 L
.88 .29859 L
.884 .29864 L
.888 .29894 L
.892 .29916 L
.896 .29899 L
.9 .2986 L
.904 .29828 L
.908 .29834 L
.912 .29883 L
.916 .2993 L
.92 .2993 L
.924 .29891 L
.928 .29844 L
.932 .29829 L
.936 .29859 L
.94 .29896 L
.944 .29897 L
.948 .29873 L
.952 .29852 L
.956 .29853 L
.96 .29888 L
.964 .29914 L
.968 .2989 L
.972 .29855 L
.976 .29836 L
.98 .2984 L
.984 .29882 L
.988 .29904 L
.992 .29872 L
.996 .29846 L
1 .29847 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .10774 m
.008 .11258 L
.012 .11429 L
.016 .1129 L
.02 .11265 L
.024 .11352 L
.028 .11384 L
.032 .1137 L
.036 .11359 L
.04 .11361 L
.044 .11355 L
.048 .11349 L
.052 .11355 L
.056 .11392 L
.06 .11467 L
.064 .11579 L
.068 .11708 L
.072 .11862 L
.076 .12056 L
.08 .12287 L
.084 .12519 L
.088 .12735 L
.092 .12937 L
.096 .13142 L
.1 .13357 L
.104 .13575 L
.108 .13765 L
.112 .13921 L
.116 .14059 L
.12 .14207 L
.124 .14396 L
.128 .14627 L
.132 .14863 L
.136 .1507 L
.14 .15241 L
.144 .15406 L
.148 .15621 L
.152 .1591 L
.156 .1625 L
.16 .16593 L
.164 .16889 L
.168 .17119 L
.172 .17288 L
.176 .17411 L
.18 .17511 L
.184 .17615 L
.188 .17767 L
.192 .18006 L
.196 .18355 L
.2 .18804 L
Mistroke
.204 .19318 L
.208 .19863 L
.212 .20424 L
.216 .21009 L
.22 .21627 L
.224 .22277 L
.228 .22936 L
.232 .23579 L
.236 .24195 L
.24 .24793 L
.244 .25394 L
.248 .26019 L
.252 .26669 L
.256 .27325 L
.26 .27959 L
.264 .28554 L
.268 .2911 L
.272 .2965 L
.276 .30205 L
.28 .30797 L
.284 .31431 L
.288 .32093 L
.292 .32753 L
.296 .33385 L
.3 .33971 L
.304 .34515 L
.308 .35034 L
.312 .35558 L
.316 .36116 L
.32 .36727 L
.324 .37398 L
.328 .38119 L
.332 .3887 L
.336 .39623 L
.34 .4035 L
.344 .41026 L
.348 .41633 L
.352 .4216 L
.356 .42607 L
.36 .42976 L
.364 .43275 L
.368 .43513 L
.372 .43701 L
.376 .43848 L
.38 .43963 L
.384 .44053 L
.388 .44124 L
.392 .44183 L
.396 .44233 L
.4 .44277 L
Mistroke
.404 .44315 L
.408 .44349 L
.412 .44377 L
.416 .44399 L
.42 .44417 L
.424 .4443 L
.428 .44441 L
.432 .44452 L
.436 .44463 L
.44 .44476 L
.444 .44489 L
.448 .445 L
.452 .4451 L
.456 .44517 L
.46 .44521 L
.464 .44524 L
.468 .44527 L
.472 .44531 L
.476 .44536 L
.48 .44541 L
.484 .44547 L
.488 .44551 L
.492 .44554 L
.496 .44556 L
.5 .44558 L
.504 .4456 L
.508 .44563 L
.512 .44567 L
.516 .44571 L
.52 .44575 L
.524 .44578 L
.528 .44581 L
.532 .44584 L
.536 .44586 L
.54 .44589 L
.544 .44591 L
.548 .44594 L
.552 .44597 L
.556 .44599 L
.56 .44601 L
.564 .44604 L
.568 .44607 L
.572 .44611 L
.576 .44614 L
.58 .44618 L
.584 .44621 L
.588 .44623 L
.592 .44625 L
.596 .44627 L
.6 .4463 L
Mistroke
.604 .44633 L
.608 .44636 L
.612 .44639 L
.616 .44642 L
.62 .44644 L
.624 .44647 L
.628 .4465 L
.632 .44653 L
.636 .44656 L
.64 .4466 L
.644 .44662 L
.648 .44665 L
.652 .44667 L
.656 .44669 L
.66 .44672 L
.664 .44675 L
.668 .44678 L
.672 .44681 L
.676 .44684 L
.68 .44687 L
.684 .4469 L
.688 .44693 L
.692 .44696 L
.696 .44699 L
.7 .44701 L
.704 .44703 L
.708 .44705 L
.712 .44708 L
.716 .44711 L
.72 .44714 L
.724 .44717 L
.728 .44721 L
.732 .44724 L
.736 .44727 L
.74 .44729 L
.744 .44732 L
.748 .44734 L
.752 .44736 L
.756 .44739 L
.76 .44742 L
.764 .44745 L
.768 .44748 L
.772 .44752 L
.776 .44755 L
.78 .44757 L
.784 .4476 L
.788 .44762 L
.792 .44765 L
.796 .44767 L
.8 .4477 L
Mistroke
.804 .44773 L
.808 .44776 L
.812 .44779 L
.816 .44782 L
.82 .44785 L
.824 .44788 L
.828 .44791 L
.832 .44793 L
.836 .44796 L
.84 .44798 L
.844 .44801 L
.848 .44804 L
.852 .44806 L
.856 .44809 L
.86 .44813 L
.864 .44816 L
.868 .44819 L
.872 .44822 L
.876 .44824 L
.88 .44827 L
.884 .44829 L
.888 .44831 L
.892 .44834 L
.896 .44838 L
.9 .44841 L
.904 .44844 L
.908 .44847 L
.912 .4485 L
.916 .44852 L
.92 .44855 L
.924 .44857 L
.928 .4486 L
.932 .44862 L
.936 .44866 L
.94 .44868 L
.944 .44872 L
.948 .44874 L
.952 .44878 L
.956 .44879 L
.96 .44882 L
.964 .44884 L
.968 .44888 L
.972 .4489 L
.976 .44894 L
.98 .44896 L
.984 .449 L
.988 .44902 L
.992 .44906 L
.996 .44907 L
1 .44911 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16141 L
.012 .15878 L
.016 .15704 L
.02 .15659 L
.024 .15629 L
.028 .15608 L
.032 .15609 L
.036 .15654 L
.04 .15734 L
.044 .15844 L
.048 .15956 L
.052 .16075 L
.056 .16213 L
.06 .16377 L
.064 .16536 L
.068 .16687 L
.072 .16843 L
.076 .17027 L
.08 .17238 L
.084 .17464 L
.088 .17675 L
.092 .17881 L
.096 .18111 L
.1 .18377 L
.104 .18653 L
.108 .18915 L
.112 .19141 L
.116 .19342 L
.12 .1956 L
.124 .19823 L
.128 .20125 L
.132 .20428 L
.136 .20679 L
.14 .2087 L
.144 .21051 L
.148 .21284 L
.152 .21611 L
.156 .22013 L
.16 .22427 L
.164 .22801 L
.168 .23108 L
.172 .23349 L
.176 .23538 L
.18 .23692 L
.184 .23841 L
.188 .24029 L
.192 .24309 L
.196 .24711 L
.2 .2523 L
Mistroke
.204 .25833 L
.208 .26485 L
.212 .27174 L
.216 .27909 L
.22 .28699 L
.224 .29533 L
.228 .30379 L
.232 .31197 L
.236 .31968 L
.24 .32704 L
.244 .33437 L
.248 .34197 L
.252 .34989 L
.256 .35795 L
.26 .3658 L
.264 .37321 L
.268 .38016 L
.272 .3869 L
.276 .39378 L
.28 .40109 L
.284 .40889 L
.288 .41702 L
.292 .42516 L
.296 .43296 L
.3 .44024 L
.304 .44702 L
.308 .4535 L
.312 .46004 L
.316 .46698 L
.32 .47455 L
.324 .48282 L
.328 .4917 L
.332 .50094 L
.336 .51021 L
.34 .51916 L
.344 .52749 L
.348 .53498 L
.352 .5415 L
.356 .54701 L
.36 .55155 L
.364 .55521 L
.368 .5581 L
.372 .56037 L
.376 .56214 L
.38 .56352 L
.384 .56461 L
.388 .56546 L
.392 .56614 L
.396 .56666 L
.4 .56707 L
Mistroke
.404 .56738 L
.408 .56764 L
.412 .56786 L
.416 .56806 L
.42 .56826 L
.424 .56845 L
.428 .56862 L
.432 .56874 L
.436 .56882 L
.44 .56885 L
.444 .56884 L
.448 .56882 L
.452 .56881 L
.456 .56882 L
.46 .56883 L
.464 .56886 L
.468 .56887 L
.472 .56886 L
.476 .56882 L
.48 .56877 L
.484 .56872 L
.488 .56867 L
.492 .56865 L
.496 .56863 L
.5 .56861 L
.504 .56859 L
.508 .56855 L
.512 .56849 L
.516 .56844 L
.52 .56838 L
.524 .56834 L
.528 .5683 L
.532 .56826 L
.536 .56823 L
.54 .56818 L
.544 .56814 L
.548 .5681 L
.552 .56806 L
.556 .56802 L
.56 .56799 L
.564 .56795 L
.568 .5679 L
.572 .56785 L
.576 .56779 L
.58 .56774 L
.584 .56769 L
.588 .56766 L
.592 .56763 L
.596 .56759 L
.6 .56756 L
Mistroke
.604 .56751 L
.608 .56747 L
.612 .56742 L
.616 .56737 L
.62 .56733 L
.624 .56729 L
.628 .56725 L
.632 .5672 L
.636 .56716 L
.64 .56711 L
.644 .56706 L
.648 .56702 L
.652 .56698 L
.656 .56695 L
.66 .56691 L
.664 .56687 L
.668 .56682 L
.672 .56678 L
.676 .56673 L
.68 .56669 L
.684 .56664 L
.688 .56659 L
.692 .56654 L
.696 .5665 L
.7 .56646 L
.704 .56643 L
.708 .5664 L
.712 .56636 L
.716 .56632 L
.72 .56626 L
.724 .56621 L
.728 .56616 L
.732 .56611 L
.736 .56607 L
.74 .56603 L
.744 .566 L
.748 .56596 L
.752 .56592 L
.756 .56588 L
.76 .56583 L
.764 .56579 L
.768 .56574 L
.772 .56569 L
.776 .56564 L
.78 .5656 L
.784 .56556 L
.788 .56552 L
.792 .56548 L
.796 .56544 L
.8 .5654 L
Mistroke
.804 .56535 L
.808 .56531 L
.812 .56527 L
.816 .56522 L
.82 .56518 L
.824 .56513 L
.828 .56509 L
.832 .56504 L
.836 .565 L
.84 .56496 L
.844 .56492 L
.848 .56488 L
.852 .56484 L
.856 .5648 L
.86 .56475 L
.864 .5647 L
.868 .56465 L
.872 .56461 L
.876 .56457 L
.88 .56453 L
.884 .56449 L
.888 .56445 L
.892 .5644 L
.896 .56436 L
.9 .56431 L
.904 .56427 L
.908 .56422 L
.912 .56418 L
.916 .56414 L
.92 .5641 L
.924 .56405 L
.928 .56402 L
.932 .56397 L
.936 .56393 L
.94 .56388 L
.944 .56385 L
.948 .56379 L
.952 .56376 L
.956 .5637 L
.96 .56367 L
.964 .56361 L
.968 .56358 L
.972 .56353 L
.976 .56351 L
.98 .56345 L
.984 .56342 L
.988 .56335 L
.992 .56333 L
.996 .56326 L
1 .56324 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo0P000goo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Ool00002Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0002
Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0
2goo10000goo00@007ooOol0009oo`<00005Ool00000Ool00002Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogooOol40003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:
Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool00`00Oomoo`0200001Goo001oo`00
Ool00P0000Eoo`00001oo`00009oo`04001oogoo0002Ool00`00Oomoo`02Ool20003Ool00`00Oomo
o`04Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo
00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000ROol3000;Ool50003Ool60002Ool00`00
Ool00002Ool00`00Oomoo`020004Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P00
17oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Ool0000DOol00`00Oomoo`0:Ool00`00
Oomoo`18Ool0029oo`<001=oo`03001oogoo00aoo`800004Ool00000Ool2000017oo000007oo0P00
00=oo`0000000`000Woo00@007oo0000009oo`800003Ool007oo00800003Ool007oo00800003Ool0
000000=oo`800003Ool007oo00800005Ool00000001oo`04000<Ool0029oof<000aoo`008Woo00<0
07ooOol00P000goo00D007ooOomoo`0000=oo`04001oogooOol20002Ool01000Oomoo`000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00009o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo000037oo000ROol200000goo001oo`0>Ool00`00Oomoo`1IOol0029oo`04
001oogoo000?Ool00`00Oomoo`1IOol0029oo`80009oo`03001oogoo008000Yoo`03001oogoo05Uo
o`008Woo0P000Woo00@007oo001oo`8000=oo`03001oo`00009oo`03001oogoo05Yoo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo00@007ooOomoo`<0009oo`H00004Ool007oo001LOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P003Woo00<007oo0000G7oo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000moo`8005aoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0
K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo
00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol0
0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2
000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00
Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
1000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<0
07ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@00
0Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:
Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
06Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool7001ROol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol00goo0`00H7oo000@Ool0
1000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00Eoo`<005ioo`004Goo0P002Woo
0P0017oo00<007ooOol00Woo00<007ooOol01goo0`00G7oo000XOol00`00Oomoo`0:Ool2001JOol0
02Qoo`03001oogoo00]oo`8005Uoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`00
0goo00<007ooOol03Goo0`00EWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`000goo00@007ooOol0015oo`8005Eoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOol0019oo`03001oogoo05=oo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`000goo0`001goo0`0017oo
0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo
0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00
Oomoo`09Ool01@00Oomoogoo00000Woo10001goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<0
07ooOol03Goo00D007ooOol007oo008000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo
00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yo
o`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo
00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo
0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
o`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`03001oogoo
008000Eoo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool0
0006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20002Ool00`00Oomoo`03Ool0
0`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P00
17oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`0EOol2001?Ool002Qoo`03001oogoo01Io
o`03001oogoo04eoo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`05Ool00`00Oomo
o`08Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03
001oogoo01Qoo`03001oogoo04]oo`00:7oo00<007ooOol06Goo00<007ooOol0BWoo000XOol00`00
Oomoo`0IOol2001;Ool002Qoo`03001oogoo01Yoo`03001oogoo04Uoo`00:7oo00<007ooOol06goo
00<007ooOol0B7oo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomo
o`0KOol00`00Oomoo`18Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0003Ool01000Oomoo`007Woo00<007ooOol0Agoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0005Ool01000Oomoo`007Woo0P00B7oo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`02000NOol00`00Oomoo`16Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo01ioo`03001oogoo04Eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo01moo`L0
041oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol09Goo=@0037oo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo
00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo
009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000
Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001o
ogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=o
o`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04
001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol0
0003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00
Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
0goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo
00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomo
o`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@0
07ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04
001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@0
07ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@0
07ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00H007ooOomoo`00Ool3
0004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`06Ool2001ZOol001aoo`8000Uoo`8006Qo
o`0077oo00<007ooOol02Goo0P00Igoo000LOol00`00Oomoo`0;Ool2001UOol001aoo`8000ioo`03
001oogoo069oo`0077oo00<007ooOol03Woo0P00HWoo000LOol00`00Oomoo`0?Ool3001POol001ao
o`80019oo`03001oogoo05ioo`0077oo00<007ooOol04Woo00<007ooOol0GGoo000LOol2000DOol0
0`00Oomoo`1LOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo01=oo`8005eoo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0DOol00`00Oomoo`1KOol000Yo
o`04001oogoo000;Ool00`00Oomoo`02000EOol00`00Oomoo`1KOol000Yoo`04001oogoo000;Ool0
1000Oomoo`005goo00<007ooOol0FWoo000:Ool01000Oomoo`001goo10000goo00<007ooOol05Goo
00<007ooOol0FWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P005goo00<007ooOol0FGoo
000;Ool20008Ool50002Ool00`00Oomoo`0FOol00`00Oomoo`1IOol001aoo`03001oogoo01Moo`03
001oogoo05Qoo`0077oo0P0067oo00<007ooOol0F7oo000LOol00`00Oomoo`0HOol00`00Oomoo`1G
Ool001aoo`8001Yoo`03001oogoo05Ioo`0077oo00<007ooOol06Goo00<007ooOol0EWoo000LOol0
0`00Oomoo`0IOol2001GOol001aoo`8001]oo`03001oogoo05Eoo`005Woo0`000goo00<007ooOol0
6goo00<007ooOol0E7oo000GOol00`00Oomoo`02Ool00`00Oomoo`0KOol00`00Oomoo`1DOol001Mo
o`03001oogoo009oo`8001aoo`8005Eoo`005goo00<007ooOol00Woo00<007ooOol077oo00<007oo
Ool0Dgoo000GOol00`00Oomoo`02Ool00`00Oomoo`0MOol00`00Oomoo`1BOol001Ioo`8000Aoo`80
01ioo`03001oogoo059oo`005goo00<007ooOol00Woo00<007ooOol07Woo00<007ooOol0DGoo000L
Ool00`00Oomoo`0NOol00`00Oomoo`1AOol001aoo`80021oo`03001oogoo051oo`0077oo00<007oo
Ool087oo00<007ooOol0Cgoo000LOol2000QOol00`00Oomoo`1?Ool001aoo`03001oogoo021oo`03
001oogoo04moo`0077oo00<007ooOol08Goo00<007ooOol0CWoo000:Ool30004Ool00`00Oomoo`02
Ool30003Ool2000ROol00`00Oomoo`1>Ool000]oo`03001oogoo00Moo`05001oogooOol00002Ool0
0`00Oomoo`0ROol00`00Oomoo`1=Ool000]oo`03001oogoo00]oo`04001oogoo000TOol2001>Ool0
00]oo`03001oogoo00]oo`03001oogoo008002Eood8000aoo`002goo00<007ooOol01goo10000goo
00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo
00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(38744\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32497 m
.008 .33366 L
.012 .34111 L
.016 .34368 L
.02 .34194 L
.024 .33727 L
.028 .33083 L
.032 .32241 L
.036 .31309 L
.04 .30521 L
.044 .29983 L
.048 .29803 L
.052 .29922 L
.056 .30269 L
.06 .30819 L
.064 .31588 L
.068 .32458 L
.072 .33185 L
.076 .33767 L
.08 .34371 L
.084 .35048 L
.088 .35662 L
.092 .361 L
.096 .36379 L
.1 .36555 L
.104 .3668 L
.108 .36673 L
.112 .36435 L
.116 .35979 L
.12 .35446 L
.124 .35049 L
.128 .35003 L
.132 .35368 L
.136 .35948 L
.14 .3645 L
.144 .36643 L
.148 .36564 L
.152 .36462 L
.156 .36454 L
.16 .36406 L
.164 .36113 L
.168 .35539 L
.172 .3497 L
.176 .34823 L
.18 .35278 L
.184 .36173 L
.188 .37156 L
.192 .37923 L
.196 .38346 L
.2 .38388 L
Mistroke
.204 .37993 L
.208 .37095 L
.212 .3577 L
.216 .34304 L
.22 .33083 L
.224 .32364 L
.228 .32088 L
.232 .31919 L
.236 .31496 L
.24 .30671 L
.244 .29604 L
.248 .28625 L
.252 .27998 L
.256 .27756 L
.26 .27723 L
.264 .27652 L
.268 .27409 L
.272 .27039 L
.276 .26707 L
.28 .26562 L
.284 .26625 L
.288 .26768 L
.292 .26792 L
.296 .26545 L
.3 .26013 L
.304 .25335 L
.308 .24742 L
.312 .2445 L
.316 .24561 L
.32 .25021 L
.324 .25637 L
.328 .26154 L
.332 .26346 L
.336 .26098 L
.34 .25442 L
.344 .24538 L
.348 .23618 L
.352 .22899 L
.356 .22524 L
.36 .22522 L
.364 .22826 L
.368 .23322 L
.372 .23909 L
.376 .24538 L
.38 .25219 L
.384 .2599 L
.388 .2686 L
.392 .27779 L
.396 .28633 L
.4 .29287 L
Mistroke
.404 .29649 L
.408 .29719 L
.412 .296 L
.416 .29455 L
.42 .29431 L
.424 .29587 L
.428 .29874 L
.432 .30161 L
.436 .30311 L
.44 .30258 L
.444 .30041 L
.448 .29786 L
.452 .29634 L
.456 .29663 L
.46 .29852 L
.464 .30088 L
.468 .30235 L
.472 .30211 L
.476 .30033 L
.48 .29803 L
.484 .29652 L
.488 .29661 L
.492 .29817 L
.496 .30023 L
.5 .30159 L
.504 .30151 L
.508 .30011 L
.512 .29832 L
.516 .29721 L
.52 .29741 L
.524 .29871 L
.528 .30026 L
.532 .30111 L
.536 .30078 L
.54 .29953 L
.544 .29817 L
.548 .2975 L
.552 .29785 L
.556 .29893 L
.56 .30003 L
.564 .3005 L
.568 .30015 L
.572 .2993 L
.576 .29853 L
.58 .2983 L
.584 .29866 L
.588 .2993 L
.592 .29977 L
.596 .29979 L
.6 .29938 L
Mistroke
.604 .29882 L
.608 .29846 L
.612 .29851 L
.616 .29892 L
.62 .29943 L
.624 .29975 L
.628 .29974 L
.632 .29944 L
.636 .29903 L
.64 .29872 L
.644 .29862 L
.648 .29877 L
.652 .29905 L
.656 .29928 L
.66 .29935 L
.664 .29921 L
.668 .29901 L
.672 .29892 L
.676 .29902 L
.68 .29924 L
.684 .29939 L
.688 .29931 L
.692 .29902 L
.696 .29869 L
.7 .29855 L
.704 .29871 L
.708 .29908 L
.712 .29942 L
.716 .2995 L
.72 .29926 L
.724 .29889 L
.728 .29867 L
.732 .29878 L
.736 .29912 L
.74 .29936 L
.744 .29927 L
.748 .29887 L
.752 .29848 L
.756 .29846 L
.76 .29886 L
.764 .2994 L
.768 .29967 L
.772 .29947 L
.776 .29895 L
.78 .29851 L
.784 .29844 L
.788 .29871 L
.792 .29907 L
.796 .29921 L
.8 .29909 L
Mistroke
.804 .29887 L
.808 .29879 L
.812 .29893 L
.816 .29916 L
.82 .29923 L
.824 .29902 L
.828 .29867 L
.832 .29845 L
.836 .29856 L
.84 .29894 L
.844 .2993 L
.848 .29932 L
.852 .29902 L
.856 .29864 L
.86 .29849 L
.864 .29873 L
.868 .2991 L
.872 .29923 L
.876 .29904 L
.88 .29865 L
.884 .29843 L
.888 .2986 L
.892 .29894 L
.896 .29915 L
.9 .29912 L
.904 .29889 L
.908 .29873 L
.912 .29879 L
.916 .29886 L
.92 .29875 L
.924 .29856 L
.928 .29847 L
.932 .29868 L
.936 .29915 L
.94 .29942 L
.944 .29917 L
.948 .29867 L
.952 .29823 L
.956 .29819 L
.96 .29868 L
.964 .29911 L
.968 .29913 L
.972 .29894 L
.976 .29865 L
.98 .29854 L
.984 .29876 L
.988 .29886 L
.992 .29871 L
.996 .29863 L
1 .29865 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .11557 m
.008 .11801 L
.012 .1184 L
.016 .11689 L
.02 .11554 L
.024 .1147 L
.028 .11384 L
.032 .11293 L
.036 .11221 L
.04 .11184 L
.044 .11171 L
.048 .11179 L
.052 .11194 L
.056 .11224 L
.06 .11264 L
.064 .11313 L
.068 .11348 L
.072 .11379 L
.076 .11425 L
.08 .11495 L
.084 .1157 L
.088 .11649 L
.092 .11742 L
.096 .11867 L
.1 .12029 L
.104 .12217 L
.108 .12405 L
.112 .12589 L
.116 .12782 L
.12 .12998 L
.124 .13233 L
.128 .13468 L
.132 .13671 L
.136 .13832 L
.14 .13971 L
.144 .14126 L
.148 .14323 L
.152 .14553 L
.156 .14774 L
.16 .14958 L
.164 .15109 L
.168 .15268 L
.172 .15483 L
.176 .15767 L
.18 .16097 L
.184 .16433 L
.188 .16741 L
.192 .17001 L
.196 .17204 L
.2 .1735 L
Mistroke
.204 .17451 L
.208 .17538 L
.212 .1766 L
.216 .17862 L
.22 .18163 L
.224 .18554 L
.228 .19007 L
.232 .19499 L
.236 .20023 L
.24 .2059 L
.244 .21205 L
.248 .21858 L
.252 .22522 L
.256 .2317 L
.26 .23789 L
.264 .24388 L
.268 .24989 L
.272 .25611 L
.276 .26257 L
.28 .26911 L
.284 .27546 L
.288 .28145 L
.292 .28706 L
.296 .29249 L
.3 .29802 L
.304 .30387 L
.308 .31013 L
.312 .3167 L
.316 .32331 L
.32 .32972 L
.324 .33571 L
.328 .34126 L
.332 .34651 L
.336 .3517 L
.34 .35712 L
.344 .36299 L
.348 .36942 L
.352 .37638 L
.356 .38374 L
.36 .39125 L
.364 .39866 L
.368 .40572 L
.372 .41221 L
.376 .41801 L
.38 .42303 L
.384 .42726 L
.388 .43073 L
.392 .43353 L
.396 .43573 L
.4 .43746 L
Mistroke
.404 .43882 L
.408 .4399 L
.412 .44077 L
.416 .4415 L
.42 .44211 L
.424 .44262 L
.428 .44304 L
.432 .44337 L
.436 .44364 L
.44 .44386 L
.444 .44406 L
.448 .44425 L
.452 .44443 L
.456 .4446 L
.46 .44475 L
.464 .44487 L
.468 .44496 L
.472 .44504 L
.476 .4451 L
.48 .44516 L
.484 .44523 L
.488 .4453 L
.492 .44536 L
.496 .44542 L
.5 .44547 L
.504 .44551 L
.508 .44554 L
.512 .44558 L
.516 .44561 L
.52 .44564 L
.524 .44568 L
.528 .44571 L
.532 .44573 L
.536 .44576 L
.54 .44579 L
.544 .44582 L
.548 .44586 L
.552 .4459 L
.556 .44593 L
.56 .44596 L
.564 .44598 L
.568 .446 L
.572 .44602 L
.576 .44605 L
.58 .44608 L
.584 .44611 L
.588 .44614 L
.592 .44617 L
.596 .4462 L
.6 .44623 L
Mistroke
.604 .44625 L
.608 .44628 L
.612 .44631 L
.616 .44635 L
.62 .44638 L
.624 .4464 L
.628 .44643 L
.632 .44645 L
.636 .44647 L
.64 .4465 L
.644 .44653 L
.648 .44656 L
.652 .44659 L
.656 .44662 L
.66 .44665 L
.664 .44668 L
.668 .44671 L
.672 .44674 L
.676 .44676 L
.68 .44678 L
.684 .4468 L
.688 .44683 L
.692 .44686 L
.696 .4469 L
.7 .44693 L
.704 .44697 L
.708 .447 L
.712 .44702 L
.716 .44704 L
.72 .44707 L
.724 .44709 L
.728 .44711 L
.732 .44714 L
.736 .44717 L
.74 .44721 L
.744 .44724 L
.748 .44727 L
.752 .4473 L
.756 .44732 L
.76 .44735 L
.764 .44737 L
.768 .4474 L
.772 .44743 L
.776 .44746 L
.78 .44748 L
.784 .44751 L
.788 .44754 L
.792 .44757 L
.796 .4476 L
.8 .44763 L
Mistroke
.804 .44766 L
.808 .44769 L
.812 .44771 L
.816 .44774 L
.82 .44776 L
.824 .44779 L
.828 .44781 L
.832 .44785 L
.836 .44788 L
.84 .44791 L
.844 .44794 L
.848 .44797 L
.852 .44799 L
.856 .44802 L
.86 .44804 L
.864 .44806 L
.868 .44809 L
.872 .44813 L
.876 .44816 L
.88 .44819 L
.884 .44822 L
.888 .44825 L
.892 .44827 L
.896 .4483 L
.9 .44832 L
.904 .44835 L
.908 .44837 L
.912 .44841 L
.916 .44843 L
.92 .44847 L
.924 .44849 L
.928 .44853 L
.932 .44855 L
.936 .44858 L
.94 .4486 L
.944 .44863 L
.948 .44865 L
.952 .44869 L
.956 .4487 L
.96 .44874 L
.964 .44877 L
.968 .44881 L
.972 .44883 L
.976 .44887 L
.98 .44887 L
.984 .44891 L
.988 .44892 L
.992 .44897 L
.996 .44898 L
1 .44903 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15802 L
.012 .16148 L
.016 .16253 L
.02 .16131 L
.024 .16086 L
.028 .1611 L
.032 .16089 L
.036 .16033 L
.04 .15985 L
.044 .15954 L
.048 .15907 L
.052 .15858 L
.056 .15822 L
.06 .15814 L
.064 .15817 L
.068 .15828 L
.072 .15856 L
.076 .15919 L
.08 .16019 L
.084 .16145 L
.088 .16277 L
.092 .16424 L
.096 .16608 L
.1 .16836 L
.104 .17077 L
.108 .17312 L
.112 .17529 L
.116 .17746 L
.12 .17984 L
.124 .18248 L
.128 .18511 L
.132 .18747 L
.136 .18945 L
.14 .1913 L
.144 .1935 L
.148 .19629 L
.152 .19947 L
.156 .2025 L
.16 .20488 L
.164 .20668 L
.168 .20843 L
.172 .21074 L
.176 .21389 L
.18 .21768 L
.184 .22167 L
.188 .22548 L
.192 .22884 L
.196 .23162 L
.2 .23371 L
Mistroke
.204 .2352 L
.208 .23642 L
.212 .23794 L
.216 .24034 L
.22 .24393 L
.224 .24862 L
.228 .25412 L
.232 .26016 L
.236 .26668 L
.24 .27378 L
.244 .28148 L
.248 .28964 L
.252 .29789 L
.256 .3059 L
.26 .31352 L
.264 .32089 L
.268 .32831 L
.272 .33603 L
.276 .34408 L
.28 .35225 L
.284 .3602 L
.288 .36767 L
.292 .37466 L
.296 .38138 L
.3 .38819 L
.304 .39538 L
.308 .40308 L
.312 .41116 L
.316 .41932 L
.32 .42723 L
.324 .43466 L
.328 .44154 L
.332 .44805 L
.336 .45448 L
.34 .46118 L
.344 .46844 L
.348 .47639 L
.352 .48503 L
.356 .49416 L
.36 .50349 L
.364 .51269 L
.368 .52141 L
.372 .5294 L
.376 .53648 L
.38 .54258 L
.384 .54771 L
.388 .55193 L
.392 .55536 L
.396 .55811 L
.4 .56028 L
Mistroke
.404 .56199 L
.408 .56331 L
.412 .56432 L
.416 .56509 L
.42 .56568 L
.424 .56616 L
.428 .56656 L
.432 .5669 L
.436 .56721 L
.44 .56748 L
.444 .5677 L
.448 .56787 L
.452 .56799 L
.456 .56807 L
.46 .56814 L
.464 .5682 L
.468 .56825 L
.472 .56831 L
.476 .56835 L
.48 .56837 L
.484 .56837 L
.488 .56836 L
.492 .56833 L
.496 .5683 L
.5 .56827 L
.504 .56825 L
.508 .56823 L
.512 .5682 L
.516 .56817 L
.52 .56814 L
.524 .56811 L
.528 .56807 L
.532 .56803 L
.536 .568 L
.54 .56795 L
.544 .56791 L
.548 .56786 L
.552 .56781 L
.556 .56776 L
.56 .56772 L
.564 .56768 L
.568 .56765 L
.572 .56762 L
.576 .56758 L
.58 .56753 L
.584 .56749 L
.588 .56744 L
.592 .56739 L
.596 .56735 L
.6 .56731 L
Mistroke
.604 .56727 L
.608 .56722 L
.612 .56717 L
.616 .56713 L
.62 .56708 L
.624 .56705 L
.628 .56701 L
.632 .56697 L
.636 .56693 L
.64 .56689 L
.644 .56684 L
.648 .5668 L
.652 .56675 L
.656 .56671 L
.66 .56666 L
.664 .56662 L
.668 .56657 L
.672 .56653 L
.676 .56649 L
.68 .56645 L
.684 .56642 L
.688 .56638 L
.692 .56634 L
.696 .56629 L
.7 .56623 L
.704 .56618 L
.708 .56613 L
.712 .56609 L
.716 .56605 L
.72 .56602 L
.724 .56599 L
.728 .56595 L
.732 .56591 L
.736 .56586 L
.74 .56581 L
.744 .56576 L
.748 .56571 L
.752 .56567 L
.756 .56562 L
.76 .56559 L
.764 .56555 L
.768 .56551 L
.772 .56547 L
.776 .56542 L
.78 .56538 L
.784 .56533 L
.788 .56529 L
.792 .56524 L
.796 .5652 L
.8 .56515 L
Mistroke
.804 .56511 L
.808 .56507 L
.812 .56503 L
.816 .56499 L
.82 .56495 L
.824 .56491 L
.828 .56486 L
.832 .56482 L
.836 .56477 L
.84 .56472 L
.844 .56468 L
.848 .56464 L
.852 .5646 L
.856 .56456 L
.86 .56452 L
.864 .56448 L
.868 .56443 L
.872 .56438 L
.876 .56433 L
.88 .56429 L
.884 .56425 L
.888 .56421 L
.892 .56416 L
.896 .56413 L
.9 .56408 L
.904 .56404 L
.908 .56399 L
.912 .56395 L
.916 .5639 L
.92 .56386 L
.924 .56381 L
.928 .56378 L
.932 .56373 L
.936 .5637 L
.94 .56365 L
.944 .56361 L
.948 .56356 L
.952 .56352 L
.956 .56347 L
.96 .56344 L
.964 .56338 L
.968 .56336 L
.972 .5633 L
.976 .56327 L
.98 .5632 L
.984 .56318 L
.988 .56311 L
.992 .5631 L
.996 .56302 L
1 .56301 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00H007ooOol007oo0002Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`00
00=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool0
0`00Oomoo`02Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001o
ogoo00Eoo`04001oo`00Ool20002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol00goo0`0000=o
o`00Ool00P000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001o
ogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo0P0017oo00<007ooOol02goo10000goo00@007ooOol000Eoo`@000=oo`04001oogoo0002Ool0
1000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]o
o`8000Yoo`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0002Ool30000
17oo000000000goo0P0000Eoo`00Oomoo`00009oo`03001oogoo009oo`8000=oo`03001oogoo00Ao
o`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00
Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0029oo`8000aoo`D000=oo`800004Ool000000004
Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo
0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`0EOol2000=Ool00`00Oomoo`15Ool0
029oo`8000=oo`03001oogoo011oo`03001oogoo00aoo`@00004Ool00000Ool2000017oo000007oo
0P0000Aoo`00001oo`800003Ool0000000Aoo`800003Ool007oo00800003Ool0000000=oo`800003
Ool007oo00800003Ool0000000P000aoo`008WooH`0037oo000ROol02@00Oomoogoo001oo`00Ool0
0003Ool01@00Oomoogoo00000goo00<007ooOol00P000Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`04001oogoo0003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol02Woo000ROol200000goo001oo`02Ool00`00Oomoo`0<Ool00`00Oomoo`1FOol0029oo`@0
00=oo`8000eoo`03001oogoo05Ioo`008Woo0`001Goo00<007ooOol00Woo00D007ooOomoo`0000=o
o`03001oogoo05Moo`008Woo0P001Woo0P0000Aoo`00000000=oo`80009oo`03001oogoo05Moo`00
2goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol01Woo0`000Woo0`0000Eoo`00
Oomoo`0005Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool3
001JOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P004Goo0P00FWoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00
Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo
0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00
Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool0
00]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00
Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=o
o`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0
00=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000R
Ool00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003
Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]o
o`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oo`00
00H0061oo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool30005Ool3001N
Ool0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol027oo0`00Fgoo000A
Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool2001JOol002Qoo`03001oogoo00ao
o`8005Qoo`00:7oo00<007ooOol03Woo0P00EWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool2
0003Ool30003Ool00`00Oomoo`0?Ool3001DOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0003Ool01000Oomoo`0057oo00<007ooOol0DGoo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`0057oo0P00DWoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool30006
Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002
Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@0
00=oo`03001oogoo00Uoo`05001oogooOol00002Ool00`00Oomoo`020006Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007oo00001Goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007oo
Oomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007oo
Ool0009oo`03001oo`0000Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`00
0Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<0
07ooOol02Goo10000goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00
:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol0009oo`80009oo`8000Aoo`04001oogoo
0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000X
Ool00`00Oomoo`09Ool50003Ool20004Ool01@00Oomoogoo00001Goo0P0017oo0P0017oo00@007oo
Oomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<0
07ooOol05goo0P00CGoo000XOol00`00Oomoo`0HOol2001<Ool002Qooed000aoo`00:7oo00<007oo
Ool03goo00<007ooOol027oo00<007ooOol01Goo00<007ooOol03goo00<007ooOol03goo00<007oo
Ool047oo00<007ooOol02Woo000XOol00`00Oomoo`0JOol00`00Oomoo`19Ool002Qoo`03001oogoo
01]oo`03001oogoo04Qoo`00:7oo00<007ooOol06goo0P00BGoo000XOol00`00Oomoo`0MOol00`00
Oomoo`16Ool002Qoo`03001oogoo01eoo`03001oogoo04Ioo`002goo0P0017oo00<007ooOol00goo
0P0017oo0P000goo0`000goo00<007ooOol07Woo00<007ooOol0AGoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol0021oo`03001oogoo04Eoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0025oo`03001oogoo
04Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00
87oo00<007ooOol0A7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`04
0003Ool00`00Oomoo`0POol20014Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007oo
Ool007oo0006Ool00`00Oomoo`0QOol7000nOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03
001oogoo02Mooc<000aoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo
000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00
Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4
001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2
000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;
Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00
Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@00
0Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005
Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001ao
o`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001o
ogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0
009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03
001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo
00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomo
o`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004
Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo
00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001o
ogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004
Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03
001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006
Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY
000<Ool001aoo`05001oogooOol00003Ool01P00Ool00000Ool000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo
00Qoo`<006Moo`0077oo0P002goo0`00IGoo000LOol00`00Oomoo`0<Ool2001TOol001aoo`03001o
ogoo00eoo`<0069oo`0077oo0P0047oo0P00HGoo000LOol00`00Oomoo`0@Ool2001POol001aoo`03
001oogoo015oo`@005eoo`0077oo0P005Goo00<007ooOol0Fgoo000LOol00`00Oomoo`0EOol00`00
Oomoo`1JOol001aoo`8001Moo`03001oogoo05Uoo`002goo0P0017oo00<007ooOol00Woo0`000goo
00<007ooOol05Woo00<007ooOol0FGoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo01Ioo`03001oogoo05Uoo`002Woo00@007ooOol000]oo`03001oogoo008001Qoo`03001o
ogoo05Qoo`002Woo00@007ooOol000]oo`04001oogoo000JOol00`00Oomoo`1GOol000Yoo`04001o
ogoo0007Ool40003Ool00`00Oomoo`0HOol00`00Oomoo`1GOol000Yoo`04001oogoo0007Ool00`00
Oomoo`04Ool2000JOol00`00Oomoo`1FOol000]oo`8000Qoo`D0009oo`03001oogoo01Uoo`03001o
ogoo05Ioo`0077oo00<007ooOol06Woo00<007ooOol0EGoo000LOol2000KOol00`00Oomoo`1EOol0
01aoo`03001oogoo01]oo`03001oogoo05Aoo`0077oo0P0077oo00<007ooOol0E7oo000LOol00`00
Oomoo`0LOol00`00Oomoo`1COol001aoo`03001oogoo01aoo`8005Aoo`0077oo0P007Woo00<007oo
Ool0DWoo000FOol30003Ool00`00Oomoo`0MOol00`00Oomoo`1BOol001Moo`03001oogoo009oo`03
001oogoo01ioo`03001oogoo055oo`005goo00<007ooOol00Woo0P007goo00<007ooOol0DGoo000G
Ool00`00Oomoo`02Ool00`00Oomoo`0OOol00`00Oomoo`1@Ool001Moo`03001oogoo009oo`03001o
ogoo021oo`03001oogoo04moo`005Woo0P0017oo0P008Goo00<007ooOol0Cgoo000GOol00`00Oomo
o`02Ool00`00Oomoo`0QOol00`00Oomoo`1>Ool001aoo`03001oogoo025oo`03001oogoo04ioo`00
77oo0P008goo00<007ooOol0CGoo000LOol00`00Oomoo`0ROol00`00Oomoo`1=Ool001aoo`8002=o
o`03001oogoo04eoo`0077oo00<007ooOol08goo00<007ooOol0C7oo000LOol00`00Oomoo`0TOol0
0`00Oomoo`1;Ool000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8002Eoo`03001oogoo04]oo`00
2goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo02Aoo`8004aoo`002goo00<007oo
Ool02goo00@007ooOol002Moo`8004]oo`002goo00<007ooOol02goo00<007ooOol00P00:7oo?`00
37oo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Ao
o`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(38911\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .34858 m
.008 .34198 L
.012 .33226 L
.016 .32286 L
.02 .31401 L
.024 .30725 L
.028 .30322 L
.032 .30149 L
.036 .30193 L
.04 .3031 L
.044 .30543 L
.048 .30843 L
.052 .31178 L
.056 .31433 L
.06 .31633 L
.064 .31911 L
.068 .32198 L
.072 .32336 L
.076 .32268 L
.08 .32154 L
.084 .32063 L
.088 .31934 L
.092 .31769 L
.096 .31698 L
.1 .31935 L
.104 .32596 L
.108 .33586 L
.112 .34659 L
.116 .35633 L
.12 .36427 L
.124 .36958 L
.128 .37171 L
.132 .37011 L
.136 .36473 L
.14 .35675 L
.144 .34892 L
.148 .34471 L
.152 .34658 L
.156 .35359 L
.16 .36132 L
.164 .36551 L
.168 .3648 L
.172 .3614 L
.176 .35874 L
.18 .358 L
.184 .35767 L
.188 .35622 L
.192 .35398 L
.196 .35307 L
.2 .35524 L
Mistroke
.204 .35992 L
.208 .36487 L
.212 .36825 L
.216 .37001 L
.22 .37118 L
.224 .37213 L
.228 .37173 L
.232 .36819 L
.236 .36101 L
.24 .35171 L
.244 .34275 L
.248 .33562 L
.252 .32962 L
.256 .32259 L
.26 .31287 L
.264 .30094 L
.268 .28931 L
.272 .28089 L
.276 .27702 L
.28 .27661 L
.284 .27697 L
.288 .27553 L
.292 .27146 L
.296 .26599 L
.3 .26137 L
.304 .25936 L
.308 .26009 L
.312 .26204 L
.316 .26301 L
.32 .26135 L
.324 .2569 L
.328 .25101 L
.332 .24573 L
.336 .24285 L
.34 .24302 L
.344 .24564 L
.348 .24925 L
.352 .25227 L
.356 .25357 L
.36 .25271 L
.364 .2498 L
.368 .24519 L
.372 .23929 L
.376 .23257 L
.38 .22579 L
.384 .2201 L
.388 .217 L
.392 .21781 L
.396 .22318 L
.4 .23259 L
Mistroke
.404 .24444 L
.408 .2565 L
.412 .26675 L
.416 .27414 L
.42 .27886 L
.424 .28208 L
.428 .28521 L
.432 .2891 L
.436 .2936 L
.44 .29776 L
.444 .3004 L
.448 .3009 L
.452 .29959 L
.456 .29764 L
.46 .2964 L
.464 .29669 L
.468 .29838 L
.472 .30047 L
.476 .30178 L
.48 .30161 L
.484 .30016 L
.488 .29835 L
.492 .29727 L
.496 .29751 L
.5 .29883 L
.504 .30036 L
.508 .30116 L
.512 .30077 L
.516 .29951 L
.52 .29818 L
.524 .29756 L
.528 .29796 L
.532 .29905 L
.536 .30014 L
.54 .30059 L
.544 .30022 L
.548 .29936 L
.552 .29858 L
.556 .29834 L
.56 .29871 L
.564 .29937 L
.568 .29984 L
.572 .29985 L
.576 .29943 L
.58 .29886 L
.584 .29852 L
.588 .2986 L
.592 .29904 L
.596 .29958 L
.6 .29991 L
Mistroke
.604 .29986 L
.608 .29947 L
.612 .29898 L
.616 .29865 L
.62 .29862 L
.624 .29887 L
.628 .29922 L
.632 .29948 L
.636 .29951 L
.64 .29932 L
.644 .29905 L
.648 .2989 L
.652 .299 L
.656 .29927 L
.66 .2995 L
.664 .29948 L
.668 .29918 L
.672 .29878 L
.676 .29856 L
.68 .29868 L
.684 .29908 L
.688 .2995 L
.692 .29967 L
.696 .29948 L
.7 .29908 L
.704 .29876 L
.708 .29874 L
.712 .299 L
.716 .2993 L
.72 .29934 L
.724 .29908 L
.728 .29872 L
.732 .2986 L
.736 .29888 L
.74 .29938 L
.744 .29971 L
.748 .29959 L
.752 .2991 L
.756 .29858 L
.76 .2984 L
.764 .29864 L
.768 .29908 L
.772 .29939 L
.776 .29937 L
.78 .29912 L
.784 .2989 L
.788 .29888 L
.792 .29902 L
.796 .29914 L
.8 .29908 L
Mistroke
.804 .29887 L
.808 .29871 L
.812 .29875 L
.816 .29901 L
.82 .29927 L
.824 .29928 L
.828 .29904 L
.832 .29873 L
.836 .29863 L
.84 .29885 L
.844 .29919 L
.848 .29931 L
.852 .2991 L
.856 .29868 L
.86 .29844 L
.864 .29863 L
.868 .29906 L
.872 .29938 L
.876 .29934 L
.88 .29896 L
.884 .29861 L
.888 .29857 L
.892 .29877 L
.896 .29899 L
.9 .29904 L
.904 .2989 L
.908 .2988 L
.912 .29888 L
.916 .299 L
.92 .29898 L
.924 .29885 L
.928 .29869 L
.932 .29868 L
.936 .29891 L
.94 .29904 L
.944 .29894 L
.948 .29876 L
.952 .29858 L
.956 .29866 L
.96 .29899 L
.964 .29914 L
.968 .299 L
.972 .29877 L
.976 .29854 L
.98 .29856 L
.984 .29882 L
.988 .29893 L
.992 .29884 L
.996 .29878 L
1 .29878 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .11811 m
.008 .114 L
.012 .11291 L
.016 .11502 L
.02 .11603 L
.024 .11617 L
.028 .11652 L
.032 .11708 L
.036 .11721 L
.04 .11702 L
.044 .11667 L
.048 .1162 L
.052 .11554 L
.056 .11482 L
.06 .11419 L
.064 .1137 L
.068 .11322 L
.072 .11282 L
.076 .11261 L
.08 .11266 L
.084 .11279 L
.088 .11294 L
.092 .11313 L
.096 .11352 L
.1 .11413 L
.104 .11486 L
.108 .11554 L
.112 .11624 L
.116 .11713 L
.12 .11836 L
.124 .11985 L
.128 .12149 L
.132 .12312 L
.136 .12479 L
.14 .12668 L
.144 .12891 L
.148 .13137 L
.152 .13378 L
.156 .13577 L
.16 .13731 L
.164 .13872 L
.168 .14039 L
.172 .1425 L
.176 .14483 L
.18 .14696 L
.184 .14866 L
.188 .15009 L
.192 .15164 L
.196 .15366 L
.2 .15625 L
Mistroke
.204 .15927 L
.208 .16248 L
.212 .16565 L
.216 .16855 L
.22 .17095 L
.224 .1727 L
.228 .17385 L
.232 .17471 L
.236 .17579 L
.24 .17751 L
.244 .18008 L
.248 .18343 L
.252 .18736 L
.256 .19175 L
.26 .19661 L
.264 .20204 L
.268 .20805 L
.272 .21449 L
.276 .22107 L
.28 .22749 L
.284 .23365 L
.288 .23964 L
.292 .24567 L
.296 .25191 L
.3 .25841 L
.304 .26499 L
.308 .27141 L
.312 .27748 L
.316 .28315 L
.32 .2886 L
.324 .29407 L
.328 .29982 L
.332 .30596 L
.336 .31243 L
.34 .31903 L
.344 .3255 L
.348 .33164 L
.352 .33735 L
.356 .3427 L
.36 .3479 L
.364 .35319 L
.368 .35882 L
.372 .36495 L
.376 .37163 L
.38 .37879 L
.384 .38625 L
.388 .39376 L
.392 .40107 L
.396 .40794 L
.4 .41418 L
Mistroke
.404 .41967 L
.408 .42436 L
.412 .42829 L
.416 .43151 L
.42 .43412 L
.424 .43622 L
.428 .4379 L
.432 .43923 L
.436 .4403 L
.44 .44114 L
.444 .44181 L
.448 .44235 L
.452 .44279 L
.456 .44316 L
.46 .44349 L
.464 .44378 L
.468 .44404 L
.472 .44427 L
.476 .44446 L
.48 .44462 L
.484 .44475 L
.488 .44487 L
.492 .44498 L
.496 .44508 L
.5 .44516 L
.504 .44524 L
.508 .44531 L
.512 .44537 L
.516 .44543 L
.52 .44548 L
.524 .44554 L
.528 .44559 L
.532 .44563 L
.536 .44567 L
.54 .4457 L
.544 .44573 L
.548 .44576 L
.552 .44579 L
.556 .44582 L
.56 .44585 L
.564 .44589 L
.568 .44592 L
.572 .44595 L
.576 .44598 L
.58 .44601 L
.584 .44604 L
.588 .44607 L
.592 .4461 L
.596 .44613 L
.6 .44615 L
Mistroke
.604 .44618 L
.608 .4462 L
.612 .44622 L
.616 .44625 L
.62 .44629 L
.624 .44632 L
.628 .44635 L
.632 .44638 L
.636 .44641 L
.64 .44644 L
.644 .44646 L
.648 .44649 L
.652 .44652 L
.656 .44654 L
.66 .44656 L
.664 .44658 L
.668 .44661 L
.672 .44665 L
.676 .44669 L
.68 .44672 L
.684 .44675 L
.688 .44678 L
.692 .4468 L
.696 .44682 L
.7 .44684 L
.704 .44686 L
.708 .44689 L
.712 .44693 L
.716 .44696 L
.72 .447 L
.724 .44703 L
.728 .44705 L
.732 .44708 L
.736 .4471 L
.74 .44712 L
.744 .44715 L
.748 .44718 L
.752 .44721 L
.756 .44724 L
.76 .44727 L
.764 .4473 L
.768 .44733 L
.772 .44735 L
.776 .44738 L
.78 .44741 L
.784 .44744 L
.788 .44746 L
.792 .44749 L
.796 .44751 L
.8 .44754 L
Mistroke
.804 .44757 L
.808 .4476 L
.812 .44763 L
.816 .44766 L
.82 .44769 L
.824 .44772 L
.828 .44774 L
.832 .44777 L
.836 .44779 L
.84 .44782 L
.844 .44785 L
.848 .44788 L
.852 .44791 L
.856 .44794 L
.86 .44797 L
.864 .448 L
.868 .44802 L
.872 .44805 L
.876 .44807 L
.88 .4481 L
.884 .44813 L
.888 .44816 L
.892 .44819 L
.896 .44822 L
.9 .44825 L
.904 .44828 L
.908 .4483 L
.912 .44833 L
.916 .44835 L
.92 .44839 L
.924 .44841 L
.928 .44844 L
.932 .44846 L
.936 .4485 L
.94 .44852 L
.944 .44856 L
.948 .44858 L
.952 .44861 L
.956 .44863 L
.96 .44867 L
.964 .44868 L
.968 .44872 L
.972 .44874 L
.976 .44878 L
.98 .44879 L
.984 .44884 L
.988 .44885 L
.992 .4489 L
.996 .44891 L
1 .44896 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15976 L
.012 .1625 L
.016 .16377 L
.02 .16361 L
.024 .1634 L
.028 .16356 L
.032 .16336 L
.036 .16285 L
.04 .16222 L
.044 .16163 L
.048 .16098 L
.052 .16027 L
.056 .15966 L
.06 .15923 L
.064 .15891 L
.068 .15865 L
.072 .1584 L
.076 .15831 L
.08 .15836 L
.084 .15849 L
.088 .15849 L
.092 .15846 L
.096 .15863 L
.1 .15913 L
.104 .1598 L
.108 .16056 L
.112 .16148 L
.116 .16278 L
.12 .16459 L
.124 .16683 L
.128 .16915 L
.132 .17137 L
.136 .17348 L
.14 .17568 L
.144 .17816 L
.148 .18088 L
.152 .18349 L
.156 .18571 L
.16 .18753 L
.164 .18932 L
.168 .19159 L
.172 .1945 L
.176 .19766 L
.18 .20052 L
.184 .20274 L
.188 .20447 L
.192 .20627 L
.196 .20861 L
.2 .21166 L
Mistroke
.204 .2153 L
.208 .21925 L
.212 .22321 L
.216 .22687 L
.22 .22991 L
.224 .23211 L
.228 .23352 L
.232 .23454 L
.236 .23579 L
.24 .23787 L
.244 .24102 L
.248 .24519 L
.252 .25011 L
.256 .25563 L
.26 .26173 L
.264 .26852 L
.268 .27601 L
.272 .28399 L
.276 .29211 L
.28 .30003 L
.284 .30762 L
.288 .315 L
.292 .32245 L
.296 .3302 L
.3 .33827 L
.304 .34645 L
.308 .35444 L
.312 .36197 L
.316 .36901 L
.32 .37576 L
.324 .38255 L
.328 .38968 L
.332 .39731 L
.336 .40535 L
.34 .41354 L
.344 .42154 L
.348 .42909 L
.352 .43608 L
.356 .44262 L
.36 .44899 L
.364 .45551 L
.368 .4625 L
.372 .47016 L
.376 .47853 L
.38 .48746 L
.384 .49672 L
.388 .506 L
.392 .51497 L
.396 .52337 L
.4 .531 L
Mistroke
.404 .53774 L
.408 .54354 L
.412 .54841 L
.416 .55242 L
.42 .55563 L
.424 .55818 L
.428 .56016 L
.432 .56171 L
.436 .56291 L
.44 .56387 L
.444 .56465 L
.448 .56528 L
.452 .56579 L
.456 .56621 L
.46 .56653 L
.464 .56679 L
.468 .567 L
.472 .56718 L
.476 .56733 L
.48 .56746 L
.484 .56757 L
.488 .56765 L
.492 .56772 L
.496 .56777 L
.5 .5678 L
.504 .56782 L
.508 .56783 L
.512 .56783 L
.516 .56783 L
.52 .56781 L
.524 .56778 L
.528 .56775 L
.532 .56772 L
.536 .56769 L
.54 .56766 L
.544 .56764 L
.548 .56762 L
.552 .56758 L
.556 .56754 L
.56 .56749 L
.564 .56745 L
.568 .5674 L
.572 .56736 L
.576 .56733 L
.58 .56729 L
.584 .56725 L
.588 .5672 L
.592 .56715 L
.596 .56711 L
.6 .56707 L
Mistroke
.604 .56703 L
.608 .567 L
.612 .56696 L
.616 .56691 L
.62 .56687 L
.624 .56682 L
.628 .56677 L
.632 .56672 L
.636 .56668 L
.64 .56664 L
.644 .56659 L
.648 .56655 L
.652 .56652 L
.656 .56648 L
.66 .56645 L
.664 .5664 L
.668 .56636 L
.672 .5663 L
.676 .56625 L
.68 .5662 L
.684 .56616 L
.688 .56612 L
.692 .56608 L
.696 .56605 L
.7 .56601 L
.704 .56597 L
.708 .56593 L
.712 .56588 L
.716 .56583 L
.72 .56578 L
.724 .56574 L
.728 .56569 L
.732 .56565 L
.736 .56561 L
.74 .56557 L
.744 .56553 L
.748 .56549 L
.752 .56545 L
.756 .5654 L
.76 .56536 L
.764 .56532 L
.768 .56527 L
.772 .56522 L
.776 .56518 L
.78 .56513 L
.784 .56509 L
.788 .56506 L
.792 .56502 L
.796 .56498 L
.8 .56493 L
Mistroke
.804 .56489 L
.808 .56484 L
.812 .56479 L
.816 .56475 L
.82 .5647 L
.824 .56466 L
.828 .56462 L
.832 .56459 L
.836 .56455 L
.84 .56451 L
.844 .56446 L
.848 .56441 L
.852 .56436 L
.856 .56431 L
.86 .56427 L
.864 .56423 L
.868 .56419 L
.872 .56416 L
.876 .56411 L
.88 .56407 L
.884 .56402 L
.888 .56398 L
.892 .56393 L
.896 .56389 L
.9 .56384 L
.904 .5638 L
.908 .56376 L
.912 .56372 L
.916 .56367 L
.92 .56364 L
.924 .56359 L
.928 .56355 L
.932 .5635 L
.936 .56346 L
.94 .56341 L
.944 .56337 L
.948 .56332 L
.952 .56329 L
.956 .56324 L
.96 .56321 L
.964 .56315 L
.968 .56312 L
.972 .56306 L
.976 .56303 L
.98 .56296 L
.984 .56294 L
.988 .56288 L
.992 .56287 L
.996 .5628 L
1 .56279 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo10000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomo
o`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo
00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Ool000000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`<00003Ool00000009oo`04001o
ogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo00D0
07ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`00
0Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo
00]oo`@000=oo`04001oogoo0007Ool00`00Ool000030002Ool01000Oomoo`000Woo00<007ooOol0
0goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`80
00Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0004Ool40004Ool01000Oomo
o`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo
0005Ool0029oo`8000aoo`D000=oo`8000=oo`<0009oo`03001oogoo00=oo`800004Ool007ooOol2
0006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P00
1Woo000ROol00`00Oomoo`0HOol00`00Oomoo`0;Ool20014Ool0029oo`8001Qoo`03001oogoo00eo
o`800005Ool00000Ool00002Ool200001Goo000007oo00000Woo0P0017oo00H007ooOol007oo0002
Ool20003Ool01`00Ool00000Ool007oo008000=oo`<00003Ool0000000ioo`008WooH`0037oo000R
Ool01000Ool007oo0`0000Ioo`00000007oo0003Ool01@00Oomoogoo00000goo0P0000=oo`00Ool0
0Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`00009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo000037oo000ROol30004Ool4000>Ool00`00Oomoo`1COol0029o
o`8000Uoo`03001oogoo00Yoo`8005Eoo`008Woo0P002Goo00<007ooOol00P0027oo00<007ooOol0
E7oo000ROol20009Ool00`00Oomoo`0200000goo000000020003Ool00`00Oomoo`1DOol000]oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo00Uoo`80009oo`80009oo`800003Ool0
07oo05Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000;Ool00`00
Oomoo`06Ool00`00Oomoo`1FOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomo
o`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qo
o`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo
0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001o
ogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000
Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@0
07ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo
0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007oo
Ool0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001o
ogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02
001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo
06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomo
o`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`/005ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`02
0006Ool3001KOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol02Woo
0`00FGoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool3001GOol002Qoo`03
001oogoo00ioo`<005Eoo`00:7oo00<007ooOol047oo0P00E7oo000;Ool20004Ool00`00Oomoo`03
Ool20004Ool20003Ool30003Ool00`00Oomoo`0BOol2001BOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`005Woo0P00D7oo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`005goo00<007ooOol0CWoo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool3
0004Ool20003Ool01000Oomoogoo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@00
0goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007oo
Oomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002
Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001o
ogoo0002Ool01@00Oomoogoo00000goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000
Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P00
17oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`04001oogooOol20002Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo
00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo
0004Ool200000goo001oo`03Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003
Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03
001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001o
ogoo0005Ool30004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06
001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo
00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P001Woo0`001Goo0P0017oo
0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`80
00Ioo`00:7oo00<007ooOol06Woo00<007ooOol0BGoo000XOol00`00Oomoo`0KOol00`00Oomoo`18
Ool002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol02Woo00<007ooOol00goo00<007oo
Ool03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`0MOol0
0`00Oomoo`16Ool002Qoo`03001oogoo01eoo`8004Moo`00:7oo00<007ooOol07Woo00<007ooOol0
AGoo000XOol00`00Oomoo`0OOol00`00Oomoo`14Ool002Qoo`03001oogoo01moo`8004Eoo`002goo
0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol087oo00<007ooOol0@goo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol002=o
o`03001oogoo049oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOol002=oo`03001oogoo049oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol00P008goo00<007ooOol0@Goo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`05001oogoo001oo`040003Ool00`00Oomoo`0ROol20012Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0TOol6000lOol000]oo`8000Yoo`80
00Aoo`80009oo`D0009oo`03001oogoo02Uooc4000aoo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo
0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo
00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomo
o`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@0
07ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80
07=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009
Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002
Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009o
o`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo
001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0
009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol0
47oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool0
1000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=o
o`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03
001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`80
00eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006
Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo
00<007ooOol0LWoo000LOomY000<Ool001aoo`03001oo`00008000=oo`03001oogoo009oo`80009o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomo
o`0:Ool001aoo`03001oogoo00]oo`<006Aoo`0077oo0P003Woo0`00HWoo000LOol00`00Oomoo`0?
Ool2001QOol001aoo`03001oogoo011oo`<005moo`0077oo0P004goo0P00GWoo000LOol00`00Oomo
o`0COol2001MOol001aoo`03001oogoo01Aoo`<005]oo`0077oo0P005goo0P00FWoo000LOol00`00
Oomoo`0HOol00`00Oomoo`1GOol001aoo`8001Uoo`8005Qoo`002goo0P0017oo00<007ooOol00Woo
0`000goo00<007ooOol06Goo00<007ooOol0EWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo01Uoo`03001oogoo05Ioo`002Woo00@007ooOol000]oo`03001oogoo008001]o
o`03001oogoo05Eoo`002Woo00@007ooOol000]oo`04001oogoo000LOol2001FOol000Yoo`04001o
ogoo0007Ool40003Ool00`00Oomoo`0KOol00`00Oomoo`1DOol000Yoo`04001oogoo0007Ool00`00
Oomoo`04Ool2000LOol00`00Oomoo`1DOol000]oo`8000Qoo`D0009oo`03001oogoo01aoo`03001o
ogoo05=oo`0077oo00<007ooOol077oo0P00E7oo000LOol2000NOol00`00Oomoo`1BOol001aoo`03
001oogoo01eoo`03001oogoo059oo`0077oo0P007goo00<007ooOol0DGoo000LOol00`00Oomoo`0O
Ool00`00Oomoo`1@Ool001aoo`03001oogoo01moo`03001oogoo051oo`0077oo0P008Goo00<007oo
Ool0Cgoo000FOol30003Ool00`00Oomoo`0POol00`00Oomoo`1?Ool001Moo`03001oogoo009oo`03
001oogoo025oo`03001oogoo04ioo`005goo00<007ooOol00Woo0P008Woo00<007ooOol0CWoo000G
Ool00`00Oomoo`02Ool00`00Oomoo`0ROol00`00Oomoo`1=Ool001Moo`03001oogoo009oo`03001o
ogoo029oo`03001oogoo04eoo`005Woo0P0017oo0P0097oo00<007ooOol0C7oo000GOol00`00Oomo
o`02Ool00`00Oomoo`0TOol00`00Oomoo`1;Ool001aoo`03001oogoo02Aoo`03001oogoo04]oo`00
77oo0P009Goo00<007ooOol0Bgoo000LOol00`00Oomoo`0UOol00`00Oomoo`1:Ool001aoo`8002Io
o`03001oogoo04Yoo`0077oo00<007ooOol09Woo00<007ooOol0BGoo000LOol00`00Oomoo`0VOol2
001:Ool000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8002Qoo`03001oogoo04Qoo`002goo00<0
07ooOol01goo00D007ooOomoo`00009oo`03001oogoo02Moo`8004Uoo`002goo00<007ooOol02goo
00@007ooOol002Yoo`8004Qoo`002goo00<007ooOol02goo00<007ooOol00P00:goo?00037oo000;
Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001o
ogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03
001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(39078\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .29269 m
.008 .29591 L
.012 .30159 L
.016 .30973 L
.02 .31961 L
.024 .32805 L
.028 .33412 L
.032 .33929 L
.036 .34236 L
.04 .34288 L
.044 .34035 L
.048 .33624 L
.052 .33046 L
.056 .32239 L
.06 .31332 L
.064 .30523 L
.068 .29979 L
.072 .29643 L
.076 .29589 L
.08 .29928 L
.084 .30655 L
.088 .31552 L
.092 .32322 L
.096 .32804 L
.1 .32963 L
.104 .32859 L
.108 .32492 L
.112 .31894 L
.116 .31291 L
.12 .31018 L
.124 .31293 L
.128 .32095 L
.132 .33223 L
.136 .34387 L
.14 .35355 L
.144 .36029 L
.148 .36396 L
.152 .365 L
.156 .36344 L
.16 .3592 L
.164 .35355 L
.168 .34957 L
.172 .35024 L
.176 .35589 L
.18 .36302 L
.184 .36632 L
.188 .36321 L
.192 .35577 L
.196 .34877 L
.2 .34606 L
Mistroke
.204 .34791 L
.208 .3518 L
.212 .3554 L
.216 .358 L
.22 .36003 L
.224 .36158 L
.228 .36198 L
.232 .36088 L
.236 .3594 L
.24 .35972 L
.244 .36311 L
.248 .36841 L
.252 .37242 L
.256 .37196 L
.26 .36618 L
.264 .357 L
.268 .34741 L
.272 .33925 L
.276 .33201 L
.28 .32369 L
.284 .31282 L
.288 .3 L
.292 .28779 L
.296 .27914 L
.3 .27541 L
.304 .27548 L
.308 .27645 L
.312 .27529 L
.316 .2706 L
.32 .26329 L
.324 .25585 L
.328 .25102 L
.332 .25023 L
.336 .25296 L
.34 .25706 L
.344 .25971 L
.348 .25884 L
.352 .25393 L
.356 .24631 L
.36 .23858 L
.364 .23353 L
.368 .23303 L
.372 .23721 L
.376 .24434 L
.38 .2514 L
.384 .25523 L
.388 .25376 L
.392 .24679 L
.396 .23605 L
.4 .22454 L
Mistroke
.404 .21535 L
.408 .21055 L
.412 .21059 L
.416 .21449 L
.42 .2206 L
.424 .2275 L
.428 .23461 L
.432 .24214 L
.436 .25061 L
.44 .26014 L
.444 .27007 L
.448 .27915 L
.452 .2861 L
.456 .29032 L
.46 .29219 L
.464 .29286 L
.468 .2936 L
.472 .29516 L
.476 .2974 L
.48 .29955 L
.484 .30073 L
.488 .30056 L
.492 .29937 L
.496 .29804 L
.5 .29742 L
.504 .29786 L
.508 .29905 L
.512 .30025 L
.516 .30077 L
.52 .3004 L
.524 .29944 L
.528 .29853 L
.532 .29819 L
.536 .29856 L
.54 .29932 L
.544 .29994 L
.548 .30003 L
.552 .29959 L
.556 .29895 L
.56 .29852 L
.564 .29857 L
.568 .29905 L
.572 .29966 L
.576 .30004 L
.58 .29999 L
.584 .29956 L
.588 .29901 L
.592 .29864 L
.596 .29862 L
.6 .29891 L
Mistroke
.604 .29931 L
.608 .29958 L
.612 .29961 L
.616 .29943 L
.62 .29919 L
.624 .29905 L
.628 .29909 L
.632 .29928 L
.636 .29944 L
.64 .29943 L
.644 .29921 L
.648 .29891 L
.652 .29875 L
.656 .29887 L
.66 .29921 L
.664 .29956 L
.668 .29967 L
.672 .29947 L
.676 .29912 L
.68 .29886 L
.684 .29886 L
.688 .2991 L
.692 .29936 L
.696 .2994 L
.7 .29916 L
.704 .29882 L
.708 .29869 L
.712 .29894 L
.716 .29943 L
.72 .29979 L
.724 .29973 L
.728 .29923 L
.732 .29864 L
.736 .29838 L
.74 .29859 L
.744 .2991 L
.748 .29952 L
.752 .29958 L
.756 .29932 L
.76 .29899 L
.764 .29887 L
.768 .29899 L
.772 .29916 L
.776 .29919 L
.78 .29902 L
.784 .29881 L
.788 .29877 L
.792 .29899 L
.796 .2993 L
.8 .29944 L
Mistroke
.804 .29929 L
.808 .29894 L
.812 .29868 L
.816 .29873 L
.82 .29902 L
.824 .29927 L
.828 .29927 L
.832 .29901 L
.836 .29874 L
.84 .29874 L
.844 .29898 L
.848 .29926 L
.852 .29931 L
.856 .29908 L
.86 .2988 L
.864 .29872 L
.868 .29885 L
.872 .29904 L
.876 .29908 L
.88 .29895 L
.884 .29885 L
.888 .29893 L
.892 .2991 L
.896 .29917 L
.9 .29904 L
.904 .29875 L
.908 .29858 L
.912 .29871 L
.916 .29899 L
.92 .2992 L
.924 .29922 L
.928 .29898 L
.932 .29876 L
.936 .29872 L
.94 .29874 L
.944 .29883 L
.948 .29894 L
.952 .29898 L
.956 .29904 L
.96 .29906 L
.964 .2989 L
.968 .29868 L
.972 .29859 L
.976 .29866 L
.98 .29891 L
.984 .29917 L
.988 .29914 L
.992 .29885 L
.996 .29866 L
1 .2986 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .11901 m
.008 .11565 L
.012 .11438 L
.016 .11528 L
.02 .11562 L
.024 .11531 L
.028 .11519 L
.032 .11548 L
.036 .11576 L
.04 .11609 L
.044 .11642 L
.048 .11684 L
.052 .11709 L
.056 .11724 L
.06 .11727 L
.064 .11723 L
.068 .11699 L
.072 .11657 L
.076 .11609 L
.08 .11564 L
.084 .11516 L
.088 .1146 L
.092 .11404 L
.096 .1136 L
.1 .11335 L
.104 .11325 L
.108 .11315 L
.112 .11312 L
.116 .11328 L
.12 .11371 L
.124 .11428 L
.128 .11487 L
.132 .11541 L
.136 .11601 L
.14 .11686 L
.144 .11805 L
.148 .11946 L
.152 .12094 L
.156 .12239 L
.16 .12393 L
.164 .12579 L
.168 .12805 L
.172 .13051 L
.176 .1328 L
.18 .13462 L
.184 .13606 L
.188 .13752 L
.192 .13936 L
.196 .14162 L
.2 .144 L
Mistroke
.204 .14613 L
.208 .14783 L
.212 .14928 L
.216 .15079 L
.22 .15264 L
.224 .15494 L
.228 .15768 L
.232 .16076 L
.236 .16401 L
.24 .16715 L
.244 .16982 L
.248 .17179 L
.252 .17307 L
.256 .17395 L
.26 .17494 L
.264 .17644 L
.268 .17865 L
.272 .18152 L
.276 .18495 L
.28 .18887 L
.284 .19336 L
.288 .19851 L
.292 .20432 L
.296 .21059 L
.3 .21702 L
.304 .22333 L
.308 .22942 L
.312 .23537 L
.316 .24139 L
.32 .24765 L
.324 .25419 L
.328 .26083 L
.332 .26734 L
.336 .2735 L
.34 .27924 L
.344 .2847 L
.348 .29012 L
.352 .29576 L
.356 .30179 L
.36 .30819 L
.364 .3148 L
.368 .32135 L
.372 .32762 L
.376 .33346 L
.38 .33889 L
.384 .34407 L
.388 .34923 L
.392 .35466 L
.396 .36055 L
.4 .367 L
Mistroke
.404 .37399 L
.408 .38135 L
.412 .38888 L
.416 .39631 L
.42 .40341 L
.424 .40999 L
.428 .41591 L
.432 .4211 L
.436 .42554 L
.44 .42927 L
.444 .43233 L
.448 .43481 L
.452 .43679 L
.456 .43836 L
.46 .4396 L
.464 .44059 L
.468 .44138 L
.472 .44203 L
.476 .44256 L
.48 .443 L
.484 .44338 L
.488 .44369 L
.492 .44397 L
.496 .44421 L
.5 .44442 L
.504 .4446 L
.508 .44477 L
.512 .4449 L
.516 .44502 L
.52 .44512 L
.524 .44521 L
.528 .44529 L
.532 .44537 L
.536 .44544 L
.54 .44551 L
.544 .44557 L
.548 .44562 L
.552 .44566 L
.556 .4457 L
.56 .44574 L
.564 .44578 L
.568 .44582 L
.572 .44586 L
.576 .44589 L
.58 .44592 L
.584 .44594 L
.588 .44597 L
.592 .446 L
.596 .44603 L
.6 .44607 L
Mistroke
.604 .4461 L
.608 .44613 L
.612 .44616 L
.616 .44619 L
.62 .44622 L
.624 .44624 L
.628 .44626 L
.632 .44629 L
.636 .44631 L
.64 .44634 L
.644 .44637 L
.648 .44641 L
.652 .44644 L
.656 .44647 L
.66 .4465 L
.664 .44653 L
.668 .44655 L
.672 .44657 L
.676 .44659 L
.68 .44662 L
.684 .44665 L
.688 .44668 L
.692 .44671 L
.696 .44675 L
.7 .44678 L
.704 .44681 L
.708 .44683 L
.712 .44686 L
.716 .44688 L
.72 .4469 L
.724 .44693 L
.728 .44696 L
.732 .44699 L
.736 .44702 L
.74 .44705 L
.744 .44708 L
.748 .44711 L
.752 .44714 L
.756 .44717 L
.76 .44719 L
.764 .44721 L
.768 .44724 L
.772 .44727 L
.776 .4473 L
.78 .44733 L
.784 .44736 L
.788 .44739 L
.792 .44742 L
.796 .44745 L
.8 .44747 L
Mistroke
.804 .4475 L
.808 .44752 L
.812 .44754 L
.816 .44757 L
.82 .4476 L
.824 .44764 L
.828 .44767 L
.832 .4477 L
.836 .44772 L
.84 .44775 L
.844 .44777 L
.848 .4478 L
.852 .44783 L
.856 .44786 L
.86 .44788 L
.864 .44792 L
.868 .44794 L
.872 .44797 L
.876 .448 L
.88 .44803 L
.884 .44805 L
.888 .44808 L
.892 .4481 L
.896 .44814 L
.9 .44816 L
.904 .44819 L
.908 .44822 L
.912 .44825 L
.916 .44827 L
.92 .44831 L
.924 .44833 L
.928 .44836 L
.932 .44838 L
.936 .44842 L
.94 .44844 L
.944 .44847 L
.948 .44849 L
.952 .44853 L
.956 .44855 L
.96 .44859 L
.964 .4486 L
.968 .44864 L
.972 .44866 L
.976 .4487 L
.98 .44871 L
.984 .44876 L
.988 .44877 L
.992 .44882 L
.996 .44882 L
1 .44887 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16339 L
.012 .15981 L
.016 .15847 L
.02 .15933 L
.024 .15963 L
.028 .15959 L
.032 .15998 L
.036 .16081 L
.04 .16155 L
.044 .16231 L
.048 .16291 L
.052 .16337 L
.056 .16351 L
.06 .16346 L
.064 .16313 L
.068 .16256 L
.072 .16176 L
.076 .16091 L
.08 .16017 L
.084 .15957 L
.088 .159 L
.092 .15852 L
.096 .15828 L
.1 .15833 L
.104 .15842 L
.108 .15843 L
.112 .15834 L
.116 .15833 L
.12 .15852 L
.124 .15889 L
.128 .15929 L
.132 .15975 L
.136 .16046 L
.14 .16164 L
.144 .16335 L
.148 .1654 L
.152 .16749 L
.156 .16947 L
.16 .17145 L
.164 .17368 L
.168 .17634 L
.172 .17923 L
.176 .18191 L
.18 .18408 L
.184 .18585 L
.188 .1877 L
.192 .19005 L
.196 .19293 L
.2 .19591 L
Mistroke
.204 .19853 L
.208 .2006 L
.212 .20233 L
.216 .20416 L
.22 .20643 L
.224 .20931 L
.228 .21276 L
.232 .21665 L
.236 .22075 L
.24 .22467 L
.244 .228 L
.248 .2304 L
.252 .23192 L
.256 .23294 L
.26 .23409 L
.264 .23591 L
.268 .23862 L
.272 .24219 L
.276 .24646 L
.28 .25135 L
.284 .25694 L
.288 .26335 L
.292 .27057 L
.296 .27837 L
.3 .28636 L
.304 .29422 L
.308 .30179 L
.312 .30919 L
.316 .31666 L
.32 .32441 L
.324 .33247 L
.328 .34064 L
.332 .34865 L
.336 .35624 L
.34 .36336 L
.344 .37017 L
.348 .37697 L
.352 .38405 L
.356 .39157 L
.36 .39952 L
.364 .40766 L
.368 .4157 L
.372 .42337 L
.376 .43054 L
.38 .43723 L
.384 .44365 L
.388 .45009 L
.392 .45686 L
.396 .46418 L
.4 .47216 L
Mistroke
.404 .48076 L
.408 .48983 L
.412 .49911 L
.416 .5083 L
.42 .5171 L
.424 .52526 L
.428 .5326 L
.432 .53902 L
.436 .54447 L
.44 .54901 L
.444 .55272 L
.448 .5557 L
.452 .55809 L
.456 .55997 L
.46 .56146 L
.464 .56264 L
.468 .56357 L
.472 .5643 L
.476 .56489 L
.48 .56536 L
.484 .56575 L
.488 .56606 L
.492 .56632 L
.496 .56654 L
.5 .56671 L
.504 .56685 L
.508 .56697 L
.512 .56706 L
.516 .56714 L
.52 .56721 L
.524 .56726 L
.528 .56729 L
.532 .5673 L
.536 .56731 L
.54 .5673 L
.544 .56729 L
.548 .56727 L
.552 .56725 L
.556 .56723 L
.56 .5672 L
.564 .56717 L
.568 .56714 L
.572 .5671 L
.576 .56707 L
.58 .56704 L
.584 .567 L
.588 .56697 L
.592 .56693 L
.596 .56688 L
.6 .56683 L
Mistroke
.604 .56679 L
.608 .56674 L
.612 .5667 L
.616 .56666 L
.62 .56662 L
.624 .56658 L
.628 .56654 L
.632 .5665 L
.636 .56647 L
.64 .56643 L
.644 .56638 L
.648 .56633 L
.652 .56627 L
.656 .56622 L
.66 .56618 L
.664 .56614 L
.668 .56611 L
.672 .56608 L
.676 .56604 L
.68 .566 L
.684 .56595 L
.688 .5659 L
.692 .56585 L
.696 .5658 L
.7 .56576 L
.704 .56572 L
.708 .56568 L
.712 .56564 L
.716 .5656 L
.72 .56556 L
.724 .56552 L
.728 .56547 L
.732 .56542 L
.736 .56538 L
.74 .56534 L
.744 .56529 L
.748 .56525 L
.752 .56521 L
.756 .56516 L
.76 .56512 L
.764 .56508 L
.768 .56504 L
.772 .565 L
.776 .56496 L
.78 .56491 L
.784 .56487 L
.788 .56482 L
.792 .56477 L
.796 .56473 L
.8 .56469 L
Mistroke
.804 .56465 L
.808 .56461 L
.812 .56457 L
.816 .56453 L
.82 .56448 L
.824 .56444 L
.828 .56438 L
.832 .56434 L
.836 .5643 L
.84 .56426 L
.844 .56422 L
.848 .56418 L
.852 .56414 L
.856 .5641 L
.86 .56405 L
.864 .56401 L
.868 .56396 L
.872 .56391 L
.876 .56387 L
.88 .56383 L
.884 .56378 L
.888 .56375 L
.892 .5637 L
.896 .56366 L
.9 .56362 L
.904 .56358 L
.908 .56352 L
.912 .56349 L
.916 .56344 L
.92 .5634 L
.924 .56335 L
.928 .56331 L
.932 .56326 L
.936 .56323 L
.94 .56318 L
.944 .56315 L
.948 .56309 L
.952 .56306 L
.956 .563 L
.96 .56297 L
.964 .56291 L
.968 .56289 L
.972 .56283 L
.976 .5628 L
.98 .56274 L
.984 .56272 L
.988 .56265 L
.992 .56263 L
.996 .56256 L
1 .56254 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo10000Woo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00<007oo00000P0000Eoo`00Oomoo`0000Eoo`05001oogooOol00003
Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<0
07ooOol00Woo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomo
o`05Ool01000Oomoogoo0P0000=oo`0000000`000Woo00<007ooOol00goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol0
100000=oo`00Ool00P000Woo00<007ooOol00goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00=oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol017oo
00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004
Ool00`00Oomoo`0;Ool40003Ool01000Oomoo`001goo0`000Woo0P0000Eoo`00Oomoo`00009oo`03
001oogoo00=oo`04001oogooOol40003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2
000:Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0000Eo
o`00Oomoo`00009oo`04001oogoo0002Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`04Ool01000
Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00L007ooOomo
o`00Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool50003Ool20005Ool40005Ool20003Ool3
0006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P00
1Woo000ROol00`00Oomoo`0JOol00`00Oomoo`0<Ool00`00Oomoo`10Ool0029oo`8000Eoo`8001Ao
o`03001oogoo00eoo`D0009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01000
Ool000001Woo0P0000Aoo`00Ool000=oo`800004Ool00000Ool200000goo0000000<Ool0029oof<0
00aoo`008Woo00P007oo001oo`00Ool007oo0P0000=oo`0000000goo00D007ooOomoo`0000=oo`03
001oogoo0080009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000aoo`008Woo0`000goo00<007ooOol00`00
00=oo`00Ool037oo00<007ooOol0DGoo000ROol01P00Oomoo`00Ool000Aoo`04001oogoo000=Ool0
0`00Oomoo`1AOol0029oo`80009oo`03001oogoo00Ioo`06001oogooOol007oo0P001Goo00<007oo
Ool0DWoo000ROol2000<Ool01@00Ool00000Ool01P0000=oo`00Ool0Dgoo000;Ool20004Ool00`00
Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0<Ool01000Oomoo`000goo1000EGoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8001Moo`03001oogoo05=oo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004
Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo
00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]
Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`00
0goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001o
ogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`00
2goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo
0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
2goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007oo
Oomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo
1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo1@000Woo1`00Fgoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`04001oogooOol30006Ool3001IOol0011oo`04001o
ogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol037oo0`00Egoo000AOol2000:Ool20004
Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool2001EOol002Qoo`03001oogoo015oo`8005=oo`00:7oo
00<007ooOol04Woo0P00DWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool0
0`00Oomoo`0DOol3001?Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0003Ool01000Oomoo`0067oo0P00CWoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0005Ool01000Oomoo`006Goo00<007ooOol0C7oo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20005Ool00`00Ool00002
0004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool3
0004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=o
o`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001Goo00<007oo000017oo00@007oo
Ool0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000
Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00=oo`<000Aoo`04001oogoo
0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00
Oomoo`04Ool20004Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03
001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04
001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol4
0003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=o
o`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04
001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Ao
o`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<0
07oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo0P0017oo0P00
17oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=o
o`8000Ioo`00:7oo00<007ooOol07Goo00<007ooOol0AWoo000XOol00`00Oomoo`0MOol20017Ool0
02Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol037oo0P000Woo00<007ooOol03goo00<0
07ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`0OOol00`00Oomoo`14
Ool002Qoo`03001oogoo021oo`03001oogoo04=oo`00:7oo00<007ooOol08Goo00<007ooOol0@Woo
000XOol00`00Oomoo`0QOol20013Ool002Qoo`03001oogoo029oo`03001oogoo045oo`002goo0P00
17oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol08Woo0P00@Woo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol002Eoo`03001oogoo
041oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol002Io
o`03001oogoo03moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol00P009Goo0P00@7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001o
o`040003Ool00`00Oomoo`0UOol2000oOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0006Ool00`00Oomoo`0VOol6000jOol000]oo`8000Yoo`8000Aoo`80009oo`D0009o
o`03001oogoo02aoobh000aoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0
IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogoo
Ool4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;
Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol0
0P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo
1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool2
0005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool0
01aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009o
o`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo1000
0goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Oomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001o
ogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03
001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yo
o`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool2
0006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000L
OomY000<Ool001aoo`09001oogooOol007oo001oo`0000Aoo`03001oogoo008000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<0
07ooOol03Woo0P00HWoo000LOol2000AOol2001POol001aoo`03001oogoo015oo`<005ioo`0077oo
00<007ooOol04goo0P00GGoo000LOol2000FOol2001KOol001aoo`03001oogoo01Ioo`8005Yoo`00
77oo00<007ooOol05goo0`00F7oo000LOol2000JOol2001GOol001aoo`03001oogoo01Yoo`8005Io
o`0077oo0P0077oo00<007ooOol0E7oo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomo
o`0KOol2001EOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol077oo00<0
07ooOol0Dgoo000:Ool01000Oomoo`002goo00<007ooOol00P007Woo00<007ooOol0DWoo000:Ool0
1000Oomoo`002goo00@007ooOol001moo`03001oogoo059oo`002Woo00@007ooOol000Moo`@000=o
o`03001oogoo01eoo`8005=oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8001moo`03001o
ogoo055oo`002goo0P0027oo1@000Woo00<007ooOol07goo00<007ooOol0D7oo000LOol00`00Oomo
o`0OOol00`00Oomoo`1@Ool001aoo`80025oo`03001oogoo04moo`0077oo00<007ooOol087oo00<0
07ooOol0Cgoo000LOol2000ROol00`00Oomoo`1>Ool001aoo`03001oogoo025oo`8004moo`0077oo
00<007ooOol08Woo00<007ooOol0CGoo000LOol2000SOol00`00Oomoo`1=Ool001Ioo`<000=oo`03
001oogoo02=oo`03001oogoo04aoo`005goo00<007ooOol00Woo00<007ooOol08goo0P00CGoo000G
Ool00`00Oomoo`02Ool2000UOol00`00Oomoo`1;Ool001Moo`03001oogoo009oo`03001oogoo02Ao
o`8004aoo`005goo00<007ooOol00Woo00<007ooOol09Goo00<007ooOol0BWoo000FOol20004Ool2
000WOol00`00Oomoo`19Ool001Moo`03001oogoo009oo`03001oogoo02Ioo`8004Yoo`0077oo00<0
07ooOol09goo00<007ooOol0B7oo000LOol2000XOol00`00Oomoo`18Ool001aoo`03001oogoo02Qo
o`03001oogoo04Moo`0077oo0P00:Goo00<007ooOol0Agoo000LOol00`00Oomoo`0YOol00`00Oomo
o`16Ool001aoo`03001oogoo02Uoo`03001oogoo04Ioo`002Woo0`0017oo00<007ooOol00Woo0`00
0goo0P00:Woo0P00Agoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0:Woo
0P00AWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00;Goo0P00AGoo000;Ool00`00Oomoo`0;Ool0
0`00Oomoo`02000^Ooli000<Ool000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo
0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(39245\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .33491 m
.008 .33319 L
.012 .33045 L
.016 .32706 L
.02 .32331 L
.024 .31861 L
.028 .31348 L
.032 .30886 L
.036 .30604 L
.04 .30446 L
.044 .30512 L
.048 .30903 L
.052 .316 L
.056 .3246 L
.06 .33298 L
.064 .34081 L
.068 .34604 L
.072 .3466 L
.076 .34135 L
.08 .33174 L
.084 .32025 L
.088 .30871 L
.092 .29906 L
.096 .29288 L
.1 .29228 L
.104 .29771 L
.108 .30698 L
.112 .31624 L
.116 .32289 L
.12 .3265 L
.124 .32702 L
.128 .32463 L
.132 .31997 L
.136 .31485 L
.14 .31182 L
.144 .31307 L
.148 .31895 L
.152 .32774 L
.156 .33662 L
.16 .34297 L
.164 .34604 L
.168 .34738 L
.172 .34906 L
.176 .35178 L
.18 .35429 L
.184 .35498 L
.188 .35428 L
.192 .35478 L
.196 .35832 L
.2 .36363 L
Mistroke
.204 .36682 L
.208 .3644 L
.212 .35677 L
.216 .34809 L
.22 .34293 L
.224 .3431 L
.228 .34702 L
.232 .35171 L
.236 .35531 L
.24 .35764 L
.244 .35896 L
.248 .35903 L
.252 .35739 L
.256 .35461 L
.26 .35272 L
.264 .35412 L
.268 .35948 L
.272 .36685 L
.276 .37263 L
.28 .37381 L
.284 .36975 L
.288 .36217 L
.292 .35336 L
.296 .34446 L
.3 .33494 L
.304 .32369 L
.308 .31061 L
.312 .29742 L
.316 .28681 L
.32 .28073 L
.324 .27893 L
.328 .2789 L
.332 .27728 L
.336 .27193 L
.34 .26319 L
.344 .25377 L
.348 .24712 L
.352 .24554 L
.356 .24882 L
.36 .25432 L
.364 .2584 L
.368 .25822 L
.372 .2531 L
.376 .24474 L
.38 .23626 L
.384 .23066 L
.388 .2295 L
.392 .23244 L
.396 .23763 L
.4 .24276 L
Mistroke
.404 .24598 L
.408 .24646 L
.412 .24427 L
.416 .23991 L
.42 .23391 L
.424 .22674 L
.428 .21897 L
.432 .21157 L
.436 .20599 L
.44 .20374 L
.444 .20587 L
.448 .21245 L
.452 .22239 L
.456 .23388 L
.46 .24507 L
.464 .25479 L
.468 .26279 L
.472 .26957 L
.476 .27582 L
.48 .28189 L
.484 .28753 L
.488 .29214 L
.492 .29517 L
.496 .29656 L
.5 .29682 L
.504 .29674 L
.508 .297 L
.512 .2978 L
.516 .29885 L
.52 .29964 L
.524 .29983 L
.528 .29942 L
.532 .2988 L
.536 .29842 L
.54 .29856 L
.544 .2991 L
.548 .29972 L
.552 .30003 L
.556 .29989 L
.56 .29941 L
.564 .2989 L
.568 .29862 L
.572 .29869 L
.576 .29903 L
.58 .29942 L
.584 .29965 L
.588 .29963 L
.592 .29943 L
.596 .29922 L
.6 .29912 L
Mistroke
.604 .29918 L
.608 .29934 L
.612 .29947 L
.616 .29945 L
.62 .29926 L
.624 .29899 L
.628 .29884 L
.632 .29894 L
.636 .29926 L
.64 .29963 L
.644 .29979 L
.648 .29964 L
.652 .29926 L
.656 .29891 L
.66 .29881 L
.664 .299 L
.668 .2993 L
.672 .29947 L
.676 .29939 L
.68 .29913 L
.684 .29893 L
.688 .299 L
.692 .29932 L
.696 .29965 L
.7 .29969 L
.704 .29936 L
.708 .29887 L
.712 .29857 L
.716 .29868 L
.72 .29911 L
.724 .29954 L
.728 .29965 L
.732 .29943 L
.736 .2991 L
.74 .29893 L
.744 .29901 L
.748 .2992 L
.752 .29928 L
.756 .29915 L
.76 .29893 L
.764 .29885 L
.768 .29901 L
.772 .29931 L
.776 .2995 L
.78 .29942 L
.784 .2991 L
.788 .29881 L
.792 .29878 L
.796 .29901 L
.8 .29929 L
Mistroke
.804 .29936 L
.808 .29914 L
.812 .29884 L
.816 .29877 L
.82 .29899 L
.824 .29934 L
.828 .29949 L
.832 .29929 L
.836 .29891 L
.84 .29865 L
.844 .29869 L
.848 .29897 L
.852 .29923 L
.856 .29928 L
.86 .29917 L
.864 .29905 L
.868 .29901 L
.872 .29902 L
.876 .29898 L
.88 .29886 L
.884 .29881 L
.888 .29892 L
.892 .2991 L
.896 .29925 L
.9 .29921 L
.904 .29898 L
.908 .29879 L
.912 .29878 L
.916 .2989 L
.92 .29906 L
.924 .29912 L
.928 .29901 L
.932 .2989 L
.936 .29886 L
.94 .29887 L
.944 .29896 L
.948 .29904 L
.952 .29903 L
.956 .299 L
.96 .29892 L
.964 .29878 L
.968 .29871 L
.972 .29881 L
.976 .29898 L
.98 .29914 L
.984 .2992 L
.988 .29897 L
.992 .29868 L
.996 .29862 L
1 .29868 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .11331 m
.008 .11699 L
.012 .11804 L
.016 .11663 L
.02 .11607 L
.024 .11636 L
.028 .11621 L
.032 .11581 L
.036 .11554 L
.04 .11542 L
.044 .11536 L
.048 .1154 L
.052 .11552 L
.056 .11576 L
.06 .11607 L
.064 .1165 L
.068 .11687 L
.072 .11719 L
.076 .11742 L
.08 .11765 L
.084 .11776 L
.088 .11772 L
.092 .1175 L
.096 .1172 L
.1 .11689 L
.104 .11652 L
.108 .11599 L
.112 .11537 L
.116 .11482 L
.12 .11444 L
.124 .11417 L
.128 .11392 L
.132 .1137 L
.136 .1136 L
.14 .11374 L
.144 .11408 L
.148 .11448 L
.152 .11483 L
.156 .11516 L
.16 .11564 L
.164 .11646 L
.168 .11764 L
.172 .11902 L
.176 .12038 L
.18 .12171 L
.184 .12319 L
.188 .12507 L
.192 .12736 L
.196 .12976 L
.2 .13188 L
Mistroke
.204 .13354 L
.208 .13494 L
.212 .13648 L
.216 .13843 L
.22 .14073 L
.224 .14308 L
.228 .14516 L
.232 .14688 L
.236 .14838 L
.24 .14987 L
.244 .15156 L
.248 .15363 L
.252 .15616 L
.256 .15917 L
.26 .16249 L
.264 .16581 L
.268 .16869 L
.272 .17084 L
.276 .17225 L
.28 .1732 L
.284 .17416 L
.288 .17549 L
.292 .17739 L
.296 .17984 L
.3 .1828 L
.304 .18628 L
.308 .19039 L
.312 .19522 L
.316 .20075 L
.32 .20679 L
.324 .21303 L
.328 .21921 L
.332 .22523 L
.336 .23116 L
.34 .23719 L
.344 .24347 L
.348 .25001 L
.352 .25667 L
.356 .26321 L
.36 .26941 L
.364 .27521 L
.368 .28072 L
.372 .28615 L
.376 .29176 L
.38 .29773 L
.384 .30407 L
.388 .31064 L
.392 .3172 L
.396 .32353 L
.4 .32947 L
Mistroke
.404 .335 L
.408 .34023 L
.412 .34538 L
.416 .35069 L
.42 .35637 L
.424 .36256 L
.428 .36928 L
.432 .37644 L
.436 .38388 L
.44 .39137 L
.444 .39868 L
.448 .40559 L
.452 .41193 L
.456 .4176 L
.46 .42253 L
.464 .42672 L
.468 .43022 L
.472 .43308 L
.476 .43541 L
.48 .43728 L
.484 .43876 L
.488 .43995 L
.492 .44089 L
.496 .44165 L
.5 .44227 L
.504 .44278 L
.508 .44321 L
.512 .44357 L
.516 .44388 L
.52 .44415 L
.524 .44438 L
.528 .44458 L
.532 .44475 L
.536 .4449 L
.54 .44504 L
.544 .44516 L
.548 .44526 L
.552 .44535 L
.556 .44543 L
.56 .4455 L
.564 .44556 L
.568 .44563 L
.572 .44568 L
.576 .44574 L
.58 .44579 L
.584 .44583 L
.588 .44587 L
.592 .44591 L
.596 .44594 L
.6 .44597 L
Mistroke
.604 .446 L
.608 .44603 L
.612 .44605 L
.616 .44609 L
.62 .44612 L
.624 .44616 L
.628 .4462 L
.632 .44623 L
.636 .44626 L
.64 .44628 L
.644 .4463 L
.648 .44632 L
.652 .44634 L
.656 .44637 L
.66 .44641 L
.664 .44644 L
.668 .44647 L
.672 .44651 L
.676 .44653 L
.68 .44656 L
.684 .44658 L
.688 .44661 L
.692 .44663 L
.696 .44666 L
.7 .44669 L
.704 .44672 L
.708 .44675 L
.712 .44678 L
.716 .4468 L
.72 .44683 L
.724 .44686 L
.728 .44689 L
.732 .44692 L
.736 .44695 L
.74 .44697 L
.744 .44699 L
.748 .44702 L
.752 .44705 L
.756 .44708 L
.76 .44711 L
.764 .44714 L
.768 .44717 L
.772 .4472 L
.776 .44723 L
.78 .44725 L
.784 .44727 L
.788 .4473 L
.792 .44732 L
.796 .44735 L
.8 .44739 L
Mistroke
.804 .44742 L
.808 .44745 L
.812 .44748 L
.816 .4475 L
.82 .44752 L
.824 .44755 L
.828 .44758 L
.832 .44761 L
.836 .44764 L
.84 .44767 L
.844 .4477 L
.848 .44773 L
.852 .44775 L
.856 .44778 L
.86 .4478 L
.864 .44783 L
.868 .44786 L
.872 .44789 L
.876 .44791 L
.88 .44795 L
.884 .44797 L
.888 .448 L
.892 .44803 L
.896 .44806 L
.9 .44808 L
.904 .44811 L
.908 .44814 L
.912 .44817 L
.916 .44819 L
.92 .44822 L
.924 .44825 L
.928 .44828 L
.932 .44831 L
.936 .44834 L
.94 .44836 L
.944 .44839 L
.948 .44841 L
.952 .44845 L
.956 .44847 L
.96 .44851 L
.964 .44852 L
.968 .44857 L
.972 .44858 L
.976 .44862 L
.98 .44863 L
.984 .44867 L
.988 .44868 L
.992 .44873 L
.996 .44874 L
1 .44879 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16416 L
.012 .16193 L
.016 .16107 L
.02 .16189 L
.024 .16208 L
.028 .1616 L
.032 .16106 L
.036 .16065 L
.04 .16022 L
.044 .15984 L
.048 .15959 L
.052 .15959 L
.056 .15977 L
.06 .16025 L
.064 .1609 L
.068 .16169 L
.072 .16237 L
.076 .16297 L
.08 .1634 L
.084 .16362 L
.088 .16343 L
.092 .16288 L
.096 .16217 L
.1 .16144 L
.104 .16069 L
.108 .15989 L
.112 .15916 L
.116 .15865 L
.12 .15842 L
.124 .15838 L
.128 .1583 L
.132 .15814 L
.136 .15802 L
.14 .15809 L
.144 .15833 L
.148 .15865 L
.152 .15894 L
.156 .15927 L
.16 .15988 L
.164 .16095 L
.168 .16249 L
.172 .16426 L
.176 .16597 L
.18 .16759 L
.184 .16938 L
.188 .17166 L
.192 .17446 L
.196 .17745 L
.2 .18012 L
Mistroke
.204 .18223 L
.208 .18404 L
.212 .186 L
.216 .18844 L
.22 .19129 L
.224 .19416 L
.228 .19669 L
.232 .19876 L
.236 .20055 L
.24 .20236 L
.244 .20446 L
.248 .20703 L
.252 .21019 L
.256 .21395 L
.26 .2181 L
.264 .22223 L
.268 .22581 L
.272 .22848 L
.276 .23022 L
.28 .23141 L
.284 .2326 L
.288 .23425 L
.292 .23658 L
.296 .23958 L
.3 .24319 L
.304 .24745 L
.308 .25249 L
.312 .25846 L
.316 .26536 L
.32 .27292 L
.324 .28075 L
.328 .28851 L
.332 .29602 L
.336 .30338 L
.34 .3108 L
.344 .31851 L
.348 .32655 L
.352 .33477 L
.356 .34287 L
.36 .3506 L
.364 .35785 L
.368 .36472 L
.372 .37147 L
.376 .37842 L
.38 .38577 L
.384 .39358 L
.388 .40168 L
.392 .40981 L
.396 .41766 L
.4 .42505 L
Mistroke
.404 .43192 L
.408 .4384 L
.412 .44474 L
.416 .45127 L
.42 .45826 L
.424 .46589 L
.428 .4742 L
.432 .48307 L
.436 .4923 L
.44 .50159 L
.444 .51064 L
.448 .51919 L
.452 .52702 L
.456 .534 L
.46 .54007 L
.464 .54522 L
.468 .54949 L
.472 .55299 L
.476 .5558 L
.48 .55804 L
.484 .55981 L
.488 .56122 L
.492 .56233 L
.496 .56322 L
.5 .56392 L
.504 .56449 L
.508 .56494 L
.512 .5653 L
.516 .5656 L
.52 .56585 L
.524 .56606 L
.528 .56623 L
.532 .56637 L
.536 .56649 L
.54 .56657 L
.544 .56664 L
.548 .56669 L
.552 .56673 L
.556 .56676 L
.56 .56678 L
.564 .56679 L
.568 .56679 L
.572 .56677 L
.576 .56675 L
.58 .56672 L
.584 .56669 L
.588 .56666 L
.592 .56664 L
.596 .56661 L
.6 .56658 L
Mistroke
.604 .56654 L
.608 .56651 L
.612 .56647 L
.616 .56643 L
.62 .56639 L
.624 .56634 L
.628 .56629 L
.632 .56624 L
.636 .5662 L
.64 .56617 L
.644 .56613 L
.648 .5661 L
.652 .56606 L
.656 .56602 L
.66 .56597 L
.664 .56592 L
.668 .56587 L
.672 .56583 L
.676 .56578 L
.68 .56574 L
.684 .5657 L
.688 .56566 L
.692 .56563 L
.696 .56559 L
.7 .56554 L
.704 .5655 L
.708 .56545 L
.712 .5654 L
.716 .56536 L
.72 .56531 L
.724 .56527 L
.728 .56523 L
.732 .56519 L
.736 .56515 L
.74 .56511 L
.744 .56507 L
.748 .56503 L
.752 .56498 L
.756 .56493 L
.76 .56489 L
.764 .56484 L
.768 .5648 L
.772 .56476 L
.776 .56471 L
.78 .56467 L
.784 .56464 L
.788 .56459 L
.792 .56455 L
.796 .56451 L
.8 .56446 L
Mistroke
.804 .56441 L
.808 .56437 L
.812 .56432 L
.816 .56429 L
.82 .56425 L
.824 .56421 L
.828 .56416 L
.832 .56412 L
.836 .56407 L
.84 .56403 L
.844 .56398 L
.848 .56394 L
.852 .5639 L
.856 .56385 L
.86 .56381 L
.864 .56377 L
.868 .56373 L
.872 .56369 L
.876 .56364 L
.88 .5636 L
.884 .56355 L
.888 .56351 L
.892 .56347 L
.896 .56342 L
.9 .56338 L
.904 .56334 L
.908 .56329 L
.912 .56326 L
.916 .56321 L
.92 .56317 L
.924 .56312 L
.928 .56308 L
.932 .56303 L
.936 .56299 L
.94 .56294 L
.944 .56291 L
.948 .56286 L
.952 .56283 L
.956 .56277 L
.96 .56274 L
.964 .56268 L
.968 .56266 L
.972 .56259 L
.976 .56257 L
.98 .5625 L
.984 .56248 L
.988 .56242 L
.992 .5624 L
.996 .56233 L
1 .56231 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2000YOol00`00Oomoo`11Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P000Woo00@007oo000000Eo
o`<000=oo`<000Aoo`8000=oo`D000=oo`8000Aoo`8000Aoo`D0009oo`<000Aoo`8000Ioo`000goo
1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00
Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`03001oogoo00D00003Ool007oo00Ao
o`05001oogooOol00003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool0
1000Oomoo`000Woo00<007ooOol00Woo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007oo
Ool00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001o
ogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool200001Woo000007oo001oo`8000Eoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eo
o`03001oo`00009oo`03001oo`0000800003Ool007oo008000Eoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03
001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo0P0017oo00<007ooOol02goo10000goo00@007ooOol000Moo`03001oo`0000<0009oo`05
001oogoo001oo`020005Ool01000Oomoogoo10000goo00@007ooOol0009oo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogooOol007oo10000goo00@007ooOol000Eo
o`002goo0P002Woo0P0017oo00<007ooOol00Woo0P0037oo00<007ooOol017oo00@007ooOol000Io
o`<0009oo`80009oo`04001oogoo0002Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`04Ool01000
Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00L007ooOomo
o`00Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool50003Ool20008Ool20004Ool20004Ool4
0004Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P00
1Woo000ROol00`00Oomoo`0LOol2000>Ool00`00Oomoo`0mOol0029oo`8000Qoo`03001oogoo019o
o`03001oogoo00ioo`<00004Ool00000Ool2000=Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`02000<Ool0029oof<000aoo`008Woo00<007oo00000`000Woo0P0000=oo`00000010000goo
00D007ooOomoo`00009oo`03001oogoo008000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`04001oogoo0003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol02Woo000ROol30003Ool0
0`00Ool00002Ool300000goo001oo`0=Ool00`00Oomoo`1>Ool0029oo`8000Aoo`03001oo`0000Io
o`03001oogoo00]oo`03001oogoo04moo`008Woo0P0017oo0`001goo0P000goo0P001Woo00<007oo
Ool0Cgoo000ROol2000?Ool300000goo001oo`040002Ool00`00Oomoo`1?Ool000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`03001oogoo015oo`03001oogoo00Aoo`80059oo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000IOol00`00Oomoo`1AOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P00
17oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Ao
o`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<0
00=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003
Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00
Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool0
00]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029o
o`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001o
ogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Io
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uo
o`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oo`0000@000=oo`H005Uoo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20004Ool40005Ool4001FOol0011o
o`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol03goo0`00E7oo000AOol2000:
Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0AOol3001BOol002Qoo`03001oogoo01=oo`<0051o
o`00:7oo00<007ooOol05Goo0P00Cgoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool3
0003Ool00`00Oomoo`0FOol3001=Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007oo
Ool007oo0003Ool01000Oomoo`006goo00<007ooOol0BWoo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`0077oo00<007ooOol0BGoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007
Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002
Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@0
00=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001o
ogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`8000=oo`04001o
ogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004
Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool0
0`00Oomoo`05Ool30002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=o
o`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=o
o`04001oogoo0007Ool00`00Ool00002Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogoo
Ool40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
00=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Ao
o`04001oogoo0006Ool20002Ool00`00Ool00002Ool01000Oomoo`000Woo00<007ooOol00P000goo
00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008
Ool01000Oomoo`000Woo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Ao
o`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol07goo00<007ooOol0A7oo000XOol0
0`00Oomoo`0OOol20015Ool002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol03goo0P00
4Goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`0ROol00`00
Oomoo`11Ool002Qoo`03001oogoo029oo`80049oo`00:7oo00<007ooOol08goo0P00@Goo000XOol0
0`00Oomoo`0TOol00`00Oomoo`0oOol002Qoo`03001oogoo02Aoo`80041oo`002goo0P0017oo00<0
07ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol09Goo00<007ooOol0?Woo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol002Moo`8003moo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol002Qoo`03001o
ogoo03eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
0P009goo0P00?Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003
Ool00`00Oomoo`0XOol00`00Oomoo`0kOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0006Ool00`00Oomoo`0YOol5000hOol000]oo`8000Yoo`8000Aoo`80009oo`D0009o
o`03001oogoo02ioob`000aoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0
IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogoo
Ool4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;
Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol0
0P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo
1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool2
0005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool0
01aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009o
o`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo1000
0goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Oomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001o
ogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03
001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yo
o`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool2
0006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000L
OomY000<Ool001aoo`80009oo`04001oogooOol20003Ool01000Oomoogoo1@000goo00D007ooOomo
o`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`0AOol2001O
Ool001aoo`8001Aoo`8005eoo`0077oo00<007ooOol057oo0`00Fgoo000LOol00`00Oomoo`0FOol2
001JOol001aoo`8001Uoo`03001oogoo05Moo`0077oo00<007ooOol06Goo0P00Egoo000LOol00`00
Oomoo`0JOol3001EOol001aoo`8001eoo`8005Aoo`0077oo00<007ooOol07Goo00<007ooOol0DWoo
000LOol2000OOol00`00Oomoo`1AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo
01ioo`03001oogoo055oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0O
Ool00`00Oomoo`1@Ool000Yoo`04001oogoo000;Ool00`00Oomoo`02000QOol00`00Oomoo`1?Ool0
00Yoo`04001oogoo000;Ool01000Oomoo`008Woo00<007ooOol0Cgoo000:Ool01000Oomoo`001goo
10000goo00<007ooOol087oo00<007ooOol0Cgoo000:Ool01000Oomoo`001goo00<007ooOol017oo
0P008Woo00<007ooOol0CWoo000;Ool20008Ool50002Ool00`00Oomoo`0ROol00`00Oomoo`1=Ool0
01aoo`03001oogoo029oo`03001oogoo04eoo`0077oo0P008goo00<007ooOol0CGoo000LOol00`00
Oomoo`0SOol00`00Oomoo`1<Ool001aoo`8002Eoo`03001oogoo04]oo`0077oo00<007ooOol097oo
00<007ooOol0Bgoo000LOol00`00Oomoo`0UOol00`00Oomoo`1:Ool001aoo`8002Ioo`03001oogoo
04Yoo`005Woo0`000goo00<007ooOol09Woo00<007ooOol0BGoo000GOol00`00Oomoo`02Ool00`00
Oomoo`0VOol00`00Oomoo`19Ool001Moo`03001oogoo009oo`8002Qoo`03001oogoo04Qoo`005goo
00<007ooOol00Woo00<007ooOol09goo00<007ooOol0B7oo000GOol00`00Oomoo`02Ool00`00Oomo
o`0XOol00`00Oomoo`17Ool001Ioo`8000Aoo`8002Yoo`03001oogoo04Ioo`005goo00<007ooOol0
0Woo00<007ooOol0:Goo00<007ooOol0AWoo000LOol00`00Oomoo`0YOol00`00Oomoo`16Ool001ao
o`8002]oo`03001oogoo04Eoo`0077oo00<007ooOol0:goo00<007ooOol0A7oo000LOol2000/Ool0
0`00Oomoo`14Ool001aoo`03001oogoo02aoo`03001oogoo04=oo`0077oo00<007ooOol0;7oo00<0
07ooOol0@goo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2000]Ool20014Ool000]oo`03001o
ogoo00Moo`05001oogooOol00002Ool00`00Oomoo`0]Ool20013Ool000]oo`03001oogoo00]oo`04
001oogoo000`Ool20012Ool000]oo`03001oogoo00]oo`03001oogoo0080035oocH000aoo`002goo
00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomo
o`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(39412\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31695 m
.008 .31574 L
.012 .31519 L
.016 .31422 L
.02 .31351 L
.024 .31494 L
.028 .31842 L
.032 .32301 L
.036 .32757 L
.04 .33095 L
.044 .33164 L
.048 .32931 L
.052 .32421 L
.056 .31646 L
.06 .30806 L
.064 .30154 L
.068 .29946 L
.072 .3022 L
.076 .30918 L
.08 .3195 L
.084 .33117 L
.088 .34165 L
.092 .34739 L
.096 .34676 L
.1 .34042 L
.104 .33102 L
.108 .32069 L
.112 .31067 L
.116 .30313 L
.12 .30019 L
.124 .30238 L
.128 .30756 L
.132 .31276 L
.136 .31586 L
.14 .31663 L
.144 .31614 L
.148 .31518 L
.152 .31422 L
.156 .31365 L
.16 .31409 L
.164 .3163 L
.168 .32078 L
.172 .32689 L
.176 .33267 L
.18 .33604 L
.184 .33635 L
.188 .33553 L
.192 .33685 L
.196 .34179 L
.2 .3485 L
Mistroke
.204 .35341 L
.208 .35455 L
.212 .35345 L
.216 .35376 L
.22 .35724 L
.224 .36199 L
.228 .36408 L
.232 .36103 L
.236 .35405 L
.24 .34695 L
.244 .34305 L
.248 .34319 L
.252 .3461 L
.256 .35009 L
.26 .35414 L
.264 .35755 L
.268 .35915 L
.272 .35759 L
.276 .35273 L
.28 .34676 L
.284 .34357 L
.288 .34639 L
.292 .35535 L
.296 .36688 L
.3 .37572 L
.304 .37789 L
.308 .37285 L
.312 .36325 L
.316 .35278 L
.32 .34378 L
.324 .33615 L
.328 .32809 L
.332 .31797 L
.336 .3057 L
.34 .29294 L
.344 .28207 L
.348 .27467 L
.352 .27071 L
.356 .26861 L
.36 .26629 L
.364 .26234 L
.368 .25669 L
.372 .25057 L
.376 .24576 L
.38 .24361 L
.384 .24435 L
.388 .24686 L
.392 .24914 L
.396 .24918 L
.4 .24586 L
Mistroke
.404 .23952 L
.408 .23195 L
.412 .22573 L
.416 .22317 L
.42 .22529 L
.424 .23126 L
.428 .23868 L
.432 .24444 L
.436 .24597 L
.44 .24223 L
.444 .23397 L
.448 .22337 L
.452 .21301 L
.456 .205 L
.46 .20039 L
.464 .19925 L
.468 .20109 L
.472 .20539 L
.476 .21187 L
.48 .22039 L
.484 .23065 L
.488 .24192 L
.492 .25314 L
.496 .26325 L
.5 .27155 L
.504 .27791 L
.508 .28276 L
.512 .28667 L
.516 .29009 L
.52 .29312 L
.524 .29557 L
.528 .2972 L
.532 .29796 L
.536 .29808 L
.54 .29793 L
.544 .29789 L
.548 .29813 L
.552 .29861 L
.556 .29914 L
.56 .2995 L
.564 .29958 L
.568 .29941 L
.572 .29915 L
.576 .29898 L
.58 .29899 L
.584 .29916 L
.588 .29935 L
.592 .29942 L
.596 .29932 L
.6 .29911 L
Mistroke
.604 .29894 L
.608 .29897 L
.612 .29923 L
.616 .29958 L
.62 .29979 L
.624 .29971 L
.628 .29938 L
.632 .29901 L
.636 .29886 L
.64 .299 L
.644 .2993 L
.648 .29951 L
.652 .29948 L
.656 .29926 L
.66 .29906 L
.664 .2991 L
.668 .29938 L
.672 .29969 L
.676 .29975 L
.68 .29944 L
.684 .29893 L
.688 .29858 L
.692 .29866 L
.696 .29914 L
.7 .29968 L
.704 .29991 L
.708 .29968 L
.712 .29922 L
.716 .29886 L
.72 .29884 L
.724 .29909 L
.728 .29935 L
.732 .29939 L
.736 .29923 L
.74 .29905 L
.744 .29905 L
.748 .29924 L
.752 .29943 L
.756 .29944 L
.76 .29924 L
.764 .29898 L
.768 .2989 L
.772 .29905 L
.776 .2993 L
.78 .29941 L
.784 .29927 L
.788 .299 L
.792 .29887 L
.796 .299 L
.8 .29932 L
Mistroke
.804 .29952 L
.808 .29942 L
.812 .29908 L
.816 .29878 L
.82 .29874 L
.824 .29899 L
.828 .29928 L
.832 .29938 L
.836 .29927 L
.84 .2991 L
.844 .29902 L
.848 .29908 L
.852 .29914 L
.856 .29907 L
.86 .29895 L
.864 .29889 L
.868 .29898 L
.872 .29918 L
.876 .29931 L
.88 .29925 L
.884 .29908 L
.888 .29891 L
.892 .29885 L
.896 .29895 L
.9 .29906 L
.904 .2991 L
.908 .2991 L
.912 .29907 L
.916 .29902 L
.92 .29902 L
.924 .29901 L
.928 .29898 L
.932 .299 L
.936 .29901 L
.94 .299 L
.944 .29899 L
.948 .29898 L
.952 .29895 L
.956 .29896 L
.96 .29899 L
.964 .29898 L
.968 .299 L
.972 .29906 L
.976 .29902 L
.98 .29895 L
.984 .29887 L
.988 .29873 L
.992 .29876 L
.996 .299 L
1 .29916 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .11215 m
.008 .11624 L
.012 .11772 L
.016 .1167 L
.02 .11638 L
.024 .117 L
.028 .11736 L
.032 .11743 L
.036 .11739 L
.04 .11739 L
.044 .11726 L
.048 .11705 L
.052 .11673 L
.056 .1164 L
.06 .11611 L
.064 .11591 L
.068 .1158 L
.072 .11577 L
.076 .11585 L
.08 .11608 L
.084 .11642 L
.088 .11679 L
.092 .11713 L
.096 .11748 L
.1 .11784 L
.104 .11818 L
.108 .11832 L
.112 .11828 L
.116 .11814 L
.12 .11796 L
.124 .11765 L
.128 .11717 L
.132 .11655 L
.136 .11594 L
.14 .11547 L
.144 .11515 L
.148 .11486 L
.152 .11458 L
.156 .11434 L
.16 .11426 L
.164 .11438 L
.168 .11463 L
.172 .11484 L
.176 .11496 L
.18 .11509 L
.184 .11548 L
.188 .11627 L
.192 .1174 L
.196 .11863 L
.2 .11978 L
Mistroke
.204 .12093 L
.208 .12235 L
.212 .12425 L
.216 .12657 L
.22 .12891 L
.224 .13093 L
.228 .13254 L
.232 .13399 L
.236 .13563 L
.24 .13763 L
.244 .13989 L
.248 .14216 L
.252 .14421 L
.256 .14596 L
.26 .14749 L
.264 .14894 L
.268 .15048 L
.272 .15233 L
.276 .15468 L
.28 .15761 L
.284 .16098 L
.288 .16441 L
.292 .16745 L
.296 .16977 L
.3 .17134 L
.304 .17244 L
.308 .17346 L
.312 .17473 L
.316 .17639 L
.32 .17848 L
.324 .18099 L
.328 .18399 L
.332 .18765 L
.336 .19208 L
.34 .19728 L
.344 .20307 L
.348 .20914 L
.352 .21523 L
.356 .22119 L
.36 .22709 L
.364 .23307 L
.368 .23929 L
.372 .24578 L
.376 .25242 L
.38 .25899 L
.384 .26529 L
.388 .2712 L
.392 .2768 L
.396 .28226 L
.4 .28783 L
Mistroke
.404 .29369 L
.408 .2999 L
.412 .30639 L
.416 .31296 L
.42 .31938 L
.424 .32547 L
.428 .33115 L
.432 .33648 L
.436 .34162 L
.44 .34681 L
.444 .35228 L
.448 .3582 L
.452 .36465 L
.456 .3716 L
.46 .37891 L
.464 .3864 L
.468 .39384 L
.472 .40099 L
.476 .40769 L
.48 .41378 L
.484 .41917 L
.488 .42385 L
.492 .42781 L
.496 .43111 L
.5 .43381 L
.504 .43599 L
.508 .43774 L
.512 .43915 L
.516 .44028 L
.52 .44119 L
.524 .44192 L
.528 .44251 L
.532 .443 L
.536 .44341 L
.54 .44376 L
.544 .44406 L
.548 .44432 L
.552 .44454 L
.556 .44474 L
.56 .44491 L
.564 .44506 L
.568 .44518 L
.572 .44529 L
.576 .44539 L
.58 .44548 L
.584 .44556 L
.588 .44563 L
.592 .44569 L
.596 .44575 L
.6 .44581 L
Mistroke
.604 .44587 L
.608 .44591 L
.612 .44595 L
.616 .44599 L
.62 .44602 L
.624 .44605 L
.628 .44608 L
.632 .44611 L
.636 .44615 L
.64 .44618 L
.644 .44622 L
.648 .44625 L
.652 .44628 L
.656 .44631 L
.66 .44633 L
.664 .44636 L
.668 .44638 L
.672 .44641 L
.676 .44644 L
.68 .44647 L
.684 .4465 L
.688 .44653 L
.692 .44656 L
.696 .44659 L
.7 .44662 L
.704 .44664 L
.708 .44667 L
.712 .4467 L
.716 .44672 L
.72 .44675 L
.724 .44678 L
.728 .44681 L
.732 .44684 L
.736 .44687 L
.74 .4469 L
.744 .44692 L
.748 .44695 L
.752 .44698 L
.756 .447 L
.76 .44703 L
.764 .44705 L
.768 .44708 L
.772 .44711 L
.776 .44714 L
.78 .44717 L
.784 .44721 L
.788 .44723 L
.792 .44726 L
.796 .44728 L
.8 .4473 L
Mistroke
.804 .44733 L
.808 .44736 L
.812 .44739 L
.816 .44742 L
.82 .44745 L
.824 .44748 L
.828 .44751 L
.832 .44753 L
.836 .44756 L
.84 .44759 L
.844 .44761 L
.848 .44764 L
.852 .44767 L
.856 .4477 L
.86 .44773 L
.864 .44776 L
.868 .44778 L
.872 .44781 L
.876 .44784 L
.88 .44787 L
.884 .44789 L
.888 .44792 L
.892 .44794 L
.896 .44797 L
.9 .448 L
.904 .44804 L
.908 .44806 L
.912 .44809 L
.916 .44811 L
.92 .44814 L
.924 .44817 L
.928 .4482 L
.932 .44822 L
.936 .44825 L
.94 .44828 L
.944 .44832 L
.948 .44834 L
.952 .44837 L
.956 .44839 L
.96 .44842 L
.964 .44844 L
.968 .44848 L
.972 .44849 L
.976 .44854 L
.98 .44855 L
.984 .4486 L
.988 .44861 L
.992 .44865 L
.996 .44866 L
1 .44871 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15871 L
.012 .16117 L
.016 .16179 L
.02 .1609 L
.024 .1607 L
.028 .16119 L
.032 .16139 L
.036 .16148 L
.04 .16159 L
.044 .16177 L
.048 .16178 L
.052 .16165 L
.056 .16135 L
.06 .16095 L
.064 .1605 L
.068 .16007 L
.072 .15968 L
.076 .15946 L
.08 .15952 L
.084 .1599 L
.088 .16044 L
.092 .16109 L
.096 .16179 L
.1 .16254 L
.104 .16312 L
.108 .16339 L
.112 .16329 L
.116 .16298 L
.12 .16254 L
.124 .16199 L
.128 .16127 L
.132 .16044 L
.136 .1597 L
.14 .15919 L
.144 .15885 L
.148 .15855 L
.152 .15819 L
.156 .15786 L
.16 .1577 L
.164 .1578 L
.168 .15807 L
.172 .15833 L
.176 .15852 L
.18 .15874 L
.184 .15928 L
.188 .16031 L
.192 .16172 L
.196 .16322 L
.2 .1646 L
Mistroke
.204 .16595 L
.208 .16766 L
.212 .16998 L
.216 .17283 L
.22 .17575 L
.224 .17827 L
.228 .18029 L
.232 .18212 L
.236 .18417 L
.24 .18666 L
.244 .18948 L
.248 .1923 L
.252 .19485 L
.256 .19704 L
.26 .19894 L
.264 .20073 L
.268 .20262 L
.272 .20486 L
.276 .20772 L
.28 .2113 L
.284 .21544 L
.288 .21969 L
.292 .2235 L
.296 .22644 L
.3 .22847 L
.304 .22988 L
.308 .23116 L
.312 .2327 L
.316 .23469 L
.32 .23719 L
.324 .24022 L
.328 .24391 L
.332 .24845 L
.336 .254 L
.34 .26051 L
.344 .26775 L
.348 .27531 L
.352 .28286 L
.356 .29022 L
.36 .2975 L
.364 .30489 L
.368 .31261 L
.372 .32068 L
.376 .32896 L
.38 .33714 L
.384 .34496 L
.388 .35228 L
.392 .35918 L
.396 .3659 L
.4 .37277 L
Mistroke
.404 .38002 L
.408 .38774 L
.412 .3958 L
.416 .40396 L
.42 .41193 L
.424 .41947 L
.428 .42649 L
.432 .43306 L
.436 .43941 L
.44 .44581 L
.444 .45256 L
.448 .45988 L
.452 .46785 L
.456 .47644 L
.46 .48549 L
.464 .49476 L
.468 .50397 L
.472 .51284 L
.476 .52112 L
.48 .52865 L
.484 .5353 L
.488 .54103 L
.492 .54588 L
.496 .54991 L
.5 .55319 L
.504 .55584 L
.508 .55796 L
.512 .55964 L
.516 .56097 L
.52 .56202 L
.524 .56285 L
.528 .56352 L
.532 .56406 L
.536 .56451 L
.54 .56486 L
.544 .56516 L
.548 .56539 L
.552 .56558 L
.556 .56574 L
.56 .56587 L
.564 .56598 L
.568 .56607 L
.572 .56613 L
.576 .56619 L
.58 .56622 L
.584 .56625 L
.588 .56627 L
.592 .56627 L
.596 .56626 L
.6 .56623 L
Mistroke
.604 .56621 L
.608 .56618 L
.612 .56616 L
.616 .56614 L
.62 .56612 L
.624 .56609 L
.628 .56606 L
.632 .56602 L
.636 .56597 L
.64 .56593 L
.644 .56588 L
.648 .56584 L
.652 .5658 L
.656 .56576 L
.66 .56572 L
.664 .56569 L
.668 .56565 L
.672 .56561 L
.676 .56556 L
.68 .56552 L
.684 .56547 L
.688 .56543 L
.692 .56538 L
.696 .56534 L
.7 .5653 L
.704 .56525 L
.708 .56521 L
.712 .56517 L
.716 .56513 L
.72 .56509 L
.724 .56505 L
.728 .56501 L
.732 .56496 L
.736 .56491 L
.74 .56486 L
.744 .56482 L
.748 .56478 L
.752 .56474 L
.756 .5647 L
.76 .56466 L
.764 .56462 L
.768 .56458 L
.772 .56453 L
.776 .56448 L
.78 .56443 L
.784 .56439 L
.788 .56435 L
.792 .56431 L
.796 .56428 L
.8 .56424 L
Mistroke
.804 .56419 L
.808 .56414 L
.812 .56409 L
.816 .56405 L
.82 .56401 L
.824 .56397 L
.828 .56392 L
.832 .56388 L
.836 .56384 L
.84 .5638 L
.844 .56375 L
.848 .56371 L
.852 .56367 L
.856 .56362 L
.86 .56358 L
.864 .56354 L
.868 .56349 L
.872 .56345 L
.876 .56341 L
.88 .56337 L
.884 .56332 L
.888 .56328 L
.892 .56323 L
.896 .5632 L
.9 .56315 L
.904 .56311 L
.908 .56306 L
.912 .56302 L
.916 .56297 L
.92 .56294 L
.924 .56289 L
.928 .56285 L
.932 .5628 L
.936 .56276 L
.94 .56271 L
.944 .56268 L
.948 .56262 L
.952 .56259 L
.956 .56254 L
.96 .56251 L
.964 .56245 L
.968 .56242 L
.972 .56236 L
.976 .56233 L
.98 .56227 L
.984 .56225 L
.988 .56219 L
.992 .56217 L
.996 .5621 L
1 .56208 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2000[Ool20010Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P0000=oo`00Ool00Woo0`00
0goo0`0017oo0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogoo
Ool00002Ool01000Oomoo`001goo00<007ooOol00Woo00<007ooOol00P0000Aoo`00001oo`8000Ao
o`05001oogooOol00003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool0
1000Oomoo`000Woo00<007ooOol00Woo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007oo
Ool00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001o
ogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`02000017oo001oogoo0P0017oo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol00Woo100000=oo`0000000Woo00<007oo00000goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0
17oo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool20004Ool00`00Oomoo`0;Ool40003Ool01000Oomoo`001goo00@007ooOomoo`D0
009oo`06001oogoo001oo`000goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo
0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo
0006Ool20002Ool30002Ool01000Oomoo`000Woo00<007oo00000Woo0P000goo00<007ooOol017oo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001o
ogooOol007oo00001Woo00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00@007oo0000
009oo`8000Aoo`8000=oo`04001oogoo0003Ool50003Ool20004Ool30004Ool20004Ool20005Ool3
0002Ool50003Ool20006Ool0029oo`03001oogoo01moo`03001oogoo00eoo`03001oogoo03Yoo`00
8Woo0P007goo00<007ooOol03Woo1@0037oo0P002goo00<007ooOol03Goo0P003Goo000ROomS000<
Ool0029oo`D00004Ool007oo0002Ool60003Ool01@00Oomoogoo00000Woo00@007ooOomoo`80009o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`04001oogoo0003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00<007ooOol02Woo000ROol2000017oo000000000Woo00@007ooOol000Eoo`03001oogoo
00aoo`03001oogoo04aoo`008Woo00D007ooOomoo`0000=oo`03001oo`0000Ioo`<000aoo`03001o
ogoo04aoo`008Woo0P001goo0P0027oo0P000goo0P0000=oo`0000000Woo00<007ooOol0CGoo000R
Ool2000BOol4000027oo00000000Ool007oo001?Ool000]oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`03001oogoo01=oo`8000Eoo`03001oo`0004moo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2000KOol2001@Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2
001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool2
0004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0
009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007oo
Ool0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`80
06eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=o
o`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0
K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo
00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05
Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomo
o`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`<0009oo`@000=oo`H005Moo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool60002Ool50005Ool3001DOol0011oo`04001oogoo0008Ool01000Oomoo`00
0Woo0P0017oo00<007ooOol04Goo0`00DWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00
Oomoo`0COol3001@Ool002Qoo`03001oogoo01Ioo`8004ioo`00:7oo00<007ooOol05goo0`00C7oo
000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0IOol3001:Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`007Goo
0P00BGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000
Oomoo`007Woo0P00B7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool0
0`00Oomoo`02000;Ool30004Ool20007Ool40003Ool20004Ool20003Ool30003Ool30004Ool20002
Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000
Oomoo`001goo00H007oo000007oo0002Ool01000Oomoo`000Woo00D007ooOomoo`0000=oo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
0goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03
001oogoo00Eoo`06001oogoo001oo`000Woo00@007ooOol0009oo`05001oogooOol00007Ool01000
Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<0
07ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`04001oogooOol20002Ool01000Oomoo`00
0Woo00D007ooOomoo`0000Moo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03
Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool01000Oomoogoo0P000Woo00@007oo
Ool0009oo`05001oogooOol00003Ool40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=oo`04001oogoo0005Ool002Qoo`03
001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007oo
Ool0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol0
2Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=o
o`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol08Goo0P00@goo
000XOol00`00Oomoo`0ROol00`00Oomoo`11Ool002Qooed000aoo`00:7oo00<007ooOol03goo00<0
07ooOol047oo00<007oo00003goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000X
Ool00`00Oomoo`0TOol00`00Oomoo`0oOol002Qoo`03001oogoo02Eoo`03001oogoo03ioo`00:7oo
00<007ooOol09Goo0P00?goo000XOol00`00Oomoo`0VOol00`00Oomoo`0mOol002Qoo`03001oogoo
02Moo`03001oogoo03aoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<0
07ooOol0:7oo00<007ooOol0>goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`000goo00@007ooOol002Yoo`03001oogoo03]oo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOol002Yoo`8003aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00:Woo00<007ooOol0>Woo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`0ZOol00`00Oomoo`0i
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0[
Ool6000eOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo031oobX000aoo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo
06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0
06Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001W
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo
1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3
0003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo
00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007oo
Ool000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol0
0`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool5
0003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002
Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomo
ogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo
00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@0
07ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=o
o`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004
Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Io
o`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Io
o`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol0
0003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo0`0000=oo`00Ool00Woo00D007ooOomoo`00
00=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo01Aoo`8005aoo`0077oo
0P005goo0P00FWoo000LOol00`00Oomoo`0GOol3001HOol001aoo`03001oogoo01Uoo`8005Moo`00
77oo0P0077oo00<007ooOol0E7oo000LOol00`00Oomoo`0KOol3001DOol001aoo`03001oogoo01eo
o`<0059oo`0077oo0P0087oo0P00DGoo000LOol00`00Oomoo`0POol00`00Oomoo`1?Ool001aoo`80
025oo`80051oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol08Goo00<007ooOol0
CWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo029oo`03001oogoo04eo
o`002Woo00@007ooOol000]oo`03001oogoo008002=oo`03001oogoo04eoo`002Woo00@007ooOol0
00]oo`04001oogoo000UOol00`00Oomoo`1<Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomo
o`0SOol00`00Oomoo`1<Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2000UOol00`00Oomo
o`1;Ool000]oo`8000Qoo`D0009oo`03001oogoo02Aoo`03001oogoo04]oo`0077oo00<007ooOol0
9Goo00<007ooOol0BWoo000LOol2000VOol00`00Oomoo`1:Ool001aoo`03001oogoo02Ioo`03001o
ogoo04Uoo`0077oo0P00:7oo00<007ooOol0B7oo000LOol00`00Oomoo`0WOol00`00Oomoo`18Ool0
01aoo`03001oogoo02Moo`03001oogoo04Qoo`0077oo0P00:Goo00<007ooOol0Agoo000FOol30003
Ool00`00Oomoo`0YOol00`00Oomoo`16Ool001Moo`03001oogoo009oo`03001oogoo02Uoo`03001o
ogoo04Ioo`005goo00<007ooOol00Woo0P00:Woo0P00Agoo000GOol00`00Oomoo`02Ool00`00Oomo
o`0ZOol00`00Oomoo`15Ool001Moo`03001oogoo009oo`03001oogoo02]oo`03001oogoo04Aoo`00
5Woo0P0017oo0P00;Goo00<007ooOol0@goo000GOol00`00Oomoo`02Ool00`00Oomoo`0/Ool00`00
Oomoo`13Ool001aoo`03001oogoo02aoo`03001oogoo04=oo`0077oo0P00;Woo00<007ooOol0@Woo
000LOol00`00Oomoo`0]Ool00`00Oomoo`12Ool001aoo`8002moo`03001oogoo045oo`0077oo00<0
07ooOol0;Woo00<007ooOol0@Goo000LOol00`00Oomoo`0_Ool00`00Oomoo`10Ool000Yoo`<000Ao
o`03001oogoo009oo`<000=oo`80031oo`03001oogoo041oo`002goo00<007ooOol01goo00D007oo
Oomoo`00009oo`03001oogoo031oo`03001oogoo03moo`002goo00<007ooOol02goo00@007ooOol0
03=oo`8003moo`002goo00<007ooOol02goo00<007ooOol00P00=7oo<`0037oo000;Ool00`00Oomo
o`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`00
2goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(39579\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31406 m
.008 .31857 L
.012 .32364 L
.016 .3278 L
.02 .32973 L
.024 .32928 L
.028 .32613 L
.032 .32094 L
.036 .31493 L
.04 .30994 L
.044 .30766 L
.048 .30929 L
.052 .31463 L
.056 .32198 L
.06 .32886 L
.064 .33354 L
.068 .33455 L
.072 .33114 L
.076 .32371 L
.08 .31421 L
.084 .30601 L
.088 .30162 L
.092 .30205 L
.096 .30653 L
.1 .31429 L
.104 .32418 L
.108 .33341 L
.112 .33887 L
.116 .33916 L
.12 .33581 L
.124 .33078 L
.128 .32537 L
.132 .32012 L
.136 .31566 L
.14 .31309 L
.144 .3128 L
.148 .31382 L
.152 .31423 L
.156 .31314 L
.16 .31107 L
.164 .3094 L
.168 .30936 L
.172 .31102 L
.176 .31336 L
.18 .31521 L
.184 .3164 L
.188 .31794 L
.192 .32109 L
.196 .32559 L
.2 .3294 L
Mistroke
.204 .3307 L
.208 .32994 L
.212 .33 L
.216 .3337 L
.22 .34079 L
.224 .34791 L
.228 .35164 L
.232 .35167 L
.236 .35086 L
.24 .35245 L
.244 .35665 L
.248 .36044 L
.252 .36046 L
.256 .356 L
.26 .34958 L
.264 .34482 L
.268 .34363 L
.272 .34544 L
.276 .34842 L
.28 .35115 L
.284 .35314 L
.288 .35421 L
.292 .35378 L
.296 .35125 L
.3 .34716 L
.304 .3436 L
.308 .34329 L
.312 .34767 L
.316 .35557 L
.32 .3637 L
.324 .3687 L
.328 .36917 L
.332 .36627 L
.336 .36237 L
.34 .35892 L
.344 .35517 L
.348 .34872 L
.352 .33744 L
.356 .32144 L
.36 .30355 L
.364 .28795 L
.368 .27795 L
.372 .27403 L
.376 .27375 L
.38 .27314 L
.384 .26904 L
.388 .26078 L
.392 .25046 L
.396 .24159 L
.4 .23715 L
Mistroke
.404 .23795 L
.408 .24232 L
.412 .24706 L
.416 .24905 L
.42 .24668 L
.424 .24042 L
.428 .23236 L
.432 .22511 L
.436 .22071 L
.44 .21998 L
.444 .22253 L
.448 .22717 L
.452 .23234 L
.456 .23656 L
.46 .23856 L
.464 .23743 L
.468 .2328 L
.472 .225 L
.476 .21515 L
.48 .20504 L
.484 .19666 L
.488 .19168 L
.492 .19098 L
.496 .19449 L
.5 .20141 L
.504 .21057 L
.508 .22089 L
.512 .23158 L
.516 .24216 L
.52 .25235 L
.524 .26188 L
.528 .27042 L
.532 .27767 L
.536 .28343 L
.54 .28772 L
.544 .29076 L
.548 .29293 L
.552 .29455 L
.556 .29589 L
.56 .29699 L
.564 .29781 L
.568 .29828 L
.572 .29843 L
.576 .29841 L
.58 .29843 L
.584 .29864 L
.588 .29901 L
.592 .2994 L
.596 .2996 L
.6 .2995 L
Mistroke
.604 .29916 L
.608 .29881 L
.612 .2987 L
.616 .2989 L
.62 .29928 L
.624 .29956 L
.628 .29957 L
.632 .29933 L
.636 .29909 L
.64 .29907 L
.644 .29931 L
.648 .29963 L
.652 .29974 L
.656 .29952 L
.66 .29908 L
.664 .29873 L
.668 .29874 L
.672 .29914 L
.676 .29966 L
.68 .29994 L
.684 .29979 L
.688 .29936 L
.692 .29897 L
.696 .29889 L
.7 .29911 L
.704 .29938 L
.708 .29946 L
.712 .29931 L
.716 .29913 L
.72 .29912 L
.724 .29932 L
.728 .29955 L
.732 .29959 L
.736 .29937 L
.74 .29903 L
.744 .29885 L
.748 .29897 L
.752 .29929 L
.756 .29954 L
.76 .29952 L
.764 .29927 L
.768 .29901 L
.772 .29897 L
.776 .2992 L
.78 .29946 L
.784 .2995 L
.788 .29928 L
.792 .29897 L
.796 .29884 L
.8 .299 L
Mistroke
.804 .2993 L
.808 .29948 L
.812 .29942 L
.816 .29921 L
.82 .29905 L
.824 .29904 L
.828 .29913 L
.832 .29917 L
.836 .29913 L
.84 .29907 L
.844 .2991 L
.848 .29922 L
.852 .29932 L
.856 .29927 L
.86 .29911 L
.864 .29895 L
.868 .29892 L
.872 .29907 L
.876 .29924 L
.88 .29929 L
.884 .29921 L
.888 .29903 L
.892 .29892 L
.896 .29897 L
.9 .2991 L
.904 .29922 L
.908 .29926 L
.912 .29916 L
.916 .299 L
.92 .29891 L
.924 .29891 L
.928 .299 L
.932 .29914 L
.936 .2992 L
.94 .29916 L
.944 .29907 L
.948 .29899 L
.952 .29893 L
.956 .29895 L
.96 .29899 L
.964 .29901 L
.968 .29907 L
.972 .29914 L
.976 .29908 L
.98 .29901 L
.984 .29891 L
.988 .29881 L
.992 .29892 L
.996 .29913 L
1 .2992 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12054 m
.008 .11761 L
.012 .11654 L
.016 .11747 L
.02 .11748 L
.024 .11687 L
.028 .11662 L
.032 .11674 L
.036 .11678 L
.04 .11687 L
.044 .11706 L
.048 .11738 L
.052 .11762 L
.056 .11782 L
.06 .11793 L
.064 .11798 L
.068 .11791 L
.072 .11773 L
.076 .11744 L
.08 .11715 L
.084 .11687 L
.088 .11661 L
.092 .11636 L
.096 .11619 L
.1 .11617 L
.104 .11632 L
.108 .11652 L
.112 .11679 L
.116 .11717 L
.12 .11768 L
.124 .1182 L
.128 .11861 L
.132 .11883 L
.136 .11893 L
.14 .11893 L
.144 .11879 L
.148 .11844 L
.152 .11787 L
.156 .11723 L
.16 .11666 L
.164 .11622 L
.168 .11587 L
.172 .11552 L
.176 .11515 L
.18 .11488 L
.184 .1148 L
.188 .11492 L
.192 .11511 L
.196 .11519 L
.2 .11515 L
Mistroke
.204 .1152 L
.208 .11557 L
.212 .11635 L
.216 .11737 L
.22 .11837 L
.224 .11925 L
.228 .12021 L
.232 .12156 L
.236 .12346 L
.24 .12573 L
.244 .12798 L
.248 .12993 L
.252 .13155 L
.256 .13309 L
.26 .13481 L
.264 .1368 L
.268 .13899 L
.272 .1412 L
.276 .14326 L
.28 .14509 L
.284 .14669 L
.288 .14812 L
.292 .14952 L
.296 .15116 L
.3 .15331 L
.304 .1561 L
.308 .1594 L
.312 .16286 L
.316 .166 L
.32 .16852 L
.324 .17035 L
.328 .1717 L
.332 .17287 L
.336 .17413 L
.34 .1756 L
.344 .17734 L
.348 .1794 L
.352 .18193 L
.356 .18514 L
.36 .18919 L
.364 .19406 L
.368 .19958 L
.372 .20545 L
.376 .21137 L
.38 .21722 L
.384 .22302 L
.388 .22892 L
.392 .23508 L
.396 .24154 L
.4 .24819 L
Mistroke
.404 .25482 L
.408 .2612 L
.412 .26722 L
.416 .27287 L
.42 .27834 L
.424 .28386 L
.428 .28962 L
.432 .29574 L
.436 .30217 L
.44 .30874 L
.444 .31523 L
.448 .32144 L
.452 .32726 L
.456 .3327 L
.46 .33788 L
.464 .34301 L
.468 .34832 L
.472 .354 L
.476 .36017 L
.48 .36686 L
.484 .37399 L
.488 .3814 L
.492 .38889 L
.496 .39623 L
.5 .40322 L
.504 .4097 L
.508 .41553 L
.512 .42066 L
.516 .42509 L
.52 .42882 L
.524 .43193 L
.528 .43448 L
.532 .43655 L
.536 .43821 L
.54 .43954 L
.544 .44061 L
.548 .44147 L
.552 .44217 L
.556 .44274 L
.56 .44321 L
.564 .44361 L
.568 .44395 L
.572 .44424 L
.576 .44449 L
.58 .44471 L
.584 .4449 L
.588 .44506 L
.592 .4452 L
.596 .44531 L
.6 .44542 L
Mistroke
.604 .44552 L
.608 .44561 L
.612 .44569 L
.616 .44577 L
.62 .44583 L
.624 .44589 L
.628 .44594 L
.632 .44598 L
.636 .44602 L
.64 .44606 L
.644 .4461 L
.648 .44613 L
.652 .44617 L
.656 .44621 L
.66 .44624 L
.664 .44627 L
.668 .44631 L
.672 .44633 L
.676 .44636 L
.68 .44639 L
.684 .44642 L
.688 .44645 L
.692 .44648 L
.696 .4465 L
.7 .44653 L
.704 .44656 L
.708 .44659 L
.712 .44662 L
.716 .44665 L
.72 .44668 L
.724 .44671 L
.728 .44673 L
.732 .44675 L
.736 .44678 L
.74 .44681 L
.744 .44684 L
.748 .44687 L
.752 .4469 L
.756 .44693 L
.76 .44696 L
.764 .44698 L
.768 .44701 L
.772 .44703 L
.776 .44706 L
.78 .44709 L
.784 .44712 L
.788 .44715 L
.792 .44718 L
.796 .44721 L
.8 .44723 L
Mistroke
.804 .44726 L
.808 .44728 L
.812 .44731 L
.816 .44734 L
.82 .44737 L
.824 .4474 L
.828 .44742 L
.832 .44745 L
.836 .44748 L
.84 .44751 L
.844 .44753 L
.848 .44756 L
.852 .44759 L
.856 .44762 L
.86 .44765 L
.864 .44767 L
.868 .4477 L
.872 .44773 L
.876 .44775 L
.88 .44779 L
.884 .44781 L
.888 .44784 L
.892 .44787 L
.896 .4479 L
.9 .44792 L
.904 .44795 L
.908 .44798 L
.912 .44801 L
.916 .44803 L
.92 .44806 L
.924 .44809 L
.928 .44812 L
.932 .44814 L
.936 .44818 L
.94 .4482 L
.944 .44823 L
.948 .44825 L
.952 .44829 L
.956 .44831 L
.96 .44834 L
.964 .44836 L
.968 .4484 L
.972 .44842 L
.976 .44846 L
.98 .44847 L
.984 .44851 L
.988 .44852 L
.992 .44857 L
.996 .44857 L
1 .44863 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15808 L
.012 .1611 L
.016 .16218 L
.02 .16129 L
.024 .16087 L
.028 .16117 L
.032 .16126 L
.036 .16114 L
.04 .16099 L
.044 .16097 L
.048 .16096 L
.052 .16103 L
.056 .16111 L
.06 .16127 L
.064 .16145 L
.068 .16165 L
.072 .16168 L
.076 .16158 L
.08 .16135 L
.084 .16105 L
.088 .16063 L
.092 .16014 L
.096 .15973 L
.1 .15956 L
.104 .15961 L
.108 .15986 L
.112 .16023 L
.116 .16078 L
.12 .16146 L
.124 .16217 L
.128 .16267 L
.132 .16291 L
.136 .16297 L
.14 .16292 L
.144 .16272 L
.148 .16229 L
.152 .16162 L
.156 .16088 L
.16 .16022 L
.164 .15971 L
.168 .15926 L
.172 .15878 L
.176 .15826 L
.18 .15785 L
.184 .15769 L
.188 .1578 L
.192 .15801 L
.196 .15811 L
.2 .15809 L
Mistroke
.204 .15817 L
.208 .15865 L
.212 .15964 L
.216 .16091 L
.22 .16216 L
.224 .16326 L
.228 .16445 L
.232 .16614 L
.236 .1685 L
.24 .1713 L
.244 .17407 L
.248 .17644 L
.252 .1784 L
.256 .18026 L
.26 .18236 L
.264 .18485 L
.268 .18762 L
.272 .19042 L
.276 .19305 L
.28 .19538 L
.284 .19737 L
.288 .1991 L
.292 .20076 L
.296 .20271 L
.3 .20531 L
.304 .20874 L
.308 .21286 L
.312 .2172 L
.316 .22117 L
.32 .22433 L
.324 .22661 L
.328 .22824 L
.332 .22964 L
.336 .23115 L
.34 .23294 L
.344 .23509 L
.348 .23766 L
.352 .24083 L
.356 .24484 L
.36 .24986 L
.364 .2559 L
.368 .26273 L
.372 .26997 L
.376 .27731 L
.38 .28456 L
.384 .29177 L
.388 .29912 L
.392 .30679 L
.396 .31482 L
.4 .32307 L
Mistroke
.404 .33129 L
.408 .3392 L
.412 .34664 L
.416 .35364 L
.42 .3604 L
.424 .36723 L
.428 .37437 L
.432 .38195 L
.436 .38991 L
.44 .39806 L
.444 .40611 L
.448 .41381 L
.452 .42102 L
.456 .42774 L
.46 .43414 L
.464 .44046 L
.468 .447 L
.472 .45402 L
.476 .46165 L
.48 .46993 L
.484 .47876 L
.488 .48794 L
.492 .49721 L
.496 .50629 L
.5 .51493 L
.504 .52292 L
.508 .53013 L
.512 .53647 L
.516 .54191 L
.52 .54649 L
.524 .55027 L
.528 .55336 L
.532 .55585 L
.536 .55784 L
.54 .55943 L
.544 .56069 L
.548 .5617 L
.552 .5625 L
.556 .56314 L
.56 .56366 L
.564 .56407 L
.568 .56441 L
.572 .56469 L
.576 .56491 L
.58 .5651 L
.584 .56525 L
.588 .56538 L
.592 .56549 L
.596 .56557 L
.6 .56564 L
Mistroke
.604 .56569 L
.608 .56572 L
.612 .56573 L
.616 .56573 L
.62 .56572 L
.624 .56571 L
.628 .5657 L
.632 .56568 L
.636 .56567 L
.64 .56565 L
.644 .56563 L
.648 .56559 L
.652 .56556 L
.656 .56551 L
.66 .56547 L
.664 .56543 L
.668 .56539 L
.672 .56535 L
.676 .56532 L
.68 .56528 L
.684 .56523 L
.688 .56519 L
.692 .56515 L
.696 .56511 L
.7 .56507 L
.704 .56503 L
.708 .56498 L
.712 .56493 L
.716 .56489 L
.72 .56485 L
.724 .56481 L
.728 .56477 L
.732 .56473 L
.736 .56469 L
.74 .56464 L
.744 .5646 L
.748 .56456 L
.752 .56451 L
.756 .56446 L
.76 .56441 L
.764 .56437 L
.768 .56433 L
.772 .5643 L
.776 .56426 L
.78 .56422 L
.784 .56417 L
.788 .56412 L
.792 .56408 L
.796 .56403 L
.8 .56399 L
Mistroke
.804 .56395 L
.808 .56391 L
.812 .56386 L
.816 .56382 L
.82 .56378 L
.824 .56374 L
.828 .56369 L
.832 .56365 L
.836 .5636 L
.84 .56356 L
.844 .56352 L
.848 .56348 L
.852 .56343 L
.856 .56339 L
.86 .56335 L
.864 .56331 L
.868 .56326 L
.872 .56322 L
.876 .56317 L
.88 .56313 L
.884 .56308 L
.888 .56304 L
.892 .563 L
.896 .56296 L
.9 .56292 L
.904 .56288 L
.908 .56283 L
.912 .56279 L
.916 .56274 L
.92 .5627 L
.924 .56265 L
.928 .56262 L
.932 .56257 L
.936 .56253 L
.94 .56248 L
.944 .56245 L
.948 .56239 L
.952 .56236 L
.956 .5623 L
.96 .56227 L
.964 .56222 L
.968 .56219 L
.972 .56213 L
.976 .56211 L
.98 .56204 L
.984 .56202 L
.988 .56195 L
.992 .56193 L
.996 .56186 L
1 .56185 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0;Goo00<007ooOol0?7oo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool2000]Ool00`00Ool0000mOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo
0P0000Eoo`00Ool007oo00<000=oo`<000Aoo`8000=oo`D000=oo`8000Aoo`8000Aoo`D0009oo`<0
00Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`0;Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`05001oogoo
001oo`020002Ool01`00Oomoogoo001oo`0000=oo`05001oogooOol00002Ool01000Oomoo`000goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOol007oo0003Ool01000
Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01@00Ool00000Ool0
1@000goo00<007oo00001goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol00Woo00<007oo00000P0000=oo`00Ool00P000goo00<007oo0000
1goo00@007ooOol0009oo`03001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`000Woo00<0
07ooOol017oo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;Ool40003Ool01000Oomoo`001goo00<007oo
Ool00Woo0P0000Eoo`00001oo`00009oo`03001oogoo009oo`8000=oo`@000=oo`04001oogoo0002
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@0
00=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo
00Aoo`04001oogoo0006Ool20004Ool200001Goo001oogoo00000Woo00<007ooOol00Woo0P000goo
00<007ooOol017oo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P00
27oo00@007ooOomoo`@000Aoo`8000Ioo`04001oogooOol50003Ool20004Ool30004Ool20004Ool2
0005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo025oo`03001oogoo00eoo`8003Uoo`00
8Woo0P008Woo00<007ooOol03Woo1@000Woo00<007ooOol00Woo00<007ooOol0:goo000ROomS000<
Ool0029oo`80009oo`80009oo`04001oo`00Ool700000goo001oo`02Ool01000Oomoo`000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00009o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo000037oo000ROol40002Ool01@00Ool007oo00000Woo00<007ooOol00goo
0P003Woo00<007ooOol0BGoo000ROol00`00Ool00003Ool20003Ool20007Ool2000<Ool00`00Oomo
o`1:Ool0029oo`8001Aoo`03001oogoo00<00004Ool000000002Ool00`00Oomoo`1:Ool0029oo`80
01Aoo`@00007Ool00000001oo`00Ool00P00C7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool00`00Oomoo`0EOol20005Ool3001=Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol0
0Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`00
0goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomo
o`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007oo
Ool006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007oo
Ool007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`80
06eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3
001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo
06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00
Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1V
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0
IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03
Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2
00000goo001oo`03Ool30004Ool5001EOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo2@0000=oo`0000000`001Goo0`00DWoo000@Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000Aoo`03001oogoo01=oo`<0051oo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<0
07ooOol05Woo0P00CWoo000XOol00`00Oomoo`0HOol2001<Ool002Qoo`03001oogoo01Yoo`8004Yo
o`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol06goo0`00B7oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol0021o
o`03001oogoo04Eoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOol0021oo`8004Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`000Woo00@007oo000000Aoo`8000=oo`<0
00=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007oo
Oomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=o
o`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=
Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo0P0000Eoo`00Oomoo`00009oo`05
001oogooOol00007Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000
Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P00
17oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
009oo`800005Ool007ooOol00002Ool01@00Oomoogoo00001goo00@007ooOol0009oo`03001oogoo
009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@0
07ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03
001oogoo009oo`04001oo`000002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo
001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`00
0goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`80
00Aoo`04001oo`000002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo
0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000
Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool40002Ool20004
Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo
000XOol00`00Oomoo`0TOol00`00Oomoo`0oOol002Qoo`03001oogoo02Eoo`03001oogoo03ioo`00
:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool01@00Oomoogoo00003Goo00<007oo
Ool03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`0VOol2000nOol002Qoo`03
001oogoo02Moo`8003eoo`00:7oo00<007ooOol0:7oo00<007ooOol0>goo000XOol00`00Oomoo`0Y
Ool00`00Oomoo`0jOol002Qoo`03001oogoo02Uoo`03001oogoo03Yoo`002goo0P0017oo00<007oo
Ool00goo0P0017oo0P000goo0`000goo00<007ooOol0:Woo00<007ooOol0>Goo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol002aoo`03001oogoo03Uo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol002eoo`03
001oogoo03Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool00P00;Goo00<007ooOol0=goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo
001oo`040003Ool00`00Oomoo`0/Ool2000hOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0006Ool00`00Oomoo`0]Ool6000cOol000]oo`8000Yoo`8000Aoo`80009oo`D0
009oo`03001oogoo039oobP000aoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007oo
Ool0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001o
ogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo
000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007oo
Ool00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@0
00=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P00
27oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004
Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006
Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=o
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@0
07ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo
00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0
009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo
10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03
001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=o
o`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`80
00Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004
Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00<007ooOol00P000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool0
01aoo`03001oogoo01Ioo`<005Uoo`0077oo0P006Woo00<007ooOol0EWoo000LOol00`00Oomoo`0J
Ool2001FOol001aoo`03001oogoo01aoo`8005Aoo`0077oo0P007Woo0P00Dgoo000LOol00`00Oomo
o`0NOol3001AOol001aoo`03001oogoo021oo`80051oo`0077oo0P008goo00<007ooOol0CGoo000L
Ool00`00Oomoo`0SOol00`00Oomoo`1<Ool001aoo`8002Aoo`03001oogoo04aoo`002goo0P0017oo
00<007ooOol00Woo0`000goo00<007ooOol097oo00<007ooOol0Bgoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo02Aoo`03001oogoo04]oo`002Woo00@007ooOol000]oo`03
001oogoo008002Ioo`03001oogoo04Yoo`002Woo00@007ooOol000]oo`04001oogoo000WOol2001;
Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0VOol00`00Oomoo`19Ool000Yoo`04001o
ogoo0007Ool00`00Oomoo`04Ool2000XOol00`00Oomoo`18Ool000]oo`8000Qoo`D0009oo`03001o
ogoo02Moo`03001oogoo04Qoo`0077oo00<007ooOol09goo0P00BGoo000LOol2000YOol00`00Oomo
o`17Ool001aoo`03001oogoo02Uoo`03001oogoo04Ioo`0077oo0P00:Woo00<007ooOol0AWoo000L
Ool00`00Oomoo`0ZOol00`00Oomoo`15Ool001aoo`03001oogoo02Yoo`03001oogoo04Eoo`0077oo
0P00;7oo00<007ooOol0A7oo000FOol30003Ool00`00Oomoo`0[Ool20015Ool001Moo`03001oogoo
009oo`03001oogoo02aoo`03001oogoo04=oo`005goo00<007ooOol00Woo0P00;Goo0P00A7oo000G
Ool00`00Oomoo`02Ool00`00Oomoo`0]Ool00`00Oomoo`12Ool001Moo`03001oogoo009oo`03001o
ogoo02ioo`03001oogoo045oo`005Woo0P0017oo0P00;goo00<007ooOol0@Goo000GOol00`00Oomo
o`02Ool00`00Oomoo`0_Ool00`00Oomoo`10Ool001aoo`03001oogoo02moo`03001oogoo041oo`00
77oo0P00<Goo00<007ooOol0?goo000LOol00`00Oomoo`0`Ool00`00Oomoo`0oOol001aoo`80035o
o`03001oogoo03moo`0077oo00<007ooOol0<Goo00<007ooOol0?Woo000LOol00`00Oomoo`0aOol2
000oOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8003=oo`03001oogoo03eoo`002goo00<0
07ooOol01goo00D007ooOomoo`00009oo`03001oogoo03=oo`03001oogoo03aoo`002goo00<007oo
Ool02goo00@007ooOol003Ioo`8003aoo`002goo00<007ooOol02goo00<007ooOol00P00=Woo<@00
37oo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Ao
o`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(39746\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32717 m
.008 .32252 L
.012 .31546 L
.016 .31049 L
.02 .30869 L
.024 .30932 L
.028 .31278 L
.032 .31852 L
.036 .32517 L
.04 .32975 L
.044 .33095 L
.048 .32876 L
.052 .32393 L
.056 .31798 L
.06 .31268 L
.064 .31003 L
.068 .3112 L
.072 .31584 L
.076 .32209 L
.08 .32766 L
.084 .33094 L
.088 .33133 L
.092 .32821 L
.096 .32185 L
.1 .31434 L
.104 .30866 L
.108 .30646 L
.112 .30713 L
.116 .31 L
.12 .3147 L
.124 .32066 L
.128 .32631 L
.132 .32984 L
.136 .33079 L
.14 .33016 L
.144 .32953 L
.148 .32899 L
.152 .32767 L
.156 .32512 L
.16 .32191 L
.164 .31901 L
.168 .3168 L
.172 .31501 L
.176 .31293 L
.18 .31057 L
.184 .30869 L
.188 .30834 L
.192 .30999 L
.196 .31276 L
.2 .31498 L
Mistroke
.204 .31573 L
.208 .31594 L
.212 .31752 L
.216 .32124 L
.22 .32536 L
.224 .32693 L
.228 .32507 L
.232 .32246 L
.236 .32344 L
.24 .33019 L
.244 .34042 L
.248 .34902 L
.252 .35233 L
.256 .35081 L
.26 .34813 L
.264 .34779 L
.268 .35041 L
.272 .35394 L
.276 .35602 L
.28 .35576 L
.284 .35378 L
.288 .35095 L
.292 .34759 L
.296 .34399 L
.3 .34129 L
.304 .34132 L
.308 .34508 L
.312 .3513 L
.316 .35651 L
.32 .35713 L
.324 .3521 L
.328 .34405 L
.332 .33781 L
.336 .33751 L
.34 .34401 L
.344 .35454 L
.348 .36455 L
.352 .37039 L
.356 .37098 L
.36 .36757 L
.364 .36221 L
.368 .35603 L
.372 .34864 L
.376 .33888 L
.38 .3261 L
.384 .31113 L
.388 .29615 L
.392 .28363 L
.396 .27509 L
.4 .27025 L
Mistroke
.404 .2673 L
.408 .26389 L
.412 .25842 L
.416 .25086 L
.42 .24275 L
.424 .23638 L
.428 .23357 L
.432 .23469 L
.436 .23838 L
.44 .24206 L
.444 .2431 L
.448 .24001 L
.452 .23309 L
.456 .22438 L
.46 .21675 L
.464 .21273 L
.468 .21347 L
.472 .2184 L
.476 .22548 L
.48 .23206 L
.484 .23582 L
.488 .23547 L
.492 .23089 L
.496 .22301 L
.5 .21333 L
.504 .20346 L
.508 .19486 L
.512 .18866 L
.516 .18565 L
.52 .18626 L
.524 .1905 L
.528 .19799 L
.532 .20797 L
.536 .21942 L
.54 .23133 L
.544 .24281 L
.548 .25329 L
.552 .2625 L
.556 .27044 L
.56 .2772 L
.564 .28284 L
.568 .28736 L
.572 .29075 L
.576 .29309 L
.58 .29459 L
.584 .29556 L
.588 .29634 L
.592 .29711 L
.596 .29786 L
.6 .29847 L
Mistroke
.604 .29879 L
.608 .29882 L
.612 .29875 L
.616 .29877 L
.62 .29896 L
.624 .29923 L
.628 .29936 L
.632 .29924 L
.636 .29894 L
.64 .2987 L
.644 .29876 L
.648 .29913 L
.652 .29961 L
.656 .29989 L
.66 .29978 L
.664 .29937 L
.668 .29896 L
.672 .29884 L
.676 .29905 L
.68 .29939 L
.684 .29959 L
.688 .29952 L
.692 .2993 L
.696 .29916 L
.7 .29925 L
.704 .29946 L
.708 .29959 L
.712 .29949 L
.716 .29924 L
.72 .29904 L
.724 .29906 L
.728 .29928 L
.732 .2995 L
.736 .29953 L
.74 .29936 L
.744 .29916 L
.748 .29912 L
.752 .29929 L
.756 .29952 L
.76 .29956 L
.764 .29934 L
.768 .29901 L
.772 .29885 L
.776 .29901 L
.78 .29938 L
.784 .29966 L
.788 .29965 L
.792 .29936 L
.796 .29906 L
.8 .29895 L
Mistroke
.804 .29905 L
.808 .29923 L
.812 .29932 L
.816 .29928 L
.82 .29923 L
.824 .29926 L
.828 .29932 L
.832 .29932 L
.836 .29922 L
.84 .29906 L
.844 .29899 L
.848 .29908 L
.852 .29925 L
.856 .29936 L
.86 .29934 L
.864 .2992 L
.868 .29906 L
.872 .29904 L
.876 .29911 L
.88 .29921 L
.884 .29925 L
.888 .29918 L
.892 .2991 L
.896 .29908 L
.9 .29911 L
.904 .29917 L
.908 .2992 L
.912 .29915 L
.916 .29908 L
.92 .29905 L
.924 .29908 L
.928 .29914 L
.932 .29919 L
.936 .29914 L
.94 .29904 L
.944 .29902 L
.948 .29906 L
.952 .29911 L
.956 .29917 L
.96 .29912 L
.964 .29901 L
.968 .299 L
.972 .29904 L
.976 .29908 L
.98 .29913 L
.984 .29908 L
.988 .29898 L
.992 .29901 L
.996 .29907 L
1 .29908 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12177 m
.008 .11732 L
.012 .11588 L
.016 .11758 L
.02 .11834 L
.024 .11813 L
.028 .11804 L
.032 .11824 L
.036 .11821 L
.04 .11801 L
.044 .11776 L
.048 .11757 L
.052 .1174 L
.056 .11729 L
.06 .11725 L
.064 .11733 L
.068 .11747 L
.072 .11767 L
.076 .11783 L
.08 .11802 L
.084 .11818 L
.088 .11831 L
.092 .11831 L
.096 .11825 L
.1 .11813 L
.104 .11799 L
.108 .11774 L
.112 .1174 L
.116 .11708 L
.12 .11684 L
.124 .11671 L
.128 .11666 L
.132 .11669 L
.136 .1169 L
.14 .11732 L
.144 .11787 L
.148 .11839 L
.152 .11882 L
.156 .11914 L
.16 .1194 L
.164 .11953 L
.168 .11946 L
.172 .11913 L
.176 .11861 L
.18 .11804 L
.184 .11755 L
.188 .11713 L
.192 .11672 L
.196 .11624 L
.2 .11576 L
Mistroke
.204 .11543 L
.208 .11535 L
.212 .11545 L
.216 .11555 L
.22 .1155 L
.224 .11536 L
.228 .11539 L
.232 .11579 L
.236 .11655 L
.24 .11741 L
.244 .11815 L
.248 .11879 L
.252 .11961 L
.256 .12091 L
.26 .12277 L
.264 .12495 L
.268 .1271 L
.272 .12899 L
.276 .13062 L
.28 .1322 L
.284 .13392 L
.288 .13585 L
.292 .13798 L
.296 .14018 L
.3 .14234 L
.304 .14431 L
.308 .14601 L
.312 .1474 L
.316 .14865 L
.32 .15006 L
.324 .15198 L
.328 .15459 L
.332 .1578 L
.336 .16126 L
.34 .16452 L
.344 .16723 L
.348 .16931 L
.352 .1709 L
.356 .17223 L
.36 .17352 L
.364 .17486 L
.368 .17634 L
.372 .17805 L
.376 .18019 L
.38 .18299 L
.384 .18663 L
.388 .19112 L
.392 .19629 L
.396 .20188 L
.4 .2076 L
Mistroke
.404 .2133 L
.408 .219 L
.412 .22483 L
.416 .23092 L
.42 .23733 L
.424 .24396 L
.428 .25062 L
.432 .25708 L
.436 .26318 L
.44 .26893 L
.444 .27444 L
.448 .27993 L
.452 .28561 L
.456 .29162 L
.46 .29796 L
.464 .3045 L
.468 .31104 L
.472 .31737 L
.476 .32334 L
.48 .32891 L
.484 .33416 L
.488 .33927 L
.492 .34445 L
.496 .34992 L
.5 .35583 L
.504 .36226 L
.508 .36917 L
.512 .37645 L
.516 .38391 L
.52 .39135 L
.524 .39856 L
.528 .40535 L
.532 .41159 L
.536 .41717 L
.54 .42206 L
.544 .42626 L
.548 .42979 L
.552 .43273 L
.556 .43513 L
.56 .43708 L
.564 .43865 L
.568 .43991 L
.572 .44092 L
.576 .44174 L
.58 .44241 L
.584 .44296 L
.588 .44343 L
.592 .44382 L
.596 .44415 L
.6 .44443 L
Mistroke
.604 .44466 L
.608 .44487 L
.612 .44504 L
.616 .44519 L
.62 .44533 L
.624 .44545 L
.628 .44556 L
.632 .44566 L
.636 .44575 L
.64 .44583 L
.644 .44589 L
.648 .44595 L
.652 .446 L
.656 .44605 L
.66 .4461 L
.664 .44614 L
.668 .44618 L
.672 .44622 L
.676 .44625 L
.68 .44629 L
.684 .44633 L
.688 .44636 L
.692 .44639 L
.696 .44643 L
.7 .44645 L
.704 .44648 L
.708 .44651 L
.712 .44653 L
.716 .44656 L
.72 .44659 L
.724 .44662 L
.728 .44665 L
.732 .44668 L
.736 .44671 L
.74 .44674 L
.744 .44676 L
.748 .44679 L
.752 .44681 L
.756 .44684 L
.76 .44687 L
.764 .4469 L
.768 .44693 L
.772 .44696 L
.776 .44699 L
.78 .44701 L
.784 .44704 L
.788 .44707 L
.792 .44709 L
.796 .44712 L
.8 .44715 L
Mistroke
.804 .44718 L
.808 .44721 L
.812 .44724 L
.816 .44727 L
.82 .44729 L
.824 .44732 L
.828 .44734 L
.832 .44737 L
.836 .4474 L
.84 .44743 L
.844 .44745 L
.848 .44748 L
.852 .44751 L
.856 .44754 L
.86 .44757 L
.864 .4476 L
.868 .44762 L
.872 .44765 L
.876 .44767 L
.88 .4477 L
.884 .44773 L
.888 .44776 L
.892 .44779 L
.896 .44782 L
.9 .44784 L
.904 .44787 L
.908 .4479 L
.912 .44793 L
.916 .44795 L
.92 .44798 L
.924 .44801 L
.928 .44804 L
.932 .44806 L
.936 .4481 L
.94 .44812 L
.944 .44815 L
.948 .44817 L
.952 .44821 L
.956 .44823 L
.96 .44827 L
.964 .44828 L
.968 .44832 L
.972 .44833 L
.976 .44838 L
.98 .44839 L
.984 .44843 L
.988 .44844 L
.992 .44849 L
.996 .4485 L
1 .44855 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16302 L
.012 .16114 L
.016 .16059 L
.02 .16136 L
.024 .16141 L
.028 .1611 L
.032 .161 L
.036 .1611 L
.04 .16109 L
.044 .16106 L
.048 .16105 L
.052 .16108 L
.056 .16102 L
.06 .16096 L
.064 .16091 L
.068 .16093 L
.072 .16095 L
.076 .16102 L
.08 .16116 L
.084 .16139 L
.088 .16158 L
.092 .16168 L
.096 .16165 L
.1 .16155 L
.104 .16134 L
.108 .161 L
.112 .16052 L
.116 .16006 L
.12 .15975 L
.124 .15961 L
.128 .15959 L
.132 .15969 L
.136 .15999 L
.14 .16053 L
.144 .16119 L
.148 .1618 L
.152 .16226 L
.156 .1626 L
.16 .16285 L
.164 .16299 L
.168 .16289 L
.172 .16249 L
.176 .16186 L
.18 .16118 L
.184 .16058 L
.188 .16008 L
.192 .15956 L
.196 .15896 L
.2 .15836 L
Mistroke
.204 .15795 L
.208 .15784 L
.212 .15797 L
.216 .15807 L
.22 .15796 L
.224 .15773 L
.228 .15771 L
.232 .15817 L
.236 .1591 L
.24 .16019 L
.244 .16116 L
.248 .16202 L
.252 .1631 L
.256 .16475 L
.26 .16706 L
.264 .16972 L
.268 .17231 L
.272 .17457 L
.276 .17655 L
.28 .1785 L
.284 .18065 L
.288 .18311 L
.292 .18581 L
.296 .18858 L
.3 .19125 L
.304 .19368 L
.308 .19573 L
.312 .19742 L
.316 .19894 L
.32 .20069 L
.324 .20309 L
.328 .20636 L
.332 .21037 L
.336 .21466 L
.34 .21869 L
.344 .22202 L
.348 .22456 L
.352 .2265 L
.356 .22814 L
.36 .22974 L
.364 .23142 L
.368 .23327 L
.372 .2354 L
.376 .23804 L
.38 .2415 L
.384 .24599 L
.388 .25155 L
.392 .25797 L
.396 .26489 L
.4 .27199 L
Mistroke
.404 .27908 L
.408 .28615 L
.412 .29339 L
.416 .30096 L
.42 .30892 L
.424 .31716 L
.428 .32542 L
.432 .33343 L
.436 .34099 L
.44 .3481 L
.444 .35491 L
.448 .3617 L
.452 .36874 L
.456 .37619 L
.46 .38405 L
.464 .39216 L
.468 .40026 L
.472 .4081 L
.476 .41549 L
.48 .42238 L
.484 .42887 L
.488 .43518 L
.492 .44159 L
.496 .44834 L
.5 .45565 L
.504 .46359 L
.508 .47213 L
.512 .48113 L
.516 .49037 L
.52 .49959 L
.524 .50851 L
.528 .51692 L
.532 .52463 L
.536 .53152 L
.54 .53753 L
.544 .54268 L
.548 .547 L
.552 .55057 L
.556 .55348 L
.56 .55583 L
.564 .55771 L
.568 .55922 L
.572 .56042 L
.576 .56138 L
.58 .56214 L
.584 .56275 L
.588 .56323 L
.592 .56362 L
.596 .56395 L
.6 .56422 L
Mistroke
.604 .56444 L
.608 .56463 L
.612 .56478 L
.616 .5649 L
.62 .565 L
.624 .56507 L
.628 .56512 L
.632 .56516 L
.636 .56518 L
.64 .5652 L
.644 .56521 L
.648 .56521 L
.652 .5652 L
.656 .56518 L
.66 .56516 L
.664 .56514 L
.668 .56512 L
.672 .56509 L
.676 .56506 L
.68 .56502 L
.684 .56498 L
.688 .56494 L
.692 .5649 L
.696 .56486 L
.7 .56482 L
.704 .56479 L
.708 .56475 L
.712 .56471 L
.716 .56467 L
.72 .56462 L
.724 .56458 L
.728 .56453 L
.732 .56448 L
.736 .56444 L
.74 .5644 L
.744 .56436 L
.748 .56433 L
.752 .56429 L
.756 .56424 L
.76 .56419 L
.764 .56414 L
.768 .5641 L
.772 .56406 L
.776 .56402 L
.78 .56398 L
.784 .56393 L
.788 .56389 L
.792 .56385 L
.796 .5638 L
.8 .56376 L
Mistroke
.804 .56372 L
.808 .56368 L
.812 .56363 L
.816 .56359 L
.82 .56354 L
.824 .5635 L
.828 .56346 L
.832 .56342 L
.836 .56337 L
.84 .56333 L
.844 .56329 L
.848 .56325 L
.852 .5632 L
.856 .56316 L
.86 .56311 L
.864 .56307 L
.868 .56303 L
.872 .56299 L
.876 .56295 L
.88 .56291 L
.884 .56286 L
.888 .56281 L
.892 .56277 L
.896 .56273 L
.9 .56268 L
.904 .56264 L
.908 .56259 L
.912 .56256 L
.916 .56251 L
.92 .56247 L
.924 .56242 L
.928 .56239 L
.932 .56233 L
.936 .5623 L
.94 .56225 L
.944 .56221 L
.948 .56216 L
.952 .56213 L
.956 .56207 L
.96 .56205 L
.964 .56199 L
.968 .56196 L
.972 .5619 L
.976 .56187 L
.98 .56181 L
.984 .56179 L
.988 .56172 L
.992 .5617 L
.996 .56163 L
1 .56162 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
0080031oo`03001oogoo03Yoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0;goo0P00>goo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2000_Ool01000Oomoo`00>Woo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000eoo`<000Aoo`8000Moo`<000Ao
o`8000Aoo`<0009oo`03001oo`00008000=oo`<000Aoo`8000=oo`D000=oo`8000Aoo`8000Aoo`D0
009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`0;Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04
001oogoo0002Ool00`00Ool000030003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo009oo`06001oogoo001o
o`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00<0
07ooOol01@0000Aoo`00000000=oo`8000Ioo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00800005Ool00000Ool00005
Ool20006Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`00009oo`04001oogoo0002
Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00]oo`@000=oo`04001oogoo0007Ool0
0`00Oomoo`02Ool00`00Oomoo`0200001Goo001oogoo00001Goo00@007oo001oo`@000=oo`04001o
ogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01P00Oomoogoo
001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`8000aoo`03
001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`800004
Ool007oo0006Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomo
o`000goo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool50003Ool20008
Ool00`00Oomoo`03Ool20004Ool20006Ool00`00Ool000060003Ool20004Ool30004Ool20004Ool2
0005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo02=oo`03001oogoo00ioo`03001oogoo
03Eoo`008Woo0P0097oo00<007ooOol03goo1@0000=oo`000000;goo000ROomS000<Ool0029oo`D0
0005Ool00000001oo`030003Ool60002Ool01000Oomoo`000goo00D007ooOomoo`00009oo`8000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`0:
Ool0029oo`80009oo`80009oo`<00003Ool0000000<000Aoo`<000eoo`03001oogoo04Moo`008Woo
00D007ooOomoo`0000=oo`8000=oo`8000Uoo`03001oogoo00Eoo`8000=oo`03001oogoo04Moo`00
8Woo0P005Woo0`000Woo0P0000=oo`0000000Woo00<007ooOol0B7oo000ROol2000GOol40002Ool2
000017oo001oo`00BWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0O
Ool3001:Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P008Goo00<0
07ooOol0BGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007oo
Ool0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
17oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007oo
Ool00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;
Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
0`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo
00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo
1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2
000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20009Ool20005
Ool5001BOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo300000=oo`00
000010000goo1000Cgoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo
01Ioo`<004eoo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol067oo0`00Bgoo000X
Ool00`00Oomoo`0JOol2001:Ool002Qoo`03001oogoo01aoo`8004Qoo`002goo0P0017oo00<007oo
Ool00goo0P0017oo0P000goo0`000goo00<007ooOol07Woo0P00AWoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol0029oo`8004Aoo`000goo1@000Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol002=oo`03001oogoo
049oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00
2goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P00
17oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05
001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03
001oogoo009oo`04001oo`000002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo
00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo
0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomo
o`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00P0000Eoo`00
Oomoo`0000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool00`00Oomo
o`040002Ool01@00Oomoogoo00000goo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol0
0`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00D007ooOol007oo0080009o
o`03001oogoo008000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007oo
Ool02Goo1@000goo0P0027oo00<007ooOol00goo0P000goo0`0017oo00@007ooOomoo`D000=oo`80
00=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol09Woo00<0
07ooOol0?Goo000XOol00`00Oomoo`0WOol00`00Oomoo`0lOol002Qooed000aoo`00:7oo00<007oo
Ool03goo00<007ooOol047oo00<007ooOol00goo0P002Woo00<007ooOol03goo00<007ooOol047oo
00<007ooOol02Woo000XOol00`00Oomoo`0YOol00`00Oomoo`0jOol002Qoo`03001oogoo02Yoo`03
001oogoo03Uoo`00:7oo00<007ooOol0:Woo0P00>Woo000XOol00`00Oomoo`0[Ool00`00Oomoo`0h
Ool002Qoo`03001oogoo02aoo`03001oogoo03Moo`002goo0P0017oo00<007ooOol00goo0P0017oo
0P000goo0`000goo00<007ooOol0;7oo00<007ooOol0=goo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`000goo00@007ooOol002moo`03001oogoo03Ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol002moo`8003Moo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00;goo00<007ooOol0
=Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomo
o`0_Ool2000eOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool0
0`00Oomoo`0`Ool5000aOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo03AoobH0
00aoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
06Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool2
0004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=o
o`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo
00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00
Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007oo
Ool0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool0
1000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00
Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000
Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0
LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004
Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001o
ogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo
00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Ao
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo
Ool017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001o
ogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo
001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo
0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001o
ogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo
001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`80
00Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003
Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05
001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00H007ooOomoo`00Ool30003
Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol06Goo0`00EWoo000L
Ool2000LOol2001EOol001aoo`03001oogoo01eoo`8005=oo`0077oo00<007ooOol07goo0P00DGoo
000LOol2000QOol00`00Oomoo`1?Ool001aoo`03001oogoo025oo`8004moo`0077oo00<007ooOol0
8goo0P00CGoo000LOol2000UOol2001<Ool001aoo`03001oogoo02Eoo`8004]oo`0077oo0P009goo
00<007ooOol0BGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`0WOol00`00Oomo
o`18Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol09goo00<007ooOol0
B7oo000:Ool01000Oomoo`002goo00<007ooOol00P00:Goo00<007ooOol0Agoo000:Ool01000Oomo
o`002goo00@007ooOol002Yoo`03001oogoo04Moo`002Woo00@007ooOol000Moo`@000=oo`03001o
ogoo02Uoo`03001oogoo04Ioo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8002Yoo`03001o
ogoo04Ioo`002goo0P0027oo1@000Woo00<007ooOol0:Woo00<007ooOol0AGoo000LOol00`00Oomo
o`0ZOol00`00Oomoo`15Ool001aoo`8002aoo`03001oogoo04Aoo`0077oo00<007ooOol0;7oo00<0
07ooOol0@goo000LOol2000]Ool00`00Oomoo`13Ool001aoo`03001oogoo02eoo`03001oogoo049o
o`0077oo00<007ooOol0;Goo00<007ooOol0@Woo000LOol2000_Ool00`00Oomoo`11Ool001Ioo`<0
00=oo`03001oogoo02ioo`03001oogoo045oo`005goo00<007ooOol00Woo00<007ooOol0;Woo0P00
@Woo000GOol00`00Oomoo`02Ool2000`Ool00`00Oomoo`10Ool001Moo`03001oogoo009oo`03001o
ogoo031oo`03001oogoo03moo`005goo00<007ooOol00Woo00<007ooOol0<7oo00<007ooOol0?goo
000FOol20004Ool2000bOol00`00Oomoo`0nOol001Moo`03001oogoo009oo`03001oogoo035oo`80
03moo`0077oo00<007ooOol0<Woo00<007ooOol0?Goo000LOol2000dOol00`00Oomoo`0lOol001ao
o`03001oogoo03=oo`03001oogoo03aoo`0077oo0P00=7oo00<007ooOol0?7oo000LOol00`00Oomo
o`0dOol00`00Oomoo`0kOol001aoo`03001oogoo03Aoo`03001oogoo03]oo`002Woo0`0017oo00<0
07ooOol00Woo0`000goo0P00=Woo00<007ooOol0>Woo000;Ool00`00Oomoo`07Ool01@00Oomoogoo
00000Woo00<007ooOol0=Goo0P00>goo000;Ool00`00Oomoo`0;Ool01000Oomoo`00>7oo0`00>Goo
000;Ool00`00Oomoo`0;Ool00`00Oomoo`02000iOol^000<Ool000]oo`03001oogoo00Moo`@000=o
o`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomo
o`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(39913\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31647 m
.008 .31982 L
.012 .32439 L
.016 .32762 L
.02 .32938 L
.024 .32791 L
.028 .3234 L
.032 .31868 L
.036 .31476 L
.04 .3131 L
.044 .3137 L
.048 .31646 L
.052 .32055 L
.056 .32409 L
.06 .32584 L
.064 .32484 L
.068 .3218 L
.072 .31801 L
.076 .3146 L
.08 .31256 L
.084 .31287 L
.088 .31607 L
.092 .32101 L
.096 .32549 L
.1 .32822 L
.104 .32927 L
.108 .32864 L
.112 .32599 L
.116 .3216 L
.12 .31706 L
.124 .31393 L
.128 .31251 L
.132 .31202 L
.136 .31174 L
.14 .31227 L
.144 .31437 L
.148 .31777 L
.152 .32116 L
.156 .3238 L
.16 .32607 L
.164 .32838 L
.168 .33054 L
.172 .33154 L
.176 .33065 L
.18 .32811 L
.184 .32498 L
.188 .32213 L
.192 .31959 L
.196 .31668 L
.2 .31277 L
Mistroke
.204 .30847 L
.208 .30568 L
.212 .30624 L
.216 .31018 L
.22 .31518 L
.224 .31825 L
.228 .31831 L
.232 .31707 L
.236 .317 L
.24 .31878 L
.244 .32073 L
.248 .32091 L
.252 .31984 L
.256 .32055 L
.26 .32557 L
.264 .33406 L
.268 .34197 L
.272 .34524 L
.276 .34344 L
.28 .34014 L
.284 .3399 L
.288 .3446 L
.292 .35216 L
.296 .35843 L
.3 .36031 L
.304 .35745 L
.308 .35169 L
.312 .34547 L
.316 .34059 L
.32 .33819 L
.324 .33898 L
.328 .34306 L
.332 .34915 L
.336 .35453 L
.34 .35613 L
.344 .35248 L
.348 .345 L
.352 .33759 L
.356 .33434 L
.36 .33714 L
.364 .34463 L
.368 .35326 L
.372 .35973 L
.376 .36276 L
.38 .3634 L
.384 .36347 L
.388 .36371 L
.392 .36282 L
.396 .35823 L
.4 .34797 L
Mistroke
.404 .33222 L
.408 .31373 L
.412 .29647 L
.416 .28372 L
.42 .2764 L
.424 .27287 L
.428 .27001 L
.432 .26506 L
.436 .25702 L
.44 .24702 L
.444 .23761 L
.448 .2313 L
.452 .22939 L
.456 .23135 L
.46 .2352 L
.464 .23838 L
.468 .23882 L
.472 .23562 L
.476 .22927 L
.48 .22142 L
.484 .21418 L
.488 .20953 L
.492 .20863 L
.496 .21156 L
.5 .21726 L
.504 .22388 L
.508 .22923 L
.512 .23147 L
.516 .22954 L
.52 .22343 L
.524 .21414 L
.528 .20335 L
.532 .19298 L
.536 .18475 L
.54 .17984 L
.544 .17879 L
.548 .18152 L
.552 .18757 L
.556 .19626 L
.56 .20687 L
.564 .21865 L
.568 .23088 L
.572 .24279 L
.576 .25373 L
.58 .26321 L
.584 .27107 L
.588 .27741 L
.592 .28256 L
.596 .28678 L
.6 .2902 L
Mistroke
.604 .29279 L
.608 .29452 L
.612 .29554 L
.616 .29618 L
.62 .29679 L
.624 .29755 L
.628 .29837 L
.632 .29897 L
.636 .29914 L
.64 .29891 L
.644 .29854 L
.648 .29837 L
.652 .29855 L
.656 .29897 L
.66 .29935 L
.664 .29946 L
.668 .29932 L
.672 .29914 L
.676 .29912 L
.68 .29928 L
.684 .29945 L
.688 .29945 L
.692 .29927 L
.696 .29907 L
.7 .29906 L
.704 .29926 L
.708 .29953 L
.712 .29964 L
.716 .29952 L
.72 .29927 L
.724 .29912 L
.728 .2992 L
.732 .29943 L
.736 .29959 L
.74 .29952 L
.744 .29927 L
.748 .29904 L
.752 .29905 L
.756 .2993 L
.76 .29958 L
.764 .29967 L
.768 .29951 L
.772 .29924 L
.776 .29908 L
.78 .29912 L
.784 .29927 L
.788 .29937 L
.792 .29934 L
.796 .29928 L
.8 .29928 L
Mistroke
.804 .29937 L
.808 .29944 L
.812 .29939 L
.816 .29921 L
.82 .29906 L
.824 .29906 L
.828 .29921 L
.832 .2994 L
.836 .29947 L
.84 .29936 L
.844 .2992 L
.848 .29911 L
.852 .29914 L
.856 .29925 L
.86 .29933 L
.864 .29929 L
.868 .29919 L
.872 .29912 L
.876 .29913 L
.88 .29921 L
.884 .2993 L
.888 .29931 L
.892 .29924 L
.896 .29916 L
.9 .29911 L
.904 .29911 L
.908 .29915 L
.912 .29916 L
.916 .29917 L
.92 .29921 L
.924 .29926 L
.928 .29926 L
.932 .29922 L
.936 .29907 L
.94 .29895 L
.944 .29899 L
.948 .29912 L
.952 .29928 L
.956 .29936 L
.96 .29923 L
.964 .29903 L
.968 .29894 L
.972 .29898 L
.976 .2991 L
.98 .29922 L
.984 .2992 L
.988 .2991 L
.992 .29906 L
.996 .29907 L
1 .29907 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .11675 m
.008 .1188 L
.012 .11924 L
.016 .1182 L
.02 .11779 L
.024 .11793 L
.028 .11785 L
.032 .11774 L
.036 .11781 L
.04 .11804 L
.044 .11821 L
.048 .11839 L
.052 .11849 L
.056 .11856 L
.06 .1185 L
.064 .11841 L
.068 .11829 L
.072 .11817 L
.076 .11804 L
.08 .11796 L
.084 .11793 L
.088 .11797 L
.092 .118 L
.096 .11806 L
.1 .11817 L
.104 .11834 L
.108 .11849 L
.112 .11859 L
.116 .11866 L
.12 .11873 L
.124 .11873 L
.128 .11863 L
.132 .11837 L
.136 .11805 L
.14 .11776 L
.144 .11751 L
.148 .11727 L
.152 .11709 L
.156 .11706 L
.16 .11725 L
.164 .11764 L
.168 .11811 L
.172 .11856 L
.176 .11898 L
.18 .11938 L
.184 .11975 L
.188 .11998 L
.192 .11998 L
.196 .11972 L
.2 .1193 L
Mistroke
.204 .11886 L
.208 .11846 L
.212 .11806 L
.216 .11756 L
.22 .11695 L
.224 .11638 L
.228 .11604 L
.232 .11599 L
.236 .11607 L
.24 .11607 L
.244 .11588 L
.248 .11566 L
.252 .11568 L
.256 .11608 L
.26 .11674 L
.264 .11741 L
.268 .11793 L
.272 .11841 L
.276 .11917 L
.28 .12044 L
.284 .12222 L
.288 .12426 L
.292 .12626 L
.296 .12806 L
.3 .12969 L
.304 .13128 L
.308 .13299 L
.312 .13488 L
.316 .13698 L
.32 .13921 L
.324 .14146 L
.328 .14355 L
.332 .1453 L
.336 .14666 L
.34 .14779 L
.344 .14903 L
.348 .15076 L
.352 .15321 L
.356 .15629 L
.36 .1597 L
.364 .16298 L
.368 .16583 L
.372 .16813 L
.376 .16996 L
.38 .17151 L
.384 .1729 L
.388 .17422 L
.392 .17553 L
.396 .17696 L
.4 .17873 L
Mistroke
.404 .18112 L
.408 .18432 L
.412 .1884 L
.416 .19321 L
.42 .1985 L
.424 .20399 L
.428 .20952 L
.432 .21509 L
.436 .22081 L
.44 .2268 L
.444 .23314 L
.448 .23973 L
.452 .24641 L
.456 .25293 L
.46 .25913 L
.464 .26496 L
.468 .27052 L
.472 .276 L
.476 .28162 L
.48 .28753 L
.484 .29377 L
.488 .30027 L
.492 .30683 L
.496 .31325 L
.5 .31935 L
.504 .32507 L
.508 .33043 L
.512 .33556 L
.516 .34067 L
.52 .34597 L
.524 .35165 L
.528 .3578 L
.532 .36446 L
.536 .37155 L
.54 .37892 L
.544 .38638 L
.548 .39374 L
.552 .4008 L
.556 .40739 L
.56 .4134 L
.564 .41874 L
.568 .4234 L
.572 .42737 L
.576 .43071 L
.58 .43347 L
.584 .43574 L
.588 .43757 L
.592 .43906 L
.596 .44026 L
.6 .44123 L
Mistroke
.604 .44202 L
.608 .44267 L
.612 .4432 L
.616 .44364 L
.62 .44401 L
.624 .44432 L
.628 .44459 L
.632 .44482 L
.636 .44502 L
.64 .44519 L
.644 .44534 L
.648 .44548 L
.652 .44559 L
.656 .4457 L
.66 .44579 L
.664 .44588 L
.668 .44596 L
.672 .44602 L
.676 .44607 L
.68 .44612 L
.684 .44617 L
.688 .44622 L
.692 .44626 L
.696 .4463 L
.7 .44634 L
.704 .44638 L
.708 .44642 L
.712 .44645 L
.716 .44648 L
.72 .44651 L
.724 .44653 L
.728 .44656 L
.732 .44659 L
.736 .44662 L
.74 .44666 L
.744 .44669 L
.748 .44671 L
.752 .44674 L
.756 .44676 L
.76 .44679 L
.764 .44682 L
.768 .44685 L
.772 .44688 L
.776 .4469 L
.78 .44693 L
.784 .44696 L
.788 .44699 L
.792 .44702 L
.796 .44705 L
.8 .44707 L
Mistroke
.804 .4471 L
.808 .44713 L
.812 .44715 L
.816 .44718 L
.82 .44721 L
.824 .44724 L
.828 .44727 L
.832 .4473 L
.836 .44732 L
.84 .44735 L
.844 .44738 L
.848 .4474 L
.852 .44743 L
.856 .44746 L
.86 .44748 L
.864 .44752 L
.868 .44754 L
.872 .44757 L
.876 .4476 L
.88 .44763 L
.884 .44765 L
.888 .44768 L
.892 .4477 L
.896 .44774 L
.9 .44776 L
.904 .44779 L
.908 .44782 L
.912 .44785 L
.916 .44787 L
.92 .4479 L
.924 .44793 L
.928 .44796 L
.932 .44798 L
.936 .44802 L
.94 .44804 L
.944 .44807 L
.948 .44809 L
.952 .44813 L
.956 .44815 L
.96 .44818 L
.964 .4482 L
.968 .44824 L
.972 .44825 L
.976 .4483 L
.98 .44831 L
.984 .44836 L
.988 .44836 L
.992 .44841 L
.996 .44842 L
1 .44847 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16452 L
.012 .16114 L
.016 .15988 L
.02 .16095 L
.024 .16136 L
.028 .16107 L
.032 .16094 L
.036 .16113 L
.04 .1612 L
.044 .16123 L
.048 .16122 L
.052 .16128 L
.056 .16127 L
.06 .16124 L
.064 .16118 L
.068 .16114 L
.072 .16103 L
.076 .1609 L
.08 .16076 L
.084 .1607 L
.088 .16067 L
.092 .16068 L
.096 .16074 L
.1 .16091 L
.104 .16115 L
.108 .16141 L
.112 .16157 L
.116 .16166 L
.12 .1617 L
.124 .16167 L
.128 .16145 L
.132 .16107 L
.136 .16062 L
.14 .16023 L
.144 .15991 L
.148 .15964 L
.152 .15944 L
.156 .15943 L
.16 .15968 L
.164 .16018 L
.168 .16076 L
.172 .16132 L
.176 .16184 L
.18 .16234 L
.184 .16278 L
.188 .16306 L
.192 .16302 L
.196 .16266 L
.2 .16208 L
Mistroke
.204 .16147 L
.208 .16095 L
.212 .16044 L
.216 .15985 L
.22 .15915 L
.224 .1585 L
.228 .15813 L
.232 .15807 L
.236 .15815 L
.24 .15807 L
.244 .15775 L
.248 .15741 L
.252 .15739 L
.256 .15788 L
.26 .15874 L
.264 .15962 L
.268 .16031 L
.272 .16094 L
.276 .16187 L
.28 .16341 L
.284 .16558 L
.288 .16807 L
.292 .17055 L
.296 .1728 L
.3 .17484 L
.304 .17685 L
.308 .17898 L
.312 .18133 L
.316 .18391 L
.32 .18665 L
.324 .18941 L
.328 .19198 L
.332 .19414 L
.336 .19584 L
.34 .19726 L
.344 .19882 L
.348 .20098 L
.352 .20401 L
.356 .20783 L
.36 .21203 L
.364 .21609 L
.368 .21961 L
.372 .22245 L
.376 .22472 L
.38 .22663 L
.384 .22835 L
.388 .22998 L
.392 .23159 L
.396 .23336 L
.4 .23556 L
Mistroke
.404 .23851 L
.408 .24249 L
.412 .24754 L
.416 .2535 L
.42 .26005 L
.424 .26686 L
.428 .27373 L
.432 .28065 L
.436 .28775 L
.44 .2952 L
.444 .30306 L
.448 .31124 L
.452 .31952 L
.456 .32762 L
.46 .33531 L
.464 .34254 L
.468 .34943 L
.472 .35621 L
.476 .36316 L
.48 .37047 L
.484 .3782 L
.488 .38624 L
.492 .39437 L
.496 .40234 L
.5 .40991 L
.504 .41699 L
.508 .42362 L
.512 .42996 L
.516 .43626 L
.52 .4428 L
.524 .44981 L
.528 .45741 L
.532 .46564 L
.536 .47441 L
.54 .48354 L
.544 .4928 L
.548 .50192 L
.552 .51065 L
.556 .5188 L
.56 .5262 L
.564 .53277 L
.568 .53848 L
.572 .54336 L
.576 .54744 L
.58 .55082 L
.584 .55357 L
.588 .5558 L
.592 .55758 L
.596 .559 L
.6 .56013 L
Mistroke
.604 .56103 L
.608 .56175 L
.612 .56233 L
.616 .5628 L
.62 .56319 L
.624 .5635 L
.628 .56377 L
.632 .56398 L
.636 .56415 L
.64 .56429 L
.644 .5644 L
.648 .56449 L
.652 .56456 L
.656 .56461 L
.66 .56465 L
.664 .56467 L
.668 .56468 L
.672 .56468 L
.676 .56468 L
.68 .56468 L
.684 .56466 L
.688 .56465 L
.692 .56462 L
.696 .56459 L
.7 .56455 L
.704 .56452 L
.708 .56448 L
.712 .56444 L
.716 .56441 L
.72 .56437 L
.724 .56434 L
.728 .5643 L
.732 .56426 L
.736 .56421 L
.74 .56417 L
.744 .56412 L
.748 .56408 L
.752 .56404 L
.756 .564 L
.76 .56396 L
.764 .56392 L
.768 .56388 L
.772 .56383 L
.776 .56379 L
.78 .56374 L
.784 .5637 L
.788 .56365 L
.792 .56361 L
.796 .56357 L
.8 .56353 L
Mistroke
.804 .56349 L
.808 .56345 L
.812 .5634 L
.816 .56336 L
.82 .56331 L
.824 .56327 L
.828 .56323 L
.832 .56319 L
.836 .56314 L
.84 .5631 L
.844 .56305 L
.848 .56301 L
.852 .56297 L
.856 .56293 L
.86 .56288 L
.864 .56284 L
.868 .56279 L
.872 .56275 L
.876 .56271 L
.88 .56267 L
.884 .56262 L
.888 .56258 L
.892 .56254 L
.896 .5625 L
.9 .56245 L
.904 .56241 L
.908 .56236 L
.912 .56232 L
.916 .56228 L
.92 .56224 L
.924 .56219 L
.928 .56215 L
.932 .5621 L
.936 .56207 L
.94 .56202 L
.944 .56198 L
.948 .56193 L
.952 .5619 L
.956 .56184 L
.96 .56181 L
.964 .56175 L
.968 .56173 L
.972 .56167 L
.976 .56164 L
.98 .56158 L
.984 .56156 L
.988 .56149 L
.992 .56147 L
.996 .5614 L
1 .56139 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
0080039oo`<003Qoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0<Goo00<007oo0000>7oo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2000bOol00`00Ool0000hOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo
0P0017oo0P0000=oo`0000000Woo0`0000=oo`00Ool00`0017oo0P000goo1@000goo0P0017oo0P00
17oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol0
0Woo00@007ooOol0009oo`03001oogoo00800003Ool007oo0080009oo`8000=oo`04001oogoo0002
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02Ool01P00
Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
009oo`04001oogoo0002Ool50002Ool00`00Ool00002Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007oo000000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo
00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001o
ogoo00]oo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`04001oogooOol40003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002
Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:Ool2
0004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00D007oo
Ool007oo0080009oo`03001oogoo009oo`8000=oo`8000Eoo`04001oogoo0002Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo
0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`800004Ool00000Ool20006Ool0
1000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000R
Ool00`00Oomoo`0VOol00`00Oomoo`0>Ool00`00Oomoo`0bOol0029oo`8002Ioo`03001oogoo011o
o`<00003Ool0000002ioo`008WooH`0037oo000ROol200001Goo00000000Ool00`000Woo1@000Woo
1P000Woo00D007ooOomoo`0000=oo`04001oogooOol20002Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`04001oogoo0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol02Woo000ROol400001Goo00000000Ool0
0`000goo0P0000=oo`00000017oo0P003Woo00<007ooOol0A7oo000ROol00`00Oomoo`0>Ool00`00
Oomoo`06Ool00`00Oomoo`02Ool200000goo00000004Ool00`00Oomoo`14Ool0029oo`8001Qoo`<0
009oo`800004Ool007oo0002Ool00`00Oomoo`15Ool0029oo`8001]oo`80009oo`800005Ool007oo
Ool00017Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo029oo`8004Qo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03
001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=o
o`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2
001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomo
o`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]o
o`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`80
06eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogoo
Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0
009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo019oo`@0051oo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02OolE0003Ool4001=Ool0011oo`04001oogoo0008
Ool01000Oomoo`000Woo0P0017oo00<007ooOol067oo0`00Bgoo000AOol2000:Ool20004Ool00`00
Oomoo`02Ool00`00Oomoo`0JOol40018Ool002Qoo`03001oogoo01eoo`8004Moo`00:7oo00<007oo
Ool07Woo0P00AWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomo
o`0POol30013Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool0
1000Oomoo`0097oo0P00@Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0005Ool01000Oomoo`009Woo00<007ooOol0?goo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool2000017oo0000
07oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P00
1Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomo
o`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`05001oogoo001oo`02
0002Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool0
0`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00D007ooOol007oo
0080009oo`05001oogooOol00007Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo
0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo
0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@0
07ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool200000goo001oo`02Ool01000Oomoogoo
10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003
Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool0
1000Oomoo`001Woo0P0017oo00@007ooOol0009oo`@0009oo`8000=oo`03001oogoo00Aoo`06001o
ogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo0000
1Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P00
17oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=o
o`8000Ioo`00:7oo00<007ooOol0:Goo00<007ooOol0>Woo000XOol00`00Oomoo`0YOol2000kOol0
02Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol01Woo00<007ooOol0
1Woo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`0[Ool2000i
Ool002Qoo`03001oogoo02aoo`8003Qoo`00:7oo00<007ooOol0;Goo00<007ooOol0=Woo000XOol0
0`00Oomoo`0]Ool2000gOol002Qoo`03001oogoo02ioo`03001oogoo03Eoo`002goo0P0017oo00<0
07ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0;goo00<007ooOol0=7oo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol0035oo`8003Eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0039oo`03001o
ogoo03=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
0P00<Goo0P00=7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003
Ool00`00Oomoo`0aOol2000cOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0006Ool00`00Oomoo`0cOol5000^Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001o
ogoo03Moob<000aoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000A
Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomo
ogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
1Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:
Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool2
0004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo
000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo
00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool3
0003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`80
00eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009o
o`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001o
ogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@0
07ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@0
00=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool0
1P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Ao
o`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo
00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool0
1`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001o
ogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool3
0002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<
Ool001aoo`80009oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`<00003Ool007oo009oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo01ao
o`8005Aoo`0077oo0P007goo0P00DWoo000LOol00`00Oomoo`0POol2001@Ool001aoo`03001oogoo
029oo`03001oogoo04eoo`0077oo0P008goo0P00CWoo000LOol00`00Oomoo`0TOol2001<Ool001ao
o`03001oogoo02Ioo`8004Yoo`0077oo0P00:7oo0P00BGoo000LOol00`00Oomoo`0XOol20018Ool0
01aoo`8002Yoo`03001oogoo04Ioo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0
:Goo00<007ooOol0AWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo02Yo
o`03001oogoo04Eoo`002Woo00@007ooOol000]oo`03001oogoo008002aoo`03001oogoo04Aoo`00
2Woo00@007ooOol000]oo`04001oogoo000]Ool00`00Oomoo`14Ool000Yoo`04001oogoo0007Ool4
0003Ool00`00Oomoo`0/Ool00`00Oomoo`13Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2
000]Ool00`00Oomoo`13Ool000]oo`8000Qoo`D0009oo`03001oogoo02eoo`03001oogoo049oo`00
77oo00<007ooOol0;Goo00<007ooOol0@Woo000LOol2000_Ool00`00Oomoo`11Ool001aoo`03001o
ogoo02ioo`03001oogoo045oo`0077oo0P00<7oo00<007ooOol0@7oo000LOol00`00Oomoo`0_Ool0
0`00Oomoo`10Ool001aoo`03001oogoo031oo`03001oogoo03moo`0077oo0P00<Goo00<007ooOol0
?goo000FOol30003Ool00`00Oomoo`0aOol00`00Oomoo`0nOol001Moo`03001oogoo009oo`03001o
ogoo035oo`8003moo`005goo00<007ooOol00Woo0P00<goo00<007ooOol0?Goo000GOol00`00Oomo
o`02Ool00`00Oomoo`0cOol00`00Oomoo`0lOol001Moo`03001oogoo009oo`03001oogoo03=oo`03
001oogoo03aoo`005Woo0P0017oo0P00=Goo00<007ooOol0>goo000GOol00`00Oomoo`02Ool00`00
Oomoo`0dOol00`00Oomoo`0kOol001aoo`03001oogoo03Eoo`03001oogoo03Yoo`0077oo0P00=Woo
00<007ooOol0>Woo000LOol00`00Oomoo`0eOol2000kOol001aoo`8003Moo`03001oogoo03Uoo`00
77oo00<007ooOol0=goo00<007ooOol0>7oo000LOol00`00Oomoo`0gOol00`00Oomoo`0hOol000Yo
o`<000Aoo`03001oogoo009oo`<000=oo`8003Uoo`03001oogoo03Moo`002goo00<007ooOol01goo
00D007ooOomoo`00009oo`03001oogoo03Qoo`8003Qoo`002goo00<007ooOol02goo00@007ooOol0
03]oo`<003Ioo`002goo00<007ooOol02goo00<007ooOol00P00?Goo:P0037oo000;Ool00`00Oomo
o`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`00
2goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(40080\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3193 m
.008 .31565 L
.012 .31394 L
.016 .31426 L
.02 .31535 L
.024 .31839 L
.028 .32191 L
.032 .32355 L
.036 .3236 L
.04 .32169 L
.044 .31902 L
.048 .31621 L
.052 .31451 L
.056 .31516 L
.06 .31752 L
.064 .32098 L
.068 .32427 L
.072 .32669 L
.076 .3273 L
.08 .32532 L
.084 .32165 L
.088 .31785 L
.092 .3151 L
.096 .31344 L
.1 .31305 L
.104 .31447 L
.108 .31741 L
.112 .32059 L
.116 .32281 L
.12 .32405 L
.124 .32499 L
.128 .32583 L
.132 .32584 L
.136 .32448 L
.14 .32227 L
.144 .32034 L
.148 .31879 L
.152 .31692 L
.156 .31462 L
.16 .31281 L
.164 .31253 L
.168 .31371 L
.172 .31542 L
.176 .31691 L
.18 .31852 L
.184 .32122 L
.188 .32533 L
.192 .33 L
.196 .33356 L
.2 .3346 L
Mistroke
.204 .33275 L
.208 .32886 L
.212 .32414 L
.216 .31931 L
.22 .31455 L
.224 .3102 L
.228 .30756 L
.232 .30817 L
.236 .31202 L
.24 .31656 L
.244 .3183 L
.248 .31578 L
.252 .31135 L
.256 .30947 L
.26 .31275 L
.264 .31944 L
.268 .32494 L
.272 .32582 L
.276 .32281 L
.28 .32002 L
.284 .32112 L
.288 .32644 L
.292 .33317 L
.296 .33817 L
.3 .34054 L
.304 .34169 L
.308 .34342 L
.312 .3462 L
.316 .34913 L
.32 .3512 L
.324 .35224 L
.328 .35258 L
.332 .3521 L
.336 .34996 L
.34 .34561 L
.344 .3401 L
.348 .33615 L
.352 .33659 L
.356 .34202 L
.36 .3498 L
.364 .35536 L
.368 .355 L
.372 .34846 L
.376 .33915 L
.38 .33213 L
.384 .33108 L
.388 .33636 L
.392 .34523 L
.396 .35394 L
.4 .35991 L
Mistroke
.404 .36281 L
.408 .36385 L
.412 .36419 L
.416 .36355 L
.42 .36022 L
.424 .35223 L
.428 .33888 L
.432 .32163 L
.436 .3037 L
.44 .28851 L
.444 .27812 L
.448 .27222 L
.452 .26856 L
.456 .2642 L
.46 .25719 L
.464 .24752 L
.468 .23709 L
.472 .22864 L
.476 .22438 L
.48 .22484 L
.484 .22865 L
.488 .23313 L
.492 .23546 L
.496 .2338 L
.5 .228 L
.504 .21956 L
.508 .21094 L
.512 .20467 L
.516 .20244 L
.52 .20459 L
.524 .2101 L
.528 .21704 L
.532 .22317 L
.536 .22663 L
.54 .22628 L
.544 .22192 L
.548 .21411 L
.552 .20402 L
.556 .19319 L
.56 .18328 L
.564 .17585 L
.568 .17206 L
.572 .17245 L
.576 .17691 L
.58 .18472 L
.584 .1949 L
.588 .20648 L
.592 .21871 L
.596 .23106 L
.6 .24302 L
Mistroke
.604 .25407 L
.608 .26368 L
.612 .27153 L
.616 .27764 L
.62 .28238 L
.624 .28623 L
.628 .28953 L
.632 .29231 L
.636 .29445 L
.64 .29584 L
.644 .29658 L
.648 .29699 L
.652 .29739 L
.656 .29791 L
.66 .29843 L
.664 .29872 L
.668 .29872 L
.672 .29857 L
.676 .29853 L
.68 .29874 L
.684 .29911 L
.688 .29939 L
.692 .29942 L
.696 .29923 L
.7 .29904 L
.704 .29904 L
.708 .29923 L
.712 .29944 L
.716 .29947 L
.72 .29931 L
.724 .29911 L
.728 .29909 L
.732 .29931 L
.736 .29961 L
.74 .29975 L
.744 .2996 L
.748 .29928 L
.752 .29903 L
.756 .29904 L
.76 .29928 L
.764 .29953 L
.768 .2996 L
.772 .2995 L
.776 .29935 L
.78 .29929 L
.784 .29932 L
.788 .29936 L
.792 .29933 L
.796 .29926 L
.8 .29925 L
Mistroke
.804 .29934 L
.808 .29945 L
.812 .29948 L
.816 .29937 L
.82 .29923 L
.824 .29915 L
.828 .29922 L
.832 .29937 L
.836 .29947 L
.84 .29942 L
.844 .29927 L
.848 .29914 L
.852 .29912 L
.856 .29924 L
.86 .29938 L
.864 .29943 L
.868 .29937 L
.872 .29925 L
.876 .29917 L
.88 .29917 L
.884 .29922 L
.888 .29925 L
.892 .29926 L
.896 .29926 L
.9 .29926 L
.904 .29929 L
.908 .29929 L
.912 .29923 L
.916 .29915 L
.92 .29912 L
.924 .29916 L
.928 .29924 L
.932 .2993 L
.936 .29924 L
.94 .29916 L
.944 .29914 L
.948 .29918 L
.952 .29925 L
.956 .29927 L
.96 .29916 L
.964 .29905 L
.968 .29905 L
.972 .29914 L
.976 .29926 L
.98 .2993 L
.984 .29922 L
.988 .29908 L
.992 .29904 L
.996 .29909 L
1 .29913 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .11333 m
.008 .11832 L
.012 .12008 L
.016 .11872 L
.02 .11829 L
.024 .11897 L
.028 .11922 L
.032 .11905 L
.036 .11886 L
.04 .11877 L
.044 .11862 L
.048 .11848 L
.052 .11839 L
.056 .11841 L
.06 .11846 L
.064 .11858 L
.068 .11869 L
.072 .11882 L
.076 .11887 L
.08 .11889 L
.084 .11887 L
.088 .11884 L
.092 .11876 L
.096 .11866 L
.1 .11857 L
.104 .11852 L
.108 .11849 L
.112 .11845 L
.116 .11843 L
.12 .11849 L
.124 .11861 L
.128 .11875 L
.132 .11887 L
.136 .119 L
.14 .11914 L
.144 .11928 L
.148 .11929 L
.152 .11915 L
.156 .11892 L
.16 .11867 L
.164 .1184 L
.168 .11811 L
.172 .1178 L
.176 .11757 L
.18 .11752 L
.184 .11768 L
.188 .11798 L
.192 .11834 L
.196 .11871 L
.2 .11913 L
Mistroke
.204 .11961 L
.208 .12008 L
.212 .1204 L
.216 .12047 L
.22 .12029 L
.224 .11998 L
.228 .11965 L
.232 .11932 L
.236 .1189 L
.24 .1183 L
.244 .11761 L
.248 .11705 L
.252 .11677 L
.256 .11676 L
.26 .11678 L
.264 .11662 L
.268 .11628 L
.272 .11599 L
.276 .11601 L
.28 .11639 L
.284 .11696 L
.288 .11747 L
.292 .11783 L
.296 .11821 L
.3 .11889 L
.304 .12005 L
.308 .12167 L
.312 .12353 L
.316 .12541 L
.32 .12718 L
.324 .12883 L
.328 .13044 L
.332 .13212 L
.336 .13394 L
.34 .13598 L
.344 .13822 L
.348 .14054 L
.352 .14272 L
.356 .14455 L
.36 .14592 L
.364 .14699 L
.368 .14811 L
.372 .14968 L
.376 .15194 L
.38 .15484 L
.384 .15812 L
.388 .16138 L
.392 .16433 L
.396 .16684 L
.4 .16894 L
Mistroke
.404 .17072 L
.408 .17226 L
.412 .17361 L
.416 .17482 L
.42 .17603 L
.424 .1775 L
.428 .17951 L
.432 .1823 L
.436 .18595 L
.44 .19037 L
.444 .19532 L
.448 .20055 L
.452 .20589 L
.456 .2113 L
.46 .21689 L
.464 .22276 L
.468 .22899 L
.472 .23552 L
.476 .24218 L
.48 .24875 L
.484 .25505 L
.488 .26098 L
.492 .26661 L
.496 .2721 L
.5 .27767 L
.504 .28348 L
.508 .28961 L
.512 .29603 L
.516 .30259 L
.52 .30907 L
.524 .31531 L
.528 .32118 L
.532 .32668 L
.536 .33188 L
.54 .33697 L
.544 .34215 L
.548 .34761 L
.552 .35349 L
.556 .35988 L
.56 .36673 L
.564 .37395 L
.568 .38138 L
.572 .38883 L
.576 .39608 L
.58 .40298 L
.584 .40936 L
.588 .41513 L
.592 .42023 L
.596 .42464 L
.6 .4284 L
Mistroke
.604 .43156 L
.608 .43417 L
.612 .43632 L
.616 .43806 L
.62 .43947 L
.624 .44061 L
.628 .44154 L
.632 .44229 L
.636 .44291 L
.64 .44342 L
.644 .44385 L
.648 .4442 L
.652 .4445 L
.656 .44476 L
.66 .44498 L
.664 .44517 L
.668 .44534 L
.672 .44549 L
.676 .44562 L
.68 .44574 L
.684 .44584 L
.688 .44593 L
.692 .44601 L
.696 .44607 L
.7 .44613 L
.704 .44619 L
.708 .44624 L
.712 .44629 L
.716 .44635 L
.72 .44639 L
.724 .44643 L
.728 .44646 L
.732 .44649 L
.736 .44652 L
.74 .44656 L
.744 .44659 L
.748 .44662 L
.752 .44665 L
.756 .44668 L
.76 .44671 L
.764 .44674 L
.768 .44677 L
.772 .4468 L
.776 .44682 L
.78 .44685 L
.784 .44688 L
.788 .44691 L
.792 .44694 L
.796 .44697 L
.8 .44699 L
Mistroke
.804 .44702 L
.808 .44705 L
.812 .44708 L
.816 .44711 L
.82 .44713 L
.824 .44716 L
.828 .44718 L
.832 .44721 L
.836 .44724 L
.84 .44727 L
.844 .4473 L
.848 .44733 L
.852 .44735 L
.856 .44738 L
.86 .44741 L
.864 .44744 L
.868 .44746 L
.872 .44749 L
.876 .44752 L
.88 .44755 L
.884 .44757 L
.888 .4476 L
.892 .44763 L
.896 .44766 L
.9 .44768 L
.904 .44771 L
.908 .44774 L
.912 .44777 L
.916 .44779 L
.92 .44782 L
.924 .44785 L
.928 .44788 L
.932 .4479 L
.936 .44794 L
.94 .44796 L
.944 .44799 L
.948 .44801 L
.952 .44805 L
.956 .44806 L
.96 .4481 L
.964 .44812 L
.968 .44816 L
.972 .44817 L
.976 .44822 L
.98 .44823 L
.984 .44827 L
.988 .44828 L
.992 .44833 L
.996 .44833 L
1 .44839 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16006 L
.012 .16149 L
.016 .16177 L
.02 .1613 L
.024 .1612 L
.028 .16144 L
.032 .16137 L
.036 .16122 L
.04 .16109 L
.044 .16101 L
.048 .16088 L
.052 .16082 L
.056 .16077 L
.06 .16081 L
.064 .16087 L
.068 .16102 L
.072 .16115 L
.076 .16127 L
.08 .16132 L
.084 .16136 L
.088 .16133 L
.092 .16123 L
.096 .16106 L
.1 .16089 L
.104 .16075 L
.108 .16065 L
.112 .16056 L
.116 .16053 L
.12 .1606 L
.124 .16079 L
.128 .16099 L
.132 .16117 L
.136 .16134 L
.14 .16153 L
.144 .16168 L
.148 .16169 L
.152 .16151 L
.156 .16122 L
.16 .16089 L
.164 .16054 L
.168 .16013 L
.172 .1597 L
.176 .15937 L
.18 .15926 L
.184 .15944 L
.188 .15983 L
.192 .16031 L
.196 .16084 L
.2 .16141 L
Mistroke
.204 .16204 L
.208 .16262 L
.212 .16298 L
.216 .16299 L
.22 .16268 L
.224 .16223 L
.228 .16179 L
.232 .16139 L
.236 .1609 L
.24 .16021 L
.244 .15939 L
.248 .1587 L
.252 .15833 L
.256 .15827 L
.26 .15825 L
.264 .15802 L
.268 .15758 L
.272 .15722 L
.276 .15726 L
.28 .15776 L
.284 .15848 L
.288 .1591 L
.292 .15952 L
.296 .15995 L
.3 .16076 L
.304 .16219 L
.308 .16421 L
.312 .16654 L
.316 .1689 L
.32 .17111 L
.324 .17317 L
.328 .17517 L
.332 .17723 L
.336 .17947 L
.34 .18197 L
.344 .18474 L
.348 .18762 L
.352 .19033 L
.356 .1926 L
.36 .19431 L
.364 .19563 L
.368 .19702 L
.372 .19896 L
.376 .20176 L
.38 .20537 L
.384 .20943 L
.388 .21348 L
.392 .21712 L
.396 .22022 L
.4 .2228 L
Mistroke
.404 .225 L
.408 .22691 L
.412 .22857 L
.416 .23007 L
.42 .23157 L
.424 .23338 L
.428 .23585 L
.432 .23931 L
.436 .24384 L
.44 .24933 L
.444 .25548 L
.448 .26196 L
.452 .26858 L
.456 .27529 L
.46 .28221 L
.464 .2895 L
.468 .29723 L
.472 .30535 L
.476 .31363 L
.48 .3218 L
.484 .3296 L
.488 .33696 L
.492 .34392 L
.496 .35071 L
.5 .3576 L
.504 .36479 L
.508 .37239 L
.512 .38034 L
.516 .38847 L
.52 .39653 L
.524 .40426 L
.528 .41154 L
.532 .41833 L
.536 .42474 L
.54 .43101 L
.544 .43739 L
.548 .44414 L
.552 .45142 L
.556 .45933 L
.56 .46782 L
.564 .47677 L
.568 .48597 L
.572 .49518 L
.576 .50416 L
.58 .51267 L
.584 .52054 L
.588 .52765 L
.592 .53393 L
.596 .53936 L
.6 .54399 L
Mistroke
.604 .54785 L
.608 .55103 L
.612 .55363 L
.616 .55572 L
.62 .5574 L
.624 .55875 L
.628 .55983 L
.632 .56069 L
.636 .56137 L
.64 .56193 L
.644 .56237 L
.648 .56275 L
.652 .56305 L
.656 .5633 L
.66 .56351 L
.664 .56367 L
.668 .5638 L
.672 .5639 L
.676 .56398 L
.68 .56405 L
.684 .56409 L
.688 .56413 L
.692 .56415 L
.696 .56417 L
.7 .56417 L
.704 .56417 L
.708 .56416 L
.712 .56413 L
.716 .56411 L
.72 .56408 L
.724 .56405 L
.728 .56402 L
.732 .56399 L
.736 .56396 L
.74 .56392 L
.744 .56388 L
.748 .56384 L
.752 .5638 L
.756 .56376 L
.76 .56372 L
.764 .56368 L
.768 .56363 L
.772 .56359 L
.776 .56355 L
.78 .56351 L
.784 .56347 L
.788 .56343 L
.792 .56338 L
.796 .56334 L
.8 .5633 L
Mistroke
.804 .56325 L
.808 .56321 L
.812 .56316 L
.816 .56312 L
.82 .56308 L
.824 .56304 L
.828 .563 L
.832 .56296 L
.836 .56291 L
.84 .56286 L
.844 .56282 L
.848 .56278 L
.852 .56274 L
.856 .5627 L
.86 .56265 L
.864 .56261 L
.868 .56257 L
.872 .56252 L
.876 .56248 L
.88 .56244 L
.884 .56239 L
.888 .56235 L
.892 .56231 L
.896 .56227 L
.9 .56222 L
.904 .56218 L
.908 .56213 L
.912 .56209 L
.916 .56204 L
.92 .56201 L
.924 .56196 L
.928 .56192 L
.932 .56187 L
.936 .56184 L
.94 .56178 L
.944 .56175 L
.948 .5617 L
.952 .56166 L
.956 .56161 L
.96 .56158 L
.964 .56152 L
.968 .5615 L
.972 .56144 L
.976 .56141 L
.98 .56135 L
.984 .56133 L
.988 .56126 L
.992 .56124 L
.996 .56117 L
1 .56116 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02000eOol2000fOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008003Eoo`<003Eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0<goo00@007oo
Ool003Eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00<7oo0P000Woo00@007oo
Ool003Eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000=Ool30004
Ool20007Ool30004Ool20004Ool20004Ool50002Ool30004Ool20003Ool50003Ool20004Ool20004
Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol02goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00<007ooOol00P0000Aoo`00Oomoo`80009oo`05001oo`00Ool00002Ool0
1000Oomoo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOol0
07oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00<007ooOol010000Woo00<007ooOol00goo00<007oo00000Woo00@007ooOol0
00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool00`00Oomoo`04Ool20002Ool01000Oomoo`001Goo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00]oo`@000=oo`04001o
ogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo000000Eoo`04001oogooOol40003
Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00H0
07ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool2
000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oo`000004
Ool20003Ool01000Oomoo`000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`00
0Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`008Woo0P0037oo
1@000goo0P0027oo00<007ooOol00goo0P000goo0`001Woo00@007ooOomoo`D000=oo`8000Aoo`<0
00Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol0:7oo00<007ooOol0
3goo00<007ooOol0;goo000ROol2000YOol00`00Oomoo`0?Ool6000/Ool0029oof<000aoo`008Woo
0`0000Eoo`00000007oo00D0009oo`@00003Ool007oo00@00003Ool007oo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00002Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000aoo`008Woo0P0000Aoo`00001oo`<0009oo`@000=oo`04001oo`000004Ool3000=
Ool00`00Oomoo`12Ool0029oo`03001oogoo011oo`8000Qoo`03001oogoo009oo`03001oogoo0080
00=oo`03001oogoo049oo`008Woo0P006goo0`0000=oo`0000000P0000=oo`00Ool00Woo00<007oo
Ool0@Woo000ROol2000MOol20003Ool01P00Oomoo`00Ool004Eoo`002goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo00<007ooOol09Goo0P00AGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001o
ogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`00
27oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@0
07ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001o
ogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04
001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000R
Ool2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00
Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<0
07ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001o
ogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol05Goo0`00CWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009ooaT00003Ool00000008004]oo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool0
0`00Oomoo`0KOol30018Ool0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo01eoo`<0
04Ioo`00:7oo00<007ooOol07goo0P00AGoo000XOol00`00Oomoo`0QOol20013Ool000]oo`8000Ao
o`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo029oo`@0041oo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000WOol00`00Oomoo`0n
Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo
000XOol00`00Oomoo`0mOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000=oo`<000=oo`<000=oo`<000Aoo`80
009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04
001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo10000goo00D007ooOomoo`0000=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo
00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo000000=oo`03001oogoo00Eoo`04
001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool0
0`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`00
1Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0
009oo`03001oogoo00800003Ool0000000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eo
o`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0000Eoo`00001o
o`0000=oo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo
00<007ooOol0:goo0P00>Goo000XOol00`00Oomoo`0/Ool00`00Oomoo`0gOol002Qooed000aoo`00
:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol027oo00<007ooOol017oo00<007ooOol0
3goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`0^Ool00`00Oomoo`0eOol002Qo
o`03001oogoo02ioo`8003Ioo`00:7oo00<007ooOol0;goo0P00=Goo000XOol00`00Oomoo`0`Ool0
0`00Oomoo`0cOol002Qoo`03001oogoo035oo`03001oogoo039oo`002goo0P0017oo00<007ooOol0
0goo0P0017oo0P000goo0`000goo00<007ooOol0<Goo00<007ooOol0<Woo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol003Aoo`03001oogoo035oo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol003Aoo`80039o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00=7oo
00<007ooOol0<7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003
Ool00`00Oomoo`0dOol00`00Oomoo`0_Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0006Ool00`00Oomoo`0eOol5000/Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009o
o`03001oogoo03Uoob4000aoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0
IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogoo
Ool4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;
Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol0
0P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo
1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool2
0005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool0
01aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009o
o`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo1000
0goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Oomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001o
ogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03
001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yo
o`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool2
0006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000L
OomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`03001oogoo008000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001ao
o`03001oogoo01moo`80055oo`0077oo0P008Woo0P00Cgoo000LOol00`00Oomoo`0ROol3001=Ool0
01aoo`03001oogoo02Aoo`8004aoo`0077oo0P009Woo0P00Bgoo000LOol00`00Oomoo`0WOol20019
Ool001aoo`03001oogoo02Uoo`8004Moo`0077oo0P00:goo0P00AWoo000LOol00`00Oomoo`0[Ool0
0`00Oomoo`14Ool001aoo`8002eoo`03001oogoo04=oo`002goo0P0017oo00<007ooOol00Woo0`00
0goo00<007ooOol0;7oo00<007ooOol0@goo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo02eoo`03001oogoo049oo`002Woo00@007ooOol000]oo`03001oogoo008002ioo`80
04=oo`002Woo00@007ooOol000]oo`04001oogoo000`Ool00`00Oomoo`11Ool000Yoo`04001oogoo
0007Ool40003Ool00`00Oomoo`0^Ool00`00Oomoo`11Ool000Yoo`04001oogoo0007Ool00`00Oomo
o`04Ool2000`Ool00`00Oomoo`10Ool000]oo`8000Qoo`D0009oo`03001oogoo02moo`80045oo`00
77oo00<007ooOol0<7oo00<007ooOol0?goo000LOol2000aOol00`00Oomoo`0oOol001aoo`03001o
ogoo035oo`03001oogoo03ioo`0077oo0P00<goo00<007ooOol0?Goo000LOol00`00Oomoo`0bOol0
0`00Oomoo`0mOol001aoo`03001oogoo03=oo`03001oogoo03aoo`0077oo0P00=7oo00<007ooOol0
?7oo000FOol30003Ool00`00Oomoo`0dOol00`00Oomoo`0kOol001Moo`03001oogoo009oo`03001o
ogoo03Aoo`03001oogoo03]oo`005goo00<007ooOol00Woo0P00=Woo00<007ooOol0>Woo000GOol0
0`00Oomoo`02Ool00`00Oomoo`0eOol00`00Oomoo`0jOol001Moo`03001oogoo009oo`03001oogoo
03Ioo`03001oogoo03Uoo`005Woo0P0017oo0P00>7oo00<007ooOol0>7oo000GOol00`00Oomoo`02
Ool00`00Oomoo`0gOol00`00Oomoo`0hOol001aoo`03001oogoo03Qoo`03001oogoo03Moo`0077oo
0P00>Goo00<007ooOol0=goo000LOol00`00Oomoo`0hOol00`00Oomoo`0gOol001aoo`8003Yoo`03
001oogoo03Ioo`0077oo00<007ooOol0>Goo0P00=goo000LOol00`00Oomoo`0jOol00`00Oomoo`0e
Ool000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8003]oo`8003Ioo`002goo00<007ooOol01goo
00D007ooOomoo`00009oo`03001oogoo03]oo`8003Eoo`002goo00<007ooOol02goo00@007ooOol0
03ioo`<003=oo`002goo00<007ooOol02goo00<007ooOol00P00@7oo9`0037oo000;Ool00`00Oomo
o`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`00
2goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(40247\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32348 m
.008 .32639 L
.012 .32635 L
.016 .32255 L
.02 .31758 L
.024 .31372 L
.028 .31295 L
.032 .31483 L
.036 .31817 L
.04 .32295 L
.044 .32673 L
.048 .32829 L
.052 .32692 L
.056 .3232 L
.06 .3187 L
.064 .31415 L
.068 .31143 L
.072 .31145 L
.076 .31404 L
.08 .31792 L
.084 .32163 L
.088 .32481 L
.092 .32664 L
.096 .32651 L
.1 .32451 L
.104 .32179 L
.108 .31955 L
.112 .31791 L
.116 .3166 L
.12 .31571 L
.124 .31582 L
.128 .31715 L
.132 .31889 L
.136 .32011 L
.14 .32088 L
.144 .32191 L
.148 .32311 L
.152 .32359 L
.156 .32299 L
.16 .32219 L
.164 .3222 L
.168 .32298 L
.172 .32328 L
.176 .32195 L
.18 .31902 L
.184 .31553 L
.188 .31251 L
.192 .31049 L
.196 .30994 L
.2 .31144 L
Mistroke
.204 .31545 L
.208 .32166 L
.212 .32847 L
.216 .33347 L
.22 .33472 L
.224 .33214 L
.228 .32772 L
.232 .32424 L
.236 .323 L
.24 .32286 L
.244 .32153 L
.248 .31795 L
.252 .31351 L
.256 .31069 L
.26 .31051 L
.264 .31158 L
.268 .31183 L
.272 .31104 L
.276 .31123 L
.28 .31441 L
.284 .31983 L
.288 .32397 L
.292 .32365 L
.296 .31917 L
.3 .31462 L
.304 .31461 L
.308 .32048 L
.312 .32922 L
.316 .33609 L
.32 .33828 L
.324 .33676 L
.328 .33495 L
.332 .33582 L
.336 .33996 L
.34 .34578 L
.344 .35109 L
.348 .35435 L
.352 .35493 L
.356 .35264 L
.36 .34772 L
.364 .34128 L
.368 .33561 L
.372 .33344 L
.376 .33631 L
.38 .34319 L
.384 .35056 L
.388 .3543 L
.392 .35212 L
.396 .345 L
.4 .33659 L
Mistroke
.404 .33101 L
.408 .33054 L
.412 .33468 L
.416 .34106 L
.42 .3472 L
.424 .35203 L
.428 .35604 L
.432 .36015 L
.436 .36434 L
.44 .367 L
.444 .36561 L
.448 .35813 L
.452 .34444 L
.456 .32665 L
.46 .30833 L
.464 .2929 L
.468 .28209 L
.472 .27539 L
.476 .27055 L
.48 .26491 L
.484 .25679 L
.488 .24633 L
.492 .23531 L
.496 .22621 L
.5 .22107 L
.504 .22049 L
.508 .22344 L
.512 .22765 L
.516 .23053 L
.52 .23012 L
.524 .22575 L
.528 .21819 L
.532 .20938 L
.536 .20174 L
.54 .19741 L
.544 .19751 L
.548 .20183 L
.552 .20883 L
.556 .2162 L
.56 .22156 L
.564 .2232 L
.568 .22045 L
.572 .21371 L
.576 .20416 L
.58 .1933 L
.584 .18267 L
.588 .17366 L
.592 .16749 L
.596 .1651 L
.6 .16696 L
Mistroke
.604 .17296 L
.608 .18235 L
.612 .19398 L
.616 .20667 L
.62 .21947 L
.624 .23182 L
.628 .24344 L
.632 .25408 L
.636 .26347 L
.64 .27135 L
.644 .27766 L
.648 .28259 L
.652 .28649 L
.656 .28968 L
.66 .29228 L
.664 .29425 L
.668 .29554 L
.672 .29628 L
.676 .29676 L
.68 .29725 L
.684 .29782 L
.688 .29833 L
.692 .29861 L
.696 .29861 L
.7 .29851 L
.704 .29853 L
.708 .29879 L
.712 .29919 L
.716 .29946 L
.72 .29944 L
.724 .29917 L
.728 .2989 L
.732 .29887 L
.736 .29909 L
.74 .29941 L
.744 .29959 L
.748 .29955 L
.752 .29939 L
.756 .2993 L
.76 .29932 L
.764 .29939 L
.768 .29939 L
.772 .29931 L
.776 .29925 L
.78 .2993 L
.784 .29945 L
.788 .29959 L
.792 .29958 L
.796 .29942 L
.8 .29924 L
Mistroke
.804 .29918 L
.808 .29927 L
.812 .29943 L
.816 .2995 L
.82 .29946 L
.824 .29935 L
.828 .29928 L
.832 .2993 L
.836 .29937 L
.84 .29941 L
.844 .29939 L
.848 .29932 L
.852 .29927 L
.856 .29929 L
.86 .29935 L
.864 .29937 L
.868 .29935 L
.872 .2993 L
.876 .29927 L
.88 .29931 L
.884 .29935 L
.888 .29933 L
.892 .29928 L
.896 .29923 L
.9 .29923 L
.904 .29931 L
.908 .29937 L
.912 .29934 L
.916 .29925 L
.92 .29918 L
.924 .29917 L
.928 .29925 L
.932 .29934 L
.936 .29933 L
.94 .29927 L
.944 .2992 L
.948 .29917 L
.952 .2992 L
.956 .29924 L
.96 .29922 L
.964 .2992 L
.968 .29924 L
.972 .29928 L
.976 .29928 L
.98 .29922 L
.984 .2991 L
.988 .29903 L
.992 .29912 L
.996 .29926 L
1 .29933 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .1204 m
.008 .11924 L
.012 .11882 L
.016 .11927 L
.02 .1192 L
.024 .1189 L
.028 .11885 L
.032 .119 L
.036 .11907 L
.04 .11918 L
.044 .11928 L
.048 .1194 L
.052 .11943 L
.056 .11941 L
.06 .11932 L
.064 .11921 L
.068 .11908 L
.072 .11899 L
.076 .11892 L
.08 .11891 L
.084 .11894 L
.088 .11905 L
.092 .11914 L
.096 .11923 L
.1 .1193 L
.104 .11937 L
.108 .1194 L
.112 .11937 L
.116 .11928 L
.12 .1192 L
.124 .11912 L
.128 .11904 L
.132 .11893 L
.136 .11885 L
.14 .11884 L
.144 .11892 L
.148 .11902 L
.152 .11913 L
.156 .11927 L
.16 .11945 L
.164 .11965 L
.168 .11977 L
.172 .11976 L
.176 .11966 L
.18 .11951 L
.184 .11933 L
.188 .11908 L
.192 .11875 L
.196 .1184 L
.2 .11813 L
Mistroke
.204 .11803 L
.208 .1181 L
.212 .11827 L
.216 .11851 L
.22 .11884 L
.224 .11931 L
.228 .11988 L
.232 .12044 L
.236 .12081 L
.24 .12091 L
.244 .12078 L
.248 .12057 L
.252 .12037 L
.256 .12012 L
.26 .11968 L
.264 .11903 L
.268 .11833 L
.272 .11781 L
.276 .11759 L
.28 .11755 L
.284 .11745 L
.288 .11713 L
.292 .1167 L
.296 .1164 L
.3 .11644 L
.304 .11681 L
.308 .11727 L
.312 .11762 L
.316 .11784 L
.32 .11811 L
.324 .11868 L
.328 .1197 L
.332 .12115 L
.336 .12285 L
.34 .12464 L
.344 .12639 L
.348 .12806 L
.352 .12965 L
.356 .13125 L
.36 .13298 L
.364 .13495 L
.368 .1372 L
.372 .1396 L
.376 .14189 L
.38 .1438 L
.384 .14521 L
.388 .14625 L
.392 .14728 L
.396 .14869 L
.4 .15075 L
Mistroke
.404 .15346 L
.408 .15658 L
.412 .15978 L
.416 .16278 L
.42 .16546 L
.424 .16779 L
.428 .16982 L
.432 .17156 L
.436 .17301 L
.44 .1742 L
.444 .17527 L
.448 .17647 L
.452 .17814 L
.456 .18052 L
.46 .18376 L
.464 .18778 L
.468 .19238 L
.472 .19732 L
.476 .20243 L
.48 .20765 L
.484 .21306 L
.488 .21878 L
.492 .22488 L
.496 .23132 L
.5 .23795 L
.504 .24456 L
.508 .25094 L
.512 .25698 L
.516 .2627 L
.52 .26822 L
.524 .27374 L
.528 .27946 L
.532 .28548 L
.536 .29181 L
.54 .29833 L
.544 .30487 L
.548 .31122 L
.552 .31725 L
.556 .32289 L
.56 .3282 L
.564 .3333 L
.568 .33839 L
.572 .34368 L
.576 .34932 L
.58 .35544 L
.584 .36204 L
.588 .36907 L
.592 .3764 L
.596 .38386 L
.6 .39124 L
Mistroke
.604 .39836 L
.608 .40507 L
.612 .41122 L
.616 .41676 L
.62 .42162 L
.624 .42582 L
.628 .42939 L
.632 .43237 L
.636 .43484 L
.64 .43687 L
.644 .43852 L
.648 .43987 L
.652 .44095 L
.656 .44184 L
.66 .44255 L
.664 .44314 L
.668 .44363 L
.672 .44404 L
.676 .44438 L
.68 .44467 L
.684 .44492 L
.688 .44514 L
.692 .44533 L
.696 .4455 L
.7 .44564 L
.704 .44576 L
.708 .44587 L
.712 .44596 L
.716 .44605 L
.72 .44613 L
.724 .4462 L
.728 .44626 L
.732 .44632 L
.736 .44637 L
.74 .44642 L
.744 .44646 L
.748 .4465 L
.752 .44654 L
.756 .44657 L
.76 .44661 L
.764 .44664 L
.768 .44667 L
.772 .44671 L
.776 .44674 L
.78 .44677 L
.784 .4468 L
.788 .44683 L
.792 .44686 L
.796 .44688 L
.8 .44691 L
Mistroke
.804 .44694 L
.808 .44697 L
.812 .447 L
.816 .44703 L
.82 .44706 L
.824 .44708 L
.828 .44711 L
.832 .44713 L
.836 .44716 L
.84 .44719 L
.844 .44722 L
.848 .44725 L
.852 .44727 L
.856 .4473 L
.86 .44733 L
.864 .44736 L
.868 .44738 L
.872 .44741 L
.876 .44744 L
.88 .44747 L
.884 .44749 L
.888 .44752 L
.892 .44755 L
.896 .44758 L
.9 .4476 L
.904 .44763 L
.908 .44766 L
.912 .44769 L
.916 .44771 L
.92 .44775 L
.924 .44777 L
.928 .4478 L
.932 .44782 L
.936 .44786 L
.94 .44788 L
.944 .44791 L
.948 .44793 L
.952 .44797 L
.956 .44799 L
.96 .44802 L
.964 .44804 L
.968 .44808 L
.972 .44809 L
.976 .44814 L
.98 .44815 L
.984 .44819 L
.988 .4482 L
.992 .44825 L
.996 .44825 L
1 .44831 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15753 L
.012 .1611 L
.016 .16227 L
.02 .16106 L
.024 .16055 L
.028 .16092 L
.032 .16106 L
.036 .16102 L
.04 .16105 L
.044 .16124 L
.048 .16135 L
.052 .16145 L
.056 .16144 L
.06 .16139 L
.064 .16125 L
.068 .16109 L
.072 .16091 L
.076 .16077 L
.08 .16067 L
.084 .16067 L
.088 .16074 L
.092 .16088 L
.096 .161 L
.1 .16113 L
.104 .16123 L
.108 .1613 L
.112 .16127 L
.116 .16117 L
.12 .16104 L
.124 .16095 L
.128 .16082 L
.132 .16068 L
.136 .16056 L
.14 .16052 L
.144 .16058 L
.148 .16067 L
.152 .16076 L
.156 .16089 L
.16 .16111 L
.164 .16138 L
.168 .16158 L
.172 .16163 L
.176 .16154 L
.18 .16138 L
.184 .16113 L
.188 .16077 L
.192 .16028 L
.196 .15976 L
.2 .15937 L
Mistroke
.204 .15923 L
.208 .15934 L
.212 .1596 L
.216 .15995 L
.22 .1604 L
.224 .16097 L
.228 .16166 L
.232 .16231 L
.236 .16273 L
.24 .16281 L
.244 .16264 L
.248 .1624 L
.252 .16217 L
.256 .16186 L
.26 .16132 L
.264 .1605 L
.268 .15959 L
.272 .15891 L
.276 .1586 L
.28 .15853 L
.284 .15841 L
.288 .15803 L
.292 .1575 L
.296 .15715 L
.3 .15721 L
.304 .15765 L
.308 .15819 L
.312 .1586 L
.316 .15884 L
.32 .15915 L
.324 .15986 L
.328 .16114 L
.332 .16294 L
.336 .16507 L
.34 .1673 L
.344 .16947 L
.348 .17153 L
.352 .1735 L
.356 .17548 L
.36 .17762 L
.364 .18007 L
.368 .18285 L
.372 .18581 L
.376 .18865 L
.38 .19101 L
.384 .19276 L
.388 .19406 L
.392 .19533 L
.396 .19708 L
.4 .19964 L
Mistroke
.404 .20299 L
.408 .20685 L
.412 .21082 L
.416 .21455 L
.42 .21787 L
.424 .22075 L
.428 .22325 L
.432 .22539 L
.436 .22717 L
.44 .22863 L
.444 .22995 L
.448 .23145 L
.452 .23352 L
.456 .23648 L
.46 .24049 L
.464 .24547 L
.468 .25117 L
.472 .25729 L
.476 .26361 L
.48 .27009 L
.484 .27681 L
.488 .28391 L
.492 .29149 L
.496 .2995 L
.5 .30774 L
.504 .31595 L
.508 .32386 L
.512 .33133 L
.516 .3384 L
.52 .34523 L
.524 .35207 L
.528 .35915 L
.532 .36663 L
.536 .37448 L
.54 .38257 L
.544 .39067 L
.548 .39854 L
.552 .406 L
.556 .41297 L
.56 .41952 L
.564 .42582 L
.568 .43211 L
.572 .43864 L
.576 .44563 L
.58 .4532 L
.584 .46137 L
.588 .47007 L
.592 .47914 L
.596 .48836 L
.6 .4975 L
Mistroke
.604 .50631 L
.608 .51459 L
.612 .52219 L
.616 .52901 L
.62 .53499 L
.624 .54016 L
.628 .54453 L
.632 .54819 L
.636 .5512 L
.64 .55365 L
.644 .55563 L
.648 .55721 L
.652 .55849 L
.656 .55951 L
.66 .56032 L
.664 .56099 L
.668 .56152 L
.672 .56196 L
.676 .56232 L
.68 .56261 L
.684 .56284 L
.688 .56302 L
.692 .56317 L
.696 .56329 L
.7 .5634 L
.704 .56348 L
.708 .56355 L
.712 .56359 L
.716 .56362 L
.72 .56364 L
.724 .56364 L
.728 .56364 L
.732 .56364 L
.736 .56362 L
.74 .56361 L
.744 .56358 L
.748 .56355 L
.752 .56353 L
.756 .5635 L
.76 .56346 L
.764 .56343 L
.768 .56339 L
.772 .56335 L
.776 .56331 L
.78 .56327 L
.784 .56323 L
.788 .56319 L
.792 .56314 L
.796 .5631 L
.8 .56306 L
Mistroke
.804 .56302 L
.808 .56298 L
.812 .56294 L
.816 .56289 L
.82 .56285 L
.824 .5628 L
.828 .56276 L
.832 .56272 L
.836 .56268 L
.84 .56264 L
.844 .56259 L
.848 .56255 L
.852 .56251 L
.856 .56246 L
.86 .56242 L
.864 .56238 L
.868 .56233 L
.872 .56229 L
.876 .56225 L
.88 .56221 L
.884 .56216 L
.888 .56212 L
.892 .56207 L
.896 .56203 L
.9 .56199 L
.904 .56195 L
.908 .5619 L
.912 .56186 L
.916 .56181 L
.92 .56178 L
.924 .56173 L
.928 .56169 L
.932 .56164 L
.936 .5616 L
.94 .56155 L
.944 .56152 L
.948 .56147 L
.952 .56143 L
.956 .56138 L
.96 .56135 L
.964 .56129 L
.968 .56126 L
.972 .5612 L
.976 .56118 L
.98 .56111 L
.984 .56109 L
.988 .56103 L
.992 .56101 L
.996 .56094 L
1 .56093 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000>Goo00<007ooOol0<Woo000:Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool00`00Oomoo`02000gOol3000cOol000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`03001oogoo008003Moo`03001oo`0003=oo`002goo0P002Woo0P000goo0`000goo
00<007ooOol0=Woo00@007ooOol0039oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo
0P00<Woo0`0000=oo`00Ool00Woo00<007ooOol0<7oo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8000eoo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000Eoo`@00003Ool0
000000<000=oo`8000=oo`D000=oo`8000Aoo`8000Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@00
0Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomo
ogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01@00Oomoo`00Ool0
1@000Woo0P000goo0P0000Eoo`00Oomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol00Woo00@007ooOol0009oo`07001oogoo001oo`00Ool00`001goo0P0000Eo
o`00Oomoo`0000Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007oo
Ool0009oo`06001oogoo001oo`000goo00<007ooOol01Goo0P0000Eoo`00Oomoo`0000Eoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol017oo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;
Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo008000Ao
o`04001oogooOol40002Ool20002Ool01000Oomoo`000goo00@007ooOol0009oo`04001oogoo0002
Ool01@00Oomoogoo00000goo00<007oo00000`000goo00@007ooOol000Eoo`002goo0P002Woo0P00
17oo00<007ooOol00Woo0P0037oo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo
0002Ool00`00Oomoo`020003Ool20003Ool00`00Oomoo`03Ool20002Ool01000Oomoo`000goo00@0
07ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000goo00<007oo00001Woo00@007ooOol0
00Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo100017oo00@007ooOomo
o`D00003Ool00000008000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo
00<007ooOol0:goo00<007ooOol03Woo0P00;Woo000ROol2000[Ool00`00Oomoo`0@Ool6000YOol0
029oof<000aoo`008Woo00<007oo00000P0000Aoo`000000009oo`<0009oo`03001oo`00008000=o
o`@00004Ool000000003Ool01@00Oomoogoo00000goo00D007oo001oo`0000=oo`05001oogooOol0
0003Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`03001oogoo00Yoo`008Woo0`0000Eoo`00000007oo00@00003
Ool0000000<0009oo`D000=oo`@000eoo`03001oogoo03moo`008Woo00<007ooOol04Woo0P0027oo
0P000goo0P0000=oo`00000017oo00<007ooOol0?goo000ROol2000OOol00`00Ool00002000017oo
001oo`000Woo00<007ooOol0@7oo000ROol2000POol20002Ool00`00Oomoo`0200000goo001oo`11
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo02Qoo`03001oogoo045o
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03
001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=o
o`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2
001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomo
o`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]o
o`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`80
06eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogoo
Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0
009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo01Qoo`8004aoo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02OolK00000goo000000030018Ool0011oo`04001o
ogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol07Goo0`00AWoo000AOol2000:Ool20004
Ool00`00Oomoo`02Ool00`00Oomoo`0OOol30014Ool002Qoo`03001oogoo029oo`80049oo`00:7oo
00<007ooOol08goo0P00@Goo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool0
0`00Oomoo`0UOol3000nOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0003Ool01000Oomoo`00:Goo0P00?Goo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0005Ool01000Oomoo`00:Woo0P00?7oo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool30002
Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05
001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo
0080009oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00
Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`03
001oogoo0080009oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007oo
Ool0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;
Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`08001oogoo001oo`00Ool000Moo`04001oogoo0002
Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001o
ogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001o
ogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`@000=oo`06
001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo
00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol0
00Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006
Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004
Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo
0P001Woo000XOol00`00Oomoo`0^Ool00`00Oomoo`0eOol002Qoo`03001oogoo02ioo`03001oogoo
03Eoo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0;Ool01@00
Oomoogoo00004Goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`0`Ool2000dOol0
02Qoo`03001oogoo035oo`03001oogoo039oo`00:7oo00<007ooOol0<Woo00<007ooOol0<Goo000X
Ool00`00Oomoo`0cOol00`00Oomoo`0`Ool002Qoo`03001oogoo03=oo`03001oogoo031oo`002goo
0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0=7oo00<007ooOol0;goo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol003Io
o`03001oogoo02moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOol003Moo`03001oogoo02ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol00P00=Woo0P00;goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05
001oogoo001oo`040003Ool00`00Oomoo`0fOol2000^Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0gOol5000ZOol000]oo`8000Yoo`8000Aoo`80
009oo`D0009oo`03001oogoo03]ooal000aoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007oo
Ool0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo
00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol0
00Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`00
2goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004
Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004
Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001o
ogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`00
0goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03
001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo
0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo
00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Ao
o`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D0
00=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004
Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`06001oogooOol007oo0`0017oo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`00
77oo00<007ooOol08Woo0P00CWoo000LOol2000TOol2001=Ool001aoo`03001oogoo02Eoo`<004Yo
o`0077oo00<007ooOol09goo0P00BGoo000LOol2000YOol20018Ool001aoo`03001oogoo02Uoo`<0
04Ioo`0077oo00<007ooOol0;7oo0P00A7oo000LOol2000^Ool00`00Oomoo`12Ool001aoo`03001o
ogoo02ioo`03001oogoo045oo`0077oo0P00;goo00<007ooOol0@Goo000;Ool20004Ool00`00Oomo
o`02Ool30003Ool00`00Oomoo`0_Ool00`00Oomoo`10Ool000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0<7oo00<007ooOol0?goo000:Ool01000Oomoo`002goo00<007ooOol0
0P00<Goo00<007ooOol0?goo000:Ool01000Oomoo`002goo00@007ooOol0039oo`80041oo`002Woo
00@007ooOol000Moo`@000=oo`03001oogoo035oo`03001oogoo03ioo`002Woo00@007ooOol000Mo
o`03001oogoo00Aoo`8003=oo`03001oogoo03eoo`002goo0P0027oo1@000Woo00<007ooOol0<Woo
00<007ooOol0?Goo000LOol00`00Oomoo`0cOol00`00Oomoo`0lOol001aoo`8003Aoo`03001oogoo
03aoo`0077oo00<007ooOol0=7oo00<007ooOol0>goo000LOol2000eOol2000lOol001aoo`03001o
ogoo03Eoo`03001oogoo03Yoo`0077oo00<007ooOol0=Goo00<007ooOol0>Woo000LOol2000gOol0
0`00Oomoo`0iOol001Ioo`<000=oo`03001oogoo03Ioo`8003Yoo`005goo00<007ooOol00Woo00<0
07ooOol0=goo00<007ooOol0>7oo000GOol00`00Oomoo`02Ool2000iOol00`00Oomoo`0gOol001Mo
o`03001oogoo009oo`03001oogoo03Qoo`03001oogoo03Moo`005goo00<007ooOol00Woo00<007oo
Ool0>Goo00<007ooOol0=Woo000FOol20004Ool2000kOol00`00Oomoo`0eOol001Moo`03001oogoo
009oo`03001oogoo03Yoo`03001oogoo03Eoo`0077oo00<007ooOol0>Woo00<007ooOol0=Goo000L
Ool2000lOol00`00Oomoo`0dOol001aoo`03001oogoo03]oo`03001oogoo03Aoo`0077oo0P00?Goo
00<007ooOol0<goo000LOol00`00Oomoo`0lOol00`00Oomoo`0cOol001aoo`03001oogoo03aoo`80
03Aoo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00?Woo0P00<goo000;Ool00`00Oomoo`07
Ool01@00Oomoogoo00000Woo00<007ooOol0?Woo0P00<Woo000;Ool00`00Oomoo`0;Ool01000Oomo
o`00@Goo0`00<7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`020012OolU000<Ool000]oo`03001o
ogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo
000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(40414\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31086 m
.008 .31178 L
.012 .31493 L
.016 .32063 L
.02 .32595 L
.024 .329 L
.028 .32815 L
.032 .32453 L
.036 .3194 L
.04 .31408 L
.044 .31108 L
.048 .3107 L
.052 .31329 L
.056 .31799 L
.06 .32298 L
.064 .32685 L
.068 .32808 L
.072 .32717 L
.076 .32449 L
.08 .3206 L
.084 .31675 L
.088 .31404 L
.092 .31344 L
.096 .31441 L
.1 .31635 L
.104 .31894 L
.108 .32178 L
.112 .32428 L
.116 .32528 L
.12 .32451 L
.124 .32265 L
.128 .32069 L
.132 .31896 L
.136 .31738 L
.14 .31657 L
.144 .31733 L
.148 .31934 L
.152 .32106 L
.156 .32121 L
.16 .31999 L
.164 .31862 L
.168 .31806 L
.172 .31847 L
.176 .31971 L
.18 .32191 L
.184 .32498 L
.188 .32774 L
.192 .32837 L
.196 .32576 L
.2 .32065 L
Mistroke
.204 .31522 L
.208 .31166 L
.212 .31089 L
.216 .31224 L
.22 .31439 L
.224 .3164 L
.228 .31826 L
.232 .32044 L
.236 .32301 L
.24 .32542 L
.244 .32708 L
.248 .32822 L
.252 .32962 L
.256 .33134 L
.26 .33181 L
.264 .32879 L
.268 .32185 L
.272 .31372 L
.276 .30874 L
.28 .30934 L
.284 .31371 L
.288 .31722 L
.292 .31656 L
.296 .31262 L
.3 .30951 L
.304 .31069 L
.308 .3158 L
.312 .32108 L
.316 .32287 L
.32 .32075 L
.324 .31758 L
.328 .31682 L
.332 .31973 L
.336 .32479 L
.34 .32949 L
.344 .33243 L
.348 .33395 L
.352 .33517 L
.356 .33683 L
.36 .339 L
.364 .34164 L
.368 .34495 L
.372 .34891 L
.376 .35247 L
.38 .35358 L
.384 .35045 L
.388 .34331 L
.392 .33512 L
.396 .33021 L
.4 .33164 L
Mistroke
.404 .33894 L
.408 .34815 L
.412 .35404 L
.416 .35326 L
.42 .34623 L
.424 .3367 L
.428 .32934 L
.432 .32713 L
.436 .33004 L
.44 .3358 L
.444 .3418 L
.448 .34679 L
.452 .35119 L
.456 .35608 L
.46 .36169 L
.464 .36653 L
.468 .36783 L
.472 .36299 L
.476 .35119 L
.48 .33405 L
.484 .3151 L
.488 .29817 L
.492 .2857 L
.496 .27778 L
.5 .2724 L
.504 .26667 L
.508 .25842 L
.512 .2473 L
.516 .23492 L
.52 .22404 L
.524 .21717 L
.528 .21543 L
.532 .21802 L
.536 .22261 L
.54 .22633 L
.544 .22686 L
.548 .22328 L
.552 .21619 L
.556 .20736 L
.56 .19908 L
.564 .19344 L
.568 .19177 L
.572 .19435 L
.576 .20033 L
.58 .20794 L
.584 .21489 L
.588 .21899 L
.592 .21873 L
.596 .21377 L
.6 .20487 L
Mistroke
.604 .19366 L
.608 .18202 L
.612 .17168 L
.616 .16394 L
.62 .15965 L
.624 .15929 L
.628 .16298 L
.632 .17041 L
.636 .18086 L
.64 .19328 L
.644 .20653 L
.648 .21972 L
.652 .23229 L
.656 .24396 L
.66 .25454 L
.664 .26382 L
.668 .2716 L
.672 .27783 L
.676 .28269 L
.68 .28653 L
.684 .28965 L
.688 .29217 L
.692 .29409 L
.696 .29535 L
.7 .29609 L
.704 .29657 L
.708 .29704 L
.712 .29762 L
.716 .2982 L
.72 .2986 L
.724 .29874 L
.728 .2987 L
.732 .29866 L
.736 .29876 L
.74 .29896 L
.744 .29911 L
.748 .29915 L
.752 .29912 L
.756 .29913 L
.76 .29925 L
.764 .2994 L
.768 .29946 L
.772 .29939 L
.776 .29926 L
.78 .29922 L
.784 .29931 L
.788 .29946 L
.792 .29954 L
.796 .29948 L
.8 .29933 L
Mistroke
.804 .29925 L
.808 .29931 L
.812 .29947 L
.816 .29958 L
.82 .29956 L
.824 .29942 L
.828 .29927 L
.832 .29922 L
.836 .2993 L
.84 .29943 L
.844 .29951 L
.848 .29951 L
.852 .29944 L
.856 .29937 L
.86 .29933 L
.864 .29931 L
.868 .29929 L
.872 .2993 L
.876 .29934 L
.88 .29943 L
.884 .29949 L
.888 .29945 L
.892 .29934 L
.896 .29922 L
.9 .29919 L
.904 .29927 L
.908 .29939 L
.912 .29943 L
.916 .29939 L
.92 .2993 L
.924 .29924 L
.928 .29927 L
.932 .29932 L
.936 .29933 L
.94 .2993 L
.944 .29926 L
.948 .29926 L
.952 .29929 L
.956 .29931 L
.96 .29928 L
.964 .29925 L
.968 .29926 L
.972 .29929 L
.976 .29928 L
.98 .29925 L
.984 .29917 L
.988 .29915 L
.992 .29925 L
.996 .29934 L
1 .29935 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .1247 m
.008 .11962 L
.012 .11791 L
.016 .11966 L
.02 .12026 L
.024 .11977 L
.028 .11954 L
.032 .11971 L
.036 .11971 L
.04 .11959 L
.044 .11948 L
.048 .11945 L
.052 .11943 L
.056 .11947 L
.06 .11952 L
.064 .11963 L
.068 .11973 L
.072 .11985 L
.076 .1199 L
.08 .11991 L
.084 .11985 L
.088 .11977 L
.092 .11965 L
.096 .11952 L
.1 .1194 L
.104 .11936 L
.108 .11937 L
.112 .11943 L
.116 .1195 L
.12 .11962 L
.124 .11975 L
.128 .11987 L
.132 .11991 L
.136 .11988 L
.14 .11983 L
.144 .11977 L
.148 .11966 L
.152 .11952 L
.156 .11939 L
.16 .11933 L
.164 .11934 L
.168 .11938 L
.172 .11943 L
.176 .11951 L
.18 .11965 L
.184 .11985 L
.188 .12003 L
.192 .12015 L
.196 .12019 L
.2 .12019 L
Mistroke
.204 .12015 L
.208 .12003 L
.212 .11978 L
.216 .1194 L
.22 .119 L
.224 .11869 L
.228 .11854 L
.232 .11852 L
.236 .11858 L
.24 .11874 L
.244 .11904 L
.248 .11954 L
.252 .12016 L
.256 .12074 L
.26 .1211 L
.264 .12122 L
.268 .12119 L
.272 .12115 L
.276 .1211 L
.28 .12092 L
.284 .12045 L
.288 .11977 L
.292 .11907 L
.296 .1186 L
.3 .11841 L
.304 .11831 L
.308 .11808 L
.312 .11766 L
.316 .11719 L
.32 .11692 L
.324 .11697 L
.328 .11728 L
.332 .11761 L
.336 .11782 L
.34 .11792 L
.344 .1181 L
.348 .11857 L
.352 .11944 L
.356 .12071 L
.36 .12226 L
.364 .12396 L
.368 .12567 L
.372 .12732 L
.376 .12887 L
.38 .13039 L
.384 .13203 L
.388 .13394 L
.392 .13619 L
.396 .13864 L
.4 .14101 L
Mistroke
.404 .14301 L
.408 .14449 L
.412 .14555 L
.416 .14652 L
.42 .14781 L
.424 .14967 L
.428 .15215 L
.432 .15507 L
.436 .15817 L
.44 .16119 L
.444 .164 L
.448 .16655 L
.452 .16883 L
.456 .17078 L
.46 .17236 L
.464 .17359 L
.468 .17459 L
.472 .17561 L
.476 .17699 L
.48 .17901 L
.484 .18184 L
.488 .18545 L
.492 .18969 L
.496 .19431 L
.5 .19915 L
.504 .20415 L
.508 .20937 L
.512 .2149 L
.516 .22084 L
.52 .22716 L
.524 .23374 L
.528 .24037 L
.532 .24682 L
.536 .25296 L
.54 .25876 L
.544 .26432 L
.548 .26983 L
.552 .27547 L
.556 .28138 L
.56 .28761 L
.564 .29409 L
.568 .30064 L
.572 .30709 L
.576 .31326 L
.58 .31905 L
.584 .32448 L
.588 .32964 L
.592 .33471 L
.596 .33987 L
.6 .3453 L
Mistroke
.604 .35116 L
.608 .35749 L
.612 .36429 L
.616 .37146 L
.62 .37886 L
.624 .3863 L
.628 .3936 L
.632 .40057 L
.636 .40707 L
.64 .413 L
.644 .4183 L
.648 .42294 L
.652 .42693 L
.656 .43031 L
.66 .43314 L
.664 .43549 L
.668 .43741 L
.672 .43898 L
.676 .44025 L
.68 .44128 L
.684 .44211 L
.688 .4428 L
.692 .44337 L
.696 .44384 L
.7 .44424 L
.704 .44457 L
.708 .44485 L
.712 .44509 L
.716 .4453 L
.72 .44548 L
.724 .44564 L
.728 .44578 L
.732 .4459 L
.736 .446 L
.74 .4461 L
.744 .44618 L
.748 .44626 L
.752 .44632 L
.756 .44638 L
.76 .44644 L
.764 .44649 L
.768 .44654 L
.772 .44658 L
.776 .44662 L
.78 .44665 L
.784 .44669 L
.788 .44672 L
.792 .44676 L
.796 .44679 L
.8 .44683 L
Mistroke
.804 .44686 L
.808 .44688 L
.812 .44691 L
.816 .44694 L
.82 .44697 L
.824 .447 L
.828 .44703 L
.832 .44706 L
.836 .44708 L
.84 .44711 L
.844 .44714 L
.848 .44717 L
.852 .44719 L
.856 .44722 L
.86 .44725 L
.864 .44728 L
.868 .44731 L
.872 .44734 L
.876 .44736 L
.88 .44739 L
.884 .44741 L
.888 .44744 L
.892 .44747 L
.896 .4475 L
.9 .44752 L
.904 .44755 L
.908 .44758 L
.912 .44761 L
.916 .44763 L
.92 .44767 L
.924 .44769 L
.928 .44772 L
.932 .44774 L
.936 .44778 L
.94 .4478 L
.944 .44783 L
.948 .44785 L
.952 .44789 L
.956 .44791 L
.96 .44794 L
.964 .44796 L
.968 .448 L
.972 .44801 L
.976 .44806 L
.98 .44807 L
.984 .44811 L
.988 .44812 L
.992 .44817 L
.996 .44817 L
1 .44823 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16167 L
.012 .16101 L
.016 .16093 L
.02 .16134 L
.024 .16134 L
.028 .16126 L
.032 .16125 L
.036 .1613 L
.04 .16118 L
.044 .16104 L
.048 .16091 L
.052 .16084 L
.056 .1608 L
.06 .16085 L
.064 .16093 L
.068 .1611 L
.072 .16123 L
.076 .16136 L
.08 .16138 L
.084 .16134 L
.088 .16124 L
.092 .16109 L
.096 .16091 L
.1 .16076 L
.104 .16067 L
.108 .16068 L
.112 .16072 L
.116 .16079 L
.12 .16089 L
.124 .16103 L
.128 .16112 L
.132 .16116 L
.136 .16113 L
.14 .1611 L
.144 .16106 L
.148 .16099 L
.152 .16085 L
.156 .16069 L
.16 .16057 L
.164 .16053 L
.168 .1605 L
.172 .16049 L
.176 .16054 L
.18 .16072 L
.184 .161 L
.188 .16128 L
.192 .16147 L
.196 .16154 L
.2 .16153 L
Mistroke
.204 .16145 L
.208 .16125 L
.212 .16089 L
.216 .1604 L
.22 .15989 L
.224 .15952 L
.228 .15935 L
.232 .15933 L
.236 .15941 L
.24 .15958 L
.244 .15993 L
.248 .16052 L
.252 .16127 L
.256 .16197 L
.26 .16243 L
.264 .16258 L
.268 .16257 L
.272 .16253 L
.276 .16248 L
.28 .16222 L
.284 .16162 L
.288 .16072 L
.292 .15983 L
.296 .15922 L
.3 .15897 L
.304 .15886 L
.308 .15859 L
.312 .15806 L
.316 .15747 L
.32 .15712 L
.324 .15718 L
.328 .15755 L
.332 .15795 L
.336 .1582 L
.34 .15832 L
.344 .15853 L
.348 .15909 L
.352 .16017 L
.356 .16173 L
.36 .16366 L
.364 .16578 L
.368 .16792 L
.372 .16996 L
.376 .17188 L
.38 .17376 L
.384 .17578 L
.388 .17816 L
.392 .18094 L
.396 .18399 L
.4 .18693 L
Mistroke
.404 .18941 L
.408 .19122 L
.412 .19252 L
.416 .19373 L
.42 .19532 L
.424 .19764 L
.428 .20073 L
.432 .20436 L
.436 .20819 L
.44 .21193 L
.444 .2154 L
.448 .21855 L
.452 .22136 L
.456 .22377 L
.46 .22573 L
.464 .22725 L
.468 .22849 L
.472 .22975 L
.476 .23145 L
.48 .23395 L
.484 .23745 L
.488 .24191 L
.492 .24715 L
.496 .25288 L
.5 .25889 L
.504 .2651 L
.508 .27158 L
.512 .27847 L
.516 .28585 L
.52 .2937 L
.524 .30186 L
.528 .31008 L
.532 .31807 L
.536 .32568 L
.54 .33286 L
.544 .33976 L
.548 .34658 L
.552 .35358 L
.556 .36091 L
.56 .36864 L
.564 .37666 L
.568 .38477 L
.572 .39275 L
.576 .40039 L
.58 .40757 L
.584 .41428 L
.588 .42066 L
.592 .42691 L
.596 .43327 L
.6 .44 L
Mistroke
.604 .44724 L
.608 .45509 L
.612 .46351 L
.616 .47238 L
.62 .48153 L
.624 .49073 L
.628 .49975 L
.632 .50837 L
.636 .51641 L
.64 .52373 L
.644 .53027 L
.648 .53598 L
.652 .54088 L
.656 .54503 L
.66 .54848 L
.664 .55131 L
.668 .55362 L
.672 .55549 L
.676 .557 L
.68 .55822 L
.684 .55919 L
.688 .55998 L
.692 .56061 L
.696 .56111 L
.7 .56152 L
.704 .56186 L
.708 .56214 L
.712 .56236 L
.716 .56254 L
.72 .56269 L
.724 .56281 L
.728 .5629 L
.732 .56298 L
.736 .56304 L
.74 .56308 L
.744 .5631 L
.748 .56312 L
.752 .56312 L
.756 .56312 L
.76 .56311 L
.764 .5631 L
.768 .56308 L
.772 .56306 L
.776 .56303 L
.78 .563 L
.784 .56297 L
.788 .56293 L
.792 .56289 L
.796 .56285 L
.8 .56281 L
Mistroke
.804 .56278 L
.808 .56274 L
.812 .5627 L
.816 .56266 L
.82 .56261 L
.824 .56257 L
.828 .56253 L
.832 .56249 L
.836 .56245 L
.84 .5624 L
.844 .56236 L
.848 .56232 L
.852 .56227 L
.856 .56223 L
.86 .56219 L
.864 .56215 L
.868 .5621 L
.872 .56206 L
.876 .56202 L
.88 .56198 L
.884 .56193 L
.888 .56189 L
.892 .56184 L
.896 .5618 L
.9 .56176 L
.904 .56172 L
.908 .56167 L
.912 .56163 L
.916 .56158 L
.92 .56155 L
.924 .56149 L
.928 .56146 L
.932 .56141 L
.936 .56137 L
.94 .56132 L
.944 .56129 L
.948 .56124 L
.952 .5612 L
.956 .56115 L
.96 .56112 L
.964 .56106 L
.968 .56103 L
.972 .56097 L
.976 .56095 L
.98 .56089 L
.984 .56087 L
.988 .5608 L
.992 .56078 L
.996 .56071 L
1 .56069 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000>goo0P00<Goo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`02000jOol00`00Ool0000`Ool000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`03001oogoo008003Uoo`04001oogoo000`Ool000]oo`8000Yoo`8000=oo`<000=o
o`03001oogoo03Aoo`80009oo`04001oogoo000`Ool000]oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`8003Eoo`80009oo`04001oogoo000`Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo10000Woo0`00
0goo0`000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002
Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0004Ool400001Woo
00000000Ool0009oo`04001oogoo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0004Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001goo00<007ooOol0
0P0000=oo`00Ool00goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Moo`03001oogoo00800003Ool007oo00Aoo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol017oo00@007ooOol0
009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomo
o`0;Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool00`00Ool00003Ool40003Ool200001Goo001oogoo00000goo00@007ooOol0009oo`04001oogoo
0002Ool01@00Oomoogoo00000goo00<007oo00000`000goo00@007ooOol000Eoo`002goo0P002Woo
0P0017oo00<007ooOol00Woo0P0037oo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001o
ogoo0002Ool01000Oomoo`000Woo10000goo00<007ooOol017oo00@007oo0000009oo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007oo
Ool000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P000Woo0P000Woo
00@007ooOomoo`D000=oo`<000=oo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`00
8Woo00<007ooOol0;Goo00<007ooOol03goo00<007ooOol0:Woo000ROol2000^Ool00`00Oomoo`0@
Ool6000VOol0029oof<000aoo`008Woo0P000Woo0`0000Eoo`00000007oo00<00003Ool00000009o
o`<00004Ool007ooOol60002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`03001oogoo00Yoo`008Woo1@0000Aoo`000000009oo`<0
0003Ool0000000@0009oo`800003Ool007oo00=oo`<000Qoo`03001oogoo009oo`03001oogoo03eo
o`008Woo00<007ooOol05Woo00<007ooOol01Woo0P000Woo100000=oo`00Ool00Woo00<007ooOol0
?Goo000ROol2000ROol01000Ool007oo0P0000=oo`0000000Woo00<007ooOol0?Goo000ROol2000S
Ool200000goo00000002Ool200000goo001oo`0nOol000]oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`03001oogoo02Yoo`80041oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool0
0`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
0`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^
Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0
00=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00
KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo
000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006ao
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo
0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol0
00]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02OolS0016Ool0011o
o`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol07goo0`00A7oo000AOol2000:
Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0QOol40011Ool002Qoo`03001oogoo02Aoo`80041o
o`00:7oo00<007ooOol09Goo0`00?Woo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool3
0003Ool00`00Oomoo`0WOol3000lOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007oo
Ool007oo0003Ool01000Oomoo`00;7oo00<007ooOol0>Goo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00;7oo0P00>Woo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004
Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004
Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03
001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0002Ool20003Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogoo001oo`000goo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Io
o`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@0
07ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo
000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool20006Ool01000Oomoo`00
0Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000
Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool20002Ool40003Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
o`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo
0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`800004Ool007oo0006Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Io
o`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Ao
o`8000Aoo`03001oo`0000H000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`80
00Ioo`00:7oo00<007ooOol0<7oo00<007ooOol0<goo000XOol00`00Oomoo`0aOol00`00Oomoo`0b
Ool002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03Goo00<007oo
00004Goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`0cOol00`00Oomoo`0`Ool0
02Qoo`03001oogoo03Aoo`03001oogoo02moo`00:7oo00<007ooOol0=7oo00<007ooOol0;goo000X
Ool00`00Oomoo`0eOol00`00Oomoo`0^Ool002Qoo`03001oogoo03Eoo`8002moo`002goo0P0017oo
00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0=Woo00<007ooOol0;Goo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol003Uoo`03001o
ogoo02aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0
03Uoo`03001oogoo02aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol00P00>Goo00<007ooOol0:goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05
001oogoo001oo`040003Ool00`00Oomoo`0hOol2000/Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0jOol4000XOol000]oo`8000Yoo`8000Aoo`80
009oo`D0009oo`03001oogoo03iooa`000aoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007oo
Ool0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo
00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol0
00Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`00
2goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004
Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004
Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001o
ogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`00
0goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03
001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo
0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo
00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Ao
o`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D0
00=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004
Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool30002Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo
000LOol00`00Oomoo`0TOol3001;Ool001aoo`8002Moo`8004Yoo`0077oo00<007ooOol0:7oo0P00
B7oo000LOol00`00Oomoo`0ZOol00`00Oomoo`15Ool001aoo`8002aoo`8004Eoo`0077oo00<007oo
Ool0;7oo0`00@goo000LOol00`00Oomoo`0^Ool20012Ool001aoo`80035oo`03001oogoo03moo`00
77oo00<007ooOol0<7oo0P00@7oo000LOol2000bOol00`00Oomoo`0nOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`03001oogoo039oo`03001oogoo03eoo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`0cOol00`00Oomoo`0lOol000Yoo`04001oogoo000;Ool00`00Oomo
o`02000dOol00`00Oomoo`0lOol000Yoo`04001oogoo000;Ool01000Oomoo`00=Goo00<007ooOol0
?7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0=7oo00<007ooOol0>goo000:Ool01000
Oomoo`001goo00<007ooOol017oo0P00=Woo00<007ooOol0>Woo000;Ool20008Ool50002Ool00`00
Oomoo`0eOol00`00Oomoo`0jOol001aoo`03001oogoo03Eoo`8003]oo`0077oo0P00=goo00<007oo
Ool0>Goo000LOol00`00Oomoo`0gOol00`00Oomoo`0hOol001aoo`8003Qoo`03001oogoo03Qoo`00
77oo00<007ooOol0>7oo00<007ooOol0=goo000LOol00`00Oomoo`0hOol00`00Oomoo`0gOol001ao
o`8003Yoo`03001oogoo03Ioo`005Woo0`000goo00<007ooOol0>Goo0P00=goo000GOol00`00Oomo
o`02Ool00`00Oomoo`0jOol00`00Oomoo`0eOol001Moo`03001oogoo009oo`8003]oo`8003Ioo`00
5goo00<007ooOol00Woo00<007ooOol0>goo00<007ooOol0=7oo000GOol00`00Oomoo`02Ool00`00
Oomoo`0lOol00`00Oomoo`0cOol001Ioo`8000Aoo`8003eoo`03001oogoo03=oo`005goo00<007oo
Ool00Woo00<007ooOol0?7oo0P00=7oo000LOol00`00Oomoo`0mOol00`00Oomoo`0bOol001aoo`80
03moo`03001oogoo035oo`0077oo00<007ooOol0?Woo00<007ooOol0<Goo000LOol20010Ool00`00
Oomoo`0`Ool001aoo`03001oogoo03moo`03001oogoo031oo`0077oo00<007ooOol0?goo0P00<Goo
000:Ool30004Ool00`00Oomoo`02Ool30003Ool20011Ool00`00Oomoo`0_Ool000]oo`03001oogoo
00Moo`05001oogooOol00002Ool00`00Oomoo`11Ool00`00Oomoo`0^Ool000]oo`03001oogoo00]o
o`04001oogoo0014Ool3000]Ool000]oo`03001oogoo00]oo`03001oogoo008004Ioob4000aoo`00
2goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00
Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol0
0`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(40581\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32977 m
.008 .3266 L
.012 .3212 L
.016 .31625 L
.02 .31351 L
.024 .31205 L
.028 .31292 L
.032 .31584 L
.036 .32013 L
.04 .32413 L
.044 .32628 L
.048 .32658 L
.052 .32458 L
.056 .32143 L
.06 .31807 L
.064 .31506 L
.068 .31354 L
.072 .31375 L
.076 .31596 L
.08 .31919 L
.084 .32233 L
.088 .32494 L
.092 .32616 L
.096 .32571 L
.1 .32328 L
.104 .31969 L
.108 .31648 L
.112 .31465 L
.116 .31461 L
.12 .31589 L
.124 .31828 L
.128 .32129 L
.132 .32357 L
.136 .32392 L
.14 .32235 L
.144 .32042 L
.148 .3194 L
.152 .31942 L
.156 .31998 L
.16 .32075 L
.164 .32158 L
.168 .32189 L
.172 .32078 L
.176 .31817 L
.18 .31545 L
.184 .3146 L
.188 .31635 L
.192 .31969 L
.196 .32286 L
.2 .32476 L
Mistroke
.204 .32529 L
.208 .32486 L
.212 .32377 L
.216 .32226 L
.22 .32076 L
.224 .31981 L
.228 .31959 L
.232 .31954 L
.236 .31856 L
.24 .31594 L
.244 .31236 L
.248 .30997 L
.252 .31103 L
.256 .31602 L
.26 .32284 L
.264 .32815 L
.268 .33002 L
.272 .32929 L
.276 .3284 L
.28 .32869 L
.284 .32906 L
.288 .32733 L
.292 .32296 L
.296 .31798 L
.3 .31519 L
.304 .31528 L
.308 .31611 L
.312 .31494 L
.316 .31148 L
.32 .3085 L
.324 .30924 L
.328 .31421 L
.332 .32027 L
.336 .3232 L
.34 .3213 L
.344 .31672 L
.348 .31361 L
.352 .31476 L
.356 .3197 L
.36 .32555 L
.364 .32957 L
.368 .33099 L
.372 .33097 L
.376 .33112 L
.38 .33238 L
.384 .33483 L
.388 .33837 L
.392 .34291 L
.396 .34797 L
.4 .35203 L
Mistroke
.404 .35293 L
.408 .3492 L
.412 .3416 L
.416 .33339 L
.42 .32878 L
.424 .33041 L
.428 .33753 L
.432 .34631 L
.436 .35195 L
.44 .35151 L
.444 .3454 L
.448 .33686 L
.452 .32981 L
.456 .32674 L
.46 .32772 L
.464 .33115 L
.468 .33529 L
.472 .33957 L
.476 .34458 L
.48 .35112 L
.484 .35892 L
.488 .36602 L
.492 .36943 L
.496 .36649 L
.5 .35631 L
.504 .34039 L
.508 .322 L
.512 .30479 L
.516 .29126 L
.52 .28186 L
.524 .2751 L
.528 .26851 L
.532 .25993 L
.536 .24865 L
.54 .23572 L
.544 .2235 L
.548 .21465 L
.552 .21089 L
.556 .2122 L
.56 .21673 L
.564 .22152 L
.568 .22366 L
.572 .22141 L
.576 .21481 L
.58 .20554 L
.584 .19617 L
.588 .1892 L
.592 .18624 L
.596 .18771 L
.6 .1929 L
Mistroke
.604 .20022 L
.608 .20766 L
.612 .21316 L
.616 .21503 L
.62 .21237 L
.624 .20528 L
.628 .19484 L
.632 .18284 L
.636 .17122 L
.64 .16163 L
.644 .15522 L
.648 .15261 L
.652 .15402 L
.656 .15937 L
.66 .16824 L
.664 .17981 L
.668 .19302 L
.672 .20677 L
.676 .2202 L
.68 .23283 L
.684 .24447 L
.688 .255 L
.692 .26425 L
.696 .27202 L
.7 .27822 L
.704 .28298 L
.708 .2866 L
.712 .28946 L
.716 .29178 L
.72 .29363 L
.724 .29503 L
.728 .29601 L
.732 .29672 L
.736 .2973 L
.74 .29778 L
.744 .29812 L
.748 .2983 L
.752 .29837 L
.756 .29846 L
.76 .29865 L
.764 .29892 L
.768 .29913 L
.772 .2992 L
.776 .29913 L
.78 .29906 L
.784 .29909 L
.788 .29923 L
.792 .29939 L
.796 .29946 L
.8 .2994 L
Mistroke
.804 .29931 L
.808 .29928 L
.812 .29934 L
.816 .29943 L
.82 .29949 L
.824 .29947 L
.828 .29941 L
.832 .29939 L
.836 .29942 L
.84 .29946 L
.844 .29946 L
.848 .29941 L
.852 .29936 L
.856 .29936 L
.86 .29943 L
.864 .29949 L
.868 .29949 L
.872 .29943 L
.876 .29936 L
.88 .29935 L
.884 .29939 L
.888 .29942 L
.892 .29941 L
.896 .29936 L
.9 .29934 L
.904 .29938 L
.908 .29943 L
.912 .29944 L
.916 .29939 L
.92 .29932 L
.924 .29928 L
.928 .29931 L
.932 .29937 L
.936 .29938 L
.94 .29936 L
.944 .29934 L
.948 .29935 L
.952 .29936 L
.956 .29936 L
.96 .29929 L
.964 .29924 L
.968 .29925 L
.972 .2993 L
.976 .29935 L
.98 .29938 L
.984 .29932 L
.988 .29928 L
.992 .29928 L
.996 .29928 L
1 .29926 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .11995 m
.008 .12022 L
.012 .12019 L
.016 .11998 L
.02 .12001 L
.024 .12017 L
.028 .12012 L
.032 .12008 L
.036 .1201 L
.04 .12018 L
.044 .12018 L
.048 .12022 L
.052 .12022 L
.056 .12023 L
.06 .12017 L
.064 .12011 L
.068 .12002 L
.072 .11995 L
.076 .11989 L
.08 .11988 L
.084 .1199 L
.088 .12001 L
.092 .12013 L
.096 .12026 L
.1 .12035 L
.104 .12042 L
.108 .12042 L
.112 .12035 L
.116 .12021 L
.12 .12005 L
.124 .11992 L
.128 .11984 L
.132 .11981 L
.136 .11983 L
.14 .11991 L
.144 .12007 L
.148 .12021 L
.152 .1203 L
.156 .12033 L
.16 .12034 L
.164 .12033 L
.168 .12028 L
.172 .12017 L
.176 .12005 L
.18 .11995 L
.184 .11991 L
.188 .11988 L
.192 .11983 L
.196 .11981 L
.2 .11986 L
Mistroke
.204 .12001 L
.208 .12021 L
.212 .12039 L
.216 .12053 L
.22 .12064 L
.224 .12074 L
.228 .12077 L
.232 .12067 L
.236 .12041 L
.24 .12002 L
.244 .11962 L
.248 .11932 L
.252 .11913 L
.256 .11902 L
.26 .11896 L
.264 .11901 L
.268 .11927 L
.272 .11978 L
.276 .1204 L
.28 .12095 L
.284 .1213 L
.288 .12146 L
.292 .12159 L
.296 .12174 L
.3 .12182 L
.304 .12166 L
.308 .12117 L
.312 .12046 L
.316 .11981 L
.32 .11941 L
.324 .11923 L
.328 .11907 L
.332 .11874 L
.336 .11824 L
.34 .11775 L
.344 .11749 L
.348 .11752 L
.352 .11775 L
.356 .11798 L
.36 .11809 L
.364 .11812 L
.368 .11822 L
.372 .11856 L
.376 .11925 L
.38 .12033 L
.384 .12173 L
.388 .12335 L
.392 .12503 L
.396 .12664 L
.4 .12812 L
Mistroke
.404 .12954 L
.408 .13108 L
.412 .13294 L
.416 .13517 L
.42 .13767 L
.424 .14012 L
.428 .14221 L
.432 .14376 L
.436 .14486 L
.44 .14582 L
.444 .147 L
.448 .14868 L
.452 .15094 L
.456 .15365 L
.46 .1566 L
.464 .15959 L
.468 .16248 L
.472 .16521 L
.476 .16771 L
.48 .16989 L
.484 .17165 L
.488 .17298 L
.492 .17398 L
.496 .17489 L
.5 .17604 L
.504 .17773 L
.508 .18017 L
.512 .18338 L
.516 .18723 L
.52 .19152 L
.524 .19607 L
.528 .20083 L
.532 .20582 L
.536 .21115 L
.54 .21691 L
.544 .22308 L
.548 .22957 L
.552 .23618 L
.556 .24268 L
.56 .2489 L
.564 .2548 L
.568 .26043 L
.572 .26594 L
.576 .27152 L
.58 .27733 L
.584 .28345 L
.588 .28985 L
.592 .29639 L
.596 .3029 L
.6 .3092 L
Mistroke
.604 .31516 L
.608 .32074 L
.612 .32599 L
.616 .33106 L
.62 .33613 L
.624 .3414 L
.628 .34702 L
.632 .35309 L
.636 .35963 L
.64 .36661 L
.644 .37389 L
.648 .38132 L
.652 .38872 L
.656 .39589 L
.66 .40269 L
.664 .40898 L
.668 .41469 L
.672 .41977 L
.676 .4242 L
.68 .42799 L
.684 .4312 L
.688 .43388 L
.692 .4361 L
.696 .43792 L
.7 .4394 L
.704 .44061 L
.708 .44159 L
.712 .44239 L
.716 .44305 L
.72 .4436 L
.724 .44405 L
.728 .44443 L
.732 .44475 L
.736 .44502 L
.74 .44525 L
.744 .44546 L
.748 .44563 L
.752 .44578 L
.756 .44592 L
.76 .44603 L
.764 .44614 L
.768 .44623 L
.772 .44631 L
.776 .44639 L
.78 .44645 L
.784 .44651 L
.788 .44656 L
.792 .44661 L
.796 .44665 L
.8 .4467 L
Mistroke
.804 .44674 L
.808 .44677 L
.812 .44681 L
.816 .44684 L
.82 .44687 L
.824 .44691 L
.828 .44694 L
.832 .44697 L
.836 .447 L
.84 .44703 L
.844 .44705 L
.848 .44708 L
.852 .44711 L
.856 .44714 L
.86 .44717 L
.864 .4472 L
.868 .44723 L
.872 .44725 L
.876 .44728 L
.88 .44731 L
.884 .44733 L
.888 .44736 L
.892 .44739 L
.896 .44742 L
.9 .44745 L
.904 .44748 L
.908 .4475 L
.912 .44753 L
.916 .44755 L
.92 .44758 L
.924 .44761 L
.928 .44764 L
.932 .44766 L
.936 .4477 L
.94 .44772 L
.944 .44775 L
.948 .44777 L
.952 .44781 L
.956 .44782 L
.96 .44786 L
.964 .44788 L
.968 .44792 L
.972 .44793 L
.976 .44798 L
.98 .44799 L
.984 .44803 L
.988 .44804 L
.992 .44809 L
.996 .44809 L
1 .44815 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16492 L
.012 .16129 L
.016 .16 L
.02 .16122 L
.024 .16157 L
.028 .16112 L
.032 .16091 L
.036 .16105 L
.04 .1611 L
.044 .16113 L
.048 .16115 L
.052 .16124 L
.056 .16125 L
.06 .16123 L
.064 .16113 L
.068 .16102 L
.072 .16091 L
.076 .16083 L
.08 .16078 L
.084 .1608 L
.088 .16089 L
.092 .16103 L
.096 .16114 L
.1 .16123 L
.104 .16127 L
.108 .16127 L
.112 .16119 L
.116 .16105 L
.12 .1609 L
.124 .16079 L
.128 .16072 L
.132 .16067 L
.136 .16064 L
.14 .16068 L
.144 .16078 L
.148 .16091 L
.152 .16099 L
.156 .16105 L
.16 .1611 L
.164 .16114 L
.168 .16111 L
.172 .16098 L
.176 .16081 L
.18 .16066 L
.184 .16055 L
.188 .16047 L
.192 .1604 L
.196 .16037 L
.2 .16045 L
Mistroke
.204 .16065 L
.208 .1609 L
.212 .16112 L
.216 .16127 L
.22 .16138 L
.224 .16147 L
.228 .16149 L
.232 .16136 L
.236 .16103 L
.24 .16056 L
.244 .16008 L
.248 .15972 L
.252 .15948 L
.256 .15932 L
.26 .15921 L
.264 .15924 L
.268 .15954 L
.272 .16015 L
.276 .16092 L
.28 .16162 L
.284 .16206 L
.288 .16228 L
.292 .16243 L
.296 .1626 L
.3 .16269 L
.304 .16247 L
.308 .16184 L
.312 .16095 L
.316 .16014 L
.32 .15962 L
.324 .15938 L
.328 .15917 L
.332 .15875 L
.336 .15812 L
.34 .15751 L
.344 .15718 L
.348 .15723 L
.352 .1575 L
.356 .15777 L
.36 .1579 L
.364 .15792 L
.368 .15803 L
.372 .15844 L
.376 .1593 L
.38 .16063 L
.384 .16236 L
.388 .16436 L
.392 .16645 L
.396 .16845 L
.4 .1703 L
Mistroke
.404 .17208 L
.408 .17399 L
.412 .17628 L
.416 .17904 L
.42 .18213 L
.424 .18516 L
.428 .18774 L
.432 .18966 L
.436 .19103 L
.44 .19221 L
.444 .19368 L
.448 .19578 L
.452 .19858 L
.456 .20194 L
.46 .20559 L
.464 .20928 L
.468 .21286 L
.472 .21623 L
.476 .21932 L
.48 .22203 L
.484 .22422 L
.488 .22587 L
.492 .2271 L
.496 .22821 L
.5 .22961 L
.504 .2317 L
.508 .23471 L
.512 .23868 L
.516 .24345 L
.52 .24877 L
.524 .25443 L
.528 .26034 L
.532 .26655 L
.536 .27316 L
.54 .2803 L
.544 .28797 L
.548 .29602 L
.552 .30421 L
.556 .31228 L
.56 .32001 L
.564 .32731 L
.568 .33428 L
.572 .34111 L
.576 .34802 L
.58 .35524 L
.584 .36283 L
.588 .37076 L
.592 .37887 L
.596 .38692 L
.6 .39471 L
Mistroke
.604 .40208 L
.608 .40898 L
.612 .41548 L
.616 .42176 L
.62 .42803 L
.624 .43454 L
.628 .44148 L
.632 .44899 L
.636 .45709 L
.64 .46571 L
.644 .47472 L
.648 .48391 L
.652 .49306 L
.656 .50194 L
.66 .51036 L
.664 .51814 L
.668 .52518 L
.672 .53143 L
.676 .53686 L
.68 .54151 L
.684 .54544 L
.688 .54871 L
.692 .5514 L
.696 .55359 L
.7 .55536 L
.704 .55679 L
.708 .55794 L
.712 .55886 L
.716 .55961 L
.72 .56021 L
.724 .5607 L
.728 .56109 L
.732 .56141 L
.736 .56167 L
.74 .56189 L
.744 .56206 L
.748 .5622 L
.752 .56232 L
.756 .56241 L
.76 .56248 L
.764 .56253 L
.768 .56256 L
.772 .56258 L
.776 .56259 L
.78 .5626 L
.784 .5626 L
.788 .56259 L
.792 .56258 L
.796 .56255 L
.8 .56253 L
Mistroke
.804 .5625 L
.808 .56247 L
.812 .56243 L
.816 .5624 L
.82 .56236 L
.824 .56233 L
.828 .56229 L
.832 .56225 L
.836 .56221 L
.84 .56217 L
.844 .56212 L
.848 .56208 L
.852 .56204 L
.856 .562 L
.86 .56196 L
.864 .56192 L
.868 .56187 L
.872 .56183 L
.876 .56178 L
.88 .56174 L
.884 .5617 L
.888 .56166 L
.892 .56161 L
.896 .56157 L
.9 .56153 L
.904 .56149 L
.908 .56144 L
.912 .5614 L
.916 .56135 L
.92 .56131 L
.924 .56127 L
.928 .56123 L
.932 .56118 L
.936 .56115 L
.94 .56109 L
.944 .56106 L
.948 .561 L
.952 .56097 L
.956 .56092 L
.96 .56089 L
.964 .56083 L
.968 .5608 L
.972 .56074 L
.976 .56072 L
.98 .56065 L
.984 .56063 L
.988 .56057 L
.992 .56055 L
.996 .56048 L
1 .56047 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8003eoo`8002ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0004Ool01@00Oomoogoo0000?Goo0`00;Woo000:Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool00`00Oomoo`02000lOol00`00Ool0000^Ool000Yoo`04001oogoo0008Ool0
1P00Oomoo`00Ool000=oo`03001oogoo008003aoo`04001oogoo000]Ool000]oo`8000Yoo`8000=o
o`<000=oo`03001oogoo03Ioo`<00003Ool007oo009oo`03001oogoo02]oo`002goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo0P00=goo00D007oo001oo`0000=oo`03001oogoo02]oo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000=Ool30004Ool20007Ool30004
Ool20004Ool20005Ool400000goo000000040002Ool30002Ool50003Ool20004Ool20004Ool50002
Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol02goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`800003Ool0000000=oo`04001oogoo0002Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo0P001Woo00@007ooOol0009oo`03001oogoo009oo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool20006
Ool01000Oomoo`000Woo0P0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000Aoo`03001oogoo00]oo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool00`00Oomoo`0200000goo001o
o`02Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00003Ool00`00Ool000030003
Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04
Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomo
o`04Ool01@00Oomoo`00Ool00P000goo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo
00000goo00<007oo00001Woo00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007oo
Ool00goo0P0017oo0P001Goo0P000goo1@000goo0P000Woo00<007oo00000P0017oo0P0017oo0P00
1Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`0`Ool00`00Oomoo`0?Ool00`00Oomoo`0W
Ool0029oo`80031oo`03001oogoo015oo`D002Aoo`008WooH`0037oo000ROol00`00Ool000020000
17oo000000000Woo0P000goo0`0000Aoo`00Oomoo`<00003Ool007oo00@00003Ool0000000=oo`05
001oogooOol00003Ool00`00Oomoo`020003Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
000<Ool0029oo`80009oo`<00004Ool000000002Ool500000goo0000000300000goo000000030002
Ool200000goo001oo`04Ool01@00Oomoogoo000017oo00<007ooOol0>Woo000ROol2000HOol00`00
Oomoo`07Ool30002Ool2000017oo000000000goo00<007ooOol0>Woo000ROol2000TOol300000goo
00000003Ool00`00Ool0000mOol0029oo`8002Eoo`80009oo`07001oogooOol007oo0000?Goo000;
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0]Ool00`00Oomoo`0lOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eo
o`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]
Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:
Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0
029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00
0Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo9@00A7oo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`03001oogoo029oo`<0045oo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0
97oo0`00?goo000XOol00`00Oomoo`0VOol3000mOol002Qoo`03001oogoo02Qoo`8003aoo`002goo
0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0:Goo1000>Goo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol002ioo`8003Qo
o`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0
02moo`03001oogoo03Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P00
0Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@0
07ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo0`0000=oo`00Ool0
0Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001o
ogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009o
o`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007oo0000
00Aoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool5
0002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0003Ool01000Oomoo`0017oo00@007ooOol0009oo`03001oogoo009oo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0
009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01@000goo00H007ooOol007oo0003
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000
Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@0
07ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005
Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001o
ogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03
001oogoo03=oo`03001oogoo031oo`00:7oo00<007ooOol0<goo00<007ooOol0<7oo000XOomM000<
Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`80011oo`03001oogoo011o
o`03001oogoo00Yoo`00:7oo00<007ooOol0=Goo00<007ooOol0;Woo000XOol00`00Oomoo`0fOol0
0`00Oomoo`0]Ool002Qoo`03001oogoo03Moo`03001oogoo02aoo`00:7oo00<007ooOol0=goo0P00
;Goo000XOol00`00Oomoo`0hOol00`00Oomoo`0[Ool000]oo`8000Aoo`03001oogoo00=oo`8000Ao
o`8000=oo`<000=oo`03001oogoo03Qoo`8002aoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000=oo`04001oogoo000kOol00`00Oomoo`0ZOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000kOol2000[Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008003]oo`8002Yoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0>goo0P00:Goo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0?7oo
1@009Goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`10OolJ000<Ool002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007oo
Ool00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1V
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001X
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D0
06]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`00
0goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079o
o`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04
001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<0
07ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@00
0goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo
00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomo
o`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03
001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool0
1000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo
00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool0
1000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000L
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol20002Ool01@00Oomo
ogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00`000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`0WOol30018Ool001aoo`8002Yoo`<0
04Ioo`0077oo00<007ooOol0:goo0P00AGoo000LOol00`00Oomoo`0]Ool00`00Oomoo`12Ool001ao
o`8002moo`03001oogoo045oo`0077oo00<007ooOol0;goo0`00@7oo000LOol00`00Oomoo`0aOol2
000oOol001aoo`8003Aoo`03001oogoo03aoo`0077oo00<007ooOol0<goo00<007ooOol0?7oo000L
Ool2000eOol00`00Oomoo`0kOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo03Eo
o`03001oogoo03Yoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0eOol0
0`00Oomoo`0jOol000Yoo`04001oogoo000;Ool00`00Oomoo`02000gOol00`00Oomoo`0iOol000Yo
o`04001oogoo000;Ool01000Oomoo`00>7oo00<007ooOol0>Goo000:Ool01000Oomoo`001goo1000
0goo00<007ooOol0=goo00<007ooOol0>7oo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00
>7oo0P00>Goo000;Ool20008Ool50002Ool00`00Oomoo`0hOol00`00Oomoo`0gOol001aoo`03001o
ogoo03Qoo`03001oogoo03Moo`0077oo0P00>Woo00<007ooOol0=Woo000LOol00`00Oomoo`0jOol0
0`00Oomoo`0eOol001aoo`8003]oo`03001oogoo03Eoo`0077oo00<007ooOol0>Woo00<007ooOol0
=Goo000LOol00`00Oomoo`0kOol00`00Oomoo`0dOol001aoo`8003eoo`03001oogoo03=oo`005Woo
0`000goo00<007ooOol0?7oo00<007ooOol0<goo000GOol00`00Oomoo`02Ool00`00Oomoo`0lOol2
000dOol001Moo`03001oogoo009oo`8003ioo`03001oogoo039oo`005goo00<007ooOol00Woo00<0
07ooOol0?Woo00<007ooOol0<Goo000GOol00`00Oomoo`02Ool00`00Oomoo`0oOol00`00Oomoo`0`
Ool001Ioo`8000Aoo`80041oo`03001oogoo031oo`005goo00<007ooOol00Woo00<007ooOol0?goo
00<007ooOol0<7oo000LOol00`00Oomoo`10Ool00`00Oomoo`0_Ool001aoo`80045oo`03001oogoo
02moo`0077oo00<007ooOol0@Goo00<007ooOol0;Woo000LOol20012Ool00`00Oomoo`0^Ool001ao
o`03001oogoo049oo`03001oogoo02eoo`0077oo00<007ooOol0@Woo00<007ooOol0;Goo000:Ool3
0004Ool00`00Oomoo`02Ool30003Ool20014Ool00`00Oomoo`0/Ool000]oo`03001oogoo00Moo`05
001oogooOol00002Ool00`00Oomoo`13Ool2000]Ool000]oo`03001oogoo00]oo`04001oogoo0017
Ool3000ZOol000]oo`03001oogoo00]oo`03001oogoo008004Uooah000aoo`002goo00<007ooOol0
1goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]o
o`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(40748\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3148 m
.008 .31614 L
.012 .3194 L
.016 .32169 L
.02 .32298 L
.024 .32379 L
.028 .32352 L
.032 .32242 L
.036 .32037 L
.04 .31844 L
.044 .31696 L
.048 .3159 L
.052 .31604 L
.056 .31721 L
.06 .31944 L
.064 .32186 L
.068 .32342 L
.072 .32401 L
.076 .32309 L
.08 .32102 L
.084 .31829 L
.088 .31589 L
.092 .31512 L
.096 .31603 L
.1 .31823 L
.104 .32067 L
.108 .32267 L
.112 .32388 L
.116 .32364 L
.12 .3221 L
.124 .32013 L
.128 .31902 L
.132 .31903 L
.136 .31924 L
.14 .31909 L
.144 .31863 L
.148 .31826 L
.152 .31795 L
.156 .31772 L
.16 .31822 L
.164 .32008 L
.168 .32304 L
.172 .32543 L
.176 .32562 L
.18 .32348 L
.184 .32036 L
.188 .31771 L
.192 .31615 L
.196 .31582 L
.2 .31676 L
Mistroke
.204 .31878 L
.208 .32105 L
.212 .32223 L
.216 .32155 L
.22 .31966 L
.224 .31834 L
.228 .31908 L
.232 .32192 L
.236 .32528 L
.24 .32711 L
.244 .32633 L
.248 .32347 L
.252 .32005 L
.256 .31728 L
.26 .31534 L
.264 .31381 L
.268 .31274 L
.272 .31296 L
.276 .3151 L
.28 .31848 L
.284 .32131 L
.288 .32244 L
.292 .32276 L
.296 .32448 L
.3 .32856 L
.304 .33304 L
.308 .33423 L
.312 .3301 L
.316 .32255 L
.32 .31621 L
.324 .31454 L
.328 .31684 L
.332 .31912 L
.336 .31785 L
.34 .31323 L
.344 .30893 L
.348 .30867 L
.352 .31294 L
.356 .31868 L
.36 .32194 L
.364 .32108 L
.368 .31772 L
.372 .31502 L
.376 .31514 L
.38 .31805 L
.384 .32218 L
.388 .32596 L
.392 .32866 L
.396 .33027 L
.4 .33099 L
Mistroke
.404 .33112 L
.408 .33147 L
.412 .33337 L
.416 .33789 L
.42 .34457 L
.424 .35094 L
.428 .35354 L
.432 .35015 L
.436 .34164 L
.44 .332 L
.444 .32624 L
.448 .32745 L
.452 .33487 L
.456 .34435 L
.46 .35078 L
.464 .35099 L
.468 .34531 L
.472 .33691 L
.476 .32966 L
.48 .32598 L
.484 .32589 L
.488 .32787 L
.492 .3304 L
.496 .33328 L
.5 .33758 L
.504 .34447 L
.508 .35382 L
.512 .36344 L
.516 .36981 L
.52 .3696 L
.524 .36146 L
.528 .34666 L
.532 .3286 L
.536 .31119 L
.54 .29715 L
.544 .28703 L
.548 .27939 L
.552 .27182 L
.556 .26229 L
.56 .25019 L
.564 .23651 L
.568 .22344 L
.572 .21338 L
.576 .20803 L
.58 .20771 L
.584 .21114 L
.588 .21585 L
.592 .21899 L
.596 .21836 L
.6 .21323 L
Mistroke
.604 .20457 L
.608 .19465 L
.612 .18619 L
.616 .18135 L
.62 .18113 L
.624 .18517 L
.628 .19209 L
.632 .19994 L
.636 .20664 L
.64 .21041 L
.644 .21001 L
.648 .20499 L
.652 .19592 L
.656 .1842 L
.66 .17177 L
.664 .16058 L
.668 .15213 L
.672 .1473 L
.676 .14646 L
.68 .14958 L
.684 .15641 L
.688 .16645 L
.692 .17893 L
.696 .19282 L
.7 .2071 L
.704 .22094 L
.708 .23382 L
.712 .24549 L
.716 .25584 L
.72 .26475 L
.724 .27216 L
.728 .27811 L
.732 .28281 L
.736 .28653 L
.74 .28953 L
.744 .29191 L
.748 .2937 L
.752 .29496 L
.756 .29584 L
.76 .29653 L
.764 .29714 L
.768 .29766 L
.772 .29804 L
.776 .29825 L
.78 .29836 L
.784 .29847 L
.788 .29866 L
.792 .29889 L
.796 .29908 L
.8 .29917 L
Mistroke
.804 .29916 L
.808 .29913 L
.812 .29914 L
.816 .29921 L
.82 .2993 L
.824 .29935 L
.828 .29939 L
.832 .29942 L
.836 .29946 L
.84 .29947 L
.844 .29944 L
.848 .29937 L
.852 .29932 L
.856 .29937 L
.86 .29948 L
.864 .29957 L
.868 .29958 L
.872 .29948 L
.876 .29935 L
.88 .29931 L
.884 .29937 L
.888 .29947 L
.892 .29953 L
.896 .29951 L
.9 .29945 L
.904 .2994 L
.908 .29938 L
.912 .29937 L
.916 .29938 L
.92 .29939 L
.924 .29943 L
.928 .29947 L
.932 .29947 L
.936 .29941 L
.94 .29934 L
.944 .2993 L
.948 .29932 L
.952 .29939 L
.956 .29944 L
.96 .29941 L
.964 .29937 L
.968 .29934 L
.972 .29934 L
.976 .29936 L
.98 .29937 L
.984 .29933 L
.988 .29931 L
.992 .29933 L
.996 .29934 L
1 .29934 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .11547 m
.008 .12064 L
.012 .12231 L
.016 .1206 L
.02 .11998 L
.024 .12057 L
.028 .12074 L
.032 .12058 L
.036 .12049 L
.04 .12058 L
.044 .12059 L
.048 .12056 L
.052 .12053 L
.056 .12054 L
.06 .12054 L
.064 .12057 L
.068 .12061 L
.072 .12068 L
.076 .12072 L
.08 .12075 L
.084 .12072 L
.088 .12066 L
.092 .12057 L
.096 .12046 L
.1 .12035 L
.104 .1203 L
.108 .12033 L
.112 .12042 L
.116 .12054 L
.12 .12068 L
.124 .12081 L
.128 .1209 L
.132 .1209 L
.136 .12082 L
.14 .1207 L
.144 .12058 L
.148 .12047 L
.152 .12037 L
.156 .12031 L
.16 .12032 L
.164 .1204 L
.168 .1205 L
.172 .12059 L
.176 .12065 L
.18 .12072 L
.184 .1208 L
.188 .12083 L
.192 .12079 L
.196 .1207 L
.2 .12061 L
Mistroke
.204 .12054 L
.208 .12047 L
.212 .12037 L
.216 .12026 L
.22 .12022 L
.224 .12027 L
.228 .12041 L
.232 .12059 L
.236 .12075 L
.24 .1209 L
.244 .12107 L
.248 .12123 L
.252 .12132 L
.256 .12124 L
.26 .12099 L
.264 .12063 L
.268 .12029 L
.272 .12002 L
.276 .1198 L
.28 .11956 L
.284 .11936 L
.288 .11931 L
.292 .11954 L
.296 .12003 L
.3 .12063 L
.304 .12112 L
.308 .12145 L
.312 .1217 L
.316 .12198 L
.32 .12228 L
.324 .12245 L
.328 .1223 L
.332 .12181 L
.336 .12116 L
.34 .1206 L
.344 .12026 L
.348 .12006 L
.352 .11982 L
.356 .1194 L
.36 .11886 L
.364 .11837 L
.368 .11811 L
.372 .11811 L
.376 .11825 L
.38 .11839 L
.384 .11843 L
.388 .11841 L
.392 .11843 L
.396 .11864 L
.4 .11916 L
Mistroke
.404 .12005 L
.408 .1213 L
.412 .12281 L
.416 .12444 L
.42 .126 L
.424 .12741 L
.428 .12874 L
.432 .13019 L
.436 .13197 L
.44 .13417 L
.444 .13668 L
.448 .13919 L
.452 .14136 L
.456 .14301 L
.46 .14418 L
.464 .14515 L
.468 .14627 L
.472 .1478 L
.476 .14984 L
.48 .15232 L
.484 .15509 L
.488 .15799 L
.492 .16092 L
.496 .16377 L
.5 .16647 L
.504 .16888 L
.508 .17086 L
.512 .17235 L
.516 .17341 L
.52 .17427 L
.524 .17524 L
.528 .17665 L
.532 .17873 L
.536 .18155 L
.54 .18501 L
.544 .18896 L
.548 .19322 L
.552 .19771 L
.556 .20246 L
.56 .20755 L
.564 .21308 L
.568 .21908 L
.572 .22544 L
.576 .232 L
.58 .23853 L
.584 .24484 L
.588 .25083 L
.592 .25652 L
.596 .26205 L
.6 .26759 L
Mistroke
.604 .27332 L
.608 .27933 L
.612 .28564 L
.616 .29214 L
.62 .29869 L
.624 .30508 L
.628 .31119 L
.632 .31692 L
.636 .3223 L
.64 .32743 L
.644 .33247 L
.648 .33761 L
.652 .34303 L
.656 .34885 L
.66 .35513 L
.664 .36186 L
.668 .36897 L
.672 .37632 L
.676 .38375 L
.68 .39107 L
.684 .39812 L
.688 .40474 L
.692 .41083 L
.696 .41631 L
.7 .42117 L
.704 .42539 L
.708 .42899 L
.712 .43204 L
.716 .43458 L
.72 .43668 L
.724 .4384 L
.728 .43981 L
.732 .44096 L
.736 .4419 L
.74 .44266 L
.744 .4433 L
.748 .44382 L
.752 .44426 L
.756 .44462 L
.76 .44493 L
.764 .44519 L
.768 .44541 L
.772 .44561 L
.776 .44578 L
.78 .44593 L
.784 .44606 L
.788 .44617 L
.792 .44627 L
.796 .44636 L
.8 .44644 L
Mistroke
.804 .44651 L
.808 .44657 L
.812 .44663 L
.816 .44668 L
.82 .44673 L
.824 .44677 L
.828 .44681 L
.832 .44685 L
.836 .44689 L
.84 .44692 L
.844 .44696 L
.848 .44699 L
.852 .44702 L
.856 .44705 L
.86 .44708 L
.864 .44711 L
.868 .44714 L
.872 .44717 L
.876 .4472 L
.88 .44723 L
.884 .44725 L
.888 .44728 L
.892 .44731 L
.896 .44734 L
.9 .44736 L
.904 .44739 L
.908 .44742 L
.912 .44745 L
.916 .44747 L
.92 .44751 L
.924 .44753 L
.928 .44756 L
.932 .44758 L
.936 .44762 L
.94 .44764 L
.944 .44767 L
.948 .44769 L
.952 .44773 L
.956 .44775 L
.96 .44779 L
.964 .4478 L
.968 .44784 L
.972 .44785 L
.976 .44789 L
.98 .44791 L
.984 .44795 L
.988 .44796 L
.992 .44801 L
.996 .44801 L
1 .44807 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .1613 L
.012 .16129 L
.016 .16106 L
.02 .16098 L
.024 .16106 L
.028 .1612 L
.032 .16116 L
.036 .16117 L
.04 .16117 L
.044 .16119 L
.048 .16112 L
.052 .16109 L
.056 .16105 L
.06 .16105 L
.064 .16104 L
.068 .16108 L
.072 .1611 L
.076 .16115 L
.08 .16115 L
.084 .16112 L
.088 .16106 L
.092 .161 L
.096 .1609 L
.1 .16081 L
.104 .16075 L
.108 .16077 L
.112 .16082 L
.116 .1609 L
.12 .16099 L
.124 .16111 L
.128 .16121 L
.132 .16124 L
.136 .16119 L
.14 .16108 L
.144 .16096 L
.148 .16082 L
.152 .16067 L
.156 .16055 L
.16 .16051 L
.164 .16058 L
.168 .16069 L
.172 .16081 L
.176 .1609 L
.18 .16101 L
.184 .1611 L
.188 .16113 L
.192 .16105 L
.196 .16091 L
.2 .16077 L
Mistroke
.204 .16067 L
.208 .16057 L
.212 .16045 L
.216 .16034 L
.22 .1603 L
.224 .16037 L
.228 .16054 L
.232 .16073 L
.236 .16089 L
.24 .16105 L
.244 .16123 L
.248 .16142 L
.252 .16153 L
.256 .16145 L
.26 .16115 L
.264 .16071 L
.268 .16028 L
.272 .15993 L
.276 .15962 L
.28 .15931 L
.284 .15905 L
.288 .15898 L
.292 .15926 L
.296 .15986 L
.3 .16059 L
.304 .16119 L
.308 .16159 L
.312 .16189 L
.316 .16224 L
.32 .16262 L
.324 .16283 L
.328 .16264 L
.332 .16201 L
.336 .16117 L
.34 .16046 L
.344 .16002 L
.348 .15978 L
.352 .15947 L
.356 .15894 L
.36 .15824 L
.364 .15762 L
.368 .15729 L
.372 .15729 L
.376 .15747 L
.38 .15765 L
.384 .15769 L
.388 .15765 L
.392 .15765 L
.396 .15789 L
.4 .15852 L
Mistroke
.404 .15961 L
.408 .16117 L
.412 .16306 L
.416 .16508 L
.42 .16703 L
.424 .16879 L
.428 .17044 L
.432 .17222 L
.436 .17442 L
.44 .17714 L
.444 .18024 L
.448 .18334 L
.452 .18604 L
.456 .18809 L
.46 .18955 L
.464 .19076 L
.468 .19214 L
.472 .19403 L
.476 .19655 L
.48 .19962 L
.484 .20305 L
.488 .20664 L
.492 .21026 L
.496 .21381 L
.5 .21716 L
.504 .22015 L
.508 .2226 L
.512 .22444 L
.516 .22575 L
.52 .22679 L
.524 .22797 L
.528 .22971 L
.532 .23228 L
.536 .23577 L
.54 .24007 L
.544 .24496 L
.548 .25024 L
.552 .25581 L
.556 .26171 L
.56 .26804 L
.564 .27491 L
.568 .28235 L
.572 .29025 L
.576 .29838 L
.58 .30647 L
.584 .31429 L
.588 .32173 L
.592 .3288 L
.596 .33566 L
.6 .34253 L
Mistroke
.604 .34962 L
.608 .35707 L
.612 .36488 L
.616 .37294 L
.62 .38104 L
.624 .38896 L
.628 .39652 L
.632 .40362 L
.636 .41029 L
.64 .41663 L
.644 .42286 L
.648 .42921 L
.652 .43589 L
.656 .44307 L
.66 .45084 L
.664 .45918 L
.668 .46799 L
.672 .47709 L
.676 .48628 L
.68 .49534 L
.684 .50405 L
.688 .51223 L
.692 .51975 L
.696 .52652 L
.7 .53249 L
.704 .53767 L
.708 .54209 L
.712 .54581 L
.716 .54891 L
.72 .55145 L
.724 .55352 L
.728 .5552 L
.732 .55655 L
.736 .55765 L
.74 .55853 L
.744 .55924 L
.748 .55981 L
.752 .56027 L
.756 .56065 L
.76 .56096 L
.764 .56121 L
.768 .56142 L
.772 .56158 L
.776 .56171 L
.78 .56182 L
.784 .5619 L
.788 .56197 L
.792 .56202 L
.796 .56205 L
.8 .56207 L
Mistroke
.804 .56208 L
.808 .56208 L
.812 .56208 L
.816 .56207 L
.82 .56205 L
.824 .56203 L
.828 .562 L
.832 .56197 L
.836 .56194 L
.84 .56191 L
.844 .56187 L
.848 .56183 L
.852 .5618 L
.856 .56176 L
.86 .56172 L
.864 .56168 L
.868 .56163 L
.872 .56159 L
.876 .56155 L
.88 .56151 L
.884 .56147 L
.888 .56143 L
.892 .56138 L
.896 .56134 L
.9 .56129 L
.904 .56125 L
.908 .56121 L
.912 .56117 L
.916 .56112 L
.92 .56109 L
.924 .56104 L
.928 .561 L
.932 .56095 L
.936 .56091 L
.94 .56086 L
.944 .56083 L
.948 .56077 L
.952 .56074 L
.956 .56069 L
.96 .56066 L
.964 .5606 L
.968 .56057 L
.972 .56051 L
.976 .56049 L
.98 .56042 L
.984 .5604 L
.988 .56034 L
.992 .56032 L
.996 .56025 L
1 .56024 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8003moo`8002aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0004Ool01@00Oomoogoo0000@7oo00<007oo0000:goo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool00`00Oomoo`02000nOol01000Oomoo`00:goo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02000jOol20002Ool01@00Oomoogoo0000:Woo
000;Ool2000:Ool20003Ool30003Ool00`00Oomoo`0hOol30002Ool01@00Oomoogoo0000:Woo000;
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2000iOol00`00Oomoo`020004Ool00`00Oomo
o`0XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo
0P001goo0`0017oo0P0017oo0P001Goo0`000Woo10000Woo10000Woo1P000goo0P0017oo0P0017oo
1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000017oo001oo`000Woo00@007ooOol0
009oo`80009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo00H007ooOol007oo
0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogoo0004Ool01000Oomoo`000Woo00H007ooOol007oo
0004Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOol000Aoo`04001oogoo0002Ool01`00Oomoogoo001oo`0000=oo`04001oogoo0002Ool0
1000Oomoo`001Woo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;Ool40003Ool01000Oomoo`001goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`050003Ool01000Oomoo`00
0Woo0P000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000goo00<007oo0000
0`000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo0P0037oo00<007oo
Ool017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P0000Aoo`00
Ool000Ioo`04001oogoo0002Ool20002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogoo
Ool00003Ool00`00Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool50003Ool20008Ool00`00
Oomoo`03Ool20004Ool20006Ool01000Ool007oo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo
0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`0bOol2000@Ool2000VOol0029oo`8003=oo`03
001oogoo011oo`H0025oo`008WooH`0037oo000ROol20002Ool300001Goo00000000Ool01@0000Mo
o`00000007oo001oo`040003Ool700000goo001oo`02Ool01@00Oomoogoo00000goo0P000Woo00D0
07ooOomoo`00009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo000037oo000ROol500001Goo00000000Ool00`000goo
0`0000=oo`00000010000Woo0P0000=oo`00Ool00Woo0P0000=oo`00Ool00goo0P000Woo0P000goo
00<007ooOol0>7oo000ROol00`00Oomoo`0KOol20007Ool3000017oo000007oo10000Woo00<007oo
Ool0>7oo000ROol2000WOol01000Ool007oo0P000Woo00@007ooOol003Yoo`008Woo0P009goo0P00
0Woo00<007ooOol00Woo00<007oo0000>Woo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003
Ool00`00Oomoo`0_Ool2000kOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007oo
Ool0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
17oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007oo
Ool00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;
Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
0`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo
00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo
1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2
000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo:000@Goo000@Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo02Aoo`<003moo`004Goo0P002Woo0P00
17oo00<007ooOol00Woo00<007ooOol09Woo0`00?Goo000XOol00`00Oomoo`0YOol2000kOol002Qo
o`03001oogoo02Yoo`<003Uoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo
00<007ooOol0;7oo0`00=goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`000goo00@007ooOol0031oo`8003Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOol0039oo`03001oogoo03=oo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P00
17oo0P000goo0`0000=oo`0000000`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`00
17oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool0
0`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00
Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000=oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Oomoo`02Ool200001Goo001oogoo00000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo
000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol0
0`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001o
ogoo0002Ool20003Ool01000Oomoo`000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomo
o`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P00
0goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`0eOol00`00
Oomoo`0^Ool002Qoo`03001oogoo03Eoo`8002moo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool0
0`00Oomoo`0@Ool00`00Oomoo`0?Ool01000Oomoo`003Woo00<007ooOol047oo00<007ooOol02Woo
000XOol00`00Oomoo`0hOol00`00Oomoo`0[Ool002Qoo`03001oogoo03Qoo`8002aoo`00:7oo00<0
07ooOol0>Goo00<007ooOol0:Woo000XOol00`00Oomoo`0jOol00`00Oomoo`0YOol002Qoo`03001o
ogoo03Yoo`8002Yoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007oo
Ool0>goo00<007ooOol0:7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`000goo00@007ooOol003eoo`8002Uoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`001Goo00@007ooOol003ioo`03001oogoo02Moo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol00P00?Woo00<007ooOol09Woo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`0mOol2000WOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0oOol4000SOol0
00]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo04=ooaL000aoo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001o
ogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool5
0002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol0
07Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03
001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=
Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004
Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomo
o`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol0
47oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`00
77oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009o
o`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo
0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomo
o`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo
0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogoo
Ool50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001o
ogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00
Oomoo`02Ool50003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool00`00Oomoo`0:Ool001aoo`03001oogoo02Yoo`8004Ioo`0077oo0P00;Goo0`00@goo000LOol0
0`00Oomoo`0^Ool20012Ool001aoo`03001oogoo02moo`80045oo`0077oo0P00<Goo0P00@7oo000L
Ool00`00Oomoo`0bOol3000mOol001aoo`03001oogoo03Aoo`8003aoo`0077oo0P00=Woo0P00>goo
000LOol00`00Oomoo`0fOol00`00Oomoo`0iOol001aoo`8003Qoo`03001oogoo03Qoo`002goo0P00
17oo00<007ooOol00Woo0`000goo00<007ooOol0>7oo00<007ooOol0=goo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo03Qoo`03001oogoo03Moo`002Woo00@007ooOol000]o
o`03001oogoo008003Uoo`8003Qoo`002Woo00@007ooOol000]oo`04001oogoo000kOol00`00Oomo
o`0fOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0jOol00`00Oomoo`0eOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool2000kOol00`00Oomoo`0eOol000]oo`8000Qoo`D0009oo`03
001oogoo03Yoo`8003Ioo`0077oo00<007ooOol0>goo00<007ooOol0=7oo000LOol2000mOol00`00
Oomoo`0cOol001aoo`03001oogoo03aoo`03001oogoo03=oo`0077oo0P00?Woo00<007ooOol0<Woo
000LOol00`00Oomoo`0mOol00`00Oomoo`0bOol001aoo`03001oogoo03ioo`03001oogoo035oo`00
77oo0P00?goo0P00<Woo000FOol30003Ool00`00Oomoo`0oOol00`00Oomoo`0`Ool001Moo`03001o
ogoo009oo`03001oogoo03moo`80035oo`005goo00<007ooOol00Woo0P00@Goo00<007ooOol0;goo
000GOol00`00Oomoo`02Ool00`00Oomoo`11Ool00`00Oomoo`0^Ool001Moo`03001oogoo009oo`03
001oogoo045oo`03001oogoo02ioo`005Woo0P0017oo0P00@goo00<007ooOol0;Goo000GOol00`00
Oomoo`02Ool00`00Oomoo`12Ool00`00Oomoo`0]Ool001aoo`03001oogoo04=oo`03001oogoo02ao
o`0077oo0P00A7oo00<007ooOol0;7oo000LOol00`00Oomoo`13Ool00`00Oomoo`0/Ool001aoo`80
04Eoo`03001oogoo02]oo`0077oo00<007ooOol0A7oo0P00;7oo000LOol00`00Oomoo`15Ool00`00
Oomoo`0ZOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8004Moo`03001oogoo02Uoo`002goo
00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo04Ioo`8002Yoo`002goo00<007ooOol0
2goo00@007ooOol004Yoo`@002Ioo`002goo00<007ooOol02goo00<007ooOol00P00C7oo6`0037oo
000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03
001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(40915\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31919 m
.008 .31946 L
.012 .31992 L
.016 .31978 L
.02 .31846 L
.024 .31793 L
.028 .31822 L
.032 .31814 L
.036 .31823 L
.04 .31874 L
.044 .3199 L
.048 .32099 L
.052 .32141 L
.056 .32145 L
.06 .32084 L
.064 .31998 L
.068 .31909 L
.072 .31849 L
.076 .31867 L
.08 .31917 L
.084 .31975 L
.088 .32006 L
.092 .32015 L
.096 .3204 L
.1 .32053 L
.104 .32056 L
.108 .32052 L
.112 .32043 L
.116 .32001 L
.12 .31869 L
.124 .31709 L
.128 .31634 L
.132 .31717 L
.136 .31934 L
.14 .32199 L
.144 .32457 L
.148 .3262 L
.152 .32584 L
.156 .32291 L
.16 .31828 L
.164 .31422 L
.168 .31264 L
.172 .31392 L
.176 .31696 L
.18 .32049 L
.184 .32361 L
.188 .32538 L
.192 .32504 L
.196 .32269 L
.2 .3198 L
Mistroke
.204 .31825 L
.208 .31879 L
.212 .32046 L
.216 .32151 L
.22 .32101 L
.224 .31939 L
.228 .31776 L
.232 .31697 L
.236 .31717 L
.24 .31815 L
.244 .31967 L
.248 .32154 L
.252 .32339 L
.256 .32456 L
.26 .32448 L
.264 .32325 L
.268 .32185 L
.272 .32145 L
.276 .32216 L
.28 .32255 L
.284 .32078 L
.288 .31654 L
.292 .31194 L
.296 .31006 L
.3 .31226 L
.304 .31685 L
.308 .32068 L
.312 .32208 L
.316 .32232 L
.32 .32396 L
.324 .32782 L
.328 .33173 L
.332 .33243 L
.336 .32884 L
.34 .32332 L
.344 .31957 L
.348 .31924 L
.352 .3205 L
.356 .32002 L
.36 .31631 L
.364 .31127 L
.368 .30857 L
.372 .31033 L
.376 .31531 L
.38 .31999 L
.384 .32143 L
.388 .31942 L
.392 .31619 L
.396 .31435 L
.4 .3151 L
Mistroke
.404 .31786 L
.408 .32131 L
.412 .32448 L
.416 .327 L
.42 .32868 L
.424 .32924 L
.428 .32878 L
.432 .32835 L
.436 .32977 L
.44 .33442 L
.444 .34181 L
.448 .34913 L
.452 .35257 L
.456 .3497 L
.46 .34135 L
.464 .33151 L
.468 .3252 L
.472 .32559 L
.476 .33222 L
.48 .34134 L
.484 .34816 L
.488 .34951 L
.492 .34525 L
.496 .33789 L
.5 .33079 L
.504 .32623 L
.508 .32456 L
.512 .32476 L
.516 .32576 L
.52 .3275 L
.524 .33108 L
.528 .33775 L
.532 .34761 L
.536 .35878 L
.54 .36775 L
.544 .37085 L
.548 .36589 L
.552 .35335 L
.556 .33612 L
.56 .31825 L
.564 .30308 L
.568 .29187 L
.572 .28358 L
.576 .27579 L
.58 .26613 L
.584 .25357 L
.588 .23891 L
.592 .22437 L
.596 .21254 L
.6 .20539 L
Mistroke
.604 .2035 L
.608 .2059 L
.612 .21037 L
.616 .21416 L
.62 .21488 L
.624 .21124 L
.628 .20355 L
.632 .19359 L
.636 .18401 L
.64 .17734 L
.644 .17518 L
.648 .17774 L
.652 .18392 L
.656 .19186 L
.66 .19942 L
.664 .20471 L
.668 .20634 L
.672 .20357 L
.676 .19647 L
.68 .18594 L
.684 .17352 L
.688 .16112 L
.692 .15055 L
.696 .14315 L
.7 .13973 L
.704 .14053 L
.708 .14543 L
.712 .15398 L
.716 .16547 L
.72 .17895 L
.724 .19337 L
.728 .20781 L
.732 .22164 L
.736 .2345 L
.74 .24619 L
.744 .25652 L
.748 .26533 L
.752 .27256 L
.756 .27831 L
.76 .28286 L
.764 .28652 L
.768 .2895 L
.772 .29186 L
.776 .29364 L
.78 .29491 L
.784 .29579 L
.788 .29646 L
.792 .29701 L
.796 .29749 L
.8 .29788 L
Mistroke
.804 .29818 L
.808 .29841 L
.812 .29861 L
.816 .29877 L
.82 .2989 L
.824 .29896 L
.828 .29899 L
.832 .29904 L
.836 .29914 L
.84 .29926 L
.844 .29936 L
.848 .29937 L
.852 .29935 L
.856 .29935 L
.86 .29938 L
.864 .29944 L
.868 .29947 L
.872 .29944 L
.876 .2994 L
.88 .2994 L
.884 .29946 L
.888 .29953 L
.892 .29955 L
.896 .2995 L
.9 .29943 L
.904 .2994 L
.908 .29942 L
.912 .29945 L
.916 .29947 L
.92 .29948 L
.924 .29948 L
.928 .29949 L
.932 .29948 L
.936 .29943 L
.94 .29939 L
.944 .29937 L
.948 .2994 L
.952 .29946 L
.956 .29949 L
.96 .29946 L
.964 .29941 L
.968 .29938 L
.972 .29937 L
.976 .29939 L
.98 .2994 L
.984 .29938 L
.988 .29938 L
.992 .2994 L
.996 .29941 L
1 .2994 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12019 m
.008 .12094 L
.012 .12123 L
.016 .1212 L
.02 .12102 L
.024 .12103 L
.028 .12107 L
.032 .1211 L
.036 .12103 L
.04 .12102 L
.044 .12102 L
.048 .12105 L
.052 .12105 L
.056 .12109 L
.06 .12109 L
.064 .12109 L
.068 .12106 L
.072 .12103 L
.076 .12099 L
.08 .12097 L
.084 .12096 L
.088 .12101 L
.092 .12107 L
.096 .12115 L
.1 .1212 L
.104 .12123 L
.108 .12121 L
.112 .12116 L
.116 .12106 L
.12 .12095 L
.124 .12086 L
.128 .12082 L
.132 .12083 L
.136 .12087 L
.14 .12096 L
.144 .12109 L
.148 .12122 L
.152 .1213 L
.156 .12132 L
.16 .12129 L
.164 .12124 L
.168 .12115 L
.172 .12103 L
.176 .1209 L
.18 .12082 L
.184 .12081 L
.188 .12085 L
.192 .1209 L
.196 .12096 L
.2 .12105 L
Mistroke
.204 .12117 L
.208 .12127 L
.212 .1213 L
.216 .12127 L
.22 .12122 L
.224 .12117 L
.228 .1211 L
.232 .12099 L
.236 .12084 L
.24 .12072 L
.244 .12069 L
.248 .12074 L
.252 .12085 L
.256 .12097 L
.26 .12109 L
.264 .12125 L
.268 .12146 L
.272 .12168 L
.276 .12181 L
.28 .12176 L
.284 .12156 L
.288 .12127 L
.292 .12101 L
.296 .12075 L
.3 .12045 L
.304 .1201 L
.308 .11979 L
.312 .11969 L
.316 .1199 L
.32 .12035 L
.324 .12085 L
.328 .12125 L
.332 .12156 L
.336 .1219 L
.34 .12233 L
.344 .12277 L
.348 .123 L
.352 .12287 L
.356 .12242 L
.36 .12184 L
.364 .12137 L
.368 .12109 L
.372 .12088 L
.376 .12058 L
.38 .1201 L
.384 .11952 L
.388 .11902 L
.392 .11874 L
.396 .11869 L
.4 .11877 L
Mistroke
.404 .11885 L
.408 .11885 L
.412 .11879 L
.416 .11873 L
.42 .1188 L
.424 .11914 L
.428 .11984 L
.432 .12094 L
.436 .12236 L
.44 .12392 L
.444 .12542 L
.448 .12676 L
.452 .128 L
.456 .12935 L
.46 .13104 L
.464 .13319 L
.468 .13568 L
.472 .13821 L
.476 .14046 L
.48 .14222 L
.484 .1435 L
.488 .14452 L
.492 .14561 L
.496 .14701 L
.5 .14884 L
.504 .15109 L
.508 .15365 L
.512 .15642 L
.516 .15932 L
.52 .16227 L
.524 .16514 L
.528 .16776 L
.532 .16997 L
.536 .17165 L
.54 .17283 L
.544 .1737 L
.548 .17456 L
.552 .17575 L
.556 .17752 L
.56 .17997 L
.564 .18305 L
.568 .18664 L
.572 .19058 L
.576 .19479 L
.58 .19927 L
.584 .20411 L
.588 .20941 L
.592 .21519 L
.596 .22139 L
.6 .22786 L
Mistroke
.604 .23438 L
.608 .24074 L
.612 .24682 L
.616 .2526 L
.62 .25817 L
.624 .2637 L
.628 .26935 L
.632 .27526 L
.636 .28146 L
.64 .2879 L
.644 .29444 L
.648 .30091 L
.652 .30715 L
.656 .31305 L
.66 .31858 L
.664 .32381 L
.668 .32886 L
.672 .33392 L
.676 .33916 L
.68 .34474 L
.684 .35076 L
.688 .35724 L
.692 .36414 L
.696 .37137 L
.7 .37876 L
.704 .38616 L
.708 .39338 L
.712 .40028 L
.716 .40671 L
.72 .41259 L
.724 .41786 L
.728 .4225 L
.732 .42651 L
.736 .42994 L
.74 .43283 L
.744 .43524 L
.748 .43723 L
.752 .43887 L
.756 .44021 L
.76 .4413 L
.764 .4422 L
.768 .44293 L
.772 .44353 L
.776 .44404 L
.78 .44445 L
.784 .4448 L
.788 .4451 L
.792 .44535 L
.796 .44557 L
.8 .44576 L
Mistroke
.804 .44593 L
.808 .44607 L
.812 .44619 L
.816 .4463 L
.82 .4464 L
.824 .44649 L
.828 .44656 L
.832 .44663 L
.836 .44669 L
.84 .44675 L
.844 .4468 L
.848 .44685 L
.852 .44689 L
.856 .44693 L
.86 .44697 L
.864 .447 L
.868 .44704 L
.872 .44707 L
.876 .44711 L
.88 .44714 L
.884 .44717 L
.888 .4472 L
.892 .44722 L
.896 .44726 L
.9 .44728 L
.904 .44731 L
.908 .44734 L
.912 .44737 L
.916 .4474 L
.92 .44743 L
.924 .44745 L
.928 .44748 L
.932 .4475 L
.936 .44754 L
.94 .44756 L
.944 .44759 L
.948 .44761 L
.952 .44765 L
.956 .44767 L
.96 .4477 L
.964 .44772 L
.968 .44776 L
.972 .44777 L
.976 .44782 L
.98 .44783 L
.984 .44787 L
.988 .44788 L
.992 .44793 L
.996 .44793 L
1 .44798 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15755 L
.012 .1613 L
.016 .16248 L
.02 .16127 L
.024 .16081 L
.028 .16122 L
.032 .16129 L
.036 .16113 L
.04 .16102 L
.044 .16105 L
.048 .16103 L
.052 .16103 L
.056 .16102 L
.06 .16107 L
.064 .16108 L
.068 .1611 L
.072 .16109 L
.076 .16108 L
.08 .16104 L
.084 .16101 L
.088 .16098 L
.092 .161 L
.096 .16102 L
.1 .16106 L
.104 .16108 L
.108 .16111 L
.112 .16109 L
.116 .16101 L
.12 .16089 L
.124 .16077 L
.128 .16069 L
.132 .16065 L
.136 .16066 L
.14 .16074 L
.144 .16089 L
.148 .16107 L
.152 .16118 L
.156 .16121 L
.16 .16118 L
.164 .1611 L
.168 .16097 L
.172 .16078 L
.176 .1606 L
.18 .16049 L
.184 .16047 L
.188 .16053 L
.192 .1606 L
.196 .16068 L
.2 .1608 L
Mistroke
.204 .16094 L
.208 .16104 L
.212 .16105 L
.216 .16097 L
.22 .16088 L
.224 .1608 L
.228 .16072 L
.232 .1606 L
.236 .16044 L
.24 .1603 L
.244 .16024 L
.248 .16029 L
.252 .1604 L
.256 .16052 L
.26 .16066 L
.264 .16085 L
.268 .16111 L
.272 .16138 L
.276 .16153 L
.28 .16146 L
.284 .16118 L
.288 .16083 L
.292 .16049 L
.296 .16018 L
.3 .15981 L
.304 .15936 L
.308 .15895 L
.312 .15881 L
.316 .15906 L
.32 .15961 L
.324 .16022 L
.328 .16072 L
.332 .1611 L
.336 .16151 L
.34 .16203 L
.344 .16257 L
.348 .16286 L
.352 .1627 L
.356 .16212 L
.36 .1614 L
.364 .1608 L
.368 .16043 L
.372 .16014 L
.376 .15975 L
.38 .15914 L
.384 .15842 L
.388 .1578 L
.392 .15745 L
.396 .15739 L
.4 .15748 L
Mistroke
.404 .15757 L
.408 .15756 L
.412 .15746 L
.416 .15737 L
.42 .15744 L
.424 .15785 L
.428 .15872 L
.432 .1601 L
.436 .16187 L
.44 .16381 L
.444 .16568 L
.448 .16733 L
.452 .16885 L
.456 .17051 L
.46 .1726 L
.464 .17526 L
.468 .17835 L
.472 .1815 L
.476 .1843 L
.48 .18648 L
.484 .18807 L
.488 .18933 L
.492 .19066 L
.496 .19239 L
.5 .19465 L
.504 .19743 L
.508 .20061 L
.512 .20406 L
.516 .20765 L
.52 .2113 L
.524 .21486 L
.528 .21811 L
.532 .22085 L
.536 .22293 L
.54 .22439 L
.544 .22545 L
.548 .22649 L
.552 .22794 L
.556 .23011 L
.56 .23315 L
.564 .23698 L
.568 .24144 L
.572 .24634 L
.576 .25156 L
.58 .25711 L
.584 .26312 L
.588 .26968 L
.592 .27685 L
.596 .28455 L
.6 .29258 L
Mistroke
.604 .30067 L
.608 .30858 L
.612 .31613 L
.616 .3233 L
.62 .3302 L
.624 .33704 L
.628 .34404 L
.632 .35135 L
.636 .35904 L
.64 .36702 L
.644 .37514 L
.648 .38316 L
.652 .39088 L
.656 .39818 L
.66 .40503 L
.664 .41149 L
.668 .41774 L
.672 .42398 L
.676 .43046 L
.68 .43736 L
.684 .4448 L
.688 .45282 L
.692 .46137 L
.696 .47031 L
.7 .47946 L
.704 .48861 L
.708 .49755 L
.712 .50607 L
.716 .51402 L
.72 .52127 L
.724 .52776 L
.728 .53347 L
.732 .5384 L
.736 .54261 L
.74 .54614 L
.744 .54906 L
.748 .55147 L
.752 .55343 L
.756 .55502 L
.76 .5563 L
.764 .55734 L
.768 .55818 L
.772 .55886 L
.776 .55941 L
.78 .55985 L
.784 .56021 L
.788 .5605 L
.792 .56074 L
.796 .56094 L
.8 .5611 L
Mistroke
.804 .56122 L
.808 .56133 L
.812 .5614 L
.816 .56146 L
.82 .5615 L
.824 .56153 L
.828 .56155 L
.832 .56156 L
.836 .56156 L
.84 .56156 L
.844 .56154 L
.848 .56152 L
.852 .5615 L
.856 .56147 L
.86 .56144 L
.864 .56141 L
.868 .56138 L
.872 .56134 L
.876 .5613 L
.88 .56127 L
.884 .56122 L
.888 .56119 L
.892 .56114 L
.896 .5611 L
.9 .56106 L
.904 .56102 L
.908 .56098 L
.912 .56094 L
.916 .56089 L
.92 .56085 L
.924 .5608 L
.928 .56077 L
.932 .56072 L
.936 .56068 L
.94 .56063 L
.944 .5606 L
.948 .56055 L
.952 .56051 L
.956 .56046 L
.96 .56043 L
.964 .56037 L
.968 .56034 L
.972 .56028 L
.976 .56026 L
.98 .5602 L
.984 .56018 L
.988 .56011 L
.992 .56009 L
.996 .56002 L
1 .56 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00@Woo0P00:Goo0003Ool50002
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80049oo`<002Qoo`002Woo00@0
07ooOol000Qoo`04001oogoo0004Ool01@00Oomoogoo0000@Woo00@007ooOol002Qoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00?Goo00D007ooOomoo`00009oo`03
001oogoo02Ioo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00?7oo
0`000Woo00@007ooOol002Qoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0>goo00D007oo
001oo`0000Aoo`03001oogoo02Eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00
>Goo00<007oo00000Woo0`0017oo00<007ooOol09Goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8000eoo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000Eoo`<000=oo`D0
009oo`8000=oo`D000=oo`8000Aoo`8000Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo0000
0Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00T007oo
Oomoo`00Ool007oo00000Woo00@007ooOol000=oo`800005Ool007ooOol00002Ool01000Oomoo`00
0Woo00<007ooOol00Woo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00=o
o`03001oo`00009oo`04001oogoo0004Ool20003Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
00<007ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`80
00Yoo`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`8000Eoo`04001oogoo0002Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo
0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogoo
Ool50003Ool20004Ool40003Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001o
ogoo03Eoo`03001oogoo00moo`8002=oo`008Woo0P00=Goo00<007ooOol04Goo1@007goo000ROomS
000<Ool0029oo`D0009oo`8000=oo`80009oo`80009oo`03001oo`000080009oo`D0009oo`L0009o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`0:
Ool0029oo`<00005Ool00000001oo`04000017oo000000000Woo1@0000=oo`0000000`0000=oo`00
0000100000Aoo`00001oo`<000=oo`03001oogoo00<000=oo`03001oogoo03Eoo`008Woo00<007oo
Ool07Goo00<007ooOol027oo00@007oo001oo`<00005Ool00000Ool0000hOol0029oo`8002Uoo`<0
0003Ool0000000=oo`03001oo`0003Qoo`008Woo0P00:Woo00<007ooOol01Goo00<007oo0000>7oo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0bOol2000hOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00<goo00<007ooOol0=goo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004
Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`80
06eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool3
0003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<0
07ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo
000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000R
Ool2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000
Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009
Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo:P00?goo000@Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000Aoo`03001oogoo02Ioo`<003eoo`004Goo0P002Woo0P0017oo00<007ooOol00Woo
00<007ooOol0:Goo0`00>Woo000XOol00`00Oomoo`0[Ool2000iOol002Qoo`03001oogoo02eoo`80
03Moo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0;Woo0`00
=Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol0
03=oo`03001oogoo039oo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOol003Aoo`80039oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo
0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo
00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00H0
07ooOomoo`00Ool30002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0
009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo
Ool017oo0P000Woo00@007ooOol000=oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
17oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P00
0Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009o
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`H00007Ool007ooOol007oo
00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo
00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Ao
o`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol00Woo0`000Woo00<007oo0000
0goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007oo
Ool000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo
00@007ooOomoo`D00003Ool007oo008000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`80
00Ioo`00:7oo00<007ooOol0=goo0P00;Goo000XOol00`00Oomoo`0hOol00`00Oomoo`0[Ool002Qo
oed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol00Woo
0P002goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`0jOol2000ZOol002Qoo`03
001oogoo03]oo`03001oogoo02Qoo`00:7oo00<007ooOol0?7oo00<007ooOol09goo000XOol00`00
Oomoo`0lOol00`00Oomoo`0WOol002Qoo`03001oogoo03eoo`03001oogoo02Ioo`002goo0P0017oo
00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0?Goo00<007ooOol09Woo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol0041oo`03001o
ogoo02Eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0
045oo`03001oogoo02Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol00P00@7oo0P009Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo
001oo`040003Ool00`00Oomoo`10Ool2000TOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0006Ool00`00Oomoo`11Ool4000QOol000]oo`8000Yoo`8000Aoo`80009oo`D0
009oo`03001oogoo04EooaD000aoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007oo
Ool0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001o
ogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo
000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007oo
Ool00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@0
00=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P00
27oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004
Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006
Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=o
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@0
07ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo
00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0
009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo
10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03
001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=o
o`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`80
00Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004
Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01000Oomoogoo0`0000=o
o`00Ool00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomo
o`0:Ool001aoo`03001oogoo02eoo`8004=oo`0077oo0P00;goo0`00@Goo000LOol00`00Oomoo`0a
Ool2000oOol001aoo`03001oogoo039oo`8003ioo`0077oo0P00=7oo0P00?Goo000LOol00`00Oomo
o`0eOol3000jOol001aoo`03001oogoo03Moo`8003Uoo`0077oo0P00>Goo00<007ooOol0=goo000L
Ool00`00Oomoo`0iOol00`00Oomoo`0fOol001aoo`8003]oo`03001oogoo03Eoo`002goo0P0017oo
00<007ooOol00Woo0`000goo00<007ooOol0>Woo00<007ooOol0=Goo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo03]oo`03001oogoo03Aoo`002Woo00@007ooOol000]oo`03
001oogoo008003aoo`03001oogoo03Aoo`002Woo00@007ooOol000]oo`04001oogoo000nOol00`00
Oomoo`0cOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0lOol00`00Oomoo`0cOol000Yo
o`04001oogoo0007Ool00`00Oomoo`04Ool2000nOol00`00Oomoo`0bOol000]oo`8000Qoo`D0009o
o`03001oogoo03eoo`8003=oo`0077oo00<007ooOol0?Woo00<007ooOol0<Goo000LOol20010Ool0
0`00Oomoo`0`Ool001aoo`03001oogoo03moo`03001oogoo031oo`0077oo0P00@7oo0P00<Goo000L
Ool00`00Oomoo`10Ool00`00Oomoo`0_Ool001aoo`03001oogoo045oo`03001oogoo02ioo`0077oo
0P00@Woo00<007ooOol0;Woo000FOol30003Ool00`00Oomoo`12Ool00`00Oomoo`0]Ool001Moo`03
001oogoo009oo`03001oogoo049oo`8002ioo`005goo00<007ooOol00Woo0P00A7oo00<007ooOol0
;7oo000GOol00`00Oomoo`02Ool00`00Oomoo`13Ool00`00Oomoo`0/Ool001Moo`03001oogoo009o
o`03001oogoo04Aoo`03001oogoo02]oo`005Woo0P0017oo0P00AWoo00<007ooOol0:Woo000GOol0
0`00Oomoo`02Ool00`00Oomoo`15Ool00`00Oomoo`0ZOol001aoo`03001oogoo04Ioo`03001oogoo
02Uoo`0077oo0P00Agoo00<007ooOol0:Goo000LOol00`00Oomoo`16Ool00`00Oomoo`0YOol001ao
o`8004Qoo`03001oogoo02Qoo`0077oo00<007ooOol0Agoo0P00:Goo000LOol00`00Oomoo`18Ool0
0`00Oomoo`0WOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8004Uoo`8002Qoo`002goo00<0
07ooOol01goo00D007ooOomoo`00009oo`03001oogoo04Uoo`8002Moo`002goo00<007ooOol02goo
00@007ooOol004eoo`@001Aoo`<000aoo`002goo00<007ooOol02goo00<007ooOol00P00Cgoo5P00
3Woo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Ao
o`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(41082\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31901 m
.008 .32006 L
.012 .31982 L
.016 .31961 L
.02 .3196 L
.024 .31935 L
.028 .31931 L
.032 .31965 L
.036 .32005 L
.04 .32059 L
.044 .32094 L
.048 .32111 L
.052 .32071 L
.056 .31963 L
.06 .3184 L
.064 .31719 L
.068 .31665 L
.072 .3171 L
.076 .31863 L
.08 .32105 L
.084 .32314 L
.088 .32405 L
.092 .32325 L
.096 .32099 L
.1 .31811 L
.104 .31545 L
.108 .31449 L
.112 .31606 L
.116 .31961 L
.12 .32348 L
.124 .3258 L
.128 .32587 L
.132 .32356 L
.136 .31948 L
.14 .3151 L
.144 .31241 L
.148 .31295 L
.152 .31639 L
.156 .32091 L
.16 .32448 L
.164 .32607 L
.168 .32575 L
.172 .3238 L
.176 .32086 L
.18 .31813 L
.184 .31691 L
.188 .31745 L
.192 .31856 L
.196 .31896 L
.2 .31843 L
Mistroke
.204 .31796 L
.208 .31858 L
.212 .32023 L
.216 .32207 L
.22 .32338 L
.224 .32391 L
.228 .32361 L
.232 .32235 L
.236 .32023 L
.24 .31798 L
.244 .31673 L
.248 .31719 L
.252 .31894 L
.256 .32061 L
.26 .32089 L
.264 .31966 L
.268 .31816 L
.272 .31803 L
.276 .3199 L
.28 .32273 L
.284 .32475 L
.288 .32501 L
.292 .32413 L
.296 .32338 L
.3 .32309 L
.304 .32221 L
.308 .31964 L
.312 .31589 L
.316 .31309 L
.32 .31305 L
.324 .31535 L
.328 .31758 L
.332 .31791 L
.336 .31713 L
.34 .31805 L
.344 .32251 L
.348 .32903 L
.352 .33355 L
.356 .33295 L
.36 .3279 L
.364 .32233 L
.368 .32002 L
.372 .32135 L
.376 .32324 L
.38 .32216 L
.384 .31742 L
.388 .31176 L
.392 .30895 L
.396 .31068 L
.4 .31537 L
Mistroke
.404 .31968 L
.408 .32113 L
.412 .31959 L
.416 .3168 L
.42 .31477 L
.424 .31457 L
.428 .3162 L
.432 .31919 L
.436 .32291 L
.44 .32651 L
.444 .32879 L
.448 .32881 L
.452 .32679 L
.456 .32467 L
.46 .32524 L
.464 .33031 L
.468 .33903 L
.472 .34779 L
.476 .35214 L
.48 .34945 L
.484 .34081 L
.488 .33058 L
.492 .32394 L
.496 .32398 L
.5 .33012 L
.504 .33871 L
.508 .34533 L
.512 .34714 L
.516 .34411 L
.52 .33833 L
.524 .33241 L
.528 .32795 L
.532 .32506 L
.536 .32305 L
.54 .32156 L
.544 .3213 L
.548 .32379 L
.552 .33038 L
.556 .34102 L
.56 .35369 L
.564 .36481 L
.568 .37058 L
.572 .36851 L
.576 .35852 L
.58 .34296 L
.584 .32556 L
.588 .30984 L
.592 .29762 L
.596 .28847 L
.6 .28028 L
Mistroke
.604 .27055 L
.608 .25783 L
.612 .24249 L
.616 .22656 L
.62 .21284 L
.624 .20364 L
.628 .19993 L
.632 .20104 L
.636 .20496 L
.64 .20904 L
.644 .2108 L
.648 .20865 L
.652 .20232 L
.656 .193 L
.66 .1829 L
.664 .17459 L
.668 .17016 L
.672 .17054 L
.676 .17533 L
.68 .18299 L
.684 .1914 L
.688 .19838 L
.692 .20215 L
.696 .20159 L
.7 .19642 L
.704 .18718 L
.708 .17519 L
.712 .16224 L
.716 .15023 L
.72 .14075 L
.724 .13488 L
.728 .13315 L
.732 .13566 L
.736 .14218 L
.74 .15217 L
.744 .1648 L
.748 .17907 L
.752 .19396 L
.756 .20865 L
.76 .22259 L
.764 .23546 L
.768 .24704 L
.772 .25719 L
.776 .26579 L
.78 .27286 L
.784 .27854 L
.788 .28307 L
.792 .28668 L
.796 .28954 L
.8 .29175 L
Mistroke
.804 .29344 L
.808 .29471 L
.812 .29569 L
.816 .29647 L
.82 .29708 L
.824 .29752 L
.828 .29782 L
.832 .29807 L
.836 .29831 L
.84 .29856 L
.844 .29878 L
.848 .29892 L
.852 .29897 L
.856 .299 L
.86 .29905 L
.864 .29915 L
.868 .29926 L
.872 .29934 L
.876 .29938 L
.88 .29941 L
.884 .29942 L
.888 .29942 L
.892 .2994 L
.896 .29938 L
.9 .2994 L
.904 .29947 L
.908 .29955 L
.912 .29958 L
.916 .29955 L
.92 .29947 L
.924 .2994 L
.928 .2994 L
.932 .29945 L
.936 .2995 L
.94 .29953 L
.944 .29953 L
.948 .29952 L
.952 .29949 L
.956 .29945 L
.96 .29941 L
.964 .2994 L
.968 .29942 L
.972 .29947 L
.976 .29951 L
.98 .29951 L
.984 .29946 L
.988 .29942 L
.992 .29941 L
.996 .29941 L
1 .29941 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12647 m
.008 .1215 L
.012 .11982 L
.016 .12154 L
.02 .12207 L
.024 .12153 L
.028 .12133 L
.032 .12156 L
.036 .12162 L
.04 .12157 L
.044 .12152 L
.048 .12154 L
.052 .12152 L
.056 .12151 L
.06 .12149 L
.064 .1215 L
.068 .1215 L
.072 .12153 L
.076 .12154 L
.08 .12156 L
.084 .12155 L
.088 .12154 L
.092 .12152 L
.096 .12151 L
.1 .12148 L
.104 .12147 L
.108 .12147 L
.112 .1215 L
.116 .12153 L
.12 .12157 L
.124 .12161 L
.128 .12166 L
.132 .12167 L
.136 .12164 L
.14 .12157 L
.144 .12149 L
.148 .12142 L
.152 .12135 L
.156 .1213 L
.16 .1213 L
.164 .12138 L
.168 .1215 L
.172 .12161 L
.176 .1217 L
.18 .12176 L
.184 .1218 L
.188 .12178 L
.192 .12169 L
.196 .12155 L
.2 .12143 L
Mistroke
.204 .12134 L
.208 .1213 L
.212 .12128 L
.216 .1213 L
.22 .12137 L
.224 .12149 L
.228 .12163 L
.232 .12172 L
.236 .12174 L
.24 .12173 L
.244 .12171 L
.248 .12169 L
.252 .12162 L
.256 .1215 L
.26 .12136 L
.264 .12124 L
.268 .1212 L
.272 .12122 L
.276 .12127 L
.28 .12132 L
.284 .12141 L
.288 .1216 L
.292 .12187 L
.296 .12213 L
.3 .12227 L
.304 .12223 L
.308 .12208 L
.312 .1219 L
.316 .12172 L
.32 .12148 L
.324 .12112 L
.328 .12066 L
.332 .12028 L
.336 .12014 L
.34 .12032 L
.344 .12069 L
.348 .12107 L
.352 .12138 L
.356 .12169 L
.36 .12211 L
.364 .12265 L
.368 .12318 L
.372 .12346 L
.376 .12337 L
.38 .12298 L
.384 .12252 L
.388 .12215 L
.392 .12191 L
.396 .12168 L
.4 .12132 L
Mistroke
.404 .1208 L
.408 .12022 L
.412 .11971 L
.416 .1194 L
.42 .11929 L
.424 .11931 L
.428 .11935 L
.432 .11934 L
.436 .11924 L
.44 .1191 L
.444 .11904 L
.448 .1192 L
.452 .11973 L
.456 .12069 L
.46 .12201 L
.464 .12349 L
.468 .12492 L
.472 .12617 L
.476 .12731 L
.48 .12855 L
.484 .13014 L
.488 .13221 L
.492 .13466 L
.496 .13721 L
.5 .13954 L
.504 .1414 L
.508 .1428 L
.512 .1439 L
.516 .14498 L
.52 .14628 L
.524 .14793 L
.528 .14996 L
.532 .1523 L
.536 .15492 L
.54 .15774 L
.544 .16071 L
.548 .1637 L
.552 .16652 L
.556 .16896 L
.56 .17087 L
.564 .17222 L
.568 .17316 L
.572 .17397 L
.576 .17499 L
.58 .17648 L
.584 .17859 L
.588 .18132 L
.592 .18457 L
.596 .18818 L
.6 .1921 L
Mistroke
.604 .1963 L
.608 .20086 L
.612 .20588 L
.616 .21141 L
.62 .21742 L
.624 .22376 L
.628 .23025 L
.632 .23665 L
.636 .24281 L
.64 .24868 L
.644 .2543 L
.648 .25982 L
.652 .26541 L
.656 .27122 L
.66 .27731 L
.664 .28366 L
.668 .29018 L
.672 .2967 L
.676 .30305 L
.68 .30911 L
.684 .3148 L
.688 .32016 L
.692 .32526 L
.696 .33029 L
.7 .33541 L
.704 .34078 L
.708 .34655 L
.712 .35277 L
.716 .35943 L
.72 .36648 L
.724 .37378 L
.728 .38119 L
.732 .38853 L
.736 .39564 L
.74 .40237 L
.744 .4086 L
.748 .41427 L
.752 .41932 L
.756 .42376 L
.76 .42759 L
.764 .43085 L
.768 .43359 L
.772 .43588 L
.776 .43777 L
.78 .43932 L
.784 .44059 L
.788 .44163 L
.792 .44249 L
.796 .44319 L
.8 .44377 L
Mistroke
.804 .44425 L
.808 .44465 L
.812 .44499 L
.816 .44527 L
.82 .44552 L
.824 .44573 L
.828 .44591 L
.832 .44607 L
.836 .44621 L
.84 .44633 L
.844 .44643 L
.848 .44653 L
.852 .44661 L
.856 .44669 L
.86 .44675 L
.864 .44681 L
.868 .44687 L
.872 .44692 L
.876 .44696 L
.88 .44701 L
.884 .44704 L
.888 .44708 L
.892 .44712 L
.896 .44716 L
.9 .44719 L
.904 .44722 L
.908 .44725 L
.912 .44728 L
.916 .44731 L
.92 .44734 L
.924 .44736 L
.928 .4474 L
.932 .44742 L
.936 .44746 L
.94 .44748 L
.944 .44751 L
.948 .44753 L
.952 .44757 L
.956 .44758 L
.96 .44762 L
.964 .44764 L
.968 .44768 L
.972 .4477 L
.976 .44774 L
.98 .44775 L
.984 .44779 L
.988 .4478 L
.992 .44785 L
.996 .44785 L
1 .44791 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16031 L
.012 .161 L
.016 .16134 L
.02 .16123 L
.024 .16102 L
.028 .16104 L
.032 .1611 L
.036 .16117 L
.04 .16115 L
.044 .1612 L
.048 .16121 L
.052 .16122 L
.056 .16116 L
.06 .16112 L
.064 .16104 L
.068 .16099 L
.072 .16094 L
.076 .16095 L
.08 .16097 L
.084 .16102 L
.088 .16105 L
.092 .16108 L
.096 .16106 L
.1 .16101 L
.104 .16094 L
.108 .1609 L
.112 .16089 L
.116 .16092 L
.12 .16096 L
.124 .16103 L
.128 .16109 L
.132 .16112 L
.136 .16108 L
.14 .16097 L
.144 .16085 L
.148 .16073 L
.152 .16062 L
.156 .16055 L
.16 .16055 L
.164 .16066 L
.168 .16081 L
.172 .16097 L
.176 .16107 L
.18 .16114 L
.184 .16116 L
.188 .1611 L
.192 .16095 L
.196 .16076 L
.2 .16059 L
Mistroke
.204 .1605 L
.208 .16047 L
.212 .16046 L
.216 .16049 L
.22 .16056 L
.224 .16069 L
.228 .16083 L
.232 .16092 L
.236 .16094 L
.24 .16092 L
.244 .16089 L
.248 .16086 L
.252 .16077 L
.256 .1606 L
.26 .16041 L
.264 .16026 L
.268 .1602 L
.272 .16024 L
.276 .16029 L
.28 .16035 L
.284 .16044 L
.288 .16065 L
.292 .16097 L
.296 .16128 L
.3 .16145 L
.304 .1614 L
.308 .16121 L
.312 .16097 L
.316 .16074 L
.32 .16043 L
.324 .15998 L
.328 .15941 L
.332 .15893 L
.336 .15875 L
.34 .15896 L
.344 .15939 L
.348 .15985 L
.352 .16022 L
.356 .16059 L
.36 .16111 L
.364 .1618 L
.368 .16245 L
.372 .1628 L
.376 .16268 L
.38 .16219 L
.384 .16159 L
.388 .16111 L
.392 .16079 L
.396 .16049 L
.4 .16003 L
Mistroke
.404 .15938 L
.408 .15865 L
.412 .15803 L
.416 .15764 L
.42 .1575 L
.424 .15751 L
.428 .15754 L
.432 .1575 L
.436 .15736 L
.44 .15718 L
.444 .1571 L
.448 .1573 L
.452 .15795 L
.456 .15915 L
.46 .16078 L
.464 .16262 L
.468 .16439 L
.472 .16593 L
.476 .16734 L
.48 .16887 L
.484 .17084 L
.488 .17341 L
.492 .17646 L
.496 .17962 L
.5 .1825 L
.504 .18482 L
.508 .18655 L
.512 .18792 L
.516 .18925 L
.52 .19086 L
.524 .19289 L
.528 .19538 L
.532 .19828 L
.536 .20153 L
.54 .20504 L
.544 .20874 L
.548 .21245 L
.552 .21595 L
.556 .21896 L
.56 .22131 L
.564 .22297 L
.568 .22412 L
.572 .22511 L
.576 .22636 L
.58 .2282 L
.584 .23082 L
.588 .23421 L
.592 .23823 L
.596 .24272 L
.6 .24756 L
Mistroke
.604 .25276 L
.608 .25842 L
.612 .26465 L
.616 .27152 L
.62 .27899 L
.624 .28687 L
.628 .29491 L
.632 .30285 L
.636 .31049 L
.64 .31777 L
.644 .32475 L
.648 .33159 L
.652 .33851 L
.656 .3457 L
.66 .35325 L
.664 .36113 L
.668 .36921 L
.672 .37729 L
.676 .38516 L
.68 .39266 L
.684 .3997 L
.688 .40632 L
.692 .41263 L
.696 .41884 L
.7 .42516 L
.704 .43181 L
.708 .43894 L
.712 .44663 L
.716 .45489 L
.72 .46361 L
.724 .47265 L
.728 .48181 L
.732 .49089 L
.736 .49968 L
.74 .508 L
.744 .51571 L
.748 .5227 L
.752 .52892 L
.756 .53437 L
.76 .53907 L
.764 .54306 L
.768 .5464 L
.772 .54918 L
.776 .55145 L
.78 .55331 L
.784 .55482 L
.788 .55605 L
.792 .55703 L
.796 .55783 L
.8 .55848 L
Mistroke
.804 .559 L
.808 .55942 L
.812 .55977 L
.816 .56005 L
.82 .56027 L
.824 .56046 L
.828 .56061 L
.832 .56073 L
.836 .56083 L
.84 .5609 L
.844 .56095 L
.848 .56099 L
.852 .56102 L
.856 .56104 L
.86 .56104 L
.864 .56104 L
.868 .56103 L
.872 .56102 L
.876 .561 L
.88 .56097 L
.884 .56094 L
.888 .56091 L
.892 .56088 L
.896 .56085 L
.9 .56081 L
.904 .56078 L
.908 .56073 L
.912 .5607 L
.916 .56065 L
.92 .56062 L
.924 .56057 L
.928 .56053 L
.932 .56049 L
.936 .56045 L
.94 .5604 L
.944 .56037 L
.948 .56031 L
.952 .56028 L
.956 .56023 L
.96 .5602 L
.964 .56014 L
.968 .56011 L
.972 .56005 L
.976 .56003 L
.98 .55997 L
.984 .55994 L
.988 .55988 L
.992 .55986 L
.996 .55979 L
1 .55978 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo04Aoo`03001o
ogoo02Eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00A7oo0`00
9Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8004Aoo`03
001oo`0002Ioo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01@00Oomoogoo0000AGoo00@0
07ooOol002Eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00?goo
0P000Woo00D007ooOomoo`0002Eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<0
07ooOol00P00?Woo00<007oo00000Woo00D007ooOomoo`0002Eoo`002goo0P002Woo0P000goo0`00
0goo00<007ooOol0?Goo00H007ooOol007oo0003Ool00`00Oomoo`0SOol000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`8003]oo`800004Ool007ooOol20004Ool00`00Oomoo`0SOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`00
17oo0P0017oo0P001Goo0`000goo0`0000=oo`0000000`000goo1P000Woo0P0017oo0P0017oo1@00
0Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`05001oogoo
Ool00002Ool200001Goo001oogoo00000Woo00@007ooOol000Aoo`06001oogoo001oo`000goo00@0
07ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00@007ooOomo
o`80009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04
001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`020002Ool01000Oomo
o`000Woo00<007ooOol017oo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;Ool40003Ool01000Oomoo`00
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo1@000Woo00@0
07ooOol0009oo`06001oogooOol007oo0P000Woo00@007ooOol0009oo`05001oogooOol00003Ool0
0`00Ool000030003Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool2000<
Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool2
0003Ool01000Oomoo`000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`008Woo0P0037oo1@00
0goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000=o
o`<000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol0=goo0P004Goo00<007oo
Ool07goo000ROol2000hOol00`00Oomoo`0AOol5000LOol0029oof<000aoo`008Woo0P000Woo00<0
07oo00000P0000Eoo`00000007oo00<00004Ool000000003Ool40003Ool3000017oo001oogoo0P00
00Aoo`00000000=oo`05001oogooOol00003Ool01@00Ool007oo00000Woo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
000<Ool0029oo`L00003Ool0000000@00004Ool000000003Ool300000goo000000040003Ool40002
Ool00`00Oomoo`030002Ool01000Oomoogoo0`000Woo00<007ooOol0<goo000ROol00`00Oomoo`0O
Ool20009Ool200001Goo000007oo00000Woo00@007ooOol003Eoo`008Woo0P00;7oo0P000Woo00D0
07ooOomoo`00009oo`03001oogoo03=oo`008Woo0P00;Goo00<007ooOol01Goo0P00=Woo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0dOol2000fOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P00
2Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002
Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`80
06eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol0
00Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007oo
Ool007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03
001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000
Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool3
0003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001o
ogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007oo
Oomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogoo
Ool40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<0
07ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000A
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo;@00?7oo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001o
ogoo02Uoo`8003]oo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0:goo0`00>7oo
000XOol00`00Oomoo`0]Ool2000gOol002Qoo`03001oogoo02moo`8003Eoo`002goo0P0017oo00<0
07ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0<Goo0`00<Woo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol003Eoo`80035oo`000goo1@00
0Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol003Ioo`80031o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo
0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo10000goo0P000Woo1@000goo0P0017oo
0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001o
ogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`800005Ool007oo
Ool00002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool01P00Oomoo`00Ool0
00=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Ool000000Woo00D0
07ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007ooOol01Goo00@007oo0000009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomo
o`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo
00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007oo
Ool02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`00
0Woo0P000goo00<007ooOol017oo0P0000Aoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D0
00=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004
Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo03Yoo`03001oogoo02Uo
o`00:7oo00<007ooOol0>goo00<007ooOol0:7oo000XOomM000<Ool002Qoo`03001oogoo00moo`03
001oogoo011oo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo011oo`03
001oogoo00Yoo`00:7oo00<007ooOol0?7oo0P00:7oo000XOol00`00Oomoo`0mOol00`00Oomoo`0V
Ool002Qoo`03001oogoo03ioo`03001oogoo02Eoo`00:7oo00<007ooOol0?goo00<007ooOol097oo
000XOol00`00Oomoo`0oOol00`00Oomoo`0TOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`80
00=oo`<000=oo`03001oogoo041oo`03001oogoo02=oo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01P00Oomoo`00Ool000=oo`04001oogoo0012Ool00`00Oomoo`0SOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo0013Ool00`00Oomoo`0ROol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008004=oo`03001o
ogoo025oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<0
07ooOol0@Woo0P008Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`00
1Woo00<007ooOol0A7oo10007Woo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`17
OolC000<Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomo
o`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P00
2Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3
0003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`00
00=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo
00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03
001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P00
17oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo
00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00
009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo
00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001o
ogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo
0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool0
1@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo
0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool0
1000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007oo
Oomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000
Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool0
1000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007oo
Oomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03
Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo
1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000L
Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`00009oo`8000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomo
o`0`Ool20010Ool001aoo`80039oo`<003ioo`0077oo00<007ooOol0<goo0`00?7oo000LOol00`00
Oomoo`0eOol00`00Oomoo`0jOol001aoo`8003Moo`8003Yoo`0077oo00<007ooOol0>7oo0`00=goo
000LOol00`00Oomoo`0jOol00`00Oomoo`0eOol001aoo`8003aoo`03001oogoo03Aoo`0077oo00<0
07ooOol0?7oo00<007ooOol0<goo000LOol2000mOol00`00Oomoo`0cOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`03001oogoo03eoo`03001oogoo039oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`0nOol00`00Oomoo`0aOol000Yoo`04001oogoo000;Ool00`00Oomo
o`02000oOol00`00Oomoo`0aOol000Yoo`04001oogoo000;Ool01000Oomoo`00@Goo00<007ooOol0
<7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0?goo00<007ooOol0<7oo000:Ool01000
Oomoo`001goo00<007ooOol017oo0P00@Goo00<007ooOol0;goo000;Ool20008Ool50002Ool00`00
Oomoo`10Ool00`00Oomoo`0_Ool001aoo`03001oogoo045oo`03001oogoo02ioo`0077oo0P00@Woo
00<007ooOol0;Woo000LOol00`00Oomoo`12Ool00`00Oomoo`0]Ool001aoo`8004=oo`03001oogoo
02eoo`0077oo00<007ooOol0@goo00<007ooOol0;7oo000LOol00`00Oomoo`13Ool00`00Oomoo`0/
Ool001aoo`8004Eoo`03001oogoo02]oo`005Woo0`000goo00<007ooOol0A7oo0P00;7oo000GOol0
0`00Oomoo`02Ool00`00Oomoo`15Ool00`00Oomoo`0ZOol001Moo`03001oogoo009oo`8004Moo`03
001oogoo02Uoo`005goo00<007ooOol00Woo00<007ooOol0AWoo00<007ooOol0:Goo000GOol00`00
Oomoo`02Ool00`00Oomoo`17Ool00`00Oomoo`0XOol001Ioo`8000Aoo`8004Qoo`03001oogoo02Qo
o`005goo00<007ooOol00Woo00<007ooOol0B7oo00<007ooOol09goo000LOol00`00Oomoo`18Ool0
0`00Oomoo`0WOol001aoo`8004Yoo`03001oogoo02Ioo`0077oo00<007ooOol0BGoo00<007ooOol0
9Woo000LOol2001;Ool00`00Oomoo`0UOol001aoo`03001oogoo04Yoo`03001oogoo02Eoo`0077oo
00<007ooOol0Bgoo00<007ooOol097oo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001<Ool2
000UOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1<Ool2000TOol000]o
o`03001oogoo00]oo`04001oogoo001?Ool6000>Ool5000<Ool000]oo`03001oogoo00]oo`03001o
ogoo008005=oo`l0015oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009
Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(41249\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3205 m
.008 .31934 L
.012 .31825 L
.016 .31868 L
.02 .32043 L
.024 .3214 L
.028 .32115 L
.032 .32054 L
.036 .31953 L
.04 .31793 L
.044 .31652 L
.048 .31615 L
.052 .31729 L
.056 .31957 L
.06 .3222 L
.064 .32428 L
.068 .3246 L
.072 .32288 L
.076 .31968 L
.08 .31634 L
.084 .31433 L
.088 .31431 L
.092 .31654 L
.096 .32021 L
.1 .32369 L
.104 .32534 L
.108 .32437 L
.112 .32164 L
.116 .31839 L
.12 .31585 L
.124 .31502 L
.128 .31626 L
.132 .31913 L
.136 .32207 L
.14 .3236 L
.144 .32338 L
.148 .32206 L
.152 .32065 L
.156 .31946 L
.16 .31856 L
.164 .31812 L
.168 .31817 L
.172 .31835 L
.176 .31809 L
.18 .31776 L
.184 .31843 L
.188 .3206 L
.192 .32348 L
.196 .32541 L
.2 .32535 L
Mistroke
.204 .32346 L
.208 .32061 L
.212 .31762 L
.216 .31522 L
.22 .31429 L
.224 .3155 L
.228 .31848 L
.232 .32171 L
.236 .32352 L
.24 .32334 L
.244 .32204 L
.248 .32101 L
.252 .32092 L
.256 .32135 L
.26 .32146 L
.264 .32082 L
.268 .31976 L
.272 .31895 L
.276 .31866 L
.28 .31857 L
.284 .31833 L
.288 .31809 L
.292 .31854 L
.296 .32003 L
.3 .32193 L
.304 .32298 L
.308 .3226 L
.312 .32176 L
.316 .32209 L
.32 .32404 L
.324 .32595 L
.328 .3253 L
.332 .32132 L
.336 .3161 L
.34 .31299 L
.344 .31354 L
.348 .3161 L
.352 .31758 L
.356 .31667 L
.36 .31526 L
.364 .31657 L
.368 .32176 L
.372 .32837 L
.376 .33225 L
.38 .33121 L
.384 .32686 L
.388 .32303 L
.392 .32236 L
.396 .32405 L
.4 .32494 L
Mistroke
.404 .32254 L
.408 .31733 L
.412 .31231 L
.416 .31043 L
.42 .31236 L
.424 .31623 L
.428 .31937 L
.432 .32024 L
.436 .31904 L
.44 .31704 L
.444 .31539 L
.448 .31472 L
.452 .31537 L
.456 .31763 L
.46 .32141 L
.464 .32571 L
.468 .32866 L
.472 .32861 L
.476 .32559 L
.48 .32195 L
.484 .32125 L
.488 .32596 L
.492 .33538 L
.496 .34559 L
.5 .35145 L
.504 .34975 L
.508 .34125 L
.512 .33036 L
.516 .32263 L
.52 .32163 L
.524 .32712 L
.528 .33563 L
.532 .34268 L
.536 .34533 L
.54 .34334 L
.544 .33863 L
.548 .33355 L
.552 .32937 L
.556 .32595 L
.56 .32251 L
.564 .31893 L
.568 .3164 L
.572 .31703 L
.576 .32263 L
.58 .33338 L
.584 .34724 L
.588 .36045 L
.592 .36893 L
.596 .36982 L
.6 .36258 L
Mistroke
.604 .34905 L
.608 .33264 L
.612 .31683 L
.616 .30384 L
.62 .29386 L
.624 .28525 L
.628 .27559 L
.632 .26306 L
.636 .24742 L
.64 .23029 L
.644 .21448 L
.648 .20274 L
.652 .1967 L
.656 .19624 L
.66 .1996 L
.664 .20409 L
.668 .20692 L
.672 .2061 L
.676 .20094 L
.68 .19219 L
.684 .1818 L
.688 .1723 L
.692 .16601 L
.696 .16436 L
.7 .1675 L
.704 .17431 L
.708 .18287 L
.712 .19096 L
.716 .19658 L
.72 .1983 L
.724 .19542 L
.728 .18804 L
.732 .17711 L
.736 .16417 L
.74 .15111 L
.744 .13973 L
.748 .13145 L
.752 .12716 L
.756 .12721 L
.76 .13154 L
.764 .13972 L
.768 .15102 L
.772 .16456 L
.776 .17937 L
.78 .19459 L
.784 .20952 L
.788 .22366 L
.792 .23661 L
.796 .24811 L
.8 .25801 L
Mistroke
.804 .26629 L
.808 .27309 L
.812 .27864 L
.816 .28316 L
.82 .28679 L
.824 .28964 L
.828 .29179 L
.832 .29339 L
.836 .29461 L
.84 .29559 L
.844 .29639 L
.848 .297 L
.852 .29746 L
.856 .2978 L
.86 .29807 L
.864 .29833 L
.868 .29855 L
.872 .29872 L
.876 .29885 L
.88 .29896 L
.884 .29905 L
.888 .29913 L
.892 .2992 L
.896 .29924 L
.9 .2993 L
.904 .29937 L
.908 .29943 L
.912 .29945 L
.916 .29944 L
.92 .29941 L
.924 .29941 L
.928 .29945 L
.932 .29952 L
.936 .29956 L
.94 .29955 L
.944 .29951 L
.948 .29947 L
.952 .29946 L
.956 .29947 L
.96 .29949 L
.964 .29952 L
.968 .29955 L
.972 .29955 L
.976 .29952 L
.98 .29947 L
.984 .29942 L
.988 .29942 L
.992 .29947 L
.996 .29951 L
1 .29952 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12378 m
.008 .12218 L
.012 .12151 L
.016 .1219 L
.02 .12211 L
.024 .12204 L
.028 .1219 L
.032 .12193 L
.036 .12196 L
.04 .122 L
.044 .12198 L
.048 .12201 L
.052 .12201 L
.056 .12202 L
.06 .122 L
.064 .12201 L
.068 .122 L
.072 .12202 L
.076 .12201 L
.08 .12202 L
.084 .12201 L
.088 .12199 L
.092 .12197 L
.096 .12197 L
.1 .12196 L
.104 .12197 L
.108 .12198 L
.112 .12201 L
.116 .12202 L
.12 .12201 L
.124 .12199 L
.128 .12197 L
.132 .12195 L
.136 .12195 L
.14 .12195 L
.144 .12199 L
.148 .12205 L
.152 .12211 L
.156 .12213 L
.16 .12213 L
.164 .12209 L
.168 .12204 L
.172 .12194 L
.176 .12183 L
.18 .12176 L
.184 .12175 L
.188 .12181 L
.192 .1219 L
.196 .122 L
.2 .12212 L
Mistroke
.204 .12224 L
.208 .1223 L
.212 .12228 L
.216 .12218 L
.22 .12205 L
.224 .12195 L
.228 .12186 L
.232 .12179 L
.236 .12175 L
.24 .12175 L
.244 .12182 L
.248 .12194 L
.252 .12205 L
.256 .12212 L
.26 .12216 L
.264 .12219 L
.268 .12223 L
.272 .12222 L
.276 .12215 L
.28 .12201 L
.284 .12186 L
.288 .12176 L
.292 .12173 L
.296 .12172 L
.3 .1217 L
.304 .12169 L
.308 .12176 L
.312 .12196 L
.316 .12226 L
.32 .12253 L
.324 .12267 L
.328 .12267 L
.332 .1226 L
.336 .12253 L
.34 .12242 L
.344 .12218 L
.348 .12176 L
.352 .12124 L
.356 .12083 L
.36 .12069 L
.364 .12081 L
.368 .12106 L
.372 .1213 L
.376 .12151 L
.38 .12181 L
.384 .1223 L
.388 .12293 L
.392 .12352 L
.396 .12384 L
.4 .12381 L
Mistroke
.404 .12352 L
.408 .12318 L
.412 .1229 L
.416 .12269 L
.42 .12245 L
.424 .12206 L
.428 .12153 L
.432 .12095 L
.436 .12043 L
.44 .12008 L
.444 .11992 L
.448 .11988 L
.452 .11989 L
.456 .11986 L
.46 .11974 L
.464 .11954 L
.468 .11935 L
.472 .11935 L
.476 .11972 L
.48 .12054 L
.484 .12174 L
.488 .12313 L
.492 .12448 L
.496 .12564 L
.5 .12668 L
.504 .12782 L
.508 .12931 L
.512 .13128 L
.516 .13366 L
.52 .13619 L
.524 .13856 L
.528 .14054 L
.532 .14207 L
.536 .14328 L
.54 .1444 L
.544 .14564 L
.548 .14713 L
.552 .14893 L
.556 .15105 L
.56 .15347 L
.564 .15618 L
.568 .15913 L
.572 .1622 L
.576 .16518 L
.58 .16784 L
.584 .16998 L
.588 .17153 L
.592 .1726 L
.596 .17342 L
.6 .17433 L
Mistroke
.604 .17561 L
.608 .17743 L
.612 .17983 L
.616 .18274 L
.62 .18603 L
.624 .18963 L
.628 .19353 L
.632 .1978 L
.636 .20253 L
.64 .20779 L
.644 .21357 L
.648 .21975 L
.652 .22615 L
.656 .23256 L
.66 .23878 L
.664 .24474 L
.668 .25043 L
.672 .25597 L
.676 .26151 L
.68 .26722 L
.684 .2732 L
.688 .27946 L
.692 .28592 L
.696 .29246 L
.7 .2989 L
.704 .3051 L
.708 .31096 L
.712 .31646 L
.716 .32166 L
.72 .3267 L
.724 .33173 L
.728 .33695 L
.732 .34248 L
.736 .34844 L
.74 .35485 L
.744 .36169 L
.748 .36885 L
.752 .37621 L
.756 .3836 L
.76 .39086 L
.764 .39783 L
.768 .40438 L
.772 .41042 L
.776 .41588 L
.78 .42072 L
.784 .42496 L
.788 .42861 L
.792 .4317 L
.796 .43431 L
.8 .43648 L
Mistroke
.804 .43827 L
.808 .43975 L
.812 .44096 L
.816 .44195 L
.82 .44277 L
.824 .44344 L
.828 .444 L
.832 .44446 L
.836 .44484 L
.84 .44517 L
.844 .44544 L
.848 .44568 L
.852 .44588 L
.856 .44606 L
.86 .44621 L
.864 .44635 L
.868 .44646 L
.872 .44657 L
.876 .44666 L
.88 .44674 L
.884 .44681 L
.888 .44688 L
.892 .44693 L
.896 .44699 L
.9 .44703 L
.904 .44708 L
.908 .44712 L
.912 .44716 L
.916 .4472 L
.92 .44724 L
.924 .44727 L
.928 .4473 L
.932 .44733 L
.936 .44737 L
.94 .44739 L
.944 .44743 L
.948 .44745 L
.952 .44748 L
.956 .4475 L
.96 .44754 L
.964 .44756 L
.968 .4476 L
.972 .44761 L
.976 .44765 L
.98 .44767 L
.984 .44771 L
.988 .44772 L
.992 .44777 L
.996 .44777 L
1 .44783 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16469 L
.012 .16117 L
.016 .16 L
.02 .16126 L
.024 .16161 L
.028 .16121 L
.032 .16103 L
.036 .16115 L
.04 .16112 L
.044 .16104 L
.048 .16098 L
.052 .16102 L
.056 .16103 L
.06 .16109 L
.064 .16112 L
.068 .16116 L
.072 .16115 L
.076 .16114 L
.08 .16108 L
.084 .16103 L
.088 .16097 L
.092 .16094 L
.096 .16093 L
.1 .16094 L
.104 .16096 L
.108 .16099 L
.112 .161 L
.116 .161 L
.12 .16096 L
.124 .16091 L
.128 .16087 L
.132 .16084 L
.136 .16083 L
.14 .16084 L
.144 .1609 L
.148 .16099 L
.152 .16105 L
.156 .16107 L
.16 .16103 L
.164 .16096 L
.168 .16085 L
.172 .16071 L
.176 .16057 L
.18 .16049 L
.184 .1605 L
.188 .16059 L
.192 .1607 L
.196 .16082 L
.2 .16094 L
Mistroke
.204 .16106 L
.208 .16111 L
.212 .16107 L
.216 .16094 L
.22 .16079 L
.224 .16065 L
.228 .16054 L
.232 .16044 L
.236 .16036 L
.24 .16036 L
.244 .16045 L
.248 .16059 L
.252 .16073 L
.256 .16081 L
.26 .16084 L
.264 .16086 L
.268 .16088 L
.272 .16087 L
.276 .16077 L
.28 .1606 L
.284 .16041 L
.288 .16028 L
.292 .16022 L
.296 .1602 L
.3 .16017 L
.304 .16015 L
.308 .16024 L
.312 .16049 L
.316 .16084 L
.32 .16115 L
.324 .1613 L
.328 .16128 L
.332 .16119 L
.336 .1611 L
.34 .16098 L
.344 .16068 L
.348 .16015 L
.352 .1595 L
.356 .15897 L
.36 .15877 L
.364 .15891 L
.368 .1592 L
.372 .15948 L
.376 .15974 L
.38 .16011 L
.384 .16073 L
.388 .16152 L
.392 .16225 L
.396 .16263 L
.4 .16258 L
Mistroke
.404 .1622 L
.408 .16175 L
.412 .16139 L
.416 .16112 L
.42 .16081 L
.424 .16033 L
.428 .15967 L
.432 .15893 L
.436 .15829 L
.44 .15784 L
.444 .15762 L
.448 .15756 L
.452 .15756 L
.456 .15751 L
.46 .15735 L
.464 .15709 L
.468 .15685 L
.472 .15685 L
.476 .15729 L
.48 .1583 L
.484 .1598 L
.488 .16153 L
.492 .1632 L
.496 .16464 L
.5 .16592 L
.504 .16731 L
.508 .16915 L
.512 .17159 L
.516 .17456 L
.52 .17772 L
.524 .18067 L
.528 .18312 L
.532 .185 L
.536 .18649 L
.54 .18786 L
.544 .18939 L
.548 .19124 L
.552 .19347 L
.556 .1961 L
.56 .19911 L
.564 .20247 L
.568 .20614 L
.572 .20994 L
.576 .21363 L
.58 .21692 L
.584 .21956 L
.588 .22147 L
.592 .22278 L
.596 .2238 L
.6 .22492 L
Mistroke
.604 .22649 L
.608 .22873 L
.612 .2317 L
.616 .2353 L
.62 .23939 L
.624 .24385 L
.628 .24869 L
.632 .25398 L
.636 .25985 L
.64 .26638 L
.644 .27355 L
.648 .28123 L
.652 .28918 L
.656 .29713 L
.66 .30485 L
.664 .31223 L
.668 .31929 L
.672 .32615 L
.676 .33303 L
.68 .3401 L
.684 .34751 L
.688 .35527 L
.692 .36329 L
.696 .37139 L
.7 .37937 L
.704 .38705 L
.708 .39429 L
.712 .40109 L
.716 .40753 L
.72 .41375 L
.724 .41998 L
.728 .42643 L
.732 .43327 L
.736 .44064 L
.74 .44857 L
.744 .45703 L
.748 .46589 L
.752 .475 L
.756 .48414 L
.76 .49312 L
.764 .50175 L
.768 .50985 L
.772 .5173 L
.776 .52403 L
.78 .52999 L
.784 .5352 L
.788 .53967 L
.792 .54346 L
.796 .54663 L
.8 .54926 L
Mistroke
.804 .55141 L
.808 .55318 L
.812 .55461 L
.816 .55578 L
.82 .55671 L
.824 .55747 L
.828 .55809 L
.832 .55858 L
.836 .55899 L
.84 .55932 L
.844 .55959 L
.848 .55981 L
.852 .55998 L
.856 .56013 L
.86 .56024 L
.864 .56033 L
.868 .56039 L
.872 .56045 L
.876 .56048 L
.88 .56051 L
.884 .56052 L
.888 .56053 L
.892 .56052 L
.896 .56051 L
.9 .56049 L
.904 .56047 L
.908 .56044 L
.912 .56042 L
.916 .56038 L
.92 .56036 L
.924 .56032 L
.928 .56029 L
.932 .56024 L
.936 .56021 L
.94 .56016 L
.944 .56013 L
.948 .56008 L
.952 .56005 L
.956 .55999 L
.96 .55997 L
.964 .55991 L
.968 .55988 L
.972 .55982 L
.976 .5598 L
.98 .55973 L
.984 .55971 L
.988 .55965 L
.992 .55963 L
.996 .55956 L
1 .55955 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo04Ioo`8002Ao
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00Agoo00<007oo0000
8goo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8004Ioo`04
001oogoo000SOol000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00D007ooOomoo`0004=oo`05
001oogooOol00002Ool00`00Oomoo`0QOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=o
o`03001oogoo0080045oo`<0009oo`04001oogoo000SOol000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`03001oogoo0080045oo`05001oo`00Ool00004Ool00`00Oomoo`0POol000]oo`80
00Yoo`8000=oo`<000=oo`03001oogoo03moo`04001oogooOol20004Ool00`00Oomoo`0POol000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8003eoo`@000=oo`03001oogoo00=oo`03001o
ogoo021oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000=Ool30004
Ool20007Ool30004Ool20004Ool20005Ool30003Ool30003Ool30003Ool50003Ool20004Ool20004
Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol02goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00D0
07ooOomoo`00009oo`03001oogoo00800005Ool007ooOol00002Ool00`00Oomoo`02Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007oo0000009oo`03001oogoo
009oo`03001oogoo009oo`800005Ool007ooOol00002Ool00`00Oomoo`03Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oo`000002Ool00`00Oomoo`03Ool01000Oomo
ogoo0P0000Eoo`00Oomoo`00009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0002Ool0
0`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol02goo
10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOomoo`@0009oo`80009oo`04001oogoo0003Ool01@00Oomoo`00Ool00P000Woo00@007ooOol0
00=oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007oo
Ool00Woo0P0037oo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000
Oomoo`0017oo0P000goo00<007ooOol00goo0P000Woo00@007ooOol000=oo`05001oogoo001oo`02
0002Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000ROol2000<
Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1P000Woo0P0017oo
0`0017oo0`000goo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`0jOol00`00Oomo
o`0?Ool2000NOol0029oo`8003]oo`03001oogoo011oo`H001Uoo`008WooH`0037oo000ROol30000
0goo00000002Ool2000017oo000000000Woo0`0000Ioo`00000007oo0002Ool300000goo001oo`04
0002Ool300001Woo00000000Ool000=oo`04001oogooOol20002Ool200000goo001oo`02Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00<007ooOol02Woo000ROol500001Goo00000000Ool00P0000Aoo`000000009oo`<0009oo`@0009o
o`@000=oo`03001oo`0000800004Ool007ooOol400000goo00000002Ool30003Ool00`00Oomoo`0`
Ool0029oo`03001oogoo029oo`03001oogoo00Qoo`04001oo`00Ool30002Ool00`00Ool0000cOol0
029oo`8002ioo`<00003Ool0000000=oo`03001oo`0003=oo`008Woo0P00;goo00<007ooOol01Goo
00<007oo0000<goo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`0fOol3
000cOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004
Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`80
06eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool3
0003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<0
07ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo
000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000R
Ool2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000
Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009
Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo;`00>Woo000@Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000Aoo`03001oogoo02]oo`<003Qoo`004Goo0P002Woo0P0017oo00<007ooOol00Woo
00<007ooOol0;Goo1000=Goo000XOol00`00Oomoo`0`Ool2000dOol002Qoo`03001oogoo035oo`<0
039oo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0<goo0`00
<7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol0
03Moo`8002moo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOol003Uoo`03001oogoo02aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo
0`000goo0`000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo
00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D0
07ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04
001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo00800003Ool007oo009oo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P00
2Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol01000
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000
Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H007oo0000
07oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool000030003
Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P00
17oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool0
00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04001o
ogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ao
o`04001oogooOol50003Ool200000goo001oo`030004Ool20004Ool20004Ool30002Ool50003Ool2
0006Ool002Qoo`03001oogoo03aoo`03001oogoo02Moo`00:7oo00<007ooOol0?Goo00<007ooOol0
9Woo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001o
ogoo00Moo`8000Ioo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0?goo00<007oo
Ool097oo000XOol00`00Oomoo`10Ool00`00Oomoo`0SOol002Qoo`03001oogoo041oo`8002Aoo`00
:7oo00<007ooOol0@Goo00<007ooOol08Woo000XOol00`00Oomoo`12Ool00`00Oomoo`0QOol000]o
o`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo049oo`03001oogoo025o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo0015
Ool00`00Oomoo`0POol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04
001oogoo0015Ool2000QOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo008004Eoo`03001oogoo01moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1@00Oomoo`00Ool010000goo00<007ooOol0AGoo0P007goo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`001Woo00<007ooOol0AWoo100077oo000;Ool2000:Ool20004Ool2
0002Ool50002Ool00`00Oomoo`1:Ool@000<Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Ao
o`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00
Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001o
ogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol000]o
o`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo
0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol0
00]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`00
17oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`00
17oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool0
00=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04
001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001ao
o`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002
Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomo
o`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004
Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002
Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool5
0003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`00
17oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`0077ooJ@0037oo000LOol20002Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=o
o`D000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00
Oomoo`0cOol00`00Oomoo`0lOol001aoo`8003Eoo`<003]oo`0077oo00<007ooOol0=Woo0P00>Woo
000LOol00`00Oomoo`0hOol00`00Oomoo`0gOol001aoo`8003Yoo`8003Moo`0077oo00<007ooOol0
>Woo0`00=Goo000LOol00`00Oomoo`0lOol2000dOol001aoo`8003moo`03001oogoo035oo`0077oo
00<007ooOol0?goo00<007ooOol0<7oo000LOol20010Ool00`00Oomoo`0`Ool000]oo`8000Aoo`03
001oogoo009oo`<000=oo`03001oogoo041oo`03001oogoo02moo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`10Ool2000`Ool000Yoo`04001oogoo000;Ool00`00Oomoo`02
0012Ool00`00Oomoo`0^Ool000Yoo`04001oogoo000;Ool01000Oomoo`00@goo00<007ooOol0;Woo
000:Ool01000Oomoo`001goo10000goo00<007ooOol0@Woo00<007ooOol0;Goo000:Ool01000Oomo
o`001goo00<007ooOol017oo0P00@goo0P00;Woo000;Ool20008Ool50002Ool00`00Oomoo`13Ool0
0`00Oomoo`0/Ool001aoo`03001oogoo04=oo`03001oogoo02aoo`0077oo0P00AGoo00<007ooOol0
:goo000LOol00`00Oomoo`15Ool00`00Oomoo`0ZOol001aoo`8004Ioo`03001oogoo02Yoo`0077oo
00<007ooOol0AWoo00<007ooOol0:Goo000LOol00`00Oomoo`16Ool00`00Oomoo`0YOol001aoo`80
04Qoo`03001oogoo02Qoo`005Woo0`000goo00<007ooOol0Agoo0P00:Goo000GOol00`00Oomoo`02
Ool00`00Oomoo`18Ool00`00Oomoo`0WOol001Moo`03001oogoo009oo`8004Uoo`8002Qoo`005goo
00<007ooOol00Woo00<007ooOol0BGoo00<007ooOol09Woo000GOol00`00Oomoo`02Ool00`00Oomo
o`1:Ool00`00Oomoo`0UOol001Ioo`8000Aoo`8004]oo`03001oogoo02Eoo`005goo00<007ooOol0
0Woo00<007ooOol0Bgoo00<007ooOol097oo000LOol00`00Oomoo`1;Ool00`00Oomoo`0TOol001ao
o`8004aoo`03001oogoo02Aoo`0077oo00<007ooOol0C7oo00<007ooOol08goo000LOol2001>Ool0
0`00Oomoo`0ROol001aoo`03001oogoo04eoo`03001oogoo029oo`0077oo00<007ooOol0CGoo0P00
8goo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001?Ool2000ROol000]oo`03001oogoo00Mo
o`05001oogooOol00002Ool00`00Oomoo`1?Ool2000QOol000]oo`03001oogoo00]oo`04001oogoo
001BOol70007Ool8000<Ool000]oo`03001oogoo00]oo`03001oogoo008005Moo`T001=oo`002goo
00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomo
o`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(41416\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32202 m
.008 .32074 L
.012 .3197 L
.016 .31815 L
.02 .317 L
.024 .31674 L
.028 .31754 L
.032 .31923 L
.036 .3213 L
.04 .32287 L
.044 .32312 L
.048 .32191 L
.052 .31966 L
.056 .31727 L
.06 .31574 L
.064 .31581 L
.068 .31747 L
.072 .31983 L
.076 .32197 L
.08 .32307 L
.084 .3227 L
.088 .3211 L
.092 .31906 L
.096 .3178 L
.1 .31776 L
.104 .31857 L
.108 .31961 L
.112 .32031 L
.116 .32046 L
.12 .31994 L
.124 .31914 L
.128 .31891 L
.132 .31967 L
.136 .32108 L
.14 .32198 L
.144 .32159 L
.148 .32011 L
.152 .31826 L
.156 .31686 L
.16 .31652 L
.164 .31784 L
.168 .32078 L
.172 .324 L
.176 .32561 L
.18 .3245 L
.184 .32132 L
.188 .31774 L
.192 .31516 L
.196 .31425 L
.2 .31518 L
Mistroke
.204 .31778 L
.208 .32124 L
.212 .32405 L
.216 .32497 L
.22 .32398 L
.224 .3223 L
.228 .32104 L
.232 .32033 L
.236 .31955 L
.24 .31835 L
.244 .31716 L
.248 .31675 L
.252 .3174 L
.256 .31873 L
.26 .32022 L
.264 .32157 L
.268 .32271 L
.272 .32348 L
.276 .32346 L
.28 .32234 L
.284 .32047 L
.288 .31884 L
.292 .31845 L
.296 .31939 L
.3 .32058 L
.304 .32063 L
.308 .31922 L
.312 .31754 L
.316 .31729 L
.32 .31894 L
.324 .32119 L
.328 .32229 L
.332 .32186 L
.336 .32141 L
.34 .32257 L
.344 .32507 L
.348 .32664 L
.352 .32513 L
.356 .3209 L
.36 .31674 L
.364 .31529 L
.368 .31652 L
.372 .31781 L
.376 .3168 L
.38 .31398 L
.384 .31258 L
.388 .31541 L
.392 .32201 L
.396 .32862 L
.4 .33128 L
Mistroke
.404 .32915 L
.408 .32503 L
.412 .32272 L
.416 .32375 L
.42 .32623 L
.424 .32682 L
.428 .32368 L
.432 .31805 L
.436 .31311 L
.44 .31143 L
.444 .31323 L
.448 .31667 L
.452 .31943 L
.456 .32026 L
.46 .31927 L
.464 .31735 L
.468 .3154 L
.472 .3142 L
.476 .31449 L
.48 .31684 L
.484 .32105 L
.488 .3257 L
.492 .32853 L
.496 .32779 L
.5 .32381 L
.504 .31932 L
.508 .31814 L
.512 .32277 L
.516 .33245 L
.52 .34319 L
.524 .34982 L
.528 .349 L
.532 .34121 L
.536 .3305 L
.54 .32223 L
.544 .32012 L
.548 .32442 L
.552 .33219 L
.556 .33932 L
.56 .34283 L
.564 .34218 L
.568 .33884 L
.572 .33479 L
.576 .33107 L
.58 .32737 L
.584 .32286 L
.588 .31745 L
.592 .31263 L
.596 .311 L
.6 .31498 L
Mistroke
.604 .32521 L
.608 .33982 L
.612 .3549 L
.616 .36596 L
.62 .36969 L
.624 .36513 L
.628 .35379 L
.632 .33883 L
.636 .32367 L
.64 .31066 L
.644 .30026 L
.648 .29121 L
.652 .28131 L
.656 .26867 L
.66 .25276 L
.664 .23482 L
.668 .21741 L
.672 .20344 L
.676 .19497 L
.68 .19244 L
.684 .19456 L
.688 .19884 L
.692 .2024 L
.696 .20292 L
.7 .19921 L
.704 .1915 L
.708 .18128 L
.712 .1709 L
.716 .16285 L
.72 .15901 L
.724 .16012 L
.728 .16563 L
.732 .17393 L
.736 .18282 L
.74 .19009 L
.744 .19395 L
.748 .19334 L
.752 .18803 L
.756 .17859 L
.76 .16633 L
.764 .15294 L
.768 .14023 L
.772 .12981 L
.776 .12288 L
.78 .12019 L
.784 .12195 L
.788 .12797 L
.792 .13769 L
.796 .15025 L
.8 .16469 L
Mistroke
.804 .18007 L
.808 .1956 L
.812 .21067 L
.816 .22483 L
.82 .2377 L
.824 .24903 L
.828 .25871 L
.832 .26679 L
.836 .27345 L
.84 .27891 L
.844 .28334 L
.848 .28688 L
.852 .28964 L
.856 .29175 L
.86 .29337 L
.864 .29462 L
.868 .29558 L
.872 .29631 L
.876 .29688 L
.88 .29735 L
.884 .29776 L
.888 .29811 L
.892 .29839 L
.896 .29857 L
.9 .29871 L
.904 .29881 L
.908 .29891 L
.912 .29902 L
.916 .29912 L
.92 .29921 L
.924 .2993 L
.928 .29938 L
.932 .29942 L
.936 .29942 L
.94 .2994 L
.944 .29939 L
.948 .29941 L
.952 .29947 L
.956 .29953 L
.96 .29956 L
.964 .29957 L
.968 .29954 L
.972 .29951 L
.976 .29948 L
.98 .29947 L
.984 .29948 L
.988 .29951 L
.992 .29956 L
.996 .29958 L
1 .29956 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .11772 m
.008 .12246 L
.012 .12399 L
.016 .12244 L
.02 .12195 L
.024 .12256 L
.028 .12271 L
.032 .12252 L
.036 .12242 L
.04 .12247 L
.044 .12246 L
.048 .12245 L
.052 .12243 L
.056 .12246 L
.06 .12246 L
.064 .12247 L
.068 .12244 L
.072 .12244 L
.076 .12243 L
.08 .12244 L
.084 .12245 L
.088 .12248 L
.092 .1225 L
.096 .12252 L
.1 .12252 L
.104 .12251 L
.108 .12248 L
.112 .12246 L
.116 .12243 L
.12 .12242 L
.124 .12241 L
.128 .12243 L
.132 .12246 L
.136 .12249 L
.14 .1225 L
.144 .1225 L
.148 .12249 L
.152 .12246 L
.156 .12242 L
.16 .12238 L
.164 .12239 L
.168 .12244 L
.172 .1225 L
.176 .12256 L
.18 .12261 L
.184 .12264 L
.188 .12262 L
.192 .12254 L
.196 .12242 L
.2 .12231 L
Mistroke
.204 .12224 L
.208 .12223 L
.212 .12226 L
.216 .12232 L
.22 .12242 L
.224 .12256 L
.228 .12268 L
.232 .12274 L
.236 .12273 L
.24 .12267 L
.244 .1226 L
.248 .1225 L
.252 .12239 L
.256 .12228 L
.26 .1222 L
.264 .1222 L
.268 .12227 L
.272 .12238 L
.276 .12246 L
.28 .12252 L
.284 .12258 L
.288 .12265 L
.292 .12272 L
.296 .12273 L
.3 .12265 L
.304 .12252 L
.308 .1224 L
.312 .12232 L
.316 .12227 L
.32 .1222 L
.324 .12211 L
.328 .12206 L
.332 .12214 L
.336 .12237 L
.34 .12266 L
.344 .1229 L
.348 .12302 L
.352 .12305 L
.356 .12309 L
.36 .12313 L
.364 .12309 L
.368 .12285 L
.372 .12239 L
.376 .12186 L
.38 .12146 L
.384 .1213 L
.388 .12135 L
.392 .12146 L
.396 .12154 L
.4 .12167 L
Mistroke
.404 .12197 L
.408 .1225 L
.412 .12319 L
.416 .1238 L
.42 .12416 L
.424 .1242 L
.428 .12402 L
.432 .12379 L
.436 .1236 L
.44 .12343 L
.444 .12319 L
.448 .12281 L
.452 .12229 L
.456 .12171 L
.46 .12118 L
.464 .12078 L
.468 .12054 L
.472 .12046 L
.476 .12046 L
.48 .12044 L
.484 .1203 L
.488 .12004 L
.492 .11973 L
.496 .11958 L
.5 .11979 L
.504 .12047 L
.508 .12156 L
.512 .12286 L
.516 .12411 L
.52 .12519 L
.524 .12613 L
.528 .12716 L
.532 .12852 L
.536 .13037 L
.54 .13267 L
.544 .13517 L
.548 .13757 L
.552 .13964 L
.556 .14131 L
.56 .14264 L
.564 .14382 L
.568 .14503 L
.572 .1464 L
.576 .14801 L
.58 .14991 L
.584 .15213 L
.588 .15469 L
.592 .15757 L
.596 .16066 L
.6 .16375 L
Mistroke
.604 .1666 L
.608 .16897 L
.612 .17076 L
.616 .17199 L
.62 .17289 L
.624 .17375 L
.628 .17487 L
.632 .17644 L
.636 .17854 L
.64 .18113 L
.644 .18411 L
.648 .1874 L
.652 .191 L
.656 .19496 L
.66 .19938 L
.664 .20434 L
.668 .20985 L
.672 .21583 L
.676 .22212 L
.68 .22849 L
.684 .23476 L
.688 .24078 L
.692 .24654 L
.696 .25211 L
.7 .25763 L
.704 .26327 L
.708 .26914 L
.712 .27529 L
.716 .28168 L
.72 .28821 L
.724 .29471 L
.728 .30103 L
.732 .30704 L
.736 .3127 L
.74 .31803 L
.744 .32312 L
.748 .32813 L
.752 .33322 L
.756 .33856 L
.76 .34427 L
.764 .35042 L
.768 .35702 L
.772 .36399 L
.776 .37124 L
.78 .37862 L
.784 .38597 L
.788 .39313 L
.792 .39995 L
.796 .40632 L
.8 .41216 L
Mistroke
.804 .41741 L
.808 .42206 L
.812 .4261 L
.816 .42957 L
.82 .43252 L
.824 .435 L
.828 .43706 L
.832 .43876 L
.836 .44016 L
.84 .44132 L
.844 .44226 L
.848 .44304 L
.852 .44369 L
.856 .44422 L
.86 .44466 L
.864 .44503 L
.868 .44534 L
.872 .44561 L
.876 .44584 L
.88 .44604 L
.884 .44621 L
.888 .44636 L
.892 .44648 L
.896 .4466 L
.9 .44669 L
.904 .44678 L
.908 .44686 L
.912 .44694 L
.916 .44699 L
.92 .44706 L
.924 .4471 L
.928 .44716 L
.932 .44719 L
.936 .44724 L
.94 .44727 L
.944 .44732 L
.948 .44734 L
.952 .44739 L
.956 .44741 L
.96 .44745 L
.964 .44747 L
.968 .44751 L
.972 .44753 L
.976 .44757 L
.98 .44758 L
.984 .44763 L
.988 .44764 L
.992 .44769 L
.996 .44769 L
1 .44774 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16264 L
.012 .16133 L
.016 .16067 L
.02 .16103 L
.024 .16124 L
.028 .1612 L
.032 .1611 L
.036 .16115 L
.04 .16118 L
.044 .1612 L
.048 .16115 L
.052 .16113 L
.056 .16108 L
.06 .16106 L
.064 .16101 L
.068 .161 L
.072 .16099 L
.076 .16101 L
.08 .16101 L
.084 .16104 L
.088 .16104 L
.092 .16106 L
.096 .16106 L
.1 .16105 L
.104 .16101 L
.108 .16098 L
.112 .16095 L
.116 .16092 L
.12 .1609 L
.124 .1609 L
.128 .16091 L
.132 .16094 L
.136 .16094 L
.14 .16093 L
.144 .16089 L
.148 .16086 L
.152 .16082 L
.156 .16078 L
.16 .16076 L
.164 .16079 L
.168 .16085 L
.172 .16091 L
.176 .16095 L
.18 .16098 L
.184 .16098 L
.188 .16095 L
.192 .16086 L
.196 .16072 L
.2 .16058 L
Mistroke
.204 .16049 L
.208 .16045 L
.212 .16047 L
.216 .16054 L
.22 .16066 L
.224 .16083 L
.228 .16099 L
.232 .16106 L
.236 .16103 L
.24 .16093 L
.244 .16081 L
.248 .16068 L
.252 .16054 L
.256 .1604 L
.26 .16031 L
.264 .1603 L
.268 .16038 L
.272 .16049 L
.276 .16059 L
.28 .16066 L
.284 .16073 L
.288 .16081 L
.292 .16087 L
.296 .16086 L
.3 .16075 L
.304 .16057 L
.308 .16041 L
.312 .16031 L
.316 .16026 L
.32 .16018 L
.324 .16007 L
.328 .15999 L
.332 .16007 L
.336 .16033 L
.34 .16068 L
.344 .16096 L
.348 .16109 L
.352 .16113 L
.356 .16118 L
.36 .16123 L
.364 .16119 L
.368 .16088 L
.372 .16029 L
.376 .15961 L
.38 .15909 L
.384 .15888 L
.388 .15892 L
.392 .15905 L
.396 .15916 L
.4 .15931 L
Mistroke
.404 .15968 L
.408 .16035 L
.412 .16119 L
.416 .16195 L
.42 .16237 L
.424 .16241 L
.428 .16217 L
.432 .16187 L
.436 .16163 L
.44 .16141 L
.444 .1611 L
.448 .16062 L
.452 .15996 L
.456 .15923 L
.46 .15856 L
.464 .15806 L
.468 .15776 L
.472 .15765 L
.476 .15763 L
.48 .15758 L
.484 .1574 L
.488 .15706 L
.492 .15668 L
.496 .1565 L
.5 .15676 L
.504 .1576 L
.508 .15894 L
.512 .16053 L
.516 .16208 L
.52 .16341 L
.524 .16458 L
.528 .16585 L
.532 .16754 L
.536 .16985 L
.54 .1727 L
.544 .1758 L
.548 .17878 L
.552 .18135 L
.556 .1834 L
.56 .18504 L
.564 .1865 L
.568 .188 L
.572 .1897 L
.576 .1917 L
.58 .19405 L
.584 .19679 L
.588 .19996 L
.592 .20353 L
.596 .20737 L
.6 .21121 L
Mistroke
.604 .21474 L
.608 .21768 L
.612 .21987 L
.616 .22139 L
.62 .2225 L
.624 .22355 L
.628 .22493 L
.632 .22686 L
.636 .22946 L
.64 .23266 L
.644 .23635 L
.648 .24043 L
.652 .2449 L
.656 .24981 L
.66 .25529 L
.664 .26145 L
.668 .26829 L
.672 .27572 L
.676 .28353 L
.68 .29144 L
.684 .2992 L
.688 .30667 L
.692 .31382 L
.696 .32073 L
.7 .32758 L
.704 .33456 L
.708 .34183 L
.712 .34945 L
.716 .35738 L
.72 .36547 L
.724 .37352 L
.728 .38135 L
.732 .3888 L
.736 .3958 L
.74 .40239 L
.744 .40869 L
.748 .41487 L
.752 .42117 L
.756 .42777 L
.76 .43483 L
.764 .44244 L
.768 .4506 L
.772 .45923 L
.776 .46821 L
.78 .47734 L
.784 .48644 L
.788 .49529 L
.792 .50373 L
.796 .5116 L
.8 .5188 L
Mistroke
.804 .52527 L
.808 .53098 L
.812 .53595 L
.816 .54021 L
.82 .5438 L
.824 .54681 L
.828 .5493 L
.832 .55135 L
.836 .55302 L
.84 .55439 L
.844 .55549 L
.848 .55638 L
.852 .55711 L
.856 .55769 L
.86 .55817 L
.864 .55856 L
.868 .55887 L
.872 .55913 L
.876 .55933 L
.88 .5595 L
.884 .55963 L
.888 .55974 L
.892 .55982 L
.896 .55989 L
.9 .55993 L
.904 .55997 L
.908 .55999 L
.912 .56 L
.916 .56 L
.92 .56 L
.924 .55998 L
.928 .55997 L
.932 .55994 L
.936 .55992 L
.94 .55989 L
.944 .55986 L
.948 .55982 L
.952 .5598 L
.956 .55975 L
.96 .55972 L
.964 .55967 L
.968 .55964 L
.972 .55958 L
.976 .55956 L
.98 .5595 L
.984 .55948 L
.988 .55942 L
.992 .5594 L
.996 .55933 L
1 .55931 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001:Ool2000QOol000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo04Qo
o`03001oo`00025oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00
BGoo00<007oo00008Goo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8004Uoo`04001oogoo000POol000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00D007oo
Oomoo`0004Eoo`8000=oo`04001oogoo000POol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0
00=oo`03001oogoo008004Aoo`80009oo`05001oogooOol0000POol000Yoo`04001oogoo0008Ool0
1P00Oomoo`00Ool000=oo`03001oogoo008004=oo`06001oogoo001oo`000goo00<007ooOol07Woo
000;Ool2000:Ool20003Ool30003Ool00`00Oomoo`0oOol2000017oo001oogoo0P001Goo00<007oo
Ool07Goo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool20010Ool3000:Ool00`00Oomo
o`0MOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo
0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0`000Woo1@000goo0`000goo0P0017oo
1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00D007ooOol007oo008000=o
o`04001oogoo0002Ool00`00Oomoo`0200001Goo001oogoo000017oo00H007ooOol007oo0003Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo00Eoo`05001oogoo001oo`020004Ool00`00Oomoo`02Ool0
0`00Oomoo`0200001Goo001oogoo00001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01@00Oomoo`00Ool00P001Goo00D007ooOomoo`00009oo`800005Ool007ooOol00006
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000Aoo`03001oogoo00]oo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool200001Goo001oogoo00000goo
00@007ooOol0009oo`800005Ool007ooOol00003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo
0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo
0006Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`800005
Ool007ooOol00003Ool01000Oomoo`000Woo00@007oo0000009oo`05001oogooOol00003Ool00`00
Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004
Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P000goo0`001Goo0`000Woo1@000goo
0P001Woo000ROol00`00Oomoo`0mOol00`00Oomoo`0?Ool2000KOol0029oo`8003eoo`03001oogoo
015oo`H001Ioo`008WooH`0037oo000ROol00`00Ool0000200000goo00000003000017oo000007oo
0P0000Aoo`00000000=oo`800003Ool0000000<000=oo`D0009oo`H0009oo`8000=oo`03001oo`00
0080009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo000037oo000ROol20002Ool200001Goo00000000Ool01@0000Ao
o`00001oo`@00003Ool0000000@00003Ool000000080009oo`D00004Ool00000Ool40002Ool20002
Ool00`00Ool00002Ool00`00Oomoo`0^Ool0029oo`03001oogoo02Aoo`03001oogoo00Qoo`04001o
o`00Ool30002Ool01000Oomoo`00<7oo000ROol2000aOol20002Ool01@00Oomoogoo00000Woo00<0
07ooOol0;Woo000ROol2000jOol2000aOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`03001oogoo03Uoo`80035oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomo
o`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004
Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomo
o`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]o
o`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=o
o`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol0
0`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool5
0002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`80
00Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Io
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Oola000hOol0011oo`04001o
ogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0;Woo0P00=Woo000AOol2000:Ool20004
Ool00`00Oomoo`02Ool00`00Oomoo`0`Ool3000cOol002Qoo`03001oogoo039oo`80039oo`00:7oo
00<007ooOol0=7oo0P00<7oo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool0
0`00Oomoo`0eOol4000]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0003Ool01000Oomoo`00>Woo0P00;7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0005Ool01000Oomoo`00>goo00<007ooOol0:Woo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004
Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo
00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo
00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo
00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`80009oo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=o
o`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001o
ogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@0
07ooOol0009oo`8000=oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@0
07ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@0
00=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@0
07ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo
00D007ooOol007oo0080009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03
001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo
00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002
Ool50003Ool20006Ool002Qoo`03001oogoo03moo`03001oogoo02Aoo`00:7oo00<007ooOol0?goo
0P009Goo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03
001oogoo00Yoo`03001oogoo009oo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0
@Woo00<007ooOol08Goo000XOol00`00Oomoo`12Ool2000ROol002Qoo`03001oogoo04=oo`03001o
ogoo021oo`00:7oo00<007ooOol0A7oo00<007ooOol07goo000XOol00`00Oomoo`14Ool00`00Oomo
o`0OOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo04Eoo`03
001oogoo01ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04
001oogoo0017Ool2000OOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eo
o`04001oogoo0018Ool00`00Oomoo`0MOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo008004Moo`8001ioo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01@00Oomoo`00Ool010000goo00<007ooOol0Agoo0P007Goo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0B7oo10006Woo000;Ool2000:Ool20004
Ool20002Ool50002Ool00`00Oomoo`1<Ool>000<Ool002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03
001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol0
00]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001o
ogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001c
Ool000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo
0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo
0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00
Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011o
o`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool0
01aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00
Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo
0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=
Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo
0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03
001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007oo
Oomoo`0000=oo`04001oogooOol300000goo001oo`02Ool01@00Oomoogoo00000goo00<007ooOol0
0Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol0
0Woo00<007ooOol02Woo000LOol00`00Oomoo`0eOol2000kOol001aoo`8003Qoo`<003Qoo`0077oo
00<007ooOol0>Goo0P00=goo000LOol00`00Oomoo`0jOol2000fOol001aoo`8003eoo`8003Aoo`00
77oo00<007ooOol0?Goo0`00<Woo000LOol00`00Oomoo`0oOol2000aOol001aoo`80049oo`03001o
ogoo02ioo`0077oo00<007ooOol0@Goo00<007ooOol0;Woo000LOol20013Ool00`00Oomoo`0]Ool0
00]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo04=oo`03001oogoo02aoo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`13Ool00`00Oomoo`0/Ool000Yoo`04001o
ogoo000;Ool00`00Oomoo`020014Ool00`00Oomoo`0/Ool000Yoo`04001oogoo000;Ool01000Oomo
o`00AWoo00<007ooOol0:goo000:Ool01000Oomoo`001goo10000goo00<007ooOol0AGoo00<007oo
Ool0:Woo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00AWoo0P00:goo000;Ool20008Ool5
0002Ool00`00Oomoo`16Ool00`00Oomoo`0YOol001aoo`03001oogoo04Ioo`03001oogoo02Uoo`00
77oo0P00B7oo00<007ooOol0:7oo000LOol00`00Oomoo`17Ool2000YOol001aoo`8004Uoo`03001o
ogoo02Moo`0077oo00<007ooOol0B7oo00<007ooOol09goo000LOol00`00Oomoo`19Ool00`00Oomo
o`0VOol001aoo`8004Yoo`8002Moo`005Woo0`000goo00<007ooOol0BWoo0P009Woo000GOol00`00
Oomoo`02Ool00`00Oomoo`1;Ool00`00Oomoo`0TOol001Moo`03001oogoo009oo`8004aoo`03001o
ogoo02Aoo`005goo00<007ooOol00Woo00<007ooOol0C7oo00<007ooOol08goo000GOol00`00Oomo
o`02Ool00`00Oomoo`1=Ool00`00Oomoo`0ROol001Ioo`8000Aoo`8004ioo`03001oogoo029oo`00
5goo00<007ooOol00Woo00<007ooOol0CGoo00<007ooOol08Woo000LOol00`00Oomoo`1>Ool00`00
Oomoo`0QOol001aoo`8004moo`03001oogoo025oo`0077oo00<007ooOol0Cgoo00<007ooOol087oo
000LOol2001@Ool00`00Oomoo`0POol001aoo`03001oogoo051oo`03001oogoo01moo`0077oo00<0
07ooOol0D7oo0P0087oo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001BOol2000OOol000]o
o`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1BOol2000NOol000]oo`03001oogoo
00]oo`04001oogoo001EOolC000<Ool000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo
00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomo
o`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(41583\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31606 m
.008 .31806 L
.012 .32112 L
.016 .32263 L
.02 .32192 L
.024 .32076 L
.028 .31931 L
.032 .31757 L
.036 .3164 L
.04 .31677 L
.044 .31856 L
.048 .32071 L
.052 .32222 L
.056 .32236 L
.06 .32109 L
.064 .31916 L
.068 .31758 L
.072 .31714 L
.076 .31801 L
.08 .31982 L
.084 .3215 L
.088 .32196 L
.092 .32089 L
.096 .31896 L
.1 .31736 L
.104 .31693 L
.108 .31799 L
.112 .32026 L
.116 .32264 L
.12 .32381 L
.124 .32285 L
.128 .32016 L
.132 .31723 L
.136 .3155 L
.14 .31572 L
.144 .31765 L
.148 .32058 L
.152 .32332 L
.156 .32447 L
.16 .32334 L
.164 .32058 L
.168 .31788 L
.172 .31652 L
.176 .31665 L
.18 .31777 L
.184 .31939 L
.188 .32114 L
.192 .32246 L
.196 .32278 L
.2 .32216 L
Mistroke
.204 .32126 L
.208 .32066 L
.212 .32009 L
.216 .31892 L
.22 .31721 L
.224 .31598 L
.228 .31627 L
.232 .31815 L
.236 .32073 L
.24 .32304 L
.244 .32452 L
.248 .32495 L
.252 .32409 L
.256 .32191 L
.26 .31902 L
.264 .31665 L
.268 .31587 L
.272 .31681 L
.276 .31858 L
.28 .32002 L
.284 .32064 L
.288 .32084 L
.292 .32131 L
.296 .32218 L
.3 .32283 L
.304 .32251 L
.308 .32126 L
.312 .31999 L
.316 .31967 L
.32 .32023 L
.324 .32059 L
.328 .31981 L
.332 .31828 L
.336 .31748 L
.34 .31837 L
.344 .32024 L
.348 .32129 L
.352 .3206 L
.356 .31937 L
.36 .31988 L
.364 .32296 L
.368 .32669 L
.372 .32793 L
.376 .32523 L
.38 .32043 L
.384 .31707 L
.388 .31702 L
.392 .31882 L
.396 .31922 L
.4 .31657 L
Mistroke
.404 .31268 L
.408 .31135 L
.412 .31483 L
.416 .32163 L
.42 .32763 L
.424 .3295 L
.428 .32727 L
.432 .324 L
.436 .3229 L
.44 .32467 L
.444 .3272 L
.448 .32758 L
.452 .32462 L
.456 .31957 L
.46 .31504 L
.464 .31299 L
.468 .31372 L
.472 .31609 L
.476 .31863 L
.48 .32022 L
.484 .32031 L
.488 .31884 L
.492 .31627 L
.496 .31377 L
.5 .31302 L
.504 .31527 L
.508 .32031 L
.512 .32597 L
.516 .3292 L
.52 .3279 L
.524 .32269 L
.528 .31695 L
.532 .315 L
.536 .31949 L
.54 .32949 L
.544 .34079 L
.548 .34812 L
.552 .34809 L
.556 .34101 L
.56 .33066 L
.564 .32211 L
.568 .31903 L
.572 .32203 L
.576 .32876 L
.58 .33565 L
.584 .33987 L
.588 .3406 L
.592 .33876 L
.596 .33586 L
.6 .3327 L
Mistroke
.604 .32893 L
.608 .32375 L
.612 .31708 L
.616 .31039 L
.62 .30651 L
.624 .30827 L
.628 .31695 L
.632 .33125 L
.636 .3475 L
.64 .36102 L
.644 .36794 L
.648 .36659 L
.652 .35787 L
.656 .34461 L
.66 .3302 L
.664 .31723 L
.668 .30658 L
.672 .29735 L
.676 .28753 L
.68 .27511 L
.684 .25921 L
.688 .24063 L
.692 .22171 L
.696 .20546 L
.7 .19435 L
.704 .18945 L
.708 .18999 L
.712 .19372 L
.716 .19775 L
.72 .19943 L
.724 .19712 L
.728 .19055 L
.732 .18082 L
.736 .17003 L
.74 .16065 L
.744 .15481 L
.748 .15374 L
.752 .15744 L
.756 .16478 L
.76 .17384 L
.764 .18236 L
.768 .18831 L
.772 .19019 L
.776 .18729 L
.78 .17975 L
.784 .16856 L
.788 .15524 L
.792 .14162 L
.796 .12947 L
.8 .12023 L
Mistroke
.804 .1149 L
.808 .11399 L
.812 .11753 L
.816 .12519 L
.82 .13625 L
.824 .14986 L
.828 .16505 L
.832 .18095 L
.836 .19682 L
.84 .21204 L
.844 .22615 L
.848 .23881 L
.852 .24988 L
.856 .25934 L
.86 .2673 L
.864 .2739 L
.868 .27929 L
.872 .2836 L
.876 .28698 L
.88 .28962 L
.884 .29169 L
.888 .29331 L
.892 .29457 L
.896 .29554 L
.9 .29629 L
.904 .29688 L
.908 .29736 L
.912 .29776 L
.916 .29809 L
.92 .29834 L
.924 .29853 L
.928 .29869 L
.932 .29881 L
.936 .29892 L
.94 .29904 L
.944 .29915 L
.948 .29927 L
.952 .29935 L
.956 .29939 L
.96 .29938 L
.964 .29937 L
.968 .29937 L
.972 .29942 L
.976 .29949 L
.98 .29956 L
.984 .29958 L
.988 .29958 L
.992 .29954 L
.996 .29949 L
1 .29946 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .1204 m
.008 .1229 L
.012 .12374 L
.016 .12305 L
.02 .12265 L
.024 .12283 L
.028 .12294 L
.032 .12293 L
.036 .12288 L
.04 .12293 L
.044 .12294 L
.048 .12296 L
.052 .12294 L
.056 .12295 L
.06 .12294 L
.064 .12296 L
.068 .12295 L
.072 .12296 L
.076 .12295 L
.08 .12295 L
.084 .12293 L
.088 .12292 L
.092 .12289 L
.096 .12289 L
.1 .12288 L
.104 .12289 L
.108 .12291 L
.112 .12294 L
.116 .12297 L
.12 .123 L
.124 .123 L
.128 .12299 L
.132 .12297 L
.136 .12293 L
.14 .12289 L
.144 .12287 L
.148 .12287 L
.152 .1229 L
.156 .12293 L
.16 .12296 L
.164 .12297 L
.168 .12298 L
.172 .12295 L
.176 .12291 L
.18 .12287 L
.184 .12285 L
.188 .12287 L
.192 .12291 L
.196 .12295 L
.2 .123 L
Mistroke
.204 .12306 L
.208 .12311 L
.212 .1231 L
.216 .12303 L
.22 .12293 L
.224 .12284 L
.228 .12276 L
.232 .1227 L
.236 .12268 L
.24 .12273 L
.244 .12284 L
.248 .12299 L
.252 .12311 L
.256 .12318 L
.26 .12319 L
.264 .12317 L
.268 .12312 L
.272 .12303 L
.276 .12291 L
.28 .12278 L
.284 .1227 L
.288 .12269 L
.292 .12273 L
.296 .1228 L
.3 .12285 L
.304 .12292 L
.308 .12301 L
.312 .12312 L
.316 .12321 L
.32 .12321 L
.324 .12313 L
.328 .12302 L
.332 .12293 L
.336 .12288 L
.34 .12281 L
.344 .12269 L
.348 .12255 L
.352 .12248 L
.356 .12256 L
.36 .12279 L
.364 .12305 L
.368 .12323 L
.372 .12333 L
.376 .12342 L
.38 .12357 L
.384 .12372 L
.388 .12372 L
.392 .12348 L
.396 .12301 L
.4 .1225 L
Mistroke
.404 .12213 L
.408 .12196 L
.412 .12191 L
.416 .12187 L
.42 .12183 L
.424 .12188 L
.428 .12217 L
.432 .12272 L
.436 .12341 L
.44 .12404 L
.444 .12442 L
.448 .12453 L
.452 .12447 L
.456 .12436 L
.46 .12425 L
.464 .12412 L
.468 .1239 L
.472 .12354 L
.476 .12305 L
.48 .12248 L
.484 .12192 L
.488 .12148 L
.492 .1212 L
.496 .12108 L
.5 .12107 L
.504 .12104 L
.508 .12089 L
.512 .12057 L
.516 .12018 L
.52 .1199 L
.524 .11997 L
.528 .1205 L
.532 .12147 L
.536 .12266 L
.54 .12382 L
.544 .1248 L
.548 .12565 L
.552 .12657 L
.556 .12781 L
.56 .12953 L
.564 .13171 L
.568 .13415 L
.572 .13656 L
.576 .13871 L
.58 .1405 L
.584 .14196 L
.588 .14323 L
.592 .14446 L
.596 .14575 L
.6 .1472 L
Mistroke
.604 .14889 L
.608 .15089 L
.612 .15326 L
.616 .15602 L
.62 .15908 L
.624 .16225 L
.628 .16526 L
.632 .16785 L
.636 .16987 L
.64 .17132 L
.644 .17234 L
.648 .17321 L
.652 .17423 L
.656 .1756 L
.66 .17743 L
.664 .17973 L
.668 .1824 L
.672 .1854 L
.676 .18869 L
.68 .19234 L
.684 .19643 L
.688 .20107 L
.692 .2063 L
.696 .21204 L
.7 .21817 L
.704 .22447 L
.708 .23074 L
.712 .23682 L
.716 .24265 L
.72 .24827 L
.724 .25379 L
.728 .25936 L
.732 .26513 L
.736 .27116 L
.74 .27746 L
.744 .28395 L
.748 .29047 L
.752 .29689 L
.756 .30305 L
.76 .30888 L
.764 .31435 L
.768 .31954 L
.772 .32456 L
.776 .32958 L
.78 .33476 L
.784 .34025 L
.788 .34615 L
.792 .35248 L
.796 .35924 L
.8 .36633 L
Mistroke
.804 .37365 L
.808 .38102 L
.812 .38831 L
.816 .39535 L
.82 .40201 L
.824 .4082 L
.828 .41383 L
.832 .41888 L
.836 .42333 L
.84 .42719 L
.844 .4305 L
.848 .4333 L
.852 .43565 L
.856 .43761 L
.86 .43923 L
.864 .44057 L
.868 .44166 L
.872 .44257 L
.876 .44331 L
.88 .44392 L
.884 .44443 L
.888 .44486 L
.892 .44521 L
.896 .44552 L
.9 .44578 L
.904 .446 L
.908 .44619 L
.912 .44635 L
.916 .44649 L
.92 .44662 L
.924 .44672 L
.928 .44683 L
.932 .44691 L
.936 .44699 L
.94 .44705 L
.944 .44712 L
.948 .44717 L
.952 .44723 L
.956 .44726 L
.96 .44732 L
.964 .44735 L
.968 .4474 L
.972 .44742 L
.976 .44747 L
.98 .44749 L
.984 .44754 L
.988 .44755 L
.992 .4476 L
.996 .44761 L
1 .44766 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15799 L
.012 .16135 L
.016 .16234 L
.02 .16118 L
.024 .16078 L
.028 .16116 L
.032 .16121 L
.036 .16107 L
.04 .16101 L
.044 .1611 L
.048 .16112 L
.052 .16113 L
.056 .16112 L
.06 .16113 L
.064 .1611 L
.068 .16109 L
.072 .16106 L
.076 .16105 L
.08 .16102 L
.084 .16101 L
.088 .16099 L
.092 .16098 L
.096 .16096 L
.1 .16096 L
.104 .16095 L
.108 .16096 L
.112 .16097 L
.116 .16099 L
.12 .16098 L
.124 .16098 L
.128 .16096 L
.132 .16095 L
.136 .16092 L
.14 .16089 L
.144 .16086 L
.148 .16085 L
.152 .16085 L
.156 .16085 L
.16 .16085 L
.164 .16086 L
.168 .16087 L
.172 .16085 L
.176 .1608 L
.18 .16074 L
.184 .1607 L
.188 .16071 L
.192 .16074 L
.196 .16079 L
.2 .16086 L
Mistroke
.204 .16094 L
.208 .16098 L
.212 .16095 L
.216 .16084 L
.22 .1607 L
.224 .16057 L
.228 .16047 L
.232 .1604 L
.236 .16038 L
.24 .16042 L
.244 .16055 L
.248 .16072 L
.252 .16087 L
.256 .16095 L
.26 .16096 L
.264 .16092 L
.268 .16085 L
.272 .16072 L
.276 .16054 L
.28 .16037 L
.284 .16026 L
.288 .16025 L
.292 .16032 L
.296 .1604 L
.3 .16046 L
.304 .16052 L
.308 .16062 L
.312 .16073 L
.316 .16082 L
.32 .16081 L
.324 .16071 L
.328 .16056 L
.332 .16045 L
.336 .16039 L
.34 .16031 L
.344 .16015 L
.348 .15996 L
.352 .15985 L
.356 .15994 L
.36 .1602 L
.364 .16051 L
.368 .16073 L
.372 .16085 L
.376 .16097 L
.38 .16115 L
.384 .16133 L
.388 .16133 L
.392 .16101 L
.396 .16041 L
.4 .15976 L
Mistroke
.404 .15928 L
.408 .15906 L
.412 .15899 L
.416 .15894 L
.42 .15888 L
.424 .15894 L
.428 .15929 L
.432 .15996 L
.436 .16082 L
.44 .16159 L
.444 .16206 L
.448 .16219 L
.452 .1621 L
.456 .16194 L
.46 .16179 L
.464 .16162 L
.468 .16135 L
.472 .1609 L
.476 .16028 L
.48 .15957 L
.484 .15886 L
.488 .15828 L
.492 .15791 L
.496 .15776 L
.5 .15774 L
.504 .1577 L
.508 .15751 L
.512 .15711 L
.516 .15661 L
.52 .15625 L
.524 .15633 L
.528 .15698 L
.532 .15817 L
.536 .15964 L
.54 .16107 L
.544 .16229 L
.548 .16335 L
.552 .16449 L
.556 .16602 L
.56 .16816 L
.564 .17086 L
.568 .17388 L
.572 .17687 L
.576 .17954 L
.58 .18176 L
.584 .18357 L
.588 .18514 L
.592 .18665 L
.596 .18825 L
.6 .19005 L
Mistroke
.604 .19214 L
.608 .19461 L
.612 .19755 L
.616 .20097 L
.62 .20476 L
.624 .2087 L
.628 .21243 L
.632 .21565 L
.636 .21814 L
.64 .21992 L
.644 .22118 L
.648 .22225 L
.652 .22349 L
.656 .22518 L
.66 .22744 L
.664 .23027 L
.668 .23359 L
.672 .23731 L
.676 .24139 L
.68 .24591 L
.684 .25099 L
.688 .25675 L
.692 .26322 L
.696 .27036 L
.7 .27797 L
.704 .28579 L
.708 .29357 L
.712 .30112 L
.716 .30835 L
.72 .31531 L
.724 .32216 L
.728 .32907 L
.732 .33621 L
.736 .34369 L
.74 .3515 L
.744 .35954 L
.748 .36763 L
.752 .37558 L
.756 .38321 L
.76 .39042 L
.764 .39719 L
.768 .40361 L
.772 .40981 L
.776 .41602 L
.78 .42242 L
.784 .42921 L
.788 .4365 L
.792 .44434 L
.796 .4527 L
.8 .46149 L
Mistroke
.804 .47054 L
.808 .47967 L
.812 .48868 L
.816 .49739 L
.82 .50562 L
.824 .51326 L
.828 .52021 L
.832 .52643 L
.836 .5319 L
.84 .53664 L
.844 .54068 L
.848 .5441 L
.852 .54696 L
.856 .54932 L
.86 .55126 L
.864 .55285 L
.868 .55415 L
.872 .5552 L
.876 .55604 L
.88 .55674 L
.884 .55729 L
.888 .55775 L
.892 .55811 L
.896 .55842 L
.9 .55866 L
.904 .55886 L
.908 .55902 L
.912 .55915 L
.916 .55924 L
.92 .55933 L
.924 .55938 L
.928 .55943 L
.932 .55945 L
.936 .55948 L
.94 .55948 L
.944 .55949 L
.948 .55947 L
.952 .55947 L
.956 .55944 L
.96 .55943 L
.964 .55938 L
.968 .55937 L
.972 .55932 L
.976 .55931 L
.98 .55925 L
.984 .55923 L
.988 .55917 L
.992 .55916 L
.996 .55909 L
1 .55908 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001<Ool2000OOol000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo04]o
o`03001oo`0001ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00
Bgoo00@007ooOol001ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool20017Ool01@00Oomoogoo00000Woo00<007ooOol077oo000:Ool01000Oomoo`0027oo00@0
07ooOol000Aoo`05001oogooOol00017Ool30002Ool01@00Oomoogoo00007Goo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool00`00Oomoo`020016Ool00`00Ool00002Ool01@00Oomoogoo
00007Goo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`020015Ool01000
Oomoogoo0P0017oo00<007ooOol06goo000;Ool2000:Ool20003Ool30003Ool00`00Oomoo`11Ool4
0003Ool20004Ool00`00Oomoo`0KOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`80
049oo`04001oo`00000:Ool00`00Oomoo`0JOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo
0P000Woo1P000goo0P000goo0`0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool0
1000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`05001oo`00Ool00002Ool01000Oomoo`000Woo00@007ooOol0009o
o`03001oogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007oo00000Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool20004
Ool01@00Oomoogoo00000Woo00<007ooOol00P0000=oo`00Ool01Goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00
Oomoo`0;Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool01000Oomoogoo10000goo00<007ooOol00P0000=oo`00Ool00Woo00@007ooOol0009oo`03
001oogoo00800003Ool007oo009oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo
0P002Woo0P0017oo00<007ooOol00Woo0P0037oo00<007ooOol017oo00@007ooOol000Ioo`8000Ao
o`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00<007ooOol00P0000=o
o`00Ool00Woo00@007ooOol0009oo`05001oogoo001oo`020003Ool01`00Oomoogoo001oo`0000Io
o`04001oogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Io
o`04001oogooOol50003Ool30003Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0
029oo`03001oogoo03moo`03001oogoo011oo`03001oogoo01Moo`008Woo0P00@7oo00<007ooOol0
4Goo1P004goo000ROomS000<Ool0029oo`800004Ool00000Ool300000goo0000000300001Goo0000
0000Ool020000goo0`0000Aoo`00Oomoo`<0009oo`03001oo`0000@00003Ool00000009oo`04001o
ogooOol40002Ool20003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo000037oo000ROol4000017oo000007oo0P0000Eoo`00000007oo00800003
Ool0000000800005Ool00000001oo`0600000goo000000020003Ool5000017oo001oogoo100000=o
o`0000000Woo00<007oo00000goo00<007ooOol0:goo000ROol00`00Oomoo`0bOol01000Ool007oo
0`000Woo00<007oo0000;Woo000ROol2000cOol20002Ool00`00Oomoo`02Ool00`00Ool0000^Ool0
029oo`8003aoo`03001oo`0002ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<0
07ooOol0>goo0P00;goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
06eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06ao
o`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04
001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo0080
06eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P00
2Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007oo
Ool00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@0
07ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001o
ogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo
0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo
00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001W
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009ooc@003Eoo`0047oo00@007ooOol0
00Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0`Ool2000dOol0015oo`8000Yoo`8000Aoo`03
001oogoo009oo`03001oogoo039oo`<0035oo`00:7oo00<007ooOol0=Goo0P00;goo000XOol00`00
Oomoo`0fOol3000]Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001o
ogoo03Qoo`<002]oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=o
o`04001oogoo000lOol2000ZOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogoo000nOol00`00Oomoo`0WOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`80
00=oo`<000=oo`<000Aoo`800003Ool0000000@000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`80
00Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007oo
Ool02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007oo0000009oo`04001o
ogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006
Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00P0017oo00@0
07ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo
000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00@007ooOomoo`8000=oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
17oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol0
00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`0:
001oogoo001oo`00Ool007oo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`06001oogooOol0
07oo10000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol0
00Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007oo
Ool007oo0002Ool20002Ool01000Oomoo`000Woo00@007ooOol0009oo`07001oogooOol007oo0000
1Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P00
17oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`@000=oo`8000Aoo`8000Aoo`<0009oo`D000=o
o`8000Ioo`00:7oo00<007ooOol0@Goo0P008goo000XOol00`00Oomoo`12Ool00`00Oomoo`0QOol0
02Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol0
37oo00@007ooOol0019oo`03001oogoo00Yoo`00:7oo00<007ooOol0A7oo00<007ooOol07goo000X
Ool00`00Oomoo`15Ool00`00Oomoo`0NOol002Qoo`03001oogoo04Ioo`03001oogoo01eoo`00:7oo
00<007ooOol0AWoo00<007ooOol07Goo000XOol00`00Oomoo`17Ool00`00Oomoo`0LOol000]oo`80
00Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo04Moo`03001oogoo01aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001:Ool0
0`00Oomoo`0KOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001o
ogoo001:Ool00`00Oomoo`0KOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo008004Yoo`03001oogoo01Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01@00Oomoo`00Ool010000goo00<007ooOol0BWoo0P006Woo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0Bgoo10005goo000;Ool2000:Ool20004
Ool20002Ool50002Ool00`00Oomoo`1>Ool<000<Ool002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03
001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol0
00]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001o
ogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001c
Ool000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo
0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo
0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00
Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011o
o`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool0
01aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00
Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo
0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=
Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo
0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03
001oogoo079oo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007oo
Oomoo`0000=oo`05001oogooOol00002Ool30002Ool01@00Oomoogoo00000goo00<007ooOol00Woo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo
00<007ooOol02Woo000LOol00`00Oomoo`0hOol2000hOol001aoo`8003]oo`<003Eoo`0077oo00<0
07ooOol0?7oo0P00=7oo000LOol00`00Oomoo`0mOol2000cOol001aoo`8003moo`<0035oo`0077oo
00<007ooOol0@7oo0`00;goo000LOol00`00Oomoo`12Ool2000^Ool001aoo`8004Aoo`03001oogoo
02aoo`0077oo00<007ooOol0A7oo00<007ooOol0:goo000LOol20016Ool00`00Oomoo`0ZOol000]o
o`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo04Eoo`8002]oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`16Ool00`00Oomoo`0YOol000Yoo`04001oogoo000;Ool0
0`00Oomoo`020017Ool00`00Oomoo`0YOol000Yoo`04001oogoo000;Ool01000Oomoo`00BGoo00<0
07ooOol0:7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0B7oo00<007ooOol09goo000:
Ool01000Oomoo`001goo00<007ooOol017oo0P00BGoo00<007ooOol09goo000;Ool20008Ool50002
Ool00`00Oomoo`18Ool2000XOol001aoo`03001oogoo04Uoo`03001oogoo02Ioo`0077oo0P00Bgoo
00<007ooOol09Goo000LOol00`00Oomoo`1:Ool00`00Oomoo`0UOol001aoo`8004aoo`03001oogoo
02Aoo`0077oo00<007ooOol0Bgoo00<007ooOol097oo000LOol00`00Oomoo`1<Ool00`00Oomoo`0S
Ool001aoo`8004eoo`8002Aoo`005Woo0`000goo00<007ooOol0CGoo00<007ooOol08Woo000GOol0
0`00Oomoo`02Ool00`00Oomoo`1=Ool2000SOol001Moo`03001oogoo009oo`8004moo`03001oogoo
025oo`005goo00<007ooOol00Woo00<007ooOol0Cgoo00<007ooOol087oo000GOol00`00Oomoo`02
Ool00`00Oomoo`1?Ool00`00Oomoo`0POol001Ioo`8000Aoo`80055oo`03001oogoo01moo`005goo
00<007ooOol00Woo00<007ooOol0D7oo00<007ooOol07goo000LOol00`00Oomoo`1AOol00`00Oomo
o`0NOol001aoo`80059oo`03001oogoo01ioo`0077oo00<007ooOol0DWoo00<007ooOol07Goo000L
Ool2001COol00`00Oomoo`0MOol001aoo`03001oogoo059oo`8001ioo`0077oo00<007ooOol0Dgoo
00<007ooOol077oo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001EOol00`00Oomoo`0KOol0
00]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1EOol2000KOol000]oo`03001o
ogoo00]oo`04001oogoo001HOol@000<Ool000]oo`03001oogoo00]oo`03001oogoo008007=oo`00
2goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00
Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol0
0`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(41750\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31676 m
.008 .31708 L
.012 .31718 L
.016 .31848 L
.02 .31997 L
.024 .32133 L
.028 .32211 L
.032 .32151 L
.036 .31989 L
.04 .31788 L
.044 .31658 L
.048 .31675 L
.052 .31821 L
.056 .32035 L
.06 .32207 L
.064 .32258 L
.068 .3216 L
.072 .3195 L
.076 .31737 L
.08 .31637 L
.084 .31708 L
.088 .31906 L
.092 .32127 L
.096 .32268 L
.1 .32262 L
.104 .32109 L
.108 .31877 L
.112 .31689 L
.116 .31648 L
.12 .31762 L
.124 .31956 L
.128 .32126 L
.132 .3221 L
.136 .32198 L
.14 .32101 L
.144 .31971 L
.148 .31879 L
.152 .31875 L
.156 .31927 L
.16 .31952 L
.164 .31925 L
.168 .31891 L
.172 .31909 L
.176 .31985 L
.18 .3208 L
.184 .32167 L
.188 .32213 L
.192 .32179 L
.196 .32028 L
.2 .31797 L
Mistroke
.204 .31623 L
.208 .31632 L
.212 .31833 L
.216 .32109 L
.22 .32326 L
.224 .32421 L
.228 .32387 L
.232 .32233 L
.236 .31986 L
.24 .31725 L
.244 .31567 L
.248 .31586 L
.252 .31748 L
.256 .31946 L
.26 .32099 L
.264 .32203 L
.268 .32292 L
.272 .32365 L
.276 .32369 L
.28 .32258 L
.284 .32054 L
.288 .31847 L
.292 .31728 L
.296 .3172 L
.3 .31781 L
.304 .31856 L
.308 .31933 L
.312 .32042 L
.316 .32186 L
.32 .32304 L
.324 .32309 L
.328 .32183 L
.332 .32024 L
.336 .3197 L
.34 .32062 L
.344 .32182 L
.348 .32167 L
.352 .31979 L
.356 .31765 L
.36 .3172 L
.364 .3188 L
.368 .32071 L
.372 .32092 L
.376 .31934 L
.38 .31815 L
.384 .3196 L
.388 .32352 L
.392 .32712 L
.396 .32746 L
.4 .3243 L
Mistroke
.404 .32033 L
.408 .31859 L
.412 .3196 L
.416 .32091 L
.42 .3197 L
.424 .3157 L
.428 .31177 L
.432 .31138 L
.436 .31552 L
.44 .32171 L
.444 .32613 L
.448 .32671 L
.452 .32459 L
.456 .32277 L
.46 .32339 L
.464 .32604 L
.468 .32836 L
.472 .32813 L
.476 .32498 L
.48 .32041 L
.484 .31648 L
.488 .3145 L
.492 .31458 L
.496 .3161 L
.5 .31828 L
.504 .32027 L
.508 .32114 L
.512 .32008 L
.516 .31711 L
.52 .31361 L
.524 .31193 L
.528 .31395 L
.532 .31955 L
.536 .32611 L
.54 .32987 L
.544 .32831 L
.548 .32215 L
.552 .31521 L
.556 .31235 L
.56 .31644 L
.564 .32656 L
.568 .33828 L
.572 .34619 L
.576 .34684 L
.58 .34048 L
.584 .33069 L
.588 .32224 L
.592 .3186 L
.596 .32045 L
.6 .32588 L
Mistroke
.604 .33189 L
.608 .33613 L
.612 .33784 L
.616 .33764 L
.62 .33647 L
.624 .33459 L
.628 .33133 L
.632 .32575 L
.636 .31782 L
.64 .30915 L
.644 .30284 L
.648 .30215 L
.652 .30894 L
.656 .32244 L
.66 .33929 L
.664 .35477 L
.668 .36458 L
.672 .3664 L
.676 .36051 L
.68 .34934 L
.684 .33614 L
.688 .32365 L
.692 .31306 L
.696 .30382 L
.7 .29412 L
.704 .28199 L
.708 .26627 L
.712 .2474 L
.716 .22738 L
.72 .20911 L
.724 .19536 L
.728 .18771 L
.732 .18605 L
.736 .18864 L
.74 .19273 L
.744 .19547 L
.748 .19472 L
.752 .1896 L
.756 .18067 L
.76 .16972 L
.764 .15918 L
.768 .15142 L
.772 .14813 L
.776 .14985 L
.78 .1559 L
.784 .16463 L
.788 .1739 L
.792 .18151 L
.796 .18567 L
.8 .18528 L
Mistroke
.804 .18003 L
.808 .17049 L
.812 .15789 L
.816 .14394 L
.82 .13045 L
.824 .11911 L
.828 .11121 L
.832 .10756 L
.836 .10849 L
.84 .11383 L
.844 .12305 L
.848 .13536 L
.852 .14987 L
.856 .1657 L
.86 .18204 L
.864 .19817 L
.868 .21346 L
.872 .22748 L
.876 .23996 L
.88 .25081 L
.884 .26008 L
.888 .26788 L
.892 .27432 L
.896 .27956 L
.9 .28376 L
.904 .28708 L
.908 .28969 L
.912 .29173 L
.916 .29331 L
.92 .29454 L
.924 .2955 L
.928 .29625 L
.932 .29685 L
.936 .29734 L
.94 .29774 L
.944 .29807 L
.948 .29833 L
.952 .29854 L
.956 .29869 L
.96 .29881 L
.964 .29893 L
.968 .29904 L
.972 .29916 L
.976 .29927 L
.98 .29933 L
.984 .29935 L
.988 .29937 L
.992 .29937 L
.996 .29939 L
1 .29941 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12753 m
.008 .12333 L
.012 .12194 L
.016 .12346 L
.02 .12388 L
.024 .12339 L
.028 .12324 L
.032 .12346 L
.036 .12349 L
.04 .12343 L
.044 .12339 L
.048 .1234 L
.052 .12338 L
.056 .12337 L
.06 .12336 L
.064 .12338 L
.068 .12338 L
.072 .1234 L
.076 .1234 L
.08 .12341 L
.084 .12341 L
.088 .12343 L
.092 .12343 L
.096 .12344 L
.1 .12343 L
.104 .12343 L
.108 .1234 L
.112 .12338 L
.116 .12336 L
.12 .12335 L
.124 .12334 L
.128 .12336 L
.132 .12339 L
.136 .12342 L
.14 .12344 L
.144 .12345 L
.148 .12345 L
.152 .12345 L
.156 .12343 L
.16 .12341 L
.164 .12338 L
.168 .12337 L
.172 .12336 L
.176 .12336 L
.18 .12337 L
.184 .1234 L
.188 .12343 L
.192 .12345 L
.196 .12343 L
.2 .1234 L
Mistroke
.204 .12336 L
.208 .12334 L
.212 .12332 L
.216 .12333 L
.22 .12337 L
.224 .12345 L
.228 .12354 L
.232 .12358 L
.236 .12357 L
.24 .12352 L
.244 .12345 L
.248 .12336 L
.252 .12327 L
.256 .12318 L
.26 .12314 L
.264 .12317 L
.268 .12327 L
.272 .12339 L
.276 .12351 L
.28 .12359 L
.284 .12365 L
.288 .12368 L
.292 .12365 L
.296 .12356 L
.3 .12342 L
.304 .12328 L
.308 .1232 L
.312 .12318 L
.316 .1232 L
.32 .12323 L
.324 .12326 L
.328 .12333 L
.332 .12345 L
.336 .12359 L
.34 .12367 L
.344 .12366 L
.348 .12359 L
.352 .12351 L
.356 .12348 L
.36 .12345 L
.364 .12335 L
.368 .12318 L
.372 .123 L
.376 .12293 L
.38 .12302 L
.384 .12322 L
.388 .1234 L
.392 .12353 L
.396 .12363 L
.4 .12379 L
Mistroke
.404 .12404 L
.408 .12427 L
.412 .1243 L
.416 .12406 L
.42 .12362 L
.424 .12316 L
.428 .12283 L
.432 .12264 L
.436 .1225 L
.44 .12234 L
.444 .12218 L
.448 .12216 L
.452 .1224 L
.456 .12293 L
.46 .12361 L
.464 .12423 L
.468 .12465 L
.472 .12484 L
.476 .12489 L
.48 .12486 L
.484 .12483 L
.488 .12475 L
.492 .12458 L
.496 .12427 L
.5 .12382 L
.504 .12327 L
.508 .12269 L
.512 .12219 L
.516 .12185 L
.52 .1217 L
.524 .12169 L
.528 .12167 L
.532 .12152 L
.536 .12116 L
.54 .12069 L
.544 .1203 L
.548 .12023 L
.552 .12063 L
.556 .12146 L
.56 .12253 L
.564 .12359 L
.568 .1245 L
.572 .12526 L
.576 .12607 L
.58 .12718 L
.584 .12875 L
.588 .1308 L
.592 .13314 L
.596 .13553 L
.6 .13774 L
Mistroke
.604 .13964 L
.608 .14125 L
.612 .14263 L
.616 .1439 L
.62 .14515 L
.624 .14648 L
.628 .14798 L
.632 .14976 L
.636 .15193 L
.64 .15453 L
.644 .15751 L
.648 .16069 L
.652 .16382 L
.656 .16662 L
.66 .16888 L
.664 .17055 L
.668 .17174 L
.672 .17268 L
.676 .17365 L
.68 .17487 L
.684 .17648 L
.688 .17851 L
.692 .18091 L
.696 .18362 L
.7 .18662 L
.704 .18995 L
.708 .19371 L
.712 .19802 L
.716 .20292 L
.72 .20839 L
.724 .21431 L
.728 .2205 L
.732 .22674 L
.736 .23286 L
.74 .23875 L
.744 .24442 L
.748 .24995 L
.752 .25549 L
.756 .26116 L
.76 .26708 L
.764 .27328 L
.768 .27969 L
.772 .28622 L
.776 .2927 L
.78 .29899 L
.784 .30498 L
.788 .31061 L
.792 .31592 L
.796 .321 L
.8 .326 L
Mistroke
.804 .33106 L
.808 .33636 L
.812 .34202 L
.816 .3481 L
.82 .35461 L
.824 .36151 L
.828 .3687 L
.832 .37605 L
.836 .3834 L
.84 .3906 L
.844 .39751 L
.848 .404 L
.852 .41 L
.856 .41544 L
.86 .42028 L
.864 .42454 L
.868 .42822 L
.872 .43138 L
.876 .43404 L
.88 .43628 L
.884 .43814 L
.888 .43968 L
.892 .44095 L
.896 .442 L
.9 .44286 L
.904 .44357 L
.908 .44416 L
.912 .44465 L
.916 .44505 L
.92 .4454 L
.924 .44569 L
.928 .44594 L
.932 .44615 L
.936 .44634 L
.94 .44649 L
.944 .44664 L
.948 .44675 L
.952 .44686 L
.956 .44695 L
.96 .44704 L
.964 .4471 L
.968 .44718 L
.972 .44723 L
.976 .4473 L
.98 .44733 L
.984 .4474 L
.988 .44742 L
.992 .44749 L
.996 .4475 L
1 .44757 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15907 L
.012 .16099 L
.016 .16174 L
.02 .16124 L
.024 .16094 L
.028 .16116 L
.032 .16126 L
.036 .16123 L
.04 .16114 L
.044 .16113 L
.048 .16108 L
.052 .16106 L
.056 .16102 L
.06 .16103 L
.064 .16103 L
.068 .16106 L
.072 .16106 L
.076 .16108 L
.08 .16107 L
.084 .16107 L
.088 .16104 L
.092 .16102 L
.096 .161 L
.1 .16099 L
.104 .16097 L
.108 .16097 L
.112 .16095 L
.116 .16095 L
.12 .16093 L
.124 .1609 L
.128 .16088 L
.132 .16088 L
.136 .16089 L
.14 .16091 L
.144 .16093 L
.148 .16095 L
.152 .16095 L
.156 .16092 L
.16 .16087 L
.164 .16082 L
.168 .16078 L
.172 .16078 L
.176 .16078 L
.18 .16079 L
.184 .16082 L
.188 .16084 L
.192 .16083 L
.196 .16079 L
.2 .16073 L
Mistroke
.204 .16068 L
.208 .16066 L
.212 .16065 L
.216 .16065 L
.22 .16069 L
.224 .16077 L
.228 .16087 L
.232 .16092 L
.236 .1609 L
.24 .16083 L
.244 .16072 L
.248 .1606 L
.252 .16046 L
.256 .16034 L
.26 .16028 L
.264 .16032 L
.268 .16046 L
.272 .16062 L
.276 .16075 L
.28 .16084 L
.284 .16088 L
.288 .16089 L
.292 .16084 L
.296 .16072 L
.3 .16054 L
.304 .16037 L
.308 .16026 L
.312 .16024 L
.316 .16027 L
.32 .16029 L
.324 .16031 L
.328 .16038 L
.332 .16051 L
.336 .16066 L
.34 .16076 L
.344 .16074 L
.348 .16065 L
.352 .16056 L
.356 .16051 L
.36 .16047 L
.364 .16034 L
.368 .16011 L
.372 .15987 L
.376 .15976 L
.38 .15986 L
.384 .1601 L
.388 .16033 L
.392 .16048 L
.396 .1606 L
.4 .1608 L
Mistroke
.404 .1611 L
.408 .16136 L
.412 .16139 L
.416 .16109 L
.42 .16054 L
.424 .15996 L
.428 .15953 L
.432 .15928 L
.436 .15909 L
.44 .15887 L
.444 .15867 L
.448 .15865 L
.452 .15896 L
.456 .15961 L
.46 .16043 L
.464 .16118 L
.468 .16168 L
.472 .16192 L
.476 .16196 L
.48 .16194 L
.484 .16189 L
.488 .16179 L
.492 .16157 L
.496 .16117 L
.5 .16059 L
.504 .15989 L
.508 .15916 L
.512 .15852 L
.516 .15809 L
.52 .1579 L
.524 .15788 L
.528 .15786 L
.532 .15766 L
.536 .1572 L
.54 .15659 L
.544 .15609 L
.548 .156 L
.552 .15649 L
.556 .15752 L
.56 .15885 L
.564 .16016 L
.568 .16127 L
.572 .16221 L
.576 .16322 L
.58 .16459 L
.584 .16655 L
.588 .16908 L
.592 .17199 L
.596 .17495 L
.6 .17769 L
Mistroke
.604 .18005 L
.608 .18204 L
.612 .18375 L
.616 .18532 L
.62 .18686 L
.624 .18851 L
.628 .19036 L
.632 .19257 L
.636 .19525 L
.64 .19847 L
.644 .20217 L
.648 .20613 L
.652 .21001 L
.656 .21348 L
.66 .21627 L
.664 .21833 L
.668 .21979 L
.672 .22094 L
.676 .22213 L
.68 .22364 L
.684 .22563 L
.688 .22814 L
.692 .2311 L
.696 .23446 L
.7 .23817 L
.704 .2423 L
.708 .24697 L
.712 .25231 L
.716 .25839 L
.72 .26518 L
.724 .27254 L
.728 .28022 L
.732 .28797 L
.736 .29556 L
.74 .30287 L
.744 .3099 L
.748 .31676 L
.752 .32362 L
.756 .33065 L
.76 .33799 L
.764 .34566 L
.768 .35362 L
.772 .36172 L
.776 .36975 L
.78 .37754 L
.784 .38495 L
.788 .39192 L
.792 .39849 L
.796 .40477 L
.8 .41094 L
Mistroke
.804 .4172 L
.808 .42376 L
.812 .43075 L
.816 .43827 L
.82 .44633 L
.824 .45487 L
.828 .46377 L
.832 .47287 L
.836 .48196 L
.84 .49087 L
.844 .49941 L
.848 .50744 L
.852 .51484 L
.856 .52154 L
.86 .52751 L
.864 .53274 L
.868 .53726 L
.872 .54111 L
.876 .54436 L
.88 .54707 L
.884 .54931 L
.888 .55116 L
.892 .55266 L
.896 .5539 L
.9 .55489 L
.904 .5557 L
.908 .55635 L
.912 .55689 L
.916 .55732 L
.92 .55768 L
.924 .55796 L
.928 .5582 L
.932 .55838 L
.936 .55854 L
.94 .55865 L
.944 .55875 L
.948 .55881 L
.952 .55888 L
.956 .55891 L
.96 .55895 L
.964 .55895 L
.968 .55897 L
.972 .55895 L
.976 .55896 L
.98 .55892 L
.984 .55892 L
.988 .55887 L
.992 .55887 L
.996 .55881 L
1 .5588 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0CWoo0P00
77oo000ROol2001>Ool00`00Ool0000LOol000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009o
o`03001oogoo04eoo`03001oo`0001aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`000Woo0P00CWoo00@007ooOol001]oo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool20019Ool20003Ool01000Oomoo`006goo000:Ool01000Oomoo`0027oo
00@007ooOol000Aoo`05001oogooOol0001:Ool300000goo001oo`02Ool00`00Oomoo`0IOol000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008004Qoo`06001oogoo001oo`00
17oo00<007ooOol067oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
0018Ool00`00Oomoo`020005Ool00`00Oomoo`0HOol000]oo`8000Yoo`8000=oo`<000=oo`03001o
ogoo04Aoo`<000Yoo`03001oogoo01Qoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo
0P00AGoo00<007ooOol02Woo00<007ooOol067oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8000eoo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Ao
o`8000=oo`D000=oo`8000Aoo`<000=oo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo00000Woo
00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomo
o`0000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002
Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`04001oogooOol20004Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`07001oogooOol0
07oo00000goo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`04Ool01000Oomoo`000Woo
00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00]o
o`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04
001oogooOol40003Ool01000Oomoo`000Woo0P000Woo00@007ooOol0009oo`04001oogoo0002Ool2
0002Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03001o
ogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`03001oogoo00<00003Ool007oo009oo`03001oo`0000Ioo`04001oogoo0005Ool0
029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003
Ool20003Ool40004Ool20004Ool20002Ool00`00Oomoo`030002Ool50003Ool20006Ool0029oo`03
001oogoo049oo`03001oogoo00moo`8001Ioo`008Woo0P00@Woo00<007ooOol04Woo1@004Goo000R
OomS000<Ool0029oo`<00003Ool00000009oo`800003Ool00000009oo`<0009oo`80009oo`800003
Ool0000000<000=oo`<00003Ool0000000<000=oo`H00003Ool00000009oo`80009oo`09001oo`00
Ool007oo001oo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`03001oogoo00Yoo`008Woo1@0000Aoo`00001oo`800005Ool00000001oo`0400001Goo0000
0000Ool0100000=oo`0000000`0000=oo`000000100000=oo`0000000`0000Aoo`00001oo`@00004
Ool000000002Ool00`00Ool00002Ool00`00Oomoo`0YOol0029oo`03001oogoo039oo`06001oo`00
Ool007oo0`000Woo00@007ooOol002]oo`008Woo0P00=Woo0P001Woo00<007oo0000;7oo000ROol2
000oOol2000/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo03ioo`80
02aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P00
17oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Ao
o`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<0
00=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003
Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00
Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool0
00]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029o
o`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001o
ogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Io
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uo
o`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Oolf000cOol0011oo`04001oogoo0008Ool01000Oomo
o`000Woo0P0017oo00<007ooOol0<goo0P00<Goo000AOol2000:Ool20004Ool00`00Oomoo`02Ool0
0`00Oomoo`0dOol4000^Ool002Qoo`03001oogoo03Moo`8002eoo`00:7oo00<007ooOol0>7oo0`00
:goo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0jOol3000Y
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00
?goo00<007ooOol09Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0005Ool01000Oomoo`00@7oo0P009Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool3
0004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol0
0002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00
Oomoogoo00000goo00@007ooOol0009oo`05001oogoo001oo`020002Ool01000Oomoo`000Woo00@0
07ooOol000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo
0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
ogoo00Eoo`04001oogoo0002Ool01000Oomoogoo0P000goo00@007ooOol0009oo`04001oogoo0004
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002
Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo
0P000Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool20000
1Goo001oogoo00000Woo00@007ooOol0009oo`06001oogooOol007oo10000goo00@007ooOol000Eo
o`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002
Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool40002Ool01000
Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo
00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003
Ool30002Ool01000Ool0000017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`14
Ool00`00Oomoo`0OOol002Qoo`03001oogoo04Aoo`03001oogoo01moo`00:7ooG@0037oo000XOol0
0`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool0
0`00Oomoo`0:Ool002Qoo`03001oogoo04Ioo`8001ioo`00:7oo00<007ooOol0Agoo00<007ooOol0
77oo000XOol00`00Oomoo`18Ool00`00Oomoo`0KOol002Qoo`03001oogoo04Qoo`03001oogoo01]o
o`00:7oo00<007ooOol0BGoo00<007ooOol06Woo000;Ool20004Ool00`00Oomoo`03Ool20004Ool2
0003Ool30003Ool00`00Oomoo`1:Ool00`00Oomoo`0IOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00H007ooOol007oo0003Ool01000Oomoo`00C7oo00<007ooOol06Goo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00CGoo00<007ooOol067oo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001<Ool2000I
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo
04aoo`8001Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03
001oogoo04eoo`D001Aoo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0DGoo2@00
37oo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo
0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`80
00Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo
00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool0
1000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001o
ogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04
001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001o
ogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1b
Ool001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Ao
o`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007oo
Oomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol0
0goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol0
07oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol0
00Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol0
07oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P00
17oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=o
o`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo00D0
07ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07oo00000P000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0>goo0P00
=Goo000LOol2000mOol3000cOol001aoo`03001oogoo03moo`03001oogoo031oo`0077oo00<007oo
Ool0@7oo0P00<7oo000LOol20012Ool3000^Ool001aoo`03001oogoo04=oo`<002aoo`0077oo00<0
07ooOol0AGoo0P00:goo000LOol20017Ool00`00Oomoo`0YOol001aoo`03001oogoo04Moo`03001o
ogoo02Qoo`0077oo0P00BGoo00<007ooOol09goo000;Ool20004Ool00`00Oomoo`02Ool30003Ool0
0`00Oomoo`18Ool00`00Oomoo`0WOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0B7oo0P00:7oo000:Ool01000Oomoo`002goo00<007ooOol00P00BWoo00<007ooOol09Woo
000:Ool01000Oomoo`002goo00@007ooOol004aoo`03001oogoo02Eoo`002Woo00@007ooOol000Mo
o`@000=oo`03001oogoo04Yoo`8002Ioo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8004ao
o`03001oogoo02Aoo`002goo0P0027oo1@000Woo00<007ooOol0Bgoo00<007ooOol097oo000LOol0
0`00Oomoo`1<Ool00`00Oomoo`0SOol001aoo`8004ioo`03001oogoo029oo`0077oo00<007ooOol0
CGoo00<007ooOol08Woo000LOol2001>Ool00`00Oomoo`0ROol001aoo`03001oogoo04ioo`03001o
ogoo025oo`0077oo00<007ooOol0Cgoo00<007ooOol087oo000LOol2001@Ool00`00Oomoo`0POol0
01Ioo`<000=oo`03001oogoo051oo`03001oogoo01moo`005goo00<007ooOol00Woo00<007ooOol0
D7oo0P0087oo000GOol00`00Oomoo`02Ool2001BOol00`00Oomoo`0NOol001Moo`03001oogoo009o
o`03001oogoo059oo`03001oogoo01eoo`005goo00<007ooOol00Woo00<007ooOol0DWoo00<007oo
Ool07Goo000FOol20004Ool2001COol00`00Oomoo`0MOol001Moo`03001oogoo009oo`03001oogoo
05=oo`03001oogoo01aoo`0077oo00<007ooOol0E7oo00<007ooOol06goo000LOol2001EOol00`00
Oomoo`0KOol001aoo`03001oogoo05Aoo`03001oogoo01]oo`0077oo0P00EWoo00<007ooOol06Woo
000LOol00`00Oomoo`1EOol00`00Oomoo`0JOol001aoo`03001oogoo05Ioo`03001oogoo01Uoo`00
2Woo0`0017oo00<007ooOol00Woo0`000goo0P00F7oo00<007ooOol067oo000;Ool00`00Oomoo`07
Ool01@00Oomoogoo00000Woo00<007ooOol0Egoo0`0067oo000;Ool00`00Oomoo`0;Ool01000Oomo
o`00Fgoo3@0037oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Mo
o`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool0
0`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(41917\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3249 m
.008 .32347 L
.012 .31975 L
.016 .31655 L
.02 .31572 L
.024 .3158 L
.028 .31723 L
.032 .32006 L
.036 .32264 L
.04 .32357 L
.044 .32222 L
.048 .31969 L
.052 .31726 L
.056 .3159 L
.06 .31637 L
.064 .31831 L
.068 .32071 L
.072 .32228 L
.076 .32222 L
.08 .3208 L
.084 .31891 L
.088 .31757 L
.092 .31742 L
.096 .31846 L
.1 .32007 L
.104 .32128 L
.108 .32135 L
.112 .32035 L
.116 .31906 L
.12 .31838 L
.124 .31863 L
.128 .31954 L
.132 .32057 L
.136 .3211 L
.14 .32065 L
.144 .31926 L
.148 .31782 L
.152 .31745 L
.156 .31855 L
.16 .32048 L
.164 .32213 L
.168 .32284 L
.172 .3223 L
.176 .32064 L
.18 .3184 L
.184 .31665 L
.188 .31646 L
.192 .31796 L
.196 .32017 L
.2 .32184 L
Mistroke
.204 .32246 L
.208 .32226 L
.212 .32152 L
.216 .32031 L
.22 .31885 L
.224 .31778 L
.228 .31766 L
.232 .31838 L
.236 .31936 L
.24 .32025 L
.244 .3212 L
.248 .32238 L
.252 .32331 L
.256 .32312 L
.26 .3215 L
.264 .3191 L
.268 .3171 L
.272 .31628 L
.276 .31664 L
.28 .31777 L
.284 .31941 L
.288 .32138 L
.292 .32328 L
.296 .32441 L
.3 .32412 L
.304 .32248 L
.308 .32033 L
.312 .31875 L
.316 .31824 L
.32 .3184 L
.324 .3185 L
.328 .31831 L
.332 .31841 L
.336 .31948 L
.34 .32135 L
.344 .32286 L
.348 .32289 L
.352 .32159 L
.356 .32036 L
.36 .32048 L
.364 .32168 L
.368 .32236 L
.372 .32128 L
.376 .31906 L
.38 .31765 L
.384 .31833 L
.388 .32018 L
.392 .32098 L
.396 .31959 L
.4 .31741 L
Mistroke
.404 .3172 L
.408 .32025 L
.412 .32479 L
.416 .32739 L
.42 .32612 L
.424 .3224 L
.428 .31967 L
.432 .32009 L
.436 .32248 L
.44 .32344 L
.444 .32065 L
.448 .31525 L
.452 .31104 L
.456 .31124 L
.46 .31583 L
.464 .32161 L
.468 .32498 L
.472 .32471 L
.476 .3226 L
.48 .32158 L
.484 .32316 L
.488 .32637 L
.492 .32881 L
.496 .32863 L
.5 .32576 L
.504 .3216 L
.508 .31785 L
.512 .31556 L
.516 .31501 L
.52 .31604 L
.524 .31824 L
.528 .32077 L
.532 .32226 L
.536 .32137 L
.54 .31791 L
.544 .31348 L
.548 .31095 L
.552 .31269 L
.556 .31869 L
.56 .32606 L
.564 .33055 L
.568 .32918 L
.572 .32247 L
.576 .31442 L
.58 .31027 L
.584 .31338 L
.588 .32311 L
.592 .33516 L
.596 .34395 L
.6 .34574 L
Mistroke
.604 .34041 L
.608 .3312 L
.612 .32266 L
.616 .31824 L
.62 .31885 L
.624 .32299 L
.628 .32814 L
.632 .33229 L
.636 .33477 L
.64 .33598 L
.644 .33645 L
.648 .33603 L
.652 .33368 L
.656 .32825 L
.66 .31959 L
.664 .3093 L
.668 .30061 L
.672 .2972 L
.676 .3015 L
.68 .31344 L
.684 .33021 L
.688 .34717 L
.692 .35967 L
.696 .36473 L
.7 .36188 L
.704 .353 L
.708 .3412 L
.712 .3294 L
.716 .31914 L
.72 .31022 L
.724 .30103 L
.728 .28949 L
.732 .27418 L
.736 .25517 L
.74 .23417 L
.744 .21403 L
.748 .19771 L
.752 .18728 L
.756 .1832 L
.76 .18422 L
.764 .18786 L
.768 .1912 L
.772 .19177 L
.776 .18817 L
.78 .1804 L
.784 .16978 L
.788 .15854 L
.792 .14913 L
.796 .14361 L
.8 .14305 L
Mistroke
.804 .14732 L
.808 .15522 L
.812 .16476 L
.816 .1737 L
.82 .17997 L
.824 .18207 L
.828 .17927 L
.832 .17172 L
.836 .16036 L
.84 .1467 L
.844 .1325 L
.848 .11953 L
.852 .1093 L
.856 .10293 L
.86 .10103 L
.864 .10373 L
.868 .11072 L
.872 .12135 L
.876 .13483 L
.88 .15024 L
.884 .16673 L
.888 .18345 L
.892 .1997 L
.896 .21493 L
.9 .22879 L
.904 .24107 L
.908 .25174 L
.912 .26084 L
.916 .26846 L
.92 .27475 L
.924 .27987 L
.928 .28397 L
.932 .28721 L
.936 .28976 L
.94 .29174 L
.944 .29327 L
.948 .29448 L
.952 .29544 L
.956 .29621 L
.96 .29683 L
.964 .29735 L
.968 .29774 L
.972 .29804 L
.976 .29824 L
.98 .29839 L
.984 .29853 L
.988 .29869 L
.992 .29885 L
.996 .29898 L
1 .29906 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12717 m
.008 .12396 L
.012 .1228 L
.016 .1238 L
.02 .12421 L
.024 .12395 L
.028 .12376 L
.032 .12383 L
.036 .12386 L
.04 .12385 L
.044 .12382 L
.048 .12386 L
.052 .12387 L
.056 .1239 L
.06 .1239 L
.064 .12391 L
.068 .12389 L
.072 .12388 L
.076 .12386 L
.08 .12385 L
.084 .12383 L
.088 .12383 L
.092 .12382 L
.096 .12384 L
.1 .12386 L
.104 .12388 L
.108 .12389 L
.112 .12391 L
.116 .1239 L
.12 .1239 L
.124 .12388 L
.128 .12387 L
.132 .12386 L
.136 .12386 L
.14 .12385 L
.144 .12384 L
.148 .12383 L
.152 .12383 L
.156 .12383 L
.16 .12384 L
.164 .12387 L
.168 .12391 L
.172 .12393 L
.176 .12394 L
.18 .12392 L
.184 .12389 L
.188 .12386 L
.192 .12384 L
.196 .12382 L
.2 .12382 L
Mistroke
.204 .12384 L
.208 .12388 L
.212 .12391 L
.216 .12391 L
.22 .12389 L
.224 .12387 L
.228 .12385 L
.232 .12382 L
.236 .12378 L
.24 .12378 L
.244 .12382 L
.248 .12389 L
.252 .12397 L
.256 .12402 L
.26 .12404 L
.264 .12403 L
.268 .12398 L
.272 .12389 L
.276 .12377 L
.28 .12365 L
.284 .12359 L
.288 .12362 L
.292 .1237 L
.296 .1238 L
.3 .12391 L
.304 .12401 L
.308 .12411 L
.312 .12417 L
.316 .12415 L
.32 .12406 L
.324 .12392 L
.328 .12379 L
.332 .12372 L
.336 .12369 L
.34 .12367 L
.344 .12366 L
.348 .12367 L
.352 .12375 L
.356 .12389 L
.36 .12403 L
.364 .1241 L
.368 .12408 L
.372 .12404 L
.376 .12402 L
.38 .12404 L
.384 .12401 L
.388 .12388 L
.392 .12366 L
.396 .12347 L
.4 .12342 L
Mistroke
.404 .1235 L
.408 .12365 L
.412 .12376 L
.416 .12383 L
.42 .12393 L
.424 .12416 L
.428 .12448 L
.432 .12475 L
.436 .12481 L
.44 .1246 L
.444 .12423 L
.448 .12385 L
.452 .12356 L
.456 .12334 L
.46 .12311 L
.464 .12283 L
.468 .12258 L
.472 .12249 L
.476 .1227 L
.48 .12318 L
.484 .1238 L
.488 .1244 L
.492 .12484 L
.496 .12511 L
.5 .12524 L
.504 .12531 L
.508 .12535 L
.512 .12534 L
.516 .12524 L
.52 .12499 L
.524 .12459 L
.528 .12405 L
.532 .12345 L
.536 .1229 L
.54 .12252 L
.544 .12235 L
.548 .12233 L
.552 .12233 L
.556 .12217 L
.56 .12179 L
.564 .12125 L
.568 .12076 L
.572 .12057 L
.576 .12083 L
.58 .12153 L
.584 .12248 L
.588 .12345 L
.592 .12427 L
.596 .12494 L
.6 .12566 L
Mistroke
.604 .12663 L
.608 .12805 L
.612 .12994 L
.616 .13217 L
.62 .1345 L
.624 .13674 L
.628 .13874 L
.632 .14048 L
.636 .14199 L
.64 .14334 L
.644 .14459 L
.648 .14584 L
.652 .14718 L
.656 .14875 L
.66 .15069 L
.664 .1531 L
.668 .15596 L
.672 .15912 L
.676 .16232 L
.68 .16528 L
.684 .16777 L
.688 .16968 L
.692 .17107 L
.696 .17212 L
.7 .1731 L
.704 .17423 L
.708 .17567 L
.712 .17747 L
.716 .17962 L
.72 .18205 L
.724 .18476 L
.728 .18779 L
.732 .19122 L
.736 .19518 L
.74 .19974 L
.744 .2049 L
.748 .21058 L
.752 .21661 L
.756 .22279 L
.76 .22892 L
.764 .23486 L
.768 .24058 L
.772 .24614 L
.776 .25165 L
.78 .25724 L
.784 .26305 L
.788 .26913 L
.792 .27546 L
.796 .28196 L
.8 .28848 L
Mistroke
.804 .29487 L
.808 .301 L
.812 .3068 L
.816 .31226 L
.82 .31744 L
.824 .32245 L
.828 .32745 L
.832 .3326 L
.836 .33804 L
.84 .34387 L
.844 .35013 L
.848 .3568 L
.852 .36383 L
.856 .37109 L
.86 .37844 L
.864 .38574 L
.868 .39284 L
.872 .39961 L
.876 .40593 L
.88 .41173 L
.884 .41697 L
.888 .42162 L
.892 .42569 L
.896 .42921 L
.9 .43221 L
.904 .43475 L
.908 .43687 L
.912 .43865 L
.916 .44011 L
.92 .44133 L
.924 .44232 L
.928 .44315 L
.932 .44382 L
.936 .44439 L
.94 .44485 L
.944 .44525 L
.948 .44558 L
.952 .44587 L
.956 .4461 L
.96 .44632 L
.964 .44648 L
.968 .44665 L
.972 .44677 L
.976 .44691 L
.98 .447 L
.984 .44711 L
.988 .44718 L
.992 .44728 L
.996 .44733 L
1 .44742 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16402 L
.012 .16112 L
.016 .1602 L
.02 .16127 L
.024 .1615 L
.028 .16112 L
.032 .16098 L
.036 .16111 L
.04 .16111 L
.044 .1611 L
.048 .16109 L
.052 .16114 L
.056 .16114 L
.06 .16115 L
.064 .16111 L
.068 .16108 L
.072 .16103 L
.076 .161 L
.08 .16097 L
.084 .16098 L
.088 .16099 L
.092 .16101 L
.096 .16101 L
.1 .16102 L
.104 .161 L
.108 .16098 L
.112 .16096 L
.116 .16096 L
.12 .16096 L
.124 .16096 L
.128 .16095 L
.132 .16094 L
.136 .16091 L
.14 .16087 L
.144 .16084 L
.148 .16082 L
.152 .16082 L
.156 .16084 L
.16 .16084 L
.164 .16086 L
.168 .16087 L
.172 .16089 L
.176 .16088 L
.18 .16085 L
.184 .16082 L
.188 .16079 L
.192 .16076 L
.196 .16072 L
.2 .1607 L
Mistroke
.204 .16072 L
.208 .16075 L
.212 .16078 L
.216 .16078 L
.22 .16075 L
.224 .16071 L
.228 .16066 L
.232 .1606 L
.236 .16056 L
.24 .16056 L
.244 .16061 L
.248 .16071 L
.252 .1608 L
.256 .16084 L
.26 .16084 L
.264 .1608 L
.268 .16072 L
.272 .1606 L
.276 .16045 L
.28 .16031 L
.284 .16024 L
.288 .16026 L
.292 .16036 L
.296 .16048 L
.3 .16059 L
.304 .1607 L
.308 .1608 L
.312 .16086 L
.316 .16083 L
.32 .16071 L
.324 .16054 L
.328 .16038 L
.332 .16029 L
.336 .16024 L
.34 .1602 L
.344 .16017 L
.348 .16017 L
.352 .16026 L
.356 .16042 L
.36 .16059 L
.364 .16067 L
.368 .16064 L
.372 .16058 L
.376 .16056 L
.38 .16057 L
.384 .16052 L
.388 .16034 L
.392 .16007 L
.396 .15982 L
.4 .15974 L
Mistroke
.404 .15984 L
.408 .16 L
.412 .16012 L
.416 .1602 L
.42 .16033 L
.424 .16062 L
.428 .16102 L
.432 .16135 L
.436 .1614 L
.44 .16112 L
.444 .16063 L
.448 .16015 L
.452 .15979 L
.456 .15952 L
.46 .15923 L
.464 .15887 L
.468 .15854 L
.472 .15843 L
.476 .15867 L
.48 .15925 L
.484 .16002 L
.488 .16075 L
.492 .16129 L
.496 .16162 L
.5 .16178 L
.504 .16187 L
.508 .16191 L
.512 .16188 L
.516 .16173 L
.52 .16141 L
.524 .1609 L
.528 .16022 L
.532 .15947 L
.536 .15878 L
.54 .15829 L
.544 .15806 L
.548 .15803 L
.552 .15803 L
.556 .15783 L
.56 .15735 L
.564 .15666 L
.568 .15603 L
.572 .15578 L
.576 .15611 L
.58 .15697 L
.584 .15815 L
.588 .15935 L
.592 .16035 L
.596 .16119 L
.6 .16206 L
Mistroke
.604 .16327 L
.608 .16503 L
.612 .16737 L
.616 .17013 L
.62 .17303 L
.624 .17581 L
.628 .1783 L
.632 .18046 L
.636 .18232 L
.64 .18398 L
.644 .18552 L
.648 .18706 L
.652 .18872 L
.656 .19067 L
.66 .19308 L
.664 .19607 L
.668 .19961 L
.672 .20352 L
.676 .2075 L
.68 .21118 L
.684 .21426 L
.688 .21662 L
.692 .21832 L
.696 .21962 L
.7 .22081 L
.704 .2222 L
.708 .22398 L
.712 .22621 L
.716 .22886 L
.72 .23187 L
.724 .23523 L
.728 .23898 L
.732 .24323 L
.736 .24814 L
.74 .25379 L
.744 .26021 L
.748 .26726 L
.752 .27475 L
.756 .28242 L
.76 .29002 L
.764 .29739 L
.768 .30449 L
.772 .31138 L
.776 .31821 L
.78 .32515 L
.784 .33235 L
.788 .33989 L
.792 .34774 L
.796 .35579 L
.8 .36387 L
Mistroke
.804 .37179 L
.808 .37938 L
.812 .38656 L
.816 .39332 L
.82 .39971 L
.824 .40591 L
.828 .41209 L
.832 .41846 L
.836 .42518 L
.84 .43239 L
.844 .44013 L
.848 .4484 L
.852 .45709 L
.856 .46608 L
.86 .47518 L
.864 .48422 L
.868 .493 L
.872 .50136 L
.876 .50917 L
.88 .51633 L
.884 .52278 L
.888 .52851 L
.892 .53351 L
.896 .53782 L
.9 .54148 L
.904 .54457 L
.908 .54714 L
.912 .54928 L
.916 .55102 L
.92 .55246 L
.924 .55362 L
.928 .55458 L
.932 .55534 L
.936 .55597 L
.94 .55647 L
.944 .55689 L
.948 .55722 L
.952 .5575 L
.956 .55771 L
.96 .5579 L
.964 .55803 L
.968 .55816 L
.972 .55822 L
.976 .55831 L
.98 .55833 L
.984 .55839 L
.988 .55838 L
.992 .55841 L
.996 .55837 L
1 .55839 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo0080059oo`03001oogoo01Qoo`002goo0P002Woo0P000goo0`000goo00<0
07ooOol0D7oo0`006Goo000ROol2001AOol00`00Ool0000IOol000]oo`8000Aoo`03001oogoo00=o
o`80009oo`D0009oo`03001oogoo04moo`04001oogoo000IOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol0009oo`8004aoo`05001oogooOol00002Ool00`00Oomoo`0GOol000=o
o`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Bgoo0P000goo00D0
07ooOomoo`0001Qoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01@00Oomoogoo0000C7oo
00<007oo00000Woo00D007ooOomoo`0001Qoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`00
0goo00<007ooOol00P00Bgoo00<007ooOol00P0017oo00<007ooOol05Woo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool00`00Oomoo`020018Ool00`00Ool00003Ool20005Ool00`00Oomo
o`0EOol000]oo`8000Yoo`8000=oo`<000=oo`03001oogoo04Ioo`04001oo`00000:Ool00`00Oomo
o`0EOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8004Moo`03001oogoo00]oo`03
001oogoo01Eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000=Ool3
0004Ool20007Ool30004Ool20004Ool20005Ool30003Ool30004Ool20003Ool50003Ool20004Ool2
0002Ool00`00Ool000040002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol02goo00D007ooOomoo`00009oo`04001oogoo0007
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000
Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007oo0000
0Woo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`02Ool20003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0007Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`04Ool01000Oomoo`000Woo
00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00]o
o`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04
001oogooOol40003Ool01000Oomoo`000Woo00<007ooOol00P000Woo00@007ooOol0009oo`04001o
ogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03
001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo
00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`020002Ool0
1000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`00
8Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=o
o`8000Aoo`<000Aoo`8000Aoo`8000Aoo`@0009oo`D000=oo`8000Ioo`008Woo00<007ooOol0A7oo
00<007ooOol047oo0P004goo000ROol20010Ool00`00Oomoo`02Ool00`00Oomoo`0AOol6000>Ool0
029oof<000aoo`008Woo00<007oo0000100000=oo`0000000`0000Eoo`00000007oo00<00005Ool0
0000001oo`020003Ool20002Ool00`00Ool000030002Ool3000017oo001oogoo0P0000=oo`000000
0`0000=oo`0000000P000Woo0P000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000aoo`008Woo0P0000Eoo`00000007oo00800004Ool00000
Ool2000017oo000007oo0`0000Aoo`000000009oo`<0009oo`@00003Ool0000000@00003Ool00000
00<0009oo`03001oogoo00<0009oo`80009oo`03001oo`0000=oo`03001oogoo02Ioo`008Woo00<0
07ooOol0=7oo00<007ooOol00P000Woo0`000Woo00@007ooOol002Qoo`008Woo0P00>7oo0P001goo
00<007oo0000:Goo000ROol20012Ool2000YOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`03001oogoo045oo`03001oogoo02Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06ao
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02
Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo
001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomo
o`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007oo
Ool000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00
KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<0
06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0
JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001W
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Io
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1V
Ool000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Oolh000aOol0
011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0=Goo0P00;goo000AOol2
000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0gOol3000/Ool002Qoo`03001oogoo03Uoo`<0
02Yoo`00:7oo00<007ooOol0>goo0P00:Goo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003
Ool30003Ool00`00Oomoo`0mOol3000VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0003Ool01000Oomoo`00@Goo0P009Goo0003Ool50002Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool01000Oomoo`00@Woo0P0097oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool2
0004Ool20003Ool30003Ool30004Ool20002Ool60002Ool20004Ool20003Ool50002Ool30004Ool2
0006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001o
ogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool20000
1Goo001oogoo00000Woo00@007ooOol000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03
001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo00000goo0P000Woo
00@007ooOol0009oo`03001oogoo009oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`020002Ool01000Oomoo`000Woo00<007ooOol0
0goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo1000
0goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007oo
Oomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol0
17oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007oo
Ool017oo00H007ooOol007oo0003Ool00`00Oomoo`0200001Goo001oogoo00000Woo00@007ooOol0
00=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03
001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004
Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo04Ioo`03001oogoo01eoo`00:7oo00<007oo
Ool0Agoo00<007ooOol077oo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03
001oogoo00moo`03001oogoo00moo`03001oo`00011oo`03001oogoo00Yoo`00:7oo00<007ooOol0
BGoo00<007ooOol06Woo000XOol00`00Oomoo`1:Ool00`00Oomoo`0IOol002Qoo`03001oogoo04Yo
o`8001Yoo`00:7oo00<007ooOol0Bgoo00<007ooOol067oo000XOol00`00Oomoo`1;Ool2000IOol0
00]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo04aoo`03001oogoo
01Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo
001>Ool2000HOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001o
ogoo001?Ool2000GOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo008004moo`03001oogoo01Eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00
Oomoo`00Ool010000goo00<007ooOol0Cgoo00<007ooOol057oo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0D7oo10004Woo000;Ool2000:Ool20004
Ool20002Ool50002Ool00`00Oomoo`1COol7000<Ool002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03
001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo00@007ooOol0
00]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001o
ogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001c
Ool000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol03Goo0`0017oo0P002Goo
0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo
0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00
Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011o
o`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool0
01aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00
Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo
0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=
Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo
0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1bOol001aoo`03
001oogoo079oo`0077ooJ@0037oo000LOol20002Ool01@00Oomoogoo000017oo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01000Oomoogoo0`0000=oo`00Ool00Woo00<007ooOol00Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<0
07ooOol02Woo000LOol00`00Oomoo`0nOol2000bOol001aoo`80041oo`<0031oo`0077oo00<007oo
Ool0@Goo0P00;goo000LOol00`00Oomoo`13Ool00`00Oomoo`0/Ool001aoo`8004Eoo`<002]oo`00
77oo00<007ooOol0AWoo0P00:Woo000LOol00`00Oomoo`18Ool00`00Oomoo`0WOol001aoo`8004Yo
o`03001oogoo02Ioo`0077oo00<007ooOol0BWoo00<007ooOol09Goo000LOol2001;Ool2000VOol0
00]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo04]oo`03001oogoo02Aoo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1;Ool00`00Oomoo`0TOol000Yoo`04001o
ogoo000;Ool00`00Oomoo`02001=Ool00`00Oomoo`0SOol000Yoo`04001oogoo000;Ool01000Oomo
o`00Cgoo00<007ooOol08Woo000:Ool01000Oomoo`001goo10000goo00<007ooOol0CGoo00<007oo
Ool08Woo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Cgoo00<007ooOol08Goo000;Ool2
0008Ool50002Ool00`00Oomoo`1>Ool00`00Oomoo`0QOol001aoo`03001oogoo04moo`03001oogoo
021oo`0077oo0P00D7oo00<007ooOol087oo000LOol00`00Oomoo`1@Ool00`00Oomoo`0OOol001ao
o`80055oo`03001oogoo01moo`0077oo00<007ooOol0DGoo00<007ooOol07Woo000LOol00`00Oomo
o`1AOol2000OOol001aoo`8005=oo`03001oogoo01eoo`005Woo0`000goo00<007ooOol0DWoo0P00
7Woo000GOol00`00Oomoo`02Ool00`00Oomoo`1COol00`00Oomoo`0LOol001Moo`03001oogoo009o
o`8005Eoo`03001oogoo01]oo`005goo00<007ooOol00Woo00<007ooOol0E7oo00<007ooOol06goo
000GOol00`00Oomoo`02Ool00`00Oomoo`1EOol00`00Oomoo`0JOol001Ioo`8000Aoo`8005Ioo`03
001oogoo01Yoo`005goo00<007ooOol00Woo00<007ooOol0EWoo00<007ooOol06Goo000LOol00`00
Oomoo`1FOol00`00Oomoo`0IOol001aoo`8005Qoo`03001oogoo01Qoo`0077oo00<007ooOol0Egoo
00<007ooOol067oo000LOol2001IOol00`00Oomoo`0GOol001aoo`03001oogoo05Qoo`03001oogoo
01Moo`0077oo00<007ooOol0FGoo00<007ooOol05Woo000:Ool30004Ool00`00Oomoo`02Ool30003
Ool2001JOol2000GOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1JOol2
000FOol000]oo`03001oogoo00]oo`04001oogoo001NOol:000<Ool000]oo`03001oogoo00]oo`03
001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool0
0`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(42084\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31902 m
.008 .31916 L
.012 .32054 L
.016 .3212 L
.02 .32113 L
.024 .32011 L
.028 .31821 L
.032 .31719 L
.036 .3174 L
.04 .31852 L
.044 .32002 L
.048 .32092 L
.052 .32101 L
.056 .32019 L
.06 .31892 L
.064 .31818 L
.068 .31829 L
.072 .31924 L
.076 .32037 L
.08 .32093 L
.084 .32064 L
.088 .31955 L
.092 .31828 L
.096 .31762 L
.1 .31804 L
.104 .31942 L
.108 .32092 L
.112 .32168 L
.116 .32132 L
.12 .32011 L
.124 .31866 L
.128 .31766 L
.132 .31771 L
.136 .31891 L
.14 .32057 L
.144 .32165 L
.148 .32162 L
.152 .32073 L
.156 .31957 L
.16 .3186 L
.164 .31809 L
.168 .31826 L
.172 .31907 L
.176 .32002 L
.18 .32056 L
.184 .32058 L
.188 .32055 L
.192 .3208 L
.196 .32106 L
.2 .32078 L
Mistroke
.204 .31989 L
.208 .31888 L
.212 .31822 L
.216 .31803 L
.22 .31834 L
.224 .31934 L
.228 .32099 L
.232 .3226 L
.236 .3231 L
.24 .32201 L
.244 .31997 L
.248 .31814 L
.252 .31729 L
.256 .31739 L
.26 .3182 L
.264 .31958 L
.268 .32138 L
.272 .32304 L
.276 .32372 L
.28 .32298 L
.284 .32122 L
.288 .31937 L
.292 .3181 L
.296 .31749 L
.3 .31729 L
.304 .31748 L
.308 .31836 L
.312 .32012 L
.316 .32229 L
.32 .32392 L
.324 .32414 L
.328 .32298 L
.332 .32127 L
.336 .31994 L
.34 .31925 L
.344 .31876 L
.348 .31807 L
.352 .31754 L
.356 .31801 L
.36 .3197 L
.364 .3217 L
.368 .32255 L
.372 .32179 L
.376 .32053 L
.38 .32044 L
.384 .32186 L
.388 .3233 L
.392 .32287 L
.396 .32038 L
.4 .31782 L
Mistroke
.404 .31749 L
.408 .31959 L
.412 .3218 L
.416 .32157 L
.42 .31877 L
.424 .31607 L
.428 .3165 L
.432 .32045 L
.436 .32507 L
.44 .32684 L
.444 .32478 L
.448 .32129 L
.452 .31985 L
.456 .32164 L
.46 .32448 L
.464 .32483 L
.468 .32113 L
.472 .31536 L
.476 .31142 L
.48 .31194 L
.484 .31623 L
.488 .3211 L
.492 .32351 L
.496 .32289 L
.5 .32114 L
.504 .32077 L
.508 .32279 L
.512 .32611 L
.516 .32863 L
.52 .32882 L
.524 .32654 L
.528 .32284 L
.532 .31906 L
.536 .31628 L
.54 .31518 L
.544 .31608 L
.548 .31867 L
.552 .3218 L
.556 .32358 L
.56 .32242 L
.564 .31822 L
.568 .31301 L
.572 .31006 L
.576 .3119 L
.58 .3184 L
.584 .32636 L
.588 .33123 L
.592 .32987 L
.596 .32275 L
.6 .31392 L
Mistroke
.604 .30879 L
.608 .31097 L
.612 .32009 L
.616 .33208 L
.62 .34143 L
.624 .34424 L
.628 .34006 L
.632 .33169 L
.636 .32336 L
.64 .31839 L
.644 .31781 L
.648 .32053 L
.652 .3245 L
.656 .32817 L
.66 .33106 L
.664 .33351 L
.668 .33572 L
.672 .33705 L
.676 .33605 L
.68 .3312 L
.684 .32216 L
.688 .3105 L
.692 .2996 L
.696 .29345 L
.7 .29505 L
.704 .30497 L
.708 .32092 L
.712 .33859 L
.716 .35319 L
.72 .36121 L
.724 .3615 L
.728 .35531 L
.732 .34538 L
.736 .33464 L
.74 .32494 L
.744 .31644 L
.748 .30782 L
.752 .29705 L
.756 .28247 L
.76 .26376 L
.764 .24223 L
.768 .22051 L
.772 .20171 L
.776 .18833 L
.78 .18146 L
.784 .18044 L
.788 .18318 L
.792 .18679 L
.796 .18851 L
.8 .18642 L
Mistroke
.804 .17996 L
.808 .16997 L
.812 .1584 L
.816 .14771 L
.82 .14018 L
.824 .13732 L
.828 .13951 L
.832 .14602 L
.836 .15519 L
.84 .1649 L
.844 .17294 L
.848 .17745 L
.852 .17729 L
.856 .17214 L
.86 .16253 L
.864 .14969 L
.868 .13529 L
.872 .12114 L
.876 .10892 L
.88 .1 L
.884 .09529 L
.888 .09519 L
.892 .09964 L
.896 .10821 L
.9 .12021 L
.904 .13478 L
.908 .15102 L
.912 .16801 L
.916 .18497 L
.92 .20125 L
.924 .21638 L
.928 .23008 L
.932 .2422 L
.936 .2527 L
.94 .26162 L
.944 .26905 L
.948 .27515 L
.952 .28009 L
.956 .28405 L
.96 .28719 L
.964 .28967 L
.968 .29162 L
.972 .29313 L
.976 .29429 L
.98 .29519 L
.984 .29589 L
.988 .29645 L
.992 .29688 L
.996 .29718 L
1 .29738 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12079 m
.008 .12444 L
.012 .12556 L
.016 .12426 L
.02 .12387 L
.024 .12437 L
.028 .12446 L
.032 .12431 L
.036 .12428 L
.04 .12437 L
.044 .12438 L
.048 .12437 L
.052 .12434 L
.056 .12433 L
.06 .12429 L
.064 .12428 L
.068 .12427 L
.072 .1243 L
.076 .12433 L
.08 .12437 L
.084 .12439 L
.088 .1244 L
.092 .12437 L
.096 .12435 L
.1 .12431 L
.104 .12429 L
.108 .12428 L
.112 .12429 L
.116 .12431 L
.12 .12433 L
.124 .12434 L
.128 .12434 L
.132 .12434 L
.136 .12435 L
.14 .12435 L
.144 .12436 L
.148 .12436 L
.152 .12437 L
.156 .12436 L
.16 .12433 L
.164 .12431 L
.168 .12429 L
.172 .12429 L
.176 .12429 L
.18 .12429 L
.184 .12431 L
.188 .12433 L
.192 .12436 L
.196 .12438 L
.2 .12439 L
Mistroke
.204 .12439 L
.208 .12438 L
.212 .12435 L
.216 .12431 L
.22 .12428 L
.224 .12427 L
.228 .1243 L
.232 .12433 L
.236 .12436 L
.24 .12438 L
.244 .12438 L
.248 .12437 L
.252 .12433 L
.256 .12427 L
.26 .12422 L
.264 .12422 L
.268 .12427 L
.272 .12434 L
.276 .12441 L
.28 .12447 L
.284 .12452 L
.288 .12453 L
.292 .12449 L
.296 .12439 L
.3 .12426 L
.304 .12414 L
.308 .12408 L
.312 .12408 L
.316 .12413 L
.32 .12421 L
.324 .12431 L
.328 .12443 L
.332 .12456 L
.336 .12463 L
.34 .12463 L
.344 .12454 L
.348 .12442 L
.352 .12432 L
.356 .12426 L
.36 .1242 L
.364 .12414 L
.368 .12409 L
.372 .12409 L
.376 .12419 L
.38 .12434 L
.384 .12446 L
.388 .1245 L
.392 .12449 L
.396 .12449 L
.4 .12454 L
Mistroke
.404 .12458 L
.408 .12454 L
.412 .12438 L
.416 .12416 L
.42 .12399 L
.424 .12395 L
.428 .12401 L
.432 .12408 L
.436 .1241 L
.44 .12412 L
.444 .12425 L
.448 .12454 L
.452 .12491 L
.456 .12521 L
.46 .12528 L
.464 .12511 L
.468 .12481 L
.472 .12452 L
.476 .12428 L
.48 .12405 L
.484 .12375 L
.488 .12338 L
.492 .12305 L
.496 .1229 L
.5 .12303 L
.504 .12343 L
.508 .12399 L
.512 .12455 L
.516 .12501 L
.52 .12534 L
.524 .12557 L
.528 .12571 L
.532 .12582 L
.536 .12587 L
.54 .12584 L
.544 .12567 L
.548 .12533 L
.552 .12482 L
.556 .12421 L
.56 .12362 L
.564 .12319 L
.568 .123 L
.572 .12298 L
.576 .123 L
.58 .12285 L
.584 .12245 L
.588 .12186 L
.592 .12129 L
.596 .12098 L
.6 .12112 L
Mistroke
.604 .12169 L
.608 .12252 L
.612 .12338 L
.616 .12412 L
.62 .12472 L
.624 .12533 L
.628 .12618 L
.632 .12744 L
.636 .12915 L
.64 .13123 L
.644 .13349 L
.648 .13573 L
.652 .13781 L
.656 .13967 L
.66 .14131 L
.664 .14275 L
.668 .14404 L
.672 .14525 L
.676 .14647 L
.68 .14785 L
.684 .14958 L
.688 .15177 L
.692 .15446 L
.696 .15754 L
.7 .16077 L
.704 .16386 L
.708 .16655 L
.712 .1687 L
.716 .17031 L
.72 .17151 L
.724 .17255 L
.728 .17364 L
.732 .17496 L
.736 .17658 L
.74 .1785 L
.744 .18069 L
.748 .18313 L
.752 .18586 L
.756 .18896 L
.76 .19257 L
.764 .19677 L
.768 .2016 L
.772 .207 L
.776 .21284 L
.78 .2189 L
.784 .225 L
.788 .23097 L
.792 .23675 L
.796 .24234 L
.8 .24783 L
Mistroke
.804 .25337 L
.808 .25908 L
.812 .26504 L
.816 .27127 L
.82 .2777 L
.824 .28423 L
.828 .29069 L
.832 .29696 L
.836 .30292 L
.84 .30854 L
.844 .31384 L
.848 .31891 L
.852 .32389 L
.856 .32893 L
.86 .33419 L
.864 .33979 L
.868 .34579 L
.872 .35223 L
.876 .35904 L
.88 .36617 L
.884 .37347 L
.888 .38082 L
.892 .38805 L
.896 .39503 L
.9 .40164 L
.904 .40779 L
.908 .4134 L
.912 .41844 L
.916 .4229 L
.92 .4268 L
.924 .43015 L
.928 .43302 L
.932 .43543 L
.936 .43746 L
.94 .43914 L
.944 .44054 L
.948 .44169 L
.952 .44266 L
.956 .44344 L
.96 .4441 L
.964 .44464 L
.968 .44511 L
.972 .44548 L
.976 .44583 L
.98 .4461 L
.984 .44636 L
.988 .44656 L
.992 .44678 L
.996 .44693 L
1 .44712 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16377 L
.012 .16134 L
.016 .16035 L
.02 .1611 L
.024 .1614 L
.028 .1612 L
.032 .16105 L
.036 .16114 L
.04 .16116 L
.044 .16115 L
.048 .16109 L
.052 .16108 L
.056 .16105 L
.06 .16105 L
.064 .16103 L
.068 .16106 L
.072 .16106 L
.076 .16108 L
.08 .16107 L
.084 .16107 L
.088 .16104 L
.092 .16102 L
.096 .16099 L
.1 .16098 L
.104 .16096 L
.108 .16094 L
.112 .16092 L
.116 .16092 L
.12 .16092 L
.124 .16093 L
.128 .16093 L
.132 .16094 L
.136 .16094 L
.14 .16093 L
.144 .16091 L
.148 .16089 L
.152 .16088 L
.156 .16087 L
.16 .16085 L
.164 .16083 L
.168 .16081 L
.172 .16079 L
.176 .16077 L
.18 .16075 L
.184 .16076 L
.188 .16079 L
.192 .16082 L
.196 .16084 L
.2 .16083 L
Mistroke
.204 .16081 L
.208 .16078 L
.212 .16074 L
.216 .1607 L
.22 .16066 L
.224 .16066 L
.228 .16068 L
.232 .1607 L
.236 .16071 L
.24 .1607 L
.244 .16069 L
.248 .16067 L
.252 .16063 L
.256 .16056 L
.26 .1605 L
.264 .1605 L
.268 .16054 L
.272 .16062 L
.276 .16069 L
.28 .16074 L
.284 .16078 L
.288 .16079 L
.292 .16073 L
.296 .16061 L
.3 .16044 L
.304 .1603 L
.308 .16022 L
.312 .16021 L
.316 .16025 L
.32 .16033 L
.324 .16044 L
.328 .16058 L
.332 .16073 L
.336 .16082 L
.34 .1608 L
.344 .16069 L
.348 .16054 L
.352 .1604 L
.356 .16031 L
.36 .16023 L
.364 .16014 L
.368 .16006 L
.372 .16007 L
.376 .16018 L
.38 .16035 L
.384 .16049 L
.388 .16053 L
.392 .16051 L
.396 .16051 L
.4 .16056 L
Mistroke
.404 .16062 L
.408 .16056 L
.412 .16034 L
.416 .16003 L
.42 .15981 L
.424 .15975 L
.428 .15982 L
.432 .15991 L
.436 .15993 L
.44 .15995 L
.444 .1601 L
.448 .16044 L
.452 .1609 L
.456 .16125 L
.46 .16133 L
.464 .16111 L
.468 .16073 L
.472 .16036 L
.476 .16006 L
.48 .15977 L
.484 .15939 L
.488 .15892 L
.492 .15848 L
.496 .15828 L
.5 .15844 L
.504 .15893 L
.508 .15962 L
.512 .16032 L
.516 .16088 L
.52 .16128 L
.524 .16154 L
.528 .16172 L
.532 .16184 L
.536 .16191 L
.54 .16186 L
.544 .16163 L
.548 .16119 L
.552 .16054 L
.556 .15977 L
.56 .15904 L
.564 .1585 L
.568 .15825 L
.572 .15822 L
.576 .15822 L
.58 .15803 L
.584 .15752 L
.588 .15678 L
.592 .15605 L
.596 .15567 L
.6 .15583 L
Mistroke
.604 .15653 L
.608 .15756 L
.612 .15863 L
.616 .15953 L
.62 .16026 L
.624 .16101 L
.628 .16206 L
.632 .16363 L
.636 .16576 L
.64 .16834 L
.644 .17114 L
.648 .17391 L
.652 .17649 L
.656 .1788 L
.66 .18083 L
.664 .18262 L
.668 .18421 L
.672 .18569 L
.676 .1872 L
.68 .18892 L
.684 .19105 L
.688 .19377 L
.692 .19711 L
.696 .20092 L
.7 .20493 L
.704 .20877 L
.708 .2121 L
.712 .21476 L
.716 .21674 L
.72 .21822 L
.724 .21949 L
.728 .22084 L
.732 .22246 L
.736 .22446 L
.74 .22683 L
.744 .22954 L
.748 .23256 L
.752 .23594 L
.756 .23979 L
.76 .24426 L
.764 .24947 L
.768 .25546 L
.772 .26217 L
.776 .26942 L
.78 .27695 L
.784 .28452 L
.788 .29193 L
.792 .29909 L
.796 .30602 L
.8 .31284 L
Mistroke
.804 .3197 L
.808 .32678 L
.812 .33417 L
.816 .34189 L
.82 .34986 L
.824 .35795 L
.828 .36596 L
.832 .37373 L
.836 .38111 L
.84 .38807 L
.844 .39462 L
.848 .40089 L
.852 .40704 L
.856 .41328 L
.86 .41978 L
.864 .4267 L
.868 .43413 L
.872 .44209 L
.876 .45053 L
.88 .45935 L
.884 .46839 L
.888 .47748 L
.892 .48642 L
.896 .49506 L
.9 .50322 L
.904 .51082 L
.908 .51773 L
.912 .52395 L
.916 .52943 L
.92 .53421 L
.924 .53831 L
.928 .54181 L
.932 .54473 L
.936 .54719 L
.94 .5492 L
.944 .55087 L
.948 .55222 L
.952 .55333 L
.956 .55422 L
.96 .55496 L
.964 .55553 L
.968 .55602 L
.972 .55639 L
.976 .55671 L
.98 .55693 L
.984 .55715 L
.988 .55727 L
.992 .5574 L
.996 .55744 L
1 .55751 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008005Aoo`8001Moo`002goo0P002Woo0P000goo0`000goo00<007ooOol0
DWoo00<007oo00005goo000ROol2001COol01000Oomoo`005Woo000;Ool20004Ool00`00Oomoo`03
Ool20002Ool50002Ool00`00Oomoo`1BOol01000Oomoo`005Woo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0002Ool2001>Ool20003Ool01000Oomoo`005Woo0003Ool50002Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8004ioo`80009oo`03001oogoo009o
o`03001oogoo01=oo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01@00Oomoogoo0000CWoo
00H007ooOol007oo0004Ool00`00Oomoo`0COol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0
00=oo`03001oogoo008004eoo`06001oogoo001oo`0017oo00<007ooOol04goo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001:Ool30004Ool00`00Oomoo`03Ool00`00
Oomoo`0COol000]oo`8000Yoo`8000=oo`<000=oo`03001oogoo04Uoo`<000Yoo`03001oogoo01=o
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00BGoo00<007ooOol037oo00<007oo
Ool04Woo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000eoo`<000Ao
o`8000Moo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000=oo`D00003Ool007oo008000Ao
o`8000Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002
Ool01@00Oomoogoo00000Woo00@007oo0000009oo`04001oogoo0002Ool00`00Oomoo`02Ool01P00
Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo009oo`04001oogooOol20002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo00<007oo
Ool00P000Woo00@007ooOol0009oo`03001oogoo00=oo`8000Ioo`04001oogoo0002Ool00`00Oomo
o`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol02goo10000goo
00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomo
o`@000=oo`04001oogoo0002Ool01P00Oomoogoo001oo`80009oo`04001oogoo0002Ool02P00Oomo
ogoo001oo`00Ool007oo10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol0
0Woo0P0037oo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomo
o`0017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`04001oogooOol200001Goo001oogoo
00000Woo00@007ooOol000=oo`03001oogoo00800003Ool007oo00Eoo`04001oogoo0005Ool0029o
o`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool2
0004Ool3000017oo001oogoo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomo
o`17Ool00`00Oomoo`0@Ool2000@Ool0029oo`80049oo`03001oogoo009oo`03001oogoo019oo`D0
00aoo`008WooH`0037oo000ROol2000017oo000007oo1@0000=oo`0000000Woo0P000Woo0`0000Io
o`00001oo`00Ool3000017oo000000000goo1@000Woo0P000goo1`0000Aoo`00Oomoo`80009oo`80
0003Ool00000009oo`8000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000aoo`008Woo0`0000Eoo`00000007oo00D00004Ool00000Ool400001Goo00000000Ool00`00
0Woo0`0000=oo`0000002P0000=oo`0000000`0000Aoo`00001oo`800003Ool007oo00<0009oo`03
001oo`00009oo`03001oogoo02Aoo`008Woo00<007ooOol0=Woo0P0000Eoo`00Ool007oo00<000=o
o`03001oo`0002Ioo`008Woo0P00>goo00<007ooOol01Woo0P009goo000ROol20014Ool2000WOol0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo04=oo`8002Moo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;
Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=o
o`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
0Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000
Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool0
1P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`00
8Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool0
00Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`80
00=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo
00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@0
07ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003
Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Oolk000^Ool0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo
00<007ooOol0=goo0`00;7oo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0iOol3
000ZOol002Qoo`03001oogoo03aoo`8002Qoo`00:7oo00<007ooOol0?Goo0`009Woo000;Ool20004
Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0oOol3000TOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00A7oo0P008Woo0003
Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00AGoo
00<007ooOol087oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool5
0002Ool30004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`0200001Goo001oogoo00000Woo00D007oo
Oomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`@0009oo`04001oogoo0004Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00
Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00H007ooOomoo`00
Ool20002Ool01000Oomoo`001Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00
:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo00<0
07ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomo
o`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09
Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo
0`0017oo0P0000Aoo`00Oomoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0B7oo
0P0077oo000XOol00`00Oomoo`19Ool00`00Oomoo`0JOol002Qooed000aoo`00:7oo00<007ooOol0
3goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00@007ooOomoo`8000eoo`03001o
ogoo00Yoo`00:7oo00<007ooOol0Bgoo0P006Goo000XOol00`00Oomoo`1<Ool00`00Oomoo`0GOol0
02Qoo`03001oogoo04eoo`03001oogoo01Ioo`00:7oo00<007ooOol0CGoo0P005goo000XOol00`00
Oomoo`1>Ool00`00Oomoo`0EOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=o
o`03001oogoo04ioo`8001Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00
Ool000=oo`04001oogoo001AOol00`00Oomoo`0DOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogoo001AOol2000EOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo0080055oo`8001Aoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0DGoo0P004goo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0DWoo100047oo000;Ool2
000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1FOol4000<Ool002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`000goo1@000Woo
00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol0
00Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomo
o`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol03Goo0`00
17oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P00
1Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04
001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03
001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00
Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo
000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009o
o`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo
000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@00
0goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`1b
Ool001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol20002Ool01@00Oomoogoo000017oo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo0P000Woo00<007ooOol0
0Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol0
0Woo00<007ooOol02Woo000LOol00`00Oomoo`10Ool3000_Ool001aoo`8004=oo`<002eoo`0077oo
00<007ooOol0A7oo0P00;7oo000LOol00`00Oomoo`16Ool00`00Oomoo`0YOol001aoo`8004Moo`<0
02Uoo`0077oo00<007ooOol0BGoo0P009goo000LOol00`00Oomoo`1;Ool00`00Oomoo`0TOol001ao
o`8004eoo`03001oogoo02=oo`0077oo00<007ooOol0CGoo00<007ooOol08Woo000LOol2001>Ool0
0`00Oomoo`0ROol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo04ioo`03001oogoo
025oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1>Ool00`00Oomoo`0Q
Ool000Yoo`04001oogoo000;Ool00`00Oomoo`02001@Ool00`00Oomoo`0POol000Yoo`04001oogoo
000;Ool01000Oomoo`00DGoo00<007ooOol087oo000:Ool01000Oomoo`001goo10000goo00<007oo
Ool0D7oo00<007ooOol07goo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00DGoo0P0087oo
000;Ool20008Ool50002Ool00`00Oomoo`1AOol00`00Oomoo`0NOol001aoo`03001oogoo059oo`03
001oogoo01eoo`0077oo0P00Dgoo00<007ooOol07Goo000LOol00`00Oomoo`1BOol2000NOol001ao
o`8005Aoo`03001oogoo01aoo`0077oo00<007ooOol0E7oo00<007ooOol06goo000LOol00`00Oomo
o`1DOol00`00Oomoo`0KOol001aoo`8005Ioo`03001oogoo01Yoo`005Woo0`000goo00<007ooOol0
EGoo0P006goo000GOol00`00Oomoo`02Ool00`00Oomoo`1FOol00`00Oomoo`0IOol001Moo`03001o
ogoo009oo`8005Qoo`03001oogoo01Qoo`005goo00<007ooOol00Woo00<007ooOol0Egoo00<007oo
Ool067oo000GOol00`00Oomoo`02Ool00`00Oomoo`1HOol00`00Oomoo`0GOol001Ioo`8000Aoo`80
05Uoo`03001oogoo01Moo`005goo00<007ooOol00Woo00<007ooOol0FGoo00<007ooOol05Woo000L
Ool00`00Oomoo`1IOol00`00Oomoo`0FOol001aoo`8005Yoo`03001oogoo01Ioo`0077oo00<007oo
Ool0FWoo00<007ooOol05Goo000LOol2001KOol2000FOol001aoo`03001oogoo05]oo`03001oogoo
01Aoo`0077oo00<007ooOol0Fgoo0P005Goo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001M
Ool2000DOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1MOol2000COol0
00]oo`03001oogoo00]oo`04001oogoo001QOol7000<Ool000]oo`03001oogoo00]oo`03001oogoo
008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomo
o`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(42251\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31471 m
.008 .31531 L
.012 .31815 L
.016 .32098 L
.02 .3219 L
.024 .32217 L
.028 .32135 L
.032 .31902 L
.036 .31695 L
.04 .31622 L
.044 .31732 L
.048 .31952 L
.052 .32144 L
.056 .32234 L
.06 .32153 L
.064 .31949 L
.068 .31746 L
.072 .3164 L
.076 .31699 L
.08 .31883 L
.084 .32094 L
.088 .32232 L
.092 .32215 L
.096 .32066 L
.1 .31874 L
.104 .31744 L
.108 .31738 L
.112 .31834 L
.116 .31974 L
.12 .32087 L
.124 .32113 L
.128 .32045 L
.132 .31937 L
.136 .31874 L
.14 .31889 L
.144 .31952 L
.148 .32006 L
.152 .32023 L
.156 .32001 L
.16 .31952 L
.164 .31906 L
.168 .31906 L
.172 .31977 L
.176 .3208 L
.18 .32132 L
.184 .32083 L
.188 .31963 L
.192 .31847 L
.196 .31791 L
.2 .31802 L
Mistroke
.204 .31883 L
.208 .32025 L
.212 .32178 L
.216 .32259 L
.22 .32214 L
.224 .32075 L
.228 .31929 L
.232 .31838 L
.236 .31801 L
.24 .31801 L
.244 .31849 L
.248 .31964 L
.252 .32115 L
.256 .32225 L
.26 .32236 L
.264 .32162 L
.268 .32056 L
.272 .31952 L
.276 .31851 L
.28 .31765 L
.284 .31743 L
.288 .31837 L
.292 .32035 L
.296 .32246 L
.3 .32364 L
.304 .32344 L
.308 .3222 L
.312 .32059 L
.316 .31909 L
.32 .31781 L
.324 .31692 L
.328 .31679 L
.332 .31781 L
.336 .31984 L
.34 .32206 L
.344 .32342 L
.348 .32344 L
.352 .32262 L
.356 .32184 L
.36 .32142 L
.364 .32083 L
.368 .31944 L
.372 .31754 L
.376 .31648 L
.38 .31741 L
.384 .31992 L
.388 .32216 L
.392 .32249 L
.396 .32112 L
.4 .31995 L
Mistroke
.404 .32058 L
.408 .32257 L
.412 .32376 L
.416 .32255 L
.42 .31971 L
.424 .31778 L
.428 .31854 L
.432 .32105 L
.436 .32251 L
.44 .32102 L
.444 .31762 L
.448 .31551 L
.452 .31699 L
.456 .32123 L
.46 .32494 L
.464 .32538 L
.468 .32283 L
.472 .32027 L
.476 .32047 L
.48 .32338 L
.484 .32615 L
.488 .32566 L
.492 .32132 L
.496 .31566 L
.5 .31227 L
.504 .31299 L
.508 .31668 L
.512 .3205 L
.516 .32217 L
.52 .32155 L
.524 .32031 L
.528 .32032 L
.532 .3222 L
.536 .32513 L
.54 .3276 L
.544 .32844 L
.548 .32728 L
.552 .32443 L
.556 .32069 L
.56 .31717 L
.564 .31517 L
.568 .3157 L
.572 .3187 L
.576 .32264 L
.58 .32504 L
.584 .32383 L
.588 .31894 L
.592 .31283 L
.596 .30925 L
.6 .311 L
Mistroke
.604 .31789 L
.608 .32649 L
.612 .33191 L
.616 .33081 L
.62 .3235 L
.624 .31402 L
.628 .30787 L
.632 .30892 L
.636 .31717 L
.64 .32889 L
.644 .33872 L
.648 .3426 L
.652 .33967 L
.656 .33226 L
.66 .32422 L
.664 .31876 L
.668 .31709 L
.672 .31845 L
.676 .32124 L
.68 .32422 L
.684 .32715 L
.688 .33039 L
.692 .33402 L
.696 .33712 L
.7 .33783 L
.704 .33422 L
.708 .32552 L
.712 .31304 L
.716 .30014 L
.72 .29115 L
.724 .28965 L
.728 .29696 L
.732 .31151 L
.736 .32932 L
.74 .34556 L
.744 .35625 L
.748 .35957 L
.752 .35613 L
.756 .34829 L
.76 .33891 L
.764 .33008 L
.768 .32229 L
.772 .31448 L
.776 .30466 L
.78 .29104 L
.784 .27291 L
.788 .2512 L
.792 .2283 L
.796 .20732 L
.8 .19109 L
Mistroke
.804 .18123 L
.808 .17771 L
.812 .17895 L
.816 .18227 L
.82 .18479 L
.824 .18417 L
.828 .17925 L
.832 .17028 L
.836 .15882 L
.84 .1472 L
.844 .13783 L
.848 .13263 L
.852 .13249 L
.856 .1372 L
.86 .14551 L
.864 .15547 L
.868 .16482 L
.872 .1715 L
.876 .17395 L
.88 .17141 L
.884 .16397 L
.888 .15251 L
.892 .1385 L
.896 .1237 L
.9 .10992 L
.904 .09874 L
.908 .09132 L
.912 .08835 L
.916 .09003 L
.92 .09617 L
.924 .10624 L
.928 .11948 L
.932 .13502 L
.936 .15192 L
.94 .16932 L
.944 .18644 L
.948 .20272 L
.952 .21771 L
.956 .23118 L
.96 .24301 L
.964 .25321 L
.968 .26183 L
.972 .269 L
.976 .27485 L
.98 .27954 L
.984 .28322 L
.988 .28606 L
.992 .28818 L
.996 .28969 L
1 .29072 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12079 m
.008 .12473 L
.012 .12605 L
.016 .12489 L
.02 .12438 L
.024 .12477 L
.028 .12494 L
.032 .12484 L
.036 .12475 L
.04 .12478 L
.044 .12477 L
.048 .12477 L
.052 .12476 L
.056 .1248 L
.06 .12481 L
.064 .12484 L
.068 .12483 L
.072 .12483 L
.076 .12479 L
.08 .12477 L
.084 .12475 L
.088 .12475 L
.092 .12476 L
.096 .12479 L
.1 .1248 L
.104 .12483 L
.108 .12483 L
.112 .12483 L
.116 .12482 L
.12 .12482 L
.124 .1248 L
.128 .12479 L
.132 .12477 L
.136 .12476 L
.14 .12476 L
.144 .12477 L
.148 .12478 L
.152 .1248 L
.156 .12481 L
.16 .12482 L
.164 .12482 L
.168 .12482 L
.172 .12482 L
.176 .12482 L
.18 .12482 L
.184 .12481 L
.188 .1248 L
.192 .12478 L
.196 .12476 L
.2 .12474 L
Mistroke
.204 .12474 L
.208 .12476 L
.212 .1248 L
.216 .12483 L
.22 .12485 L
.224 .12486 L
.228 .12486 L
.232 .12485 L
.236 .12481 L
.24 .12477 L
.244 .12475 L
.248 .12475 L
.252 .12477 L
.256 .12479 L
.26 .12481 L
.264 .12484 L
.268 .12486 L
.272 .12484 L
.276 .12479 L
.28 .12473 L
.284 .12469 L
.288 .12469 L
.292 .12472 L
.296 .12477 L
.3 .12484 L
.304 .12491 L
.308 .12498 L
.312 .12502 L
.316 .12498 L
.32 .12489 L
.324 .12476 L
.328 .12466 L
.332 .12459 L
.336 .12456 L
.34 .12457 L
.344 .12461 L
.348 .12471 L
.352 .12485 L
.356 .12499 L
.36 .12508 L
.364 .12508 L
.368 .12502 L
.372 .12493 L
.376 .12486 L
.38 .12479 L
.384 .12471 L
.388 .1246 L
.392 .12453 L
.396 .12455 L
.4 .12466 L
Mistroke
.404 .12478 L
.408 .12486 L
.412 .12488 L
.416 .12489 L
.42 .12495 L
.424 .12506 L
.428 .12512 L
.432 .12506 L
.436 .12488 L
.44 .12466 L
.444 .12452 L
.448 .1245 L
.452 .12452 L
.456 .12451 L
.46 .12445 L
.464 .12444 L
.468 .12459 L
.472 .12491 L
.476 .12531 L
.48 .1256 L
.484 .12569 L
.488 .12558 L
.492 .12537 L
.496 .12518 L
.5 .125 L
.504 .12476 L
.508 .12441 L
.512 .12398 L
.516 .12358 L
.52 .12336 L
.524 .12341 L
.528 .12372 L
.532 .1242 L
.536 .12472 L
.54 .12519 L
.544 .12556 L
.548 .12584 L
.552 .12605 L
.556 .12623 L
.56 .12635 L
.564 .12641 L
.568 .12633 L
.572 .12605 L
.576 .12557 L
.58 .12496 L
.584 .12434 L
.588 .12388 L
.592 .12367 L
.596 .12365 L
.6 .12367 L
Mistroke
.604 .12354 L
.608 .12313 L
.612 .12251 L
.616 .12187 L
.62 .12147 L
.624 .12148 L
.628 .12192 L
.632 .12263 L
.636 .12339 L
.64 .12405 L
.644 .12457 L
.648 .12509 L
.652 .12581 L
.656 .12691 L
.66 .12845 L
.664 .13037 L
.668 .13251 L
.672 .13472 L
.676 .13685 L
.68 .13881 L
.684 .14058 L
.688 .14214 L
.692 .1435 L
.696 .1447 L
.7 .14583 L
.704 .14706 L
.708 .14858 L
.712 .15055 L
.716 .15304 L
.72 .15599 L
.724 .15919 L
.728 .16236 L
.732 .16523 L
.736 .16761 L
.74 .16944 L
.744 .17083 L
.748 .17197 L
.752 .17307 L
.756 .17431 L
.76 .17579 L
.764 .17753 L
.768 .1795 L
.772 .1817 L
.776 .18415 L
.78 .18694 L
.784 .1902 L
.788 .19403 L
.792 .1985 L
.796 .20359 L
.8 .20918 L
Mistroke
.804 .2151 L
.808 .22113 L
.812 .22711 L
.816 .23292 L
.82 .23854 L
.824 .24405 L
.828 .24954 L
.832 .25516 L
.836 .261 L
.84 .26712 L
.844 .27346 L
.848 .27996 L
.852 .28647 L
.856 .29284 L
.86 .29896 L
.864 .30474 L
.868 .31019 L
.872 .31536 L
.876 .32036 L
.88 .32535 L
.884 .33046 L
.888 .33585 L
.892 .34161 L
.896 .3478 L
.9 .35439 L
.904 .36134 L
.908 .36854 L
.912 .37587 L
.916 .38317 L
.92 .39033 L
.924 .39718 L
.928 .40364 L
.932 .4096 L
.936 .41503 L
.94 .41988 L
.944 .42417 L
.948 .4279 L
.952 .43112 L
.956 .43386 L
.96 .43619 L
.964 .43812 L
.968 .43977 L
.972 .44112 L
.976 .44227 L
.98 .4432 L
.984 .44403 L
.988 .44469 L
.992 .44531 L
.996 .44581 L
1 .44631 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15882 L
.012 .16133 L
.016 .16198 L
.02 .16109 L
.024 .16084 L
.028 .16119 L
.032 .16124 L
.036 .16114 L
.04 .1611 L
.044 .16115 L
.048 .16112 L
.052 .1611 L
.056 .16106 L
.06 .16107 L
.064 .16106 L
.068 .16108 L
.072 .16107 L
.076 .16107 L
.08 .16103 L
.084 .16101 L
.088 .16097 L
.092 .16096 L
.096 .16096 L
.1 .16099 L
.104 .16101 L
.108 .16103 L
.112 .16102 L
.116 .161 L
.12 .16096 L
.124 .16092 L
.128 .16088 L
.132 .16087 L
.136 .16087 L
.14 .16088 L
.144 .16088 L
.148 .16088 L
.152 .16087 L
.156 .16087 L
.16 .16086 L
.164 .16086 L
.168 .16086 L
.172 .16086 L
.176 .16085 L
.18 .16082 L
.184 .1608 L
.188 .16078 L
.192 .16076 L
.196 .16074 L
.2 .16071 L
Mistroke
.204 .1607 L
.208 .16071 L
.212 .16072 L
.216 .16073 L
.22 .16075 L
.224 .16076 L
.228 .16077 L
.232 .16076 L
.236 .16071 L
.24 .16065 L
.244 .16061 L
.248 .1606 L
.252 .16061 L
.256 .16061 L
.26 .16063 L
.264 .16065 L
.268 .16067 L
.272 .16065 L
.276 .16059 L
.28 .16051 L
.284 .16045 L
.288 .16044 L
.292 .16046 L
.296 .16051 L
.3 .16057 L
.304 .16065 L
.308 .16073 L
.312 .16077 L
.316 .16073 L
.32 .1606 L
.324 .16044 L
.328 .1603 L
.332 .1602 L
.336 .16015 L
.34 .16015 L
.344 .16019 L
.348 .1603 L
.352 .16047 L
.356 .16064 L
.36 .16074 L
.364 .16073 L
.368 .16064 L
.372 .16053 L
.376 .16044 L
.38 .16036 L
.384 .16024 L
.388 .16009 L
.392 .15997 L
.396 .15998 L
.4 .1601 L
Mistroke
.404 .16026 L
.408 .16037 L
.412 .16039 L
.416 .16039 L
.42 .16045 L
.424 .16056 L
.428 .16063 L
.432 .16055 L
.436 .16031 L
.44 .16003 L
.444 .15985 L
.448 .15981 L
.452 .15984 L
.456 .15982 L
.46 .15974 L
.464 .15971 L
.468 .15988 L
.472 .16026 L
.476 .16074 L
.48 .16111 L
.484 .16121 L
.488 .16107 L
.492 .16081 L
.496 .16055 L
.5 .1603 L
.504 .16 L
.508 .15956 L
.512 .15902 L
.516 .15851 L
.52 .15822 L
.524 .15827 L
.528 .15865 L
.532 .15924 L
.536 .15988 L
.54 .16046 L
.544 .16091 L
.548 .16125 L
.552 .1615 L
.556 .16171 L
.56 .16186 L
.564 .16192 L
.568 .16181 L
.572 .16146 L
.576 .16085 L
.58 .16007 L
.584 .1593 L
.588 .15872 L
.592 .15844 L
.596 .1584 L
.6 .15842 L
Mistroke
.604 .15824 L
.608 .15773 L
.612 .15695 L
.616 .15615 L
.62 .15564 L
.624 .15564 L
.628 .15617 L
.632 .15705 L
.636 .158 L
.64 .1588 L
.644 .15944 L
.648 .16008 L
.652 .16097 L
.656 .16233 L
.66 .16424 L
.664 .16662 L
.668 .16928 L
.672 .17202 L
.676 .17466 L
.68 .17709 L
.684 .17929 L
.688 .18122 L
.692 .1829 L
.696 .18438 L
.7 .18578 L
.704 .1873 L
.708 .18917 L
.712 .19161 L
.716 .1947 L
.72 .19835 L
.724 .20233 L
.728 .20627 L
.732 .20983 L
.736 .21277 L
.74 .21503 L
.744 .21674 L
.748 .21814 L
.752 .21949 L
.756 .22102 L
.76 .22285 L
.764 .22499 L
.768 .22743 L
.772 .23015 L
.776 .23318 L
.78 .23664 L
.784 .24067 L
.788 .24543 L
.792 .25098 L
.796 .2573 L
.8 .26424 L
Mistroke
.804 .27158 L
.808 .27907 L
.812 .28649 L
.816 .2937 L
.82 .30067 L
.824 .3075 L
.828 .31431 L
.832 .32127 L
.836 .32852 L
.84 .3361 L
.844 .34397 L
.848 .35203 L
.852 .36009 L
.856 .36799 L
.86 .37556 L
.864 .38272 L
.868 .38946 L
.872 .39585 L
.876 .40204 L
.88 .4082 L
.884 .41452 L
.888 .42118 L
.892 .4283 L
.896 .43595 L
.9 .44411 L
.904 .45271 L
.908 .46162 L
.912 .47069 L
.916 .47972 L
.92 .48857 L
.924 .49703 L
.928 .505 L
.932 .51234 L
.936 .51902 L
.94 .52498 L
.944 .53023 L
.948 .53477 L
.952 .53868 L
.956 .54197 L
.96 .54475 L
.964 .54703 L
.968 .54894 L
.972 .55046 L
.976 .55173 L
.98 .5527 L
.984 .55352 L
.988 .55411 L
.992 .55461 L
.996 .55493 L
1 .5552 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001GOol00`00Oomoo`0COol000Yoo`04001oogoo0008
Ool01P00Oomoo`00Ool000=oo`03001oogoo008005Ioo`03001oo`0001Aoo`002goo0P002Woo0P00
0goo0`000goo00<007ooOol0EGoo00<007oo000057oo000ROol2001EOol01@00Oomoogoo00004goo
000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool00`00Oomoo`1@Ool01@00Oomoogoo0000
0goo00<007ooOol04Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2
001@Ool00`00Ool00002Ool01@00Oomoogoo00004goo0003Ool50002Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`80051oo`03001oo`00009oo`05001oogooOol0000COol000Yo
o`04001oogoo0008Ool01000Oomoo`0017oo00D007ooOomoo`00055oo`03001oo`00008000Aoo`03
001oogoo015oo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00Cgoo
00@007ooOomoo`8000Eoo`03001oogoo011oo`002Woo00@007ooOol000Qoo`06001oogoo001oo`00
0goo00<007ooOol00P00C7oo10002Woo00<007ooOol047oo000;Ool2000:Ool20003Ool30003Ool0
0`00Oomoo`1;Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool000]oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`8004aoo`03001oogoo00]oo`03001oogoo011oo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2000=Ool30004Ool20007Ool30004Ool20004Ool20005Ool3
0003Ool30004Ool20003Ool50003Ool20004Ool20004Ool50002Ool30004Ool20006Ool000=oo`D0
009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol02goo00D007oo
Oomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`05001oogooOol00003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`05001oogoo001oo`02
0002Ool01000Oomoo`0017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool200001Goo001oogoo00000Woo
00<007ooOol00goo00<007oo00001Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00goo00@007ooOomoo`800005Ool007ooOol00002Ool00`00Oomoo`04Ool0
0`00Ool00004Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000Aoo`03001oogoo00]oo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`000Woo00D007ooOomo
o`00009oo`800005Ool007ooOol00002Ool01@00Oomoogoo00000goo1P000goo00@007ooOol000Eo
o`002goo0P002Woo0P0017oo00<007ooOol00Woo0P0037oo00<007ooOol017oo00@007ooOol000Io
o`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0
009oo`05001oogooOol00002Ool200001Goo001oogoo00000Woo00D007ooOomoo`0000=oo`<000Io
o`04001oogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Io
o`04001oogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0
029oo`03001oogoo04Yoo`03001oogoo011oo`8000eoo`008Woo0P00A7oo0P0017oo00<007ooOol0
4Woo0P0037oo000ROomS000<Ool0029oo`800003Ool00000009oo`800003Ool0000000<00004Ool0
0000Ool2000017oo000000000Woo0P000Woo0P000Woo0`0000=oo`00Ool010000Woo1@000goo1@00
00=oo`0000000Woo0P000goo0P000Woo0P000Woo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo000037oo000ROol4000017oo000007oo2`0000Eoo`00000007oo00@00005Ool0
0000001oo`0400000goo0000000400000goo0000000200000goo0000000300001Woo000007oo001o
o`800003Ool007oo00800005Ool007ooOol00002Ool00`00Oomoo`0QOol0029oo`03001oogoo03Uo
o`03001oogoo0080009oo`<0009oo`04001oo`00000SOol0029oo`8003eoo`03001oogoo00Ioo`03
001oo`0002Aoo`008Woo0P00Agoo00<007ooOol08goo000;Ool20004Ool00`00Oomoo`03Ool20003
Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007oo
Ool0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
17oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007oo
Ool00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;
Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
0`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo
00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo
1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2
000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo?@00;7oo000@Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo03Uoo`<002Yoo`004Goo0P002Woo0P00
17oo00<007ooOol00Woo00<007ooOol0>goo10009goo000XOol00`00Oomoo`0nOol2000VOol002Qo
o`03001oogoo041oo`8002Aoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo
00<007ooOol0@Woo0`008Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`000goo00@007ooOol004Ioo`80021oo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`001Goo00@007ooOol004Moo`8001moo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P00
0goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool0
1@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001o
ogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00<007ooOol0
0P0000Eoo`00Oomoo`0000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]o
o`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo0P0000Eoo`00Oomoo`0000Eoo`03001oogoo
00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo
0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Ool000000Woo00@007ooOol000=oo`03001o
o`0000<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo
0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001o
ogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo0000
1Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P00
17oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000=oo`<000Aoo`<0009oo`D000=o
o`8000Ioo`00:7oo00<007ooOol0Bgoo00<007ooOol067oo000XOol00`00Oomoo`1;Ool2000IOol0
02Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol0
3goo00<007ooOol017oo00<007ooOol02Goo00<007ooOol02Woo000XOol00`00Oomoo`1>Ool00`00
Oomoo`0EOol002Qoo`03001oogoo04ioo`8001Ioo`00:7oo00<007ooOol0Cgoo00<007ooOol057oo
000XOol00`00Oomoo`1@Ool00`00Oomoo`0COol002Qoo`03001oogoo051oo`8001Aoo`002goo0P00
17oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0DGoo00<007ooOol04Woo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol005=oo`80
01=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol005Ao
o`03001oogoo015oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol00P00E7oo00<007ooOol047oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001o
ogoo001oo`040003Ool00`00Oomoo`1COol2000AOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00H007ooOol007oo0006Ool00`00Oomoo`1EOol3000>Ool000]oo`8000Yoo`8000Aoo`80009o
o`D0009oo`03001oogoo05Moo`<000aoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04
001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0
KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<0
07ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Mo
o`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo
0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool2
0004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool2
0006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo
00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo
00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001o
ogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007oo
Ool0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`00
0Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P00
3Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04
001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00ao
o`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`80
00=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04
001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=o
o`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool2
0004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Ool000020004Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:
Ool001aoo`03001oogoo04=oo`8002eoo`0077oo0P00AWoo0`00:Woo000LOol00`00Oomoo`17Ool2
000YOol001aoo`03001oogoo04Qoo`8002Qoo`0077oo0P00BWoo0`009Woo000LOol00`00Oomoo`1<
Ool2000TOol001aoo`03001oogoo04eoo`8002=oo`0077oo0P00D7oo00<007ooOol087oo000LOol0
0`00Oomoo`1?Ool00`00Oomoo`0POol001aoo`80055oo`03001oogoo01moo`002goo0P0017oo00<0
07ooOol00Woo0`000goo00<007ooOol0D7oo0P0087oo000:Ool01000Oomoo`001goo00D007ooOomo
o`00009oo`03001oogoo055oo`03001oogoo01ioo`002Woo00@007ooOol000]oo`03001oogoo0080
05=oo`03001oogoo01eoo`002Woo00@007ooOol000]oo`04001oogoo001DOol00`00Oomoo`0MOol0
00Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1COol00`00Oomoo`0LOol000Yoo`04001oogoo
0007Ool00`00Oomoo`04Ool2001DOol00`00Oomoo`0LOol000]oo`8000Qoo`D0009oo`03001oogoo
05Aoo`03001oogoo01]oo`0077oo00<007ooOol0E7oo00<007ooOol06goo000LOol2001FOol00`00
Oomoo`0JOol001aoo`03001oogoo05Eoo`03001oogoo01Yoo`0077oo0P00Egoo00<007ooOol06Goo
000LOol00`00Oomoo`1GOol00`00Oomoo`0HOol001aoo`03001oogoo05Moo`03001oogoo01Qoo`00
77oo0P00F7oo0P006Goo000FOol30003Ool00`00Oomoo`1HOol2000HOol001Moo`03001oogoo009o
o`03001oogoo05Uoo`03001oogoo01Ioo`005goo00<007ooOol00Woo0P00FWoo00<007ooOol05Woo
000GOol00`00Oomoo`02Ool00`00Oomoo`1JOol00`00Oomoo`0EOol001Moo`03001oogoo009oo`03
001oogoo05Yoo`8001Ioo`005Woo0P0017oo0P00G7oo00<007ooOol057oo000GOol00`00Oomoo`02
Ool00`00Oomoo`1KOol00`00Oomoo`0DOol001aoo`03001oogoo05aoo`03001oogoo01=oo`0077oo
0P00GGoo00<007ooOol04goo000LOol00`00Oomoo`1MOol00`00Oomoo`0BOol001aoo`8005ioo`03
001oogoo019oo`0077oo00<007ooOol0GWoo00<007ooOol04Goo000LOol00`00Oomoo`1NOol2000B
Ool000Yoo`<000Aoo`03001oogoo009oo`<000=oo`80061oo`80015oo`002goo00<007ooOol01goo
00D007ooOomoo`00009oo`03001oogoo061oo`<000moo`002goo00<007ooOol02goo00@007ooOol0
06Aoo`@000aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool4
0003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<0
07ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(42418\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32048 m
.008 .32051 L
.012 .31888 L
.016 .31735 L
.02 .3166 L
.024 .31724 L
.028 .31939 L
.032 .32105 L
.036 .32138 L
.04 .32071 L
.044 .31923 L
.048 .31799 L
.052 .31756 L
.056 .31808 L
.06 .31941 L
.064 .32052 L
.068 .32094 L
.072 .32055 L
.076 .31952 L
.08 .31863 L
.084 .31825 L
.088 .31859 L
.092 .31933 L
.096 .31985 L
.1 .31995 L
.104 .31967 L
.108 .31931 L
.112 .31919 L
.116 .31942 L
.12 .32 L
.124 .32049 L
.128 .32042 L
.132 .31972 L
.136 .31884 L
.14 .31835 L
.144 .31848 L
.148 .31912 L
.152 .32005 L
.156 .32086 L
.16 .32112 L
.164 .32057 L
.168 .31953 L
.172 .31868 L
.176 .3185 L
.18 .31889 L
.184 .31947 L
.188 .32004 L
.192 .32058 L
.196 .32092 L
.2 .32081 L
Mistroke
.204 .32029 L
.208 .31973 L
.212 .31939 L
.216 .31914 L
.22 .31876 L
.224 .31844 L
.228 .31871 L
.232 .31974 L
.236 .32105 L
.24 .32192 L
.244 .32205 L
.248 .3216 L
.252 .32071 L
.256 .31942 L
.26 .31797 L
.264 .3171 L
.268 .3175 L
.272 .31912 L
.276 .32108 L
.28 .3224 L
.284 .32269 L
.288 .3222 L
.292 .32125 L
.296 .31995 L
.3 .31847 L
.304 .31733 L
.308 .31719 L
.312 .3183 L
.316 .32018 L
.32 .32194 L
.324 .32293 L
.328 .32309 L
.332 .32269 L
.336 .32187 L
.34 .32051 L
.344 .31861 L
.348 .31676 L
.352 .31597 L
.356 .31696 L
.36 .31939 L
.364 .32191 L
.368 .32325 L
.372 .32317 L
.376 .32253 L
.38 .32223 L
.384 .32216 L
.388 .32142 L
.392 .31954 L
.396 .31742 L
.4 .31667 L
Mistroke
.404 .31802 L
.408 .32037 L
.412 .32175 L
.416 .32126 L
.42 .32002 L
.424 .31996 L
.428 .32167 L
.432 .32362 L
.436 .32367 L
.44 .32137 L
.444 .31867 L
.448 .31811 L
.452 .32019 L
.456 .32275 L
.46 .32295 L
.464 .32011 L
.468 .31651 L
.472 .31538 L
.476 .31788 L
.48 .32201 L
.484 .32445 L
.488 .32359 L
.492 .32094 L
.496 .3196 L
.5 .32137 L
.504 .325 L
.508 .32728 L
.512 .32582 L
.516 .32108 L
.52 .31595 L
.524 .31345 L
.528 .31452 L
.532 .31764 L
.536 .32034 L
.54 .32112 L
.544 .32029 L
.548 .31933 L
.552 .3196 L
.556 .3214 L
.56 .32411 L
.564 .32667 L
.568 .32815 L
.572 .32792 L
.576 .32571 L
.58 .3219 L
.584 .31774 L
.588 .31506 L
.592 .3154 L
.596 .31887 L
.6 .32359 L
Mistroke
.604 .3265 L
.608 .32519 L
.612 .31967 L
.616 .31275 L
.62 .30861 L
.624 .31027 L
.628 .31746 L
.632 .32654 L
.636 .33244 L
.64 .33166 L
.644 .32439 L
.648 .31455 L
.652 .30762 L
.656 .30757 L
.66 .31473 L
.664 .32579 L
.668 .33572 L
.672 .34048 L
.676 .33889 L
.68 .33274 L
.684 .32537 L
.688 .31971 L
.692 .31704 L
.696 .31693 L
.7 .31826 L
.704 .32023 L
.708 .32288 L
.712 .32666 L
.716 .33157 L
.72 .33644 L
.724 .33906 L
.728 .33704 L
.732 .32918 L
.736 .31644 L
.74 .30203 L
.744 .29042 L
.748 .28572 L
.752 .28998 L
.756 .30241 L
.76 .3196 L
.764 .33684 L
.768 .34982 L
.772 .35608 L
.776 .35551 L
.78 .34998 L
.784 .34218 L
.788 .33438 L
.792 .32743 L
.796 .32057 L
.8 .31197 L
Mistroke
.804 .29965 L
.808 .28253 L
.812 .2611 L
.816 .23741 L
.82 .21451 L
.824 .19549 L
.828 .1825 L
.832 .17616 L
.836 .17543 L
.84 .17798 L
.844 .1809 L
.848 .18152 L
.852 .17814 L
.856 .17045 L
.86 .15952 L
.864 .14738 L
.868 .1365 L
.872 .12907 L
.876 .12648 L
.88 .12904 L
.884 .13597 L
.888 .1456 L
.892 .15576 L
.896 .16422 L
.9 .1691 L
.904 .16923 L
.908 .16425 L
.912 .15466 L
.916 .14163 L
.92 .12679 L
.924 .11196 L
.928 .09882 L
.932 .08879 L
.936 .08286 L
.94 .08154 L
.944 .08489 L
.948 .0926 L
.952 .10402 L
.956 .1183 L
.96 .1345 L
.964 .15169 L
.968 .16903 L
.972 .1858 L
.976 .20147 L
.98 .21562 L
.984 .22804 L
.988 .23854 L
.992 .24711 L
.996 .25371 L
1 .25849 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12806 m
.008 .12519 L
.012 .12425 L
.016 .12536 L
.02 .12558 L
.024 .1252 L
.028 .12511 L
.032 .12529 L
.036 .12531 L
.04 .12527 L
.044 .12525 L
.048 .12527 L
.052 .12525 L
.056 .12526 L
.06 .12525 L
.064 .12526 L
.068 .12525 L
.072 .12526 L
.076 .12525 L
.08 .12525 L
.084 .12525 L
.088 .12527 L
.092 .12528 L
.096 .12529 L
.1 .12528 L
.104 .12527 L
.108 .12524 L
.112 .12522 L
.116 .12521 L
.12 .12522 L
.124 .12525 L
.128 .12528 L
.132 .1253 L
.136 .12531 L
.14 .1253 L
.144 .12528 L
.148 .12526 L
.152 .12524 L
.156 .12524 L
.16 .12524 L
.164 .12523 L
.168 .12524 L
.172 .12524 L
.176 .12525 L
.18 .12526 L
.184 .12527 L
.188 .12528 L
.192 .1253 L
.196 .1253 L
.2 .12529 L
Mistroke
.204 .12528 L
.208 .12527 L
.212 .12526 L
.216 .12524 L
.22 .12522 L
.224 .12521 L
.228 .12521 L
.232 .12523 L
.236 .12525 L
.24 .12527 L
.244 .12529 L
.248 .12532 L
.252 .12533 L
.256 .12531 L
.26 .12528 L
.264 .12525 L
.268 .12523 L
.272 .12523 L
.276 .12523 L
.28 .12524 L
.284 .12527 L
.288 .12531 L
.292 .12533 L
.296 .12531 L
.3 .12526 L
.304 .12521 L
.308 .12518 L
.312 .12516 L
.316 .12517 L
.32 .1252 L
.324 .12526 L
.328 .12535 L
.332 .12544 L
.336 .12549 L
.34 .12547 L
.344 .12539 L
.348 .12528 L
.352 .12518 L
.356 .1251 L
.36 .12503 L
.364 .125 L
.368 .12503 L
.372 .12513 L
.376 .12528 L
.38 .12542 L
.384 .1255 L
.388 .12551 L
.392 .12548 L
.396 .12544 L
.4 .12541 L
Mistroke
.404 .12534 L
.408 .12521 L
.412 .12507 L
.416 .12499 L
.42 .12502 L
.424 .12512 L
.428 .12521 L
.432 .12525 L
.436 .12526 L
.44 .1253 L
.444 .12542 L
.448 .12556 L
.452 .12562 L
.456 .12554 L
.46 .12536 L
.464 .12517 L
.468 .12508 L
.472 .12506 L
.476 .12504 L
.48 .12496 L
.484 .12483 L
.488 .1248 L
.492 .12494 L
.496 .12528 L
.5 .12567 L
.504 .12596 L
.508 .12607 L
.512 .12602 L
.516 .12591 L
.52 .12581 L
.524 .12568 L
.528 .12545 L
.532 .12509 L
.536 .12462 L
.54 .12416 L
.544 .12387 L
.548 .12383 L
.552 .12404 L
.556 .12443 L
.56 .12491 L
.564 .12537 L
.568 .12576 L
.572 .12608 L
.576 .12634 L
.58 .12657 L
.584 .12678 L
.588 .12692 L
.592 .12694 L
.596 .12674 L
.6 .12631 L
Mistroke
.604 .1257 L
.608 .12507 L
.612 .12458 L
.616 .12434 L
.62 .12432 L
.624 .12435 L
.628 .12423 L
.632 .12383 L
.636 .12319 L
.64 .12251 L
.644 .12202 L
.648 .12192 L
.652 .12222 L
.656 .12281 L
.66 .12347 L
.664 .12405 L
.668 .12451 L
.672 .12494 L
.676 .12554 L
.68 .12648 L
.684 .12783 L
.688 .12957 L
.692 .13159 L
.696 .13372 L
.7 .13586 L
.704 .13791 L
.708 .1398 L
.712 .14149 L
.716 .14294 L
.72 .14417 L
.724 .14527 L
.728 .14637 L
.732 .1477 L
.736 .14944 L
.74 .15171 L
.744 .15448 L
.748 .15761 L
.752 .16082 L
.756 .16382 L
.76 .1664 L
.764 .16847 L
.768 .17006 L
.772 .17134 L
.776 .17249 L
.78 .17371 L
.784 .17509 L
.788 .17668 L
.792 .17847 L
.796 .18045 L
.8 .18265 L
Mistroke
.804 .18515 L
.808 .18807 L
.812 .19153 L
.816 .19563 L
.82 .20038 L
.824 .20569 L
.828 .2114 L
.832 .21733 L
.836 .22328 L
.84 .22911 L
.844 .23477 L
.848 .24028 L
.852 .24575 L
.856 .25129 L
.86 .25703 L
.864 .26302 L
.868 .26926 L
.872 .27571 L
.876 .28223 L
.88 .28868 L
.884 .29493 L
.888 .30088 L
.892 .30649 L
.896 .31179 L
.9 .31686 L
.904 .32184 L
.908 .32686 L
.912 .33209 L
.916 .33762 L
.92 .34357 L
.924 .34992 L
.928 .35668 L
.932 .36375 L
.936 .37103 L
.94 .37838 L
.944 .38567 L
.948 .39274 L
.952 .39951 L
.956 .40583 L
.96 .41168 L
.964 .41697 L
.968 .42173 L
.972 .42592 L
.976 .42963 L
.98 .43282 L
.984 .43562 L
.988 .43801 L
.992 .44014 L
.996 .44197 L
1 .44367 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15818 L
.012 .16112 L
.016 .16216 L
.02 .16128 L
.024 .16085 L
.028 .16113 L
.032 .16122 L
.036 .16113 L
.04 .16104 L
.044 .16109 L
.048 .1611 L
.052 .16113 L
.056 .16111 L
.06 .16111 L
.064 .16107 L
.068 .16105 L
.072 .16102 L
.076 .16102 L
.08 .16102 L
.084 .16104 L
.088 .16105 L
.092 .16105 L
.096 .16102 L
.1 .16099 L
.104 .16095 L
.108 .16093 L
.112 .16091 L
.116 .16092 L
.12 .16093 L
.124 .16094 L
.128 .16095 L
.132 .16095 L
.136 .16095 L
.14 .16094 L
.144 .16091 L
.148 .16088 L
.152 .16085 L
.156 .16083 L
.16 .16081 L
.164 .1608 L
.168 .1608 L
.172 .16082 L
.176 .16083 L
.18 .16082 L
.184 .16081 L
.188 .1608 L
.192 .16079 L
.196 .16079 L
.2 .16078 L
Mistroke
.204 .16078 L
.208 .16077 L
.212 .16076 L
.216 .16072 L
.22 .16068 L
.224 .16064 L
.228 .16063 L
.232 .16063 L
.236 .16064 L
.24 .16066 L
.244 .16069 L
.248 .16072 L
.252 .16073 L
.256 .16071 L
.26 .16066 L
.264 .16061 L
.268 .16057 L
.272 .16055 L
.276 .16053 L
.28 .16053 L
.284 .16057 L
.288 .16061 L
.292 .16063 L
.296 .16061 L
.3 .16054 L
.304 .16047 L
.308 .16041 L
.312 .16038 L
.316 .16038 L
.32 .1604 L
.324 .16047 L
.328 .16057 L
.332 .16067 L
.336 .16072 L
.34 .16069 L
.344 .16058 L
.348 .16044 L
.352 .16032 L
.356 .16021 L
.36 .16012 L
.364 .16006 L
.368 .16007 L
.372 .16018 L
.376 .16036 L
.38 .16054 L
.384 .16064 L
.388 .16065 L
.392 .1606 L
.396 .16054 L
.4 .16048 L
Mistroke
.404 .16037 L
.408 .16021 L
.412 .16002 L
.416 .15992 L
.42 .15994 L
.424 .16006 L
.428 .16018 L
.432 .16022 L
.436 .16022 L
.44 .16026 L
.444 .16039 L
.448 .16055 L
.452 .16062 L
.456 .16051 L
.46 .16028 L
.464 .16004 L
.468 .15992 L
.472 .15988 L
.476 .15984 L
.48 .15972 L
.484 .15956 L
.488 .15951 L
.492 .15969 L
.496 .16009 L
.5 .16056 L
.504 .16091 L
.508 .16104 L
.512 .16098 L
.516 .16085 L
.52 .1607 L
.524 .16053 L
.528 .16023 L
.532 .15976 L
.536 .15917 L
.54 .1586 L
.544 .15823 L
.548 .15817 L
.552 .15842 L
.556 .1589 L
.56 .15948 L
.564 .16005 L
.568 .16053 L
.572 .16091 L
.576 .16123 L
.58 .1615 L
.584 .16175 L
.588 .16193 L
.592 .16194 L
.596 .16168 L
.6 .16113 L
Mistroke
.604 .16036 L
.608 .15956 L
.612 .15895 L
.616 .15864 L
.62 .15861 L
.624 .15863 L
.628 .15847 L
.632 .15797 L
.636 .15716 L
.64 .1563 L
.644 .15568 L
.648 .15554 L
.652 .15592 L
.656 .15664 L
.66 .15746 L
.664 .15817 L
.668 .15873 L
.672 .15926 L
.676 .16 L
.68 .16116 L
.684 .16284 L
.688 .16499 L
.692 .16749 L
.696 .17014 L
.7 .17279 L
.704 .17533 L
.708 .17768 L
.712 .17977 L
.716 .18156 L
.72 .18309 L
.724 .18443 L
.728 .1858 L
.732 .18744 L
.736 .18959 L
.74 .1924 L
.744 .19585 L
.748 .19973 L
.752 .20371 L
.756 .20744 L
.76 .21063 L
.764 .21319 L
.768 .21515 L
.772 .21672 L
.776 .21814 L
.78 .21964 L
.784 .22134 L
.788 .22331 L
.792 .22552 L
.796 .22797 L
.8 .23068 L
Mistroke
.804 .23377 L
.808 .23739 L
.812 .24168 L
.816 .24677 L
.82 .25266 L
.824 .25925 L
.828 .26635 L
.832 .27371 L
.836 .28109 L
.84 .28832 L
.844 .29534 L
.848 .30218 L
.852 .30896 L
.856 .31583 L
.86 .32294 L
.864 .33037 L
.868 .33811 L
.872 .3461 L
.876 .35418 L
.88 .36217 L
.884 .36991 L
.888 .37727 L
.892 .38421 L
.896 .39076 L
.9 .39701 L
.904 .40315 L
.908 .40934 L
.912 .41579 L
.916 .42262 L
.92 .42994 L
.924 .43778 L
.928 .4461 L
.932 .4548 L
.936 .46377 L
.94 .47279 L
.944 .48174 L
.948 .49039 L
.952 .49865 L
.956 .50633 L
.96 .51339 L
.964 .51973 L
.968 .52537 L
.972 .53026 L
.976 .53448 L
.98 .538 L
.984 .54096 L
.988 .54331 L
.992 .54521 L
.996 .54659 L
1 .54763 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo05Qoo`80019oo`002Woo00@0
07ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001IOol2000BOol000Yoo`04001oogoo0008
Ool01P00Oomoo`00Ool000=oo`03001oogoo008005Uoo`80019oo`002goo0P002Woo0P000goo0`00
0goo00<007ooOol0Egoo00@007ooOol0015oo`008Woo0P00F7oo00@007ooOol0015oo`002goo0P00
17oo00<007ooOol00goo0P000Woo1@000Woo00<007ooOol0DWoo0P000goo00D007ooOomoo`00011o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00Dgoo0P000Woo00<0
07ooOol00Woo00<007ooOol03Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`80059oo`06001oogoo001oo`0017oo00<007ooOol03Woo000:Ool01000Oomoo`00
27oo00@007ooOol000Aoo`05001oogooOol0001COol01P00Oomoo`00Ool000Aoo`03001oogoo00io
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00D7oo00<007oo0000
0goo00<007ooOol00goo00<007ooOol03Woo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001?Ool3000;Ool00`00Oomoo`0=Ool000]oo`8000Yoo`8000=oo`<000=oo`03
001oogoo04eoo`03001oogoo00aoo`03001oogoo00eoo`002goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo0P00CWoo00<007ooOol037oo00<007ooOol03Goo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8000eoo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000Eoo`<0
00=oo`<000Aoo`8000=oo`D000=oo`800004Ool007ooOol20004Ool50002Ool30004Ool20006Ool0
00=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol02goo
00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo
0002Ool200001Goo001oogoo000017oo00D007ooOol007oo0080009oo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo0080
0005Ool007ooOol00005Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`00009oo`800005Ool007ooOol00006Ool0
1000Oomoogoo0P0000Eoo`00Oomoo`00009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool20004Ool00`00Oomoo`0;Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol0009oo`05001o
ogooOol00002Ool00`00Oomoo`0200001Goo001oogoo00000goo00H007ooOomoo`00Ool40003Ool0
1000Oomoo`001Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool0
1000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00L0
07ooOomoo`00Ool00002Ool01@00Oomoogoo00000Woo00<007ooOol00goo000ROol2000<Ool50003
Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo
0`000goo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`16Ool00`00Oomoo`03Ool0
0`00Oomoo`0MOol0029oo`8004Moo`03001oogoo00=oo`03001oogoo01eoo`008WooH`0037oo000R
Ool300001Goo00000000Ool00P0000=oo`0000001P0000Eoo`00000007oo00@00004Ool000000002
Ool20003Ool20002Ool200000goo00000003Ool20002Ool00`00Ool0000700002Woo001oo`00Ool0
07oo001oo`000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000037oo
000ROol2000017oo000007oo200000=oo`0000001@0000Eoo`00000007oo00<00005Ool00000001o
o`0400000goo0000000400000goo0000000200000goo00000004000017oo000007oo0P0000Eoo`00
Ool007oo00<0009oo`03001oogoo0080021oo`008Woo00<007ooOol0>goo00<007ooOol00P000goo
0P000goo00<007oo00008Goo000ROol20010Ool00`00Oomoo`06Ool3000QOol0029oo`8004Uoo`80
029oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]o
o`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo
0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000R
Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P00
0goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol0
0`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05
001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000
Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=o
o`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oocl002Yoo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool0
0`00Oomoo`0lOol2000XOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo03ioo`<0
02Eoo`00:7oo00<007ooOol0@Goo0P008goo000XOol00`00Oomoo`12Ool3000QOol000]oo`8000Ao
o`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo04Aoo`<001moo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo0018Ool2000NOol000=o
o`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001:Ool0
0`00Oomoo`0KOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D0
00=oo`800004Ool00000Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool0
1000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo0000009oo`05
001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0
009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo
Ool01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Ao
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009o
o`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000Woo00<007ooOol00P0000=oo`00Ool017oo00<007ooOol017oo00@007ooOol0
009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`00
0goo00@007ooOol0009oo`03001oogoo00@0009oo`06001oogooOol007oo10000goo00@007ooOol0
00Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo
0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomo
o`000Woo00D007ooOol007oo0080009oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`00
:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomo
o`D000=oo`8000=oo`<000Aoo`8000Aoo`<000=oo`<0009oo`D000=oo`8000Ioo`00:7oo00<007oo
Ool0CGoo0P005goo000XOol00`00Oomoo`1>Ool00`00Oomoo`0EOol002Qooed000aoo`00:7oo00<0
07ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol01Woo0P00
27oo00<007ooOol02Woo000XOol00`00Oomoo`1@Ool2000DOol002Qoo`03001oogoo055oo`03001o
ogoo019oo`00:7oo00<007ooOol0DWoo00<007ooOol04Goo000XOol00`00Oomoo`1BOol00`00Oomo
o`0AOol002Qoo`03001oogoo05=oo`03001oogoo011oo`002goo0P0017oo00<007ooOol00goo0P00
17oo0P000goo0`000goo00<007ooOol0Dgoo00<007ooOol047oo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`06001oogoo001oo`000goo00@007ooOol005Ioo`03001oogoo00moo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol005Moo`03001oogoo00io
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00EWoo
0P003goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00
Oomoo`1FOol2000>Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006
Ool00`00Oomoo`1GOol3000<Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Mo
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03
001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@0
07ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0
JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000
Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomo
o`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomo
o`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo
000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool2
0005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogoo
Ool00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
1@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomo
o`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=o
o`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol0
17oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo
0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001o
o`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008
Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo
0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001o
o`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Ao
o`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool2
0006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001o
ogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01000Oomoogoo100000=oo`00Ool00Woo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo000017oo00<007ooOol02Woo000LOol00`00Oomoo`16Ool2000ZOol0
01aoo`8004Uoo`<002Moo`0077oo00<007ooOol0BWoo0P009Woo000LOol00`00Oomoo`1;Ool2000U
Ool001aoo`8004eoo`<002=oo`0077oo00<007ooOol0Cgoo0P008Goo000LOol00`00Oomoo`1@Ool2
000POol001aoo`80059oo`8001moo`0077oo00<007ooOol0DWoo00<007ooOol07Goo000LOol2001D
Ool00`00Oomoo`0LOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo05=oo`03001o
ogoo01aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1DOol00`00Oomo
o`0KOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001EOol00`00Oomoo`0KOol000Yoo`04001o
ogoo000;Ool01000Oomoo`00Egoo00<007ooOol06Woo000:Ool01000Oomoo`001goo10000goo00<0
07ooOol0EGoo0P006goo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Egoo00<007ooOol0
6Goo000;Ool20008Ool50002Ool00`00Oomoo`1GOol00`00Oomoo`0HOol001aoo`03001oogoo05Mo
o`03001oogoo01Qoo`0077oo0P00FGoo00<007ooOol05goo000LOol00`00Oomoo`1HOol00`00Oomo
o`0GOol001aoo`8005Yoo`03001oogoo01Ioo`0077oo00<007ooOol0FGoo00<007ooOol05Woo000L
Ool00`00Oomoo`1JOol00`00Oomoo`0EOol001aoo`8005]oo`8001Ioo`005Woo0`000goo00<007oo
Ool0Fgoo00<007ooOol057oo000GOol00`00Oomoo`02Ool00`00Oomoo`1KOol2000EOol001Moo`03
001oogoo009oo`8005eoo`03001oogoo01=oo`005goo00<007ooOol00Woo00<007ooOol0GGoo00<0
07ooOol04Woo000GOol00`00Oomoo`02Ool00`00Oomoo`1MOol00`00Oomoo`0BOol001Ioo`8000Ao
o`8005moo`03001oogoo015oo`005goo00<007ooOol00Woo00<007ooOol0GWoo00<007ooOol04Goo
000LOol00`00Oomoo`1OOol00`00Oomoo`0@Ool001aoo`80061oo`03001oogoo011oo`0077oo00<0
07ooOol0H7oo00<007ooOol03goo000LOol2001QOol00`00Oomoo`0?Ool001aoo`03001oogoo061o
o`80011oo`0077oo00<007ooOol0HGoo0P003goo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2
001SOol00`00Oomoo`0=Ool000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1S
Ool3000<Ool000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001o
ogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00
Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(42585\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32173 m
.008 .32171 L
.012 .31983 L
.016 .31797 L
.02 .31763 L
.024 .31764 L
.028 .3182 L
.032 .31992 L
.036 .32128 L
.04 .32147 L
.044 .32036 L
.048 .31853 L
.052 .31726 L
.056 .31699 L
.06 .31797 L
.064 .31974 L
.068 .32112 L
.072 .32155 L
.076 .32071 L
.08 .31908 L
.084 .31774 L
.088 .31737 L
.092 .31825 L
.096 .31981 L
.1 .32108 L
.104 .32149 L
.108 .32076 L
.112 .31928 L
.116 .31789 L
.12 .31739 L
.124 .31807 L
.128 .31942 L
.132 .32065 L
.136 .32124 L
.14 .32101 L
.144 .32019 L
.148 .31918 L
.152 .31853 L
.156 .31859 L
.16 .31917 L
.164 .31977 L
.168 .32 L
.172 .31994 L
.176 .31987 L
.18 .31988 L
.184 .31987 L
.188 .31985 L
.192 .31989 L
.196 .31988 L
.2 .31959 L
Mistroke
.204 .31909 L
.208 .31883 L
.212 .31922 L
.216 .32011 L
.22 .3209 L
.224 .3212 L
.228 .32104 L
.232 .32056 L
.236 .31978 L
.24 .31874 L
.244 .31789 L
.248 .31787 L
.252 .31881 L
.256 .32019 L
.26 .32129 L
.264 .32184 L
.268 .32197 L
.272 .32174 L
.276 .32095 L
.28 .31956 L
.284 .3181 L
.288 .31736 L
.292 .31775 L
.296 .31896 L
.3 .32038 L
.304 .3216 L
.308 .32249 L
.312 .32285 L
.316 .32233 L
.32 .32075 L
.324 .3186 L
.328 .31694 L
.332 .3167 L
.336 .31797 L
.34 .32 L
.344 .32177 L
.348 .32274 L
.352 .32302 L
.356 .32289 L
.36 .32233 L
.364 .32103 L
.368 .31904 L
.372 .31709 L
.376 .3163 L
.38 .3172 L
.384 .3192 L
.388 .32106 L
.392 .32199 L
.396 .3223 L
.4 .32272 L
Mistroke
.404 .32333 L
.408 .32326 L
.412 .32167 L
.416 .31902 L
.42 .31705 L
.424 .31722 L
.428 .31921 L
.432 .32107 L
.436 .32116 L
.44 .3198 L
.444 .31898 L
.448 .32022 L
.452 .32279 L
.456 .3243 L
.46 .32308 L
.464 .32004 L
.468 .31802 L
.472 .31899 L
.476 .32206 L
.48 .32415 L
.484 .32287 L
.488 .31892 L
.492 .31552 L
.496 .31559 L
.5 .31903 L
.504 .3229 L
.508 .32409 L
.512 .32207 L
.516 .31929 L
.52 .31886 L
.524 .32173 L
.528 .32583 L
.532 .32787 L
.536 .32601 L
.54 .32132 L
.544 .31672 L
.548 .31474 L
.552 .31578 L
.556 .31827 L
.56 .32018 L
.564 .3205 L
.568 .31967 L
.572 .31883 L
.576 .31897 L
.58 .32036 L
.584 .32273 L
.588 .32548 L
.592 .32776 L
.596 .32853 L
.6 .32693 L
Mistroke
.604 .323 L
.608 .31814 L
.612 .31475 L
.616 .31492 L
.62 .31888 L
.624 .32445 L
.628 .32802 L
.632 .32677 L
.636 .32069 L
.64 .31291 L
.644 .30803 L
.648 .30937 L
.652 .31675 L
.656 .32638 L
.66 .33297 L
.664 .33275 L
.668 .32568 L
.672 .31555 L
.676 .3078 L
.68 .30656 L
.684 .31254 L
.688 .32284 L
.692 .33273 L
.696 .33824 L
.7 .3379 L
.704 .33304 L
.708 .32649 L
.712 .32089 L
.716 .31749 L
.72 .31608 L
.724 .31592 L
.728 .3166 L
.732 .31852 L
.736 .32236 L
.74 .32819 L
.744 .33474 L
.748 .33946 L
.752 .33949 L
.756 .33306 L
.76 .32063 L
.764 .30513 L
.768 .29113 L
.772 .28321 L
.776 .28417 L
.78 .29402 L
.784 .30996 L
.788 .32753 L
.792 .34224 L
.796 .35107 L
.8 .35327 L
Mistroke
.804 .35016 L
.808 .34419 L
.812 .33769 L
.816 .33178 L
.82 .32606 L
.824 .31883 L
.828 .30804 L
.832 .29227 L
.836 .27156 L
.84 .24757 L
.844 .22317 L
.848 .20159 L
.852 .18545 L
.856 .17601 L
.86 .17287 L
.864 .1741 L
.868 .17692 L
.872 .17843 L
.876 .1765 L
.88 .17023 L
.884 .16014 L
.888 .14793 L
.892 .13593 L
.896 .1265 L
.9 .12141 L
.904 .12149 L
.908 .12648 L
.912 .1351 L
.916 .14538 L
.92 .15506 L
.924 .16203 L
.928 .16469 L
.932 .16222 L
.936 .15465 L
.94 .1428 L
.944 .12809 L
.948 .11222 L
.952 .09698 L
.956 .08388 L
.96 .07415 L
.964 .06852 L
.968 .06728 L
.972 .07025 L
.976 .07695 L
.98 .08657 L
.984 .09816 L
.988 .11081 L
.992 .12348 L
.996 .1356 L
1 .14633 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13018 m
.008 .12579 L
.012 .12425 L
.016 .12568 L
.02 .12619 L
.024 .12577 L
.028 .12555 L
.032 .1257 L
.036 .12576 L
.04 .12574 L
.044 .12571 L
.048 .12574 L
.052 .12573 L
.056 .12573 L
.06 .1257 L
.064 .12571 L
.068 .1257 L
.072 .12573 L
.076 .12573 L
.08 .12575 L
.084 .12574 L
.088 .12573 L
.092 .1257 L
.096 .1257 L
.1 .12569 L
.104 .12571 L
.108 .12573 L
.112 .12575 L
.116 .12575 L
.12 .12575 L
.124 .12574 L
.128 .12572 L
.132 .1257 L
.136 .12569 L
.14 .12569 L
.144 .12569 L
.148 .1257 L
.152 .12572 L
.156 .12574 L
.16 .12576 L
.164 .12577 L
.168 .12576 L
.172 .12574 L
.176 .12573 L
.18 .1257 L
.184 .12568 L
.188 .12568 L
.192 .12569 L
.196 .12571 L
.2 .12572 L
Mistroke
.204 .12572 L
.208 .12574 L
.212 .12575 L
.216 .12575 L
.22 .12575 L
.224 .12575 L
.228 .12575 L
.232 .12575 L
.236 .12573 L
.24 .12571 L
.244 .1257 L
.248 .12569 L
.252 .12568 L
.256 .12568 L
.26 .12569 L
.264 .12571 L
.268 .12575 L
.272 .12578 L
.276 .12579 L
.28 .12578 L
.284 .12575 L
.288 .12573 L
.292 .12571 L
.296 .12569 L
.3 .12567 L
.304 .12569 L
.308 .12573 L
.312 .12577 L
.316 .12579 L
.32 .12578 L
.324 .12574 L
.328 .1257 L
.332 .12566 L
.336 .12563 L
.34 .12561 L
.344 .12563 L
.348 .12569 L
.352 .12579 L
.356 .12589 L
.36 .12594 L
.364 .12592 L
.368 .12587 L
.372 .1258 L
.376 .12572 L
.38 .12562 L
.384 .12552 L
.388 .12545 L
.392 .12545 L
.396 .12555 L
.4 .12569 L
Mistroke
.404 .12583 L
.408 .12591 L
.412 .12593 L
.416 .12595 L
.42 .12596 L
.424 .12594 L
.428 .12585 L
.432 .1257 L
.436 .12555 L
.44 .12548 L
.444 .12551 L
.448 .12559 L
.452 .12564 L
.456 .12564 L
.46 .12565 L
.464 .12572 L
.468 .12588 L
.472 .12604 L
.476 .12609 L
.48 .126 L
.484 .12584 L
.488 .12571 L
.492 .12565 L
.496 .12563 L
.5 .12556 L
.504 .12541 L
.508 .12524 L
.512 .12519 L
.516 .12533 L
.52 .12564 L
.524 .126 L
.528 .12628 L
.532 .12641 L
.536 .12644 L
.54 .12643 L
.544 .1264 L
.548 .12633 L
.552 .12613 L
.556 .12576 L
.56 .12528 L
.564 .12479 L
.568 .12443 L
.572 .1243 L
.576 .12441 L
.58 .12471 L
.584 .12513 L
.588 .12556 L
.592 .12596 L
.596 .1263 L
.6 .12659 L
Mistroke
.604 .12687 L
.608 .12715 L
.612 .12739 L
.616 .1275 L
.62 .12739 L
.624 .12702 L
.628 .12643 L
.632 .12578 L
.636 .12528 L
.64 .12502 L
.644 .12499 L
.648 .12503 L
.652 .12493 L
.656 .12454 L
.66 .1239 L
.664 .12318 L
.668 .12262 L
.672 .12241 L
.676 .1226 L
.68 .12306 L
.684 .12363 L
.688 .12413 L
.692 .12452 L
.696 .12488 L
.7 .12537 L
.704 .12615 L
.708 .12732 L
.712 .12887 L
.716 .13072 L
.72 .13276 L
.724 .13488 L
.728 .13697 L
.732 .13897 L
.736 .14078 L
.74 .14235 L
.744 .14365 L
.748 .14474 L
.752 .14576 L
.756 .14692 L
.76 .14844 L
.764 .15048 L
.768 .15306 L
.772 .15606 L
.776 .15925 L
.78 .16234 L
.784 .1651 L
.788 .16738 L
.792 .16919 L
.796 .17063 L
.8 .17188 L
Mistroke
.804 .17311 L
.808 .17445 L
.812 .17593 L
.816 .17758 L
.82 .17938 L
.824 .18135 L
.828 .18357 L
.832 .18617 L
.836 .18927 L
.84 .19299 L
.844 .19737 L
.848 .20237 L
.852 .20785 L
.856 .21363 L
.86 .21951 L
.864 .22534 L
.868 .23102 L
.872 .23656 L
.876 .24201 L
.88 .2475 L
.884 .25314 L
.888 .25902 L
.892 .26516 L
.896 .27154 L
.9 .27804 L
.904 .28456 L
.908 .29093 L
.912 .29706 L
.916 .30286 L
.92 .30835 L
.924 .31355 L
.928 .3186 L
.932 .32362 L
.936 .32879 L
.94 .3342 L
.944 .34 L
.948 .34621 L
.952 .35287 L
.956 .35991 L
.96 .36727 L
.964 .37481 L
.968 .38244 L
.972 .38999 L
.976 .3974 L
.98 .40451 L
.984 .41132 L
.988 .4177 L
.992 .42373 L
.996 .42932 L
1 .4346 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16294 L
.012 .16101 L
.016 .16046 L
.02 .16125 L
.024 .16138 L
.028 .16114 L
.032 .16108 L
.036 .16119 L
.04 .16116 L
.044 .16111 L
.048 .16107 L
.052 .16109 L
.056 .16108 L
.06 .16108 L
.064 .16106 L
.068 .16106 L
.072 .16104 L
.076 .16104 L
.08 .16102 L
.084 .16103 L
.088 .16102 L
.092 .16102 L
.096 .16099 L
.1 .16098 L
.104 .16096 L
.108 .16097 L
.112 .16097 L
.116 .16098 L
.12 .16097 L
.124 .16096 L
.128 .16092 L
.132 .16089 L
.136 .16085 L
.14 .16085 L
.144 .16085 L
.148 .16087 L
.152 .16089 L
.156 .16091 L
.16 .1609 L
.164 .16088 L
.168 .16085 L
.172 .16082 L
.176 .1608 L
.18 .16078 L
.184 .16077 L
.188 .16076 L
.192 .16076 L
.196 .16076 L
.2 .16075 L
Mistroke
.204 .16074 L
.208 .16074 L
.212 .16074 L
.216 .16074 L
.22 .16074 L
.224 .16073 L
.228 .16074 L
.232 .16073 L
.236 .1607 L
.24 .16066 L
.244 .16062 L
.248 .1606 L
.252 .16058 L
.256 .16056 L
.26 .16057 L
.264 .16059 L
.268 .16064 L
.272 .16067 L
.276 .16067 L
.28 .16065 L
.284 .16061 L
.288 .16057 L
.292 .16053 L
.296 .16049 L
.3 .16046 L
.304 .16047 L
.308 .16051 L
.312 .16056 L
.316 .16057 L
.32 .16055 L
.324 .1605 L
.328 .16044 L
.332 .16039 L
.336 .16034 L
.34 .1603 L
.344 .1603 L
.348 .16036 L
.352 .16047 L
.356 .16059 L
.36 .16066 L
.364 .16065 L
.368 .16057 L
.372 .16046 L
.376 .16034 L
.38 .1602 L
.384 .16006 L
.388 .15997 L
.392 .15997 L
.396 .16009 L
.4 .16026 L
Mistroke
.404 .16042 L
.408 .16051 L
.412 .16053 L
.416 .16054 L
.42 .16054 L
.424 .16051 L
.428 .16038 L
.432 .16018 L
.436 .15999 L
.44 .1599 L
.444 .15993 L
.448 .16002 L
.452 .16007 L
.456 .16005 L
.46 .16005 L
.464 .16015 L
.468 .16034 L
.472 .16052 L
.476 .16057 L
.48 .16045 L
.484 .16024 L
.488 .16007 L
.492 .16 L
.496 .15996 L
.5 .15986 L
.504 .15965 L
.508 .15943 L
.512 .15935 L
.516 .15953 L
.52 .15992 L
.524 .16036 L
.528 .16069 L
.532 .16084 L
.536 .16086 L
.54 .16084 L
.544 .1608 L
.548 .1607 L
.552 .16043 L
.556 .15997 L
.56 .15936 L
.564 .15875 L
.568 .1583 L
.572 .15812 L
.576 .15824 L
.58 .15861 L
.584 .15911 L
.588 .15965 L
.592 .16014 L
.596 .16055 L
.6 .1609 L
Mistroke
.604 .16124 L
.608 .16158 L
.612 .16187 L
.616 .16201 L
.62 .16186 L
.624 .16137 L
.628 .16063 L
.632 .15982 L
.636 .15918 L
.64 .15885 L
.644 .15881 L
.648 .15884 L
.652 .1587 L
.656 .15822 L
.66 .15741 L
.664 .15651 L
.668 .1558 L
.672 .15553 L
.676 .15574 L
.68 .15632 L
.684 .15701 L
.688 .15763 L
.692 .15811 L
.696 .15854 L
.7 .15914 L
.704 .16011 L
.708 .16155 L
.712 .16348 L
.716 .16577 L
.72 .1683 L
.724 .17093 L
.728 .17353 L
.732 .17601 L
.736 .17825 L
.74 .18019 L
.744 .1818 L
.748 .18315 L
.752 .18441 L
.756 .18584 L
.76 .18772 L
.764 .19024 L
.768 .19344 L
.772 .19717 L
.776 .20112 L
.78 .20496 L
.784 .20838 L
.788 .2112 L
.792 .21343 L
.796 .21521 L
.8 .21675 L
Mistroke
.804 .21827 L
.808 .21991 L
.812 .22174 L
.816 .22377 L
.82 .22599 L
.824 .22843 L
.828 .23118 L
.832 .23439 L
.836 .23823 L
.84 .24285 L
.844 .24828 L
.848 .25448 L
.852 .26128 L
.856 .26845 L
.86 .27574 L
.864 .28297 L
.868 .29001 L
.872 .29688 L
.876 .30363 L
.88 .31042 L
.884 .31739 L
.888 .32466 L
.892 .33225 L
.896 .34012 L
.9 .34816 L
.904 .35619 L
.908 .36404 L
.912 .37157 L
.916 .37867 L
.92 .38537 L
.924 .3917 L
.928 .39782 L
.932 .40388 L
.936 .41009 L
.94 .41657 L
.944 .42349 L
.948 .43087 L
.952 .43876 L
.956 .44702 L
.96 .45561 L
.964 .46429 L
.968 .47295 L
.972 .48134 L
.976 .48935 L
.98 .49674 L
.984 .50346 L
.988 .50932 L
.992 .51435 L
.996 .51841 L
1 .5216 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00G7oo0P00
3goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo05]oo`8000moo`00
2Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001KOol01000Oomoo`003Woo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001KOol01000Oomoo`003Woo
000;Ool2000:Ool20003Ool30003Ool00`00Oomoo`1IOol01@00Oomoogoo00003Woo000ROol2001F
Ool01@00Oomoogoo000017oo00<007ooOol02goo000;Ool20004Ool00`00Oomoo`03Ool20002Ool5
0002Ool00`00Oomoo`1DOol00`00Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8005Eoo`03001oo`00009oo`03001o
ogoo009oo`03001oogoo00]oo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2001EOol01@00Ool007oo00001Woo00<007ooOol02Woo000:Ool01000Oomoo`0027oo
00@007ooOol000Aoo`05001oogooOol0001EOol01000Oomoogoo0P004goo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool00`00Oomoo`02001BOol00`00Ool0000HOol000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`03001oogoo0080055oo`<001Uoo`002goo0P002Woo0P000goo
0`000goo00<007ooOol0D7oo00<007ooOol06Goo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool2001AOol00`00Oomoo`0IOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomo
o`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001o
ogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001o
ogooOol50003Ool20004Ool30004Ool20003Ool30005Ool30002Ool50003Ool20006Ool0029oo`03
001oogoo04Qoo`8000Eoo`03001oogoo01Yoo`008Woo0P00BGoo0P0017oo00<007ooOol06goo000R
OomS000<Ool0029oo`03001oo`0000@00004Ool00000Ool20002Ool20003Ool20002Ool200001Goo
00000000Ool00`0000=oo`0000000`0000Aoo`000000009oo`H00003Ool000000080009oo`H00003
Ool00000009oo`80009oo`800007Ool00000Ool007oo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol0000<Ool0029oo`800004Ool00000Ool3000017oo000007oo0P0000=oo`0000001P0000Eo
o`00000007oo00<00003Ool0000000800005Ool00000001oo`0400000goo001oo`0500000goo001o
o`03000017oo000007oo0P0000=oo`00Ool00P0000Aoo`00Ool0009oo`04001oogoo000NOol0029o
o`03001oogoo03eoo`80009oo`8000=oo`80009oo`04001oo`00000NOol0029oo`8004]oo`03001o
o`0001moo`008Woo0P00C7oo00<007ooOol07Woo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0
K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo
00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol0
0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2
000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00
Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
1000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<0
07ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@00
0Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:
Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
06Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo@P009goo000@Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo03ioo`<002Eoo`004Goo0P002Woo0P0017oo
00<007ooOol00Woo00<007ooOol0@7oo10008Woo000XOol00`00Oomoo`13Ool2000QOol002Qoo`03
001oogoo04Aoo`<001moo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<0
07ooOol0AWoo0`007Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`00
0goo00@007ooOol004]oo`8001]oo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`001Goo00@007ooOol004aoo`8001Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo
0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00
Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05
001oogoo001oo`020003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool0
1000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000
Ool0000017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P00
17oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo0P0017oo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001o
o`000goo00@007ooOol0009oo`04001oogoo0002Ool200000goo001oo`02Ool00`00Ool000030003
Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P00
17oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool0
00=oo`04001oogoo0002Ool01000Oomoo`000Woo10000goo00<007oo00001Woo00@007ooOol000Eo
o`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007oo
Oomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`80009oo`03001oo`000080009oo`D000=oo`8000Io
o`00:7oo00<007ooOol0D7oo00<007ooOol04goo000XOol00`00Oomoo`1AOol00`00Oomoo`0BOol0
02Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol0
3goo00<007ooOol02Goo00<007ooOol017oo00<007ooOol02Woo000XOol00`00Oomoo`1COol00`00
Oomoo`0@Ool002Qoo`03001oogoo05=oo`80015oo`00:7oo00<007ooOol0E7oo00<007ooOol03goo
000XOol00`00Oomoo`1EOol00`00Oomoo`0>Ool002Qoo`03001oogoo05Eoo`03001oogoo00ioo`00
2goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0EWoo00<007ooOol0
3Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol0
05Qoo`03001oogoo00eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOol005Uoo`03001oogoo00aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol00P00F7oo00<007ooOol037oo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1HOol00`00Oomoo`0;Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1IOol00`00Oomoo`0:
Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo
06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002
Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Ao
o`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001o
ogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool3
0004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool2
0005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`00
2Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@0
07ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eo
o`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo
00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03
001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005
Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo0P000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
17oo00<007ooOol02Woo000LOol00`00Oomoo`18Ool3000WOol001aoo`8004aoo`8002Eoo`0077oo
00<007ooOol0CGoo00<007ooOol08Woo000LOol00`00Oomoo`1>Ool2000ROol001aoo`80051oo`<0
021oo`0077oo00<007ooOol0DGoo0P007goo000LOol00`00Oomoo`1COol2000MOol001aoo`8005Eo
o`03001oogoo01]oo`0077oo00<007ooOol0EGoo00<007ooOol06Woo000LOol2001FOol2000KOol0
00]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo05Ioo`03001oogoo01Uoo`002Woo00@0
07ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1GOol00`00Oomoo`0HOol000Yoo`04001o
ogoo000;Ool00`00Oomoo`02001HOol00`00Oomoo`0HOol000Yoo`04001oogoo000;Ool01000Oomo
o`00FWoo00<007ooOol05goo000:Ool01000Oomoo`001goo10000goo00<007ooOol0F7oo0P0067oo
000:Ool01000Oomoo`001goo00<007ooOol017oo0P00FWoo00<007ooOol05Woo000;Ool20008Ool5
0002Ool00`00Oomoo`1IOol00`00Oomoo`0FOol001aoo`03001oogoo05Yoo`03001oogoo01Eoo`00
77oo0P00Fgoo0P005Woo000LOol00`00Oomoo`1KOol00`00Oomoo`0DOol001aoo`8005aoo`03001o
ogoo01Aoo`0077oo00<007ooOol0G7oo00<007ooOol04goo000LOol00`00Oomoo`1MOol00`00Oomo
o`0BOol001aoo`8005ioo`8001=oo`005Woo0`000goo00<007ooOol0GWoo00<007ooOol04Goo000G
Ool00`00Oomoo`02Ool00`00Oomoo`1NOol2000BOol001Moo`03001oogoo009oo`80061oo`03001o
ogoo011oo`005goo00<007ooOol00Woo00<007ooOol0H7oo00<007ooOol03goo000GOol00`00Oomo
o`02Ool00`00Oomoo`1POol00`00Oomoo`0?Ool001Ioo`8000Aoo`80065oo`03001oogoo00moo`00
5goo00<007ooOol00Woo00<007ooOol0HGoo00<007ooOol03Woo000LOol00`00Oomoo`1ROol00`00
Oomoo`0=Ool001aoo`8006=oo`03001oogoo00eoo`0077oo00<007ooOol0HWoo00<007ooOol03Goo
000LOol2001TOol00`00Oomoo`0<Ool001aoo`03001oogoo06Aoo`03001oogoo00]oo`0077oo00<0
07ooOol0IGoo00<007ooOol02Woo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]o
o`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04
001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo
10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03
001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(42752\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31876 m
.008 .31842 L
.012 .31944 L
.016 .32064 L
.02 .32131 L
.024 .32062 L
.028 .31854 L
.032 .31703 L
.036 .31696 L
.04 .31782 L
.044 .31941 L
.048 .32076 L
.052 .32124 L
.056 .32081 L
.06 .31955 L
.064 .31837 L
.068 .31785 L
.072 .31809 L
.076 .31899 L
.08 .31982 L
.084 .32019 L
.088 .32008 L
.092 .31957 L
.096 .3191 L
.1 .31886 L
.104 .31899 L
.108 .31939 L
.112 .31968 L
.116 .31974 L
.12 .31966 L
.124 .31958 L
.128 .3196 L
.132 .31959 L
.136 .31955 L
.14 .31946 L
.144 .3193 L
.148 .31911 L
.152 .31903 L
.156 .31928 L
.16 .31984 L
.164 .32036 L
.168 .32047 L
.172 .32017 L
.176 .31969 L
.18 .31925 L
.184 .31892 L
.188 .31887 L
.192 .31925 L
.196 .31993 L
.2 .32047 L
Mistroke
.204 .32052 L
.208 .32018 L
.212 .31983 L
.216 .31961 L
.22 .31941 L
.224 .31917 L
.228 .31912 L
.232 .31944 L
.236 .31996 L
.24 .32032 L
.244 .32047 L
.248 .32063 L
.252 .32086 L
.256 .32082 L
.26 .32016 L
.264 .31907 L
.268 .31821 L
.272 .31809 L
.276 .31866 L
.28 .31959 L
.284 .32064 L
.288 .32172 L
.292 .32249 L
.296 .3224 L
.3 .32121 L
.304 .3194 L
.308 .31794 L
.312 .31752 L
.316 .31809 L
.32 .31912 L
.324 .32017 L
.328 .32119 L
.332 .32215 L
.336 .32273 L
.34 .32244 L
.344 .32109 L
.348 .31917 L
.352 .31763 L
.356 .31719 L
.36 .31791 L
.364 .31926 L
.368 .32069 L
.372 .32196 L
.376 .32302 L
.38 .32361 L
.384 .3232 L
.388 .32149 L
.392 .31904 L
.396 .31712 L
.4 .31677 L
Mistroke
.404 .3179 L
.408 .31939 L
.412 .32027 L
.416 .32061 L
.42 .32134 L
.424 .32285 L
.428 .32422 L
.432 .32394 L
.436 .32157 L
.44 .3186 L
.444 .31724 L
.448 .31835 L
.452 .32051 L
.456 .3214 L
.46 .32014 L
.464 .31828 L
.468 .31824 L
.472 .32072 L
.476 .3238 L
.48 .32465 L
.484 .3224 L
.488 .31909 L
.492 .31786 L
.496 .31991 L
.5 .3233 L
.504 .32466 L
.508 .32239 L
.512 .31817 L
.516 .3155 L
.52 .31652 L
.524 .32019 L
.528 .32324 L
.532 .3232 L
.536 .32052 L
.54 .31808 L
.544 .31855 L
.548 .32211 L
.552 .32624 L
.556 .3279 L
.56 .32587 L
.564 .32154 L
.568 .31762 L
.572 .31609 L
.576 .317 L
.58 .31891 L
.584 .32021 L
.588 .32024 L
.592 .31939 L
.596 .31852 L
.6 .31835 L
Mistroke
.604 .31927 L
.608 .32138 L
.612 .32437 L
.616 .32737 L
.62 .32895 L
.624 .32779 L
.628 .32371 L
.632 .31832 L
.636 .31445 L
.64 .31457 L
.644 .31898 L
.648 .32523 L
.652 .32932 L
.656 .32817 L
.66 .32172 L
.664 .31329 L
.668 .30777 L
.672 .3087 L
.676 .31603 L
.68 .326 L
.684 .33321 L
.688 .33368 L
.692 .32712 L
.696 .31699 L
.7 .30859 L
.704 .30617 L
.708 .31078 L
.712 .32003 L
.716 .32963 L
.72 .33573 L
.724 .33664 L
.728 .3332 L
.732 .32769 L
.736 .32238 L
.74 .31842 L
.744 .3158 L
.748 .31411 L
.752 .31336 L
.756 .31427 L
.76 .31779 L
.764 .32416 L
.768 .33209 L
.772 .33885 L
.776 .34116 L
.78 .33666 L
.784 .3252 L
.788 .30928 L
.792 .29337 L
.796 .28238 L
.8 .27984 L
Mistroke
.804 .2866 L
.808 .30062 L
.812 .31783 L
.816 .33368 L
.82 .34471 L
.824 .34952 L
.828 .34886 L
.832 .34485 L
.836 .33981 L
.84 .3351 L
.844 .33063 L
.848 .32489 L
.852 .31581 L
.856 .3017 L
.86 .28215 L
.864 .25837 L
.868 .23295 L
.872 .20914 L
.876 .18991 L
.88 .17714 L
.884 .17106 L
.888 .1703 L
.892 .17235 L
.896 .17425 L
.9 .17348 L
.904 .16857 L
.908 .15942 L
.912 .14723 L
.916 .13411 L
.92 .12244 L
.924 .1143 L
.928 .11099 L
.932 .1127 L
.936 .11857 L
.94 .12683 L
.944 .13525 L
.948 .1415 L
.952 .14363 L
.956 .14034 L
.96 .13117 L
.964 .11659 L
.968 .09765 L
.972 .07613 L
.976 .05371 L
.98 .03257 L
.984 .01403 L
Mfstroke
.984 .01403 m
.98798 0 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12416 m
.008 .12628 L
.012 .12689 L
.016 .12611 L
.02 .12593 L
.024 .12628 L
.028 .12628 L
.032 .12616 L
.036 .12611 L
.04 .12617 L
.044 .12617 L
.048 .12619 L
.052 .12619 L
.056 .12621 L
.06 .1262 L
.064 .12619 L
.068 .12617 L
.072 .12618 L
.076 .12617 L
.08 .12618 L
.084 .12618 L
.088 .12619 L
.092 .12618 L
.096 .12618 L
.1 .12618 L
.104 .12619 L
.108 .12619 L
.112 .12619 L
.116 .12618 L
.12 .12617 L
.124 .12616 L
.128 .12616 L
.132 .12617 L
.136 .1262 L
.14 .12622 L
.144 .12623 L
.148 .12622 L
.152 .1262 L
.156 .12617 L
.16 .12614 L
.164 .12613 L
.168 .12614 L
.172 .12616 L
.176 .12619 L
.18 .12622 L
.184 .12623 L
.188 .12623 L
.192 .12622 L
.196 .1262 L
.2 .12618 L
Mistroke
.204 .12616 L
.208 .12615 L
.212 .12616 L
.216 .12616 L
.22 .12617 L
.224 .12617 L
.228 .12618 L
.232 .1262 L
.236 .1262 L
.24 .1262 L
.244 .1262 L
.248 .12621 L
.252 .12622 L
.256 .12622 L
.26 .1262 L
.264 .12619 L
.268 .12618 L
.272 .12616 L
.276 .12614 L
.28 .12613 L
.284 .12613 L
.288 .12617 L
.292 .12621 L
.296 .12623 L
.3 .12624 L
.304 .12624 L
.308 .12623 L
.312 .12621 L
.316 .12618 L
.32 .12615 L
.324 .12613 L
.328 .12615 L
.332 .12619 L
.336 .12622 L
.34 .12624 L
.344 .12623 L
.348 .12622 L
.352 .1262 L
.356 .12616 L
.36 .1261 L
.364 .12606 L
.368 .12606 L
.372 .12612 L
.376 .12622 L
.38 .12632 L
.384 .12637 L
.388 .12639 L
.392 .12637 L
.396 .12632 L
.4 .12625 L
Mistroke
.404 .12613 L
.408 .12599 L
.412 .1259 L
.416 .1259 L
.42 .12599 L
.424 .12612 L
.428 .12623 L
.432 .1263 L
.436 .12636 L
.44 .12642 L
.444 .12647 L
.448 .12645 L
.452 .12635 L
.456 .12618 L
.46 .12604 L
.464 .12599 L
.468 .12602 L
.472 .12606 L
.476 .12605 L
.48 .12602 L
.484 .12604 L
.488 .12616 L
.492 .12634 L
.496 .12649 L
.5 .12652 L
.504 .12644 L
.508 .12632 L
.512 .12625 L
.516 .12623 L
.52 .1262 L
.524 .12609 L
.528 .12588 L
.532 .12568 L
.536 .1256 L
.54 .12573 L
.544 .12601 L
.548 .12633 L
.552 .12659 L
.556 .12674 L
.56 .12683 L
.564 .1269 L
.568 .12695 L
.572 .12694 L
.576 .12678 L
.58 .12644 L
.584 .12597 L
.588 .12546 L
.592 .12504 L
.596 .12482 L
.6 .12482 L
Mistroke
.604 .12503 L
.608 .12538 L
.612 .12578 L
.616 .12616 L
.62 .12649 L
.624 .1268 L
.628 .12712 L
.632 .12747 L
.636 .1278 L
.64 .12802 L
.644 .128 L
.648 .12769 L
.652 .12713 L
.656 .12649 L
.66 .12597 L
.664 .1257 L
.668 .12566 L
.672 .12571 L
.676 .12562 L
.68 .12526 L
.684 .12464 L
.688 .1239 L
.692 .12328 L
.696 .12297 L
.7 .12303 L
.704 .12338 L
.708 .12385 L
.712 .12428 L
.716 .12461 L
.72 .1249 L
.724 .12529 L
.728 .12592 L
.732 .12691 L
.736 .12826 L
.74 .12993 L
.744 .13184 L
.748 .1339 L
.752 .13602 L
.756 .13809 L
.76 .14002 L
.764 .14172 L
.768 .14312 L
.772 .14424 L
.776 .14522 L
.78 .14625 L
.784 .14757 L
.788 .14937 L
.792 .15172 L
.796 .15456 L
.8 .15768 L
Mistroke
.804 .16082 L
.808 .16371 L
.812 .16619 L
.816 .16821 L
.82 .16984 L
.824 .17122 L
.828 .17251 L
.832 .17384 L
.836 .17526 L
.84 .17681 L
.844 .17846 L
.848 .18024 L
.852 .18223 L
.856 .18453 L
.86 .18729 L
.864 .19064 L
.868 .19465 L
.872 .19931 L
.876 .20453 L
.88 .21013 L
.884 .21593 L
.888 .22175 L
.892 .22747 L
.896 .23306 L
.9 .23856 L
.904 .24405 L
.908 .24966 L
.912 .25549 L
.916 .26159 L
.92 .26797 L
.924 .27455 L
.928 .28124 L
.932 .28787 L
.936 .29436 L
.94 .30059 L
.944 .30657 L
.948 .3123 L
.952 .31791 L
.956 .3235 L
.96 .32929 L
.964 .33537 L
.968 .34194 L
.972 .34905 L
.976 .3568 L
.98 .36512 L
.984 .37402 L
.988 .38333 L
.992 .39296 L
.996 .40274 L
1 .41251 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16452 L
.012 .16131 L
.016 .1601 L
.02 .16115 L
.024 .16151 L
.028 .16118 L
.032 .161 L
.036 .16112 L
.04 .16114 L
.044 .16112 L
.048 .16108 L
.052 .16109 L
.056 .16108 L
.06 .16109 L
.064 .16108 L
.068 .16109 L
.072 .16107 L
.076 .16106 L
.08 .16102 L
.084 .16101 L
.088 .16098 L
.092 .16099 L
.096 .16099 L
.1 .161 L
.104 .16099 L
.108 .16099 L
.112 .16096 L
.116 .16094 L
.12 .16092 L
.124 .16092 L
.128 .16091 L
.132 .16092 L
.136 .16092 L
.14 .16092 L
.144 .16091 L
.148 .16089 L
.152 .16086 L
.156 .16084 L
.16 .16082 L
.164 .16081 L
.168 .1608 L
.172 .1608 L
.176 .16082 L
.18 .16083 L
.184 .16083 L
.188 .16082 L
.192 .16081 L
.196 .16079 L
.2 .16076 L
Mistroke
.204 .16073 L
.208 .16071 L
.212 .16071 L
.216 .1607 L
.22 .16069 L
.224 .16068 L
.228 .16068 L
.232 .16069 L
.236 .16068 L
.24 .16068 L
.244 .16068 L
.248 .16069 L
.252 .16069 L
.256 .16067 L
.26 .16064 L
.264 .16061 L
.268 .16058 L
.272 .16055 L
.276 .16052 L
.28 .1605 L
.284 .1605 L
.288 .16053 L
.292 .16057 L
.296 .16059 L
.3 .1606 L
.304 .16059 L
.308 .16058 L
.312 .16054 L
.316 .16048 L
.32 .16042 L
.324 .16039 L
.328 .1604 L
.332 .16045 L
.336 .1605 L
.34 .16052 L
.344 .1605 L
.348 .16047 L
.352 .16041 L
.356 .16035 L
.36 .16027 L
.364 .16021 L
.368 .16021 L
.372 .16028 L
.376 .1604 L
.38 .16051 L
.384 .16057 L
.388 .16057 L
.392 .16054 L
.396 .16047 L
.4 .16036 L
Mistroke
.404 .1602 L
.408 .16003 L
.412 .15991 L
.416 .15991 L
.42 .16001 L
.424 .16016 L
.428 .16028 L
.432 .16035 L
.436 .16041 L
.44 .16049 L
.444 .16055 L
.448 .16052 L
.452 .16037 L
.456 .16015 L
.46 .15997 L
.464 .1599 L
.468 .15994 L
.472 .15998 L
.476 .15996 L
.48 .1599 L
.484 .15991 L
.488 .16004 L
.492 .16027 L
.496 .16045 L
.5 .16048 L
.504 .16037 L
.508 .16021 L
.512 .1601 L
.516 .16008 L
.52 .16003 L
.524 .15988 L
.528 .1596 L
.532 .15934 L
.536 .15925 L
.54 .1594 L
.544 .15974 L
.548 .16013 L
.552 .16043 L
.556 .16061 L
.56 .16071 L
.564 .16079 L
.568 .16085 L
.572 .16083 L
.576 .16061 L
.58 .16018 L
.584 .15958 L
.588 .15894 L
.592 .15842 L
.596 .15813 L
.6 .15812 L
Mistroke
.604 .15837 L
.608 .15879 L
.612 .15928 L
.616 .15975 L
.62 .16016 L
.624 .16053 L
.628 .16092 L
.632 .16134 L
.636 .16175 L
.64 .16201 L
.644 .16198 L
.648 .16158 L
.652 .16087 L
.656 .16006 L
.66 .15941 L
.664 .15906 L
.668 .15901 L
.672 .15905 L
.676 .15893 L
.68 .15848 L
.684 .15768 L
.688 .15676 L
.692 .15598 L
.696 .15559 L
.7 .15566 L
.704 .15608 L
.708 .15665 L
.712 .15718 L
.716 .15758 L
.72 .15793 L
.724 .15841 L
.728 .15919 L
.732 .16041 L
.736 .16208 L
.74 .16416 L
.744 .16653 L
.748 .16908 L
.752 .17171 L
.756 .17428 L
.76 .17668 L
.764 .17877 L
.768 .1805 L
.772 .18189 L
.776 .18309 L
.78 .18436 L
.784 .186 L
.788 .18822 L
.792 .19114 L
.796 .19466 L
.8 .19854 L
Mistroke
.804 .20243 L
.808 .20602 L
.812 .20909 L
.816 .21158 L
.82 .21359 L
.824 .21529 L
.828 .21687 L
.832 .2185 L
.836 .22025 L
.84 .22214 L
.844 .22417 L
.848 .22637 L
.852 .22881 L
.856 .23164 L
.86 .23504 L
.864 .23917 L
.868 .24411 L
.872 .24986 L
.876 .25629 L
.88 .2632 L
.884 .27033 L
.888 .27749 L
.892 .28451 L
.896 .29134 L
.9 .29803 L
.904 .30471 L
.908 .31149 L
.912 .31852 L
.916 .32584 L
.92 .33347 L
.924 .34128 L
.928 .34914 L
.932 .35686 L
.936 .36428 L
.94 .37125 L
.944 .37774 L
.948 .38373 L
.952 .38934 L
.956 .39465 L
.96 .39988 L
.964 .40511 L
.968 .41054 L
.972 .41618 L
.976 .42211 L
.98 .42822 L
.984 .4345 L
.988 .44076 L
.992 .4469 L
.996 .45275 L
1 .45819 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1MOol00`00Oomoo`0<Ool0029oo`8005io
o`03001oogoo00aoo`008Woo00<007ooOol0GGoo00<007ooOol037oo000ROol2001NOol00`00Oomo
o`0<Ool0029oo`8005ioo`03001oogoo00aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0GGoo00<007ooOol037oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001MOol00`00Oomoo`0=Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomo
o`001Goo00<007ooOol00P00GGoo00<007ooOol03Goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`8000=oo`03001oogoo05aoo`03001oogoo00eoo`002Woo00@007ooOol000Qoo`04001oogoo
0005Ool00`00Oomoo`02001MOol00`00Oomoo`0=Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008005aoo`03001oogoo00ioo`002goo0P002Woo0P000goo0`000goo00<0
07ooOol0F7oo00@007ooOol0011oo`008Woo0P00F7oo0P000Woo00<007ooOol03Woo000;Ool20004
Ool00`00Oomoo`03Ool20002Ool50002Ool00`00Oomoo`1FOol01P00Oomoo`00Ool0011oo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00Egoo00<007ooOol00P004Goo
0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8005Moo`03001o
ogoo01=oo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01@00Oomoogoo0000F7oo00<007oo
Ool04goo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001DOol3000F
Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008005Aoo`03001oogoo
01Ioo`002goo0P002Woo0P000goo0`000goo00<007ooOol0DWoo00<007ooOol05goo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool2001COol00`00Oomoo`0GOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P00
1Goo0`000goo0`0017oo0P000goo1@000goo0P0017oo0`000goo1@000Woo0`0017oo0P001Woo0003
Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05
001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`00
0Woo00@007ooOol0009oo`03001oogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool0
1000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo
00Aoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo0P0017oo00<007ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`04001oo`000003Ool01P00Oomoogoo001oo`@000=oo`04
001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04
001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Ao
o`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oo`000003Ool01`00
Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo
00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20004Ool30004Ool20004Ool20005Ool30002
Ool50003Ool20006Ool0029oo`03001oogoo04]oo`03001oogoo00=oo`03001oogoo01Qoo`008Woo
0P00Bgoo0P001Goo00<007ooOol067oo000ROomS000<Ool0029oo`800004Ool00000Ool300001Goo
001oo`00Ool00`0000Uoo`00000007oo001oo`00Ool00P000Woo0P000Woo0`0000Aoo`000000009o
o`H00006Ool00000Ool007oo1@000Woo0P0000Aoo`00001oo`<00004Ool000000002Ool30002Ool2
0002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000aoo`008Woo0`0000Eoo`00000007oo0080
0003Ool0000000800004Ool00000Ool700000goo0000000200001Goo00000000Ool00`0000=oo`00
00002`0000Aoo`00001oo`D00008Ool00000Ool007oo001oo`<0009oo`05001oo`00Ool00003Ool0
0`00Oomoo`0IOol0029oo`03001oogoo041oo`03001oogoo008000=oo`8000=oo`03001oo`0001ao
o`008Woo0P00BWoo00@007ooOomoo`8001eoo`008Woo0P00KGoo000;Ool20004Ool00`00Oomoo`03
Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
06eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo
00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000
Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00
KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo
00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo
0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol0
06ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eo
o`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uo
o`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1Y
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo
000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo>`0000=oo`00
00001P009Goo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo03Moo`80
00Moo`<002=oo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0@goo0`0087oo000X
Ool00`00Oomoo`16Ool00`00Oomoo`0MOol002Qoo`03001oogoo04Moo`8001eoo`002goo0P0017oo
00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0BGoo0`006Woo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol004eoo`8001Uoo`000goo
1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol004ioo`80
01Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00
2goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P00
17oo100000=oo`0000000`000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol0
00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool20002Ool01P00
Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01P00Oomoo`00Ool0009oo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03
001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`04001oo`000002Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000
Oomoo`000Woo00@007ooOol0009oo`03001oogoo0080009oo`03001oo`0000<000=oo`04001oogoo
0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomo
o`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007oo
Ool0009oo`04001oogoo0002Ool00`00Oomoo`020002Ool00`00Ool00006Ool01000Oomoo`001Goo
000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomo
ogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00
Oomoo`1BOol00`00Oomoo`0AOol002Qoo`03001oogoo05=oo`03001oogoo011oo`00:7ooG@0037oo
000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomo
o`0;Ool20003Ool00`00Oomoo`0:Ool002Qoo`03001oogoo05Eoo`03001oogoo00ioo`00:7oo00<0
07ooOol0EGoo0P003goo000XOol00`00Oomoo`1FOol00`00Oomoo`0=Ool002Qoo`03001oogoo05Mo
o`03001oogoo00aoo`00:7oo00<007ooOol0Egoo00<007ooOol037oo000;Ool20004Ool00`00Oomo
o`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1GOol00`00Oomoo`0<Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00FWoo00<007ooOol02goo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00FWoo00<0
07ooOol02goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`02001JOol00`00Oomoo`0:Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol0
07oo00@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo
0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`80
00Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo
00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool0
1000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001o
ogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04
001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001o
ogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1b
Ool001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Ao
o`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007oo
Oomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol0
0goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol0
07oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol0
00Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007oo
Ool000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol0
07oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P00
17oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=o
o`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000aoo`0077oo0P00
0Woo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00004Ool00`00Ool000020003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0Bgoo0`0097oo000L
Ool2001>Ool3000ROol001aoo`03001oogoo04moo`80025oo`0077oo00<007ooOol0D7oo0`007goo
000LOol2001COol3000MOol001aoo`03001oogoo05Aoo`8001aoo`0077oo00<007ooOol0EWoo0P00
6Woo000LOol2001HOol00`00Oomoo`0HOol001aoo`03001oogoo05Qoo`03001oogoo01Moo`0077oo
0P00FGoo00<007ooOol05goo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1IOol0
0`00Oomoo`0FOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0FGoo00<0
07ooOol05Woo000:Ool01000Oomoo`002goo00<007ooOol00P00Fgoo00<007ooOol05Goo000:Ool0
1000Oomoo`002goo00@007ooOol005eoo`03001oogoo01Aoo`002Woo00@007ooOol000Moo`@000=o
o`03001oogoo05]oo`03001oogoo01Aoo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8005ao
o`8001Eoo`002goo0P0027oo1@000Woo00<007ooOol0G7oo00<007ooOol04goo000LOol00`00Oomo
o`1MOol00`00Oomoo`0BOol001aoo`8005ioo`8001=oo`0077oo00<007ooOol0GWoo00<007ooOol0
4Goo000LOol2001OOol00`00Oomoo`0AOol001aoo`03001oogoo05moo`03001oogoo011oo`0077oo
00<007ooOol0H7oo00<007ooOol03goo000LOol2001QOol2000@Ool001Ioo`<000=oo`03001oogoo
065oo`03001oogoo00ioo`005goo00<007ooOol00Woo00<007ooOol0HWoo00<007ooOol03Goo000G
Ool00`00Oomoo`02Ool2001SOol00`00Oomoo`0=Ool001Moo`03001oogoo009oo`03001oogoo06=o
o`03001oogoo00aoo`005goo00<007ooOol00Woo00<007ooOol0I7oo00<007ooOol02goo000FOol2
0004Ool2001VOol00`00Oomoo`0:Ool001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;
Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool0
1000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Mo
o`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool0
0`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(42919\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31672 m
.008 .31659 L
.012 .3183 L
.016 .31999 L
.02 .32038 L
.024 .3205 L
.028 .32018 L
.032 .31889 L
.036 .31791 L
.04 .31788 L
.044 .31869 L
.048 .31987 L
.052 .32043 L
.056 .32023 L
.06 .31934 L
.064 .31816 L
.068 .31765 L
.072 .31807 L
.076 .31928 L
.08 .32064 L
.084 .32123 L
.088 .32083 L
.092 .31963 L
.096 .31821 L
.1 .31745 L
.104 .3177 L
.108 .31886 L
.112 .32026 L
.116 .32104 L
.12 .32092 L
.124 .32003 L
.128 .31892 L
.132 .3182 L
.136 .31817 L
.14 .3189 L
.144 .31993 L
.148 .32063 L
.152 .32064 L
.156 .32008 L
.16 .31938 L
.164 .31889 L
.168 .31871 L
.172 .31893 L
.176 .31946 L
.18 .32002 L
.184 .32027 L
.188 .3201 L
.192 .3198 L
.196 .31965 L
.2 .31963 L
Mistroke
.204 .31958 L
.208 .31949 L
.212 .31952 L
.216 .31969 L
.22 .31983 L
.224 .31981 L
.228 .3198 L
.232 .32 L
.236 .32024 L
.24 .32017 L
.244 .31971 L
.248 .31923 L
.252 .31913 L
.256 .31939 L
.26 .31975 L
.264 .32007 L
.268 .32047 L
.272 .32093 L
.276 .32112 L
.28 .32071 L
.284 .31986 L
.288 .3191 L
.292 .31879 L
.296 .3188 L
.3 .31892 L
.304 .31919 L
.308 .31993 L
.312 .32113 L
.316 .32222 L
.32 .32247 L
.324 .32162 L
.328 .32014 L
.332 .31877 L
.336 .318 L
.34 .3179 L
.344 .3184 L
.348 .31944 L
.352 .3209 L
.356 .32233 L
.36 .32305 L
.364 .32258 L
.368 .32109 L
.372 .31936 L
.376 .3182 L
.38 .31792 L
.384 .31825 L
.388 .31882 L
.392 .31966 L
.396 .32101 L
.4 .32274 L
Mistroke
.404 .324 L
.408 .32376 L
.412 .32181 L
.416 .31924 L
.42 .31764 L
.424 .3177 L
.428 .31869 L
.432 .3193 L
.436 .31916 L
.44 .31922 L
.444 .32062 L
.448 .32309 L
.452 .32484 L
.456 .32419 L
.46 .3214 L
.464 .31864 L
.468 .31801 L
.472 .31953 L
.476 .32116 L
.48 .32089 L
.484 .3189 L
.488 .31746 L
.492 .31856 L
.496 .32177 L
.5 .32441 L
.504 .3241 L
.508 .3211 L
.512 .31824 L
.516 .31826 L
.52 .32123 L
.524 .3244 L
.528 .3247 L
.532 .32158 L
.536 .31752 L
.54 .31584 L
.544 .31774 L
.548 .32134 L
.552 .32343 L
.556 .32232 L
.56 .31924 L
.564 .31718 L
.568 .31831 L
.572 .32219 L
.576 .3262 L
.58 .32765 L
.584 .32576 L
.588 .32196 L
.592 .31859 L
.596 .31722 L
.6 .31783 L
Mistroke
.604 .31929 L
.608 .32038 L
.612 .3205 L
.616 .31976 L
.62 .31864 L
.624 .31782 L
.628 .318 L
.632 .31978 L
.636 .32312 L
.64 .32698 L
.644 .32942 L
.648 .32863 L
.652 .32431 L
.656 .3183 L
.66 .31394 L
.664 .31403 L
.668 .31893 L
.672 .32591 L
.676 .33059 L
.68 .32961 L
.684 .32287 L
.688 .31382 L
.692 .30762 L
.696 .30805 L
.7 .31524 L
.704 .32548 L
.708 .33331 L
.712 .33456 L
.716 .32862 L
.72 .31865 L
.724 .30977 L
.728 .30627 L
.732 .30952 L
.736 .31761 L
.74 .32669 L
.744 .3331 L
.748 .33507 L
.752 .33299 L
.756 .32868 L
.76 .32397 L
.764 .31981 L
.768 .31626 L
.772 .31312 L
.776 .31076 L
.78 .31029 L
.784 .31302 L
.788 .31945 L
.792 .32844 L
.796 .33713 L
.8 .34189 L
Mistroke
.804 .33975 L
.808 .32986 L
.812 .31416 L
.816 .29687 L
.82 .28311 L
.824 .27701 L
.828 .2803 L
.832 .29177 L
.836 .30791 L
.84 .32424 L
.844 .33697 L
.848 .3441 L
.852 .34577 L
.856 .34369 L
.86 .3401 L
.864 .33657 L
.868 .33329 L
.872 .32902 L
.876 .3217 L
.88 .30939 L
.884 .29118 L
.888 .26776 L
.892 .24133 L
.896 .21507 L
.9 .19219 L
.904 .17507 L
.908 .16457 L
.912 .15986 L
.916 .15872 L
.92 .15821 L
.924 .1555 L
.928 .14856 L
.932 .1367 L
.936 .12055 L
.94 .10194 L
.944 .08316 L
.948 .06674 L
.952 .05438 L
.956 .04728 L
.96 .04516 L
.964 .04734 L
.968 .05187 L
.972 .05713 L
.976 .06108 L
.98 .0625 L
.984 .06076 L
.988 .05559 L
.992 .04807 L
.996 .03847 L
1 .02887 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12182 m
.008 .12664 L
.012 .12822 L
.016 .12669 L
.02 .12609 L
.024 .12661 L
.028 .1268 L
.032 .12667 L
.036 .12659 L
.04 .12666 L
.044 .12666 L
.048 .12665 L
.052 .12663 L
.056 .12664 L
.06 .12664 L
.064 .12665 L
.068 .12663 L
.072 .12664 L
.076 .12663 L
.08 .12665 L
.084 .12664 L
.088 .12666 L
.092 .12665 L
.096 .12665 L
.1 .12664 L
.104 .12664 L
.108 .12663 L
.112 .12663 L
.116 .12664 L
.12 .12665 L
.124 .12666 L
.128 .12666 L
.132 .12665 L
.136 .12664 L
.14 .12663 L
.144 .12662 L
.148 .12662 L
.152 .12663 L
.156 .12665 L
.16 .12667 L
.164 .12667 L
.168 .12668 L
.172 .12667 L
.176 .12665 L
.18 .12663 L
.184 .12661 L
.188 .1266 L
.192 .12661 L
.196 .12662 L
.2 .12665 L
Mistroke
.204 .12666 L
.208 .12668 L
.212 .12669 L
.216 .12668 L
.22 .12666 L
.224 .12665 L
.228 .12663 L
.232 .12663 L
.236 .12662 L
.24 .12662 L
.244 .12662 L
.248 .12663 L
.252 .12664 L
.256 .12665 L
.26 .12665 L
.264 .12665 L
.268 .12666 L
.272 .12668 L
.276 .12668 L
.28 .12668 L
.284 .12667 L
.288 .12666 L
.292 .12665 L
.296 .12663 L
.3 .1266 L
.304 .12659 L
.308 .1266 L
.312 .12662 L
.316 .12664 L
.32 .12667 L
.324 .12669 L
.328 .12672 L
.332 .12672 L
.336 .12669 L
.34 .12665 L
.344 .1266 L
.348 .12659 L
.352 .1266 L
.356 .12664 L
.36 .12667 L
.364 .12669 L
.368 .12671 L
.372 .12671 L
.376 .12669 L
.38 .12663 L
.384 .12656 L
.388 .12651 L
.392 .1265 L
.396 .12656 L
.4 .12665 L
Mistroke
.404 .12674 L
.408 .1268 L
.412 .12684 L
.416 .12686 L
.42 .12684 L
.424 .12676 L
.428 .12663 L
.432 .12648 L
.436 .12639 L
.44 .12638 L
.444 .12644 L
.448 .12653 L
.452 .12661 L
.456 .12668 L
.46 .12678 L
.464 .12689 L
.468 .12696 L
.472 .12694 L
.476 .12682 L
.48 .12666 L
.484 .12655 L
.488 .12653 L
.492 .12654 L
.496 .12653 L
.5 .12647 L
.504 .12642 L
.508 .12645 L
.512 .1266 L
.516 .12679 L
.52 .12692 L
.524 .12694 L
.528 .12687 L
.532 .1268 L
.536 .12678 L
.54 .1268 L
.544 .12676 L
.548 .12661 L
.552 .12636 L
.556 .12614 L
.56 .12606 L
.564 .12616 L
.568 .12639 L
.572 .12666 L
.576 .12689 L
.58 .12705 L
.584 .12719 L
.588 .12733 L
.592 .12746 L
.596 .1275 L
.6 .1274 L
Mistroke
.604 .12711 L
.608 .12666 L
.612 .12615 L
.616 .12569 L
.62 .12538 L
.624 .12529 L
.628 .1254 L
.632 .12568 L
.636 .12602 L
.64 .12637 L
.644 .12669 L
.648 .12699 L
.652 .12734 L
.656 .12775 L
.66 .12817 L
.664 .12849 L
.668 .12856 L
.672 .12832 L
.676 .12781 L
.68 .12719 L
.684 .12666 L
.688 .12638 L
.692 .12633 L
.696 .12638 L
.7 .12631 L
.704 .12598 L
.708 .12538 L
.712 .12464 L
.716 .12397 L
.72 .12358 L
.724 .12353 L
.728 .12377 L
.732 .12413 L
.736 .12449 L
.74 .12476 L
.744 .12499 L
.748 .12529 L
.752 .1258 L
.756 .1266 L
.76 .12776 L
.764 .12924 L
.768 .13099 L
.772 .13296 L
.776 .13506 L
.78 .13718 L
.784 .13922 L
.788 .14104 L
.792 .14256 L
.796 .14376 L
.8 .14473 L
Mistroke
.804 .14567 L
.808 .14682 L
.812 .14839 L
.816 .15051 L
.82 .15315 L
.824 .15617 L
.828 .1593 L
.832 .1623 L
.836 .16496 L
.84 .16719 L
.844 .16902 L
.848 .17057 L
.852 .17197 L
.856 .17335 L
.86 .17477 L
.864 .17627 L
.868 .17785 L
.872 .17952 L
.876 .18135 L
.88 .18344 L
.884 .18594 L
.888 .189 L
.892 .19272 L
.896 .19714 L
.9 .20218 L
.904 .20772 L
.908 .21358 L
.912 .21959 L
.916 .22561 L
.92 .2316 L
.924 .23755 L
.928 .24357 L
.932 .24976 L
.936 .25629 L
.94 .26319 L
.944 .27056 L
.948 .27833 L
.952 .28645 L
.956 .29476 L
.96 .30315 L
.964 .3115 L
.968 .31972 L
.972 .32778 L
.976 .33569 L
.98 .34352 L
.984 .35133 L
.988 .35922 L
.992 .36728 L
.996 .37555 L
1 .38409 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16001 L
.012 .16139 L
.016 .16163 L
.02 .16107 L
.024 .16095 L
.028 .16118 L
.032 .16117 L
.036 .16112 L
.04 .16112 L
.044 .16118 L
.048 .16114 L
.052 .16112 L
.056 .16107 L
.06 .16106 L
.064 .16103 L
.068 .16104 L
.072 .16104 L
.076 .16105 L
.08 .16104 L
.084 .16104 L
.088 .16102 L
.092 .16102 L
.096 .161 L
.1 .161 L
.104 .16098 L
.108 .16097 L
.112 .16094 L
.116 .16093 L
.12 .16092 L
.124 .16093 L
.128 .16093 L
.132 .16094 L
.136 .16093 L
.14 .16091 L
.144 .16088 L
.148 .16085 L
.152 .16084 L
.156 .16084 L
.16 .16085 L
.164 .16086 L
.168 .16087 L
.172 .16086 L
.176 .16083 L
.18 .1608 L
.184 .16076 L
.188 .16074 L
.192 .16073 L
.196 .16074 L
.2 .16075 L
Mistroke
.204 .16076 L
.208 .16077 L
.212 .16078 L
.216 .16077 L
.22 .16074 L
.224 .16071 L
.228 .16069 L
.232 .16067 L
.236 .16065 L
.24 .16063 L
.244 .16062 L
.248 .16063 L
.252 .16063 L
.256 .16063 L
.26 .16062 L
.264 .16062 L
.268 .16062 L
.272 .16063 L
.276 .16063 L
.28 .16061 L
.284 .1606 L
.288 .16058 L
.292 .16055 L
.296 .1605 L
.3 .16046 L
.304 .16043 L
.308 .16044 L
.312 .16047 L
.316 .1605 L
.32 .16053 L
.324 .16054 L
.328 .16054 L
.332 .16053 L
.336 .16048 L
.34 .16042 L
.344 .16037 L
.348 .16035 L
.352 .16036 L
.356 .16039 L
.36 .16042 L
.364 .16043 L
.368 .16044 L
.372 .16043 L
.376 .16039 L
.38 .16032 L
.384 .16022 L
.388 .16015 L
.392 .16014 L
.396 .1602 L
.4 .1603 L
Mistroke
.404 .1604 L
.408 .16046 L
.412 .1605 L
.416 .16052 L
.42 .16049 L
.424 .16039 L
.428 .1602 L
.432 .16 L
.436 .15987 L
.44 .15986 L
.444 .15994 L
.448 .16004 L
.452 .16013 L
.456 .1602 L
.46 .1603 L
.464 .16043 L
.468 .16052 L
.472 .1605 L
.476 .16034 L
.48 .16013 L
.484 .15998 L
.488 .15993 L
.492 .15994 L
.496 .15992 L
.5 .15984 L
.504 .15976 L
.508 .15979 L
.512 .15996 L
.516 .16019 L
.52 .16035 L
.524 .16037 L
.528 .16027 L
.532 .16017 L
.536 .16014 L
.54 .16015 L
.544 .1601 L
.548 .1599 L
.552 .15958 L
.556 .15929 L
.56 .15917 L
.564 .15929 L
.568 .15958 L
.572 .15991 L
.576 .16018 L
.58 .16037 L
.584 .16053 L
.588 .1607 L
.592 .16085 L
.596 .1609 L
.6 .16076 L
Mistroke
.604 .16038 L
.608 .15981 L
.612 .15917 L
.616 .15859 L
.62 .15819 L
.624 .15807 L
.628 .1582 L
.632 .15853 L
.636 .15896 L
.64 .15938 L
.644 .15976 L
.648 .16013 L
.652 .16055 L
.656 .16105 L
.66 .16157 L
.664 .16196 L
.668 .16204 L
.672 .16173 L
.676 .16108 L
.68 .1603 L
.684 .15963 L
.688 .15927 L
.692 .1592 L
.696 .15925 L
.7 .15916 L
.704 .15874 L
.708 .15798 L
.712 .15704 L
.716 .15621 L
.72 .15571 L
.724 .15564 L
.728 .15592 L
.732 .15637 L
.736 .15681 L
.74 .15714 L
.744 .15742 L
.748 .15778 L
.752 .1584 L
.756 .15939 L
.76 .16082 L
.764 .16265 L
.768 .16483 L
.772 .16727 L
.776 .16987 L
.78 .17251 L
.784 .17503 L
.788 .17728 L
.792 .17916 L
.796 .18064 L
.8 .18183 L
Mistroke
.804 .18299 L
.808 .1844 L
.812 .18633 L
.816 .18895 L
.82 .19223 L
.824 .19596 L
.828 .19983 L
.832 .20353 L
.836 .20679 L
.84 .20953 L
.844 .21176 L
.848 .21363 L
.852 .21531 L
.856 .21695 L
.86 .21864 L
.864 .22041 L
.868 .22225 L
.872 .22421 L
.876 .22632 L
.88 .22875 L
.884 .23165 L
.888 .23521 L
.892 .23955 L
.896 .24469 L
.9 .25054 L
.904 .25694 L
.908 .26362 L
.912 .27037 L
.916 .27697 L
.92 .28335 L
.924 .28946 L
.928 .2954 L
.932 .30125 L
.936 .30716 L
.94 .31314 L
.944 .31926 L
.948 .32539 L
.952 .33143 L
.956 .33717 L
.96 .34248 L
.964 .34721 L
.968 .3513 L
.972 .35477 L
.976 .35774 L
.98 .36039 L
.984 .36293 L
.988 .36563 L
.992 .36872 L
.996 .37234 L
1 .37666 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001POol00`00Oomoo`0:Ool0029oo`8005moo`03001oogoo00]oo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0FWoo0P000Woo00<007ooOol02goo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001KOol01000Ool000003Woo
0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008005Yoo`03001oogoo
011oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool00`00Oomoo`1IOol00`00Oomo
o`0@Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00FWoo00<007ooOol0
47oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001JOol00`00Oomo
o`0@Ool000]oo`8000Yoo`8000=oo`<000=oo`03001oogoo05Uoo`03001oogoo011oo`008Woo0P00
FGoo00<007ooOol04Goo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool00`00Oomoo`1H
Ool00`00Oomoo`0AOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`80
05Uoo`03001oogoo015oo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2001IOol00`00Oomoo`0AOol000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00D007oo
Oomoo`0005Qoo`8001Aoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol0
0P00EWoo00<007ooOol057oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomo
o`02001FOol00`00Oomoo`0DOol000]oo`8000Yoo`8000=oo`<000=oo`03001oogoo05Eoo`03001o
ogoo01Aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00EWoo00<007ooOol057oo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000eoo`<000Aoo`8000Mo
o`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000=oo`D000=oo`8000Aoo`80009oo`03001o
o`0000@0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Ool00002Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
009oo`03001oogoo009oo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00<007oo000017oo00<007ooOol017oo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;Ool4
0003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000
Oomoogoo10000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00P007oo
Ool007oo001oo`000goo00<007oo00000`000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo
00<007ooOol00Woo0P0037oo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002
Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001oogooOol00002
Ool01000Oomoo`000Woo00P007ooOol007oo001oo`000goo00<007oo00001Woo00@007ooOol000Eo
o`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D0
00=oo`8000Aoo`<000Aoo`800004Ool007ooOol20002Ool00`00Oomoo`030002Ool50003Ool20006
Ool0029oo`03001oogoo04eoo`8000Aoo`03001oogoo01Ioo`008Woo0P00CWoo0P0017oo00<007oo
Ool05Woo000ROomS000<Ool0029oo`800004Ool00000Ool300000goo0000000300000goo00000002
Ool01000Oomoogoo0P0000=oo`0000001`0000Eoo`00000007oo00<00003Ool0000000800003Ool0
000000800004Ool007ooOol2000017oo000007oo1@0000Eoo`00000007oo00H0009oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00<007ooOol02Woo000ROol4000017oo000007oo0P0000Ao
o`00001oo`l00005Ool00000001oo`03000017oo000000000Woo2P0000=oo`00Ool00P0000Aoo`00
001oo`<00004Ool00000Ool200000goo001oo`02000017oo001oo`000Woo00@007ooOol001Uoo`00
8Woo00<007ooOol0?goo00<007ooOol00P000Woo00<007ooOol00Woo0P000Woo00@007oo000001Uo
o`008Woo0P00C7oo00<007ooOol00Woo0P006Woo000ROol2001]Ool000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06ao
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02
Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo
001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomo
o`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007oo
Ool000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00
KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<0
06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0
JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001W
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Io
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1V
Ool000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Oolm00000goo
00000006000SOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00>Woo0`001goo
0P008Goo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`15Ool3000NOol002Qoo`03
001oogoo04Qoo`8001aoo`00:7oo00<007ooOol0BGoo0`006Woo000;Ool20004Ool00`00Oomoo`03
Ool20004Ool20003Ool30003Ool00`00Oomoo`1;Ool3000HOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00D7oo0P005Woo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00DGoo00<007ooOol057oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool3
0004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool2
0003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007oo
Ool007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00
Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009o
o`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000=oo`8000Moo`04001oogoo0002
Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001o
ogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`03001oogoo009oo`8000Ioo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo
00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=o
o`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo
00D007ooOol007oo00<00003Ool00000008000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uo
o`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`80
00=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`000Woo0P0000=oo`00Ool01Goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@00
0goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Ao
o`8000Aoo`8000Aoo`@00003Ool0000000<000=oo`8000Ioo`00:7oo00<007ooOol0E7oo00<007oo
Ool03goo000XOol00`00Oomoo`1EOol00`00Oomoo`0>Ool002Qooed000aoo`00:7oo00<007ooOol0
3goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol03Goo00@007ooOol0
00aoo`00:7oo00<007ooOol0EWoo00<007ooOol03Goo000XOol00`00Oomoo`1FOol2000>Ool002Qo
o`03001oogoo05Moo`03001oogoo00aoo`00:7oo00<007ooOol0Egoo0P003Goo000XOol00`00Oomo
o`1HOol00`00Oomoo`0;Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03
001oogoo05Uoo`03001oogoo00Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00
Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001W
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P00
17oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool0
0`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04
001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007oo
Ool00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@0
07ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007oo
Ool00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007oo
Ool000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yo
o`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079o
o`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo
0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomo
ogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomo
o`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00
Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`00
27oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomo
o`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00
Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004
Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo
0P001Woo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077ooJ@0037oo000LOol01@00
Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000Aoo`04001oogooOol300000goo001oo`02Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000Aoo`03001oogoo00Yoo`0077oo00<007ooOol0CWoo0`008Goo
000LOol2001AOol3000OOol001aoo`03001oogoo059oo`8001ioo`0077oo00<007ooOol0Dgoo0P00
7Goo000LOol2001FOol3000JOol001aoo`03001oogoo05Moo`8001Uoo`0077oo00<007ooOol0FGoo
00<007ooOol05Woo000LOol2001KOol00`00Oomoo`0EOol001aoo`03001oogoo05Yoo`8001Ioo`00
77oo0P00G7oo00<007ooOol057oo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1K
Ool2000EOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0G7oo00<007oo
Ool04goo000:Ool01000Oomoo`002goo00<007ooOol00P00GWoo00<007ooOol04Woo000:Ool01000
Oomoo`002goo00@007ooOol0061oo`03001oogoo015oo`002Woo00@007ooOol000Moo`@000=oo`03
001oogoo05ioo`03001oogoo015oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80061oo`03
001oogoo011oo`002goo0P0027oo1@000Woo00<007ooOol0H7oo00<007ooOol03goo000LOol00`00
Oomoo`1POol2000@Ool001aoo`80069oo`8000moo`0077oo00<007ooOol0HWoo0P003Woo000LOol2
001UOol00`00Oomoo`0;Ool001aoo`03001oogoo06Eoo`03001oogoo00Yoo`0077oo00<007ooOol0
LWoo000LOol2001cOol001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007oo
Ool0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`00
5goo00<007ooOol00Woo00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009o
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007oo
Ool00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02
001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol0
17oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(43086\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31916 m
.008 .3197 L
.012 .31917 L
.016 .31821 L
.02 .31734 L
.024 .31767 L
.028 .3193 L
.032 .32038 L
.036 .32031 L
.04 .31976 L
.044 .31885 L
.048 .3182 L
.052 .31816 L
.056 .31867 L
.06 .31963 L
.064 .3203 L
.068 .32031 L
.072 .31982 L
.076 .31896 L
.08 .31829 L
.084 .3181 L
.088 .3184 L
.092 .31915 L
.096 .31987 L
.1 .32026 L
.104 .32029 L
.108 .31995 L
.112 .31947 L
.116 .31898 L
.12 .31862 L
.124 .3186 L
.128 .31887 L
.132 .31931 L
.136 .31978 L
.14 .32011 L
.144 .32026 L
.148 .32005 L
.152 .31953 L
.156 .31897 L
.16 .31868 L
.164 .31883 L
.168 .31927 L
.172 .31978 L
.176 .32025 L
.18 .32047 L
.184 .32027 L
.188 .31967 L
.192 .31905 L
.196 .3188 L
.2 .319 L
Mistroke
.204 .3194 L
.208 .31979 L
.212 .32011 L
.216 .32032 L
.22 .32025 L
.224 .31986 L
.228 .31944 L
.232 .31934 L
.236 .31959 L
.24 .31984 L
.244 .31986 L
.248 .31975 L
.252 .31978 L
.256 .31995 L
.26 .32004 L
.264 .31997 L
.268 .31988 L
.272 .3199 L
.276 .31985 L
.28 .31954 L
.284 .3192 L
.288 .3193 L
.292 .32003 L
.296 .32096 L
.3 .32141 L
.304 .32112 L
.308 .32038 L
.312 .31962 L
.316 .31903 L
.32 .31861 L
.324 .31846 L
.328 .31887 L
.332 .31991 L
.336 .32119 L
.34 .32206 L
.344 .32214 L
.348 .32153 L
.352 .32063 L
.356 .31969 L
.36 .31879 L
.364 .31807 L
.368 .3179 L
.372 .31868 L
.376 .32034 L
.38 .32215 L
.384 .32312 L
.388 .32272 L
.392 .32134 L
.396 .31989 L
.4 .319 L
Mistroke
.404 .31863 L
.408 .31837 L
.412 .31818 L
.416 .31863 L
.42 .32023 L
.424 .32254 L
.428 .3242 L
.432 .324 L
.436 .32205 L
.44 .31978 L
.444 .31861 L
.448 .31869 L
.452 .31896 L
.456 .31857 L
.46 .31797 L
.464 .31852 L
.468 .32083 L
.472 .32368 L
.476 .32492 L
.48 .3235 L
.484 .32067 L
.488 .31886 L
.492 .31935 L
.496 .32105 L
.5 .32163 L
.504 .32004 L
.508 .31764 L
.512 .31701 L
.516 .31927 L
.52 .32282 L
.524 .32465 L
.528 .3232 L
.532 .31985 L
.536 .31778 L
.54 .31896 L
.544 .32241 L
.548 .32498 L
.552 .32429 L
.556 .32077 L
.56 .31731 L
.564 .31665 L
.568 .31906 L
.572 .3222 L
.576 .32326 L
.58 .32138 L
.584 .31828 L
.588 .31676 L
.592 .31836 L
.596 .3222 L
.6 .32582 L
Mistroke
.604 .32702 L
.608 .32541 L
.612 .32227 L
.616 .3195 L
.62 .31826 L
.624 .31858 L
.628 .31968 L
.632 .32068 L
.636 .32099 L
.64 .32037 L
.644 .31897 L
.648 .31744 L
.652 .31686 L
.656 .31828 L
.66 .32192 L
.664 .32653 L
.668 .32972 L
.672 .32928 L
.676 .32476 L
.68 .31824 L
.684 .31343 L
.688 .31344 L
.692 .31869 L
.696 .32629 L
.7 .33158 L
.704 .33095 L
.708 .32415 L
.712 .31467 L
.716 .3078 L
.72 .30757 L
.724 .31435 L
.728 .32466 L
.732 .33306 L
.736 .33521 L
.74 .33014 L
.744 .32061 L
.748 .31144 L
.752 .30693 L
.756 .30875 L
.76 .31549 L
.764 .32381 L
.768 .33033 L
.772 .33318 L
.776 .33244 L
.78 .32943 L
.784 .32556 L
.788 .3215 L
.792 .31727 L
.796 .31281 L
.8 .30876 L
Mistroke
.804 .30661 L
.808 .30808 L
.812 .31404 L
.816 .32362 L
.82 .33397 L
.824 .34117 L
.828 .34164 L
.832 .33378 L
.836 .31883 L
.84 .30064 L
.844 .28438 L
.848 .27469 L
.852 .27412 L
.856 .28231 L
.86 .29636 L
.864 .31202 L
.868 .32526 L
.872 .33355 L
.876 .33641 L
.88 .33509 L
.884 .33159 L
.888 .32753 L
.892 .3233 L
.896 .31787 L
.9 .30921 L
.904 .29516 L
.908 .2744 L
.912 .24709 L
.916 .21509 L
.92 .18141 L
.924 .14967 L
.928 .12281 L
.932 .10279 L
.936 .08967 L
.94 .08231 L
.944 .07827 L
.948 .07513 L
.952 .07075 L
.956 .0641 L
.96 .05544 L
.964 .04576 L
.968 .03729 L
.972 .03145 L
.976 .03025 L
.98 .0337 L
.984 .04181 L
.988 .05288 L
.992 .06468 L
.996 .07544 L
1 .08201 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12819 m
.008 .12702 L
.012 .12665 L
.016 .12721 L
.02 .12724 L
.024 .12704 L
.028 .12702 L
.032 .12716 L
.036 .12714 L
.04 .12711 L
.044 .12708 L
.048 .1271 L
.052 .12708 L
.056 .12709 L
.06 .1271 L
.064 .12712 L
.068 .12712 L
.072 .12712 L
.076 .1271 L
.08 .1271 L
.084 .12708 L
.088 .12709 L
.092 .12709 L
.096 .12711 L
.1 .12711 L
.104 .12711 L
.108 .1271 L
.112 .1271 L
.116 .1271 L
.12 .12711 L
.124 .12711 L
.128 .12711 L
.132 .1271 L
.136 .1271 L
.14 .1271 L
.144 .1271 L
.148 .1271 L
.152 .12711 L
.156 .12711 L
.16 .12711 L
.164 .1271 L
.168 .12709 L
.172 .12708 L
.176 .12709 L
.18 .1271 L
.184 .12711 L
.188 .12713 L
.192 .12713 L
.196 .12713 L
.2 .12712 L
Mistroke
.204 .1271 L
.208 .12708 L
.212 .12707 L
.216 .12707 L
.22 .12708 L
.224 .12709 L
.228 .12711 L
.232 .12713 L
.236 .12714 L
.24 .12714 L
.244 .12713 L
.248 .12712 L
.252 .12711 L
.256 .12709 L
.26 .12708 L
.264 .12708 L
.268 .12708 L
.272 .1271 L
.276 .1271 L
.28 .1271 L
.284 .1271 L
.288 .12711 L
.292 .12712 L
.296 .12712 L
.3 .12713 L
.304 .12714 L
.308 .12715 L
.312 .12715 L
.316 .12712 L
.32 .12709 L
.324 .12705 L
.328 .12704 L
.332 .12705 L
.336 .12707 L
.34 .12709 L
.344 .12712 L
.348 .12715 L
.352 .12718 L
.356 .12718 L
.36 .12715 L
.364 .12711 L
.368 .12707 L
.372 .12706 L
.376 .12707 L
.38 .12709 L
.384 .12712 L
.388 .12714 L
.392 .12717 L
.396 .12719 L
.4 .12717 L
Mistroke
.404 .1271 L
.408 .12703 L
.412 .12697 L
.416 .12697 L
.42 .12701 L
.424 .12707 L
.428 .12714 L
.432 .12721 L
.436 .12729 L
.44 .12735 L
.444 .12735 L
.448 .12727 L
.452 .12712 L
.456 .12697 L
.46 .12688 L
.464 .12687 L
.468 .12691 L
.472 .12695 L
.476 .12699 L
.48 .12707 L
.484 .1272 L
.488 .12734 L
.492 .12743 L
.496 .12741 L
.5 .12729 L
.504 .12716 L
.508 .12708 L
.512 .12707 L
.516 .12706 L
.52 .12699 L
.524 .12689 L
.528 .12683 L
.532 .12688 L
.536 .12704 L
.54 .12722 L
.544 .12733 L
.548 .12734 L
.552 .12729 L
.556 .12727 L
.56 .12731 L
.564 .12735 L
.568 .12731 L
.572 .12713 L
.576 .12687 L
.58 .12664 L
.584 .12654 L
.588 .1266 L
.592 .12678 L
.596 .12699 L
.6 .12719 L
Mistroke
.604 .12736 L
.608 .12753 L
.612 .12773 L
.616 .12791 L
.62 .12802 L
.624 .12798 L
.628 .12776 L
.632 .12735 L
.636 .12685 L
.64 .12636 L
.644 .12598 L
.648 .1258 L
.652 .12583 L
.656 .12603 L
.66 .12631 L
.664 .12661 L
.668 .12688 L
.672 .12717 L
.676 .12753 L
.68 .12798 L
.684 .12848 L
.688 .1289 L
.692 .12907 L
.696 .12891 L
.7 .12846 L
.704 .12786 L
.708 .12734 L
.712 .12705 L
.716 .12699 L
.72 .12704 L
.724 .127 L
.728 .1267 L
.732 .12613 L
.736 .1254 L
.74 .1247 L
.744 .12424 L
.748 .12409 L
.752 .12421 L
.756 .12448 L
.76 .12477 L
.764 .12499 L
.768 .12517 L
.772 .12539 L
.776 .12578 L
.78 .12642 L
.784 .12738 L
.788 .12866 L
.792 .13024 L
.796 .13209 L
.8 .13413 L
Mistroke
.804 .13628 L
.808 .13841 L
.812 .14036 L
.816 .14202 L
.82 .14333 L
.824 .14436 L
.828 .14527 L
.832 .1463 L
.836 .14768 L
.84 .1496 L
.844 .15206 L
.848 .15497 L
.852 .15811 L
.856 .16122 L
.86 .16408 L
.864 .1666 L
.868 .16873 L
.872 .17059 L
.876 .17227 L
.88 .17392 L
.884 .1756 L
.888 .17738 L
.892 .17924 L
.896 .18124 L
.9 .18342 L
.904 .18592 L
.908 .18888 L
.912 .19248 L
.916 .19686 L
.92 .2021 L
.924 .20818 L
.928 .21501 L
.932 .22242 L
.936 .23022 L
.94 .23824 L
.944 .24636 L
.948 .2545 L
.952 .26268 L
.956 .27093 L
.96 .27932 L
.964 .28787 L
.968 .29659 L
.972 .30542 L
.976 .31429 L
.98 .32303 L
.984 .33159 L
.988 .33979 L
.992 .3477 L
.996 .35521 L
1 .36251 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15763 L
.012 .16114 L
.016 .16232 L
.02 .16122 L
.024 .16078 L
.028 .16117 L
.032 .16127 L
.036 .16115 L
.04 .16105 L
.044 .16109 L
.048 .16109 L
.052 .16109 L
.056 .16107 L
.06 .1611 L
.064 .16108 L
.068 .16109 L
.072 .16106 L
.076 .16106 L
.08 .16103 L
.084 .16102 L
.088 .16099 L
.092 .16098 L
.096 .16097 L
.1 .16097 L
.104 .16097 L
.108 .16098 L
.112 .16098 L
.116 .16098 L
.12 .16096 L
.124 .16094 L
.128 .16091 L
.132 .16089 L
.136 .16087 L
.14 .16088 L
.144 .16088 L
.148 .16089 L
.152 .16089 L
.156 .16088 L
.16 .16087 L
.164 .16084 L
.168 .16081 L
.172 .16079 L
.176 .16078 L
.18 .16079 L
.184 .1608 L
.188 .16081 L
.192 .16081 L
.196 .16081 L
.2 .16078 L
Mistroke
.204 .16075 L
.208 .16071 L
.212 .16068 L
.216 .16067 L
.22 .16067 L
.224 .16068 L
.228 .1607 L
.232 .16072 L
.236 .16072 L
.24 .16071 L
.244 .16069 L
.248 .16066 L
.252 .16064 L
.256 .16062 L
.26 .16059 L
.264 .16058 L
.268 .16057 L
.272 .16057 L
.276 .16056 L
.28 .16055 L
.284 .16055 L
.288 .16056 L
.292 .16057 L
.296 .16058 L
.3 .16057 L
.304 .16055 L
.308 .16054 L
.312 .16053 L
.316 .1605 L
.32 .16046 L
.324 .16042 L
.328 .16039 L
.332 .16039 L
.336 .1604 L
.34 .16041 L
.344 .16044 L
.348 .16047 L
.352 .1605 L
.356 .16049 L
.36 .16044 L
.364 .16038 L
.368 .16033 L
.372 .1603 L
.376 .1603 L
.38 .16032 L
.384 .16033 L
.388 .16036 L
.392 .16039 L
.396 .16041 L
.4 .16037 L
Mistroke
.404 .16028 L
.408 .16017 L
.412 .16009 L
.416 .16008 L
.42 .16013 L
.424 .1602 L
.428 .16028 L
.432 .16035 L
.436 .16043 L
.44 .16049 L
.444 .16048 L
.448 .16038 L
.452 .16019 L
.456 .16 L
.46 .15987 L
.464 .15984 L
.468 .15987 L
.472 .15992 L
.476 .15996 L
.48 .16005 L
.484 .1602 L
.488 .16038 L
.492 .16048 L
.496 .16044 L
.5 .16029 L
.504 .16011 L
.508 .16 L
.512 .15997 L
.516 .15995 L
.52 .15987 L
.524 .15974 L
.528 .15965 L
.532 .1597 L
.536 .15988 L
.54 .1601 L
.544 .16023 L
.548 .16023 L
.552 .16016 L
.556 .16013 L
.56 .16016 L
.564 .1602 L
.568 .16014 L
.572 .15992 L
.576 .15958 L
.58 .15928 L
.584 .15914 L
.588 .15921 L
.592 .15943 L
.596 .15969 L
.6 .15992 L
Mistroke
.604 .16012 L
.608 .16033 L
.612 .16056 L
.616 .16078 L
.62 .16091 L
.624 .16085 L
.628 .16056 L
.632 .16004 L
.636 .15941 L
.64 .15879 L
.644 .15831 L
.648 .15807 L
.652 .1581 L
.656 .15834 L
.66 .15868 L
.664 .15904 L
.668 .15937 L
.672 .15972 L
.676 .16016 L
.68 .16071 L
.684 .16133 L
.688 .16183 L
.692 .16204 L
.696 .16183 L
.7 .16125 L
.704 .16051 L
.708 .15985 L
.712 .15947 L
.716 .15939 L
.72 .15944 L
.724 .15938 L
.728 .159 L
.732 .15828 L
.736 .15735 L
.74 .15648 L
.744 .15589 L
.748 .15569 L
.752 .15584 L
.756 .15616 L
.76 .15651 L
.764 .15678 L
.768 .15698 L
.772 .15725 L
.776 .15771 L
.78 .1585 L
.784 .15968 L
.788 .16126 L
.792 .16321 L
.796 .16549 L
.8 .16801 L
Mistroke
.804 .17066 L
.808 .17327 L
.812 .17567 L
.816 .17769 L
.82 .17927 L
.824 .18049 L
.828 .18156 L
.832 .18276 L
.836 .1844 L
.84 .18668 L
.844 .18963 L
.848 .19311 L
.852 .19684 L
.856 .20051 L
.86 .20385 L
.864 .20669 L
.868 .20901 L
.872 .21092 L
.876 .21253 L
.88 .214 L
.884 .2154 L
.888 .21676 L
.892 .21806 L
.896 .21932 L
.9 .22056 L
.904 .2219 L
.908 .22348 L
.912 .22549 L
.916 .22803 L
.92 .23118 L
.924 .23486 L
.928 .23896 L
.932 .24323 L
.936 .24748 L
.94 .25149 L
.944 .25519 L
.948 .25858 L
.952 .26175 L
.956 .26489 L
.96 .2682 L
.964 .27183 L
.968 .27593 L
.972 .28048 L
.976 .28546 L
.98 .29068 L
.984 .29602 L
.988 .30119 L
.992 .30614 L
.996 .31063 L
1 .31473 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001MOol00`00Oomoo`0=Ool0029oo`8005aoo`03001oo`0000ioo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0Fgoo00<007oo00003Woo000:Ool01000
Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001LOol00`00Ool0000>Ool000=oo`D0
009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00Fgoo00D007ooOomoo`0000eo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool00`00Oomoo`1IOol00`00Oomoo`02
Ool2000<Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00FGoo00<007oo
Ool04Goo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001IOol00`00
Oomoo`0AOol000]oo`8000Yoo`8000=oo`<000=oo`03001oogoo05Qoo`03001oogoo015oo`008Woo
0P00FGoo00<007ooOol04Goo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool00`00Oomo
o`1HOol00`00Oomoo`0AOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009o
o`8005Qoo`03001oogoo019oo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2001HOol00`00Oomoo`0BOol000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00D0
07ooOomoo`0005Uoo`03001oogoo019oo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00<007ooOol00P00F7oo00<007ooOol04Woo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001HOol00`00Oomoo`0BOol000]oo`8000Yoo`8000=oo`<000=oo`03001oogoo
05Moo`03001oogoo019oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00Egoo00<0
07ooOol04goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000eoo`<0
00Aoo`8000Moo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000=oo`D000=oo`8000Aoo`80
00Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoogoo0P000Woo00<0
07oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
0Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00007Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00]oo`@0
00=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001o
ogooOol40003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomo
o`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool00`00
Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04
001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000R
Ool2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo
0P0017oo0`0017oo0P0017oo0P0017oo10000Woo1@000goo0P001Woo000ROol00`00Oomoo`1?Ool0
0`00Ool00004Ool00`00Oomoo`0COol0029oo`80051oo`03001oo`0000=oo`03001oogoo01Aoo`00
8WooH`0037oo000ROol7000017oo000007oo0`0000Eoo`00000007oo008000=oo`03001oogoo0080
009oo`80009oo`80009oo`<00005Ool00000001oo`0200000goo0000000200000goo001oo`030000
0goo0000000200001Goo00000000Ool00P0000=oo`0000000Woo0`000Woo00@007oo001oo`<00003
Ool007oo009oo`05001oogooOol0000<Ool0029oo`800004Ool00000Ool20002Ool200001Goo0000
0000Ool00P0000=oo`0000001P0000=oo`0000001@0000Eoo`00000007oo00<0009oo`@00003Ool0
000000800003Ool0000000D00005Ool00000001oo`0200001Goo001oo`00Ool00`000Woo00<007oo
00000Woo00<007oo00005goo000ROol00`00Oomoo`0nOol00`00Oomoo`0200000goo00000002Ool2
0003Ool20003Ool2000HOol0029oo`8004ioo`8001eoo`008Woo0P00KGoo000;Ool20004Ool00`00
Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007oo
Ool00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008
Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001o
o`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000
Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo
0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007oo
Ool007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@0
07ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04
001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029o
o`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003
Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001o
ogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00
Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0
0P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomo
o`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007oo
Ool0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomo
o`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo>@00
00=oo`0000000`000Woo200087oo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03
001oogoo03Eoo`<000=oo`<000Moo`<001ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<0
07ooOol0Agoo10006goo000XOol00`00Oomoo`1:Ool2000JOol002Qoo`03001oogoo04]oo`<001Qo
o`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0CGoo0`005Woo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol0055o
o`<001Aoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOol005=oo`03001oogoo019oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`00
17oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo0000
0Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007oo
Oomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoogoo0P0000Aoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`00
17oo0P001Woo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@00
0Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001o
ogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009o
o`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007oo
Ool000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001o
ogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo
000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomo
ogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`0000=oo`00000010000goo0P001Woo000X
Ool00`00Oomoo`1EOol00`00Oomoo`0>Ool002Qoo`03001oogoo05Ioo`03001oogoo00eoo`00:7oo
G@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool0
0`00Oomoo`0=Ool200000goo001oo`0;Ool002Qoo`03001oogoo05Moo`03001oogoo00aoo`00:7oo
00<007ooOol0Egoo00<007ooOol037oo000XOol00`00Oomoo`1HOol00`00Oomoo`0;Ool002Qoo`03
001oogoo05Uoo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03
Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00D007ooOol007oo00@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015o
o`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogoo
Ool00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05
Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006ao
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yo
o`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`80
00Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogoo
Ool00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol0
00Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool0
0`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<0
00=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P00
3Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo
00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000
Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo1000
0goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06
001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo
00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol0
17oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07
001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007oo
Ool00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0
009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoofT000ao
o`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000Woo0P000goo
00D007ooOomoo`0000=oo`05001oogooOol00004Ool00`00Oomoo`0:Ool001aoo`03001oogoo055o
o`<001ioo`0077oo0P00E7oo0P007Goo000LOol00`00Oomoo`1EOol2000KOol001aoo`03001oogoo
05Ioo`8001Yoo`0077oo0P00FGoo0`005goo000LOol00`00Oomoo`1KOol2000EOol001aoo`03001o
ogoo05aoo`8001Aoo`0077oo0P00Ggoo00<007ooOol04Goo000LOol00`00Oomoo`1NOol2000BOol0
01aoo`80065oo`03001oogoo00moo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0
HGoo00<007ooOol03Woo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo069o
o`03001oogoo00eoo`002Woo00@007ooOol000]oo`03001oogoo008006=oo`8000ioo`002Woo00@0
07ooOol000]oo`04001oogoo001UOol2000=Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomo
o`1TOol2000<Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0
009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000F
Ool30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007oo
Ool00Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03
001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=o
o`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol0
2goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomo
o`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`00
2goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(43253\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32025 m
.008 .32055 L
.012 .31919 L
.016 .31804 L
.02 .31807 L
.024 .31834 L
.028 .31891 L
.032 .32002 L
.036 .32054 L
.04 .32014 L
.044 .31911 L
.048 .31799 L
.052 .31762 L
.056 .31804 L
.06 .31903 L
.064 .32012 L
.068 .3205 L
.072 .32012 L
.076 .31926 L
.08 .31841 L
.084 .3182 L
.088 .31867 L
.092 .31952 L
.096 .32024 L
.1 .32026 L
.104 .31962 L
.108 .31873 L
.112 .31811 L
.116 .3182 L
.12 .31894 L
.124 .31996 L
.128 .32076 L
.132 .32081 L
.136 .3201 L
.14 .31902 L
.144 .31818 L
.148 .31802 L
.152 .31851 L
.156 .31942 L
.16 .32035 L
.164 .32085 L
.168 .32066 L
.172 .31988 L
.176 .31901 L
.18 .31852 L
.184 .31854 L
.188 .31894 L
.192 .31954 L
.196 .32014 L
.2 .32053 L
Mistroke
.204 .32048 L
.208 .32004 L
.212 .31954 L
.216 .31925 L
.22 .31918 L
.224 .31916 L
.228 .31919 L
.232 .31944 L
.236 .3199 L
.24 .3203 L
.244 .32038 L
.248 .32021 L
.252 .31998 L
.256 .31978 L
.26 .31952 L
.264 .31925 L
.268 .31922 L
.272 .31962 L
.276 .32018 L
.28 .32045 L
.284 .32029 L
.288 .32002 L
.292 .31992 L
.296 .31994 L
.3 .31978 L
.304 .31942 L
.308 .3192 L
.312 .31944 L
.316 .32004 L
.32 .32065 L
.324 .32101 L
.328 .3211 L
.332 .32097 L
.336 .3205 L
.34 .31959 L
.344 .31855 L
.348 .31799 L
.352 .3184 L
.356 .31964 L
.36 .32103 L
.364 .3219 L
.368 .32207 L
.372 .32176 L
.376 .32122 L
.38 .32041 L
.384 .31927 L
.388 .31806 L
.392 .31749 L
.396 .31815 L
.4 .31993 L
Mistroke
.404 .32192 L
.408 .32302 L
.412 .32281 L
.416 .32175 L
.42 .32063 L
.424 .31977 L
.428 .31895 L
.432 .31804 L
.436 .31751 L
.44 .31818 L
.444 .32024 L
.448 .32268 L
.452 .32398 L
.456 .32341 L
.46 .32172 L
.464 .32037 L
.468 .32002 L
.472 .32 L
.476 .31921 L
.48 .3177 L
.484 .3169 L
.488 .31819 L
.492 .32127 L
.496 .32406 L
.5 .32449 L
.504 .3225 L
.508 .32012 L
.512 .31952 L
.516 .32087 L
.52 .32223 L
.524 .32157 L
.528 .31898 L
.532 .31677 L
.536 .31724 L
.54 .32038 L
.544 .32367 L
.548 .32433 L
.552 .32188 L
.556 .31866 L
.56 .31771 L
.564 .31999 L
.568 .32356 L
.572 .32527 L
.576 .3236 L
.58 .31989 L
.584 .31718 L
.588 .31752 L
.592 .32032 L
.596 .32298 L
.6 .32317 L
Mistroke
.604 .32072 L
.608 .31766 L
.612 .31652 L
.616 .31832 L
.62 .32197 L
.624 .32524 L
.628 .32638 L
.632 .32513 L
.636 .32258 L
.64 .32019 L
.644 .31894 L
.648 .31901 L
.652 .31999 L
.656 .3212 L
.66 .32184 L
.664 .32131 L
.668 .31948 L
.672 .31711 L
.676 .31572 L
.68 .31683 L
.684 .32082 L
.688 .32619 L
.692 .33007 L
.696 .32986 L
.7 .32506 L
.704 .318 L
.708 .31274 L
.712 .31269 L
.716 .3183 L
.72 .32651 L
.724 .33244 L
.728 .33222 L
.732 .32547 L
.736 .31564 L
.74 .30813 L
.744 .30716 L
.748 .31341 L
.752 .32362 L
.756 .3325 L
.76 .33556 L
.764 .33149 L
.768 .32259 L
.772 .31333 L
.776 .30791 L
.78 .30829 L
.784 .31355 L
.788 .32087 L
.792 .32718 L
.796 .33066 L
.8 .3311 L
Mistroke
.804 .32937 L
.808 .32642 L
.812 .32263 L
.816 .31785 L
.82 .31211 L
.824 .30622 L
.828 .30196 L
.832 .30145 L
.836 .30599 L
.84 .31504 L
.844 .32592 L
.848 .33447 L
.852 .33657 L
.856 .32981 L
.86 .31457 L
.864 .29407 L
.868 .27328 L
.872 .25717 L
.876 .24899 L
.88 .24929 L
.884 .25594 L
.888 .26509 L
.892 .27277 L
.896 .27615 L
.9 .27445 L
.904 .26864 L
.908 .26093 L
.912 .25329 L
.916 .24694 L
.92 .24145 L
.924 .23541 L
.928 .22678 L
.932 .21397 L
.936 .1967 L
.94 .17584 L
.944 .15394 L
.948 .13356 L
.952 .11759 L
.956 .10718 L
.96 .1025 L
.964 .10195 L
.968 .10273 L
.972 .1025 L
.976 .0982 L
.98 .08966 L
.984 .07625 L
.988 .06051 L
.992 .0446 L
.996 .03128 L
1 .02369 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13255 m
.008 .12758 L
.012 .12588 L
.016 .12756 L
.02 .12811 L
.024 .1276 L
.028 .12737 L
.032 .12756 L
.036 .1276 L
.04 .12756 L
.044 .12753 L
.048 .12757 L
.052 .12757 L
.056 .12758 L
.06 .12756 L
.064 .12757 L
.068 .12755 L
.072 .12756 L
.076 .12755 L
.08 .12756 L
.084 .12755 L
.088 .12756 L
.092 .12756 L
.096 .12757 L
.1 .12757 L
.104 .12757 L
.108 .12756 L
.112 .12756 L
.116 .12755 L
.12 .12755 L
.124 .12755 L
.128 .12756 L
.132 .12756 L
.136 .12757 L
.14 .12757 L
.144 .12758 L
.148 .12757 L
.152 .12757 L
.156 .12756 L
.16 .12755 L
.164 .12755 L
.168 .12755 L
.172 .12756 L
.176 .12757 L
.18 .12758 L
.184 .12757 L
.188 .12756 L
.192 .12755 L
.196 .12755 L
.2 .12754 L
Mistroke
.204 .12755 L
.208 .12756 L
.212 .12758 L
.216 .1276 L
.22 .1276 L
.224 .12759 L
.228 .12757 L
.232 .12755 L
.236 .12753 L
.24 .12752 L
.244 .12753 L
.248 .12755 L
.252 .12757 L
.256 .12759 L
.26 .1276 L
.264 .12759 L
.268 .12759 L
.272 .12758 L
.276 .12757 L
.28 .12756 L
.284 .12755 L
.288 .12755 L
.292 .12755 L
.296 .12755 L
.3 .12754 L
.304 .12754 L
.308 .12755 L
.312 .12757 L
.316 .12758 L
.32 .12758 L
.324 .12759 L
.328 .1276 L
.332 .12761 L
.336 .12761 L
.34 .12758 L
.344 .12755 L
.348 .12753 L
.352 .12752 L
.356 .12751 L
.36 .12752 L
.364 .12753 L
.368 .12757 L
.372 .12761 L
.376 .12764 L
.38 .12764 L
.384 .12762 L
.388 .12758 L
.392 .12755 L
.396 .12753 L
.4 .12752 L
Mistroke
.404 .12753 L
.408 .12755 L
.412 .1276 L
.416 .12765 L
.42 .12767 L
.424 .12764 L
.428 .12757 L
.432 .1275 L
.436 .12745 L
.44 .12744 L
.444 .12746 L
.448 .1275 L
.452 .12755 L
.456 .12763 L
.46 .12773 L
.464 .12782 L
.468 .12783 L
.472 .12775 L
.476 .12761 L
.48 .12748 L
.484 .1274 L
.488 .12737 L
.492 .12736 L
.496 .12735 L
.5 .12737 L
.504 .12746 L
.508 .12763 L
.512 .12779 L
.516 .12788 L
.52 .12785 L
.524 .12775 L
.528 .12765 L
.532 .12762 L
.536 .12761 L
.54 .12756 L
.544 .12746 L
.548 .12733 L
.552 .12727 L
.556 .12733 L
.56 .12749 L
.564 .12764 L
.568 .12773 L
.572 .12773 L
.576 .12771 L
.58 .12774 L
.584 .12782 L
.588 .12788 L
.592 .12784 L
.596 .12766 L
.6 .12739 L
Mistroke
.604 .12716 L
.608 .12704 L
.612 .12706 L
.616 .12718 L
.62 .12734 L
.624 .1275 L
.628 .12767 L
.632 .12786 L
.636 .12809 L
.64 .12833 L
.644 .1285 L
.648 .12853 L
.652 .12838 L
.656 .12804 L
.66 .12756 L
.664 .12705 L
.668 .12661 L
.672 .12636 L
.676 .12631 L
.68 .12643 L
.684 .12664 L
.688 .12687 L
.692 .12709 L
.696 .12735 L
.7 .1277 L
.704 .12819 L
.708 .12875 L
.712 .12925 L
.716 .12952 L
.72 .12946 L
.724 .12907 L
.728 .12852 L
.732 .12801 L
.736 .12771 L
.74 .12765 L
.744 .1277 L
.748 .12768 L
.752 .12742 L
.756 .12689 L
.76 .12618 L
.764 .12548 L
.768 .12496 L
.772 .12472 L
.776 .12474 L
.78 .12493 L
.784 .12515 L
.788 .12533 L
.792 .12548 L
.796 .12565 L
.8 .12595 L
Mistroke
.804 .12647 L
.808 .12726 L
.812 .12837 L
.816 .1298 L
.82 .13154 L
.824 .13354 L
.828 .13573 L
.832 .13799 L
.836 .14014 L
.84 .14204 L
.844 .14361 L
.848 .14487 L
.852 .14596 L
.856 .14712 L
.86 .14861 L
.864 .15063 L
.868 .15328 L
.872 .15651 L
.876 .16015 L
.88 .16398 L
.884 .16779 L
.888 .17146 L
.892 .17494 L
.896 .1783 L
.9 .18163 L
.904 .18505 L
.908 .18863 L
.912 .19239 L
.916 .19633 L
.92 .20041 L
.924 .20464 L
.928 .20907 L
.932 .21378 L
.936 .21888 L
.94 .22446 L
.944 .23058 L
.948 .23721 L
.952 .2443 L
.956 .25165 L
.96 .25917 L
.964 .26668 L
.968 .27415 L
.972 .28153 L
.976 .28892 L
.98 .2964 L
.984 .3041 L
.988 .31212 L
.992 .32047 L
.996 .32916 L
1 .33804 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16169 L
.012 .16101 L
.016 .1609 L
.02 .16129 L
.024 .16126 L
.028 .16113 L
.032 .16111 L
.036 .16117 L
.04 .16112 L
.044 .1611 L
.048 .16108 L
.052 .16112 L
.056 .16111 L
.06 .1611 L
.064 .16107 L
.068 .16104 L
.072 .16101 L
.076 .16101 L
.08 .16101 L
.084 .16104 L
.088 .16104 L
.092 .16105 L
.096 .16102 L
.1 .161 L
.104 .16096 L
.108 .16095 L
.112 .16093 L
.116 .16093 L
.12 .16093 L
.124 .16093 L
.128 .16093 L
.132 .16092 L
.136 .16092 L
.14 .16091 L
.144 .1609 L
.148 .16088 L
.152 .16086 L
.156 .16084 L
.16 .16083 L
.164 .16082 L
.168 .16082 L
.172 .16083 L
.176 .16083 L
.18 .16083 L
.184 .16081 L
.188 .16078 L
.192 .16076 L
.196 .16074 L
.2 .16073 L
Mistroke
.204 .16073 L
.208 .16074 L
.212 .16075 L
.216 .16076 L
.22 .16075 L
.224 .16073 L
.228 .1607 L
.232 .16067 L
.236 .16064 L
.24 .16062 L
.244 .16061 L
.248 .16062 L
.252 .16063 L
.256 .16065 L
.26 .16065 L
.264 .16065 L
.268 .16064 L
.272 .16063 L
.276 .16059 L
.28 .16056 L
.284 .16053 L
.288 .16052 L
.292 .16052 L
.296 .16052 L
.3 .16051 L
.304 .1605 L
.308 .1605 L
.312 .1605 L
.316 .1605 L
.32 .16049 L
.324 .1605 L
.328 .1605 L
.332 .16051 L
.336 .16049 L
.34 .16046 L
.344 .16041 L
.348 .16037 L
.352 .16035 L
.356 .16033 L
.36 .16032 L
.364 .16033 L
.368 .16036 L
.372 .16041 L
.376 .16044 L
.38 .16044 L
.384 .16039 L
.388 .16033 L
.392 .16028 L
.396 .16026 L
.4 .16025 L
Mistroke
.404 .16024 L
.408 .16026 L
.412 .16029 L
.416 .16034 L
.42 .16036 L
.424 .16033 L
.428 .16024 L
.432 .16014 L
.436 .16006 L
.44 .16004 L
.444 .16005 L
.448 .16009 L
.452 .16014 L
.456 .16024 L
.46 .16036 L
.464 .16045 L
.468 .16046 L
.472 .16036 L
.476 .16017 L
.48 .16 L
.484 .15989 L
.488 .15984 L
.492 .15981 L
.496 .1598 L
.5 .15982 L
.504 .15992 L
.508 .16011 L
.512 .1603 L
.516 .1604 L
.52 .16036 L
.524 .16023 L
.528 .1601 L
.532 .16004 L
.536 .16002 L
.54 .15995 L
.544 .15981 L
.548 .15965 L
.552 .15956 L
.556 .15963 L
.56 .15981 L
.564 .16 L
.568 .16009 L
.572 .16008 L
.576 .16005 L
.58 .16008 L
.584 .16017 L
.588 .16024 L
.592 .16017 L
.596 .15994 L
.6 .1596 L
Mistroke
.604 .1593 L
.608 .15914 L
.612 .15915 L
.616 .1593 L
.62 .15949 L
.624 .15968 L
.628 .15987 L
.632 .1601 L
.636 .16038 L
.64 .16066 L
.644 .16087 L
.648 .16091 L
.652 .1607 L
.656 .16026 L
.66 .15966 L
.664 .15901 L
.668 .15846 L
.672 .15814 L
.676 .15806 L
.68 .1582 L
.684 .15846 L
.688 .15874 L
.692 .159 L
.696 .15931 L
.7 .15974 L
.704 .16034 L
.708 .16103 L
.712 .16165 L
.716 .16197 L
.72 .16188 L
.724 .16138 L
.728 .16068 L
.732 .16004 L
.736 .15966 L
.74 .15956 L
.744 .15961 L
.748 .15957 L
.752 .15924 L
.756 .15856 L
.76 .15766 L
.764 .15676 L
.768 .1561 L
.772 .15578 L
.776 .15578 L
.78 .15598 L
.784 .15622 L
.788 .15641 L
.792 .15655 L
.796 .15671 L
.8 .15702 L
Mistroke
.804 .15759 L
.808 .1585 L
.812 .15978 L
.816 .16145 L
.82 .16347 L
.824 .16581 L
.828 .16835 L
.832 .17094 L
.836 .17335 L
.84 .1754 L
.844 .17697 L
.848 .17808 L
.852 .17889 L
.856 .17967 L
.86 .18072 L
.864 .18227 L
.868 .1844 L
.872 .18702 L
.876 .18988 L
.88 .19265 L
.884 .19503 L
.888 .19682 L
.892 .19792 L
.896 .19838 L
.9 .19829 L
.904 .19777 L
.908 .19693 L
.912 .19582 L
.916 .19447 L
.92 .19292 L
.924 .19128 L
.928 .18971 L
.932 .18844 L
.936 .18774 L
.94 .18784 L
.944 .1889 L
.948 .19097 L
.952 .19398 L
.956 .1977 L
.96 .20194 L
.964 .20637 L
.968 .21083 L
.972 .21512 L
.976 .21924 L
.98 .22321 L
.984 .22713 L
.988 .23115 L
.992 .23533 L
.996 .23981 L
1 .24452 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001OOol2000<Ool0029oo`8005moo`03001oogoo00]oo`002goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo00<007ooOol0GWoo00<007ooOol02goo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool00`00Oomoo`02001NOol00`00Oomoo`0<Ool000=oo`D0009oo`04
001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00GWoo00<007ooOol037oo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo05eoo`03001oogoo00aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001NOol00`00Oomoo`0<Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008005aoo`8000moo`002goo0P002Woo0P00
0goo0`000goo00<007ooOol0FWoo00<007ooOol03goo000ROol2001KOol00`00Oomoo`0?Ool000]o
o`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo05Uoo`03001oogoo011oo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00FWoo00<007ooOol047oo0003
Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8005Yoo`03001oogoo
011oo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01@00Oomoogoo0000Fgoo00<007ooOol0
47oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001JOol00`00Oomo
o`0@Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008005Yoo`03001o
ogoo011oo`002goo0P002Woo0P000goo0`000goo00<007ooOol0FGoo00<007ooOol047oo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool2001IOol00`00Oomoo`0AOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo
0P001Goo0`000goo0`0017oo0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo
0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]o
o`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomo
o`000Woo00@007ooOol0009oo`03001oogoo009oo`800004Ool007oo0003Ool01000Oomoo`000Woo
00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011o
o`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Aoo`8000Moo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo
00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOomoo`80
0003Ool007oo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo0P0017oo00<007ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`03001oogoo0080009oo`06001oogooOol007oo10000goo00@0
07ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo0P0037oo00<007ooOol017oo00@0
07ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo
00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00P007ooOol007oo001oo`00
0goo00<007oo00001Woo00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol0
0goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`<00004Ool00000
Ool30002Ool50003Ool20006Ool0029oo`03001oogoo059oo`03001oogoo01Moo`008Woo0P00DWoo
00<007ooOol067oo000ROomS000<Ool0029oo`L00004Ool00000Ool200000goo0000000300001goo
00000000Ool007oo0080009oo`80009oo`80009oo`80009oo`8000=oo`80009oo`800006Ool00000
Ool007oo0P0000=oo`0000000Woo00<007ooOol00P0000=oo`0000000P0000]oo`00001oo`00Ool0
07oo001oo`0000=oo`05001oogooOol00003Ool00`00Oomoo`0:Ool0029oo`800004Ool00000Ool2
000017oo000007oo0P0000Eoo`00000007oo00<00005Ool00000001oo`0700001Goo00000000Ool0
0`0000=oo`0000000P0000=oo`0000000P0000=oo`0000001@0000Aoo`00001oo`800004Ool00000
Ool200001Goo001oo`00Ool00`000Woo00<007oo00006Woo000ROol00`00Oomoo`11Ool01000Oomo
o`000Woo0P000Woo00<007ooOol00Woo0P006Woo000ROol2001]Ool0029oo`8006eoo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Ao
o`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000
Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`00
0goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qo
o`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol0
00Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00
KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003
Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
1Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03
001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo
00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Ao
o`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo
00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oob/00003Ool0000000800003Ool000000080009oo`<0009oo`D000Aoo`H001ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Ool0000SOol20002Ool20003Ool20003Ool4
0002Ool30003Ool60004Ool3000LOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo
04Yoo`<001Uoo`00:7oo00<007ooOol0C7oo0P0067oo000XOol00`00Oomoo`1>Ool00`00Oomoo`0E
Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo04ioo`8001Io
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001B
Ool2000DOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04
001oogoo001COol00`00Oomoo`0BOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<0
00Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00
009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001o
ogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
0Woo00H007ooOomoo`00Ool200000goo001oo`02Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`8000Ioo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009o
o`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`8000Eoo`04001oogoo0002Ool0
0`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`H000=oo`04001oogoo0005Ool002Qo
o`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@0
07ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`000goo0`001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo
1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<0
00Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0EWoo00<007ooOol0
3Goo000XOol00`00Oomoo`1GOol00`00Oomoo`0<Ool002Qooed000aoo`00:7oo00<007ooOol03goo
00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol03goo0P0037oo000XOol0
0`00Oomoo`1HOol00`00Oomoo`0;Ool002Qoo`03001oogoo05Uoo`03001oogoo00Yoo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007oo
Ool00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`05001oogoo001oo`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0
009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo
000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00
Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4
001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2
000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;
Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00
Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@00
0Woo00<007ooOol0LWoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005
Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001ao
o`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001o
ogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0
009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03
001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo
00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomo
o`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004
Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo
00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001o
ogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004
Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03
001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006
Ool30002Ool50003Ool20006Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOomY
000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`03
001oo`00008000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03
001oogoo05Aoo`@001Yoo`0077oo0P00F7oo0P0017oo0`004Woo000LOol00`00Oomoo`1HOol50003
Ool00`00Oomoo`0?Ool001aoo`03001oogoo065oo`03001oogoo00ioo`0077oo0P00Hgoo00<007oo
Ool03Goo000LOol00`00Oomoo`1ROol2000>Ool001aoo`03001oogoo06=oo`8000eoo`0077oo0P00
IWoo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007oo
Ool00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]o
o`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol0
01Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00
Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo
0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo
00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1b
Ool000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(43420\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32007 m
.008 .31935 L
.012 .31909 L
.016 .3193 L
.02 .31987 L
.024 .31952 L
.028 .31824 L
.032 .31767 L
.036 .31809 L
.04 .31875 L
.044 .31953 L
.048 .32006 L
.052 .32012 L
.056 .31979 L
.06 .3191 L
.064 .31855 L
.068 .31834 L
.072 .31844 L
.076 .31887 L
.08 .31934 L
.084 .31964 L
.088 .31974 L
.092 .31956 L
.096 .3193 L
.1 .31906 L
.104 .3189 L
.108 .31898 L
.112 .31924 L
.116 .31952 L
.12 .31969 L
.124 .31962 L
.128 .3194 L
.132 .3191 L
.136 .31884 L
.14 .31884 L
.144 .31916 L
.148 .31968 L
.152 .32012 L
.156 .32018 L
.16 .31991 L
.164 .31941 L
.168 .31887 L
.172 .31854 L
.176 .31865 L
.18 .31925 L
.184 .32005 L
.188 .32058 L
.192 .32058 L
.196 .32011 L
.2 .31941 L
Mistroke
.204 .31875 L
.208 .31838 L
.212 .31857 L
.216 .31934 L
.22 .3203 L
.224 .32088 L
.228 .32079 L
.232 .32023 L
.236 .31958 L
.24 .31907 L
.244 .3188 L
.248 .31888 L
.252 .31933 L
.256 .31995 L
.26 .32033 L
.264 .32029 L
.268 .32006 L
.272 .31998 L
.276 .32006 L
.28 .32 L
.284 .31967 L
.288 .31932 L
.292 .31929 L
.296 .31959 L
.3 .31996 L
.304 .3202 L
.308 .32036 L
.312 .32051 L
.316 .3205 L
.32 .32011 L
.324 .31947 L
.328 .319 L
.332 .31906 L
.336 .31956 L
.34 .32012 L
.344 .32053 L
.348 .32088 L
.352 .32124 L
.356 .32139 L
.36 .32094 L
.364 .31982 L
.368 .31852 L
.372 .31785 L
.376 .31824 L
.38 .31944 L
.384 .32077 L
.388 .32169 L
.392 .32208 L
.396 .32206 L
.4 .32166 L
Mistroke
.404 .32074 L
.408 .31937 L
.412 .31805 L
.416 .31755 L
.42 .3183 L
.424 .31993 L
.428 .32151 L
.432 .32231 L
.436 .32232 L
.44 .32201 L
.444 .32162 L
.448 .32085 L
.452 .3194 L
.456 .3177 L
.46 .31691 L
.464 .31793 L
.468 .32035 L
.472 .32264 L
.476 .32338 L
.48 .3226 L
.484 .32154 L
.488 .32127 L
.492 .32149 L
.496 .32095 L
.5 .31904 L
.504 .31687 L
.508 .3164 L
.512 .31853 L
.516 .32191 L
.52 .32401 L
.524 .32342 L
.528 .32119 L
.532 .31977 L
.536 .32055 L
.54 .3225 L
.544 .32316 L
.548 .32122 L
.552 .31796 L
.556 .31623 L
.56 .31776 L
.564 .32143 L
.568 .32418 L
.572 .32375 L
.576 .3207 L
.58 .3179 L
.584 .31798 L
.588 .32094 L
.592 .32427 L
.596 .32513 L
.6 .32282 L
Mistroke
.604 .31929 L
.608 .31739 L
.612 .31846 L
.616 .32133 L
.62 .32345 L
.624 .323 L
.628 .32032 L
.632 .31748 L
.636 .31659 L
.64 .31831 L
.644 .32155 L
.648 .32445 L
.652 .32563 L
.656 .32486 L
.66 .32289 L
.664 .32078 L
.668 .31941 L
.672 .31921 L
.676 .32016 L
.68 .32169 L
.684 .32279 L
.688 .32242 L
.692 .32019 L
.696 .317 L
.7 .31479 L
.704 .31554 L
.708 .31978 L
.712 .32578 L
.716 .33027 L
.72 .3303 L
.724 .32526 L
.728 .3177 L
.732 .31199 L
.736 .31177 L
.74 .31759 L
.744 .32632 L
.748 .33286 L
.752 .33314 L
.756 .32657 L
.76 .3165 L
.764 .30834 L
.768 .30652 L
.772 .31202 L
.776 .3219 L
.78 .33103 L
.784 .33486 L
.788 .33171 L
.792 .32342 L
.796 .31406 L
.8 .30768 L
Mistroke
.804 .30639 L
.808 .30971 L
.812 .31527 L
.816 .32039 L
.82 .32331 L
.824 .3236 L
.828 .32173 L
.832 .31819 L
.836 .31292 L
.84 .3055 L
.844 .29577 L
.848 .2846 L
.852 .274 L
.856 .2665 L
.86 .26399 L
.864 .26649 L
.868 .27177 L
.872 .2758 L
.876 .27431 L
.88 .2644 L
.884 .24605 L
.888 .22213 L
.892 .19784 L
.896 .17872 L
.9 .16906 L
.904 .17048 L
.908 .18167 L
.912 .19922 L
.916 .21869 L
.92 .23654 L
.924 .25043 L
.928 .26017 L
.932 .26647 L
.936 .27053 L
.94 .273 L
.944 .27319 L
.948 .27004 L
.952 .26128 L
.956 .24624 L
.96 .22439 L
.964 .19772 L
.968 .16907 L
.972 .14185 L
.976 .12005 L
.98 .10501 L
.984 .09818 L
.988 .09742 L
.992 .10039 L
.996 .10417 L
1 .10473 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12782 m
.008 .12814 L
.012 .12814 L
.016 .12793 L
.02 .12795 L
.024 .1281 L
.028 .12804 L
.032 .12798 L
.036 .12798 L
.04 .12803 L
.044 .12802 L
.048 .12804 L
.052 .12803 L
.056 .12803 L
.06 .128 L
.064 .128 L
.068 .12799 L
.072 .12802 L
.076 .12803 L
.08 .12805 L
.084 .12804 L
.088 .12804 L
.092 .12801 L
.096 .128 L
.1 .12799 L
.104 .128 L
.108 .12801 L
.112 .12803 L
.116 .12803 L
.12 .12804 L
.124 .12803 L
.128 .12803 L
.132 .12802 L
.136 .12801 L
.14 .12801 L
.144 .12801 L
.148 .12801 L
.152 .12801 L
.156 .12802 L
.16 .12803 L
.164 .12803 L
.168 .12804 L
.172 .12803 L
.176 .12803 L
.18 .12802 L
.184 .12801 L
.188 .128 L
.192 .12801 L
.196 .12802 L
.2 .12803 L
Mistroke
.204 .12804 L
.208 .12803 L
.212 .12802 L
.216 .12801 L
.22 .128 L
.224 .128 L
.228 .12801 L
.232 .12802 L
.236 .12804 L
.24 .12805 L
.244 .12805 L
.248 .12804 L
.252 .12803 L
.256 .12802 L
.26 .128 L
.264 .12799 L
.268 .12799 L
.272 .128 L
.276 .12801 L
.28 .12803 L
.284 .12804 L
.288 .12806 L
.292 .12806 L
.296 .12805 L
.3 .12804 L
.304 .12802 L
.308 .12801 L
.312 .12801 L
.316 .12801 L
.32 .128 L
.324 .128 L
.328 .12801 L
.332 .12802 L
.336 .12802 L
.34 .12803 L
.344 .12803 L
.348 .12804 L
.352 .12806 L
.356 .12807 L
.36 .12807 L
.364 .12805 L
.368 .12803 L
.372 .12801 L
.376 .12798 L
.38 .12796 L
.384 .12796 L
.388 .12798 L
.392 .12802 L
.396 .12807 L
.4 .1281 L
Mistroke
.404 .12809 L
.408 .12807 L
.412 .12805 L
.416 .12803 L
.42 .12801 L
.424 .12798 L
.428 .12797 L
.432 .12799 L
.436 .12805 L
.44 .1281 L
.444 .12813 L
.448 .12811 L
.452 .12805 L
.456 .12798 L
.46 .12794 L
.464 .12792 L
.468 .12791 L
.472 .12791 L
.476 .12795 L
.48 .12805 L
.484 .12818 L
.488 .12828 L
.492 .1283 L
.496 .12823 L
.5 .12811 L
.504 .128 L
.508 .12793 L
.512 .12788 L
.516 .12782 L
.52 .12777 L
.524 .12778 L
.528 .12788 L
.532 .12805 L
.536 .12822 L
.54 .1283 L
.544 .12827 L
.548 .1282 L
.552 .12816 L
.556 .12815 L
.56 .12814 L
.564 .12806 L
.568 .12792 L
.572 .12778 L
.576 .12773 L
.58 .1278 L
.584 .12793 L
.588 .12806 L
.592 .12811 L
.596 .12811 L
.6 .12812 L
Mistroke
.604 .1282 L
.608 .12832 L
.612 .12839 L
.616 .12836 L
.62 .12818 L
.624 .12793 L
.628 .1277 L
.632 .12756 L
.636 .12754 L
.64 .12761 L
.644 .12771 L
.648 .12783 L
.652 .12798 L
.656 .12817 L
.66 .12843 L
.664 .1287 L
.668 .12893 L
.672 .12904 L
.676 .12897 L
.68 .1287 L
.684 .12826 L
.688 .12774 L
.692 .12727 L
.696 .12696 L
.7 .12684 L
.704 .12689 L
.708 .12702 L
.712 .12718 L
.716 .12734 L
.72 .12754 L
.724 .12788 L
.728 .12838 L
.732 .129 L
.736 .12958 L
.74 .12995 L
.744 .12998 L
.748 .12968 L
.752 .12919 L
.756 .12871 L
.76 .12842 L
.764 .12836 L
.768 .12843 L
.772 .12844 L
.776 .12825 L
.78 .12779 L
.784 .12715 L
.788 .12648 L
.792 .12595 L
.796 .12568 L
.8 .12567 L
Mistroke
.804 .12584 L
.808 .12608 L
.812 .12632 L
.816 .12655 L
.82 .12682 L
.824 .12722 L
.828 .12782 L
.832 .12872 L
.836 .12995 L
.84 .13158 L
.844 .13361 L
.848 .13607 L
.852 .13889 L
.856 .14197 L
.86 .14516 L
.864 .1483 L
.868 .15128 L
.872 .15409 L
.876 .15684 L
.88 .15972 L
.884 .16299 L
.888 .16685 L
.892 .17139 L
.896 .17658 L
.9 .18222 L
.904 .18806 L
.908 .19381 L
.912 .19926 L
.916 .20429 L
.92 .20886 L
.924 .21302 L
.928 .21688 L
.932 .2205 L
.936 .22398 L
.94 .22734 L
.944 .23068 L
.948 .23403 L
.952 .23755 L
.956 .24137 L
.96 .24566 L
.964 .25058 L
.968 .25619 L
.972 .26251 L
.976 .26942 L
.98 .27679 L
.984 .28442 L
.988 .29209 L
.992 .29974 L
.996 .30724 L
1 .31465 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16481 L
.012 .16124 L
.016 .15997 L
.02 .16118 L
.024 .16155 L
.028 .16116 L
.032 .16098 L
.036 .16113 L
.04 .16115 L
.044 .16112 L
.048 .16108 L
.052 .1611 L
.056 .16109 L
.06 .16109 L
.064 .16106 L
.068 .16107 L
.072 .16105 L
.076 .16105 L
.08 .16103 L
.084 .16103 L
.088 .161 L
.092 .16099 L
.096 .16098 L
.1 .16097 L
.104 .16097 L
.108 .16097 L
.112 .16097 L
.116 .16097 L
.12 .16095 L
.124 .16094 L
.128 .16092 L
.132 .1609 L
.136 .16089 L
.14 .16088 L
.144 .16087 L
.148 .16087 L
.152 .16086 L
.156 .16086 L
.16 .16086 L
.164 .16085 L
.168 .16084 L
.172 .16083 L
.176 .16081 L
.18 .16079 L
.184 .16078 L
.188 .16077 L
.192 .16076 L
.196 .16077 L
.2 .16077 L
Mistroke
.204 .16077 L
.208 .16075 L
.212 .16073 L
.216 .16071 L
.22 .16068 L
.224 .16067 L
.228 .16066 L
.232 .16067 L
.236 .16069 L
.24 .1607 L
.244 .1607 L
.248 .16068 L
.252 .16065 L
.256 .16061 L
.26 .16057 L
.264 .16055 L
.268 .16055 L
.272 .16056 L
.276 .16058 L
.28 .16059 L
.284 .16059 L
.288 .16059 L
.292 .16058 L
.296 .16056 L
.3 .16053 L
.304 .16051 L
.308 .16049 L
.312 .16048 L
.316 .16047 L
.32 .16045 L
.324 .16044 L
.328 .16044 L
.332 .16044 L
.336 .16043 L
.34 .16043 L
.344 .16042 L
.348 .16044 L
.352 .16046 L
.356 .16046 L
.36 .16044 L
.364 .1604 L
.368 .16037 L
.372 .16033 L
.376 .1603 L
.38 .16027 L
.384 .16025 L
.388 .16025 L
.392 .16029 L
.396 .16034 L
.4 .16038 L
Mistroke
.404 .16037 L
.408 .16034 L
.412 .1603 L
.416 .16025 L
.42 .16021 L
.424 .16017 L
.428 .16016 L
.432 .16018 L
.436 .16023 L
.44 .1603 L
.444 .16032 L
.448 .16028 L
.452 .1602 L
.456 .1601 L
.46 .16004 L
.464 .16 L
.468 .15998 L
.472 .15997 L
.476 .16002 L
.48 .16014 L
.484 .16028 L
.488 .1604 L
.492 .16041 L
.496 .16031 L
.5 .16016 L
.504 .16002 L
.508 .15992 L
.512 .15984 L
.516 .15975 L
.52 .15968 L
.524 .15969 L
.528 .15981 L
.532 .16002 L
.536 .16021 L
.54 .16029 L
.544 .16025 L
.548 .16016 L
.552 .16009 L
.556 .16008 L
.56 .16005 L
.564 .15995 L
.568 .15976 L
.572 .15958 L
.576 .1595 L
.58 .15958 L
.584 .15974 L
.588 .15988 L
.592 .15994 L
.596 .15993 L
.6 .15994 L
Mistroke
.604 .16002 L
.608 .16016 L
.612 .16024 L
.616 .16018 L
.62 .15996 L
.624 .15964 L
.628 .15934 L
.632 .15916 L
.636 .15912 L
.64 .15919 L
.644 .15931 L
.648 .15946 L
.652 .15963 L
.656 .15986 L
.66 .16017 L
.664 .1605 L
.668 .16078 L
.672 .16091 L
.676 .16081 L
.68 .16046 L
.684 .1599 L
.688 .15924 L
.692 .15865 L
.696 .15825 L
.7 .15808 L
.704 .15813 L
.708 .15829 L
.712 .15848 L
.716 .15866 L
.72 .1589 L
.724 .1593 L
.728 .15991 L
.732 .16067 L
.736 .16138 L
.74 .16181 L
.744 .16183 L
.748 .16142 L
.752 .16078 L
.756 .16016 L
.76 .15976 L
.764 .15963 L
.768 .15966 L
.772 .15962 L
.776 .15932 L
.78 .15867 L
.784 .15777 L
.788 .15682 L
.792 .15604 L
.796 .15555 L
.8 .15536 L
Mistroke
.804 .15535 L
.808 .15539 L
.812 .15539 L
.816 .15531 L
.82 .15521 L
.824 .15518 L
.828 .15531 L
.832 .15566 L
.836 .15627 L
.84 .15719 L
.844 .15839 L
.848 .15985 L
.852 .16146 L
.856 .16305 L
.86 .16437 L
.864 .1652 L
.868 .16534 L
.872 .16477 L
.876 .16359 L
.88 .16206 L
.884 .16051 L
.888 .15923 L
.892 .1584 L
.896 .15805 L
.9 .15805 L
.904 .1582 L
.908 .15829 L
.912 .15815 L
.916 .15773 L
.92 .15709 L
.924 .15631 L
.928 .15554 L
.932 .15481 L
.936 .15416 L
.94 .1535 L
.944 .1528 L
.948 .15201 L
.952 .15119 L
.956 .15045 L
.96 .14998 L
.964 .15002 L
.968 .15073 L
.972 .15225 L
.976 .15457 L
.98 .15761 L
.984 .16123 L
.988 .16516 L
.992 .16928 L
.996 .17336 L
1 .17739 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008005ioo`8000eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0
GGoo0`0037oo000ROol2001MOol00`00Oomoo`0=Ool000]oo`8000Aoo`03001oogoo00=oo`80009o
o`D0009oo`03001oogoo05aoo`03001oogoo00eoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`000Woo0P00GGoo00<007ooOol03Goo0003Ool50002Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8005eoo`03001oogoo00eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000GGoo00<007ooOol03Woo000:Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool00`00Oomoo`02001FOol00`00Oomoo`03Ool00`00Oomoo`0>Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008005Eoo`03001oo`0000Aoo`03001o
ogoo00ioo`002goo0P002Woo0P000goo0`000goo00<007ooOol0E7oo00<007oo000017oo00<007oo
Ool03Woo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001EOol00`00Ool00004Ool0
0`00Oomoo`0>Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo
0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo1@000goo0P0017oo
0P000Woo00<007oo00001@0000Aoo`00000000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo00000Woo00@007oo
Ool000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=o
o`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool01000
Ool007oo0P000Woo0`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`06001oogoo001oo`000Woo0P000Woo
00<007ooOol00Woo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool00goo00D007ooOomoo`00009oo`04001oogoo0002Ool20003Ool01000Ool000001Goo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00
Oomoo`0;Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool01000Oomoogoo10000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`00
0Woo00<007ooOol00P000Woo0P000Woo00<007oo00000`000goo00@007ooOol000Eoo`002goo0P00
2Woo0P0017oo00<007ooOol00Woo0P0037oo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04
001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001o
ogooOol00002Ool01000Oomoo`000Woo00<007oo00000P000Woo00L007oo001oo`00Ool00006Ool0
1000Oomoo`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool0
1000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0`0017oo0`000Woo1@000goo0P001Woo000R
Ool00`00Oomoo`1@Ool00`00Oomoo`0IOol0029oo`80051oo`03001oogoo01Yoo`008WooH`0037oo
000ROol500001Goo00000000Ool01@0000Eoo`00000007oo0080009oo`07001oogoo001oo`00Ool0
0P000Woo0`0000]oo`00000007oo001oo`00Ool007oo00<0009oo`800003Ool007oo00800003Ool0
07oo009oo`03001oo`0000@00003Ool00000009oo`800003Ool0000000=oo`05001oogooOol00003
Ool01@00Oomoogoo000037oo000ROol300001Goo00000000Ool00P0000Eoo`00000007oo00800003
Ool0000000@00003Ool0000001800005Ool00000001oo`0<00000goo00000007000017oo000007oo
0P000Woo0P007Goo000ROol00`00Oomoo`13Ool01000Oomoo`000Woo0P008Goo000ROol2001]Ool0
029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]
Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007oo
Ool00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol0
00Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00
KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000
Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo0080
06eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P00
2Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo
000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0
009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo03Moo`8000=oo`@000Eoo`@001eoo`0047oo00@0
07ooOol000Qoo`04001oogoo0002Ool20004Oom00002Ool60004Ool3000JOol0015oo`8000Yoo`80
00Aoo`03001oogoo009oo`03001oogoo04]oo`8001Uoo`00:7oo00<007ooOol0C7oo0`005goo000X
Ool00`00Oomoo`1>Ool00`00Oomoo`0EOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=o
o`<000=oo`03001oogoo04moo`03001oogoo01Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000=oo`04001oogoo001BOol00`00Oomoo`0COol000=oo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001BOol2000DOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`80
00Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0
009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool0
10000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOomoo`@00003Ool007oo009oo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007oo
Ool007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomo
o`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0`001Goo00@007ooOol0009oo`03001oogoo
00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool00goo0`0017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo
00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomo
o`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
0goo1P000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol0
00Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006
Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004
Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo
0P001Woo000XOol00`00Oomoo`1GOol00`00Oomoo`0<Ool002Qoo`03001oogoo05Moo`8000eoo`00
:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?
Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004
Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo
0P000Woo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
4Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00
Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@0
07ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]
Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00
Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo
10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool2
0008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`80
00Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`80
00Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol0
0goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomo
o`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=
Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
1000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo
00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P00
0goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo
0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`80
00Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1N
Ool5000?Ool001aoofT000aoo`0077oo0P000Woo00D007ooOomoo`0000Aoo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo
00000goo00H007ooOomoo`00Ool30003Ool01@00Oomoogoo00000Woo0`0037oo000LOol00`00Oomo
o`1TOol2000<Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo
000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000
Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00
Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomo
o`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000G
Ool00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol00Woo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomo
o`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo0080
07=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04
Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo
000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(43587\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3175 m
.008 .31721 L
.012 .31863 L
.016 .31985 L
.02 .32005 L
.024 .31996 L
.028 .31945 L
.032 .31852 L
.036 .31807 L
.04 .31831 L
.044 .31896 L
.048 .31961 L
.052 .31968 L
.056 .3193 L
.06 .31872 L
.064 .31827 L
.068 .31844 L
.072 .31908 L
.076 .31983 L
.08 .32029 L
.084 .32004 L
.088 .31927 L
.092 .31841 L
.096 .31792 L
.1 .31817 L
.104 .31895 L
.108 .31984 L
.112 .32044 L
.116 .32034 L
.12 .31966 L
.124 .31881 L
.128 .31827 L
.132 .31837 L
.136 .31896 L
.14 .31971 L
.144 .32025 L
.148 .32026 L
.152 .31977 L
.156 .31904 L
.16 .31851 L
.164 .31855 L
.168 .31907 L
.172 .31974 L
.176 .32021 L
.18 .32028 L
.184 .31996 L
.188 .31937 L
.192 .31882 L
.196 .31866 L
.2 .319 L
Mistroke
.204 .31961 L
.208 .3201 L
.212 .32027 L
.216 .32018 L
.22 .3199 L
.224 .31946 L
.228 .31901 L
.232 .3188 L
.236 .31901 L
.24 .31952 L
.244 .32002 L
.248 .32035 L
.252 .32049 L
.256 .32043 L
.26 .32005 L
.264 .3194 L
.268 .31883 L
.272 .31877 L
.276 .31925 L
.28 .31988 L
.284 .32028 L
.288 .32037 L
.292 .32034 L
.296 .32024 L
.3 .32001 L
.304 .31966 L
.308 .31942 L
.312 .31947 L
.316 .3197 L
.32 .31984 L
.324 .31986 L
.328 .31998 L
.332 .32035 L
.336 .32073 L
.34 .32069 L
.344 .32011 L
.348 .31938 L
.352 .31902 L
.356 .31919 L
.36 .31963 L
.364 .32004 L
.368 .32039 L
.372 .32083 L
.376 .32131 L
.38 .32147 L
.384 .321 L
.388 .31997 L
.392 .31888 L
.396 .31832 L
.4 .31849 L
Mistroke
.404 .31919 L
.408 .32008 L
.412 .32099 L
.416 .32185 L
.42 .32245 L
.424 .32234 L
.428 .32126 L
.432 .31952 L
.436 .31802 L
.44 .31764 L
.444 .31848 L
.448 .31987 L
.452 .32097 L
.456 .32153 L
.46 .32193 L
.464 .32241 L
.468 .32255 L
.472 .32161 L
.476 .31953 L
.48 .31742 L
.484 .31682 L
.488 .31824 L
.492 .32062 L
.496 .3222 L
.5 .32224 L
.504 .32157 L
.508 .32155 L
.512 .32242 L
.516 .32291 L
.52 .32161 L
.524 .31872 L
.528 .31629 L
.532 .3164 L
.536 .31912 L
.54 .3223 L
.544 .32346 L
.548 .32213 L
.552 .32018 L
.556 .31994 L
.56 .32178 L
.564 .32375 L
.568 .32344 L
.572 .32051 L
.576 .31718 L
.58 .3163 L
.584 .31871 L
.588 .3224 L
.592 .32425 L
.596 .32283 L
.6 .31958 L
Mistroke
.604 .31752 L
.608 .31858 L
.612 .3219 L
.616 .3247 L
.62 .32468 L
.624 .32194 L
.628 .31878 L
.632 .3177 L
.636 .31935 L
.64 .32219 L
.644 .32382 L
.648 .32292 L
.652 .32015 L
.656 .3175 L
.66 .31672 L
.664 .31822 L
.668 .32106 L
.672 .3237 L
.676 .32501 L
.68 .32467 L
.684 .32308 L
.688 .32104 L
.692 .31945 L
.696 .31907 L
.7 .32017 L
.704 .32219 L
.708 .32381 L
.712 .32357 L
.716 .3209 L
.72 .31686 L
.724 .31382 L
.728 .31418 L
.732 .31857 L
.736 .32508 L
.74 .33006 L
.744 .33024 L
.748 .32493 L
.752 .3168 L
.756 .31047 L
.76 .30982 L
.764 .31552 L
.768 .32442 L
.772 .33131 L
.776 .33187 L
.78 .32526 L
.784 .31459 L
.788 .30517 L
.792 .30157 L
.796 .30504 L
.8 .31303 L
Mistroke
.804 .3206 L
.808 .32313 L
.812 .31857 L
.816 .30819 L
.82 .29553 L
.824 .28438 L
.828 .27697 L
.832 .27325 L
.836 .27146 L
.84 .26945 L
.844 .26582 L
.848 .26031 L
.852 .25339 L
.856 .24551 L
.86 .23671 L
.864 .22665 L
.868 .21547 L
.872 .20433 L
.876 .19568 L
.88 .19257 L
.884 .19726 L
.888 .21015 L
.892 .2288 L
.896 .24869 L
.9 .26418 L
.904 .27085 L
.908 .26668 L
.912 .25298 L
.916 .23389 L
.92 .21462 L
.924 .20033 L
.928 .19366 L
.932 .19535 L
.936 .20331 L
.94 .21474 L
.944 .22679 L
.948 .23742 L
.952 .24661 L
.956 .25434 L
.96 .26194 L
.964 .26925 L
.968 .27548 L
.972 .27929 L
.976 .27772 L
.98 .2703 L
.984 .25544 L
.988 .23528 L
.992 .21234 L
.996 .18949 L
1 .17178 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12343 m
.008 .1285 L
.012 .13014 L
.016 .12849 L
.02 .1279 L
.024 .12848 L
.028 .12865 L
.032 .12849 L
.036 .1284 L
.04 .12848 L
.044 .12849 L
.048 .12848 L
.052 .12846 L
.056 .12848 L
.06 .12847 L
.064 .12848 L
.068 .12847 L
.072 .12848 L
.076 .12847 L
.08 .12847 L
.084 .12846 L
.088 .12847 L
.092 .12847 L
.096 .12848 L
.1 .12848 L
.104 .1285 L
.108 .12849 L
.112 .12849 L
.116 .12847 L
.12 .12846 L
.124 .12845 L
.128 .12846 L
.132 .12847 L
.136 .12848 L
.14 .12849 L
.144 .1285 L
.148 .12849 L
.152 .12849 L
.156 .12848 L
.16 .12847 L
.164 .12847 L
.168 .12846 L
.172 .12846 L
.176 .12847 L
.18 .12848 L
.184 .12848 L
.188 .12849 L
.192 .12849 L
.196 .12849 L
.2 .12849 L
Mistroke
.204 .12848 L
.208 .12847 L
.212 .12846 L
.216 .12847 L
.22 .12847 L
.224 .12848 L
.228 .12849 L
.232 .1285 L
.236 .12849 L
.24 .12848 L
.244 .12846 L
.248 .12845 L
.252 .12845 L
.256 .12847 L
.26 .12849 L
.264 .1285 L
.268 .12852 L
.272 .12852 L
.276 .1285 L
.28 .12848 L
.284 .12845 L
.288 .12844 L
.292 .12845 L
.296 .12845 L
.3 .12847 L
.304 .12848 L
.308 .1285 L
.312 .12852 L
.316 .12852 L
.32 .12851 L
.324 .12849 L
.328 .12848 L
.332 .12848 L
.336 .12847 L
.34 .12847 L
.344 .12846 L
.348 .12847 L
.352 .12847 L
.356 .12847 L
.36 .12847 L
.364 .12847 L
.368 .12848 L
.372 .12851 L
.376 .12852 L
.38 .12853 L
.384 .12852 L
.388 .12851 L
.392 .1285 L
.396 .12848 L
.4 .12845 L
Mistroke
.404 .12842 L
.408 .12841 L
.412 .12842 L
.416 .12847 L
.42 .12851 L
.424 .12854 L
.428 .12855 L
.432 .12854 L
.436 .12853 L
.44 .12851 L
.444 .12847 L
.448 .12843 L
.452 .12841 L
.456 .12844 L
.46 .1285 L
.464 .12856 L
.468 .12859 L
.472 .12857 L
.476 .12852 L
.48 .12847 L
.484 .12843 L
.488 .12839 L
.492 .12835 L
.496 .12833 L
.5 .12837 L
.504 .12848 L
.508 .12862 L
.512 .12872 L
.516 .12874 L
.52 .12869 L
.524 .12861 L
.528 .12854 L
.532 .12847 L
.536 .12838 L
.54 .12828 L
.544 .12819 L
.548 .1282 L
.552 .12831 L
.556 .12848 L
.56 .12863 L
.564 .1287 L
.568 .12869 L
.572 .12866 L
.576 .12866 L
.58 .12868 L
.584 .12866 L
.588 .12856 L
.592 .1284 L
.596 .12825 L
.6 .12821 L
Mistroke
.604 .12827 L
.608 .12838 L
.612 .12847 L
.616 .1285 L
.62 .1285 L
.624 .12854 L
.628 .12864 L
.632 .12879 L
.636 .12888 L
.64 .12886 L
.644 .1287 L
.648 .12847 L
.652 .12825 L
.656 .1281 L
.66 .12804 L
.664 .12806 L
.668 .12811 L
.672 .12818 L
.676 .1283 L
.68 .12849 L
.684 .12874 L
.688 .12904 L
.692 .12933 L
.696 .12952 L
.7 .12954 L
.704 .12934 L
.708 .12895 L
.712 .12846 L
.716 .12797 L
.72 .12762 L
.724 .12745 L
.728 .12744 L
.732 .12751 L
.736 .1276 L
.74 .12769 L
.744 .12785 L
.748 .12817 L
.752 .12869 L
.756 .12937 L
.76 .13006 L
.764 .13055 L
.768 .13073 L
.772 .13057 L
.776 .13021 L
.78 .12986 L
.784 .12968 L
.788 .12973 L
.792 .12994 L
.796 .13015 L
.8 .13022 L
Mistroke
.804 .13007 L
.808 .12978 L
.812 .1295 L
.816 .12941 L
.82 .12962 L
.824 .13017 L
.828 .13102 L
.832 .1321 L
.836 .13336 L
.84 .13478 L
.844 .1364 L
.848 .13828 L
.852 .1405 L
.856 .14312 L
.86 .14617 L
.864 .14968 L
.868 .15367 L
.872 .15811 L
.876 .16291 L
.88 .16791 L
.884 .1729 L
.888 .17763 L
.892 .18191 L
.896 .18565 L
.9 .18891 L
.904 .19187 L
.908 .19479 L
.912 .19797 L
.916 .2016 L
.92 .20579 L
.924 .21047 L
.928 .21551 L
.932 .22069 L
.936 .22583 L
.94 .2308 L
.944 .23551 L
.948 .23998 L
.952 .24422 L
.956 .24824 L
.96 .25209 L
.964 .25575 L
.968 .25926 L
.972 .26264 L
.976 .26603 L
.98 .26955 L
.984 .27334 L
.988 .27761 L
.992 .28238 L
.996 .28774 L
1 .29356 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16132 L
.012 .16139 L
.016 .16118 L
.02 .16106 L
.024 .1611 L
.028 .1612 L
.032 .16114 L
.036 .16114 L
.04 .16114 L
.044 .16117 L
.048 .16112 L
.052 .16109 L
.056 .16105 L
.06 .16105 L
.064 .16104 L
.068 .16107 L
.072 .16106 L
.076 .16107 L
.08 .16104 L
.084 .16102 L
.088 .161 L
.092 .16099 L
.096 .16098 L
.1 .16099 L
.104 .16099 L
.108 .16098 L
.112 .16096 L
.116 .16094 L
.12 .16092 L
.124 .16091 L
.128 .16091 L
.132 .16091 L
.136 .16091 L
.14 .16091 L
.144 .1609 L
.148 .16089 L
.152 .16087 L
.156 .16086 L
.16 .16084 L
.164 .16083 L
.168 .16081 L
.172 .16081 L
.176 .1608 L
.18 .1608 L
.184 .1608 L
.188 .1608 L
.192 .16079 L
.196 .16078 L
.2 .16076 L
Mistroke
.204 .16074 L
.208 .16072 L
.212 .16071 L
.216 .16071 L
.22 .16072 L
.224 .16072 L
.228 .16071 L
.232 .1607 L
.236 .16067 L
.24 .16065 L
.244 .16062 L
.248 .16061 L
.252 .16062 L
.256 .16063 L
.26 .16063 L
.264 .16063 L
.268 .16063 L
.272 .16062 L
.276 .1606 L
.28 .16057 L
.284 .16053 L
.288 .16051 L
.292 .1605 L
.296 .1605 L
.3 .16051 L
.304 .16052 L
.308 .16053 L
.312 .16054 L
.316 .16053 L
.32 .16051 L
.324 .16048 L
.328 .16046 L
.332 .16045 L
.336 .16043 L
.34 .16041 L
.344 .16039 L
.348 .16039 L
.352 .16039 L
.356 .16038 L
.36 .16037 L
.364 .16036 L
.368 .16036 L
.372 .16037 L
.376 .16039 L
.38 .1604 L
.384 .16039 L
.388 .16036 L
.392 .16033 L
.396 .16029 L
.4 .16024 L
Mistroke
.404 .1602 L
.408 .16018 L
.412 .16019 L
.416 .16023 L
.42 .16028 L
.424 .1603 L
.428 .1603 L
.432 .16029 L
.436 .16026 L
.44 .16022 L
.444 .16017 L
.448 .16011 L
.452 .16008 L
.456 .16011 L
.46 .16017 L
.464 .16024 L
.468 .16026 L
.472 .16022 L
.476 .16016 L
.48 .16009 L
.484 .16003 L
.488 .15997 L
.492 .1599 L
.496 .15986 L
.5 .15991 L
.504 .16004 L
.508 .1602 L
.512 .16032 L
.516 .16033 L
.52 .16026 L
.524 .16015 L
.528 .16005 L
.532 .15996 L
.536 .15984 L
.54 .1597 L
.544 .15959 L
.548 .15958 L
.552 .15971 L
.556 .15992 L
.56 .1601 L
.564 .16016 L
.568 .16014 L
.572 .16009 L
.576 .16009 L
.58 .1601 L
.584 .16007 L
.588 .15993 L
.592 .15972 L
.596 .15953 L
.6 .15947 L
Mistroke
.604 .15954 L
.608 .15967 L
.612 .15976 L
.616 .15979 L
.62 .15978 L
.624 .15982 L
.628 .15995 L
.632 .16011 L
.636 .16022 L
.64 .16018 L
.644 .15998 L
.648 .15968 L
.652 .15939 L
.656 .1592 L
.66 .15912 L
.664 .15912 L
.668 .15917 L
.672 .15926 L
.676 .1594 L
.68 .15961 L
.684 .15992 L
.688 .16028 L
.692 .16063 L
.696 .16085 L
.7 .16086 L
.704 .16059 L
.708 .16009 L
.712 .15945 L
.716 .15883 L
.72 .15836 L
.724 .15812 L
.728 .15807 L
.732 .15812 L
.736 .15819 L
.74 .15826 L
.744 .1584 L
.748 .15873 L
.752 .1593 L
.756 .16006 L
.76 .16081 L
.764 .1613 L
.768 .16137 L
.772 .161 L
.776 .16035 L
.78 .15966 L
.784 .15914 L
.788 .15885 L
.792 .1587 L
.796 .15846 L
.8 .15794 L
Mistroke
.804 .15703 L
.808 .15579 L
.812 .15438 L
.816 .15299 L
.82 .15173 L
.824 .1506 L
.828 .14951 L
.832 .14833 L
.836 .14694 L
.84 .14529 L
.844 .1434 L
.848 .14132 L
.852 .13915 L
.856 .13695 L
.86 .13482 L
.864 .13285 L
.868 .13112 L
.872 .1297 L
.876 .1286 L
.88 .12774 L
.884 .12696 L
.888 .12608 L
.892 .12495 L
.896 .12351 L
.9 .12184 L
.904 .12017 L
.908 .11874 L
.912 .11782 L
.916 .11752 L
.92 .11785 L
.924 .11861 L
.928 .11954 L
.932 .12034 L
.936 .12078 L
.94 .12078 L
.944 .12033 L
.948 .11957 L
.952 .11863 L
.956 .11764 L
.96 .11669 L
.964 .11574 L
.968 .11481 L
.972 .11385 L
.976 .1129 L
.98 .11208 L
.984 .11154 L
.988 .11159 L
.992 .11235 L
.996 .11411 L
1 .11686 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001POol00`00Oomoo`0:Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0
00=oo`03001oogoo0080061oo`03001oogoo00Yoo`002goo0P002Woo0P000goo0`000goo00<007oo
Ool0DWoo0P0017oo00<007ooOol00goo00<007ooOol02goo000;Ool20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool2001COol20003Ool20005Ool00`00Oomoo`0;Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo
0`000goo0`0017oo0P000goo1@000goo0P0017oo0`0000=oo`00Ool01@000Woo0`0017oo0P001Woo
0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]o
o`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomo
o`000Woo00D007ooOol007oo00800006Ool007ooOol007oo0P0000Ioo`00Ool007oo0002Ool01000
Oomoo`001Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04
001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00T007oo000007oo001oo`00Ool00P000goo00@007ooOol0009oo`04001oogoo0005Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00=oo`05001oogooOol00002Ool01@00Oomoo`00Ool00P0000Ao
o`00Ool0009oo`80009oo`04001oogoo0002Ool01000Oomoo`001Goo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`03001oogoo00]oo`@000=oo`04001oogoo0007Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`000Woo00D0
07ooOomoo`00009oo`04001oogoo0002Ool200001Woo001oo`00Ool000=oo`03001oo`0000<000=o
o`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Ao
o`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo
00Aoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`800004Ool007ooOol2
0003Ool40005Ool01000Oomoo`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool2
0004Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P000Woo10000goo00<007oo0000
0P0000=oo`00000010000goo0P001Woo000ROol00`00Oomoo`1=Ool00`00Oomoo`0<Ool00`00Oomo
o`0=Ool0029oo`8004ioo`03001oogoo01aoo`008WooH`0037oo000ROol2000017oo000007oo1@00
00Aoo`00001oo`<00004Ool00000Ool300000goo00000003Ool00`00Oomoo`020002Ool30002Ool0
1000Oomoogoo0P000Woo0P000Woo0`0000=oo`00Ool00P0000Moo`00000007oo001oo`0200001Goo
00000000Ool00`000Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`0:Ool0
029oo`@00005Ool007ooOol00002Ool2000017oo000007oo0P0000Eoo`00000007oo00l00005Ool0
0000001oo`0800000goo0000000@000017oo000007oo0P0000=oo`0000007goo000ROol00`00Oomo
o`15Ool200000goo0000000ROol0029oo`8006eoo`008Woo0P00KGoo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol0
0Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`00
0goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomo
o`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007oo
Ool006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007oo
Ool007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`80
06eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3
001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo
06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00
Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1V
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0
IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03
Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0?goo0P009Goo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aood<00003Ool00000
00T001Yoo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0Bgoo0P006Goo000XOol0
0`00Oomoo`1<Ool2000HOol002Qoo`03001oogoo04eoo`8001Moo`002goo0P0017oo00<007ooOol0
0goo0P0017oo0P000goo0`000goo00<007ooOol0CWoo0P005Woo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`06001oogoo001oo`000goo00@007ooOol0055oo`8001Eoo`000goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0059oo`8001Aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo
0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo
1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001o
o`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoogoo100000=oo`00Ool00Woo
00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00
Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomo
ogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool20006Ool01000Oomoo`000Woo00<007oo
Ool00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00
Oomoo`03Ool20005Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003
Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomo
ogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0003Ool60003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomo
o`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00
Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oo`00
0005Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool2
0004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@00
0goo0P001Woo000XOol00`00Oomoo`1HOol00`00Oomoo`0;Ool002Qoo`03001oogoo05Uoo`03001o
ogoo00Yoo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool0
0`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo06Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo0P00
2Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool2
0004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo
00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool0
0`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo
000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000
Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00
Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uo
o`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009o
o`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo
00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol0
07oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`00
0Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@
Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo
000LOol2000=Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomo
o`000Woo00@007ooOol000Aoo`04001oogooOol60003Ool01000Oomoo`001Goo000LOol00`00Oomo
o`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004
Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002
Ool01000Oomoo`000Woo2@000Woo00D007ooOomoo`00009oo`03001oogoo00=oo`0077oo0P003Goo
1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<0
00Aoo`8000Aoo`D000=oo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0E7oo0`006goo000L
Ool00`00Oomoo`1BOol3000MOol001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo
009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo
009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00
Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<0
07ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol0
00]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1b
Ool001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol0
0`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P00
17oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo
00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`00
2goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomo
o`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@00
0Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(43754\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31779 m
.008 .31853 L
.012 .31912 L
.016 .31903 L
.02 .31818 L
.024 .31812 L
.028 .31899 L
.032 .31935 L
.036 .31919 L
.04 .31914 L
.044 .31909 L
.048 .31907 L
.052 .31902 L
.056 .31895 L
.06 .31902 L
.064 .31907 L
.068 .31907 L
.072 .3191 L
.076 .31903 L
.08 .31897 L
.084 .31894 L
.088 .31894 L
.092 .3191 L
.096 .31935 L
.1 .31957 L
.104 .31965 L
.108 .31945 L
.112 .31911 L
.116 .31877 L
.12 .31858 L
.124 .31871 L
.128 .31915 L
.132 .3197 L
.136 .32007 L
.14 .32002 L
.144 .3196 L
.148 .31903 L
.152 .31858 L
.156 .31848 L
.16 .31884 L
.164 .31951 L
.168 .32018 L
.172 .32042 L
.176 .32011 L
.18 .31943 L
.184 .31877 L
.188 .31845 L
.192 .3186 L
.196 .31922 L
.2 .32003 L
Mistroke
.204 .32058 L
.208 .3205 L
.212 .31984 L
.216 .31906 L
.22 .31863 L
.224 .31872 L
.228 .31922 L
.232 .31989 L
.236 .32044 L
.24 .32057 L
.244 .32015 L
.248 .31942 L
.252 .31886 L
.256 .31882 L
.26 .31921 L
.264 .31968 L
.268 .32003 L
.272 .32027 L
.276 .32041 L
.28 .32031 L
.284 .31992 L
.288 .31944 L
.292 .31919 L
.296 .31926 L
.3 .31947 L
.304 .31968 L
.308 .31992 L
.312 .32023 L
.316 .32047 L
.32 .32038 L
.324 .31998 L
.328 .31959 L
.332 .31954 L
.336 .31978 L
.34 .31995 L
.344 .31985 L
.348 .31971 L
.352 .31984 L
.356 .32028 L
.36 .32067 L
.364 .32067 L
.368 .32029 L
.372 .31981 L
.376 .31948 L
.38 .31932 L
.384 .31929 L
.388 .31948 L
.392 .32005 L
.396 .3209 L
.4 .32163 L
Mistroke
.404 .32175 L
.408 .32111 L
.412 .32006 L
.416 .31915 L
.42 .31871 L
.424 .31871 L
.428 .31898 L
.432 .3195 L
.436 .32043 L
.44 .32169 L
.444 .3227 L
.448 .32273 L
.452 .32151 L
.456 .31967 L
.46 .31833 L
.464 .31814 L
.468 .31883 L
.472 .31961 L
.476 .32009 L
.48 .32061 L
.484 .32167 L
.488 .32298 L
.492 .32343 L
.496 .32212 L
.5 .31954 L
.504 .31738 L
.508 .31714 L
.512 .31874 L
.516 .32062 L
.52 .32134 L
.524 .32099 L
.528 .3209 L
.532 .32202 L
.536 .32359 L
.54 .32378 L
.544 .32161 L
.548 .31824 L
.552 .31621 L
.556 .31711 L
.56 .32004 L
.564 .32242 L
.568 .32242 L
.572 .32062 L
.576 .31941 L
.58 .32049 L
.584 .3231 L
.588 .32467 L
.592 .3233 L
.596 .31968 L
.6 .31665 L
Mistroke
.604 .31672 L
.608 .31977 L
.612 .32317 L
.616 .32408 L
.62 .3219 L
.624 .31872 L
.628 .31743 L
.632 .31921 L
.636 .32259 L
.64 .32479 L
.644 .32411 L
.648 .32123 L
.652 .31853 L
.656 .31808 L
.66 .32002 L
.664 .32267 L
.668 .32391 L
.672 .32282 L
.676 .32018 L
.68 .31772 L
.684 .31688 L
.688 .318 L
.692 .32036 L
.696 .32278 L
.7 .32425 L
.704 .32427 L
.708 .32288 L
.712 .3207 L
.716 .31876 L
.72 .31815 L
.724 .3194 L
.728 .3219 L
.732 .32395 L
.736 .32367 L
.74 .32034 L
.744 .31519 L
.748 .31103 L
.752 .31059 L
.756 .31458 L
.76 .32089 L
.764 .32545 L
.768 .3247 L
.772 .31782 L
.776 .3075 L
.78 .29855 L
.784 .29502 L
.788 .29765 L
.792 .3033 L
.796 .30663 L
.8 .3031 L
Mistroke
.804 .2916 L
.808 .27505 L
.812 .25877 L
.816 .24758 L
.82 .24335 L
.824 .24419 L
.828 .24586 L
.832 .24417 L
.836 .23724 L
.84 .22627 L
.844 .21471 L
.848 .20637 L
.852 .20366 L
.856 .20688 L
.86 .21448 L
.864 .22434 L
.868 .23458 L
.872 .24417 L
.876 .25237 L
.88 .25839 L
.884 .26095 L
.888 .25866 L
.892 .25101 L
.896 .23884 L
.9 .22519 L
.904 .21387 L
.908 .20894 L
.912 .21237 L
.916 .22354 L
.92 .23909 L
.924 .25376 L
.928 .26293 L
.932 .26324 L
.936 .25493 L
.94 .24065 L
.944 .22491 L
.948 .21286 L
.952 .20732 L
.956 .21029 L
.96 .22017 L
.964 .23502 L
.968 .25226 L
.972 .26916 L
.976 .28582 L
.98 .30065 L
.984 .3152 L
.988 .32847 L
.992 .3397 L
.996 .34809 L
1 .35017 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12817 m
.008 .12884 L
.012 .12909 L
.016 .12905 L
.02 .12887 L
.024 .12887 L
.028 .12893 L
.032 .12899 L
.036 .12894 L
.04 .12894 L
.044 .12892 L
.048 .12892 L
.052 .1289 L
.056 .12892 L
.06 .12893 L
.064 .12895 L
.068 .12895 L
.072 .12895 L
.076 .12893 L
.08 .12893 L
.084 .12892 L
.088 .12893 L
.092 .12893 L
.096 .12894 L
.1 .12894 L
.104 .12893 L
.108 .12892 L
.112 .12892 L
.116 .12892 L
.12 .12893 L
.124 .12894 L
.128 .12895 L
.132 .12895 L
.136 .12894 L
.14 .12893 L
.144 .12892 L
.148 .12891 L
.152 .12892 L
.156 .12892 L
.16 .12894 L
.164 .12894 L
.168 .12895 L
.172 .12895 L
.176 .12894 L
.18 .12894 L
.184 .12893 L
.188 .12892 L
.192 .12892 L
.196 .12891 L
.2 .12892 L
Mistroke
.204 .12893 L
.208 .12894 L
.212 .12895 L
.216 .12896 L
.22 .12895 L
.224 .12894 L
.228 .12892 L
.232 .12892 L
.236 .12892 L
.24 .12893 L
.244 .12894 L
.248 .12895 L
.252 .12895 L
.256 .12895 L
.26 .12894 L
.264 .12893 L
.268 .12892 L
.272 .12891 L
.276 .12891 L
.28 .12892 L
.284 .12894 L
.288 .12896 L
.292 .12897 L
.296 .12897 L
.3 .12896 L
.304 .12894 L
.308 .12892 L
.312 .12891 L
.316 .1289 L
.32 .12891 L
.324 .12892 L
.328 .12893 L
.332 .12895 L
.336 .12897 L
.34 .12897 L
.344 .12897 L
.348 .12896 L
.352 .12895 L
.356 .12894 L
.36 .12893 L
.364 .12892 L
.368 .12892 L
.372 .12893 L
.376 .12893 L
.38 .12893 L
.384 .12892 L
.388 .12892 L
.392 .12893 L
.396 .12895 L
.4 .12897 L
Mistroke
.404 .12898 L
.408 .12898 L
.412 .12899 L
.416 .12898 L
.42 .12895 L
.424 .12891 L
.428 .12888 L
.432 .12886 L
.436 .12888 L
.44 .12892 L
.444 .12895 L
.448 .12898 L
.452 .129 L
.456 .12901 L
.46 .129 L
.464 .12898 L
.468 .12893 L
.472 .12888 L
.476 .12887 L
.48 .1289 L
.484 .12895 L
.488 .12901 L
.492 .12903 L
.496 .12902 L
.5 .129 L
.504 .12897 L
.508 .12893 L
.512 .12886 L
.516 .12879 L
.52 .12875 L
.524 .1288 L
.528 .12891 L
.532 .12905 L
.536 .12914 L
.54 .12917 L
.544 .12914 L
.548 .12911 L
.552 .12907 L
.556 .129 L
.56 .12888 L
.564 .12874 L
.568 .12864 L
.572 .12864 L
.576 .12875 L
.58 .12891 L
.584 .12903 L
.588 .12908 L
.592 .12909 L
.596 .12911 L
.6 .12915 L
Mistroke
.604 .12919 L
.608 .12916 L
.612 .12904 L
.616 .12888 L
.62 .12874 L
.624 .1287 L
.628 .12875 L
.632 .12883 L
.636 .12888 L
.64 .12889 L
.644 .12889 L
.648 .12895 L
.652 .12908 L
.656 .12924 L
.66 .12935 L
.664 .12935 L
.668 .12922 L
.672 .12902 L
.676 .12882 L
.68 .12866 L
.684 .12858 L
.688 .12855 L
.692 .12856 L
.696 .1286 L
.7 .12869 L
.704 .12885 L
.708 .12911 L
.712 .12944 L
.716 .12978 L
.72 .13007 L
.724 .1302 L
.728 .13011 L
.732 .12981 L
.736 .12938 L
.74 .12895 L
.744 .12863 L
.748 .12848 L
.752 .12849 L
.756 .12858 L
.76 .12871 L
.764 .12886 L
.768 .12911 L
.772 .12958 L
.776 .13033 L
.78 .13132 L
.784 .13242 L
.788 .13343 L
.792 .13422 L
.796 .13478 L
.8 .13524 L
Mistroke
.804 .13579 L
.808 .13664 L
.812 .13786 L
.816 .13941 L
.82 .14115 L
.824 .14293 L
.828 .14467 L
.832 .14639 L
.836 .14819 L
.84 .15021 L
.844 .1525 L
.848 .15506 L
.852 .15782 L
.856 .16063 L
.86 .1634 L
.864 .16605 L
.868 .16856 L
.872 .17097 L
.876 .17331 L
.88 .17567 L
.884 .17813 L
.888 .18082 L
.892 .18385 L
.896 .18731 L
.9 .19122 L
.904 .19551 L
.908 .20005 L
.912 .20458 L
.916 .20892 L
.92 .21289 L
.924 .21647 L
.928 .21974 L
.932 .22291 L
.936 .22621 L
.94 .22984 L
.944 .23391 L
.948 .23841 L
.952 .24322 L
.956 .24818 L
.96 .25304 L
.964 .25771 L
.968 .26202 L
.972 .26596 L
.976 .2695 L
.98 .27266 L
.984 .27546 L
.988 .27787 L
.992 .28002 L
.996 .28188 L
1 .28363 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15759 L
.012 .16124 L
.016 .16239 L
.02 .16119 L
.024 .16074 L
.028 .16116 L
.032 .16126 L
.036 .16113 L
.04 .16106 L
.044 .16111 L
.048 .16111 L
.052 .1611 L
.056 .16108 L
.06 .1611 L
.064 .16108 L
.068 .16108 L
.072 .16105 L
.076 .16104 L
.08 .16101 L
.084 .16101 L
.088 .161 L
.092 .16101 L
.096 .161 L
.1 .161 L
.104 .16098 L
.108 .16096 L
.112 .16094 L
.116 .16093 L
.12 .16093 L
.124 .16094 L
.128 .16093 L
.132 .16093 L
.136 .16091 L
.14 .16089 L
.144 .16087 L
.148 .16085 L
.152 .16084 L
.156 .16085 L
.16 .16085 L
.164 .16085 L
.168 .16084 L
.172 .16083 L
.176 .16082 L
.18 .1608 L
.184 .16079 L
.188 .16077 L
.192 .16076 L
.196 .16075 L
.2 .16075 L
Mistroke
.204 .16074 L
.208 .16073 L
.212 .16073 L
.216 .16073 L
.22 .16072 L
.224 .16071 L
.228 .16069 L
.232 .16067 L
.236 .16066 L
.24 .16064 L
.244 .16064 L
.248 .16064 L
.252 .16065 L
.256 .16065 L
.26 .16063 L
.264 .1606 L
.268 .16057 L
.272 .16056 L
.276 .16055 L
.28 .16055 L
.284 .16056 L
.288 .16057 L
.292 .16058 L
.296 .16057 L
.3 .16055 L
.304 .16052 L
.308 .16049 L
.312 .16046 L
.316 .16044 L
.32 .16043 L
.324 .16043 L
.328 .16045 L
.332 .16047 L
.336 .16048 L
.34 .16047 L
.344 .16045 L
.348 .16043 L
.352 .16041 L
.356 .1604 L
.36 .16038 L
.364 .16036 L
.368 .16034 L
.372 .16033 L
.376 .16033 L
.38 .16031 L
.384 .1603 L
.388 .1603 L
.392 .16031 L
.396 .16032 L
.4 .16033 L
Mistroke
.404 .16033 L
.408 .16033 L
.412 .16032 L
.416 .1603 L
.42 .16026 L
.424 .1602 L
.428 .16014 L
.432 .16012 L
.436 .16013 L
.44 .16016 L
.444 .1602 L
.448 .16022 L
.452 .16023 L
.456 .16024 L
.46 .16023 L
.464 .16019 L
.468 .16011 L
.472 .16004 L
.476 .16001 L
.48 .16004 L
.484 .16011 L
.488 .16017 L
.492 .16018 L
.496 .16016 L
.5 .16012 L
.504 .16008 L
.508 .16002 L
.512 .15993 L
.516 .15982 L
.52 .15977 L
.524 .15981 L
.528 .15995 L
.532 .16011 L
.536 .16022 L
.54 .16024 L
.544 .1602 L
.548 .16014 L
.552 .16008 L
.556 .15999 L
.56 .15984 L
.564 .15965 L
.568 .15951 L
.572 .1595 L
.576 .15963 L
.58 .15982 L
.584 .15997 L
.588 .16002 L
.592 .16002 L
.596 .16003 L
.6 .16007 L
Mistroke
.604 .16011 L
.608 .16007 L
.612 .15991 L
.616 .15969 L
.62 .15951 L
.624 .15945 L
.628 .15951 L
.632 .1596 L
.636 .15965 L
.64 .15964 L
.644 .15963 L
.648 .1597 L
.652 .15985 L
.656 .16004 L
.66 .16017 L
.664 .16015 L
.668 .15998 L
.672 .15971 L
.676 .15944 L
.68 .15923 L
.684 .1591 L
.688 .15905 L
.692 .15903 L
.696 .15905 L
.7 .15913 L
.704 .1593 L
.708 .15958 L
.712 .15994 L
.716 .16032 L
.72 .16061 L
.724 .16069 L
.728 .16049 L
.732 .16002 L
.736 .15937 L
.74 .15868 L
.744 .15811 L
.748 .15773 L
.752 .15751 L
.756 .15735 L
.76 .15717 L
.764 .15695 L
.768 .15679 L
.772 .1568 L
.776 .15704 L
.78 .15743 L
.784 .15779 L
.788 .15783 L
.792 .15736 L
.796 .15633 L
.8 .15484 L
Mistroke
.804 .15312 L
.808 .15135 L
.812 .1496 L
.816 .14777 L
.82 .14568 L
.824 .14312 L
.828 .14 L
.832 .13637 L
.836 .13241 L
.84 .12834 L
.844 .12434 L
.848 .1205 L
.852 .11683 L
.856 .11331 L
.86 .1099 L
.864 .10662 L
.868 .10351 L
.872 .10064 L
.876 .09806 L
.88 .09583 L
.884 .09396 L
.888 .09249 L
.892 .09142 L
.896 .09076 L
.9 .09043 L
.904 .09028 L
.908 .09012 L
.912 .0897 L
.916 .08884 L
.92 .08745 L
.924 .08563 L
.928 .0836 L
.932 .08168 L
.936 .08019 L
.94 .07934 L
.944 .07922 L
.948 .0797 L
.952 .08057 L
.956 .08157 L
.96 .08244 L
.964 .0831 L
.968 .08348 L
.972 .08374 L
.976 .084 L
.98 .08437 L
.984 .08495 L
.988 .08567 L
.992 .08655 L
.996 .08744 L
1 .08836 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001AOol00`00Oomoo`0IOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo
0`0017oo0P000goo1@000goo0P000goo0`000goo1P000Woo0`0017oo0P001Woo0003Ool50002Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol0
0002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00
Oomoogoo00000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00D007oo
Ool007oo0080009oo`<00003Ool00000008000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0Woo0P0000Eoo`00001oo`0000Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00=oo`05001oogooOol00002Ool40002Ool00`00Ool00002Ool01@00Ool007oo
000017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool00`00Oomoo`0;Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol0009oo`05001oogooOol00002
Ool00`00Oomoo`02000027oo001oogoo001oo`00Ool300000goo000000040003Ool01000Oomoo`00
1Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`00
1Woo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomo
o`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`0300001Goo001oo`00Ool0
0`001Woo00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo
0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`<000=oo`8000Eoo`<0009oo`D000=oo`80
00Ioo`008Woo00<007ooOol0C7oo00<007ooOol03Goo00<007ooOol03Goo000ROol2001:Ool3000@
Ool00`00Oomoo`0=Ool0029oof<000aoo`008Woo2P0000Eoo`00000007oo00800003Ool0000000<0
0009Ool00000Ool007oo001oo`0000=oo`03001oogoo00800005Ool00000001oo`03000017oo0000
00000Woo0P000goo00L007oo000007oo001oo`020002Ool00`00Oomoo`030002Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oo`00Ool0000<Ool0029oo`800003Ool007oo00Eoo`80
0004Ool00000Ool3000017oo000007oo0P0000=oo`0000003@0000=oo`0000002P0000=oo`000000
2P0000=oo`0000000`0000=oo`00000057oo00<007ooOol037oo000ROol00`00Oomoo`1NOol00`00
Oomoo`0;Ool0029oo`8005moo`03001oogoo00]oo`008Woo0P00H7oo00<007ooOol02Woo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P00
17oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo
0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo
06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]
Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2
001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06ao
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`00
00=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo
00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003
Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0
17oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004
Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aood/001io
o`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0B7oo0`006goo000XOol00`00Oomo
o`1:Ool2000JOol002Qoo`03001oogoo04]oo`<001Qoo`002goo0P0017oo00<007ooOol00goo0P00
17oo0P000goo0`000goo00<007ooOol0CGoo0P005goo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`06001oogoo001oo`000goo00@007ooOol0055oo`03001oogoo01Aoo`000goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0059oo`03001oogoo01=o
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo
0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo
0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001o
ogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoogoo0P0000Aoo`00
Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P001Woo00@007ooOol0009o
o`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007oo
Ool0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`00
0Woo00<007ooOol00goo0P001Goo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol0
2Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`000goo1P000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo
00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol0
17oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomo
o`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`00
0Woo1@000goo0P001Woo000XOol00`00Oomoo`1HOol2000<Ool002Qoo`03001oogoo06Ioo`00:7oo
G@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool0
0`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool0
0`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P00
0Woo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo
0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomo
o`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo
0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007oo
Oomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool0
00]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomo
o`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo1000
0goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008
Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Ao
o`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Io
o`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo1`000Woo00@007ooOol0009oo`03
001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01@00Oomoo`00Ool0100000=oo`00Ool017oo
0`000Woo00@007ooOol000Eoo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo0P001Woo00<007ooOol0
17oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo
0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oo`000004Ool01P00Oomoogoo001o
o`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008
Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo
0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`800003Ool007oo00=oo`07001oogooOol0
07oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P00
17oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000=oo`<000Ioo`<0009oo`D000=o
o`8000Ioo`0077oo00<007ooOol0DWoo0P007Woo000LOol00`00Oomoo`1@Ool3000OOol001aoofT0
00aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo
000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol0
00]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001o
ogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001c
Ool000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo
079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Mo
o`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo
009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079o
o`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00
Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Ao
o`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(43921\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31907 m
.008 .31967 L
.012 .31888 L
.016 .31833 L
.02 .31845 L
.024 .31868 L
.028 .31911 L
.032 .31963 L
.036 .31962 L
.04 .31913 L
.044 .31848 L
.048 .31806 L
.052 .31821 L
.056 .31873 L
.06 .31941 L
.064 .3199 L
.068 .31984 L
.072 .31935 L
.076 .31872 L
.08 .31829 L
.084 .31839 L
.088 .31886 L
.092 .31942 L
.096 .3198 L
.1 .31971 L
.104 .31927 L
.108 .31875 L
.112 .31848 L
.116 .31869 L
.12 .31921 L
.124 .31971 L
.128 .31994 L
.132 .31973 L
.136 .31921 L
.14 .31868 L
.144 .31846 L
.148 .31876 L
.152 .31938 L
.156 .31996 L
.16 .32017 L
.164 .31992 L
.168 .31936 L
.172 .31877 L
.176 .31846 L
.18 .31865 L
.184 .31926 L
.188 .31994 L
.192 .32033 L
.196 .32024 L
.2 .31983 L
Mistroke
.204 .31929 L
.208 .31882 L
.212 .31861 L
.216 .3188 L
.22 .31936 L
.224 .32001 L
.228 .32038 L
.232 .32034 L
.236 .31998 L
.24 .31948 L
.244 .31899 L
.248 .31873 L
.252 .31891 L
.256 .31956 L
.26 .32029 L
.264 .32063 L
.268 .32037 L
.272 .31978 L
.276 .31926 L
.28 .31899 L
.284 .31901 L
.288 .31931 L
.292 .31982 L
.296 .32035 L
.3 .32055 L
.304 .32033 L
.308 .3199 L
.312 .31963 L
.316 .31958 L
.32 .31956 L
.324 .31944 L
.328 .31939 L
.332 .31965 L
.336 .32014 L
.34 .3205 L
.344 .32048 L
.348 .32018 L
.352 .31992 L
.356 .31982 L
.36 .31977 L
.364 .31965 L
.368 .31956 L
.372 .31971 L
.376 .32011 L
.38 .3205 L
.384 .32064 L
.388 .32051 L
.392 .3203 L
.396 .32011 L
.4 .31986 L
Mistroke
.404 .31947 L
.408 .3191 L
.412 .31914 L
.416 .31981 L
.42 .32085 L
.424 .32168 L
.428 .32179 L
.432 .32121 L
.436 .32036 L
.44 .31968 L
.444 .31922 L
.448 .31883 L
.452 .31858 L
.456 .31885 L
.46 .31998 L
.464 .32167 L
.468 .32296 L
.472 .32294 L
.476 .3216 L
.48 .31988 L
.484 .31883 L
.488 .31874 L
.492 .31903 L
.496 .31911 L
.5 .3192 L
.504 .32003 L
.508 .3218 L
.512 .32354 L
.516 .32379 L
.52 .32204 L
.524 .31941 L
.528 .31778 L
.532 .31807 L
.536 .31947 L
.54 .32036 L
.544 .3201 L
.548 .31967 L
.552 .32052 L
.556 .32274 L
.56 .32462 L
.564 .32419 L
.568 .32125 L
.572 .31786 L
.576 .31658 L
.58 .31818 L
.584 .32091 L
.588 .32222 L
.592 .32118 L
.596 .31933 L
.6 .31907 L
Mistroke
.604 .32124 L
.608 .32413 L
.612 .32502 L
.616 .32275 L
.62 .31892 L
.624 .31656 L
.628 .31752 L
.632 .32082 L
.636 .32359 L
.64 .32353 L
.644 .32086 L
.648 .31804 L
.652 .31755 L
.656 .31983 L
.66 .323 L
.664 .32453 L
.668 .3233 L
.672 .3204 L
.676 .31813 L
.68 .31809 L
.684 .32009 L
.688 .32244 L
.692 .32336 L
.696 .3222 L
.7 .31967 L
.704 .31721 L
.708 .31601 L
.712 .31642 L
.716 .31804 L
.72 .31998 L
.724 .32126 L
.728 .32108 L
.732 .31913 L
.736 .31587 L
.74 .31249 L
.744 .31039 L
.748 .31026 L
.752 .31135 L
.756 .31155 L
.76 .30854 L
.764 .30138 L
.768 .29145 L
.772 .28188 L
.776 .27574 L
.78 .2739 L
.784 .27419 L
.788 .27247 L
.792 .26509 L
.796 .2514 L
.8 .23445 L
Mistroke
.804 .21959 L
.808 .21148 L
.812 .21151 L
.816 .21709 L
.82 .22319 L
.824 .22532 L
.828 .2221 L
.832 .21598 L
.836 .21168 L
.84 .21355 L
.844 .22293 L
.848 .23753 L
.852 .25246 L
.856 .26273 L
.86 .26544 L
.864 .26074 L
.868 .25141 L
.872 .24099 L
.876 .23254 L
.88 .22733 L
.884 .22549 L
.888 .22639 L
.892 .22957 L
.896 .23491 L
.9 .24193 L
.904 .2498 L
.908 .25637 L
.912 .25947 L
.916 .2574 L
.92 .25013 L
.924 .24029 L
.928 .23156 L
.932 .22881 L
.936 .23477 L
.94 .24985 L
.944 .27148 L
.948 .29405 L
.952 .31274 L
.956 .32237 L
.96 .32219 L
.964 .31342 L
.968 .29988 L
.972 .28713 L
.976 .2783 L
.98 .27654 L
.984 .28101 L
.988 .28955 L
.992 .29975 L
.996 .30789 L
1 .31312 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13426 m
.008 .12938 L
.012 .12773 L
.016 .12942 L
.02 .12992 L
.024 .12938 L
.028 .12918 L
.032 .1294 L
.036 .12944 L
.04 .1294 L
.044 .12936 L
.048 .1294 L
.052 .12939 L
.056 .1294 L
.06 .12938 L
.064 .12939 L
.068 .12938 L
.072 .12938 L
.076 .12937 L
.08 .12938 L
.084 .12939 L
.088 .1294 L
.092 .1294 L
.096 .1294 L
.1 .12939 L
.104 .12938 L
.108 .12937 L
.112 .12938 L
.116 .12938 L
.12 .12939 L
.124 .12939 L
.128 .12939 L
.132 .12938 L
.136 .12938 L
.14 .12938 L
.144 .12939 L
.148 .12939 L
.152 .1294 L
.156 .1294 L
.16 .1294 L
.164 .12939 L
.168 .12938 L
.172 .12937 L
.176 .12937 L
.18 .12938 L
.184 .12939 L
.188 .1294 L
.192 .12941 L
.196 .1294 L
.2 .1294 L
Mistroke
.204 .12939 L
.208 .12938 L
.212 .12938 L
.216 .12938 L
.22 .12938 L
.224 .12938 L
.228 .12938 L
.232 .12939 L
.236 .1294 L
.24 .1294 L
.244 .1294 L
.248 .1294 L
.252 .12939 L
.256 .12938 L
.26 .12937 L
.264 .12938 L
.268 .12939 L
.272 .1294 L
.276 .12941 L
.28 .12941 L
.284 .1294 L
.288 .12939 L
.292 .12938 L
.296 .12937 L
.3 .12937 L
.304 .12937 L
.308 .12939 L
.312 .12941 L
.316 .12942 L
.32 .12943 L
.324 .12942 L
.328 .12941 L
.332 .12939 L
.336 .12937 L
.34 .12936 L
.344 .12936 L
.348 .12937 L
.352 .12939 L
.356 .12941 L
.36 .12941 L
.364 .12942 L
.368 .12942 L
.372 .12942 L
.376 .12941 L
.38 .1294 L
.384 .12939 L
.388 .12938 L
.392 .12938 L
.396 .12939 L
.4 .12938 L
Mistroke
.404 .12938 L
.408 .12937 L
.412 .12937 L
.416 .12939 L
.42 .1294 L
.424 .12942 L
.428 .12943 L
.432 .12944 L
.436 .12945 L
.44 .12945 L
.444 .12942 L
.448 .12938 L
.452 .12934 L
.456 .12933 L
.46 .12934 L
.464 .12936 L
.468 .12939 L
.472 .12942 L
.476 .12945 L
.48 .12947 L
.484 .12948 L
.488 .12944 L
.492 .12939 L
.496 .12934 L
.5 .12932 L
.504 .12935 L
.508 .12941 L
.512 .12945 L
.516 .12946 L
.52 .12947 L
.524 .12948 L
.528 .12947 L
.532 .12942 L
.536 .12933 L
.54 .12924 L
.544 .1292 L
.548 .12924 L
.552 .12935 L
.556 .12947 L
.56 .12955 L
.564 .12958 L
.568 .1296 L
.572 .12961 L
.576 .12959 L
.58 .12952 L
.584 .12938 L
.588 .12921 L
.592 .1291 L
.596 .12911 L
.6 .1292 L
Mistroke
.604 .12933 L
.608 .12942 L
.612 .12947 L
.616 .1295 L
.62 .12955 L
.624 .12964 L
.628 .12969 L
.632 .12966 L
.636 .12953 L
.64 .12937 L
.644 .12925 L
.648 .12921 L
.652 .12925 L
.656 .12931 L
.66 .12933 L
.664 .12931 L
.668 .12932 L
.672 .1294 L
.676 .12955 L
.68 .12974 L
.684 .12988 L
.688 .12991 L
.692 .12984 L
.696 .12969 L
.7 .12954 L
.704 .12941 L
.708 .12934 L
.712 .12932 L
.716 .12934 L
.72 .1294 L
.724 .12953 L
.728 .12974 L
.732 .13008 L
.736 .13055 L
.74 .13109 L
.744 .13163 L
.748 .13208 L
.752 .13236 L
.756 .13248 L
.76 .13251 L
.764 .13259 L
.768 .13285 L
.772 .13338 L
.776 .13417 L
.78 .13517 L
.784 .13634 L
.788 .13769 L
.792 .13932 L
.796 .14133 L
.8 .14381 L
Mistroke
.804 .14671 L
.808 .14986 L
.812 .15304 L
.816 .15605 L
.82 .15881 L
.824 .16136 L
.828 .16383 L
.832 .16633 L
.836 .16892 L
.84 .17152 L
.844 .17397 L
.848 .17613 L
.852 .17793 L
.856 .17941 L
.86 .1807 L
.864 .18199 L
.868 .18345 L
.872 .18515 L
.876 .18712 L
.88 .18932 L
.884 .19167 L
.888 .19412 L
.892 .19663 L
.896 .19916 L
.9 .2017 L
.904 .20426 L
.908 .20688 L
.912 .20962 L
.916 .2126 L
.92 .2159 L
.924 .21959 L
.928 .22361 L
.932 .22785 L
.936 .23205 L
.94 .23601 L
.944 .23948 L
.948 .2424 L
.952 .2448 L
.956 .24684 L
.96 .24879 L
.964 .25084 L
.968 .25322 L
.972 .25594 L
.976 .259 L
.98 .26227 L
.984 .26557 L
.988 .2688 L
.992 .27185 L
.996 .27473 L
1 .27747 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16037 L
.012 .16101 L
.016 .16135 L
.02 .16129 L
.024 .1611 L
.028 .16113 L
.032 .16116 L
.036 .16117 L
.04 .16111 L
.044 .1611 L
.048 .16109 L
.052 .16111 L
.056 .16109 L
.06 .16109 L
.064 .16106 L
.068 .16106 L
.072 .16103 L
.076 .16103 L
.08 .16102 L
.084 .16103 L
.088 .16102 L
.092 .16102 L
.096 .161 L
.1 .16098 L
.104 .16096 L
.108 .16095 L
.112 .16095 L
.116 .16095 L
.12 .16095 L
.124 .16094 L
.128 .16092 L
.132 .16091 L
.136 .16089 L
.14 .16088 L
.144 .16088 L
.148 .16088 L
.152 .16088 L
.156 .16087 L
.16 .16085 L
.164 .16084 L
.168 .16082 L
.172 .1608 L
.176 .16079 L
.18 .16079 L
.184 .16078 L
.188 .16078 L
.192 .16078 L
.196 .16078 L
.2 .16077 L
Mistroke
.204 .16076 L
.208 .16074 L
.212 .16072 L
.216 .1607 L
.22 .16068 L
.224 .16067 L
.228 .16067 L
.232 .16068 L
.236 .16069 L
.24 .16068 L
.244 .16067 L
.248 .16065 L
.252 .16063 L
.256 .16061 L
.26 .1606 L
.264 .16059 L
.268 .16059 L
.272 .16059 L
.276 .1606 L
.28 .16059 L
.284 .16058 L
.288 .16055 L
.292 .16052 L
.296 .1605 L
.3 .16049 L
.304 .16049 L
.308 .1605 L
.312 .16052 L
.316 .16053 L
.32 .16051 L
.324 .16049 L
.328 .16047 L
.332 .16044 L
.336 .16042 L
.34 .16039 L
.344 .16037 L
.348 .16037 L
.352 .16038 L
.356 .1604 L
.36 .16041 L
.364 .16041 L
.368 .1604 L
.372 .16039 L
.376 .16037 L
.38 .16034 L
.384 .16032 L
.388 .1603 L
.392 .16029 L
.396 .16029 L
.4 .16027 L
Mistroke
.404 .16025 L
.408 .16024 L
.412 .16024 L
.416 .16024 L
.42 .16025 L
.424 .16025 L
.428 .16026 L
.432 .16027 L
.436 .16028 L
.44 .16026 L
.444 .16021 L
.448 .16015 L
.452 .16009 L
.456 .16007 L
.46 .16007 L
.464 .16009 L
.468 .16012 L
.472 .16014 L
.476 .16017 L
.48 .16019 L
.484 .16019 L
.488 .16014 L
.492 .16006 L
.496 .15998 L
.5 .15996 L
.504 .15999 L
.508 .16004 L
.512 .16008 L
.516 .1601 L
.52 .1601 L
.524 .1601 L
.528 .16008 L
.532 .16001 L
.536 .15988 L
.54 .15976 L
.544 .15969 L
.548 .15974 L
.552 .15986 L
.556 .16 L
.56 .16009 L
.564 .16013 L
.568 .16013 L
.572 .16014 L
.576 .16011 L
.58 .16001 L
.584 .15982 L
.588 .15961 L
.592 .15946 L
.596 .15945 L
.6 .15957 L
Mistroke
.604 .15972 L
.608 .15982 L
.612 .15986 L
.616 .15989 L
.62 .15995 L
.624 .16004 L
.628 .1601 L
.632 .16005 L
.636 .15988 L
.64 .15966 L
.644 .15949 L
.648 .15943 L
.652 .15947 L
.656 .15951 L
.66 .15951 L
.664 .15947 L
.668 .15945 L
.672 .15952 L
.676 .15968 L
.68 .15987 L
.684 .16 L
.688 .15999 L
.692 .15983 L
.696 .15958 L
.7 .1593 L
.704 .15905 L
.708 .15885 L
.712 .15868 L
.716 .15855 L
.72 .15843 L
.724 .15836 L
.728 .15836 L
.732 .15846 L
.736 .15866 L
.74 .15887 L
.744 .159 L
.748 .15889 L
.752 .15843 L
.756 .15761 L
.76 .15649 L
.764 .15521 L
.768 .15389 L
.772 .15259 L
.776 .15126 L
.78 .14981 L
.784 .14813 L
.788 .1462 L
.792 .14413 L
.796 .14204 L
.8 .14001 L
Mistroke
.804 .13801 L
.808 .13588 L
.812 .13338 L
.816 .13037 L
.82 .12682 L
.824 .12292 L
.828 .11893 L
.832 .11513 L
.836 .11167 L
.84 .10853 L
.844 .10558 L
.848 .10264 L
.852 .09958 L
.856 .0964 L
.86 .09315 L
.864 .08996 L
.868 .08688 L
.872 .08392 L
.876 .08103 L
.88 .0781 L
.884 .07508 L
.888 .07196 L
.892 .06878 L
.896 .06563 L
.9 .0626 L
.904 .05981 L
.908 .05734 L
.912 .05529 L
.916 .05374 L
.92 .05275 L
.924 .05227 L
.928 .05221 L
.932 .05237 L
.936 .0525 L
.94 .05243 L
.944 .05201 L
.948 .0513 L
.952 .05049 L
.956 .04987 L
.96 .04977 L
.964 .05036 L
.968 .0518 L
.972 .05394 L
.976 .0566 L
.98 .05949 L
.984 .06232 L
.988 .06493 L
.992 .06718 L
.996 .06909 L
1 .07069 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0`0000=oo`0000000P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool0
1000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`05001oogooOol00002Ool01@00Oomoo`00Ool01@000Woo0`000Woo
00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool01000Ool000000Woo00<007ooOol00`000goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo00H0
07ooOomoo`00Ool20002Ool200001Woo001oogoo001oo`<000Ioo`04001oogoo0002Ool00`00Oomo
o`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol02goo10000goo
00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomo
o`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007oo0000009oo`800004Ool007oo
Ool3000017oo000007oo10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol0
0Woo0P0037oo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomo
o`0017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001oogooOol00002Ool200001Woo
001oogoo001oo`8000=oo`03001oogoo00800003Ool007oo00Eoo`04001oogoo0005Ool0029oo`80
00aoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20004
Ool30003Ool30004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo04Qoo`03001o
ogoo00ioo`03001oogoo008000ioo`008Woo0P00BGoo00<007ooOol03Woo00<007ooOol00P003Woo
000ROomS000<Ool0029oo`L00003Ool0000000T00003Ool00000009oo`800003Ool00000009oo`05
001oogooOol00003Ool20002Ool300001Goo00000000Ool00P000Woo0`0000=oo`00Ool0100000Ao
o`00Oomoo`H000=oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo0P000goo00<007ooOol0
2Woo000ROol2000017oo000007oo0P0000Aoo`00001oo`800003Ool0000000@00003Ool0000001@0
0005Ool00000001oo`0700000goo0000000200000goo0000000500000goo0000000EOol2000@Ool0
029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol2001]Ool000]oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool0
0`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
0`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^
Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0
00=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00
KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo
000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006ao
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo
0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol0
00]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017ooB@0087oo000AOol2000:Ool20004
Ool00`00Oomoo`02Ool00`00Oomoo`16Ool2000NOol002Qoo`03001oogoo04Moo`8001eoo`00:7oo
00<007ooOol0B7oo0`006goo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool0
0`00Oomoo`1:Ool3000IOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0003Ool01000Oomoo`00CWoo0`005goo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0005Ool01000Oomoo`00D7oo0P005Woo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003
Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05
001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogooOol2000017oo001oo`000goo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo
00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009o
o`04001oogoo0004Ool20006Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004
Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool30004Ool01000Oomo
o`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo
0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool60003Ool01000Oomoo`00
1Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0
009oo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oo`000005Ool01000Oomoo`001Goo000X
Ool00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo
1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@
Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00
Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000
Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomo
o`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02
001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001o
ogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<0
07ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=o
o`D0009oo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomo
o`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00<007ooOol017oo0P00G7oo20003goo000;Ool20008Ool50002Ool00`00Oomoo`1JOol20006Ool2
000>Ool001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<0
00Aoo`8000Eoo`D000=oo`8000Aoo`80009oo`03001oogoo00D0009oo`<000Aoo`8000Ioo`0077oo
0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007oo
Ool0009oo`04001oogoo0002Ool00`00Oomoo`020004Ool01P00Oomoo`00Ool000=oo`04001oogoo
0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo000000Ioo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00<007ooOol010001goo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol0
00Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomo
ogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001o
ogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00<007ooOol010000Woo00<007ooOol00Woo00L007oo
Oomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03
Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo10000Woo0P001Woo0`000Woo
1@000goo0P001Woo000LOol00`00Oomoo`1?Ool3000POol001aoo`03001oogoo04eoo`<0029oo`00
77ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000
Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo
00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Ao
o`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000LOol2001cOol001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<0
07ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079o
o`005goo00<007ooOol00Woo00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo
009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<0
07ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomo
o`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007oo
Ool017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(44088\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32061 m
.008 .31966 L
.012 .31841 L
.016 .31804 L
.02 .31882 L
.024 .31903 L
.028 .31861 L
.032 .31868 L
.036 .31908 L
.04 .31916 L
.044 .31904 L
.048 .31891 L
.052 .31892 L
.056 .31899 L
.06 .31897 L
.064 .31896 L
.068 .3189 L
.072 .31879 L
.076 .31882 L
.08 .31897 L
.084 .31921 L
.088 .31943 L
.092 .31942 L
.096 .31922 L
.1 .31891 L
.104 .31864 L
.108 .31863 L
.112 .3189 L
.116 .31934 L
.12 .31972 L
.124 .31977 L
.128 .31949 L
.132 .31903 L
.136 .31863 L
.14 .31855 L
.144 .31883 L
.148 .31937 L
.152 .31988 L
.156 .32001 L
.16 .3197 L
.164 .31913 L
.168 .31868 L
.172 .31861 L
.176 .31897 L
.18 .31957 L
.184 .3201 L
.188 .32019 L
.192 .31975 L
.196 .31902 L
.2 .31849 L
Mistroke
.204 .31853 L
.208 .3191 L
.212 .31986 L
.216 .32042 L
.22 .32051 L
.224 .32007 L
.228 .31928 L
.232 .31858 L
.236 .31841 L
.24 .31885 L
.244 .3196 L
.248 .32022 L
.252 .32047 L
.256 .32037 L
.26 .31999 L
.264 .31942 L
.268 .31889 L
.272 .31871 L
.276 .31904 L
.28 .31969 L
.284 .32028 L
.288 .32054 L
.292 .32045 L
.296 .3201 L
.3 .31955 L
.304 .31898 L
.308 .31872 L
.312 .31905 L
.316 .31982 L
.32 .32051 L
.324 .32071 L
.328 .32044 L
.332 .32004 L
.336 .31975 L
.34 .31958 L
.344 .31942 L
.348 .31935 L
.352 .31953 L
.356 .31989 L
.36 .32021 L
.364 .3203 L
.368 .32024 L
.372 .32021 L
.376 .32024 L
.38 .32016 L
.384 .31985 L
.388 .31949 L
.392 .31941 L
.396 .3197 L
.4 .32017 L
Mistroke
.404 .32049 L
.408 .32056 L
.412 .32054 L
.416 .32055 L
.42 .32048 L
.424 .3201 L
.428 .31942 L
.432 .31886 L
.436 .31892 L
.44 .31974 L
.444 .32088 L
.448 .32165 L
.452 .32172 L
.456 .32125 L
.46 .32069 L
.464 .3202 L
.468 .31962 L
.472 .31884 L
.476 .31825 L
.48 .3185 L
.484 .31986 L
.488 .32169 L
.492 .32285 L
.496 .32266 L
.5 .32149 L
.504 .32031 L
.508 .31976 L
.512 .31955 L
.516 .31907 L
.52 .31837 L
.524 .31832 L
.528 .31971 L
.532 .32212 L
.536 .32394 L
.54 .32375 L
.544 .32169 L
.548 .31942 L
.552 .31856 L
.556 .31923 L
.56 .32004 L
.564 .3198 L
.568 .31883 L
.572 .31872 L
.576 .32056 L
.58 .32346 L
.584 .32511 L
.588 .32393 L
.592 .32064 L
.596 .3178 L
.6 .31751 L
Mistroke
.604 .31952 L
.608 .32156 L
.612 .32158 L
.616 .31972 L
.62 .31817 L
.624 .319 L
.628 .322 L
.632 .32479 L
.636 .32483 L
.64 .32185 L
.644 .3181 L
.648 .3165 L
.652 .31812 L
.656 .32133 L
.66 .32327 L
.664 .32231 L
.668 .31934 L
.672 .31689 L
.676 .31695 L
.68 .31932 L
.684 .32192 L
.688 .32254 L
.692 .3206 L
.696 .31739 L
.7 .31498 L
.704 .31456 L
.708 .31569 L
.712 .31679 L
.716 .31631 L
.72 .31368 L
.724 .30943 L
.728 .30464 L
.732 .3003 L
.736 .29685 L
.74 .29414 L
.744 .29148 L
.748 .28783 L
.752 .2821 L
.756 .27377 L
.76 .26342 L
.764 .25269 L
.768 .24361 L
.772 .23737 L
.776 .23342 L
.78 .22969 L
.784 .22394 L
.788 .2155 L
.792 .2063 L
.796 .20007 L
.8 .2003 L
Mistroke
.804 .20789 L
.808 .22029 L
.812 .23256 L
.816 .24015 L
.82 .24132 L
.824 .23818 L
.828 .23516 L
.832 .23626 L
.836 .24246 L
.84 .25096 L
.844 .25684 L
.848 .25579 L
.852 .24694 L
.856 .23328 L
.86 .22052 L
.864 .21411 L
.868 .21666 L
.872 .22703 L
.876 .24094 L
.88 .25353 L
.884 .26115 L
.888 .26292 L
.892 .26036 L
.896 .25599 L
.9 .2525 L
.904 .25115 L
.908 .25272 L
.912 .2572 L
.916 .26474 L
.92 .2757 L
.924 .28931 L
.928 .30462 L
.932 .31843 L
.936 .3279 L
.94 .3304 L
.944 .32518 L
.948 .3148 L
.952 .30286 L
.956 .29487 L
.96 .29421 L
.964 .30161 L
.968 .31496 L
.972 .32857 L
.976 .33691 L
.98 .33594 L
.984 .32357 L
.988 .30394 L
.992 .28089 L
.996 .26166 L
1 .25189 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13145 m
.008 .12995 L
.012 .12934 L
.016 .12975 L
.02 .12998 L
.024 .12993 L
.028 .12981 L
.032 .12982 L
.036 .12983 L
.04 .12985 L
.044 .12982 L
.048 .12984 L
.052 .12984 L
.056 .12985 L
.06 .12984 L
.064 .12984 L
.068 .12984 L
.072 .12985 L
.076 .12984 L
.08 .12985 L
.084 .12984 L
.088 .12984 L
.092 .12983 L
.096 .12983 L
.1 .12983 L
.104 .12984 L
.108 .12984 L
.112 .12986 L
.116 .12985 L
.12 .12985 L
.124 .12984 L
.128 .12984 L
.132 .12983 L
.136 .12984 L
.14 .12984 L
.144 .12985 L
.148 .12984 L
.152 .12984 L
.156 .12984 L
.16 .12984 L
.164 .12984 L
.168 .12984 L
.172 .12985 L
.176 .12985 L
.18 .12985 L
.184 .12985 L
.188 .12984 L
.192 .12984 L
.196 .12983 L
.2 .12983 L
Mistroke
.204 .12983 L
.208 .12984 L
.212 .12984 L
.216 .12985 L
.22 .12986 L
.224 .12986 L
.228 .12986 L
.232 .12985 L
.236 .12984 L
.24 .12983 L
.244 .12983 L
.248 .12983 L
.252 .12983 L
.256 .12984 L
.26 .12985 L
.264 .12986 L
.268 .12986 L
.272 .12986 L
.276 .12985 L
.28 .12984 L
.284 .12983 L
.288 .12983 L
.292 .12984 L
.296 .12985 L
.3 .12986 L
.304 .12987 L
.308 .12986 L
.312 .12985 L
.316 .12983 L
.32 .12982 L
.324 .12982 L
.328 .12983 L
.332 .12985 L
.336 .12986 L
.34 .12987 L
.344 .12988 L
.348 .12988 L
.352 .12987 L
.356 .12985 L
.36 .12983 L
.364 .12981 L
.368 .12981 L
.372 .12982 L
.376 .12984 L
.38 .12985 L
.384 .12986 L
.388 .12987 L
.392 .12988 L
.396 .12988 L
.4 .12987 L
Mistroke
.404 .12986 L
.408 .12985 L
.412 .12984 L
.416 .12985 L
.42 .12985 L
.424 .12984 L
.428 .12983 L
.432 .12983 L
.436 .12983 L
.44 .12984 L
.444 .12985 L
.448 .12986 L
.452 .12988 L
.456 .1299 L
.46 .12992 L
.464 .12991 L
.468 .12988 L
.472 .12984 L
.476 .12981 L
.48 .12979 L
.484 .12979 L
.488 .1298 L
.492 .12982 L
.496 .12985 L
.5 .1299 L
.504 .12994 L
.508 .12994 L
.512 .12991 L
.516 .12985 L
.52 .1298 L
.524 .12979 L
.528 .12981 L
.532 .12985 L
.536 .12987 L
.54 .1299 L
.544 .12993 L
.548 .12996 L
.552 .12996 L
.556 .12991 L
.56 .1298 L
.564 .12969 L
.568 .12965 L
.572 .12969 L
.576 .12978 L
.58 .12987 L
.584 .12994 L
.588 .12999 L
.592 .13005 L
.596 .1301 L
.6 .13011 L
Mistroke
.604 .13003 L
.608 .12987 L
.612 .1297 L
.616 .1296 L
.62 .1296 L
.624 .12968 L
.628 .12977 L
.632 .12983 L
.636 .12988 L
.64 .12993 L
.644 .13004 L
.648 .13016 L
.652 .13023 L
.656 .13021 L
.66 .1301 L
.664 .12997 L
.668 .12988 L
.672 .12988 L
.676 .12993 L
.68 .12999 L
.684 .13002 L
.688 .13004 L
.692 .1301 L
.696 .13026 L
.7 .13051 L
.704 .13081 L
.708 .13109 L
.712 .13131 L
.716 .13145 L
.72 .13157 L
.724 .13171 L
.728 .13192 L
.732 .13224 L
.736 .13267 L
.74 .13322 L
.744 .13391 L
.748 .13478 L
.752 .13587 L
.756 .13725 L
.76 .13893 L
.764 .14089 L
.768 .14305 L
.772 .14529 L
.776 .14751 L
.78 .14968 L
.784 .15184 L
.788 .15407 L
.792 .15645 L
.796 .159 L
.8 .16166 L
Mistroke
.804 .16432 L
.808 .16687 L
.812 .16929 L
.816 .17165 L
.82 .17405 L
.824 .17659 L
.828 .17926 L
.832 .18196 L
.836 .18453 L
.84 .18685 L
.844 .18889 L
.848 .19077 L
.852 .19267 L
.856 .19476 L
.86 .1971 L
.864 .19965 L
.868 .20224 L
.872 .20469 L
.876 .20686 L
.88 .20873 L
.884 .21035 L
.888 .21186 L
.892 .21339 L
.896 .21502 L
.9 .21677 L
.904 .21864 L
.908 .22058 L
.912 .22251 L
.916 .2244 L
.92 .22616 L
.924 .22776 L
.928 .2292 L
.932 .23048 L
.936 .23171 L
.94 .23302 L
.944 .23459 L
.948 .23649 L
.952 .23878 L
.956 .24138 L
.96 .2441 L
.964 .24675 L
.968 .24912 L
.972 .25115 L
.976 .25288 L
.98 .2545 L
.984 .25623 L
.988 .25835 L
.992 .26091 L
.996 .26402 L
1 .26745 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16461 L
.012 .16115 L
.016 .15999 L
.02 .16122 L
.024 .16155 L
.028 .16116 L
.032 .16099 L
.036 .16114 L
.04 .16115 L
.044 .16111 L
.048 .16108 L
.052 .16111 L
.056 .16109 L
.06 .16109 L
.064 .16106 L
.068 .16106 L
.072 .16104 L
.076 .16105 L
.08 .16103 L
.084 .16104 L
.088 .16101 L
.092 .161 L
.096 .16098 L
.1 .16097 L
.104 .16096 L
.108 .16097 L
.112 .16097 L
.116 .16096 L
.12 .16094 L
.124 .16093 L
.128 .1609 L
.132 .1609 L
.136 .16089 L
.14 .16089 L
.144 .16089 L
.148 .16089 L
.152 .16087 L
.156 .16085 L
.16 .16083 L
.164 .16082 L
.168 .16081 L
.172 .16082 L
.176 .16082 L
.18 .16082 L
.184 .16081 L
.188 .16079 L
.192 .16076 L
.196 .16074 L
.2 .16073 L
Mistroke
.204 .16073 L
.208 .16073 L
.212 .16073 L
.216 .16073 L
.22 .16072 L
.224 .16071 L
.228 .1607 L
.232 .16068 L
.236 .16067 L
.24 .16065 L
.244 .16063 L
.248 .16062 L
.252 .16062 L
.256 .16062 L
.26 .16063 L
.264 .16062 L
.268 .16061 L
.272 .1606 L
.276 .16058 L
.28 .16055 L
.284 .16054 L
.288 .16053 L
.292 .16053 L
.296 .16053 L
.3 .16054 L
.304 .16053 L
.308 .16052 L
.312 .1605 L
.316 .16048 L
.32 .16045 L
.324 .16042 L
.328 .16042 L
.332 .16043 L
.336 .16045 L
.34 .16046 L
.344 .16046 L
.348 .16045 L
.352 .16042 L
.356 .16039 L
.36 .16036 L
.364 .16033 L
.368 .16032 L
.372 .16032 L
.376 .16033 L
.38 .16033 L
.384 .16034 L
.388 .16034 L
.392 .16034 L
.396 .16033 L
.4 .16031 L
Mistroke
.404 .16028 L
.408 .16026 L
.412 .16025 L
.416 .16025 L
.42 .16024 L
.424 .16021 L
.428 .16019 L
.432 .16018 L
.436 .16018 L
.44 .16018 L
.444 .16018 L
.448 .16018 L
.452 .16019 L
.456 .16021 L
.46 .16023 L
.464 .16022 L
.468 .16017 L
.472 .1601 L
.476 .16005 L
.48 .16002 L
.484 .16001 L
.488 .16002 L
.492 .16003 L
.496 .16006 L
.5 .16011 L
.504 .16015 L
.508 .16015 L
.512 .16009 L
.516 .16 L
.52 .15993 L
.524 .15991 L
.528 .15993 L
.532 .15997 L
.536 .15999 L
.54 .16001 L
.544 .16004 L
.548 .16007 L
.552 .16006 L
.556 .15998 L
.56 .15984 L
.564 .1597 L
.568 .15964 L
.572 .15967 L
.576 .15978 L
.58 .15988 L
.584 .15996 L
.588 .16001 L
.592 .16006 L
.596 .16012 L
.6 .16012 L
Mistroke
.604 .16001 L
.608 .1598 L
.612 .15958 L
.616 .15943 L
.62 .15941 L
.624 .15949 L
.628 .15959 L
.632 .15965 L
.636 .15968 L
.64 .15972 L
.644 .15982 L
.648 .15994 L
.652 .15999 L
.656 .15992 L
.66 .15973 L
.664 .15951 L
.668 .15933 L
.672 .15925 L
.676 .15922 L
.68 .15918 L
.684 .15908 L
.688 .15895 L
.692 .15885 L
.696 .15883 L
.7 .15888 L
.704 .15895 L
.708 .15893 L
.712 .15876 L
.716 .15841 L
.72 .15792 L
.724 .15733 L
.728 .15667 L
.732 .15596 L
.736 .15517 L
.74 .15428 L
.744 .15327 L
.748 .15214 L
.752 .15093 L
.756 .14964 L
.76 .14828 L
.764 .14678 L
.768 .14502 L
.772 .14286 L
.776 .14018 L
.78 .13698 L
.784 .13334 L
.788 .12946 L
.792 .12552 L
.796 .12166 L
.8 .1179 L
Mistroke
.804 .11424 L
.808 .11063 L
.812 .10716 L
.816 .10395 L
.82 .10116 L
.824 .09891 L
.828 .09712 L
.832 .09557 L
.836 .09396 L
.84 .09201 L
.844 .08958 L
.848 .0867 L
.852 .08356 L
.856 .08035 L
.86 .0772 L
.864 .07412 L
.868 .07103 L
.872 .06783 L
.876 .06444 L
.88 .06092 L
.884 .05736 L
.888 .05391 L
.892 .05066 L
.896 .04764 L
.9 .04482 L
.904 .04212 L
.908 .03949 L
.912 .03691 L
.916 .03445 L
.92 .03216 L
.924 .03015 L
.928 .02851 L
.932 .02732 L
.936 .02669 L
.94 .02666 L
.944 .0273 L
.948 .02855 L
.952 .0303 L
.956 .03236 L
.96 .03441 L
.964 .0362 L
.968 .03751 L
.972 .03825 L
.976 .03849 L
.98 .03842 L
.984 .03831 L
.988 .03849 L
.992 .03906 L
.996 .04026 L
1 .04193 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001;Ool2000POol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo
0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool0
1000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`05001oogooOol00002Ool00`00Oomoo`0200001Woo001oogoo001o
o`8000Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol00Woo00D007ooOol007oo00800003Ool0000000Eoo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`03001oogoo0080009oo`800005Ool00000Ool00006Ool00`00Oomoo`04Ool01000Oomoo`00
0Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo
00]oo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`04001oogooOol40003Ool01000Oomoo`000Woo00H007ooOomoo`00Ool20002Ool00`00Oomoo`02
00000goo000000030003Ool00`00Ool000030003Ool01000Oomoo`001Goo000;Ool2000:Ool20004
Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0
009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`000Woo00@007ooOomoo`80
0005Ool007ooOol00002Ool00`00Oomoo`0300000goo001oo`02Ool01@00Ool007oo000017oo00@0
07ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@0
07ooOomoo`D000=oo`8000Aoo`<00004Ool007ooOol20004Ool20005Ool30002Ool50003Ool20006
Ool0029oo`03001oogoo04Ioo`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo00]oo`008Woo
0P00AWoo0P0047oo00<007ooOol00P000Woo00<007ooOol02goo000ROomS000<Ool0029oo`T00003
Ool0000000<00004Ool00000Ool200001Goo00000000Ool00P000Woo0P000goo00D007ooOomoo`00
009oo`80009oo`80009oo`80009oo`<00004Ool00000Ool400000goo001oo`040002Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`<00006Ool007oo001oo`0037oo000ROol20007Ool00`00
Ool00002000017oo000007oo0P0000Aoo`00001oo`H00003Ool0000001800003Ool0000000T00003
Ool0000000<001Ioo`80009oo`8000ioo`008Woo00<007ooOol0FGoo00<007ooOol00P003Woo000R
Ool2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007oo
Ool0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool2
0004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P00
17oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2
001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo
0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03
001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006io
o`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`00
8Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@0
07ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
2Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0002Ool20004Oom6000SOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001o
ogoo04=oo`80025oo`00:7oo00<007ooOol0A7oo0`007goo000XOol00`00Oomoo`16Ool2000NOol0
00]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo04Qoo`8001aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001<Ool2
000JOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001o
ogoo001=Ool2000IOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009o
o`D000=oo`8000Aoo`X0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007oo00000P00
0Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001o
ogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0003Ool40005Ool01000
Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=
Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Oomoo`03Ool30004Ool01000Oomoo`000Woo00<007ooOol00goo000XOol0
0`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0003Ool01000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0003Ool00`00Ool000030003Ool01000Oomoo`001Goo000XOol00`00Oomo
o`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002
Ool20003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol000=oo`04001oo`00Ool20003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09
Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo
0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?
Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo06Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo
0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P00
17oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003
Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000=oo`D0009oo`04001o
ogoo000;Ool00`00Oomoo`02001OOol2000BOol000Yoo`04001oogoo000;Ool01000Oomoo`00GGoo
0`0000Aoo`000000011oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo05Yoo`8000Ioo`@0
00aoo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8005Yoo`8001Moo`002goo0P0027oo1@00
0Woo00<007ooOol0F7oo0P0067oo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004
Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool30004Ool50002Ool30004Ool20006
Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=o
o`04001oogoo0002Ool01000Oomoo`000Woo10001Goo00H007ooOol007oo0003Ool01000Oomoo`00
0Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol017oo00<007ooOol00Woo00D007ooOol007oo00<00003Ool007oo00Eoo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo10000Woo00<007ooOol01Goo
00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007oo
Ool000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=o
o`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007oo0000009oo`04001oogoo0004Ool01P00
Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04
001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Ao
o`04001oogoo0004Ool01@00Oomoogoo00000Woo10000Woo00@007ooOol000Aoo`07001oogooOol0
07oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P00
17oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000=oo`<000Aoo`8000Ioo`<0009oo`D000=o
o`8000Ioo`0077oo00<007ooOol0CGoo0P008goo000LOol00`00Oomoo`1:Ool4000TOol001aoofT0
00aoo`0077oo0P000Woo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool0
1000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03
001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007
Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]o
o`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`00
5goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001o
ogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<0
00=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo
00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;
Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001o
ogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03
001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(44255\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31895 m
.008 .31833 L
.012 .31891 L
.016 .31925 L
.02 .31924 L
.024 .3191 L
.028 .31867 L
.032 .31827 L
.036 .31828 L
.04 .31861 L
.044 .31905 L
.048 .31936 L
.052 .31937 L
.056 .31916 L
.06 .31881 L
.064 .31853 L
.068 .31855 L
.072 .31879 L
.076 .31912 L
.08 .31936 L
.084 .31932 L
.088 .31909 L
.092 .3188 L
.096 .31865 L
.1 .3188 L
.104 .31914 L
.108 .31945 L
.112 .31956 L
.116 .31936 L
.12 .31898 L
.124 .31863 L
.128 .31854 L
.132 .31883 L
.136 .31933 L
.14 .31977 L
.144 .3199 L
.148 .31965 L
.152 .31919 L
.156 .31874 L
.16 .31852 L
.164 .31868 L
.168 .31914 L
.172 .31965 L
.176 .31995 L
.18 .31989 L
.184 .31958 L
.188 .31919 L
.192 .31887 L
.196 .31878 L
.2 .31901 L
Mistroke
.204 .31948 L
.208 .31991 L
.212 .32003 L
.216 .31978 L
.22 .31932 L
.224 .31892 L
.228 .31878 L
.232 .31899 L
.236 .31955 L
.24 .32018 L
.244 .32048 L
.248 .32019 L
.252 .31947 L
.256 .31882 L
.26 .31861 L
.264 .31891 L
.268 .31949 L
.272 .32011 L
.276 .32049 L
.28 .32046 L
.284 .31998 L
.288 .3193 L
.292 .31887 L
.296 .31894 L
.3 .31936 L
.304 .31983 L
.308 .32015 L
.312 .32033 L
.316 .32038 L
.32 .32017 L
.324 .31966 L
.328 .31912 L
.332 .31892 L
.336 .31921 L
.34 .31977 L
.344 .32024 L
.348 .32047 L
.352 .3205 L
.356 .32038 L
.36 .32007 L
.364 .31962 L
.368 .31928 L
.372 .31929 L
.376 .31963 L
.38 .32001 L
.384 .32018 L
.388 .32018 L
.392 .32023 L
.396 .32038 L
.4 .32045 L
Mistroke
.404 .32022 L
.408 .31976 L
.412 .31943 L
.416 .31948 L
.42 .31985 L
.424 .32022 L
.428 .32039 L
.432 .32043 L
.436 .32056 L
.44 .32076 L
.444 .32074 L
.448 .32025 L
.452 .31945 L
.456 .31886 L
.46 .31896 L
.464 .31973 L
.468 .32068 L
.472 .32128 L
.476 .32143 L
.48 .32138 L
.484 .32128 L
.488 .32089 L
.492 .31996 L
.496 .31869 L
.5 .3179 L
.504 .31834 L
.508 .31994 L
.512 .32169 L
.516 .3225 L
.52 .32217 L
.524 .3214 L
.528 .32094 L
.532 .32077 L
.536 .32018 L
.54 .3189 L
.544 .31769 L
.548 .31783 L
.552 .31978 L
.556 .3224 L
.56 .32382 L
.564 .32313 L
.568 .32119 L
.572 .31977 L
.576 .31979 L
.58 .32047 L
.584 .32031 L
.588 .31889 L
.592 .31754 L
.596 .31807 L
.6 .3208 L
Mistroke
.604 .32394 L
.608 .325 L
.612 .3231 L
.616 .31982 L
.62 .31782 L
.624 .31842 L
.628 .32043 L
.632 .32145 L
.636 .32018 L
.64 .31777 L
.644 .31669 L
.648 .31836 L
.652 .32166 L
.656 .3238 L
.66 .32273 L
.664 .31898 L
.668 .31519 L
.672 .31388 L
.676 .31534 L
.68 .31746 L
.684 .31761 L
.688 .31477 L
.692 .31024 L
.696 .3064 L
.7 .30464 L
.704 .30427 L
.708 .30315 L
.712 .29943 L
.716 .29283 L
.72 .28472 L
.724 .27688 L
.728 .27028 L
.732 .26454 L
.736 .25848 L
.74 .25106 L
.744 .24203 L
.748 .23203 L
.752 .22226 L
.756 .21403 L
.76 .20843 L
.764 .20602 L
.768 .20659 L
.772 .20911 L
.776 .2122 L
.78 .21487 L
.784 .21726 L
.788 .22066 L
.792 .22661 L
.796 .23547 L
.8 .24559 L
Mistroke
.804 .25358 L
.808 .25611 L
.812 .25191 L
.816 .24284 L
.82 .23321 L
.824 .22733 L
.828 .22721 L
.832 .23132 L
.836 .23579 L
.84 .23688 L
.844 .23351 L
.848 .22816 L
.852 .22532 L
.856 .22889 L
.86 .23944 L
.864 .25372 L
.868 .26623 L
.872 .27201 L
.876 .26965 L
.88 .26169 L
.884 .25382 L
.888 .2517 L
.892 .25845 L
.896 .27359 L
.9 .293 L
.904 .31192 L
.908 .32593 L
.912 .33341 L
.916 .33492 L
.92 .33229 L
.924 .32809 L
.928 .32356 L
.932 .3199 L
.936 .31744 L
.94 .31636 L
.944 .31713 L
.948 .31916 L
.952 .32145 L
.956 .32235 L
.96 .31919 L
.964 .31172 L
.968 .29986 L
.972 .2867 L
.976 .27709 L
.98 .27356 L
.984 .28064 L
.988 .29531 L
.992 .31489 L
.996 .33385 L
1 .34404 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12572 m
.008 .13036 L
.012 .13184 L
.016 .13027 L
.02 .12975 L
.024 .13032 L
.028 .13045 L
.032 .13028 L
.036 .13022 L
.04 .13031 L
.044 .13032 L
.048 .13032 L
.052 .13029 L
.056 .1303 L
.06 .13028 L
.064 .13029 L
.068 .13028 L
.072 .1303 L
.076 .13029 L
.08 .1303 L
.084 .13029 L
.088 .13029 L
.092 .13029 L
.096 .1303 L
.1 .1303 L
.104 .13031 L
.108 .1303 L
.112 .1303 L
.116 .13029 L
.12 .13028 L
.124 .13028 L
.128 .13029 L
.132 .1303 L
.136 .13031 L
.14 .13031 L
.144 .13031 L
.148 .1303 L
.152 .13029 L
.156 .13028 L
.16 .13028 L
.164 .13029 L
.168 .1303 L
.172 .13031 L
.176 .13031 L
.18 .13029 L
.184 .13028 L
.188 .13028 L
.192 .13029 L
.196 .1303 L
.2 .13031 L
Mistroke
.204 .13031 L
.208 .13031 L
.212 .1303 L
.216 .13029 L
.22 .13029 L
.224 .13028 L
.228 .13028 L
.232 .13029 L
.236 .13029 L
.24 .1303 L
.244 .13031 L
.248 .13031 L
.252 .13031 L
.256 .13031 L
.26 .1303 L
.264 .13029 L
.268 .13028 L
.272 .13028 L
.276 .13029 L
.28 .1303 L
.284 .1303 L
.288 .13031 L
.292 .13031 L
.296 .13031 L
.3 .13031 L
.304 .1303 L
.308 .13029 L
.312 .13028 L
.316 .13029 L
.32 .1303 L
.324 .13031 L
.328 .13032 L
.332 .13032 L
.336 .13031 L
.34 .13029 L
.344 .13028 L
.348 .13027 L
.352 .13028 L
.356 .13029 L
.36 .13031 L
.364 .13032 L
.368 .13033 L
.372 .13034 L
.376 .13033 L
.38 .13031 L
.384 .13029 L
.388 .13027 L
.392 .13027 L
.396 .13027 L
.4 .13028 L
Mistroke
.404 .1303 L
.408 .13031 L
.412 .13032 L
.416 .13033 L
.42 .13033 L
.424 .13032 L
.428 .13031 L
.432 .13031 L
.436 .13031 L
.44 .13031 L
.444 .1303 L
.448 .13029 L
.452 .13029 L
.456 .13029 L
.46 .13029 L
.464 .13029 L
.468 .13029 L
.472 .1303 L
.476 .13032 L
.48 .13036 L
.484 .13038 L
.488 .13037 L
.492 .13034 L
.496 .13031 L
.5 .13028 L
.504 .13026 L
.508 .13025 L
.512 .13024 L
.516 .13025 L
.52 .13029 L
.524 .13035 L
.528 .1304 L
.532 .1304 L
.536 .13036 L
.54 .13031 L
.544 .13027 L
.548 .13026 L
.552 .13027 L
.556 .13028 L
.56 .1303 L
.564 .13033 L
.568 .13039 L
.572 .13044 L
.576 .13045 L
.58 .13039 L
.584 .13027 L
.588 .13017 L
.592 .13014 L
.596 .13017 L
.6 .13023 L
Mistroke
.604 .1303 L
.608 .13036 L
.612 .13043 L
.616 .13053 L
.62 .13063 L
.624 .13066 L
.628 .13059 L
.632 .13045 L
.636 .1303 L
.64 .13022 L
.644 .13024 L
.648 .13032 L
.652 .1304 L
.656 .13048 L
.66 .13057 L
.664 .13071 L
.668 .13091 L
.672 .13113 L
.676 .13132 L
.68 .13142 L
.684 .13147 L
.688 .13154 L
.692 .13169 L
.696 .13195 L
.7 .1323 L
.704 .13271 L
.708 .13316 L
.712 .13371 L
.716 .1344 L
.72 .13531 L
.724 .13645 L
.728 .13778 L
.732 .13925 L
.736 .14084 L
.74 .14253 L
.744 .14434 L
.748 .14632 L
.752 .14848 L
.756 .15083 L
.76 .15334 L
.764 .15597 L
.768 .15867 L
.772 .16143 L
.776 .16425 L
.78 .16712 L
.784 .17004 L
.788 .17294 L
.792 .17572 L
.796 .17826 L
.8 .18047 L
Mistroke
.804 .18234 L
.808 .18396 L
.812 .18549 L
.816 .18709 L
.82 .18886 L
.824 .19081 L
.828 .1929 L
.832 .19505 L
.836 .19726 L
.84 .19958 L
.844 .2021 L
.848 .20486 L
.852 .20782 L
.856 .21083 L
.86 .21368 L
.864 .21622 L
.868 .21838 L
.872 .22025 L
.876 .22199 L
.88 .22377 L
.884 .22567 L
.888 .22764 L
.892 .22955 L
.896 .2312 L
.9 .23246 L
.904 .23326 L
.908 .23366 L
.912 .2338 L
.916 .2338 L
.92 .23382 L
.924 .23392 L
.928 .23414 L
.932 .2345 L
.936 .23497 L
.94 .23554 L
.944 .23618 L
.948 .2369 L
.952 .23769 L
.956 .23862 L
.96 .23974 L
.964 .2412 L
.968 .24303 L
.972 .24534 L
.976 .24798 L
.98 .25086 L
.984 .25374 L
.988 .25634 L
.992 .25858 L
.996 .26031 L
1 .26171 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .1626 L
.012 .16138 L
.016 .16075 L
.02 .16108 L
.024 .16126 L
.028 .1612 L
.032 .16108 L
.036 .16111 L
.04 .16113 L
.044 .16114 L
.048 .16111 L
.052 .1611 L
.056 .16108 L
.06 .16108 L
.064 .16105 L
.068 .16106 L
.072 .16104 L
.076 .16105 L
.08 .16103 L
.084 .16102 L
.088 .161 L
.092 .161 L
.096 .16099 L
.1 .16099 L
.104 .16098 L
.108 .16098 L
.112 .16096 L
.116 .16094 L
.12 .16092 L
.124 .16092 L
.128 .16091 L
.132 .16091 L
.136 .16091 L
.14 .1609 L
.144 .16088 L
.148 .16087 L
.152 .16086 L
.156 .16085 L
.16 .16084 L
.164 .16084 L
.168 .16083 L
.172 .16082 L
.176 .1608 L
.18 .16079 L
.184 .16078 L
.188 .16077 L
.192 .16077 L
.196 .16077 L
.2 .16076 L
Mistroke
.204 .16076 L
.208 .16074 L
.212 .16073 L
.216 .16071 L
.22 .16069 L
.224 .16068 L
.228 .16067 L
.232 .16067 L
.236 .16067 L
.24 .16067 L
.244 .16066 L
.248 .16065 L
.252 .16064 L
.256 .16063 L
.26 .16061 L
.264 .16059 L
.268 .16058 L
.272 .16056 L
.276 .16056 L
.28 .16056 L
.284 .16056 L
.288 .16057 L
.292 .16056 L
.296 .16055 L
.3 .16052 L
.304 .16049 L
.308 .16047 L
.312 .16047 L
.316 .16048 L
.32 .16048 L
.324 .16048 L
.328 .16048 L
.332 .16046 L
.336 .16044 L
.34 .16042 L
.344 .16039 L
.348 .16037 L
.352 .16037 L
.356 .16038 L
.36 .16039 L
.364 .16039 L
.368 .1604 L
.372 .16039 L
.376 .16037 L
.38 .16034 L
.384 .1603 L
.388 .16028 L
.392 .16027 L
.396 .16026 L
.4 .16026 L
Mistroke
.404 .16026 L
.408 .16027 L
.412 .16028 L
.416 .16029 L
.42 .16028 L
.424 .16025 L
.428 .16023 L
.432 .16021 L
.436 .1602 L
.44 .1602 L
.444 .16018 L
.448 .16016 L
.452 .16014 L
.456 .16013 L
.46 .16012 L
.464 .16011 L
.468 .1601 L
.472 .16011 L
.476 .16013 L
.48 .16016 L
.484 .16018 L
.488 .16016 L
.492 .16011 L
.496 .16006 L
.5 .16002 L
.504 .15998 L
.508 .15996 L
.512 .15994 L
.516 .15994 L
.52 .15998 L
.524 .16005 L
.528 .16009 L
.532 .16009 L
.536 .16003 L
.54 .15995 L
.544 .1599 L
.548 .15988 L
.552 .15988 L
.556 .15988 L
.56 .15989 L
.564 .15992 L
.568 .15998 L
.572 .16004 L
.576 .16003 L
.58 .15994 L
.584 .15979 L
.588 .15965 L
.592 .15959 L
.596 .15961 L
.6 .15967 L
Mistroke
.604 .15973 L
.608 .15978 L
.612 .15985 L
.616 .15995 L
.62 .16003 L
.624 .16003 L
.628 .15991 L
.632 .15968 L
.636 .15944 L
.64 .15927 L
.644 .15921 L
.648 .15922 L
.652 .15922 L
.656 .15919 L
.66 .15915 L
.664 .15915 L
.668 .15919 L
.672 .15922 L
.676 .15916 L
.68 .15894 L
.684 .15858 L
.688 .15815 L
.692 .15773 L
.696 .15732 L
.7 .15688 L
.704 .15633 L
.708 .15564 L
.712 .15481 L
.716 .15389 L
.72 .15292 L
.724 .15186 L
.728 .15064 L
.732 .14916 L
.736 .14734 L
.74 .14516 L
.744 .14264 L
.748 .13982 L
.752 .13676 L
.756 .13351 L
.76 .13009 L
.764 .12654 L
.768 .12291 L
.772 .11929 L
.776 .11578 L
.78 .1125 L
.784 .10953 L
.788 .10686 L
.792 .10441 L
.796 .10203 L
.8 .09955 L
Mistroke
.804 .0969 L
.808 .09409 L
.812 .09118 L
.816 .08828 L
.82 .08539 L
.824 .08245 L
.828 .07938 L
.832 .07611 L
.836 .07269 L
.84 .06929 L
.844 .06614 L
.848 .06342 L
.852 .06114 L
.856 .05918 L
.86 .0573 L
.864 .05525 L
.868 .05288 L
.872 .05024 L
.876 .04744 L
.88 .04469 L
.884 .04211 L
.888 .03974 L
.892 .03754 L
.896 .03541 L
.9 .03331 L
.904 .03127 L
.908 .02935 L
.912 .02767 L
.916 .02626 L
.92 .02513 L
.924 .02421 L
.928 .02339 L
.932 .0226 L
.936 .02176 L
.94 .02087 L
.944 .01992 L
.948 .0189 L
.952 .01786 L
.956 .01682 L
.96 .01587 L
.964 .01518 L
.968 .01485 L
.972 .01512 L
.976 .01598 L
.98 .01743 L
.984 .0193 L
.988 .02125 L
.992 .02312 L
.996 .02453 L
1 .02547 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool20019Ool00`00Oomoo`0QOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo
0`0017oo0P000goo2P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool0
1000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`05001oogooOol00002Ool00`00Oomoo`02000017oo001oogoo0P00
00=oo`00Ool00goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool000070005Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool20002
Ool00`00Ool0000200000goo001oo`020006Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007oo
Ool00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00]oo`@000=o
o`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo
Ool40003Ool01000Oomoo`000Woo00<007ooOol00P000Woo00@007oo0000009oo`03001oo`0000<0
0003Ool007oo009oo`03001oo`0000<000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03
001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo
00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Ool000020002Ool0
1000Oomoo`000Woo00<007ooOol00`0000=oo`00Ool00Woo00<007oo00001Woo00@007ooOol000Eo
o`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D0
00=oo`8000Aoo`<000Aoo`8000Aoo`<00004Ool007ooOol30002Ool50003Ool20006Ool0029oo`03
001oogoo04=oo`03001oogoo00ioo`03001oogoo00Eoo`8000ioo`008Woo0P00A7oo00<007ooOol0
3goo00<007ooOol017oo0P003Woo000ROomS000<Ool0029oo`D00003Ool0000000<00004Ool00000
Ool600000goo0000000600001Goo00000000Ool00P000Woo00P007ooOomoo`00Ool007oo0`0000=o
o`00Ool00`0000Eoo`00000007oo00<00003Ool0000000800003Ool007oo009oo`05001oogooOol0
0003Ool02000Oomoogoo001oo`00Ool3000017oo001oogoo0P0037oo000ROol20003Ool01000Oomo
o`000Woo00<007oo00000P0000Aoo`00001ooad00005Ool00000001oo`0400000goo000000020000
0goo001oo`0GOol300000goo001oo`02Ool00`00Oomoo`0;Ool0029oo`03001oogoo05Ioo`8000Io
o`03001oogoo00]oo`008Woo0P00H7oo00<007ooOol02Woo000ROol2001]Ool000]oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00
Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04
001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool0
1000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool0
1P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`00
8Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<0
07ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03
001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00
Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017ooA0009Goo000AOol2
000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`10Ool3000SOol002Qoo`03001oogoo049oo`80
029oo`00:7oo00<007ooOol0A7oo0P0087oo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003
Ool30003Ool00`00Oomoo`15Ool2000OOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0003Ool01000Oomoo`00BGoo0`0077oo0003Ool50002Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool01000Oomoo`00Bgoo0P006goo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool2
0004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool2
0006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001o
ogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`000Woo00D007ooOol007oo00<0009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03
001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007oo
Ool0009oo`03001oogoo00P000Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`80
00Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`@000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00
Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000<000=o
o`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004
Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`00
0goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00@007oo001oo`8000=oo`04
001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`80
00Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo
00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo
00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`80
00=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00
Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo
001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001W
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P00
17oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool0
0`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04
001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007oo
Ool00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@0
07ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007oo
Ool00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03
001oogoo061oo`<000moo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008005aoo`D000=o
o`<000aoo`002Woo00@007ooOol000]oo`04001oogoo001KOol3000FOol000Yoo`04001oogoo0007
Ool40003Ool00`00Oomoo`1HOol2000HOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001H
Ool2000IOol000]oo`8000Qoo`D0009oo`03001oogoo05Aoo`<001]oo`0077oo00<007ooOol03Goo
0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P000Woo
10001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol0
00Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00<007ooOol010000Woo00<007ooOol0
0goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@
Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool00P0000Eoo`00Oomoo`0000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool0
01aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01000
Oomoogoo10000Woo00@007ooOol000Moo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03
Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`800005
Ool007ooOol00002Ool00`00Oomoo`02Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool0
01aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo
00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01P00Oomoogoo001oo`80
009oo`04001oogoo0002Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20006Ool50002Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo
04Yoo`8002Ioo`0077oo00<007ooOol0B7oo0`009goo000LOomY000<Ool001aoo`05001oogooOol0
0003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
00]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05
001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol0
00Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007oo
Ool0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`005Woo0`00
0goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009o
o`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomo
o`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]o
o`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04
001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo
10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03
001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(44422\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31674 m
.008 .31757 L
.012 .319 L
.016 .3195 L
.02 .31879 L
.024 .31865 L
.028 .31907 L
.032 .31901 L
.036 .3187 L
.04 .31867 L
.044 .31883 L
.048 .31893 L
.052 .31884 L
.056 .31871 L
.06 .31867 L
.064 .31872 L
.068 .31893 L
.072 .31921 L
.076 .31936 L
.08 .31931 L
.084 .31903 L
.088 .31867 L
.092 .31847 L
.096 .31853 L
.1 .31887 L
.104 .31931 L
.108 .31956 L
.112 .31951 L
.116 .3192 L
.12 .31883 L
.124 .31865 L
.128 .31876 L
.132 .31912 L
.136 .31949 L
.14 .31958 L
.144 .31934 L
.148 .31891 L
.152 .31862 L
.156 .31871 L
.16 .31913 L
.164 .31968 L
.168 .32003 L
.172 .31993 L
.176 .31938 L
.18 .31871 L
.184 .31832 L
.188 .31851 L
.192 .31913 L
.196 .31982 L
.2 .32023 L
Mistroke
.204 .32017 L
.208 .3197 L
.212 .31905 L
.216 .31859 L
.22 .31861 L
.224 .31907 L
.228 .31967 L
.232 .32008 L
.236 .32013 L
.24 .31988 L
.244 .31944 L
.248 .31898 L
.252 .31873 L
.256 .3189 L
.26 .31947 L
.264 .3201 L
.268 .32043 L
.272 .32028 L
.276 .3198 L
.28 .31922 L
.284 .31878 L
.288 .31871 L
.292 .31914 L
.296 .31991 L
.3 .32057 L
.304 .32067 L
.308 .32016 L
.312 .31946 L
.316 .319 L
.32 .31896 L
.324 .31923 L
.328 .31967 L
.332 .32015 L
.336 .32052 L
.34 .32055 L
.344 .32016 L
.348 .31957 L
.352 .31916 L
.356 .31914 L
.36 .31941 L
.364 .31973 L
.368 .32004 L
.372 .32035 L
.376 .32058 L
.38 .32053 L
.384 .32012 L
.388 .31961 L
.392 .31935 L
.396 .31949 L
.4 .31981 L
Mistroke
.404 .32001 L
.408 .32001 L
.412 .32003 L
.416 .32023 L
.42 .32051 L
.424 .32057 L
.428 .32028 L
.432 .31985 L
.436 .31959 L
.44 .31963 L
.444 .31984 L
.448 .32 L
.452 .32012 L
.456 .32036 L
.46 .32078 L
.464 .32111 L
.468 .32097 L
.472 .32027 L
.476 .31939 L
.48 .31892 L
.484 .31915 L
.488 .3198 L
.492 .32042 L
.496 .32079 L
.5 .32111 L
.504 .32156 L
.508 .32185 L
.512 .32143 L
.516 .32013 L
.52 .31858 L
.524 .31785 L
.528 .31851 L
.532 .32004 L
.536 .32133 L
.54 .32173 L
.544 .32155 L
.548 .32154 L
.552 .32184 L
.556 .32174 L
.56 .32048 L
.564 .31842 L
.568 .31704 L
.572 .31762 L
.576 .31998 L
.58 .32238 L
.584 .32312 L
.588 .32204 L
.592 .32056 L
.596 .32015 L
.6 .32078 L
Mistroke
.604 .32101 L
.608 .31967 L
.612 .31729 L
.616 .31589 L
.62 .31705 L
.624 .32018 L
.628 .32285 L
.632 .32283 L
.636 .32012 L
.64 .31688 L
.644 .31544 L
.648 .31612 L
.652 .31706 L
.656 .316 L
.66 .31254 L
.664 .30852 L
.668 .30631 L
.672 .30649 L
.676 .30716 L
.68 .30543 L
.684 .29987 L
.688 .29164 L
.692 .28345 L
.696 .27728 L
.7 .27281 L
.704 .26782 L
.708 .26025 L
.712 .24989 L
.716 .23865 L
.72 .22898 L
.724 .22217 L
.728 .21765 L
.732 .21381 L
.736 .20957 L
.74 .20523 L
.744 .20233 L
.748 .20243 L
.752 .20618 L
.756 .2129 L
.76 .2211 L
.764 .22911 L
.768 .23569 L
.772 .24021 L
.776 .24263 L
.78 .24344 L
.784 .24336 L
.788 .24295 L
.792 .24217 L
.796 .24027 L
.8 .23633 L
Mistroke
.804 .23023 L
.808 .22336 L
.812 .21849 L
.816 .21845 L
.82 .22438 L
.824 .23474 L
.828 .24563 L
.832 .25291 L
.836 .25445 L
.84 .25146 L
.844 .24781 L
.848 .24763 L
.852 .25298 L
.856 .2624 L
.86 .27222 L
.864 .27882 L
.868 .28108 L
.872 .28144 L
.876 .28401 L
.88 .29255 L
.884 .30732 L
.888 .32492 L
.892 .3397 L
.896 .34636 L
.9 .34329 L
.904 .33253 L
.908 .31947 L
.912 .30961 L
.916 .30611 L
.92 .3089 L
.924 .31465 L
.928 .31925 L
.932 .31998 L
.936 .31591 L
.94 .30945 L
.944 .30321 L
.948 .29983 L
.952 .30105 L
.956 .30531 L
.96 .31244 L
.964 .3195 L
.968 .32559 L
.972 .33048 L
.976 .33197 L
.98 .33191 L
.984 .32758 L
.988 .31998 L
.992 .31007 L
.996 .29758 L
1 .28821 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12825 m
.008 .13066 L
.012 .13149 L
.016 .13086 L
.02 .1305 L
.024 .1307 L
.028 .13081 L
.032 .13079 L
.036 .13072 L
.04 .13075 L
.044 .13074 L
.048 .13075 L
.052 .13073 L
.056 .13074 L
.06 .13074 L
.064 .13076 L
.068 .13075 L
.072 .13076 L
.076 .13075 L
.08 .13075 L
.084 .13074 L
.088 .13074 L
.092 .13074 L
.096 .13075 L
.1 .13074 L
.104 .13075 L
.108 .13075 L
.112 .13075 L
.116 .13075 L
.12 .13075 L
.124 .13075 L
.128 .13075 L
.132 .13075 L
.136 .13074 L
.14 .13074 L
.144 .13074 L
.148 .13074 L
.152 .13075 L
.156 .13075 L
.16 .13076 L
.164 .13075 L
.168 .13075 L
.172 .13075 L
.176 .13074 L
.18 .13074 L
.184 .13075 L
.188 .13075 L
.192 .13075 L
.196 .13075 L
.2 .13075 L
Mistroke
.204 .13075 L
.208 .13074 L
.212 .13074 L
.216 .13074 L
.22 .13075 L
.224 .13076 L
.228 .13076 L
.232 .13076 L
.236 .13076 L
.24 .13075 L
.244 .13074 L
.248 .13074 L
.252 .13074 L
.256 .13074 L
.26 .13075 L
.264 .13075 L
.268 .13075 L
.272 .13076 L
.276 .13077 L
.28 .13077 L
.284 .13076 L
.288 .13075 L
.292 .13073 L
.296 .13073 L
.3 .13073 L
.304 .13074 L
.308 .13076 L
.312 .13077 L
.316 .13077 L
.32 .13077 L
.324 .13076 L
.328 .13074 L
.332 .13074 L
.336 .13074 L
.34 .13074 L
.344 .13075 L
.348 .13076 L
.352 .13077 L
.356 .13078 L
.36 .13077 L
.364 .13075 L
.368 .13073 L
.372 .13073 L
.376 .13073 L
.38 .13074 L
.384 .13075 L
.388 .13077 L
.392 .13078 L
.396 .13079 L
.4 .13078 L
Mistroke
.404 .13077 L
.408 .13075 L
.412 .13074 L
.416 .13073 L
.42 .13072 L
.424 .13073 L
.428 .13074 L
.432 .13076 L
.436 .13078 L
.44 .13079 L
.444 .13078 L
.448 .13077 L
.452 .13077 L
.456 .13077 L
.46 .13077 L
.464 .13076 L
.468 .13075 L
.472 .13075 L
.476 .13075 L
.48 .13075 L
.484 .13074 L
.488 .13073 L
.492 .13073 L
.496 .13074 L
.5 .13078 L
.504 .13081 L
.508 .13083 L
.512 .13082 L
.516 .1308 L
.52 .13078 L
.524 .13076 L
.528 .13073 L
.532 .1307 L
.536 .13068 L
.54 .13069 L
.544 .13074 L
.548 .13081 L
.552 .13085 L
.556 .13085 L
.56 .13082 L
.564 .13078 L
.568 .13076 L
.572 .13075 L
.576 .13074 L
.58 .13074 L
.584 .13075 L
.588 .13081 L
.592 .13089 L
.596 .13097 L
.6 .13099 L
Mistroke
.604 .13093 L
.608 .13084 L
.612 .13078 L
.616 .13077 L
.62 .13081 L
.624 .13087 L
.628 .13094 L
.632 .13104 L
.636 .13119 L
.64 .13139 L
.644 .13159 L
.648 .13174 L
.652 .13179 L
.656 .1318 L
.66 .13184 L
.664 .13197 L
.668 .13223 L
.672 .13257 L
.676 .13298 L
.68 .13346 L
.684 .13406 L
.688 .13483 L
.692 .13577 L
.696 .13686 L
.7 .13803 L
.704 .13928 L
.708 .14064 L
.712 .14218 L
.716 .14396 L
.72 .14599 L
.724 .14821 L
.728 .1506 L
.732 .1531 L
.736 .15572 L
.74 .15847 L
.744 .16134 L
.748 .16429 L
.752 .16724 L
.756 .17008 L
.76 .17273 L
.764 .17516 L
.768 .17737 L
.772 .1794 L
.776 .1813 L
.78 .18313 L
.784 .18493 L
.788 .18675 L
.792 .18861 L
.796 .19058 L
.8 .19273 L
Mistroke
.804 .19513 L
.808 .19779 L
.812 .20067 L
.816 .20362 L
.82 .20649 L
.824 .2091 L
.828 .21138 L
.832 .21336 L
.836 .21514 L
.84 .21685 L
.844 .21858 L
.848 .22034 L
.852 .22209 L
.856 .22375 L
.86 .22535 L
.864 .22691 L
.868 .22855 L
.872 .23029 L
.876 .23212 L
.88 .23388 L
.884 .2354 L
.888 .23653 L
.892 .23723 L
.896 .2376 L
.9 .23782 L
.904 .23809 L
.908 .23855 L
.912 .2392 L
.916 .23998 L
.92 .24074 L
.924 .24139 L
.928 .2419 L
.932 .24231 L
.936 .2427 L
.94 .24316 L
.944 .24369 L
.948 .24432 L
.952 .24495 L
.956 .24553 L
.96 .24601 L
.964 .24634 L
.968 .24661 L
.972 .24682 L
.976 .24709 L
.98 .24752 L
.984 .24815 L
.988 .24918 L
.992 .25055 L
.996 .25241 L
1 .2546 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15801 L
.012 .16128 L
.016 .16224 L
.02 .16113 L
.024 .16077 L
.028 .16118 L
.032 .16127 L
.036 .16115 L
.04 .16108 L
.044 .16113 L
.048 .16111 L
.052 .16108 L
.056 .16106 L
.06 .16107 L
.064 .16106 L
.068 .16108 L
.072 .16106 L
.076 .16105 L
.08 .16103 L
.084 .16102 L
.088 .161 L
.092 .161 L
.096 .16099 L
.1 .16099 L
.104 .16098 L
.108 .16097 L
.112 .16094 L
.116 .16094 L
.12 .16093 L
.124 .16093 L
.128 .16093 L
.132 .16093 L
.136 .16091 L
.14 .16089 L
.144 .16086 L
.148 .16085 L
.152 .16084 L
.156 .16085 L
.16 .16086 L
.164 .16086 L
.168 .16084 L
.172 .16082 L
.176 .1608 L
.18 .16078 L
.184 .16078 L
.188 .16078 L
.192 .16078 L
.196 .16077 L
.2 .16075 L
Mistroke
.204 .16074 L
.208 .16072 L
.212 .16071 L
.216 .16071 L
.22 .16071 L
.224 .1607 L
.228 .1607 L
.232 .16069 L
.236 .16067 L
.24 .16066 L
.244 .16064 L
.248 .16062 L
.252 .16061 L
.256 .1606 L
.26 .16061 L
.264 .16061 L
.268 .16061 L
.272 .1606 L
.276 .16059 L
.28 .16057 L
.284 .16055 L
.288 .16054 L
.292 .16052 L
.296 .16051 L
.3 .1605 L
.304 .1605 L
.308 .1605 L
.312 .1605 L
.316 .1605 L
.32 .16049 L
.324 .16047 L
.328 .16045 L
.332 .16042 L
.336 .16041 L
.34 .16041 L
.344 .16041 L
.348 .16042 L
.352 .16042 L
.356 .16041 L
.36 .16039 L
.364 .16036 L
.368 .16034 L
.372 .16032 L
.376 .16031 L
.38 .16031 L
.384 .16032 L
.388 .16033 L
.392 .16034 L
.396 .16034 L
.4 .16032 L
Mistroke
.404 .16029 L
.408 .16025 L
.412 .16023 L
.416 .16021 L
.42 .1602 L
.424 .1602 L
.428 .1602 L
.432 .16021 L
.436 .16022 L
.44 .16022 L
.444 .16021 L
.448 .16019 L
.452 .16017 L
.456 .16016 L
.46 .16015 L
.464 .16014 L
.468 .16012 L
.472 .1601 L
.476 .16009 L
.48 .16008 L
.484 .16006 L
.488 .16004 L
.492 .16003 L
.496 .16004 L
.5 .16007 L
.504 .1601 L
.508 .16011 L
.512 .1601 L
.516 .16007 L
.52 .16003 L
.524 .15999 L
.528 .15994 L
.532 .15989 L
.536 .15986 L
.54 .15986 L
.544 .15991 L
.548 .15998 L
.552 .16002 L
.556 .16001 L
.56 .15996 L
.564 .1599 L
.568 .15985 L
.572 .15982 L
.576 .15979 L
.58 .15976 L
.584 .15975 L
.588 .15979 L
.592 .15987 L
.596 .15993 L
.6 .15991 L
Mistroke
.604 .15979 L
.608 .15963 L
.612 .15948 L
.616 .15939 L
.62 .15935 L
.624 .15932 L
.628 .15929 L
.632 .15927 L
.636 .1593 L
.64 .15935 L
.644 .15936 L
.648 .15925 L
.652 .15898 L
.656 .15859 L
.66 .15815 L
.664 .15774 L
.668 .15736 L
.672 .15695 L
.676 .15645 L
.68 .15584 L
.684 .15515 L
.688 .1544 L
.692 .15356 L
.696 .15255 L
.7 .15126 L
.704 .14964 L
.708 .14769 L
.712 .14548 L
.716 .14307 L
.72 .14047 L
.724 .13765 L
.728 .13458 L
.732 .13128 L
.736 .12781 L
.74 .1243 L
.744 .12084 L
.748 .11748 L
.752 .11423 L
.756 .11107 L
.76 .10797 L
.764 .10494 L
.768 .10201 L
.772 .09919 L
.776 .09649 L
.78 .0939 L
.784 .09135 L
.788 .08876 L
.792 .08609 L
.796 .08331 L
.8 .08047 L
Mistroke
.804 .07764 L
.808 .07488 L
.812 .07223 L
.816 .06962 L
.82 .06695 L
.824 .06414 L
.828 .06116 L
.832 .05806 L
.836 .05498 L
.84 .05202 L
.844 .04921 L
.848 .04649 L
.852 .04377 L
.856 .04096 L
.86 .03812 L
.864 .03544 L
.868 .03315 L
.872 .03146 L
.876 .03044 L
.88 .02996 L
.884 .02978 L
.888 .02962 L
.892 .02928 L
.896 .02871 L
.9 .02798 L
.904 .02719 L
.908 .02644 L
.912 .02573 L
.916 .02497 L
.92 .02404 L
.924 .02283 L
.928 .02132 L
.932 .01955 L
.936 .01761 L
.94 .01566 L
.944 .01376 L
.948 .01205 L
.952 .01056 L
.956 .00935 L
.96 .00844 L
.964 .00775 L
.968 .00725 L
.972 .00677 L
.976 .00623 L
.98 .0056 L
.984 .00484 L
.988 .00425 L
.992 .00388 L
.996 .00415 L
1 .00507 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool20016Ool2000UOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo
0P000goo1P000Woo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool0
1000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`04001oogooOol200001Goo000007oo00000Woo0P0000Eoo`00Oomo
o`0000Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00@007ooOomoo`8000=oo`800006Ool00000001oo`000Woo00<007ooOol00goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00L007ooOomoo`00
Ool00002Ool500000goo00000002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`000Woo
00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00]o
o`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04
001oogooOol40003Ool01000Oomoo`000Woo0P000Woo00@007ooOol0009oo`03001oo`0000800003
Ool007oo009oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo
00<007ooOol00Woo0P0037oo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002
Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007oo000000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eo
o`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D0
00=oo`80009oo`03001oo`00008000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo
00<007ooOol0@Goo00<007ooOol03Goo0P0037oo00<007ooOol02Woo000ROol20011Ool00`00Oomo
o`0@Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool0029oof<000aoo`008Woo3P0000Aoo`00001oo`D0
0004Ool00000Ool3000017oo000007oo0P000goo00D007ooOomoo`0000=oo`04001oogooOol20002
Ool20002Ool600000goo001oo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001o
ogoo00@00004Ool007ooOol2000<Ool0029oo`<000Eoo`05001oo`00001oo`02000017oo000007oo
0P0000=oo`000000100000=oo`000000500000=oo`0000001P0000=oo`00000067oo00D007oo001o
o`00009oo`03001oo`0000ioo`008Woo00<007ooOol0E7oo0P001Woo0P003Woo000ROol2001EOol2
000FOol0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0
K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004
Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo
00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]
Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`00
0goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001o
ogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`00
2goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo
0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
2goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007oo
Oomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo
1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0002Ool20004Oom1000XOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo
03eoo`<002Ioo`00:7oo00<007ooOol0@7oo0P0097oo000XOol00`00Oomoo`11Ool2000SOol000]o
o`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo04=oo`80025oo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo0016Ool3000O
Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo
0019Ool2000MOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D0
00=oo`800004Ool00000Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool0
1000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol010000goo
00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001o
ogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@0
07ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00<007oo00000P000goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo
00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00<007oo000020000Woo00@007ooOol0009oo`03001oogoo00=o
o`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000goo00<007oo00000`000goo00@007ooOol000Eoo`00:7oo
00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000
Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomo
o`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P00
0goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomo
o`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo06Ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`00
2goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo
0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool2
0003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo061o
o`H000aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1NOol3000AOol0
00=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001LOol4000COol000Yoo`04001oogoo000;
Ool01000Oomoo`00FGoo10005goo000:Ool01000Oomoo`001goo10000goo00<007ooOol0EGoo0P00
6goo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00EGoo00<007ooOol06goo000;Ool20008
Ool50002Ool00`00Oomoo`1BOol2000NOol001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Ao
o`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`@0009oo`8000Eoo`D0009oo`<000Ao
o`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007oo
Ool00goo00@007ooOol0009oo`@0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool200001Goo001oogoo00000Woo00<007ooOol017oo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007oo
Ool0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oo`000080009oo`04001oogoo0002
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=
Ool40003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
1000Oomoogoo10000goo00@007ooOol000Aoo`04001oogooOol200001Goo001oogoo00000Woo00@0
07ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo
00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P00
0goo00<007ooOol017oo00@007ooOol000Aoo`03001oogoo0080009oo`04001oogoo0002Ool01000
Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2
000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P00
17oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`17Ool2000YOol001aoo`03001o
ogoo04Eoo`<002Yoo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol00Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Ao
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009o
o`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02
Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@0
07ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Ioo`<000=oo`03001oogoo079oo`005goo
00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo
009oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000FOol20004Ool2001c
Ool001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00
Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`00
2Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001c
Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(44589\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31821 m
.008 .31911 L
.012 .31893 L
.016 .31871 L
.02 .31844 L
.024 .31831 L
.028 .31856 L
.032 .31884 L
.036 .3189 L
.04 .31889 L
.044 .31885 L
.048 .31885 L
.052 .31888 L
.056 .3189 L
.06 .31894 L
.064 .31894 L
.068 .31884 L
.072 .31872 L
.076 .31862 L
.08 .31865 L
.084 .31884 L
.088 .31909 L
.092 .31931 L
.096 .31938 L
.1 .31924 L
.104 .31899 L
.108 .31872 L
.112 .31857 L
.116 .31864 L
.12 .31889 L
.124 .3192 L
.128 .31942 L
.132 .31946 L
.136 .31934 L
.14 .31912 L
.144 .3189 L
.148 .31882 L
.152 .31892 L
.156 .31915 L
.16 .31937 L
.164 .31943 L
.168 .31934 L
.172 .31913 L
.176 .31893 L
.18 .3189 L
.184 .31911 L
.188 .31949 L
.192 .31982 L
.196 .31981 L
.2 .31946 L
Mistroke
.204 .31897 L
.208 .31862 L
.212 .31865 L
.216 .31906 L
.22 .31969 L
.224 .3202 L
.228 .32024 L
.232 .31975 L
.236 .31904 L
.24 .31858 L
.244 .31865 L
.248 .31915 L
.252 .31977 L
.256 .32021 L
.26 .32027 L
.264 .31992 L
.268 .31932 L
.272 .3188 L
.276 .31871 L
.28 .31909 L
.284 .31968 L
.288 .32015 L
.292 .32033 L
.296 .32023 L
.3 .31989 L
.304 .31936 L
.308 .31888 L
.312 .31877 L
.316 .31919 L
.32 .31989 L
.324 .32043 L
.328 .32053 L
.332 .32023 L
.336 .31976 L
.34 .31931 L
.344 .31903 L
.348 .31907 L
.352 .3195 L
.356 .32013 L
.36 .32059 L
.364 .32057 L
.368 .32016 L
.372 .3197 L
.376 .31943 L
.38 .31937 L
.384 .31939 L
.388 .31952 L
.392 .31985 L
.396 .32034 L
.4 .32069 L
Mistroke
.404 .32062 L
.408 .3202 L
.412 .31974 L
.416 .31955 L
.42 .31963 L
.424 .31976 L
.428 .31982 L
.432 .31988 L
.436 .3201 L
.44 .32042 L
.444 .32062 L
.448 .32053 L
.452 .3202 L
.456 .31992 L
.46 .31983 L
.464 .31987 L
.468 .31985 L
.472 .31976 L
.476 .31985 L
.48 .3203 L
.484 .32096 L
.488 .32135 L
.492 .32109 L
.496 .32029 L
.5 .3195 L
.504 .31919 L
.508 .31936 L
.512 .31967 L
.516 .31988 L
.52 .32021 L
.524 .32094 L
.528 .3219 L
.532 .32237 L
.536 .32167 L
.54 .31999 L
.544 .31841 L
.548 .31796 L
.552 .31876 L
.556 .31992 L
.56 .32054 L
.564 .32058 L
.568 .32077 L
.572 .32154 L
.576 .32229 L
.58 .32184 L
.584 .31979 L
.588 .31722 L
.592 .31595 L
.596 .31686 L
.6 .31902 L
Mistroke
.604 .3205 L
.608 .32016 L
.612 .31862 L
.616 .3175 L
.62 .31752 L
.624 .31769 L
.628 .31629 L
.632 .31273 L
.636 .30844 L
.64 .30568 L
.644 .30536 L
.648 .30599 L
.652 .30485 L
.656 .3003 L
.66 .29316 L
.664 .28584 L
.668 .28001 L
.672 .27507 L
.676 .26884 L
.68 .25972 L
.684 .24842 L
.688 .23755 L
.692 .22947 L
.696 .22437 L
.7 .22026 L
.704 .2149 L
.708 .20791 L
.712 .2013 L
.716 .19792 L
.72 .19929 L
.724 .20451 L
.728 .2111 L
.732 .21694 L
.736 .22161 L
.74 .22622 L
.744 .23192 L
.748 .23861 L
.752 .24465 L
.756 .24794 L
.76 .24722 L
.764 .24287 L
.768 .23653 L
.772 .23022 L
.776 .22544 L
.78 .22287 L
.784 .22246 L
.788 .22376 L
.792 .22621 L
.796 .22927 L
.8 .23278 L
Mistroke
.804 .2369 L
.808 .24202 L
.812 .24816 L
.816 .25456 L
.82 .25969 L
.824 .26195 L
.828 .26107 L
.832 .25872 L
.836 .25831 L
.84 .26331 L
.844 .27511 L
.848 .29198 L
.852 .30935 L
.856 .32236 L
.86 .32816 L
.864 .32754 L
.868 .32428 L
.872 .32254 L
.876 .32462 L
.88 .32917 L
.884 .33253 L
.888 .33089 L
.892 .32286 L
.896 .31076 L
.9 .29914 L
.904 .29253 L
.908 .29313 L
.912 .29923 L
.916 .30726 L
.92 .31303 L
.924 .31449 L
.928 .31298 L
.932 .31071 L
.936 .31138 L
.94 .31552 L
.944 .32187 L
.948 .32803 L
.952 .32997 L
.956 .32801 L
.96 .32205 L
.964 .31526 L
.968 .31098 L
.972 .30918 L
.976 .31149 L
.98 .31458 L
.984 .31755 L
.988 .32004 L
.992 .32111 L
.996 .32377 L
1 .32727 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13528 m
.008 .13115 L
.012 .12977 L
.016 .13127 L
.02 .13167 L
.024 .13118 L
.028 .13102 L
.032 .13122 L
.036 .13125 L
.04 .1312 L
.044 .13116 L
.048 .1312 L
.052 .1312 L
.056 .13121 L
.06 .1312 L
.064 .13121 L
.068 .1312 L
.072 .13119 L
.076 .13118 L
.08 .13119 L
.084 .13119 L
.088 .13121 L
.092 .13121 L
.096 .13122 L
.1 .1312 L
.104 .1312 L
.108 .13118 L
.112 .13119 L
.116 .13119 L
.12 .1312 L
.124 .13121 L
.128 .13121 L
.132 .1312 L
.136 .13119 L
.14 .13119 L
.144 .13119 L
.148 .1312 L
.152 .13121 L
.156 .13121 L
.16 .13121 L
.164 .13119 L
.168 .13119 L
.172 .13118 L
.176 .13119 L
.18 .1312 L
.184 .13121 L
.188 .13121 L
.192 .13121 L
.196 .1312 L
.2 .13119 L
Mistroke
.204 .13119 L
.208 .1312 L
.212 .1312 L
.216 .1312 L
.22 .1312 L
.224 .1312 L
.228 .1312 L
.232 .13119 L
.236 .13119 L
.24 .13119 L
.244 .1312 L
.248 .13121 L
.252 .13121 L
.256 .13122 L
.26 .13121 L
.264 .1312 L
.268 .13119 L
.272 .13119 L
.276 .13119 L
.28 .13119 L
.284 .1312 L
.288 .1312 L
.292 .13121 L
.296 .13121 L
.3 .13122 L
.304 .13121 L
.308 .13121 L
.312 .1312 L
.316 .13119 L
.32 .13119 L
.324 .13118 L
.328 .13119 L
.332 .1312 L
.336 .13122 L
.34 .13122 L
.344 .13122 L
.348 .13121 L
.352 .1312 L
.356 .13119 L
.36 .13119 L
.364 .13119 L
.368 .1312 L
.372 .13121 L
.376 .13123 L
.38 .13123 L
.384 .13122 L
.388 .13121 L
.392 .13119 L
.396 .13118 L
.4 .13118 L
Mistroke
.404 .13118 L
.408 .1312 L
.412 .13122 L
.416 .13124 L
.42 .13124 L
.424 .13124 L
.428 .13122 L
.432 .13121 L
.436 .1312 L
.44 .13119 L
.444 .13118 L
.448 .13118 L
.452 .13119 L
.456 .13121 L
.46 .13123 L
.464 .13123 L
.468 .13123 L
.472 .13123 L
.476 .13123 L
.48 .13123 L
.484 .13122 L
.488 .13122 L
.492 .13121 L
.496 .13121 L
.5 .13121 L
.504 .13121 L
.508 .13119 L
.512 .13118 L
.516 .13117 L
.52 .13119 L
.524 .13123 L
.528 .13126 L
.532 .13128 L
.536 .13128 L
.54 .13128 L
.544 .13127 L
.548 .13125 L
.552 .13122 L
.556 .13118 L
.56 .13116 L
.564 .13118 L
.568 .13124 L
.572 .13132 L
.576 .13137 L
.58 .13139 L
.584 .13139 L
.588 .13139 L
.592 .13141 L
.596 .13142 L
.6 .13143 L
Mistroke
.604 .13145 L
.608 .13151 L
.612 .13165 L
.616 .13183 L
.62 .132 L
.624 .13213 L
.628 .13222 L
.632 .13231 L
.636 .13246 L
.64 .13268 L
.644 .13299 L
.648 .13335 L
.652 .13381 L
.656 .1344 L
.66 .13515 L
.664 .13607 L
.668 .13709 L
.672 .13819 L
.676 .13934 L
.68 .14061 L
.684 .14207 L
.688 .14378 L
.692 .14573 L
.696 .14788 L
.7 .15021 L
.704 .1527 L
.708 .15537 L
.712 .15822 L
.716 .16117 L
.72 .16414 L
.724 .16701 L
.728 .16971 L
.732 .17224 L
.736 .17463 L
.74 .17691 L
.744 .17907 L
.748 .18112 L
.752 .18304 L
.756 .18487 L
.76 .1867 L
.764 .18862 L
.768 .1907 L
.772 .19297 L
.776 .1954 L
.78 .19795 L
.784 .20052 L
.788 .20306 L
.792 .20554 L
.796 .20791 L
.8 .21019 L
Mistroke
.804 .21236 L
.808 .21441 L
.812 .21634 L
.816 .21817 L
.82 .21995 L
.824 .22176 L
.828 .2237 L
.832 .22579 L
.836 .22801 L
.84 .23022 L
.844 .23223 L
.848 .23388 L
.852 .23507 L
.856 .23581 L
.86 .23623 L
.864 .23648 L
.868 .23667 L
.872 .23685 L
.876 .23703 L
.88 .23718 L
.884 .23734 L
.888 .23763 L
.892 .23817 L
.896 .23907 L
.9 .24034 L
.904 .24188 L
.908 .24351 L
.912 .24503 L
.916 .24634 L
.92 .24737 L
.924 .2482 L
.928 .2489 L
.932 .24954 L
.936 .25013 L
.94 .25061 L
.944 .25096 L
.948 .25117 L
.952 .25127 L
.956 .25136 L
.96 .25147 L
.964 .25173 L
.968 .25203 L
.972 .2524 L
.976 .25272 L
.98 .25294 L
.984 .25307 L
.988 .25307 L
.992 .25299 L
.996 .25286 L
1 .25266 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15919 L
.012 .16107 L
.016 .16179 L
.02 .16128 L
.024 .16096 L
.028 .16111 L
.032 .16119 L
.036 .16116 L
.04 .16109 L
.044 .1611 L
.048 .1611 L
.052 .16111 L
.056 .16108 L
.06 .16109 L
.064 .16107 L
.068 .16107 L
.072 .16104 L
.076 .16103 L
.08 .16101 L
.084 .16101 L
.088 .161 L
.092 .16101 L
.096 .161 L
.1 .161 L
.104 .16098 L
.108 .16097 L
.112 .16095 L
.116 .16094 L
.12 .16093 L
.124 .16092 L
.128 .16091 L
.132 .1609 L
.136 .16089 L
.14 .16089 L
.144 .16088 L
.148 .16088 L
.152 .16087 L
.156 .16086 L
.16 .16084 L
.164 .16083 L
.168 .16081 L
.172 .1608 L
.176 .1608 L
.18 .1608 L
.184 .16079 L
.188 .16079 L
.192 .16078 L
.196 .16076 L
.2 .16074 L
Mistroke
.204 .16073 L
.208 .16072 L
.212 .16072 L
.216 .16072 L
.22 .16071 L
.224 .1607 L
.228 .16068 L
.232 .16066 L
.236 .16065 L
.24 .16065 L
.244 .16065 L
.248 .16065 L
.252 .16064 L
.256 .16063 L
.26 .16062 L
.264 .1606 L
.268 .16059 L
.272 .16057 L
.276 .16056 L
.28 .16055 L
.284 .16054 L
.288 .16054 L
.292 .16054 L
.296 .16054 L
.3 .16054 L
.304 .16053 L
.308 .16051 L
.312 .16048 L
.316 .16046 L
.32 .16045 L
.324 .16044 L
.328 .16044 L
.332 .16044 L
.336 .16045 L
.34 .16044 L
.344 .16043 L
.348 .16041 L
.352 .16039 L
.356 .16037 L
.36 .16035 L
.364 .16035 L
.368 .16035 L
.372 .16036 L
.376 .16037 L
.38 .16036 L
.384 .16033 L
.388 .16031 L
.392 .16028 L
.396 .16027 L
.4 .16025 L
Mistroke
.404 .16024 L
.408 .16025 L
.412 .16027 L
.416 .16028 L
.42 .16028 L
.424 .16027 L
.428 .16024 L
.432 .16021 L
.436 .16018 L
.44 .16016 L
.444 .16014 L
.448 .16013 L
.452 .16013 L
.456 .16015 L
.46 .16016 L
.464 .16016 L
.468 .16015 L
.472 .16013 L
.476 .16012 L
.48 .16011 L
.484 .1601 L
.488 .16008 L
.492 .16006 L
.496 .16005 L
.5 .16004 L
.504 .16002 L
.508 .16 L
.512 .15997 L
.516 .15995 L
.52 .15997 L
.524 .16 L
.528 .16002 L
.532 .16003 L
.536 .16002 L
.54 .16 L
.544 .15998 L
.548 .15993 L
.552 .15987 L
.556 .15979 L
.56 .15974 L
.564 .15974 L
.568 .15978 L
.572 .15983 L
.576 .15985 L
.58 .15982 L
.584 .15976 L
.588 .15969 L
.592 .15962 L
.596 .15954 L
.6 .15943 L
Mistroke
.604 .15932 L
.608 .15924 L
.612 .15922 L
.616 .15921 L
.62 .15916 L
.624 .15899 L
.628 .15872 L
.632 .15837 L
.636 .15799 L
.64 .15761 L
.644 .15718 L
.648 .15668 L
.652 .15609 L
.656 .15545 L
.66 .15476 L
.664 .15398 L
.668 .153 L
.672 .15172 L
.676 .15011 L
.68 .14819 L
.684 .14603 L
.688 .1437 L
.692 .14117 L
.696 .13841 L
.7 .13542 L
.704 .13223 L
.708 .12894 L
.712 .12562 L
.716 .1223 L
.72 .11895 L
.724 .11556 L
.728 .11214 L
.732 .10878 L
.736 .10557 L
.74 .10258 L
.744 .0998 L
.748 .09718 L
.752 .09463 L
.756 .09211 L
.76 .08959 L
.764 .08707 L
.768 .08454 L
.772 .08199 L
.776 .07934 L
.78 .07656 L
.784 .0736 L
.788 .0705 L
.792 .06731 L
.796 .06412 L
.8 .06102 L
Mistroke
.804 .05804 L
.808 .05519 L
.812 .05243 L
.816 .04973 L
.82 .04706 L
.824 .04448 L
.828 .04206 L
.832 .03989 L
.836 .038 L
.84 .03633 L
.844 .03482 L
.848 .03335 L
.852 .03189 L
.856 .03051 L
.86 .02927 L
.864 .02826 L
.868 .02744 L
.872 .02671 L
.876 .0259 L
.88 .02489 L
.884 .02367 L
.888 .02237 L
.892 .0212 L
.896 .02033 L
.9 .01979 L
.904 .01947 L
.908 .01915 L
.912 .0186 L
.916 .01771 L
.92 .0165 L
.924 .01519 L
.928 .01397 L
.932 .01303 L
.936 .01244 L
.94 .01206 L
.944 .01173 L
.948 .01121 L
.952 .01037 L
.956 .00918 L
.96 .00765 L
.964 .00601 L
.968 .00431 L
.972 .00282 L
.976 .00158 L
.98 .00067 L
.984 .0001 L
Mfstroke
.984 .0001 m
.98527 0 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool20014Ool2000WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo
0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool0
1000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`04001oo`00Ool40002Ool200001Goo001oogoo00000Woo00<007oo
Ool00Woo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Ool00002Ool01000Ool007oo0P0000=oo`0000000Woo00@007ooOol000Eoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`8000Aoo`D0009o
o`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol0
0goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00]oo`@000=oo`04
001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol4
0003Ool00`00Oomoo`0200000goo001oo`02Ool2000017oo001oogoo0P0000Eoo`00Oomoo`0000=o
o`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol0
0Woo0P0037oo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomo
o`0017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001oogooOol00002Ool00`00Oomo
o`040002Ool01@00Oomoogoo00000goo00<007oo00001Woo00@007ooOol000Eoo`008Woo0P0037oo
1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`<000=oo`<0
00Aoo`8000=oo`<000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol0?Woo00<007ooOol0
3Woo00<007ooOol06Woo000ROol2000nOol00`00Oomoo`0@Ool00`00Oomoo`02Ool2000EOol0029o
of<000aoo`008Woo3@0000=oo`0000000`0000Aoo`00001oo`80009oo`03001oogoo0080009oo`80
00=oo`05001oogooOol00003Ool01P00Ool007oo001oo`<00003Ool0000000@000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo0P000Woo0P000Woo0`0000Ioo`00000007oo000<Ool0029o
o`8000Moo`80009oo`03001oogoo00D00004Ool00000Ool200000goo0000000L00000goo001oo`0G
Ool40004Ool3000017oo0000000037oo000ROol00`00Oomoo`1COol20005Ool00`00Oomoo`0?Ool0
029oo`8006eoo`008Woo0P00KGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00
Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool2
0004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomo
o`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003
Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]
Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo
00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00
KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo
000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool0
1000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomo
o`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo
0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`00
27oo00@007ooOol0009oo`8000Aoocl002Yoo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<0
07ooOol0>goo0`00:7oo000XOol00`00Oomoo`0mOol2000WOol002Qoo`03001oogoo03moo`8002Eo
o`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0@7oo0`008goo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol004Ao
o`<0025oo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOol004Ioo`80021oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P00
0Woo1@000goo0`000goo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@0
07ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`00
00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`@0009oo`05001oogooOol0
0002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001o
ogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@0
07ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo100017oo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0
3Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool0
1000Oomoo`000Woo1@0000=oo`00Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<0
07ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo
0002Ool01@00Oomoo`00Ool020000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007oo
Ool017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<0
07ooOol017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool0
0`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P00
17oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
G@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool0
0`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool0
0`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P00
0Woo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo
0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomo
o`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo
0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007oo
Oomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool0
00]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo061oo`@000ioo`002Woo00@007oo
Ool000Moo`05001oogooOol00002Ool00`00Oomoo`1LOol5000AOol000=oo`D0009oo`04001oogoo
000;Ool00`00Oomoo`02001HOol5000FOol000Yoo`04001oogoo000;Ool01000Oomoo`00EWoo1000
6Woo000:Ool01000Oomoo`001goo10000goo00<007ooOol0DWoo0`007Goo000:Ool01000Oomoo`00
1goo00<007ooOol017oo0P00DWoo0P007goo000;Ool20008Ool50002Ool00`00Oomoo`1?Ool2000Q
Ool001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Ao
o`8000Eoo`D0009oo`<000Aoo`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007oo
Oomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOol007oo0080009o
o`04001oogoo0002Ool00`00Oomoo`03Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`04Ool01P00Ool00000Ool0009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Goo0P000Woo00@007ooOol0009oo`04001oogoo0007Ool00`00Oomo
o`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007oo
Ool000Aoo`<00005Ool007ooOol00002Ool01000Oomoo`000Woo00<007ooOol00Woo00H007ooOomo
o`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomo
o`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000
Oomoo`0017oo0P000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02Ool01`00Oomo
ogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=o
o`8000Aoo`8000Ioo`04001oogooOol50003Ool20004Ool50004Ool20004Ool20006Ool30002Ool5
0003Ool20006Ool001aoo`03001oogoo04Aoo`<002]oo`0077oo00<007ooOol0@Woo0`00;Goo000L
OomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool0
1000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo
0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00
Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo
000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol0
0Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00
Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo
008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomo
o`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(44756\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32002 m
.008 .31935 L
.012 .31808 L
.016 .31787 L
.02 .31885 L
.024 .31919 L
.028 .31888 L
.032 .31888 L
.036 .31899 L
.04 .31879 L
.044 .31844 L
.048 .31827 L
.052 .31842 L
.056 .31874 L
.06 .31905 L
.064 .31926 L
.068 .31922 L
.072 .31899 L
.076 .31871 L
.08 .31856 L
.084 .31864 L
.088 .31887 L
.092 .31906 L
.096 .31911 L
.1 .31897 L
.104 .31877 L
.108 .31871 L
.112 .31885 L
.116 .31915 L
.12 .31943 L
.124 .31946 L
.128 .3192 L
.132 .31878 L
.136 .31848 L
.14 .31851 L
.144 .31886 L
.148 .31934 L
.152 .3197 L
.156 .31971 L
.16 .31939 L
.164 .31893 L
.168 .31862 L
.172 .31867 L
.176 .319 L
.18 .3194 L
.184 .31965 L
.188 .31964 L
.192 .3194 L
.196 .31904 L
.2 .31879 L
Mistroke
.204 .31882 L
.208 .31913 L
.212 .31954 L
.216 .31983 L
.22 .31984 L
.224 .31961 L
.228 .3192 L
.232 .31881 L
.236 .31867 L
.24 .31894 L
.244 .31952 L
.248 .32006 L
.252 .32022 L
.256 .31991 L
.26 .31935 L
.264 .31885 L
.268 .31868 L
.272 .31895 L
.276 .31957 L
.28 .32021 L
.284 .32045 L
.288 .32011 L
.292 .31941 L
.296 .31884 L
.3 .31872 L
.304 .31904 L
.308 .31959 L
.312 .32013 L
.316 .32046 L
.32 .32043 L
.324 .31998 L
.328 .31931 L
.332 .31883 L
.336 .31884 L
.34 .31929 L
.344 .31988 L
.348 .32033 L
.352 .32051 L
.356 .32039 L
.36 .31998 L
.364 .31938 L
.368 .31894 L
.372 .31898 L
.376 .31953 L
.38 .32023 L
.384 .32062 L
.388 .32055 L
.392 .32021 L
.396 .31986 L
.4 .31959 L
Mistroke
.404 .31939 L
.408 .31931 L
.412 .31948 L
.416 .31993 L
.42 .32042 L
.424 .32064 L
.428 .3205 L
.432 .32018 L
.436 .31993 L
.44 .31985 L
.444 .3198 L
.448 .3197 L
.452 .31963 L
.456 .31978 L
.46 .32015 L
.464 .32053 L
.468 .32065 L
.472 .32049 L
.476 .32023 L
.48 .32009 L
.484 .32006 L
.488 .31994 L
.492 .31966 L
.496 .31946 L
.5 .31968 L
.504 .32037 L
.508 .32112 L
.512 .32135 L
.516 .3209 L
.52 .32013 L
.524 .31959 L
.528 .31944 L
.532 .31941 L
.536 .3192 L
.54 .31902 L
.544 .31939 L
.548 .32049 L
.552 .3217 L
.556 .32197 L
.56 .32085 L
.564 .31896 L
.568 .31752 L
.572 .31722 L
.576 .31762 L
.58 .31777 L
.584 .3173 L
.588 .3168 L
.592 .31704 L
.596 .3178 L
.6 .31775 L
Mistroke
.604 .31566 L
.608 .31166 L
.612 .3074 L
.616 .30455 L
.62 .30325 L
.624 .30195 L
.628 .29887 L
.632 .29371 L
.636 .28772 L
.64 .28226 L
.644 .27717 L
.648 .27076 L
.652 .26158 L
.656 .25006 L
.66 .23858 L
.664 .22961 L
.668 .22363 L
.672 .21894 L
.676 .21337 L
.68 .20653 L
.684 .20031 L
.688 .19728 L
.692 .19848 L
.696 .20253 L
.7 .207 L
.704 .21053 L
.708 .21397 L
.712 .21929 L
.716 .22739 L
.72 .23674 L
.724 .24418 L
.728 .24704 L
.732 .245 L
.736 .24011 L
.74 .23508 L
.744 .23137 L
.748 .22861 L
.752 .22558 L
.756 .22183 L
.76 .21847 L
.764 .21753 L
.768 .22051 L
.772 .22721 L
.776 .23583 L
.78 .24392 L
.784 .24972 L
.788 .25277 L
.792 .25377 L
.796 .25409 L
.8 .25501 L
Mistroke
.804 .25757 L
.808 .26223 L
.812 .26893 L
.816 .27715 L
.82 .28611 L
.824 .29535 L
.828 .30468 L
.832 .31429 L
.836 .32387 L
.84 .33221 L
.844 .33729 L
.848 .3371 L
.852 .33133 L
.856 .32184 L
.86 .31249 L
.864 .30712 L
.868 .30733 L
.872 .31155 L
.876 .31561 L
.88 .31529 L
.884 .30915 L
.888 .29942 L
.892 .29144 L
.896 .29039 L
.9 .29821 L
.904 .31281 L
.908 .32781 L
.912 .33726 L
.916 .33722 L
.92 .32843 L
.924 .31597 L
.928 .30496 L
.932 .30053 L
.936 .30282 L
.94 .30944 L
.944 .31691 L
.948 .32092 L
.952 .32168 L
.956 .31951 L
.96 .31714 L
.964 .31709 L
.968 .31889 L
.972 .32291 L
.976 .32662 L
.98 .32889 L
.984 .32956 L
.988 .32825 L
.992 .32632 L
.996 .32415 L
1 .322 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13486 m
.008 .13175 L
.012 .13062 L
.016 .13156 L
.02 .13195 L
.024 .13171 L
.028 .13154 L
.032 .13163 L
.036 .13167 L
.04 .13167 L
.044 .13163 L
.048 .13165 L
.052 .13164 L
.056 .13166 L
.06 .13164 L
.064 .13165 L
.068 .13164 L
.072 .13165 L
.076 .13164 L
.08 .13165 L
.084 .13165 L
.088 .13166 L
.092 .13165 L
.096 .13165 L
.1 .13164 L
.104 .13164 L
.108 .13164 L
.112 .13165 L
.116 .13165 L
.12 .13166 L
.124 .13165 L
.128 .13165 L
.132 .13165 L
.136 .13165 L
.14 .13164 L
.144 .13165 L
.148 .13165 L
.152 .13165 L
.156 .13165 L
.16 .13165 L
.164 .13164 L
.168 .13165 L
.172 .13165 L
.176 .13166 L
.18 .13166 L
.184 .13166 L
.188 .13165 L
.192 .13164 L
.196 .13163 L
.2 .13164 L
Mistroke
.204 .13165 L
.208 .13166 L
.212 .13166 L
.216 .13166 L
.22 .13165 L
.224 .13164 L
.228 .13164 L
.232 .13165 L
.236 .13165 L
.24 .13166 L
.244 .13166 L
.248 .13165 L
.252 .13165 L
.256 .13164 L
.26 .13164 L
.264 .13165 L
.268 .13165 L
.272 .13166 L
.276 .13166 L
.28 .13166 L
.284 .13166 L
.288 .13166 L
.292 .13165 L
.296 .13165 L
.3 .13164 L
.304 .13164 L
.308 .13164 L
.312 .13165 L
.316 .13166 L
.32 .13167 L
.324 .13167 L
.328 .13167 L
.332 .13167 L
.336 .13166 L
.34 .13165 L
.344 .13164 L
.348 .13163 L
.352 .13164 L
.356 .13165 L
.36 .13167 L
.364 .13167 L
.368 .13167 L
.372 .13167 L
.376 .13166 L
.38 .13164 L
.384 .13164 L
.388 .13164 L
.392 .13165 L
.396 .13167 L
.4 .13167 L
Mistroke
.404 .13168 L
.408 .13167 L
.412 .13166 L
.416 .13165 L
.42 .13164 L
.424 .13163 L
.428 .13163 L
.432 .13165 L
.436 .13167 L
.44 .13168 L
.444 .13169 L
.448 .13169 L
.452 .13168 L
.456 .13167 L
.46 .13166 L
.464 .13164 L
.468 .13163 L
.472 .13163 L
.476 .13164 L
.48 .13166 L
.484 .13167 L
.488 .13168 L
.492 .13168 L
.496 .13168 L
.5 .13169 L
.504 .13169 L
.508 .13169 L
.512 .13168 L
.516 .13168 L
.52 .13169 L
.524 .13169 L
.528 .13169 L
.532 .13168 L
.536 .13167 L
.54 .13167 L
.544 .1317 L
.548 .13175 L
.552 .13179 L
.556 .13183 L
.56 .13186 L
.564 .1319 L
.568 .13193 L
.572 .13195 L
.576 .13195 L
.58 .13195 L
.584 .13199 L
.588 .13209 L
.592 .13224 L
.596 .13241 L
.6 .13259 L
Mistroke
.604 .13277 L
.608 .13298 L
.612 .13323 L
.616 .13352 L
.62 .13385 L
.624 .13423 L
.628 .13471 L
.632 .13534 L
.636 .13614 L
.64 .1371 L
.644 .13818 L
.648 .13935 L
.652 .14064 L
.656 .14211 L
.66 .14378 L
.664 .14566 L
.668 .14773 L
.672 .14998 L
.676 .15241 L
.68 .15506 L
.684 .15789 L
.688 .16083 L
.692 .16378 L
.696 .16662 L
.7 .16932 L
.704 .17186 L
.708 .17429 L
.712 .1766 L
.716 .17879 L
.72 .18085 L
.724 .18278 L
.728 .18467 L
.732 .1866 L
.736 .18863 L
.74 .19079 L
.744 .19303 L
.748 .19533 L
.752 .19766 L
.756 .20003 L
.76 .20246 L
.764 .20493 L
.768 .2074 L
.772 .20978 L
.776 .21203 L
.78 .21414 L
.784 .21613 L
.788 .21808 L
.792 .22004 L
.796 .22205 L
.8 .22411 L
Mistroke
.804 .22616 L
.808 .22814 L
.812 .22998 L
.816 .23163 L
.82 .23306 L
.824 .23425 L
.828 .23519 L
.832 .23588 L
.836 .23633 L
.84 .23659 L
.844 .23675 L
.848 .23694 L
.852 .2373 L
.856 .23794 L
.86 .23888 L
.864 .24002 L
.868 .24124 L
.872 .24236 L
.876 .24333 L
.88 .24414 L
.884 .24488 L
.888 .24564 L
.892 .24644 L
.896 .24722 L
.9 .24787 L
.904 .24827 L
.908 .24843 L
.912 .24845 L
.916 .2485 L
.92 .2488 L
.924 .24946 L
.928 .25047 L
.932 .25172 L
.936 .25299 L
.94 .25416 L
.944 .25508 L
.948 .25577 L
.952 .25625 L
.956 .2566 L
.96 .25686 L
.964 .25701 L
.968 .25704 L
.972 .25691 L
.976 .2566 L
.98 .25617 L
.984 .25561 L
.988 .25504 L
.992 .25444 L
.996 .25389 L
1 .25336 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16397 L
.012 .1611 L
.016 .16019 L
.02 .16124 L
.024 .16148 L
.028 .16113 L
.032 .16101 L
.036 .16116 L
.04 .16116 L
.044 .16112 L
.048 .16108 L
.052 .16111 L
.056 .16108 L
.06 .16108 L
.064 .16105 L
.068 .16105 L
.072 .16103 L
.076 .16104 L
.08 .16104 L
.084 .16104 L
.088 .16103 L
.092 .16101 L
.096 .16098 L
.1 .16096 L
.104 .16095 L
.108 .16095 L
.112 .16095 L
.116 .16096 L
.12 .16095 L
.124 .16094 L
.128 .16091 L
.132 .1609 L
.136 .16088 L
.14 .16088 L
.144 .16088 L
.148 .16088 L
.152 .16086 L
.156 .16085 L
.16 .16083 L
.164 .16083 L
.168 .16082 L
.172 .16082 L
.176 .16082 L
.18 .16081 L
.184 .16079 L
.188 .16077 L
.192 .16075 L
.196 .16074 L
.2 .16074 L
Mistroke
.204 .16074 L
.208 .16074 L
.212 .16073 L
.216 .16072 L
.22 .16071 L
.224 .16069 L
.228 .16067 L
.232 .16066 L
.236 .16066 L
.24 .16066 L
.244 .16066 L
.248 .16065 L
.252 .16063 L
.256 .16061 L
.26 .16059 L
.264 .16058 L
.268 .16058 L
.272 .16059 L
.276 .16059 L
.28 .16058 L
.284 .16057 L
.288 .16055 L
.292 .16053 L
.296 .16051 L
.3 .1605 L
.304 .16049 L
.308 .16048 L
.312 .16048 L
.316 .16048 L
.32 .16048 L
.324 .16048 L
.328 .16047 L
.332 .16045 L
.336 .16043 L
.34 .16041 L
.344 .16039 L
.348 .16038 L
.352 .16038 L
.356 .16038 L
.36 .16038 L
.364 .16038 L
.368 .16038 L
.372 .16036 L
.376 .16034 L
.38 .16031 L
.384 .16029 L
.388 .16028 L
.392 .16029 L
.396 .1603 L
.4 .16031 L
Mistroke
.404 .1603 L
.408 .16028 L
.412 .16026 L
.416 .16023 L
.42 .16021 L
.424 .16019 L
.428 .16018 L
.432 .16019 L
.436 .1602 L
.44 .16022 L
.444 .16022 L
.448 .16021 L
.452 .16019 L
.456 .16016 L
.46 .16013 L
.464 .1601 L
.468 .16008 L
.472 .16007 L
.476 .16007 L
.48 .16008 L
.484 .16009 L
.488 .16009 L
.492 .16008 L
.496 .16007 L
.5 .16006 L
.504 .16005 L
.508 .16003 L
.512 .16 L
.516 .15999 L
.52 .15998 L
.524 .15997 L
.528 .15994 L
.532 .15989 L
.536 .15985 L
.54 .15983 L
.544 .15983 L
.548 .15984 L
.552 .15984 L
.556 .15982 L
.56 .1598 L
.564 .15976 L
.568 .15971 L
.572 .15962 L
.576 .15948 L
.58 .15933 L
.584 .1592 L
.588 .1591 L
.592 .15903 L
.596 .15893 L
.6 .15878 L
Mistroke
.604 .15856 L
.608 .15829 L
.612 .15796 L
.616 .15756 L
.62 .15705 L
.624 .15642 L
.628 .15571 L
.632 .15494 L
.636 .1541 L
.64 .15313 L
.644 .15194 L
.648 .15048 L
.652 .14873 L
.656 .14673 L
.66 .1445 L
.664 .14204 L
.668 .13934 L
.672 .1364 L
.676 .13328 L
.68 .13007 L
.684 .12681 L
.688 .12352 L
.692 .12016 L
.696 .11671 L
.7 .11321 L
.704 .10977 L
.708 .10648 L
.712 .1034 L
.716 .10053 L
.72 .09781 L
.724 .0952 L
.728 .09271 L
.732 .09032 L
.736 .08801 L
.74 .08568 L
.744 .08323 L
.748 .08055 L
.752 .07762 L
.756 .07451 L
.76 .07132 L
.764 .06812 L
.768 .06498 L
.772 .06192 L
.776 .05892 L
.78 .05603 L
.784 .05326 L
.788 .05065 L
.792 .04821 L
.796 .04592 L
.8 .04371 L
Mistroke
.804 .04153 L
.808 .03934 L
.812 .03717 L
.816 .03507 L
.82 .03313 L
.824 .03145 L
.828 .03006 L
.832 .02894 L
.836 .02802 L
.84 .02722 L
.844 .02647 L
.848 .02576 L
.852 .02514 L
.856 .02463 L
.86 .02425 L
.864 .0239 L
.868 .02344 L
.872 .02273 L
.876 .02171 L
.88 .02042 L
.884 .01895 L
.888 .01744 L
.892 .01598 L
.896 .01456 L
.9 .01316 L
.904 .01177 L
.908 .01043 L
.912 .00929 L
.916 .00848 L
.92 .0081 L
.924 .00809 L
.928 .00826 L
.932 .00838 L
.936 .00818 L
.94 .00764 L
.944 .00675 L
.948 .00579 L
.952 .00496 L
.956 .00444 L
.96 .00427 L
.964 .00434 L
.968 .00448 L
.972 .00453 L
.976 .00436 L
.98 .00399 L
.984 .00344 L
.988 .00285 L
.992 .00229 L
.996 .00184 L
1 .00151 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool20011Ool2000ZOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo
0`0000=oo`00000010000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol0
0002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00
Oomoogoo00000goo00D007ooOol007oo008000=oo`03001oogoo00@0009oo`04001oogoo0002Ool0
0`00Oomoo`02Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001o
ogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00D0
07ooOol007oo008000=oo`@00003Ool00000009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`03001oogoo00800003Ool007oo00=o
o`8000=oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol017oo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;Ool4
0003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000
Oomoogoo10000goo0P0000Eoo`00Oomoo`0000=oo`03001oogoo00@0009oo`04001oogoo0003Ool0
1P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo009o
o`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0
00Aoo`8000=oo`03001oogoo00Aoo`800005Ool007ooOol00003Ool01000Oomoo`000Woo00@007oo
Ool0009oo`05001oogooOol00003Ool00`00Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool5
0003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000Woo0`0017oo0`00
17oo10000Woo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`0kOol00`00Oomoo`0?
Ool00`00Oomoo`0LOol0029oo`8003aoo`03001oogoo00moo`03001oogoo00Aoo`8001Ioo`008Woo
H`0037oo000ROol?000017oo000007oo0P0000Eoo`00000007oo00800003Ool0000000<00003Ool0
0000009oo`05001oogooOol00003Ool01000Oomoogoo0`0000=oo`0000000`000Woo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool00`00Oomoo`02000037oo00000000Ool007oo001oo`00Ool0
00=oo`03001oogoo00Yoo`008Woo0P002Woo00<007ooOol00P0000Aoo`00001oo`800004Ool00000
Ool600000goo0000000D000JOol00`00Ool00004Ool2000017oo000007oo100037oo000ROol00`00
Oomoo`1?Ool20005Ool00`00Oomoo`0COol0029oo`8006eoo`008Woo0P00KGoo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<0
07ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo
0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo
001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
1000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`00
2goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo
00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yo
o`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0
029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03
001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool0
0`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007oo
Ool00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00
Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<0
07ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00
Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aooc`002eoo`004Goo
0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0>7oo0`00:goo000XOol00`00Oomoo`0kOol2
000YOol002Qoo`03001oogoo03aoo`8002Qoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P00
0goo0`000goo00<007ooOol0?Goo0`009Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06
001oogoo001oo`000goo00@007ooOol0045oo`<002Aoo`000goo1@000Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`001Goo00@007ooOol004Aoo`80029oo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo
0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@0000=oo`0000000P0017oo0P000goo1@000Woo
0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003
Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00<007ooOol010000Woo00@007ooOol000=oo`06001oogoo001oo`000goo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Io
o`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00<0
07ooOol01@0000=oo`00Ool00goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`00
2goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo
00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`060003Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`00
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo10000goo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo00X000=oo`04001o
ogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eo
o`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007oo
Oomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007oo
Ool047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo
00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo
00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool0
0`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool0
0`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Io
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00
Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003
Ool00`00Oomoo`1LOol:000<Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0FGoo0`005Woo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00EGoo1P0067oo000:
Ool01000Oomoo`002goo00@007ooOol005=oo`@001eoo`002Woo00@007ooOol000Moo`@000=oo`03
001oogoo04moo`<0021oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8004moo`80029oo`00
2goo0P0027oo1@000Woo00<007ooOol0CGoo00<007ooOol08Woo000LOol00`00Oomoo`0=Ool30004
Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool60002Ool20004Ool20005
Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007oo
Ool0009oo`03001oogoo00=oo`04001oo`000002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06
001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`8000Aoo`04001oogoo0002Ool01000
Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol0
47oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`800003Ool007oo009oo`04
001oogoo0002Ool01000Oomoo`001goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=o
o`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0003Ool20003Ool01000Oomoo`000Woo00@0
07ooOol0009oo`03001oogoo009oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo
00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000
Oomoo`0017oo0P000goo00<007ooOol017oo00D007ooOol007oo00800003Ool007oo009oo`04001o
ogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo00L007ooOomoo`00Ool00006Ool01000Oomo
o`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomo
ogoo1@000goo0P0000=oo`0000000goo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo
000LOol00`00Oomoo`12Ool2000^Ool001aoo`03001oogoo03moo`<0031oo`0077ooJ@0037oo000L
Ool20002Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol0
0P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo
1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00
Oomoo`02Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo
00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00
Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomo
o`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001o
ogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo
000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(44923\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31992 m
.008 .31881 L
.012 .31845 L
.016 .31829 L
.02 .31852 L
.024 .31864 L
.028 .31848 L
.032 .31847 L
.036 .31871 L
.04 .31891 L
.044 .31896 L
.048 .31891 L
.052 .31882 L
.056 .31875 L
.06 .31867 L
.064 .31864 L
.068 .31866 L
.072 .3187 L
.076 .31878 L
.08 .31887 L
.084 .31895 L
.088 .31903 L
.092 .31904 L
.096 .31897 L
.1 .31886 L
.104 .31876 L
.108 .31875 L
.112 .31884 L
.116 .31898 L
.12 .31909 L
.124 .3191 L
.128 .319 L
.132 .31889 L
.136 .31886 L
.14 .31899 L
.144 .3192 L
.148 .31932 L
.152 .31928 L
.156 .31906 L
.16 .3188 L
.164 .31869 L
.168 .31884 L
.172 .31921 L
.176 .31957 L
.18 .31966 L
.184 .31942 L
.188 .31901 L
.192 .31871 L
.196 .31872 L
.2 .31904 L
Mistroke
.204 .3195 L
.208 .31982 L
.212 .31977 L
.216 .31938 L
.22 .31889 L
.224 .31864 L
.228 .31881 L
.232 .31925 L
.236 .31972 L
.24 .32 L
.244 .31995 L
.248 .31961 L
.252 .31911 L
.256 .31874 L
.26 .31873 L
.264 .3191 L
.268 .31962 L
.272 .32001 L
.276 .32012 L
.28 .31992 L
.284 .31949 L
.288 .31901 L
.292 .31876 L
.296 .31897 L
.3 .31956 L
.304 .32016 L
.308 .32037 L
.312 .3201 L
.316 .31956 L
.32 .31908 L
.324 .31886 L
.328 .31899 L
.332 .31947 L
.336 .32009 L
.34 .32052 L
.344 .32047 L
.348 .31996 L
.352 .31936 L
.356 .31902 L
.36 .31906 L
.364 .31935 L
.368 .31974 L
.372 .32017 L
.376 .3205 L
.38 .32051 L
.384 .32009 L
.388 .31946 L
.392 .31903 L
.396 .3191 L
.4 .31957 L
Mistroke
.404 .32011 L
.408 .32044 L
.412 .32052 L
.416 .32041 L
.42 .32014 L
.424 .31973 L
.428 .31933 L
.432 .3192 L
.436 .31948 L
.44 .32 L
.444 .32044 L
.448 .32056 L
.452 .32042 L
.456 .32023 L
.46 .32011 L
.464 .31999 L
.468 .31978 L
.472 .31956 L
.476 .31953 L
.48 .3198 L
.484 .32021 L
.488 .32045 L
.492 .3204 L
.496 .3202 L
.5 .3201 L
.504 .32015 L
.508 .32009 L
.512 .3197 L
.516 .31912 L
.52 .31882 L
.524 .31911 L
.528 .31984 L
.532 .32038 L
.536 .32027 L
.54 .31963 L
.544 .31892 L
.548 .31846 L
.552 .31802 L
.556 .31718 L
.56 .31597 L
.564 .31503 L
.568 .31495 L
.572 .31551 L
.576 .31562 L
.58 .31421 L
.584 .3112 L
.588 .30754 L
.592 .30418 L
.596 .30116 L
.6 .29759 L
Mistroke
.604 .2928 L
.608 .28712 L
.612 .28159 L
.616 .27667 L
.62 .27145 L
.624 .26429 L
.628 .25443 L
.632 .24296 L
.636 .23211 L
.64 .22343 L
.644 .21669 L
.648 .21053 L
.652 .20419 L
.656 .19865 L
.66 .19578 L
.664 .19658 L
.668 .20002 L
.672 .20391 L
.676 .20694 L
.68 .20983 L
.684 .21458 L
.688 .22224 L
.692 .23148 L
.696 .23925 L
.7 .24299 L
.704 .24249 L
.708 .23969 L
.712 .23679 L
.716 .23432 L
.72 .23109 L
.724 .22585 L
.728 .2192 L
.732 .21379 L
.736 .2126 L
.74 .21678 L
.744 .22474 L
.748 .23328 L
.752 .23984 L
.756 .24392 L
.76 .24682 L
.764 .25007 L
.768 .25399 L
.772 .25766 L
.776 .26002 L
.78 .26124 L
.784 .26296 L
.788 .26743 L
.792 .27607 L
.796 .28844 L
.8 .30255 L
Mistroke
.804 .31568 L
.808 .32564 L
.812 .3313 L
.816 .33277 L
.82 .33108 L
.824 .32759 L
.828 .32377 L
.832 .32044 L
.836 .31771 L
.84 .31498 L
.844 .31143 L
.848 .30689 L
.852 .30217 L
.856 .29879 L
.86 .29818 L
.864 .30041 L
.868 .3043 L
.872 .30792 L
.876 .30995 L
.88 .31099 L
.884 .31256 L
.888 .31663 L
.892 .3231 L
.896 .32941 L
.9 .3321 L
.904 .32781 L
.908 .31733 L
.912 .30438 L
.916 .29505 L
.92 .29482 L
.924 .30408 L
.928 .31982 L
.932 .33463 L
.936 .34196 L
.94 .3393 L
.944 .32798 L
.948 .31469 L
.952 .30546 L
.956 .30427 L
.96 .31104 L
.964 .32111 L
.968 .32963 L
.972 .33265 L
.976 .32969 L
.98 .32331 L
.984 .31753 L
.988 .31487 L
.992 .31634 L
.996 .3207 L
1 .32447 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12858 m
.008 .13219 L
.012 .1333 L
.016 .13203 L
.02 .13166 L
.024 .13215 L
.028 .13224 L
.032 .13209 L
.036 .13203 L
.04 .13211 L
.044 .13211 L
.048 .1321 L
.052 .13208 L
.056 .1321 L
.06 .13209 L
.064 .1321 L
.068 .13209 L
.072 .13211 L
.076 .1321 L
.08 .13211 L
.084 .13209 L
.088 .13209 L
.092 .13208 L
.096 .13209 L
.1 .13209 L
.104 .13211 L
.108 .13211 L
.112 .13211 L
.116 .1321 L
.12 .13209 L
.124 .13208 L
.128 .13208 L
.132 .13209 L
.136 .1321 L
.14 .1321 L
.144 .13211 L
.148 .1321 L
.152 .1321 L
.156 .13209 L
.16 .1321 L
.164 .1321 L
.168 .1321 L
.172 .1321 L
.176 .1321 L
.18 .1321 L
.184 .13209 L
.188 .13209 L
.192 .1321 L
.196 .1321 L
.2 .13211 L
Mistroke
.204 .13211 L
.208 .13211 L
.212 .1321 L
.216 .13209 L
.22 .13209 L
.224 .13209 L
.228 .13209 L
.232 .1321 L
.236 .13211 L
.24 .13211 L
.244 .13211 L
.248 .1321 L
.252 .13209 L
.256 .13209 L
.26 .1321 L
.264 .13211 L
.268 .13211 L
.272 .13211 L
.276 .1321 L
.28 .13209 L
.284 .13209 L
.288 .13209 L
.292 .1321 L
.296 .13211 L
.3 .13211 L
.304 .13211 L
.308 .13211 L
.312 .13211 L
.316 .13211 L
.32 .1321 L
.324 .13209 L
.328 .13209 L
.332 .13209 L
.336 .1321 L
.34 .13211 L
.344 .13211 L
.348 .13212 L
.352 .13212 L
.356 .13212 L
.36 .13211 L
.364 .1321 L
.368 .13209 L
.372 .13209 L
.376 .13209 L
.38 .1321 L
.384 .13211 L
.388 .13212 L
.392 .13213 L
.396 .13212 L
.4 .13211 L
Mistroke
.404 .1321 L
.408 .13209 L
.412 .13209 L
.416 .1321 L
.42 .13211 L
.424 .13212 L
.428 .13213 L
.432 .13213 L
.436 .13212 L
.44 .13211 L
.444 .13209 L
.448 .13208 L
.452 .13208 L
.456 .1321 L
.46 .13212 L
.464 .13213 L
.468 .13214 L
.472 .13215 L
.476 .13215 L
.48 .13214 L
.484 .13213 L
.488 .13211 L
.492 .1321 L
.496 .1321 L
.5 .13212 L
.504 .13214 L
.508 .13216 L
.512 .13217 L
.516 .13219 L
.52 .13221 L
.524 .13223 L
.528 .13224 L
.532 .13226 L
.536 .13228 L
.54 .13232 L
.544 .13236 L
.548 .13241 L
.552 .13245 L
.556 .13249 L
.56 .13256 L
.564 .13265 L
.568 .13278 L
.572 .13294 L
.576 .13313 L
.58 .13335 L
.584 .13361 L
.588 .13393 L
.592 .13428 L
.596 .13467 L
.6 .13511 L
Mistroke
.604 .13565 L
.608 .13632 L
.612 .13716 L
.616 .13817 L
.62 .13932 L
.624 .14064 L
.628 .14213 L
.632 .14381 L
.636 .14569 L
.64 .14772 L
.644 .14991 L
.648 .15225 L
.652 .15476 L
.656 .15745 L
.66 .16029 L
.664 .16318 L
.668 .16604 L
.672 .16881 L
.676 .17147 L
.68 .174 L
.684 .1764 L
.688 .17865 L
.692 .18074 L
.696 .1827 L
.7 .18461 L
.704 .18656 L
.708 .18859 L
.712 .19072 L
.716 .1929 L
.72 .19511 L
.724 .19735 L
.728 .19966 L
.732 .20206 L
.736 .2045 L
.74 .20693 L
.744 .2093 L
.748 .21156 L
.752 .21374 L
.756 .21589 L
.76 .21802 L
.764 .22012 L
.768 .22217 L
.772 .22414 L
.776 .22602 L
.78 .22784 L
.784 .22959 L
.788 .23127 L
.792 .2328 L
.796 .23412 L
.8 .23516 L
Mistroke
.804 .23593 L
.808 .23647 L
.812 .23688 L
.816 .23725 L
.82 .23767 L
.824 .23818 L
.828 .23879 L
.832 .23948 L
.836 .24023 L
.84 .241 L
.844 .24181 L
.848 .24264 L
.852 .24351 L
.856 .24437 L
.86 .24521 L
.864 .24598 L
.868 .24668 L
.872 .24734 L
.876 .24802 L
.88 .24877 L
.884 .24958 L
.888 .2504 L
.892 .25116 L
.896 .25178 L
.9 .25228 L
.904 .25271 L
.908 .2532 L
.912 .25377 L
.916 .25445 L
.92 .25508 L
.924 .25553 L
.928 .25565 L
.932 .25545 L
.936 .25504 L
.94 .25463 L
.944 .25442 L
.948 .25453 L
.952 .25492 L
.956 .25549 L
.96 .256 L
.964 .25634 L
.968 .25644 L
.972 .25635 L
.976 .25616 L
.98 .25597 L
.984 .25584 L
.988 .25574 L
.992 .25563 L
.996 .25545 L
1 .25516 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16368 L
.012 .16133 L
.016 .16037 L
.02 .1611 L
.024 .1614 L
.028 .16121 L
.032 .16105 L
.036 .16112 L
.04 .16113 L
.044 .16112 L
.048 .16108 L
.052 .1611 L
.056 .16109 L
.06 .16109 L
.064 .16107 L
.068 .16106 L
.072 .16104 L
.076 .16104 L
.08 .16102 L
.084 .16102 L
.088 .161 L
.092 .161 L
.096 .16099 L
.1 .16099 L
.104 .16097 L
.108 .16097 L
.112 .16096 L
.116 .16095 L
.12 .16093 L
.124 .16092 L
.128 .1609 L
.132 .1609 L
.136 .16089 L
.14 .1609 L
.144 .16089 L
.148 .16088 L
.152 .16086 L
.156 .16085 L
.16 .16083 L
.164 .16083 L
.168 .16082 L
.172 .16082 L
.176 .16081 L
.18 .16079 L
.184 .16078 L
.188 .16077 L
.192 .16076 L
.196 .16076 L
.2 .16076 L
Mistroke
.204 .16075 L
.208 .16073 L
.212 .16071 L
.216 .16069 L
.22 .16069 L
.224 .16068 L
.228 .16068 L
.232 .16068 L
.236 .16067 L
.24 .16066 L
.244 .16064 L
.248 .16063 L
.252 .16062 L
.256 .16061 L
.26 .16061 L
.264 .1606 L
.268 .16059 L
.272 .16058 L
.276 .16057 L
.28 .16055 L
.284 .16054 L
.288 .16053 L
.292 .16053 L
.296 .16053 L
.3 .16053 L
.304 .16052 L
.308 .16051 L
.312 .16049 L
.316 .16048 L
.32 .16046 L
.324 .16044 L
.328 .16043 L
.332 .16042 L
.336 .16042 L
.34 .16042 L
.344 .16042 L
.348 .16042 L
.352 .16042 L
.356 .1604 L
.36 .16038 L
.364 .16035 L
.368 .16033 L
.372 .16032 L
.376 .16032 L
.38 .16032 L
.384 .16032 L
.388 .16032 L
.392 .16032 L
.396 .1603 L
.4 .16028 L
Mistroke
.404 .16026 L
.408 .16024 L
.412 .16023 L
.416 .16023 L
.42 .16024 L
.424 .16024 L
.428 .16024 L
.432 .16023 L
.436 .16021 L
.44 .16018 L
.444 .16015 L
.448 .16013 L
.452 .16012 L
.456 .16012 L
.46 .16014 L
.464 .16014 L
.468 .16015 L
.472 .16014 L
.476 .16013 L
.48 .1601 L
.484 .16007 L
.488 .16003 L
.492 .16 L
.496 .15999 L
.5 .15998 L
.504 .15998 L
.508 .15997 L
.512 .15996 L
.516 .15994 L
.52 .15993 L
.524 .1599 L
.528 .15986 L
.532 .15981 L
.536 .15976 L
.54 .15971 L
.544 .15966 L
.548 .1596 L
.552 .1595 L
.556 .15937 L
.56 .15924 L
.564 .15911 L
.568 .15898 L
.572 .15882 L
.576 .15862 L
.58 .15839 L
.584 .15811 L
.588 .15777 L
.592 .15733 L
.596 .15676 L
.6 .15606 L
Mistroke
.604 .15524 L
.608 .15432 L
.612 .1533 L
.616 .15213 L
.62 .15077 L
.624 .14918 L
.628 .14736 L
.632 .1453 L
.636 .14299 L
.64 .14041 L
.644 .13754 L
.648 .13444 L
.652 .13118 L
.656 .12784 L
.66 .12447 L
.664 .12107 L
.668 .11763 L
.672 .11417 L
.676 .11077 L
.68 .10751 L
.684 .10441 L
.688 .10147 L
.692 .09867 L
.696 .09601 L
.7 .09349 L
.704 .09112 L
.708 .08885 L
.712 .08658 L
.716 .08416 L
.72 .08151 L
.724 .07862 L
.728 .07554 L
.732 .07237 L
.736 .06916 L
.74 .06595 L
.744 .06277 L
.748 .05968 L
.752 .05677 L
.756 .05408 L
.76 .05162 L
.764 .04933 L
.768 .0471 L
.772 .04482 L
.776 .04249 L
.78 .04013 L
.784 .03783 L
.788 .03567 L
.792 .03371 L
.796 .03197 L
.8 .03046 L
Mistroke
.804 .0292 L
.808 .02821 L
.812 .02747 L
.816 .02695 L
.82 .02658 L
.824 .02625 L
.828 .02584 L
.832 .02528 L
.836 .02452 L
.84 .02357 L
.844 .02248 L
.848 .02132 L
.852 .0201 L
.856 .01882 L
.86 .01746 L
.864 .01599 L
.868 .01448 L
.872 .01304 L
.876 .01186 L
.88 .01108 L
.884 .01073 L
.888 .01073 L
.892 .01086 L
.896 .01086 L
.9 .01056 L
.904 .00989 L
.908 .00893 L
.912 .00779 L
.916 .00662 L
.92 .00547 L
.924 .00437 L
.928 .00332 L
.932 .00234 L
.936 .00158 L
.94 .00113 L
.944 .00111 L
.948 .00153 L
.952 .00226 L
.956 .00314 L
.96 .00392 L
.964 .0045 L
.968 .00482 L
.972 .00499 L
.976 .00513 L
.98 .00536 L
.984 .0057 L
.988 .00612 L
.992 .0065 L
.996 .00673 L
1 .00668 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0?Goo00<007ooOol0;7oo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool2000nOol3000/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo
0`000goo0`000goo1@0000=oo`0000000`000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo
0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]o
o`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool01@00Oomoogoo00000goo00@007oo0000009oo`80009oo`@0009oo`04001oogoo0002
Ool01000Oomoo`0017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oo`000002Ool01000Ool007oo0P0000Eoo`00Oomoo`00009oo`04001oogoo0002Ool00`00
Oomoo`03Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oo`000002
Ool01000Ool000000Woo0`0000Eoo`00Oomoo`00009oo`04001oogoo0006Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Ao
o`03001oogoo00]oo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogooOol4000017oo001oo`000Woo00@007ooOol000=oo`04001oo`000002
Ool01000Oomoo`000Woo00D007ooOomoo`0000=oo`03001oo`0000<000=oo`04001oogoo0005Ool0
00]oo`8000Yoo`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool2
0004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo009oo`03001oo`00009o
o`04001oogoo0003Ool00`00Oomoo`0200001Goo001oogoo00000Woo00D007ooOomoo`0000=oo`03
001oo`0000Ioo`04001oogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03001oogoo00=oo`80
00Aoo`8000Ioo`04001oogooOol60002Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003
Ool20006Ool0029oo`03001oogoo03Qoo`80015oo`03001oogoo01ioo`008Woo0P00>Goo00<007oo
Ool047oo00<007ooOol00goo00<007ooOol00Woo0P0057oo000ROomS000<Ool0029ooaD00003Ool0
000000H00003Ool00000009oo`03001oogoo0080009oo`8000=oo`03001oogoo00800003Ool00000
00<00005Ool007ooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo
00<00008Ool00000Ool007oo001oo`<000aoo`008Woo0P003Goo00D007oo000007oo00800004Ool0
0000Ool900000goo0000000=00000goo0000000IOol30005Ool20002Ool200000goo001oo`03000<
Ool0029oo`03001oogoo04aoo`8000Moo`03001oogoo00800003Ool0000000moo`008Woo0P00FGoo
00<007ooOol04Goo000ROol2001]Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03
001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]o
o`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomo
ogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool0
00Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`80
00=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003
Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo0080
06eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo
001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/
Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Ao
o`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001o
ogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000Woo0P0017oo>@00<7oo000AOol2000:Ool20004Ool00`00Oomoo`02Ool0
0`00Oomoo`0fOol3000]Ool002Qoo`03001oogoo03Qoo`8002aoo`00:7oo00<007ooOol0>Woo0P00
:Woo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0kOol2000Y
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00
?goo0`009Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool0
1000Oomoo`00@Goo0P009Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool30004Ool2
0002Ool60002Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool0
1000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`04001oogoo0002Ool40002Ool01000Oomoo`000Woo00D007ooOomo
o`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00D007ooOomoo`0000Aoo`@0009oo`04001oogoo0004Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomo
o`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009o
o`L000Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uo
o`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04
001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo3@00
0goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`80
00Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo
0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000
Oomoo`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004
Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?
Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003
Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo
00@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00
Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Ao
o`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<0
07ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000
Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1Y
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001o
ogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo
009oo`<000=oo`03001oogoo05]oo`/000aoo`002Woo00@007ooOol000Moo`05001oogooOol00002
Ool00`00Oomoo`1FOol6000FOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001BOol6
000KOol000Yoo`04001oogoo000;Ool01000Oomoo`00DGoo0`0087oo000:Ool01000Oomoo`001goo
10000goo00<007ooOol0CGoo0P008goo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00C7oo
0P009Goo000;Ool20008Ool50002Ool00`00Oomoo`1:Ool2000VOol001aoo`03001oogoo00eoo`<0
00Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`80
00Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000
Oomoo`000Woo00<007ooOol00Woo0P000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomo
o`03Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo
011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo00Eoo`04001oogoo0002Ool01000Oomoogoo0P0000=oo`00Ool00goo00@0
07ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo
000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00@007oo000000Aoo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0
009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`03001oogoo008000=oo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@0
07ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04
001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007oo000000Aoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@0
07ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@0
07ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo
00<007ooOol0?goo0P00<Goo000LOol00`00Oomoo`0lOol4000bOol001aoofT000aoo`0077oo0P00
0Woo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=o
o`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00
Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009o
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol3
0003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol0
0Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001o
ogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`00
2goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo
00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07
Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo
00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(45090\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3171 m
.008 .31771 L
.012 .31912 L
.016 .31947 L
.02 .31868 L
.024 .31844 L
.028 .31869 L
.032 .31862 L
.036 .31841 L
.04 .31849 L
.044 .31875 L
.048 .31888 L
.052 .31882 L
.056 .31871 L
.06 .31863 L
.064 .31861 L
.068 .31871 L
.072 .31888 L
.076 .31899 L
.08 .31898 L
.084 .31882 L
.088 .31865 L
.092 .31858 L
.096 .31866 L
.1 .31887 L
.104 .31908 L
.108 .31916 L
.112 .31908 L
.116 .31889 L
.12 .31872 L
.124 .3187 L
.128 .31882 L
.132 .31902 L
.136 .31918 L
.14 .31923 L
.144 .31913 L
.148 .31895 L
.152 .3188 L
.156 .31878 L
.16 .31889 L
.164 .3191 L
.168 .31931 L
.172 .31942 L
.176 .31938 L
.18 .31916 L
.184 .31889 L
.188 .31874 L
.192 .31882 L
.196 .31911 L
.2 .31944 L
Mistroke
.204 .31962 L
.208 .31956 L
.212 .31926 L
.216 .31891 L
.22 .31875 L
.224 .31895 L
.228 .31939 L
.232 .31979 L
.236 .31984 L
.24 .31953 L
.244 .31905 L
.248 .31871 L
.252 .31872 L
.256 .3191 L
.26 .31968 L
.264 .32014 L
.268 .32017 L
.272 .31973 L
.276 .31911 L
.28 .3187 L
.284 .31871 L
.288 .31908 L
.292 .3196 L
.296 .32006 L
.3 .32026 L
.304 .32007 L
.308 .31954 L
.312 .31898 L
.316 .31874 L
.32 .319 L
.324 .31957 L
.328 .32011 L
.332 .32036 L
.336 .32024 L
.34 .31981 L
.344 .31923 L
.348 .31881 L
.352 .31885 L
.356 .3194 L
.36 .32014 L
.364 .32059 L
.368 .3205 L
.372 .32003 L
.376 .31951 L
.38 .31917 L
.384 .31907 L
.388 .31925 L
.392 .31968 L
.396 .32024 L
.4 .32061 L
Mistroke
.404 .32053 L
.408 .32004 L
.412 .31947 L
.416 .31918 L
.42 .31928 L
.424 .3196 L
.428 .31996 L
.432 .32028 L
.436 .3205 L
.44 .32051 L
.444 .32022 L
.448 .31972 L
.452 .3193 L
.456 .31923 L
.46 .31952 L
.464 .31992 L
.468 .32016 L
.472 .32018 L
.476 .32014 L
.48 .32012 L
.484 .32005 L
.488 .31979 L
.492 .31935 L
.496 .31898 L
.5 .31891 L
.504 .31912 L
.508 .31931 L
.512 .31923 L
.516 .3189 L
.52 .31858 L
.524 .31841 L
.528 .31817 L
.532 .31748 L
.536 .31623 L
.54 .31481 L
.544 .31373 L
.548 .3131 L
.552 .31243 L
.556 .31108 L
.56 .30881 L
.564 .30595 L
.568 .30282 L
.572 .29924 L
.576 .29461 L
.58 .28865 L
.584 .28186 L
.588 .27521 L
.592 .26912 L
.596 .26298 L
.6 .25562 L
Mistroke
.604 .24652 L
.608 .23637 L
.612 .22654 L
.616 .21789 L
.62 .21023 L
.624 .20306 L
.628 .19668 L
.632 .19248 L
.636 .19182 L
.64 .19467 L
.644 .19941 L
.648 .20415 L
.652 .20828 L
.656 .21278 L
.66 .2189 L
.664 .22644 L
.668 .2335 L
.672 .23792 L
.676 .23902 L
.68 .23801 L
.684 .23656 L
.688 .23507 L
.692 .23235 L
.696 .22712 L
.7 .2199 L
.704 .21335 L
.708 .21065 L
.712 .21316 L
.716 .21948 L
.72 .22675 L
.724 .23288 L
.728 .23787 L
.732 .24304 L
.736 .2491 L
.74 .25505 L
.744 .25883 L
.748 .25937 L
.752 .25796 L
.756 .25789 L
.76 .26227 L
.764 .27198 L
.768 .2852 L
.772 .29877 L
.776 .31023 L
.78 .3189 L
.784 .32543 L
.788 .33041 L
.792 .33348 L
.796 .33357 L
.8 .32995 L
Mistroke
.804 .32332 L
.808 .31567 L
.812 .30932 L
.816 .3057 L
.82 .3047 L
.824 .30505 L
.828 .30515 L
.832 .30398 L
.836 .30168 L
.84 .29928 L
.844 .29845 L
.848 .30069 L
.852 .30649 L
.856 .31511 L
.86 .32404 L
.864 .33029 L
.868 .33134 L
.872 .32657 L
.876 .31814 L
.88 .30942 L
.884 .30421 L
.888 .30405 L
.892 .30784 L
.896 .31313 L
.9 .31676 L
.904 .31822 L
.908 .31842 L
.912 .31947 L
.916 .32297 L
.92 .32755 L
.924 .33102 L
.928 .33035 L
.932 .32476 L
.936 .31673 L
.94 .31009 L
.944 .30913 L
.948 .31506 L
.952 .32551 L
.956 .33559 L
.96 .34029 L
.964 .33699 L
.968 .32712 L
.972 .31533 L
.976 .30629 L
.98 .30449 L
.984 .3095 L
.988 .31843 L
.992 .32807 L
.996 .33247 L
1 .33198 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12867 m
.008 .13248 L
.012 .13377 L
.016 .13264 L
.02 .13214 L
.024 .13251 L
.028 .13266 L
.032 .13257 L
.036 .13249 L
.04 .13254 L
.044 .13255 L
.048 .13256 L
.052 .13254 L
.056 .13255 L
.06 .13254 L
.064 .13254 L
.068 .13253 L
.072 .13254 L
.076 .13254 L
.08 .13255 L
.084 .13255 L
.088 .13255 L
.092 .13255 L
.096 .13255 L
.1 .13254 L
.104 .13255 L
.108 .13254 L
.112 .13254 L
.116 .13254 L
.12 .13254 L
.124 .13254 L
.128 .13255 L
.132 .13256 L
.136 .13256 L
.14 .13255 L
.144 .13255 L
.148 .13253 L
.152 .13253 L
.156 .13254 L
.16 .13255 L
.164 .13255 L
.168 .13256 L
.172 .13255 L
.176 .13255 L
.18 .13254 L
.184 .13255 L
.188 .13255 L
.192 .13255 L
.196 .13255 L
.2 .13254 L
Mistroke
.204 .13254 L
.208 .13254 L
.212 .13254 L
.216 .13255 L
.22 .13256 L
.224 .13256 L
.228 .13256 L
.232 .13255 L
.236 .13255 L
.24 .13254 L
.244 .13254 L
.248 .13254 L
.252 .13255 L
.256 .13255 L
.26 .13256 L
.264 .13256 L
.268 .13255 L
.272 .13255 L
.276 .13254 L
.28 .13255 L
.284 .13255 L
.288 .13255 L
.292 .13256 L
.296 .13256 L
.3 .13255 L
.304 .13254 L
.308 .13254 L
.312 .13254 L
.316 .13255 L
.32 .13255 L
.324 .13256 L
.328 .13256 L
.332 .13256 L
.336 .13256 L
.34 .13256 L
.344 .13255 L
.348 .13254 L
.352 .13254 L
.356 .13254 L
.36 .13254 L
.364 .13255 L
.368 .13256 L
.372 .13257 L
.376 .13257 L
.38 .13257 L
.384 .13256 L
.388 .13255 L
.392 .13254 L
.396 .13254 L
.4 .13254 L
Mistroke
.404 .13255 L
.408 .13256 L
.412 .13257 L
.416 .13258 L
.42 .13257 L
.424 .13256 L
.428 .13255 L
.432 .13254 L
.436 .13255 L
.44 .13255 L
.444 .13256 L
.448 .13258 L
.452 .13259 L
.456 .13259 L
.46 .13259 L
.464 .13258 L
.468 .13256 L
.472 .13256 L
.476 .13256 L
.48 .13258 L
.484 .1326 L
.488 .13263 L
.492 .13266 L
.496 .13268 L
.5 .1327 L
.504 .13271 L
.508 .13272 L
.512 .13273 L
.516 .13276 L
.52 .1328 L
.524 .13286 L
.528 .13294 L
.532 .13302 L
.536 .13312 L
.54 .13324 L
.544 .13339 L
.548 .13355 L
.552 .13373 L
.556 .13395 L
.56 .13423 L
.564 .13457 L
.568 .13498 L
.572 .13545 L
.576 .136 L
.58 .13664 L
.584 .13742 L
.588 .13835 L
.592 .13943 L
.596 .14067 L
.6 .1421 L
Mistroke
.604 .14373 L
.608 .14556 L
.612 .14759 L
.616 .14977 L
.62 .15209 L
.624 .15454 L
.628 .15713 L
.632 .15984 L
.636 .16264 L
.64 .16546 L
.644 .16826 L
.648 .171 L
.652 .17365 L
.656 .17617 L
.66 .17855 L
.664 .18074 L
.668 .18276 L
.672 .18467 L
.676 .18655 L
.68 .18847 L
.684 .19048 L
.688 .19256 L
.692 .19472 L
.696 .19695 L
.7 .19927 L
.704 .20169 L
.708 .20415 L
.712 .2066 L
.716 .20898 L
.72 .21127 L
.724 .21351 L
.728 .21572 L
.732 .21791 L
.736 .22004 L
.74 .22208 L
.744 .22401 L
.748 .22585 L
.752 .22764 L
.756 .22939 L
.76 .23106 L
.764 .23258 L
.768 .2339 L
.772 .23498 L
.776 .23587 L
.78 .23661 L
.784 .23724 L
.788 .23778 L
.792 .23825 L
.796 .23868 L
.8 .23911 L
Mistroke
.804 .23961 L
.808 .24021 L
.812 .24094 L
.816 .24175 L
.82 .24259 L
.824 .24343 L
.828 .24425 L
.832 .24506 L
.836 .24591 L
.84 .24681 L
.844 .24776 L
.848 .24871 L
.852 .24959 L
.856 .25033 L
.86 .25088 L
.864 .25128 L
.868 .25159 L
.872 .2519 L
.876 .25229 L
.88 .25278 L
.884 .25335 L
.888 .2539 L
.892 .25442 L
.896 .25485 L
.9 .25524 L
.904 .25562 L
.908 .25602 L
.912 .25642 L
.916 .25675 L
.92 .25695 L
.924 .25699 L
.928 .25689 L
.932 .25675 L
.936 .25659 L
.94 .25645 L
.944 .25626 L
.948 .25594 L
.952 .25542 L
.956 .25473 L
.96 .25395 L
.964 .25328 L
.968 .25287 L
.972 .25283 L
.976 .25312 L
.98 .25366 L
.984 .25422 L
.988 .2547 L
.992 .25497 L
.996 .25507 L
1 .25509 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15885 L
.012 .16133 L
.016 .16198 L
.02 .1611 L
.024 .16085 L
.028 .1612 L
.032 .16124 L
.036 .16113 L
.04 .16108 L
.044 .16113 L
.048 .16111 L
.052 .16109 L
.056 .16107 L
.06 .16108 L
.064 .16106 L
.068 .16107 L
.072 .16105 L
.076 .16105 L
.08 .16102 L
.084 .16102 L
.088 .161 L
.092 .161 L
.096 .16099 L
.1 .16099 L
.104 .16098 L
.108 .16096 L
.112 .16094 L
.116 .16093 L
.12 .16092 L
.124 .16092 L
.128 .16092 L
.132 .16092 L
.136 .16091 L
.14 .1609 L
.144 .16087 L
.148 .16086 L
.152 .16084 L
.156 .16084 L
.16 .16084 L
.164 .16084 L
.168 .16083 L
.172 .16082 L
.176 .16081 L
.18 .16079 L
.184 .16078 L
.188 .16077 L
.192 .16076 L
.196 .16076 L
.2 .16075 L
Mistroke
.204 .16074 L
.208 .16072 L
.212 .16071 L
.216 .1607 L
.22 .1607 L
.224 .1607 L
.228 .1607 L
.232 .16068 L
.236 .16066 L
.24 .16064 L
.244 .16063 L
.248 .16062 L
.252 .16062 L
.256 .16062 L
.26 .16062 L
.264 .16061 L
.268 .16059 L
.272 .16057 L
.276 .16056 L
.28 .16056 L
.284 .16055 L
.288 .16054 L
.292 .16054 L
.296 .16053 L
.3 .16051 L
.304 .1605 L
.308 .16048 L
.312 .16047 L
.316 .16047 L
.32 .16046 L
.324 .16046 L
.328 .16046 L
.332 .16045 L
.336 .16044 L
.34 .16042 L
.344 .1604 L
.348 .16039 L
.352 .16037 L
.356 .16037 L
.36 .16036 L
.364 .16036 L
.368 .16036 L
.372 .16036 L
.376 .16036 L
.38 .16035 L
.384 .16033 L
.388 .1603 L
.392 .16028 L
.396 .16026 L
.4 .16026 L
Mistroke
.404 .16026 L
.408 .16026 L
.412 .16026 L
.416 .16026 L
.42 .16025 L
.424 .16022 L
.428 .1602 L
.432 .16018 L
.436 .16017 L
.44 .16016 L
.444 .16017 L
.448 .16017 L
.452 .16017 L
.456 .16016 L
.46 .16014 L
.464 .1601 L
.468 .16007 L
.472 .16004 L
.476 .16002 L
.48 .16002 L
.484 .16001 L
.488 .16 L
.492 .16 L
.496 .15998 L
.5 .15995 L
.504 .1599 L
.508 .15984 L
.512 .15976 L
.516 .15969 L
.52 .15962 L
.524 .15955 L
.528 .15947 L
.532 .15938 L
.536 .15926 L
.54 .15913 L
.544 .15897 L
.548 .15876 L
.552 .1585 L
.556 .15819 L
.56 .15783 L
.564 .15742 L
.568 .15693 L
.572 .15632 L
.576 .15558 L
.58 .1547 L
.584 .15369 L
.588 .15253 L
.592 .15119 L
.596 .14964 L
.6 .14788 L
Mistroke
.604 .1459 L
.608 .1437 L
.612 .14126 L
.616 .13854 L
.62 .13556 L
.624 .13235 L
.628 .12898 L
.632 .12553 L
.636 .12205 L
.64 .11856 L
.644 .1151 L
.648 .11173 L
.652 .10849 L
.656 .10543 L
.66 .10252 L
.664 .09972 L
.668 .09703 L
.672 .09444 L
.676 .09196 L
.68 .08958 L
.684 .08722 L
.688 .08479 L
.692 .0822 L
.696 .07943 L
.7 .07649 L
.704 .07343 L
.708 .07029 L
.712 .06709 L
.716 .06387 L
.72 .06073 L
.724 .05776 L
.728 .05504 L
.732 .05256 L
.736 .05025 L
.74 .04799 L
.744 .0457 L
.748 .04336 L
.752 .04101 L
.756 .03871 L
.76 .03649 L
.764 .03439 L
.768 .03247 L
.772 .03079 L
.776 .02944 L
.78 .02847 L
.784 .02785 L
.788 .02747 L
.792 .02717 L
.796 .02681 L
.8 .02631 L
Mistroke
.804 .02565 L
.808 .02483 L
.812 .02391 L
.816 .02287 L
.82 .02173 L
.824 .02048 L
.828 .01916 L
.832 .0178 L
.836 .01646 L
.84 .01522 L
.844 .01412 L
.848 .0132 L
.852 .01243 L
.856 .01182 L
.86 .01131 L
.864 .01088 L
.868 .01047 L
.872 .01004 L
.876 .0095 L
.88 .00877 L
.884 .0078 L
.888 .00658 L
.892 .00525 L
.896 .00398 L
.9 .00301 L
.904 .00252 L
.908 .00255 L
.912 .003 L
.916 .00363 L
.92 .00421 L
.924 .0046 L
.928 .00473 L
.932 .00472 L
.936 .00466 L
.94 .00465 L
.944 .00465 L
.948 .00458 L
.952 .00436 L
.956 .00398 L
.96 .00354 L
.964 .00322 L
.968 .00319 L
.972 .00352 L
.976 .00414 L
.98 .00492 L
.984 .0056 L
.988 .00611 L
.992 .00636 L
.996 .00644 L
1 .00647 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0>goo00<007ooOol0;Woo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool2000kOol00`00Ool0000_Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo
0P001Goo0`000goo0`0000Aoo`00Oomoo`8000=oo`D000=oo`8000Aoo`8000Aoo`D0009oo`<000Ao
o`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`0;Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`03001oogoo00@00004Ool007oo0002Ool01000
Oomoo`000Woo00@007ooOol0009oo`03001oogoo009oo`06001oogoo001oo`000goo00@007ooOol0
009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2
000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool00`00Oomoo`04Ool20002Ool00`00Ool000030002Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol017oo
0P000Woo00@007ooOol000Aoo`8000=oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol0
17oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool2
0004Ool00`00Oomoo`0;Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol0009oo`03001oogoo0080009oo`04
001oogoo0002Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;
Ool2000:Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P00
17oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Ool00004Ool01000Oomoo`000Woo
00@007ooOomoo`800005Ool007ooOol00002Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006
Ool01000Oomoo`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006
Ool01000Oomoogoo1@000goo0P0017oo0`000Woo00@007oo000000Aoo`8000Eoo`<0009oo`D000=o
o`8000Ioo`008Woo00<007ooOol0=Woo00<007ooOol03goo00<007ooOol08Goo000ROol2000fOol2
000AOol00`00Oomoo`04Ool00`00Oomoo`0JOol0029oof<000aoo`008Woo4@0000=oo`0000000`00
00Aoo`00001oo`80009oo`03001oogoo00800007Ool00000001oo`00Ool00`0000=oo`0000001`00
0goo00@007ooOol000=oo`05001oogooOol00003Ool01000Ool007oo0P000Woo00<007oo00002000
00Ioo`00000007oo000<Ool0029oo`<000ioo`05001oogoo001oo`06000017oo000007oo0P0000=o
o`000000300000=oo`00Ool06Goo0P001Goo0P000goo0`0000=oo`0000000Woo00<007ooOol02goo
000ROol00`00Oomoo`1:Ool20005Ool20004Ool200000goo00000002Ool2000<Ool0029oo`8005ao
o`03001oogoo00ioo`008Woo0P00KGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool0
0`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;
Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007oo
Oomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool2
0003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
1Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomo
o`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0
K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004
Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000AoocL0039oo`004Goo0P002Woo0P0017oo00<007ooOol00Woo
00<007ooOol0<goo0`00<7oo000XOol00`00Oomoo`0eOol3000^Ool002Qoo`03001oogoo03Moo`80
02eoo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0>Goo0P00
:goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol0
03aoo`<002Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOol003ioo`<002Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo
0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo
00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomo
o`0000=oo`04001oogoo0002Ool01@00Oomoo`00Ool00`0000Eoo`00Oomoo`00009oo`04001oogoo
0003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`<0009oo`04001oogoo0002Ool00`00Oomoo`02
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002
Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo
00@007ooOomoo`L0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`04001oogoo
0002Ool00`00Oomoo`0@0003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04
Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomo
o`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=o
o`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001o
ogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool3
0002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<
Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001o
ogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001o
ogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool20002Ool5
0002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004
Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Io
o`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003
Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D0
07ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo
1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo
0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
2goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0FGoo3@0037oo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo05=oo`H001Uoo`000goo1@000Woo00@007ooOol000]o
o`03001oogoo008004moo`H001ioo`002Woo00@007ooOol000]oo`04001oogoo001>Ool3000SOol0
00Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1:Ool2000VOol000Yoo`04001oogoo0007Ool0
0`00Oomoo`04Ool20019Ool3000WOol000]oo`8000Qoo`D0009oo`03001oogoo04Moo`8002Uoo`00
77oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P00
17oo1P000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo
00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D0
07ooOomoo`0000=oo`04001oogoo0002Ool00`00Ool0000200001Goo001oogoo00000Woo00@007oo
Ool0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03
Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool30004Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00
Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`05001oogoo001oo`020007Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo
0002Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool40004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005
Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`800003Ool007oo00=oo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol0
00Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomo
o`D00003Ool00000008000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo
00<007ooOol0?7oo0P00=7oo000LOol00`00Oomoo`0jOol3000eOol001aoofT000aoo`0077oo00D0
07ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo
008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003
Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qo
o`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<0
07ooOol00Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009o
o`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`80
07=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007oo
Ool02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00
Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079o
o`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo
079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(45257\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31701 m
.008 .31819 L
.012 .31877 L
.016 .31898 L
.02 .3186 L
.024 .31844 L
.028 .31867 L
.032 .31873 L
.036 .31858 L
.04 .31852 L
.044 .31863 L
.048 .31874 L
.052 .31874 L
.056 .31867 L
.06 .31862 L
.064 .31861 L
.068 .31868 L
.072 .31881 L
.076 .31891 L
.08 .31891 L
.084 .31879 L
.088 .31864 L
.092 .31858 L
.096 .31867 L
.1 .31885 L
.104 .31904 L
.108 .31909 L
.112 .31899 L
.116 .3188 L
.12 .31867 L
.124 .31871 L
.128 .31888 L
.132 .31906 L
.136 .31912 L
.14 .31903 L
.144 .31888 L
.148 .31879 L
.152 .31886 L
.156 .31906 L
.16 .31927 L
.164 .31931 L
.168 .31915 L
.172 .31888 L
.176 .31871 L
.18 .31874 L
.184 .31896 L
.188 .31928 L
.192 .31952 L
.196 .31955 L
.2 .31934 L
Mistroke
.204 .31903 L
.208 .31881 L
.212 .31879 L
.216 .31897 L
.22 .31924 L
.224 .31949 L
.228 .31961 L
.232 .31952 L
.236 .31924 L
.24 .31896 L
.244 .31889 L
.248 .31908 L
.252 .31943 L
.256 .31971 L
.26 .31978 L
.264 .31958 L
.268 .31919 L
.272 .31883 L
.276 .31876 L
.28 .31911 L
.284 .31969 L
.288 .32013 L
.292 .32015 L
.296 .31976 L
.3 .31923 L
.304 .31884 L
.308 .31877 L
.312 .31905 L
.316 .31959 L
.32 .32012 L
.324 .32032 L
.328 .32006 L
.332 .31951 L
.336 .31904 L
.34 .3189 L
.344 .31912 L
.348 .31954 L
.352 .32 L
.356 .32033 L
.36 .32034 L
.364 .31994 L
.368 .3193 L
.372 .31885 L
.376 .3189 L
.38 .31942 L
.384 .32005 L
.388 .32044 L
.392 .32047 L
.396 .3202 L
.4 .31976 L
Mistroke
.404 .31929 L
.408 .319 L
.412 .3191 L
.416 .3196 L
.42 .32022 L
.424 .32056 L
.428 .32044 L
.432 .32 L
.436 .31953 L
.44 .31924 L
.444 .31915 L
.448 .31924 L
.452 .31952 L
.456 .31993 L
.46 .32025 L
.464 .32024 L
.468 .31978 L
.472 .31911 L
.476 .3186 L
.48 .31843 L
.484 .31851 L
.488 .31856 L
.492 .31843 L
.496 .3182 L
.5 .31793 L
.504 .31757 L
.508 .31689 L
.512 .31578 L
.516 .31439 L
.52 .313 L
.524 .31173 L
.528 .31032 L
.532 .30841 L
.536 .30583 L
.54 .30275 L
.544 .29937 L
.548 .29554 L
.552 .29078 L
.556 .28473 L
.56 .27757 L
.564 .26992 L
.568 .26226 L
.572 .2545 L
.576 .2462 L
.58 .23719 L
.584 .22793 L
.588 .21923 L
.592 .21148 L
.596 .20447 L
.6 .19796 L
Mistroke
.604 .19239 L
.608 .18903 L
.612 .18897 L
.616 .19223 L
.62 .19759 L
.624 .20365 L
.628 .20983 L
.632 .21641 L
.636 .22355 L
.64 .23034 L
.644 .23517 L
.648 .23696 L
.652 .23614 L
.656 .23424 L
.66 .23238 L
.664 .23029 L
.668 .22679 L
.672 .22141 L
.676 .21551 L
.68 .21163 L
.684 .2116 L
.688 .2152 L
.692 .22061 L
.696 .22612 L
.7 .23156 L
.704 .23785 L
.708 .2454 L
.712 .25289 L
.716 .25798 L
.72 .25926 L
.724 .25792 L
.728 .25721 L
.732 .26036 L
.736 .2683 L
.74 .27942 L
.744 .29113 L
.748 .30188 L
.752 .31179 L
.756 .32147 L
.76 .33041 L
.764 .33651 L
.768 .33738 L
.772 .33241 L
.776 .32364 L
.78 .31476 L
.784 .30885 L
.788 .30663 L
.792 .30648 L
.796 .30601 L
.8 .30394 L
Mistroke
.804 .30081 L
.808 .29827 L
.812 .29781 L
.816 .29972 L
.82 .30332 L
.824 .30767 L
.828 .31218 L
.832 .31676 L
.836 .32113 L
.84 .32462 L
.844 .32615 L
.848 .32468 L
.852 .32026 L
.856 .31366 L
.86 .30687 L
.864 .30205 L
.868 .30095 L
.872 .30465 L
.876 .31225 L
.88 .32188 L
.884 .33028 L
.888 .33433 L
.892 .33281 L
.896 .32638 L
.9 .31858 L
.904 .31329 L
.908 .31304 L
.912 .31782 L
.916 .32426 L
.92 .32853 L
.924 .32802 L
.928 .32323 L
.932 .3176 L
.936 .3151 L
.94 .31771 L
.944 .32403 L
.948 .33007 L
.952 .33125 L
.956 .32645 L
.96 .31767 L
.964 .30986 L
.968 .30864 L
.972 .31446 L
.976 .32562 L
.98 .336 L
.984 .33885 L
.988 .334 L
.992 .32155 L
.996 .30856 L
1 .30242 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13576 m
.008 .13291 L
.012 .13199 L
.016 .1331 L
.02 .13334 L
.024 .13296 L
.028 .13286 L
.032 .13303 L
.036 .13303 L
.04 .13299 L
.044 .13296 L
.048 .133 L
.052 .13299 L
.056 .133 L
.06 .13299 L
.064 .133 L
.068 .13299 L
.072 .133 L
.076 .13299 L
.08 .13299 L
.084 .13299 L
.088 .133 L
.092 .13299 L
.096 .133 L
.1 .13299 L
.104 .13299 L
.108 .13299 L
.112 .133 L
.116 .13299 L
.12 .133 L
.124 .133 L
.128 .133 L
.132 .13299 L
.136 .13299 L
.14 .13298 L
.144 .13299 L
.148 .13299 L
.152 .133 L
.156 .133 L
.16 .13301 L
.164 .133 L
.168 .133 L
.172 .13299 L
.176 .13298 L
.18 .13298 L
.184 .13299 L
.188 .133 L
.192 .13301 L
.196 .13301 L
.2 .133 L
Mistroke
.204 .13299 L
.208 .13299 L
.212 .13299 L
.216 .133 L
.22 .133 L
.224 .133 L
.228 .13299 L
.232 .13299 L
.236 .13299 L
.24 .13299 L
.244 .133 L
.248 .13301 L
.252 .13301 L
.256 .133 L
.26 .133 L
.264 .13299 L
.268 .13299 L
.272 .13299 L
.276 .13299 L
.28 .133 L
.284 .133 L
.288 .133 L
.292 .133 L
.296 .133 L
.3 .13299 L
.304 .13299 L
.308 .133 L
.312 .133 L
.316 .13301 L
.32 .13301 L
.324 .133 L
.328 .13299 L
.332 .13299 L
.336 .13299 L
.34 .13299 L
.344 .133 L
.348 .13301 L
.352 .13301 L
.356 .13301 L
.36 .13301 L
.364 .13301 L
.368 .133 L
.372 .133 L
.376 .13299 L
.38 .13299 L
.384 .13299 L
.388 .133 L
.392 .13301 L
.396 .13302 L
.4 .13302 L
Mistroke
.404 .13302 L
.408 .13302 L
.412 .13301 L
.416 .133 L
.42 .13299 L
.424 .13299 L
.428 .133 L
.432 .13302 L
.436 .13304 L
.44 .13305 L
.444 .13305 L
.448 .13304 L
.452 .13304 L
.456 .13304 L
.46 .13305 L
.464 .13306 L
.468 .13309 L
.472 .13312 L
.476 .13315 L
.48 .13318 L
.484 .13321 L
.488 .13323 L
.492 .13325 L
.496 .13329 L
.5 .13335 L
.504 .13343 L
.508 .13353 L
.512 .13365 L
.516 .13379 L
.52 .13396 L
.524 .13415 L
.528 .13436 L
.532 .13461 L
.536 .13491 L
.54 .13528 L
.544 .13573 L
.548 .13627 L
.552 .13691 L
.556 .13768 L
.56 .13857 L
.564 .13962 L
.568 .14082 L
.572 .14218 L
.576 .14371 L
.58 .14544 L
.584 .14737 L
.588 .1495 L
.592 .1518 L
.596 .15425 L
.6 .15682 L
Mistroke
.604 .15951 L
.608 .16227 L
.612 .16507 L
.616 .16785 L
.62 .17059 L
.624 .17324 L
.628 .17581 L
.632 .17826 L
.636 .18056 L
.64 .1827 L
.644 .18468 L
.648 .18657 L
.652 .18844 L
.656 .19034 L
.66 .19231 L
.664 .19437 L
.668 .19654 L
.672 .19884 L
.676 .20127 L
.68 .20379 L
.684 .20631 L
.688 .20877 L
.692 .21114 L
.696 .2134 L
.7 .21559 L
.704 .21772 L
.708 .21979 L
.712 .22178 L
.716 .22369 L
.72 .22554 L
.724 .22737 L
.728 .22917 L
.732 .23089 L
.736 .23245 L
.74 .23382 L
.744 .23499 L
.748 .23598 L
.752 .23684 L
.756 .23756 L
.76 .23815 L
.764 .23862 L
.768 .23901 L
.772 .23939 L
.776 .23983 L
.78 .24039 L
.784 .24104 L
.788 .24175 L
.792 .24248 L
.796 .24326 L
.8 .24408 L
Mistroke
.804 .245 L
.808 .246 L
.812 .24704 L
.816 .24806 L
.82 .24899 L
.824 .2498 L
.828 .25048 L
.832 .25102 L
.836 .25146 L
.84 .25181 L
.844 .2521 L
.848 .25239 L
.852 .25272 L
.856 .25316 L
.86 .25374 L
.864 .25444 L
.868 .25521 L
.872 .25595 L
.876 .25656 L
.88 .25697 L
.884 .25713 L
.888 .25711 L
.892 .25698 L
.896 .25683 L
.9 .25671 L
.904 .25659 L
.908 .25645 L
.912 .2562 L
.916 .25583 L
.92 .25539 L
.924 .255 L
.928 .25474 L
.932 .25469 L
.936 .25481 L
.94 .25502 L
.944 .25519 L
.948 .25526 L
.952 .25525 L
.956 .25521 L
.96 .25519 L
.964 .25522 L
.968 .25523 L
.972 .25511 L
.976 .25481 L
.98 .25432 L
.984 .25377 L
.988 .25336 L
.992 .25318 L
.996 .25341 L
1 .25386 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15826 L
.012 .16111 L
.016 .16211 L
.02 .16125 L
.024 .16084 L
.028 .16112 L
.032 .16122 L
.036 .16116 L
.04 .16108 L
.044 .16112 L
.048 .16111 L
.052 .1611 L
.056 .16107 L
.06 .16107 L
.064 .16106 L
.068 .16106 L
.072 .16105 L
.076 .16105 L
.08 .16103 L
.084 .16102 L
.088 .161 L
.092 .161 L
.096 .16098 L
.1 .16098 L
.104 .16097 L
.108 .16096 L
.112 .16095 L
.116 .16094 L
.12 .16093 L
.124 .16093 L
.128 .16092 L
.132 .16091 L
.136 .16089 L
.14 .16087 L
.144 .16086 L
.148 .16086 L
.152 .16086 L
.156 .16086 L
.16 .16085 L
.164 .16084 L
.168 .16082 L
.172 .1608 L
.176 .16079 L
.18 .16079 L
.184 .16078 L
.188 .16078 L
.192 .16077 L
.196 .16076 L
.2 .16075 L
Mistroke
.204 .16074 L
.208 .16073 L
.212 .16072 L
.216 .16071 L
.22 .1607 L
.224 .16069 L
.228 .16067 L
.232 .16066 L
.236 .16065 L
.24 .16065 L
.244 .16065 L
.248 .16064 L
.252 .16064 L
.256 .16062 L
.26 .16061 L
.264 .16059 L
.268 .16057 L
.272 .16056 L
.276 .16056 L
.28 .16056 L
.284 .16056 L
.288 .16055 L
.292 .16053 L
.296 .16052 L
.3 .16051 L
.304 .1605 L
.308 .16049 L
.312 .16049 L
.316 .16048 L
.32 .16047 L
.324 .16045 L
.328 .16044 L
.332 .16043 L
.336 .16042 L
.34 .16041 L
.344 .1604 L
.348 .1604 L
.352 .1604 L
.356 .16039 L
.36 .16039 L
.364 .16037 L
.368 .16035 L
.372 .16033 L
.376 .16032 L
.38 .1603 L
.384 .16029 L
.388 .16029 L
.392 .16029 L
.396 .1603 L
.4 .1603 L
Mistroke
.404 .16029 L
.408 .16027 L
.412 .16024 L
.416 .16022 L
.42 .1602 L
.424 .16018 L
.428 .16018 L
.432 .16018 L
.436 .16019 L
.44 .16018 L
.444 .16016 L
.448 .16013 L
.452 .1601 L
.456 .16007 L
.46 .16004 L
.464 .16002 L
.468 .16 L
.472 .15999 L
.476 .15997 L
.48 .15993 L
.484 .15988 L
.488 .1598 L
.492 .15972 L
.496 .15963 L
.5 .15954 L
.504 .15945 L
.508 .15934 L
.512 .15921 L
.516 .15907 L
.52 .15889 L
.524 .15865 L
.528 .15836 L
.532 .15799 L
.536 .15757 L
.54 .15707 L
.544 .15649 L
.548 .15581 L
.552 .155 L
.556 .15405 L
.56 .15296 L
.564 .15168 L
.568 .1502 L
.572 .14849 L
.576 .14654 L
.58 .14436 L
.584 .14196 L
.588 .13933 L
.592 .13646 L
.596 .13338 L
.6 .13011 L
Mistroke
.604 .12671 L
.608 .12323 L
.612 .11971 L
.616 .11621 L
.62 .11278 L
.624 .10947 L
.628 .10633 L
.632 .10339 L
.636 .1006 L
.64 .09794 L
.644 .09536 L
.648 .09285 L
.652 .0904 L
.656 .08796 L
.66 .08547 L
.664 .08288 L
.668 .08017 L
.672 .07733 L
.676 .0744 L
.68 .07139 L
.684 .0683 L
.688 .06515 L
.692 .06201 L
.696 .05897 L
.7 .0561 L
.704 .05345 L
.708 .05098 L
.712 .04862 L
.716 .04631 L
.72 .04402 L
.724 .04176 L
.728 .03954 L
.732 .03736 L
.736 .03524 L
.74 .03323 L
.744 .03144 L
.748 .02999 L
.752 .02894 L
.756 .02825 L
.76 .02781 L
.764 .02748 L
.768 .02712 L
.772 .02666 L
.776 .02607 L
.78 .02533 L
.784 .02442 L
.788 .02333 L
.792 .02209 L
.796 .02076 L
.8 .01945 L
Mistroke
.804 .01822 L
.808 .01709 L
.812 .01605 L
.816 .01503 L
.82 .01404 L
.824 .01309 L
.828 .01225 L
.832 .01156 L
.836 .01103 L
.84 .0106 L
.844 .01018 L
.848 .00964 L
.852 .00892 L
.856 .008 L
.86 .00697 L
.864 .00591 L
.868 .00498 L
.872 .00425 L
.876 .00379 L
.88 .00357 L
.884 .00355 L
.888 .00367 L
.892 .00386 L
.896 .00408 L
.9 .00428 L
.904 .00439 L
.908 .00438 L
.912 .0042 L
.916 .00392 L
.92 .00365 L
.924 .00352 L
.928 .00367 L
.932 .00412 L
.936 .00479 L
.94 .00554 L
.944 .00617 L
.948 .00658 L
.952 .00674 L
.956 .00675 L
.96 .00667 L
.964 .00661 L
.968 .00651 L
.972 .0063 L
.976 .0059 L
.98 .00526 L
.984 .00445 L
.988 .00368 L
.992 .00305 L
.996 .00284 L
1 .00296 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0>7oo0P00<Woo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool2000hOol200000goo001oo`0`Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P00
1Goo0`000goo0`0000Aoo`00001oo`@00003Ool0000000<000=oo`8000Aoo`8000Aoo`D0009oo`<0
00Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`0;Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOomoo`80009oo`05001oo`00001oo`02000017oo001oo`00
0Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol00Woo00D007ooOol007oo00D00005Ool007ooOol00004Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0
009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Oomoo`80009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo
0002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00]oo`@000=oo`04001oogoo0007
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000
Oomoo`000Woo0`0000Eoo`00Oomoo`00009oo`04001oogoo0002Ool01@00Oomoogoo00000goo00<0
07oo00000`000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo0P0037oo
00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P00
0Woo0P001Woo00@007ooOol0009oo`<00005Ool007ooOol00002Ool01000Oomoo`000Woo00D007oo
Oomoo`0000=oo`03001oo`0000Ioo`04001oogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`03
001oogoo00=oo`8000Aoo`8000Ioo`03001oogoo00H000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eo
o`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol0<goo00<007ooOol03goo00<007ooOol097oo
000ROol2000dOol00`00Oomoo`0@Ool00`00Oomoo`03Ool00`00Oomoo`0MOol0029oof<000aoo`00
8Woo4`0000=oo`0000000`0000Aoo`00001oo`<00003Ool0000000<00003Ool00000009oo`800003
Ool0000000D0009oo`05001oogooOol00002Ool01@00Oomoogoo00000goo00<007ooOol00P0000Ao
o`00Ool0009oo`800005Ool00000001oo`05000017oo000007oo0P0037oo000ROol2000>Ool00`00
Oomoo`02000017oo000007oo0P0000Aoo`00001oo`800003Ool0000000@00003Ool0000000@001]o
o`03001oo`0000Eoo`80009oo`800003Ool0000000<00004Ool007oo000=Ool0029oo`03001oogoo
04Moo`8000Yoo`8000Aoo`80009oo`03001oogoo00aoo`008Woo0P00KGoo000ROol2001]Ool000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06aoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2
001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool2
0004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0
009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007oo
Ool0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`80
06eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=o
o`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0
K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo
00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05
Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomo
o`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo=000
=Goo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0aOol3000bOol002Qoo`03001o
ogoo03=oo`80035oo`00:7oo00<007ooOol0=Goo0P00;goo000;Ool20004Ool00`00Oomoo`03Ool2
0004Ool20003Ool30003Ool00`00Oomoo`0fOol2000^Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00H007ooOol007oo0003Ool01000Oomoo`00>Woo0P00;7oo0003Ool50002Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00?7oo0P00:Woo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007
Ool30004Ool20004Ool20003Ool30003Ool30004Ool200000goo000000040003Ool20004Ool20003
Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol0
07oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03
001oo`0000800005Ool007ooOol00002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001o
o`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00@007ooOomoo`@00005Ool007ooOol00002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`03001oo`0000D0009oo`04001o
ogoo0005Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09
Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool0
1000Oomoogoo10000goo00H007ooOol007oo0003Ool01000Oomoo`000Woo4`000goo00@007ooOol0
00Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo
0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00H007ooOol007oo0003Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000X
Ool00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo
1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@
Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00
Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000
Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomo
o`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02
001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001o
ogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<0
07ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03
001oogoo05Iooa0000aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1@
Ool6000LOol000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02001=Ool5000QOol000Yoo`04
001oogoo000;Ool01000Oomoo`00Bgoo0`009Woo000:Ool01000Oomoo`001goo10000goo00<007oo
Ool0Agoo0P00:Goo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Agoo0P00:Woo000;Ool2
0008Ool50002Ool00`00Oomoo`14Ool2000/Ool001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<0
00Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`800003Ool00000009oo`D000=oo`8000Aoo`8000Eo
o`D0009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01@00Oomo
o`00Ool00`0017oo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol0
07oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`00
0Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`05Ool00`00Oomoo`040006Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo
0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eo
o`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04
001oogooOol4000017oo000000000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00
Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo
0004Ool20003Ool01000Oomoogoo0P0000Eoo`00Oomoo`0000Aoo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo
0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`80
00Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0>Woo00<0
07ooOol0=Goo000LOol00`00Oomoo`0gOol3000hOol001aoofT000aoo`0077oo00D007ooOomoo`00
00=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
2goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=oo`00
2Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03
001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol30003
Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo
0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo
079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo
00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@0
07ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool4
0003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<0
07ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(45424\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31965 m
.008 .31934 L
.012 .31813 L
.016 .31787 L
.02 .3186 L
.024 .31875 L
.028 .31844 L
.032 .31846 L
.036 .31865 L
.04 .31867 L
.044 .31858 L
.048 .31862 L
.052 .31873 L
.056 .31876 L
.06 .31872 L
.064 .31864 L
.068 .31855 L
.072 .31853 L
.076 .31859 L
.08 .31873 L
.084 .31886 L
.088 .31893 L
.092 .31891 L
.096 .31885 L
.1 .31876 L
.104 .31869 L
.108 .31867 L
.112 .31868 L
.116 .31874 L
.12 .31885 L
.124 .31898 L
.128 .31909 L
.132 .3191 L
.136 .319 L
.14 .31883 L
.144 .3187 L
.148 .31869 L
.152 .31883 L
.156 .31905 L
.16 .31921 L
.164 .31921 L
.168 .31904 L
.172 .31886 L
.176 .31881 L
.18 .31896 L
.184 .31919 L
.188 .31935 L
.192 .31931 L
.196 .31908 L
.2 .3188 L
Mistroke
.204 .31868 L
.208 .31886 L
.212 .31924 L
.216 .31959 L
.22 .31968 L
.224 .31947 L
.228 .3191 L
.232 .31879 L
.236 .31872 L
.24 .31892 L
.244 .3193 L
.248 .31965 L
.252 .31976 L
.256 .31956 L
.26 .31921 L
.264 .31893 L
.268 .31889 L
.272 .31909 L
.276 .31944 L
.28 .31978 L
.284 .31991 L
.288 .31971 L
.292 .31925 L
.296 .31882 L
.3 .31874 L
.304 .31909 L
.308 .31965 L
.312 .3201 L
.316 .32021 L
.32 .31995 L
.324 .31942 L
.328 .31889 L
.332 .31868 L
.336 .31897 L
.34 .3196 L
.344 .32019 L
.348 .32037 L
.352 .32008 L
.356 .31957 L
.36 .31913 L
.364 .31894 L
.368 .31906 L
.372 .31947 L
.376 .32003 L
.38 .32043 L
.384 .32038 L
.388 .31988 L
.392 .31924 L
.396 .31888 L
.4 .31895 L
Mistroke
.404 .31936 L
.408 .31985 L
.412 .32022 L
.416 .32035 L
.42 .32014 L
.424 .31961 L
.428 .31898 L
.432 .31862 L
.436 .31873 L
.44 .31919 L
.444 .31963 L
.448 .31974 L
.452 .31948 L
.456 .31899 L
.46 .31843 L
.464 .31785 L
.468 .31732 L
.472 .31694 L
.476 .31679 L
.48 .31672 L
.484 .31637 L
.488 .31544 L
.492 .31391 L
.496 .31204 L
.5 .31008 L
.504 .30805 L
.508 .30573 L
.512 .3029 L
.516 .29952 L
.52 .29564 L
.524 .29117 L
.528 .28584 L
.532 .27942 L
.536 .27198 L
.54 .26389 L
.544 .2555 L
.548 .2469 L
.552 .23792 L
.556 .2286 L
.56 .21936 L
.564 .21092 L
.568 .20374 L
.572 .19781 L
.576 .19295 L
.58 .18932 L
.584 .18759 L
.588 .18843 L
.592 .19191 L
.596 .19733 L
.6 .20381 L
Mistroke
.604 .21085 L
.608 .21834 L
.612 .2259 L
.616 .23241 L
.62 .2364 L
.624 .23711 L
.628 .23504 L
.632 .23158 L
.636 .22785 L
.64 .22399 L
.644 .21965 L
.648 .21507 L
.652 .21155 L
.656 .21066 L
.66 .21292 L
.664 .21739 L
.668 .22251 L
.672 .22753 L
.676 .23295 L
.68 .23954 L
.684 .24693 L
.688 .25341 L
.692 .2572 L
.696 .25821 L
.7 .25847 L
.704 .26071 L
.708 .26642 L
.712 .27498 L
.716 .2847 L
.72 .29455 L
.724 .30476 L
.728 .31583 L
.732 .32693 L
.736 .33545 L
.74 .33851 L
.744 .3351 L
.748 .32716 L
.752 .31839 L
.756 .3118 L
.76 .30803 L
.764 .30563 L
.768 .30297 L
.772 .29984 L
.776 .29758 L
.78 .29754 L
.784 .2997 L
.788 .30255 L
.792 .30448 L
.796 .3053 L
.8 .30657 L
Mistroke
.804 .31014 L
.808 .31652 L
.812 .32376 L
.816 .32858 L
.82 .32838 L
.824 .32278 L
.828 .31418 L
.832 .30601 L
.836 .30135 L
.84 .30142 L
.844 .30549 L
.848 .31194 L
.852 .31861 L
.856 .32413 L
.86 .32755 L
.864 .32854 L
.868 .32764 L
.872 .32534 L
.876 .32268 L
.88 .3203 L
.884 .31844 L
.888 .31742 L
.892 .31723 L
.896 .31835 L
.9 .32099 L
.904 .32469 L
.908 .32826 L
.912 .32985 L
.916 .32819 L
.92 .32352 L
.924 .3179 L
.928 .31407 L
.932 .31441 L
.936 .31874 L
.94 .32452 L
.944 .32872 L
.948 .32812 L
.952 .32329 L
.956 .3168 L
.96 .3117 L
.964 .3119 L
.968 .31611 L
.972 .32221 L
.976 .32741 L
.98 .3272 L
.984 .32404 L
.988 .31914 L
.992 .31522 L
.996 .31731 L
1 .32164 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13779 m
.008 .13352 L
.012 .13201 L
.016 .13338 L
.02 .13388 L
.024 .13348 L
.028 .13327 L
.032 .13343 L
.036 .13349 L
.04 .13346 L
.044 .13342 L
.048 .13344 L
.052 .13343 L
.056 .13344 L
.06 .13343 L
.064 .13345 L
.068 .13344 L
.072 .13344 L
.076 .13343 L
.08 .13344 L
.084 .13343 L
.088 .13344 L
.092 .13344 L
.096 .13345 L
.1 .13344 L
.104 .13344 L
.108 .13344 L
.112 .13344 L
.116 .13344 L
.12 .13344 L
.124 .13344 L
.128 .13344 L
.132 .13344 L
.136 .13344 L
.14 .13344 L
.144 .13345 L
.148 .13345 L
.152 .13344 L
.156 .13344 L
.16 .13343 L
.164 .13343 L
.168 .13344 L
.172 .13344 L
.176 .13345 L
.18 .13345 L
.184 .13345 L
.188 .13345 L
.192 .13344 L
.196 .13344 L
.2 .13343 L
Mistroke
.204 .13343 L
.208 .13344 L
.212 .13344 L
.216 .13345 L
.22 .13345 L
.224 .13345 L
.228 .13344 L
.232 .13344 L
.236 .13344 L
.24 .13344 L
.244 .13345 L
.248 .13345 L
.252 .13344 L
.256 .13343 L
.26 .13343 L
.264 .13344 L
.268 .13345 L
.272 .13345 L
.276 .13346 L
.28 .13345 L
.284 .13344 L
.288 .13344 L
.292 .13344 L
.296 .13344 L
.3 .13344 L
.304 .13345 L
.308 .13345 L
.312 .13345 L
.316 .13345 L
.32 .13345 L
.324 .13344 L
.328 .13344 L
.332 .13344 L
.336 .13345 L
.34 .13345 L
.344 .13345 L
.348 .13345 L
.352 .13345 L
.356 .13344 L
.36 .13344 L
.364 .13344 L
.368 .13345 L
.372 .13345 L
.376 .13346 L
.38 .13346 L
.384 .13346 L
.388 .13346 L
.392 .13346 L
.396 .13346 L
.4 .13345 L
Mistroke
.404 .13345 L
.408 .13345 L
.412 .13346 L
.416 .13348 L
.42 .13349 L
.424 .13351 L
.428 .13351 L
.432 .13352 L
.436 .13352 L
.44 .13352 L
.444 .13353 L
.448 .13355 L
.452 .13358 L
.456 .13362 L
.46 .13367 L
.464 .13372 L
.468 .13377 L
.472 .13382 L
.476 .13388 L
.48 .13395 L
.484 .13405 L
.488 .13417 L
.492 .13433 L
.496 .13452 L
.5 .13474 L
.504 .135 L
.508 .1353 L
.512 .13565 L
.516 .13607 L
.52 .13658 L
.524 .13718 L
.528 .1379 L
.532 .13876 L
.536 .13976 L
.54 .14092 L
.544 .14225 L
.548 .14374 L
.552 .14541 L
.556 .14725 L
.56 .1493 L
.564 .15152 L
.568 .15391 L
.572 .15646 L
.576 .15912 L
.58 .16187 L
.584 .16468 L
.588 .16749 L
.592 .17026 L
.596 .17293 L
.6 .1755 L
Mistroke
.604 .17795 L
.608 .18027 L
.612 .18246 L
.616 .18452 L
.62 .18648 L
.624 .18838 L
.628 .19028 L
.632 .19222 L
.636 .19422 L
.64 .19632 L
.644 .19853 L
.648 .20088 L
.652 .20334 L
.656 .20587 L
.66 .2084 L
.664 .21086 L
.668 .21322 L
.672 .21546 L
.676 .21759 L
.68 .21962 L
.684 .22155 L
.688 .22341 L
.692 .22523 L
.696 .22706 L
.7 .22888 L
.704 .23067 L
.708 .23235 L
.712 .23385 L
.716 .23514 L
.72 .23622 L
.724 .23711 L
.728 .23783 L
.732 .23839 L
.736 .23881 L
.74 .23916 L
.744 .23952 L
.748 .23996 L
.752 .24051 L
.756 .24114 L
.76 .24182 L
.764 .24254 L
.768 .2433 L
.772 .24416 L
.776 .2451 L
.78 .24612 L
.784 .24716 L
.788 .24815 L
.792 .24908 L
.796 .24992 L
.8 .25066 L
Mistroke
.804 .25127 L
.808 .25174 L
.812 .25205 L
.816 .25224 L
.82 .25242 L
.824 .25269 L
.828 .25315 L
.832 .2538 L
.836 .25461 L
.84 .25545 L
.844 .25623 L
.848 .25684 L
.852 .25725 L
.856 .25745 L
.86 .25747 L
.864 .25737 L
.868 .25717 L
.872 .25693 L
.876 .25667 L
.88 .25642 L
.884 .25622 L
.888 .25607 L
.892 .25598 L
.896 .25591 L
.9 .25585 L
.904 .25576 L
.908 .25562 L
.912 .25546 L
.916 .2553 L
.92 .2552 L
.924 .25516 L
.928 .25514 L
.932 .2551 L
.936 .25496 L
.94 .25472 L
.944 .25441 L
.948 .25414 L
.952 .25404 L
.956 .25416 L
.96 .2545 L
.964 .255 L
.968 .25547 L
.972 .25589 L
.976 .25612 L
.98 .25621 L
.984 .25619 L
.988 .25605 L
.992 .25585 L
.996 .25552 L
1 .25503 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16297 L
.012 .16106 L
.016 .16052 L
.02 .16128 L
.024 .16138 L
.028 .16112 L
.032 .16104 L
.036 .16116 L
.04 .16114 L
.044 .16111 L
.048 .16109 L
.052 .16111 L
.056 .16109 L
.06 .16108 L
.064 .16105 L
.068 .16106 L
.072 .16104 L
.076 .16104 L
.08 .16102 L
.084 .16102 L
.088 .16101 L
.092 .161 L
.096 .16099 L
.1 .16099 L
.104 .16097 L
.108 .16096 L
.112 .16095 L
.116 .16094 L
.12 .16093 L
.124 .16092 L
.128 .16091 L
.132 .16091 L
.136 .16089 L
.14 .16089 L
.144 .16088 L
.148 .16088 L
.152 .16087 L
.156 .16085 L
.16 .16083 L
.164 .16082 L
.168 .1608 L
.172 .1608 L
.176 .1608 L
.18 .16081 L
.184 .1608 L
.188 .16079 L
.192 .16076 L
.196 .16074 L
.2 .16073 L
Mistroke
.204 .16072 L
.208 .16072 L
.212 .16072 L
.216 .16072 L
.22 .1607 L
.224 .16069 L
.228 .16068 L
.232 .16067 L
.236 .16066 L
.24 .16065 L
.244 .16064 L
.248 .16063 L
.252 .16062 L
.256 .1606 L
.26 .16059 L
.264 .16059 L
.268 .16059 L
.272 .16058 L
.276 .16058 L
.28 .16057 L
.284 .16055 L
.288 .16053 L
.292 .16051 L
.296 .1605 L
.3 .1605 L
.304 .1605 L
.308 .1605 L
.312 .16049 L
.316 .16048 L
.32 .16046 L
.324 .16045 L
.328 .16044 L
.332 .16043 L
.336 .16043 L
.34 .16042 L
.344 .16041 L
.348 .1604 L
.352 .16038 L
.356 .16037 L
.36 .16036 L
.364 .16035 L
.368 .16034 L
.372 .16034 L
.376 .16034 L
.38 .16033 L
.384 .16032 L
.388 .16031 L
.392 .16029 L
.396 .16027 L
.4 .16025 L
Mistroke
.404 .16023 L
.408 .16021 L
.412 .16021 L
.416 .1602 L
.42 .1602 L
.424 .16019 L
.428 .16018 L
.432 .16015 L
.436 .16011 L
.44 .16007 L
.444 .16002 L
.448 .15999 L
.452 .15996 L
.456 .15993 L
.46 .15989 L
.464 .15984 L
.468 .15976 L
.472 .15967 L
.476 .15956 L
.48 .15943 L
.484 .15929 L
.488 .15913 L
.492 .15895 L
.496 .15874 L
.5 .15848 L
.504 .15817 L
.508 .15777 L
.512 .15729 L
.516 .15672 L
.52 .15605 L
.524 .15527 L
.528 .15436 L
.532 .1533 L
.536 .15208 L
.54 .15067 L
.544 .14905 L
.548 .1472 L
.552 .14509 L
.556 .14273 L
.56 .14015 L
.564 .13734 L
.568 .13432 L
.572 .13113 L
.576 .12779 L
.58 .12436 L
.584 .12088 L
.588 .1174 L
.592 .11396 L
.596 .11059 L
.6 .10735 L
Mistroke
.604 .10428 L
.608 .10139 L
.612 .09868 L
.616 .09609 L
.62 .09361 L
.624 .09118 L
.628 .08877 L
.632 .08632 L
.636 .08377 L
.64 .08109 L
.644 .07827 L
.648 .07535 L
.652 .07236 L
.656 .06931 L
.66 .06624 L
.664 .06316 L
.668 .06013 L
.672 .05722 L
.676 .05445 L
.68 .05184 L
.684 .04935 L
.688 .04696 L
.692 .04464 L
.696 .04241 L
.7 .04026 L
.704 .03817 L
.708 .03613 L
.712 .03417 L
.716 .03237 L
.72 .03081 L
.724 .02957 L
.728 .02867 L
.732 .02803 L
.736 .02756 L
.74 .02716 L
.744 .02676 L
.748 .0263 L
.752 .0257 L
.756 .0249 L
.76 .02387 L
.764 .02266 L
.768 .02134 L
.772 .02005 L
.776 .01885 L
.78 .01775 L
.784 .0167 L
.788 .01566 L
.792 .01464 L
.796 .01366 L
.8 .01279 L
Mistroke
.804 .01204 L
.808 .0114 L
.812 .01081 L
.816 .01023 L
.82 .00962 L
.824 .00897 L
.828 .00828 L
.832 .00753 L
.836 .00673 L
.84 .00589 L
.844 .00508 L
.848 .00439 L
.852 .00391 L
.856 .0037 L
.86 .00372 L
.864 .0039 L
.868 .00412 L
.872 .00426 L
.876 .0043 L
.88 .00422 L
.884 .00412 L
.888 .00408 L
.892 .00416 L
.896 .00439 L
.9 .00472 L
.904 .0051 L
.908 .00545 L
.912 .00576 L
.916 .00602 L
.92 .00625 L
.924 .00644 L
.928 .00653 L
.932 .00648 L
.936 .00622 L
.94 .00579 L
.944 .00529 L
.948 .00487 L
.952 .00469 L
.956 .00476 L
.96 .00502 L
.964 .00535 L
.968 .00554 L
.972 .00561 L
.976 .00554 L
.98 .0055 L
.984 .00563 L
.988 .00588 L
.992 .00623 L
.996 .00644 L
1 .00632 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0=Goo0`00=7oo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool2000eOol200000goo0000000cOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001goo0`0017oo0P0017oo0P00
1Goo0`0000=oo`00Ool00`000goo0`000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P00
1Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
00]oo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0005Ool00`00Oomoo`020002Ool2000017oo000007oo0P000goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`0017oo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007oo
Ool00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001o
ogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oo`0000Eoo`@0009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Ool00005Ool01000Oomoo`000Woo
0P0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Ao
o`03001oogoo00]oo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`80009oo`@000=oo`03001oogoo00@000=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00D007ooOomoo`0000=oo`03001oo`0000<000=oo`04001oogoo0005Ool000]oo`8000Yoo`80
00Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomo
o`000Woo00@007ooOol000Aoo`<0009oo`03001oogoo00Aoo`05001oogoo001oo`020003Ool01000
Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00003Ool00`00Ool00006Ool01000Oomoo`00
1Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo
1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomo
o`0aOol00`00Oomoo`0?Ool00`00Oomoo`0VOol0029oo`80035oo`03001oogoo011oo`03001oogoo
00=oo`03001oogoo021oo`008WooH`0037oo000ROolL00000goo00000003000017oo000007oo0P00
0Woo0P0000=oo`0000000`0000=oo`00Ool00Woo00D007ooOomoo`00009oo`05001oogooOol00003
Ool200000goo00000003Ool2000017oo000000000Woo0P000Woo0P0000Aoo`00001oo`<000aoo`00
8Woo0P0047oo0P0000Aoo`00001oo`800004Ool00000Ool9000017oo000007oo0P006Woo00<007oo
00001Goo0P000goo0`0000Eoo`00000007oo00800005Ool00000Ool0000<Ool0029oo`03001oogoo
04Eoo`8000moo`03001oogoo01=oo`008Woo0P00KGoo000ROol2001]Ool000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomo
o`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qo
o`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo
0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001o
ogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000
Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@0
07ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo
0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007oo
Ool0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001o
ogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02
001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo
06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomo
o`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo<@00>7oo000AOol2000:
Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0^Ool3000eOol002Qoo`03001oogoo035oo`8003=o
o`00:7oo00<007ooOol0<Woo0P00<Woo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool3
0003Ool00`00Oomoo`0dOol2000`Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007oo
Ool007oo0003Ool01000Oomoo`00=goo0`00;Woo0003Ool50002Ool01000Oomoo`0027oo00@007oo
Ool0009oo`04001oogoo0005Ool01000Oomoo`00>Goo0`00;7oo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004
Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo
00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`800005Ool007ooOol00002Ool0
1000Oomoo`000Woo00@007ooOol000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001o
ogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Ool000020004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`80
00Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002
Ool01000Oomoogoo1`0000Eoo`00Oomoo`00009oo`03001oogoo00=oo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003Ool01P00Oomoo`00
Ool000=oo`03001oogoo01H000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo
00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001o
ogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
0goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<0
07ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Ao
o`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed0
00aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<0
07ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<0
07ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009o
o`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0
IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogoo
Ool4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;
Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1COolC000<Ool000Yoo`04001oogoo
0007Ool01@00Oomoogoo00000Woo00<007ooOol0CWoo1@007goo0003Ool50002Ool01000Oomoo`00
2goo00<007ooOol00P00BWoo1@0097oo000:Ool01000Oomoo`002goo00@007ooOol004Qoo`@002Qo
o`002Woo00@007ooOol000Moo`@000=oo`03001oogoo04Aoo`<002]oo`002Woo00@007ooOol000Mo
o`03001oogoo00Aoo`8004Aoo`8002eoo`002goo0P0027oo1@000Woo00<007ooOol0@Goo0`00;Woo
000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool30004Ool2
0005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogoo
Ool00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
1@00Oomoogoo00000goo00<007ooOol00P0000=oo`00Ool017oo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo
000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`05Ool40002Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`800005Ool007ooOol00007Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002
Ool00`00Oomoo`03Ool001aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomo
o`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`0027oo0P0017oo00@007oo
Ool0009oo`04001oogoo0004Ool20003Ool30004Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo
000LOol2000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@00
0goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`0g
Ool2000iOol001aoo`03001oogoo03Aoo`<003]oo`0077ooJ@0037oo000LOol01@00Oomoogoo0000
0goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000;
Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:
Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2
001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Ioo`<000=o
o`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2
001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0
LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool0
0`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000
Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@0
00=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00
Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(45591\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32001 m
.008 .31875 L
.012 .31797 L
.016 .31784 L
.02 .31854 L
.024 .31889 L
.028 .3187 L
.032 .31861 L
.036 .31866 L
.04 .31857 L
.044 .31836 L
.048 .31827 L
.052 .31841 L
.056 .31865 L
.06 .31883 L
.064 .3189 L
.068 .31882 L
.072 .31867 L
.076 .31856 L
.08 .31853 L
.084 .3186 L
.088 .3187 L
.092 .31875 L
.096 .31875 L
.1 .31873 L
.104 .31874 L
.108 .31881 L
.112 .3189 L
.116 .31893 L
.12 .31889 L
.124 .31878 L
.128 .31869 L
.132 .31867 L
.136 .31873 L
.14 .31887 L
.144 .31901 L
.148 .31908 L
.152 .31907 L
.156 .319 L
.16 .31891 L
.164 .31885 L
.168 .31882 L
.172 .31886 L
.176 .31896 L
.18 .31908 L
.184 .31915 L
.188 .31914 L
.192 .31905 L
.196 .31896 L
.2 .31894 L
Mistroke
.204 .31901 L
.208 .31917 L
.212 .31932 L
.216 .31932 L
.22 .31915 L
.224 .31891 L
.228 .31879 L
.232 .31891 L
.236 .31921 L
.24 .31952 L
.244 .31965 L
.248 .31953 L
.252 .31921 L
.256 .31888 L
.26 .31876 L
.264 .31896 L
.268 .31936 L
.272 .31969 L
.276 .31975 L
.28 .31954 L
.284 .31923 L
.288 .31898 L
.292 .31894 L
.296 .31914 L
.3 .31951 L
.304 .31987 L
.308 .31995 L
.312 .31968 L
.316 .31924 L
.32 .31889 L
.324 .31885 L
.328 .31912 L
.332 .31957 L
.336 .32003 L
.34 .32024 L
.344 .32006 L
.348 .31952 L
.352 .31894 L
.356 .3187 L
.36 .31896 L
.364 .31953 L
.368 .32003 L
.372 .32023 L
.376 .32007 L
.38 .31967 L
.384 .31917 L
.388 .31879 L
.392 .31878 L
.396 .31918 L
.4 .31974 L
Mistroke
.404 .32008 L
.408 .31995 L
.412 .31942 L
.416 .31881 L
.42 .31835 L
.424 .31815 L
.428 .3182 L
.432 .31843 L
.436 .31867 L
.44 .31863 L
.444 .31808 L
.448 .31705 L
.452 .31585 L
.456 .31485 L
.46 .31414 L
.464 .3135 L
.468 .31258 L
.472 .31117 L
.476 .30921 L
.48 .30668 L
.484 .30351 L
.488 .2997 L
.492 .2954 L
.496 .29076 L
.5 .2858 L
.504 .28024 L
.508 .2737 L
.512 .26603 L
.516 .25743 L
.52 .24828 L
.524 .23892 L
.528 .22951 L
.532 .22019 L
.536 .2113 L
.54 .20334 L
.544 .19675 L
.548 .19167 L
.552 .18809 L
.556 .18611 L
.56 .18608 L
.564 .18833 L
.568 .19282 L
.572 .19893 L
.576 .20588 L
.58 .21307 L
.584 .22022 L
.588 .22693 L
.592 .2324 L
.596 .23557 L
.6 .23579 L
Mistroke
.604 .23332 L
.608 .22911 L
.612 .22415 L
.616 .21899 L
.62 .21394 L
.624 .20974 L
.628 .20759 L
.632 .20855 L
.636 .21264 L
.64 .21865 L
.644 .22506 L
.648 .23105 L
.652 .23681 L
.656 .2427 L
.66 .24838 L
.664 .25284 L
.668 .25548 L
.672 .25707 L
.676 .25949 L
.68 .26442 L
.684 .27206 L
.688 .28127 L
.692 .29079 L
.696 .30038 L
.7 .31052 L
.704 .32108 L
.708 .33039 L
.712 .33583 L
.716 .33569 L
.72 .33063 L
.724 .32326 L
.728 .3163 L
.732 .31085 L
.736 .30628 L
.74 .30169 L
.744 .29743 L
.748 .29497 L
.752 .29551 L
.756 .29854 L
.76 .30194 L
.764 .30379 L
.768 .30403 L
.772 .30468 L
.776 .30806 L
.78 .31454 L
.784 .32192 L
.788 .32672 L
.792 .32662 L
.796 .32195 L
.8 .31521 L
Mistroke
.804 .30932 L
.808 .30577 L
.812 .30454 L
.816 .305 L
.82 .30698 L
.824 .31108 L
.828 .31736 L
.832 .32475 L
.836 .33082 L
.84 .33302 L
.844 .33055 L
.848 .32464 L
.852 .31834 L
.856 .31452 L
.86 .31445 L
.864 .31755 L
.868 .32171 L
.872 .32496 L
.876 .3262 L
.88 .32553 L
.884 .32396 L
.888 .32256 L
.892 .32203 L
.896 .3223 L
.9 .32276 L
.904 .32246 L
.908 .321 L
.912 .31871 L
.916 .31668 L
.92 .31664 L
.924 .31892 L
.928 .32295 L
.932 .32653 L
.936 .32673 L
.94 .32323 L
.944 .31683 L
.948 .31125 L
.952 .31082 L
.956 .31576 L
.96 .32535 L
.964 .33405 L
.968 .33628 L
.972 .3317 L
.976 .3205 L
.98 .30975 L
.984 .3058 L
.988 .30904 L
.992 .32014 L
.996 .33107 L
1 .33512 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13189 m
.008 .134 L
.012 .1346 L
.016 .1338 L
.02 .13361 L
.024 .13395 L
.028 .13397 L
.032 .13387 L
.036 .13384 L
.04 .1339 L
.044 .13389 L
.048 .13389 L
.052 .13387 L
.056 .13389 L
.06 .13388 L
.064 .13389 L
.068 .13388 L
.072 .13389 L
.076 .13388 L
.08 .13389 L
.084 .13388 L
.088 .13389 L
.092 .13388 L
.096 .13389 L
.1 .13388 L
.104 .13389 L
.108 .13388 L
.112 .13389 L
.116 .13389 L
.12 .13389 L
.124 .13389 L
.128 .13389 L
.132 .13388 L
.136 .13388 L
.14 .13388 L
.144 .13389 L
.148 .13389 L
.152 .13389 L
.156 .13388 L
.16 .13388 L
.164 .13388 L
.168 .13389 L
.172 .1339 L
.176 .1339 L
.18 .13389 L
.184 .13388 L
.188 .13387 L
.192 .13387 L
.196 .13388 L
.2 .13389 L
Mistroke
.204 .1339 L
.208 .1339 L
.212 .1339 L
.216 .13389 L
.22 .13388 L
.224 .13388 L
.228 .13388 L
.232 .13388 L
.236 .13389 L
.24 .13389 L
.244 .13389 L
.248 .13389 L
.252 .13389 L
.256 .13389 L
.26 .13389 L
.264 .13389 L
.268 .13389 L
.272 .13389 L
.276 .13389 L
.28 .13388 L
.284 .13388 L
.288 .13388 L
.292 .13389 L
.296 .1339 L
.3 .1339 L
.304 .1339 L
.308 .13389 L
.312 .13389 L
.316 .13388 L
.32 .13388 L
.324 .13389 L
.328 .13389 L
.332 .1339 L
.336 .1339 L
.34 .1339 L
.344 .13389 L
.348 .13389 L
.352 .13389 L
.356 .1339 L
.36 .1339 L
.364 .1339 L
.368 .13391 L
.372 .13391 L
.376 .13391 L
.38 .1339 L
.384 .1339 L
.388 .13391 L
.392 .13392 L
.396 .13393 L
.4 .13394 L
Mistroke
.404 .13396 L
.408 .13397 L
.412 .13398 L
.416 .134 L
.42 .13401 L
.424 .13402 L
.428 .13404 L
.432 .13407 L
.436 .13412 L
.44 .13418 L
.444 .13425 L
.448 .13432 L
.452 .13441 L
.456 .1345 L
.46 .13461 L
.464 .13474 L
.468 .13489 L
.472 .13509 L
.476 .13534 L
.48 .13564 L
.484 .136 L
.488 .13642 L
.492 .13692 L
.496 .1375 L
.5 .13818 L
.504 .13898 L
.508 .13992 L
.512 .14101 L
.516 .14228 L
.52 .14373 L
.524 .14535 L
.528 .14716 L
.532 .14915 L
.536 .15132 L
.54 .15365 L
.544 .15614 L
.548 .15875 L
.552 .16147 L
.556 .16425 L
.56 .16706 L
.564 .16985 L
.568 .17258 L
.572 .1752 L
.576 .17769 L
.58 .18004 L
.584 .18226 L
.588 .18435 L
.592 .18633 L
.596 .18825 L
.6 .19016 L
Mistroke
.604 .19209 L
.608 .19409 L
.612 .19617 L
.616 .19834 L
.62 .20062 L
.624 .203 L
.628 .20546 L
.632 .20796 L
.636 .21043 L
.64 .21285 L
.644 .21516 L
.648 .21737 L
.652 .21946 L
.656 .22144 L
.66 .22332 L
.664 .22512 L
.668 .22688 L
.672 .22865 L
.676 .2304 L
.68 .23211 L
.684 .2337 L
.688 .23513 L
.692 .23634 L
.696 .23733 L
.7 .23811 L
.704 .23868 L
.708 .23908 L
.712 .23938 L
.716 .23967 L
.72 .24005 L
.724 .24056 L
.728 .2412 L
.732 .24192 L
.736 .2427 L
.74 .24352 L
.744 .24439 L
.748 .24531 L
.752 .24625 L
.756 .2472 L
.76 .24811 L
.764 .249 L
.768 .24985 L
.772 .25066 L
.776 .25137 L
.78 .25192 L
.784 .25229 L
.788 .25252 L
.792 .25271 L
.796 .25296 L
.8 .25338 L
Mistroke
.804 .25397 L
.808 .2547 L
.812 .2555 L
.816 .25628 L
.82 .25698 L
.824 .25752 L
.828 .25785 L
.832 .25793 L
.836 .25778 L
.84 .25746 L
.844 .25709 L
.848 .25677 L
.852 .25656 L
.856 .25649 L
.86 .25649 L
.864 .2565 L
.868 .25646 L
.872 .25635 L
.876 .2562 L
.88 .25602 L
.884 .25584 L
.888 .25568 L
.892 .25553 L
.896 .25537 L
.9 .25519 L
.904 .25502 L
.908 .25489 L
.912 .25483 L
.916 .25485 L
.92 .25494 L
.924 .25506 L
.928 .25519 L
.932 .2553 L
.936 .25541 L
.94 .25558 L
.944 .25579 L
.948 .25605 L
.952 .25623 L
.956 .25623 L
.96 .256 L
.964 .2555 L
.968 .25488 L
.972 .2543 L
.976 .25392 L
.98 .25388 L
.984 .25406 L
.988 .25441 L
.992 .25475 L
.996 .25499 L
1 .25513 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16441 L
.012 .16126 L
.016 .16009 L
.02 .16113 L
.024 .1615 L
.028 .1612 L
.032 .16102 L
.036 .16113 L
.04 .16115 L
.044 .16112 L
.048 .16107 L
.052 .1611 L
.056 .16108 L
.06 .16109 L
.064 .16106 L
.068 .16106 L
.072 .16104 L
.076 .16104 L
.08 .16102 L
.084 .16102 L
.088 .16101 L
.092 .161 L
.096 .16098 L
.1 .16098 L
.104 .16097 L
.108 .16096 L
.112 .16095 L
.116 .16095 L
.12 .16093 L
.124 .16093 L
.128 .16091 L
.132 .16091 L
.136 .16089 L
.14 .16088 L
.144 .16087 L
.148 .16086 L
.152 .16085 L
.156 .16085 L
.16 .16084 L
.164 .16083 L
.168 .16082 L
.172 .16081 L
.176 .1608 L
.18 .16079 L
.184 .16078 L
.188 .16076 L
.192 .16075 L
.196 .16075 L
.2 .16074 L
Mistroke
.204 .16074 L
.208 .16074 L
.212 .16073 L
.216 .16071 L
.22 .16069 L
.224 .16067 L
.228 .16067 L
.232 .16066 L
.236 .16066 L
.24 .16066 L
.244 .16065 L
.248 .16063 L
.252 .16062 L
.256 .16061 L
.26 .16061 L
.264 .1606 L
.268 .16059 L
.272 .16057 L
.276 .16056 L
.28 .16054 L
.284 .16054 L
.288 .16053 L
.292 .16053 L
.296 .16053 L
.3 .16052 L
.304 .16051 L
.308 .16049 L
.312 .16048 L
.316 .16046 L
.32 .16045 L
.324 .16044 L
.328 .16044 L
.332 .16044 L
.336 .16043 L
.34 .16042 L
.344 .1604 L
.348 .16039 L
.352 .16038 L
.356 .16037 L
.36 .16036 L
.364 .16036 L
.368 .16034 L
.372 .16033 L
.376 .16031 L
.38 .16029 L
.384 .16028 L
.388 .16026 L
.392 .16025 L
.396 .16024 L
.4 .16022 L
Mistroke
.404 .16021 L
.408 .16019 L
.412 .16016 L
.416 .16013 L
.42 .16008 L
.424 .16003 L
.428 .15998 L
.432 .15993 L
.436 .15988 L
.44 .15982 L
.444 .15975 L
.448 .15967 L
.452 .15956 L
.456 .15943 L
.46 .15926 L
.464 .15906 L
.468 .15883 L
.472 .15856 L
.476 .15826 L
.48 .1579 L
.484 .15748 L
.488 .15696 L
.492 .15633 L
.496 .15559 L
.5 .15471 L
.504 .15367 L
.508 .15247 L
.512 .15109 L
.516 .14953 L
.52 .14775 L
.524 .14575 L
.528 .14349 L
.532 .14099 L
.536 .13826 L
.54 .13531 L
.544 .13217 L
.548 .12887 L
.552 .12546 L
.556 .12199 L
.56 .11851 L
.564 .11506 L
.568 .11169 L
.572 .10842 L
.576 .10528 L
.58 .10231 L
.584 .0995 L
.588 .09686 L
.592 .09433 L
.596 .09189 L
.6 .08949 L
Mistroke
.604 .08708 L
.608 .08462 L
.612 .08204 L
.616 .0793 L
.62 .07642 L
.624 .07342 L
.628 .07035 L
.632 .06724 L
.636 .06415 L
.64 .06112 L
.644 .05818 L
.648 .05539 L
.652 .05275 L
.656 .05024 L
.66 .04782 L
.664 .04548 L
.668 .0432 L
.672 .041 L
.676 .03889 L
.68 .03687 L
.684 .03494 L
.688 .03316 L
.692 .03157 L
.696 .03024 L
.7 .02919 L
.704 .02838 L
.708 .02776 L
.712 .02726 L
.716 .02683 L
.72 .0264 L
.724 .02591 L
.728 .02527 L
.732 .02442 L
.736 .02336 L
.74 .02215 L
.744 .02088 L
.748 .01963 L
.752 .01842 L
.756 .01724 L
.76 .0161 L
.764 .01502 L
.768 .01403 L
.772 .01316 L
.776 .01241 L
.78 .01173 L
.784 .01109 L
.788 .01048 L
.792 .00989 L
.796 .00932 L
.8 .00875 L
Mistroke
.804 .00812 L
.808 .00738 L
.812 .00655 L
.816 .0057 L
.82 .00495 L
.824 .00439 L
.828 .00407 L
.832 .00395 L
.836 .00396 L
.84 .00402 L
.844 .00409 L
.848 .00415 L
.852 .00424 L
.856 .00435 L
.86 .00449 L
.864 .00465 L
.868 .00484 L
.872 .00505 L
.876 .0053 L
.88 .00559 L
.884 .0059 L
.888 .00619 L
.892 .0064 L
.896 .00648 L
.9 .00644 L
.904 .00627 L
.908 .00606 L
.912 .00586 L
.916 .00575 L
.92 .00573 L
.924 .00578 L
.928 .00585 L
.932 .00587 L
.936 .00581 L
.94 .00572 L
.944 .00559 L
.948 .00552 L
.952 .00548 L
.956 .00545 L
.96 .00541 L
.964 .00529 L
.968 .00515 L
.972 .00504 L
.976 .00502 L
.98 .0052 L
.984 .00548 L
.988 .00587 L
.992 .00622 L
.996 .00647 L
1 .0066 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0<goo0P00=goo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool2000cOol01000Oomoo`00=Woo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8000eoo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000Eo
o`<000=oo`<00004Ool00000Ool20003Ool50003Ool20004Ool20004Ool50002Ool30004Ool20006
Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
2goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogooOol20002Ool01000Ool000000Woo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo00H007ooOol007oo0003Ool01000Oomoo`00
0Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`03001oogoo009oo`@0009oo`800003Ool007oo00=oo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0004Ool20007Ool00`00Oomo
o`0200000goo001oo`04Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03
001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo0P0017oo00<007ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`000goo0`000goo10000goo10000Woo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2
000:Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo
00@007ooOol0009oo`04001oogoo0003Ool30003Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006Ool0
1000Oomoo`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool0
0`00Ool00003Ool50003Ool2000017oo001oogoo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo
0P001Woo000ROol00`00Oomoo`0^Ool00`00Oomoo`0?Ool00`00Oomoo`0YOol0029oo`8002ioo`03
001oogoo015oo`03001oogoo009oo`8002Aoo`008WooH`0037oo000ROolE00000goo000000060000
17oo000007oo0P000Woo0P0000=oo`0000001@000goo00D007ooOomoo`0000=oo`04001oogoo0003
Ool01000Ool007oo0P000Woo00H007oo001oo`00Ool5000017oo001oogoo0P0000Qoo`00000007oo
001oo`0037oo000ROol2000COol01@00Oomoo`00Ool00P0000=oo`000000100000Aoo`00001oo`80
01aoo`03001oo`0000Eoo`80009oo`04001oo`00Ool5000017oo000007oo0P0000=oo`00Ool037oo
000ROol00`00Oomoo`12Ool2000;Ool00`00Oomoo`09Ool200000goo0000000<Ool0029oo`8006eo
o`008Woo0P00KGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`80
06eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00
Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2
001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04
001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol0
0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2
000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]
Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo
1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000Aoobl003Yoo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0:goo
1000=goo000XOol00`00Oomoo`0^Ool2000fOol002Qoo`03001oogoo031oo`8003Aoo`002goo0P00
17oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0<Goo0`00<Woo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol003Eoo`80035oo`00
0goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol003Mo
o`8002moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
0P002goo0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`000Woo10000Woo1@000goo
0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001o
ogoo00@0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogoo001o
o`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`05001oogoo001oo`03
0002Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eo
o`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Ool0000500001Goo001oogoo00000Woo00@0
07ooOol000Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo
00Uoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=o
o`04001oogooOol40003Ool01P00Oomoo`00Ool000=oo`03001oo`0001H000=oo`04001oogoo0005
Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`00
0Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo
00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D0
00=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo
00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007oo
Ool006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0
06Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00
Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomo
o`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomo
o`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001o
ogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00
Oomoo`1@OolF000<Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0Bgoo
1P008Goo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00Agoo1P009Woo000:Ool01000
Oomoo`002goo00@007ooOol004Eoo`@002]oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo
049oo`8002ioo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80045oo`80031oo`002goo0P00
27oo1@000Woo00<007ooOol0?goo0P00<Goo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004
Ool20004Ool20005Ool30003Ool30002Ool40005Ool50003Ool20004Ool20005Ool50002Ool30004
Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo0P0000Eoo`00Oomoo`0000Eo
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@0
07ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo
00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00goo0`000Woo
00@007ooOol000Ioo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03
001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00Woo
0P0000Eoo`00Oomoo`00009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo
10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03
001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`80009o
o`8000Ioo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004
Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03
001oogoo00=oo`8000Aoo`8000Ioo`<00003Ool0000000<000=oo`8000Ioo`<000Aoo`8000Aoo`80
00Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol0=7oo0P00?7oo000LOol00`00Oomoo`0a
Ool3000nOol001aoofT000aoo`0077oo0P000Woo00D007ooOomoo`0000Aoo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo
079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo
00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol0
00Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomo
o`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009o
o`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomo
o`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00
Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Ao
o`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03
001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<0
07ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03
001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(45758\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31788 m
.008 .31792 L
.012 .31883 L
.016 .31884 L
.02 .31814 L
.024 .31806 L
.028 .31846 L
.032 .31861 L
.036 .31856 L
.04 .3186 L
.044 .31866 L
.048 .31861 L
.052 .31852 L
.056 .31853 L
.06 .31856 L
.064 .31857 L
.068 .31857 L
.072 .31855 L
.076 .31858 L
.08 .31866 L
.084 .31875 L
.088 .31882 L
.092 .3188 L
.096 .31871 L
.1 .31861 L
.104 .31857 L
.108 .31864 L
.112 .31877 L
.116 .31887 L
.12 .31888 L
.124 .3188 L
.128 .31872 L
.132 .31871 L
.136 .3188 L
.14 .31894 L
.144 .31903 L
.148 .31899 L
.152 .31884 L
.156 .31869 L
.16 .31866 L
.164 .31879 L
.168 .319 L
.172 .31917 L
.176 .3192 L
.18 .31909 L
.184 .31891 L
.188 .31878 L
.192 .31878 L
.196 .31892 L
.2 .31911 L
Mistroke
.204 .31922 L
.208 .31922 L
.212 .31912 L
.216 .31899 L
.22 .3189 L
.224 .31893 L
.228 .31909 L
.232 .31931 L
.236 .31944 L
.24 .31939 L
.244 .31917 L
.248 .31892 L
.252 .3188 L
.256 .31889 L
.26 .31918 L
.264 .31953 L
.268 .31975 L
.272 .31966 L
.276 .3193 L
.28 .31891 L
.284 .31877 L
.288 .31896 L
.292 .31935 L
.296 .3197 L
.3 .31981 L
.304 .31965 L
.308 .31929 L
.312 .31894 L
.316 .31885 L
.32 .31912 L
.324 .31959 L
.328 .31995 L
.332 .31997 L
.336 .31966 L
.34 .31922 L
.344 .31886 L
.348 .31875 L
.352 .31896 L
.356 .31945 L
.36 .31995 L
.364 .32016 L
.368 .31986 L
.372 .31922 L
.376 .31862 L
.38 .31836 L
.384 .31852 L
.388 .3189 L
.392 .31927 L
.396 .31942 L
.4 .31919 L
Mistroke
.404 .31854 L
.408 .31769 L
.412 .31697 L
.416 .31666 L
.42 .31667 L
.424 .31667 L
.428 .31628 L
.432 .31535 L
.436 .31395 L
.44 .31221 L
.444 .31024 L
.448 .30813 L
.452 .30598 L
.456 .30371 L
.46 .301 L
.464 .29742 L
.468 .29269 L
.472 .28691 L
.476 .28039 L
.48 .27342 L
.484 .26605 L
.488 .25818 L
.492 .24976 L
.496 .24087 L
.5 .2316 L
.504 .22209 L
.508 .2126 L
.512 .20361 L
.516 .1958 L
.52 .18978 L
.524 .18584 L
.528 .1839 L
.532 .1838 L
.536 .1855 L
.54 .18905 L
.544 .19435 L
.548 .20097 L
.552 .20823 L
.556 .21549 L
.56 .22226 L
.564 .22804 L
.568 .23221 L
.572 .23405 L
.576 .23318 L
.58 .2299 L
.584 .22506 L
.588 .21964 L
.592 .21436 L
.596 .20976 L
.6 .20649 L
Mistroke
.604 .20545 L
.608 .2074 L
.612 .21231 L
.616 .21922 L
.62 .22676 L
.624 .23394 L
.628 .24042 L
.632 .24612 L
.636 .25073 L
.64 .25384 L
.644 .25561 L
.648 .25725 L
.652 .26057 L
.656 .26681 L
.66 .27586 L
.664 .28647 L
.668 .29735 L
.672 .30789 L
.676 .3179 L
.68 .32669 L
.684 .33272 L
.688 .33441 L
.692 .33149 L
.696 .32547 L
.7 .31875 L
.704 .3129 L
.708 .30801 L
.712 .30334 L
.716 .29873 L
.72 .29522 L
.724 .29412 L
.728 .29566 L
.732 .29847 L
.736 .30075 L
.74 .30193 L
.744 .30332 L
.748 .30681 L
.752 .31296 L
.756 .31998 L
.76 .32488 L
.764 .32555 L
.768 .32223 L
.772 .31703 L
.776 .31211 L
.78 .30839 L
.784 .30556 L
.788 .30354 L
.792 .30338 L
.796 .30664 L
.8 .31391 L
Mistroke
.804 .32326 L
.808 .33106 L
.812 .33397 L
.816 .33109 L
.82 .32477 L
.824 .31867 L
.828 .31573 L
.832 .31639 L
.836 .31892 L
.84 .32128 L
.844 .32238 L
.848 .32271 L
.852 .32332 L
.856 .32459 L
.86 .32595 L
.864 .32624 L
.868 .32479 L
.872 .32196 L
.876 .31895 L
.88 .31702 L
.884 .31689 L
.888 .31837 L
.892 .32061 L
.896 .32273 L
.9 .3237 L
.904 .32315 L
.908 .32125 L
.912 .31847 L
.916 .31646 L
.92 .31608 L
.924 .31782 L
.928 .32142 L
.932 .32451 L
.936 .3262 L
.94 .32547 L
.944 .32261 L
.948 .32041 L
.952 .31914 L
.956 .31989 L
.96 .32199 L
.964 .32238 L
.968 .32191 L
.972 .31989 L
.976 .31763 L
.98 .31866 L
.984 .32088 L
.988 .32448 L
.992 .32747 L
.996 .32554 L
1 .32196 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12959 m
.008 .1343 L
.012 .13586 L
.016 .13439 L
.02 .13382 L
.024 .13432 L
.028 .13449 L
.032 .13435 L
.036 .13426 L
.04 .13433 L
.044 .13434 L
.048 .13434 L
.052 .13432 L
.056 .13434 L
.06 .13433 L
.064 .13433 L
.068 .13432 L
.072 .13433 L
.076 .13433 L
.08 .13433 L
.084 .13433 L
.088 .13433 L
.092 .13433 L
.096 .13433 L
.1 .13433 L
.104 .13433 L
.108 .13433 L
.112 .13433 L
.116 .13433 L
.12 .13433 L
.124 .13433 L
.128 .13433 L
.132 .13433 L
.136 .13433 L
.14 .13433 L
.144 .13433 L
.148 .13434 L
.152 .13434 L
.156 .13433 L
.16 .13433 L
.164 .13433 L
.168 .13433 L
.172 .13433 L
.176 .13433 L
.18 .13433 L
.184 .13433 L
.188 .13433 L
.192 .13434 L
.196 .13434 L
.2 .13434 L
Mistroke
.204 .13434 L
.208 .13433 L
.212 .13432 L
.216 .13432 L
.22 .13433 L
.224 .13433 L
.228 .13434 L
.232 .13435 L
.236 .13434 L
.24 .13434 L
.244 .13433 L
.248 .13433 L
.252 .13433 L
.256 .13433 L
.26 .13433 L
.264 .13434 L
.268 .13434 L
.272 .13434 L
.276 .13434 L
.28 .13434 L
.284 .13434 L
.288 .13434 L
.292 .13434 L
.296 .13434 L
.3 .13433 L
.304 .13433 L
.308 .13433 L
.312 .13433 L
.316 .13434 L
.32 .13435 L
.324 .13435 L
.328 .13435 L
.332 .13435 L
.336 .13434 L
.34 .13434 L
.344 .13434 L
.348 .13434 L
.352 .13435 L
.356 .13436 L
.36 .13436 L
.364 .13437 L
.368 .13437 L
.372 .13438 L
.376 .13439 L
.38 .1344 L
.384 .13441 L
.388 .13443 L
.392 .13445 L
.396 .13447 L
.4 .1345 L
Mistroke
.404 .13453 L
.408 .13456 L
.412 .1346 L
.416 .13466 L
.42 .13473 L
.424 .13481 L
.428 .13491 L
.432 .13503 L
.436 .13516 L
.44 .13532 L
.444 .13551 L
.448 .13573 L
.452 .136 L
.456 .13633 L
.46 .13673 L
.464 .13721 L
.468 .13778 L
.472 .13845 L
.476 .13923 L
.48 .14014 L
.484 .14118 L
.488 .14237 L
.492 .14374 L
.496 .14529 L
.5 .14704 L
.504 .14898 L
.508 .15111 L
.512 .15341 L
.516 .15586 L
.52 .15844 L
.524 .16112 L
.528 .16386 L
.532 .16664 L
.536 .16942 L
.54 .17216 L
.544 .17483 L
.548 .17738 L
.552 .17979 L
.556 .18207 L
.56 .18421 L
.564 .18623 L
.568 .18817 L
.572 .19006 L
.576 .19196 L
.58 .19392 L
.584 .19596 L
.588 .1981 L
.592 .20035 L
.596 .2027 L
.6 .20512 L
Mistroke
.604 .20759 L
.608 .21006 L
.612 .21248 L
.616 .21483 L
.62 .21707 L
.624 .21921 L
.628 .22125 L
.632 .22319 L
.636 .22503 L
.64 .22682 L
.644 .22855 L
.648 .23026 L
.652 .23192 L
.656 .23351 L
.66 .23497 L
.664 .23626 L
.668 .23736 L
.672 .23825 L
.676 .23893 L
.68 .23942 L
.684 .23976 L
.688 .24003 L
.692 .24032 L
.696 .24072 L
.7 .24126 L
.704 .24194 L
.708 .24273 L
.712 .2436 L
.716 .24452 L
.72 .24547 L
.724 .24641 L
.728 .24731 L
.732 .24817 L
.736 .24899 L
.74 .24979 L
.744 .25058 L
.748 .25133 L
.752 .25198 L
.756 .2525 L
.76 .25287 L
.764 .25315 L
.768 .25343 L
.772 .25378 L
.776 .25423 L
.78 .2548 L
.784 .25546 L
.788 .25619 L
.792 .25692 L
.796 .25756 L
.8 .25802 L
Mistroke
.804 .25822 L
.808 .25815 L
.812 .25788 L
.816 .25751 L
.82 .25718 L
.824 .25696 L
.828 .25685 L
.832 .25682 L
.836 .25682 L
.84 .2568 L
.844 .25676 L
.848 .25668 L
.852 .25654 L
.856 .25634 L
.86 .25607 L
.864 .25577 L
.868 .25548 L
.872 .25525 L
.876 .25513 L
.88 .25512 L
.884 .25519 L
.888 .2553 L
.892 .2554 L
.896 .25549 L
.9 .25557 L
.904 .25565 L
.908 .25576 L
.912 .2559 L
.916 .25606 L
.92 .25616 L
.924 .2562 L
.928 .25612 L
.932 .25593 L
.936 .25567 L
.94 .25539 L
.944 .25515 L
.948 .25498 L
.952 .25488 L
.956 .25487 L
.96 .2549 L
.964 .25499 L
.968 .25512 L
.972 .25528 L
.976 .25543 L
.98 .25553 L
.984 .25547 L
.988 .25533 L
.992 .25503 L
.996 .25472 L
1 .25446 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15999 L
.012 .16136 L
.016 .16162 L
.02 .16108 L
.024 .16098 L
.028 .16121 L
.032 .16119 L
.036 .16112 L
.04 .16108 L
.044 .16113 L
.048 .1611 L
.052 .1611 L
.056 .16108 L
.06 .16109 L
.064 .16106 L
.068 .16106 L
.072 .16103 L
.076 .16104 L
.08 .16102 L
.084 .16102 L
.088 .16101 L
.092 .161 L
.096 .16099 L
.1 .16098 L
.104 .16097 L
.108 .16097 L
.112 .16095 L
.116 .16094 L
.12 .16093 L
.124 .16092 L
.128 .16091 L
.132 .16091 L
.136 .1609 L
.14 .16089 L
.144 .16088 L
.148 .16087 L
.152 .16085 L
.156 .16084 L
.16 .16084 L
.164 .16083 L
.168 .16082 L
.172 .16081 L
.176 .16079 L
.18 .16078 L
.184 .16078 L
.188 .16077 L
.192 .16077 L
.196 .16076 L
.2 .16075 L
Mistroke
.204 .16074 L
.208 .16072 L
.212 .1607 L
.216 .16069 L
.22 .16069 L
.224 .16069 L
.228 .16069 L
.232 .16068 L
.236 .16067 L
.24 .16065 L
.244 .16063 L
.248 .16062 L
.252 .16061 L
.256 .1606 L
.26 .1606 L
.264 .1606 L
.268 .16059 L
.272 .16057 L
.276 .16056 L
.28 .16055 L
.284 .16055 L
.288 .16054 L
.292 .16053 L
.296 .16052 L
.3 .1605 L
.304 .16048 L
.308 .16047 L
.312 .16047 L
.316 .16047 L
.32 .16047 L
.324 .16046 L
.328 .16045 L
.332 .16043 L
.336 .16041 L
.34 .16039 L
.344 .16038 L
.348 .16037 L
.352 .16036 L
.356 .16036 L
.36 .16034 L
.364 .16033 L
.368 .1603 L
.372 .16028 L
.376 .16026 L
.38 .16024 L
.384 .16022 L
.388 .16019 L
.392 .16016 L
.396 .16012 L
.4 .16008 L
Mistroke
.404 .16002 L
.408 .15996 L
.412 .15989 L
.416 .15982 L
.42 .15973 L
.424 .15963 L
.428 .15951 L
.432 .15937 L
.436 .1592 L
.44 .15898 L
.444 .15872 L
.448 .15841 L
.452 .15805 L
.456 .15762 L
.46 .15712 L
.464 .15653 L
.468 .15584 L
.472 .15502 L
.476 .15405 L
.48 .15291 L
.484 .15158 L
.488 .15004 L
.492 .1483 L
.496 .14634 L
.5 .14417 L
.504 .14176 L
.508 .13912 L
.512 .13627 L
.516 .13321 L
.52 .12998 L
.524 .1266 L
.528 .12313 L
.532 .11963 L
.536 .11614 L
.54 .11273 L
.544 .10943 L
.548 .10626 L
.552 .10325 L
.556 .10039 L
.56 .0977 L
.564 .09513 L
.568 .09266 L
.572 .09024 L
.576 .08783 L
.58 .08538 L
.584 .08286 L
.588 .08021 L
.592 .07742 L
.596 .07449 L
.6 .07145 L
Mistroke
.604 .06835 L
.608 .06523 L
.612 .06214 L
.616 .05915 L
.62 .05629 L
.624 .05359 L
.628 .05106 L
.632 .04866 L
.636 .04634 L
.64 .04409 L
.644 .04188 L
.648 .03973 L
.652 .03765 L
.656 .03567 L
.66 .03383 L
.664 .03217 L
.668 .03077 L
.672 .02964 L
.676 .02877 L
.68 .0281 L
.684 .02757 L
.688 .02711 L
.692 .02666 L
.696 .02616 L
.7 .02556 L
.704 .0248 L
.708 .02387 L
.712 .02279 L
.716 .0216 L
.72 .02037 L
.724 .01913 L
.728 .01788 L
.732 .01665 L
.736 .01548 L
.74 .0144 L
.744 .01346 L
.748 .01267 L
.752 .012 L
.756 .01141 L
.76 .01087 L
.764 .01036 L
.768 .00986 L
.772 .00932 L
.776 .00869 L
.78 .00793 L
.784 .00706 L
.788 .00616 L
.792 .00535 L
.796 .00472 L
.8 .00431 L
Mistroke
.804 .00409 L
.808 .00402 L
.812 .00405 L
.816 .00416 L
.82 .00432 L
.824 .0045 L
.828 .00468 L
.832 .00482 L
.836 .00494 L
.84 .00509 L
.844 .00529 L
.848 .00557 L
.852 .00589 L
.856 .00616 L
.86 .00635 L
.864 .00641 L
.868 .00639 L
.872 .00632 L
.876 .00627 L
.88 .00625 L
.884 .00625 L
.888 .00624 L
.892 .00622 L
.896 .00618 L
.9 .00616 L
.904 .00614 L
.908 .00613 L
.912 .00608 L
.916 .00597 L
.92 .00575 L
.924 .00548 L
.928 .00521 L
.932 .00505 L
.936 .00508 L
.94 .00528 L
.944 .00563 L
.948 .006 L
.952 .00627 L
.956 .00643 L
.96 .00645 L
.964 .00645 L
.968 .00649 L
.972 .00659 L
.976 .0067 L
.98 .00671 L
.984 .00646 L
.988 .00603 L
.992 .00543 L
.996 .00493 L
1 .00468 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
0080039oo`03001oogoo03Qoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0;goo0P0000=o
o`00Ool0>7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2000`Ool01@00Oomoogoo
000017oo00<007ooOol0<Goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8000eoo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000Aoo`D0009oo`@000=oo`8000=oo`D000=o
o`8000Aoo`8000Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo00000Woo00@007ooOol000Mo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`<0009oo`80
0005Ool007ooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00
Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`<0009oo`800005Ool007oo
Ool00004Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002
Ool01P00Oomoo`00Ool000=oo`03001oogoo00Eoo`@0009oo`03001oogoo00=oo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol017oo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;Ool40003
Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`06001oogoo001oo`000goo00@0
07ooOomoo`@0009oo`80009oo`04001oogoo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`05
001oogooOol00003Ool00`00Ool000030003Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool0
0`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009o
o`03001oogoo00<0009oo`8000=oo`03001oogoo00Aoo`800005Ool007ooOol00003Ool01000Oomo
o`000Woo00@007ooOol0009oo`05001oogooOol00003Ool00`00Ool00006Ool01000Oomoo`001Goo
000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool200000goo001oo`03Ool01000
Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol0
0`00Oomoo`0[Ool2000AOol00`00Oomoo`0[Ool0029oo`8002]oo`80019oo`03001oogoo009oo`80
02Moo`008WooH`0037oo000ROolG000017oo000007oo0P0000Aoo`00001oo`/000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000Woo00H007ooOomoo`00Ool30002Ool400000goo001oo`030002
Ool300000goo00000002Ool400000goo001oo`0;Ool0029oo`8001Eoo`800004Ool00000Ool20000
17oo000007oo0P000Woo00<007ooOol067oo00<007oo00001Goo0P000Woo00@007oo001oo`@00005
Ool00000001oo`08000<Ool0029oo`03001oogoo041oo`8000Yoo`8001ioo`008Woo0P00KGoo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo
000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo
00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008
Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eo
o`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool0
00Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007oo
Ool000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]
Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yo
o`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`00
8Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool2
0003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0Woo0P0017oo;000?Goo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0YOol3000j
Ool002Qoo`03001oogoo02aoo`8003Qoo`00:7oo00<007ooOol0;Goo0P00=goo000;Ool20004Ool0
0`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0^Ool3000eOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00<Woo0`00<goo0003Ool5
0002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00=7oo0`00
<Goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;
Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003Ool40003Ool20002Ool50003Ool20004
Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D0
07ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo10000Woo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`00
00=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`040003Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001o
ogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03
001oogoo00Eoo`05001oogoo001oo`070003Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001o
ogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`04001oogooOol40003
Ool01P00Oomoo`00Ool0009ooaX000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001o
ogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03
001oogoo00Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo
00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`80
00Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
oed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo
00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo
00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80
009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007oo
Ool0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001o
ogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo
000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1>OolH000<Ool000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0B7oo1P0097oo0003Ool50002Ool01000Oomo
o`002goo00<007ooOol00P00AGoo1@00:Goo000:Ool01000Oomoo`002goo00@007ooOol004=oo`<0
02ioo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo03moo`<0031oo`002Woo00@007ooOol0
00Moo`03001oogoo00Aoo`8003ioo`<0039oo`002goo0P0027oo1@000Woo00<007ooOol0?7oo0P00
=7oo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool40003
Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001o
ogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool01000Oomoogoo0`0000Eoo`00Oomoo`00009oo`03001oogoo00=oo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo
00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`80009oo`04001oogoo0002Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oo`000004Ool01000Oomo
o`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomo
o`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool300000goo000000020003
Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H0
07ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool0
1000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool30002Ool00`00Oomoo`04
Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L0
07ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomo
o`03Ool20004Ool20005Ool20003Ool50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool5
0003Ool20006Ool001aoo`03001oogoo035oo`8003moo`0077oo00<007ooOol0;goo0`00@7oo000L
OomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool0
1000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo
0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00
Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo
000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol0
0Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00
Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo
008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomo
o`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(45925\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31656 m
.008 .31792 L
.012 .31899 L
.016 .3192 L
.02 .31843 L
.024 .31811 L
.028 .31839 L
.032 .3185 L
.036 .31839 L
.04 .3184 L
.044 .31855 L
.048 .31862 L
.052 .31856 L
.056 .3185 L
.06 .31851 L
.064 .31855 L
.068 .31859 L
.072 .31862 L
.076 .31861 L
.08 .31861 L
.084 .31861 L
.088 .31863 L
.092 .31866 L
.096 .31867 L
.1 .31866 L
.104 .31865 L
.108 .31866 L
.112 .31872 L
.116 .31879 L
.12 .31881 L
.124 .31879 L
.128 .31873 L
.132 .31871 L
.136 .31873 L
.14 .3188 L
.144 .31886 L
.148 .31887 L
.152 .31883 L
.156 .31879 L
.16 .31881 L
.164 .31891 L
.168 .31901 L
.172 .31904 L
.176 .31896 L
.18 .31883 L
.184 .31874 L
.188 .31877 L
.192 .31892 L
.196 .31912 L
.2 .31923 L
Mistroke
.204 .31919 L
.208 .31903 L
.212 .31887 L
.216 .31884 L
.22 .31894 L
.224 .31911 L
.228 .31923 L
.232 .31925 L
.236 .31915 L
.24 .319 L
.244 .31892 L
.248 .31899 L
.252 .31918 L
.256 .31938 L
.26 .31946 L
.264 .31938 L
.268 .31919 L
.272 .31897 L
.276 .31884 L
.28 .31891 L
.284 .3192 L
.288 .31955 L
.292 .31974 L
.296 .31964 L
.3 .31932 L
.304 .31898 L
.308 .31882 L
.312 .31892 L
.316 .31922 L
.32 .31958 L
.324 .31976 L
.328 .31961 L
.332 .3192 L
.336 .31879 L
.34 .31866 L
.344 .31887 L
.348 .31923 L
.352 .31949 L
.356 .31949 L
.36 .31919 L
.364 .31867 L
.368 .3181 L
.372 .31773 L
.376 .31773 L
.38 .318 L
.384 .31822 L
.388 .31804 L
.392 .31734 L
.396 .31628 L
.4 .31511 L
Mistroke
.404 .31402 L
.408 .31307 L
.412 .31221 L
.416 .31122 L
.42 .30975 L
.424 .30748 L
.428 .30432 L
.432 .30051 L
.436 .29638 L
.44 .29206 L
.444 .28737 L
.448 .28199 L
.452 .27568 L
.456 .26837 L
.46 .26007 L
.464 .25092 L
.468 .24123 L
.472 .23147 L
.476 .22209 L
.48 .21329 L
.484 .20505 L
.488 .19737 L
.492 .19051 L
.496 .185 L
.5 .18141 L
.504 .18009 L
.508 .18112 L
.512 .18441 L
.516 .18969 L
.52 .19651 L
.524 .20411 L
.528 .21167 L
.532 .21848 L
.536 .22411 L
.54 .22834 L
.544 .23089 L
.548 .23142 L
.552 .22968 L
.556 .22587 L
.56 .22067 L
.564 .21503 L
.568 .20987 L
.572 .20591 L
.576 .20381 L
.58 .20421 L
.584 .20746 L
.588 .21334 L
.592 .22093 L
.596 .22898 L
.6 .23647 L
Mistroke
.604 .24293 L
.608 .24823 L
.612 .2523 L
.616 .25512 L
.62 .2571 L
.624 .25935 L
.628 .26335 L
.632 .27016 L
.636 .27975 L
.64 .2911 L
.644 .3029 L
.648 .31413 L
.652 .32394 L
.656 .33126 L
.66 .33477 L
.664 .33363 L
.668 .32834 L
.672 .32081 L
.676 .31333 L
.68 .3073 L
.684 .30279 L
.688 .29924 L
.692 .29649 L
.696 .29506 L
.7 .29536 L
.704 .29695 L
.708 .29867 L
.712 .29976 L
.716 .30084 L
.72 .30354 L
.724 .30888 L
.728 .31605 L
.732 .32252 L
.736 .32572 L
.74 .32478 L
.744 .32078 L
.748 .31559 L
.752 .31044 L
.756 .30571 L
.76 .30182 L
.764 .30016 L
.768 .3026 L
.772 .30982 L
.776 .32006 L
.78 .32942 L
.784 .33412 L
.788 .33289 L
.792 .32756 L
.796 .32167 L
.8 .31791 L
Mistroke
.804 .31682 L
.808 .31731 L
.812 .31813 L
.816 .31926 L
.82 .32132 L
.824 .32453 L
.828 .32776 L
.832 .32907 L
.836 .32733 L
.84 .3232 L
.844 .31891 L
.848 .31673 L
.852 .31732 L
.856 .31947 L
.86 .3212 L
.864 .32134 L
.868 .32028 L
.872 .31951 L
.876 .31999 L
.88 .32151 L
.884 .32272 L
.888 .3221 L
.892 .31976 L
.896 .31688 L
.9 .31545 L
.904 .31707 L
.908 .321 L
.912 .32582 L
.916 .32898 L
.92 .32852 L
.924 .32506 L
.928 .31951 L
.932 .31483 L
.936 .3136 L
.94 .31572 L
.944 .32113 L
.948 .32648 L
.952 .32858 L
.956 .32705 L
.96 .32124 L
.964 .31506 L
.968 .31244 L
.972 .31384 L
.976 .32041 L
.98 .32744 L
.984 .33031 L
.988 .32873 L
.992 .32135 L
.996 .31368 L
1 .31101 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13587 m
.008 .13468 L
.012 .13432 L
.016 .1349 L
.02 .13494 L
.024 .13472 L
.028 .13469 L
.032 .13481 L
.036 .13479 L
.04 .13477 L
.044 .13476 L
.048 .13479 L
.052 .13477 L
.056 .13478 L
.06 .13476 L
.064 .13477 L
.068 .13477 L
.072 .13478 L
.076 .13477 L
.08 .13478 L
.084 .13477 L
.088 .13478 L
.092 .13477 L
.096 .13478 L
.1 .13477 L
.104 .13478 L
.108 .13477 L
.112 .13477 L
.116 .13477 L
.12 .13478 L
.124 .13478 L
.128 .13478 L
.132 .13478 L
.136 .13478 L
.14 .13477 L
.144 .13477 L
.148 .13477 L
.152 .13478 L
.156 .13478 L
.16 .13478 L
.164 .13478 L
.168 .13478 L
.172 .13478 L
.176 .13478 L
.18 .13478 L
.184 .13478 L
.188 .13478 L
.192 .13478 L
.196 .13477 L
.2 .13477 L
Mistroke
.204 .13477 L
.208 .13477 L
.212 .13478 L
.216 .13478 L
.22 .13478 L
.224 .13479 L
.228 .13478 L
.232 .13478 L
.236 .13477 L
.24 .13476 L
.244 .13477 L
.248 .13478 L
.252 .13479 L
.256 .13479 L
.26 .13479 L
.264 .13478 L
.268 .13477 L
.272 .13477 L
.276 .13477 L
.28 .13478 L
.284 .13478 L
.288 .13478 L
.292 .13478 L
.296 .13478 L
.3 .13478 L
.304 .13479 L
.308 .13479 L
.312 .13479 L
.316 .13479 L
.32 .13479 L
.324 .13479 L
.328 .13479 L
.332 .13479 L
.336 .1348 L
.34 .13481 L
.344 .13483 L
.348 .13484 L
.352 .13485 L
.356 .13486 L
.36 .13487 L
.364 .13488 L
.368 .1349 L
.372 .13493 L
.376 .13496 L
.38 .135 L
.384 .13505 L
.388 .1351 L
.392 .13516 L
.396 .13523 L
.4 .13532 L
Mistroke
.404 .13543 L
.408 .13556 L
.412 .13571 L
.416 .1359 L
.42 .13612 L
.424 .13639 L
.428 .1367 L
.432 .13707 L
.436 .13752 L
.44 .13806 L
.444 .13869 L
.448 .13944 L
.452 .14031 L
.456 .14133 L
.46 .14249 L
.464 .14382 L
.468 .14531 L
.472 .14699 L
.476 .14885 L
.48 .1509 L
.484 .15313 L
.488 .15553 L
.492 .15808 L
.496 .16075 L
.5 .16349 L
.504 .16627 L
.508 .16904 L
.512 .17178 L
.516 .17445 L
.52 .17703 L
.524 .17949 L
.528 .18182 L
.532 .18402 L
.536 .1861 L
.54 .18809 L
.544 .19001 L
.548 .1919 L
.552 .19381 L
.556 .19579 L
.56 .19786 L
.564 .20005 L
.568 .20236 L
.572 .20475 L
.576 .20721 L
.58 .20969 L
.584 .21214 L
.588 .21453 L
.592 .21681 L
.596 .21898 L
.6 .22104 L
Mistroke
.604 .223 L
.608 .22487 L
.612 .22668 L
.616 .22843 L
.62 .23013 L
.624 .23179 L
.628 .23338 L
.632 .23486 L
.636 .23619 L
.64 .23735 L
.644 .23831 L
.648 .23907 L
.652 .23965 L
.656 .24008 L
.66 .2404 L
.664 .2407 L
.668 .24104 L
.672 .24148 L
.676 .24205 L
.68 .24276 L
.684 .24358 L
.688 .24448 L
.692 .24544 L
.696 .24642 L
.7 .24738 L
.704 .24829 L
.708 .24913 L
.712 .24992 L
.716 .25067 L
.72 .25138 L
.724 .25204 L
.728 .2526 L
.732 .25306 L
.736 .25345 L
.74 .25379 L
.744 .25415 L
.748 .25455 L
.752 .25501 L
.756 .25555 L
.76 .25617 L
.764 .25684 L
.768 .25749 L
.772 .25803 L
.776 .25837 L
.78 .25847 L
.784 .25836 L
.788 .2581 L
.792 .2578 L
.796 .25753 L
.8 .25731 L
Mistroke
.804 .25716 L
.808 .25706 L
.812 .25701 L
.816 .25698 L
.82 .25695 L
.824 .25685 L
.828 .25667 L
.832 .25641 L
.836 .2561 L
.84 .25581 L
.844 .2556 L
.848 .25549 L
.852 .25547 L
.856 .2555 L
.86 .25558 L
.864 .25569 L
.868 .25583 L
.872 .25598 L
.876 .25612 L
.88 .2562 L
.884 .25623 L
.888 .25621 L
.892 .25618 L
.896 .25616 L
.9 .25617 L
.904 .25616 L
.908 .25609 L
.912 .25596 L
.916 .25574 L
.92 .25551 L
.924 .25532 L
.928 .25523 L
.932 .25526 L
.936 .25536 L
.94 .25548 L
.944 .25554 L
.948 .25551 L
.952 .25541 L
.956 .2553 L
.96 .25522 L
.964 .25525 L
.968 .25531 L
.972 .25537 L
.976 .25537 L
.98 .25527 L
.984 .25513 L
.988 .25502 L
.992 .25499 L
.996 .25513 L
1 .25529 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15773 L
.012 .16117 L
.016 .16231 L
.02 .16121 L
.024 .16076 L
.028 .16113 L
.032 .16125 L
.036 .16115 L
.04 .16108 L
.044 .16112 L
.048 .16111 L
.052 .1611 L
.056 .16107 L
.06 .16107 L
.064 .16106 L
.068 .16106 L
.072 .16104 L
.076 .16104 L
.08 .16103 L
.084 .16103 L
.088 .16101 L
.092 .161 L
.096 .16098 L
.1 .16098 L
.104 .16096 L
.108 .16096 L
.112 .16095 L
.116 .16095 L
.12 .16093 L
.124 .16092 L
.128 .16091 L
.132 .1609 L
.136 .16089 L
.14 .16089 L
.144 .16088 L
.148 .16086 L
.152 .16085 L
.156 .16084 L
.16 .16083 L
.164 .16083 L
.168 .16082 L
.172 .16081 L
.176 .1608 L
.18 .16079 L
.184 .16078 L
.188 .16077 L
.192 .16076 L
.196 .16075 L
.2 .16074 L
Mistroke
.204 .16073 L
.208 .16072 L
.212 .16071 L
.216 .16071 L
.22 .16071 L
.224 .16069 L
.228 .16068 L
.232 .16066 L
.236 .16065 L
.24 .16063 L
.244 .16063 L
.248 .16063 L
.252 .16063 L
.256 .16062 L
.26 .16061 L
.264 .1606 L
.268 .16058 L
.272 .16056 L
.276 .16055 L
.28 .16054 L
.284 .16054 L
.288 .16053 L
.292 .16052 L
.296 .16051 L
.3 .1605 L
.304 .16049 L
.308 .16048 L
.312 .16047 L
.316 .16046 L
.32 .16045 L
.324 .16043 L
.328 .16041 L
.332 .16039 L
.336 .16038 L
.34 .16037 L
.344 .16036 L
.348 .16034 L
.352 .16032 L
.356 .16029 L
.36 .16026 L
.364 .16022 L
.368 .16018 L
.372 .16014 L
.376 .1601 L
.38 .16005 L
.384 .15999 L
.388 .15991 L
.392 .15982 L
.396 .15972 L
.4 .15959 L
Mistroke
.404 .15945 L
.408 .15929 L
.412 .15909 L
.416 .15885 L
.42 .15857 L
.424 .15822 L
.428 .15781 L
.432 .15733 L
.436 .15675 L
.44 .15607 L
.444 .15528 L
.448 .15435 L
.452 .15327 L
.456 .15201 L
.46 .15056 L
.464 .14889 L
.468 .147 L
.472 .14488 L
.476 .14252 L
.48 .13994 L
.484 .13715 L
.488 .13416 L
.492 .131 L
.496 .1277 L
.5 .12429 L
.504 .12081 L
.508 .11731 L
.512 .11385 L
.516 .11048 L
.52 .10724 L
.524 .10416 L
.528 .10125 L
.532 .09851 L
.536 .09592 L
.54 .09345 L
.544 .09103 L
.548 .08863 L
.552 .08619 L
.556 .08368 L
.56 .08107 L
.564 .07833 L
.568 .07547 L
.572 .07249 L
.576 .06942 L
.58 .06632 L
.584 .06324 L
.588 .06021 L
.592 .05729 L
.596 .05452 L
.6 .0519 L
Mistroke
.604 .04944 L
.608 .04711 L
.612 .04487 L
.616 .0427 L
.62 .04057 L
.624 .03849 L
.628 .03649 L
.632 .03459 L
.636 .03286 L
.64 .03133 L
.644 .03007 L
.648 .02909 L
.652 .02837 L
.656 .02784 L
.66 .02741 L
.664 .027 L
.668 .02654 L
.672 .02597 L
.676 .02524 L
.68 .02435 L
.684 .02329 L
.688 .02213 L
.692 .02092 L
.696 .0197 L
.7 .01848 L
.704 .01728 L
.708 .01611 L
.712 .01499 L
.716 .01397 L
.72 .01307 L
.724 .01231 L
.728 .01167 L
.732 .01113 L
.736 .01067 L
.74 .01024 L
.744 .00979 L
.748 .00923 L
.752 .00852 L
.756 .00765 L
.76 .0067 L
.764 .00579 L
.768 .00503 L
.772 .00449 L
.776 .00419 L
.78 .0041 L
.784 .00418 L
.788 .00438 L
.792 .00465 L
.796 .00489 L
.8 .00507 L
Mistroke
.804 .00515 L
.808 .00517 L
.812 .00523 L
.816 .00538 L
.82 .00563 L
.824 .00593 L
.828 .00621 L
.832 .00641 L
.836 .00651 L
.84 .00655 L
.844 .00656 L
.848 .00657 L
.852 .00657 L
.856 .00656 L
.86 .00653 L
.864 .0065 L
.868 .00651 L
.872 .00654 L
.876 .00657 L
.88 .00654 L
.884 .0064 L
.888 .00614 L
.892 .00581 L
.896 .00548 L
.9 .00525 L
.904 .00518 L
.908 .00528 L
.912 .00554 L
.916 .00587 L
.92 .00622 L
.924 .00653 L
.928 .00674 L
.932 .00687 L
.936 .0069 L
.94 .00688 L
.944 .00678 L
.948 .00662 L
.952 .0064 L
.956 .00615 L
.96 .00589 L
.964 .00572 L
.968 .00562 L
.972 .00564 L
.976 .00577 L
.98 .00594 L
.984 .00617 L
.988 .00641 L
.992 .00663 L
.996 .0069 L
1 .00704 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008002ioo`<003aoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0;Goo00<007oo0000?7oo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2000]Ool20002Ool00`00Oomoo`02Ool2
000eOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo
0P001goo0`0017oo0P0017oo0P0000=oo`00Ool00Woo0`0000=oo`00Ool00`0017oo0P000goo1@00
0goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomoo`00
1goo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo008000Aoo`03001oo`0000800004Ool0
07oo0002Ool01000Oomoo`000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`0017oo
00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`<000=oo`<0009oo`04001oogoo0004Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
47oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol017oo0P000Woo00@007ooOol000Eoo`05001oogooOol00002Ool01000Oomo
o`000Woo00<007ooOol017oo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;Ool40003Ool01000Oomoo`00
1goo00<007ooOol00Woo00@007ooOol0009oo`04001oo`000005Ool01000Oomoogoo1P0000Eoo`00
Oomoo`00009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogoo
Ool007oo10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo0P0037oo
00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Ool0000017oo0P00
0goo00<007ooOol00Woo00<007oo00000Woo00@007ooOol000=oo`04001oogoo0002Ool01000Oomo
o`000Woo00D007ooOomoo`0000=oo`03001oo`0000Ioo`04001oogoo0005Ool0029oo`8000aoo`D0
00=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol500000goo001oo`020004
Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo02Qoo`80015o
o`03001oogoo02ioo`008Woo0P00:Goo00<007ooOol047oo00<007ooOol00goo0P00:Goo000ROomS
000<Ool0029ooad00003Ool0000000X00003Ool007oo009oo`05001oogooOol00003Ool01@00Oomo
ogoo00000Woo0P000Woo00@007ooOomoo`800004Ool000000002Ool300000goo00000002Ool30000
1Goo00000000Ool00P0000=oo`00000037oo000ROol2000GOol2000017oo000007oo0P0000=oo`00
000077oo0`0017oo0`000Woo0`0000Eoo`00000007oo00@00003Ool0000000L000eoo`008Woo00<0
07ooOol0?Goo0P002goo00<007ooOol047oo00<007ooOol037oo000ROol2001]Ool0029oo`8006eo
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`80
00Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P00
0Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2
001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo
000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001o
ogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol0
0`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P00
0goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo
0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00
Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001o
ogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomo
ogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03
001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
4Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004
OolY0010Ool0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo02Ioo`@003aoo`00:7oo
00<007ooOol0:Goo0P00>goo000XOol00`00Oomoo`0ZOol3000iOol000]oo`8000Aoo`03001oogoo
00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo02aoo`8003Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000`Ool2000fOol000=oo`D0009oo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000bOol2000dOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Ao
o`8000Moo`<000Aoo`8000Aoo`8000=oo`<0009oo`@000Aoo`80009oo`D000=oo`8000Aoo`8000=o
o`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00
Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogooOol007oo0`000Woo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogoo001oo`000goo00@0
07ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`@0009oo`05001oogooOol00004Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`03
001oogoo00H0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007oo
Ool017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007oo
Ool000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=o
o`05001oogoo001oo`0M0003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04
Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool20003Ool00`00Oomo
o`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=o
o`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001o
ogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool3
0002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<
Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001o
ogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001o
ogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool20002Ool5
0002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004
Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Io
o`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003
Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D0
07ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo
1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo
0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
2goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0Bgoo6`0037oo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo04Ioo`H002Ioo`000goo1@000Woo00@007ooOol000]o
o`03001oogoo0080049oo`H002]oo`002Woo00@007ooOol000]oo`04001oogoo0010Ool4000`Ool0
00Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0lOol3000cOol000Yoo`04001oogoo0007Ool0
0`00Oomoo`04Ool2000lOol2000eOol000]oo`8000Qoo`D0009oo`03001oogoo03Uoo`8003Moo`00
77oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000Woo100017oo0P00
1Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo
00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol00P000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`00
77oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo0`001Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`0017oo0`001Woo00@007ooOol0009oo`03001oogoo00Eoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009o
o`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`000goo0`000goo10000goo00@007ooOol000Aoo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eo
o`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002
Ool01000Oomoo`000Woo10000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eo
o`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P000Woo00D007ooOomoo`00
00=oo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<0
07ooOol0;Woo0P00@Woo000LOol00`00Oomoo`0/Ool30013Ool001aoofT000aoo`0077oo00D007oo
Oomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00
Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`00
1goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo0080
07=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool0
0`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0
009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000F
Ool30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007oo
Ool00Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03
001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=o
o`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol0
2goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomo
o`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`00
2goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(46092\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31854 m
.008 .31876 L
.012 .31809 L
.016 .31812 L
.02 .31866 L
.024 .31866 L
.028 .31833 L
.032 .31827 L
.036 .31843 L
.04 .31849 L
.044 .31848 L
.048 .3185 L
.052 .31848 L
.056 .31843 L
.06 .31844 L
.064 .31853 L
.068 .31863 L
.072 .31868 L
.076 .31863 L
.08 .31853 L
.084 .31845 L
.088 .31846 L
.092 .31856 L
.096 .3187 L
.1 .31878 L
.104 .31877 L
.108 .31869 L
.112 .31861 L
.116 .31859 L
.12 .31864 L
.124 .31871 L
.128 .31876 L
.132 .31877 L
.136 .31876 L
.14 .31875 L
.144 .31877 L
.148 .31882 L
.152 .31885 L
.156 .31885 L
.16 .31883 L
.164 .31881 L
.168 .3188 L
.172 .31879 L
.176 .31881 L
.18 .31887 L
.184 .31895 L
.188 .31902 L
.192 .31907 L
.196 .31905 L
.2 .31896 L
Mistroke
.204 .31883 L
.208 .31875 L
.212 .31879 L
.216 .31897 L
.22 .31918 L
.224 .31929 L
.228 .31924 L
.232 .31907 L
.236 .3189 L
.24 .31883 L
.244 .31893 L
.248 .31914 L
.252 .31932 L
.256 .31934 L
.26 .31918 L
.264 .31897 L
.268 .31887 L
.272 .31896 L
.276 .31918 L
.28 .3194 L
.284 .31949 L
.288 .3194 L
.292 .31914 L
.296 .31884 L
.3 .31869 L
.304 .3188 L
.308 .3191 L
.312 .3194 L
.316 .31949 L
.32 .31931 L
.324 .31894 L
.328 .31853 L
.332 .31826 L
.336 .31824 L
.34 .31846 L
.344 .3187 L
.348 .31866 L
.352 .31821 L
.356 .31748 L
.36 .31675 L
.364 .31622 L
.368 .3159 L
.372 .31562 L
.376 .31517 L
.38 .31432 L
.384 .31291 L
.388 .31093 L
.392 .30862 L
.396 .30624 L
.4 .30389 L
Mistroke
.404 .30132 L
.408 .29813 L
.412 .29403 L
.416 .28889 L
.42 .28276 L
.424 .27578 L
.428 .26818 L
.432 .26022 L
.436 .252 L
.44 .24344 L
.444 .23431 L
.448 .22458 L
.452 .21456 L
.456 .20491 L
.46 .19626 L
.464 .1891 L
.468 .18369 L
.472 .18022 L
.476 .17875 L
.48 .17923 L
.484 .18147 L
.488 .18533 L
.492 .19075 L
.496 .19763 L
.5 .20552 L
.504 .2136 L
.508 .22084 L
.512 .22633 L
.516 .22955 L
.52 .23033 L
.524 .22877 L
.528 .2252 L
.532 .22025 L
.536 .21477 L
.54 .20967 L
.544 .20567 L
.548 .20325 L
.552 .20273 L
.556 .20443 L
.56 .20855 L
.564 .21491 L
.568 .22281 L
.572 .23115 L
.576 .23887 L
.58 .2453 L
.584 .25025 L
.588 .25384 L
.592 .25643 L
.596 .2587 L
.6 .26175 L
Mistroke
.604 .26678 L
.608 .27454 L
.612 .28488 L
.616 .29674 L
.62 .30871 L
.624 .3195 L
.628 .32808 L
.632 .33349 L
.636 .33488 L
.64 .33191 L
.644 .3253 L
.648 .31685 L
.652 .30865 L
.656 .30213 L
.66 .29765 L
.664 .29495 L
.668 .29381 L
.672 .29422 L
.676 .29595 L
.68 .2982 L
.684 .30002 L
.688 .30111 L
.692 .30238 L
.696 .30528 L
.7 .31043 L
.704 .31683 L
.708 .32226 L
.712 .32477 L
.716 .32381 L
.72 .32014 L
.724 .31491 L
.728 .30899 L
.732 .30321 L
.736 .29907 L
.74 .29868 L
.744 .30357 L
.748 .31305 L
.752 .32401 L
.756 .33228 L
.76 .33516 L
.764 .3328 L
.768 .32755 L
.772 .32217 L
.776 .31811 L
.78 .31556 L
.784 .31445 L
.788 .31521 L
.792 .31846 L
.796 .32369 L
.8 .32885 L
Mistroke
.804 .33124 L
.808 .32944 L
.812 .32456 L
.816 .3195 L
.82 .31691 L
.824 .31734 L
.828 .31915 L
.832 .32013 L
.836 .3195 L
.84 .3184 L
.844 .31864 L
.848 .32095 L
.852 .32395 L
.856 .32524 L
.86 .32335 L
.864 .31887 L
.868 .31456 L
.872 .31311 L
.876 .31555 L
.88 .32081 L
.884 .32591 L
.888 .32861 L
.892 .32798 L
.896 .32461 L
.9 .32076 L
.904 .31776 L
.908 .31675 L
.912 .31794 L
.916 .31997 L
.92 .32236 L
.924 .32366 L
.928 .3231 L
.932 .32168 L
.936 .31947 L
.94 .3182 L
.944 .31882 L
.948 .32004 L
.952 .32199 L
.956 .32281 L
.96 .32181 L
.964 .32101 L
.968 .32004 L
.972 .32055 L
.976 .32255 L
.98 .32316 L
.984 .32298 L
.988 .32106 L
.992 .31808 L
.996 .31777 L
1 .31916 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14011 m
.008 .13525 L
.012 .13358 L
.016 .1352 L
.02 .13574 L
.024 .13524 L
.028 .13503 L
.032 .13522 L
.036 .13527 L
.04 .13523 L
.044 .13519 L
.048 .13522 L
.052 .13521 L
.056 .13522 L
.06 .13521 L
.064 .13522 L
.068 .13522 L
.072 .13523 L
.076 .13522 L
.08 .13522 L
.084 .13521 L
.088 .13521 L
.092 .13521 L
.096 .13522 L
.1 .13522 L
.104 .13523 L
.108 .13522 L
.112 .13522 L
.116 .13521 L
.12 .13521 L
.124 .13521 L
.128 .13522 L
.132 .13522 L
.136 .13522 L
.14 .13522 L
.144 .13522 L
.148 .13522 L
.152 .13522 L
.156 .13522 L
.16 .13522 L
.164 .13522 L
.168 .13522 L
.172 .13521 L
.176 .13522 L
.18 .13522 L
.184 .13522 L
.188 .13522 L
.192 .13522 L
.196 .13522 L
.2 .13522 L
Mistroke
.204 .13522 L
.208 .13522 L
.212 .13522 L
.216 .13522 L
.22 .13522 L
.224 .13522 L
.228 .13522 L
.232 .13522 L
.236 .13522 L
.24 .13522 L
.244 .13523 L
.248 .13523 L
.252 .13523 L
.256 .13522 L
.26 .13522 L
.264 .13521 L
.268 .13521 L
.272 .13522 L
.276 .13523 L
.28 .13524 L
.284 .13524 L
.288 .13524 L
.292 .13523 L
.296 .13523 L
.3 .13523 L
.304 .13524 L
.308 .13525 L
.312 .13525 L
.316 .13526 L
.32 .13527 L
.324 .13528 L
.328 .13529 L
.332 .13531 L
.336 .13533 L
.34 .13535 L
.344 .13537 L
.348 .13539 L
.352 .13542 L
.356 .13546 L
.36 .13552 L
.364 .13558 L
.368 .13566 L
.372 .13575 L
.376 .13585 L
.38 .13597 L
.384 .13611 L
.388 .13629 L
.392 .13649 L
.396 .13675 L
.4 .13706 L
Mistroke
.404 .13742 L
.408 .13786 L
.412 .13837 L
.416 .13897 L
.42 .13968 L
.424 .14051 L
.428 .14148 L
.432 .14259 L
.436 .14387 L
.44 .14532 L
.444 .14695 L
.448 .14876 L
.452 .15075 L
.456 .15292 L
.46 .15526 L
.464 .15775 L
.468 .16036 L
.472 .16307 L
.476 .16584 L
.48 .16863 L
.484 .1714 L
.488 .17411 L
.492 .17672 L
.496 .17921 L
.5 .18157 L
.504 .1838 L
.508 .18592 L
.512 .18793 L
.516 .18988 L
.52 .1918 L
.524 .19372 L
.528 .19567 L
.532 .1977 L
.536 .19982 L
.54 .20206 L
.544 .20439 L
.548 .20681 L
.552 .20927 L
.556 .21175 L
.56 .21418 L
.564 .21653 L
.568 .21877 L
.572 .22087 L
.576 .22285 L
.58 .22473 L
.584 .22653 L
.588 .22827 L
.592 .22997 L
.596 .23162 L
.6 .23322 L
Mistroke
.604 .23474 L
.608 .23613 L
.612 .23736 L
.616 .2384 L
.62 .23922 L
.624 .23986 L
.628 .24034 L
.632 .2407 L
.636 .241 L
.64 .24132 L
.644 .24172 L
.648 .24224 L
.652 .24288 L
.656 .24364 L
.66 .2445 L
.664 .24542 L
.668 .24639 L
.672 .24736 L
.676 .24831 L
.68 .24921 L
.684 .25005 L
.688 .25083 L
.692 .25155 L
.696 .25221 L
.7 .25278 L
.704 .25325 L
.708 .25365 L
.712 .254 L
.716 .25435 L
.72 .25474 L
.724 .2552 L
.728 .25572 L
.732 .2563 L
.736 .25693 L
.74 .25755 L
.744 .2581 L
.748 .25851 L
.752 .25871 L
.756 .25871 L
.76 .25855 L
.764 .25832 L
.768 .25805 L
.772 .2578 L
.776 .25758 L
.78 .25741 L
.784 .25728 L
.788 .2572 L
.792 .25713 L
.796 .25705 L
.8 .25691 L
Mistroke
.804 .25671 L
.808 .25648 L
.812 .25628 L
.816 .25611 L
.82 .256 L
.824 .25592 L
.828 .25587 L
.832 .25586 L
.836 .25591 L
.84 .25603 L
.844 .25619 L
.848 .25634 L
.852 .25643 L
.856 .25645 L
.86 .25643 L
.864 .25641 L
.868 .25642 L
.872 .25645 L
.876 .25648 L
.88 .25645 L
.884 .25634 L
.888 .25618 L
.892 .256 L
.896 .25585 L
.9 .25576 L
.904 .25571 L
.908 .25568 L
.912 .25565 L
.916 .25561 L
.92 .25555 L
.924 .25551 L
.928 .2555 L
.932 .25553 L
.936 .25559 L
.94 .25568 L
.944 .25573 L
.948 .25575 L
.952 .25573 L
.956 .25566 L
.96 .25559 L
.964 .25551 L
.968 .25543 L
.972 .25536 L
.976 .25526 L
.98 .25517 L
.984 .25508 L
.988 .25503 L
.992 .25501 L
.996 .25503 L
1 .25502 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16174 L
.012 .16104 L
.016 .16092 L
.02 .16129 L
.024 .16124 L
.028 .16111 L
.032 .16109 L
.036 .16117 L
.04 .16113 L
.044 .16111 L
.048 .16108 L
.052 .1611 L
.056 .16107 L
.06 .16108 L
.064 .16106 L
.068 .16107 L
.072 .16104 L
.076 .16104 L
.08 .16102 L
.084 .16102 L
.088 .161 L
.092 .161 L
.096 .16099 L
.1 .16098 L
.104 .16097 L
.108 .16096 L
.112 .16095 L
.116 .16094 L
.12 .16093 L
.124 .16092 L
.128 .16091 L
.132 .1609 L
.136 .16089 L
.14 .16089 L
.144 .16088 L
.148 .16087 L
.152 .16086 L
.156 .16085 L
.16 .16084 L
.164 .16083 L
.168 .16082 L
.172 .16081 L
.176 .16079 L
.18 .16079 L
.184 .16078 L
.188 .16077 L
.192 .16076 L
.196 .16075 L
.2 .16074 L
Mistroke
.204 .16073 L
.208 .16072 L
.212 .16071 L
.216 .16071 L
.22 .16069 L
.224 .16068 L
.228 .16067 L
.232 .16066 L
.236 .16065 L
.24 .16065 L
.244 .16065 L
.248 .16064 L
.252 .16062 L
.256 .1606 L
.26 .16058 L
.264 .16057 L
.268 .16057 L
.272 .16057 L
.276 .16056 L
.28 .16056 L
.284 .16054 L
.288 .16053 L
.292 .16051 L
.296 .16049 L
.3 .16048 L
.304 .16046 L
.308 .16045 L
.312 .16044 L
.316 .16042 L
.32 .1604 L
.324 .16038 L
.328 .16035 L
.332 .16033 L
.336 .1603 L
.34 .16027 L
.344 .16023 L
.348 .16017 L
.352 .16011 L
.356 .16005 L
.36 .15998 L
.364 .1599 L
.368 .15981 L
.372 .1597 L
.376 .15956 L
.38 .1594 L
.384 .1592 L
.388 .15896 L
.392 .15869 L
.396 .15836 L
.4 .15798 L
Mistroke
.404 .15752 L
.408 .15698 L
.412 .15633 L
.416 .15556 L
.42 .15467 L
.424 .15362 L
.428 .15241 L
.432 .15101 L
.436 .14941 L
.44 .1476 L
.444 .14556 L
.448 .14329 L
.452 .14079 L
.456 .13806 L
.46 .13513 L
.464 .13201 L
.468 .12874 L
.472 .12536 L
.476 .12191 L
.48 .11843 L
.484 .11498 L
.488 .11159 L
.492 .1083 L
.496 .10516 L
.5 .10217 L
.504 .09935 L
.508 .09669 L
.512 .09417 L
.516 .09175 L
.52 .08938 L
.524 .08699 L
.528 .08453 L
.532 .08197 L
.536 .07927 L
.54 .07644 L
.544 .07349 L
.548 .07045 L
.552 .06736 L
.556 .06428 L
.56 .06126 L
.564 .05832 L
.568 .05551 L
.572 .05283 L
.576 .0503 L
.58 .04791 L
.584 .04563 L
.588 .04344 L
.592 .04132 L
.596 .03926 L
.6 .03726 L
Mistroke
.604 .03536 L
.608 .0336 L
.612 .03201 L
.616 .03065 L
.62 .02954 L
.624 .02869 L
.628 .02807 L
.632 .02761 L
.636 .02722 L
.64 .02682 L
.644 .02633 L
.648 .02569 L
.652 .02487 L
.656 .02387 L
.66 .02272 L
.664 .02149 L
.668 .02023 L
.672 .01899 L
.676 .0178 L
.68 .01666 L
.684 .01558 L
.688 .01456 L
.692 .01364 L
.696 .01281 L
.7 .01208 L
.704 .01145 L
.708 .01091 L
.712 .01044 L
.716 .01001 L
.72 .00954 L
.724 .00896 L
.728 .00823 L
.732 .00736 L
.736 .00645 L
.74 .00559 L
.744 .00488 L
.748 .00441 L
.752 .00419 L
.756 .00421 L
.76 .00443 L
.764 .00478 L
.768 .00513 L
.772 .0054 L
.776 .00552 L
.78 .00553 L
.784 .00549 L
.788 .00551 L
.792 .00563 L
.796 .00586 L
.8 .00613 L
Mistroke
.804 .00641 L
.808 .00666 L
.812 .00685 L
.816 .00699 L
.82 .00704 L
.824 .00701 L
.828 .00692 L
.832 .0068 L
.836 .00671 L
.84 .00668 L
.844 .0067 L
.848 .00672 L
.852 .00668 L
.856 .00655 L
.86 .00634 L
.864 .00607 L
.868 .00582 L
.872 .00562 L
.876 .00551 L
.88 .00551 L
.884 .00565 L
.888 .00595 L
.892 .00635 L
.896 .00678 L
.9 .00714 L
.904 .00732 L
.908 .0073 L
.912 .0071 L
.916 .00682 L
.92 .00654 L
.924 .00634 L
.928 .00623 L
.932 .00617 L
.936 .00611 L
.94 .00607 L
.944 .00602 L
.948 .00605 L
.952 .00619 L
.956 .00644 L
.96 .00674 L
.964 .00701 L
.968 .00712 L
.972 .00709 L
.976 .00687 L
.98 .00661 L
.984 .00637 L
.988 .00624 L
.992 .00621 L
.996 .00627 L
1 .00629 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008002aoo`<003ioo`002goo0P002Woo0P000goo0`000goo00<007ooOol0:Woo00@007ooOol003io
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00:goo00<007ooOol00P000goo0P00
>7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000eoo`<000Aoo`80
00Moo`<000Aoo`8000Aoo`8000=oo`03001oo`0000800003Ool007oo00<000Aoo`8000=oo`D000=o
o`8000Aoo`8000Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo00000Woo00@007ooOol000Mo
o`03001oogoo009oo`04001oogoo0002Ool200000goo001oo`02Ool00`00Ool00002Ool20003Ool0
1000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007oo
Ool00Woo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`<000=oo`05001oogooOol00002
Ool01000Oomoo`0017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol20002Ool01000Oomoo`000Woo00<007ooOol0
0goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000
Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03
001oogoo00]oo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogooOol40003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:
Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00D0
07ooOol007oo0080009oo`03001oogoo009oo`8000=oo`04001oo`000003Ool01000Oomoo`000Woo
00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00L007ooOomoo`00Ool00006
Ool01000Oomoo`001Goo000ROol2000<Ool50003Ool20008Ool00`00Oomoo`03Ool2000017oo0000
07oo0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=o
o`8000Ioo`008Woo00<007ooOol09Woo00<007ooOol047oo00<007ooOol0<7oo000ROol2000VOol2
000BOol01000Oomoogoo0`001Goo00<007ooOol097oo000ROomS000<Ool0029ooa`00003Ool00000
00T000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo00000P000Woo00<007oo
00000`0000Aoo`00001oo`<00005Ool00000001oo`03000027oo00000000Ool007oo0002Ool2000<
Ool0029oo`8001Moo`04001oo`000002Ool00`00Oomoo`0KOol00`00Ool00005Ool20002Ool00`00
Ool00002Ool700000goo00000009000>Ool0029oo`03001oogoo03]oo`03001oogoo00Uoo`80009o
o`03001oogoo01ioo`008Woo0P00KGoo000ROol2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00
Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo
0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00
Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool0
00]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00
Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=o
o`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0
00=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000R
Ool00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003
Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]o
o`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo9`00@Woo000AOol2000:Ool20004Ool0
0`00Oomoo`02Ool00`00Oomoo`0SOol4000oOol002Qoo`03001oogoo02Ioo`<003eoo`00:7oo00<0
07ooOol0:7oo0P00?7oo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00
Oomoo`0YOol3000jOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003
Ool01000Oomoo`00;Goo0`00>7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04
001oogoo0005Ool01000Oomoo`00;goo0P00=goo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool5
000017oo0000000017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool0
1@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00@007ooOomoo`80009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001o
ogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oogoo00=oo`<0009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]o
o`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`L000Aoo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0
009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo01l000=o
o`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004
Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`06001oogoo001oo`00
0goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007oo
Ool000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo
00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo
00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo
0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`04
0003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001o
ogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007oo
Ool006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02
001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo
000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomo
ogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02
Ool30003Ool00`00Oomoo`18OolN000<Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0@goo1P00:Goo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00@7oo1@00
;Woo000:Ool01000Oomoo`002goo00@007ooOol003eoo`@003=oo`002Woo00@007ooOol000Moo`@0
00=oo`03001oogoo03Yoo`8003Ioo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8003Uoo`80
03Qoo`002goo0P0027oo1@000Woo00<007ooOol0=goo0P00>Goo000LOol00`00Oomoo`0=Ool30004
Ool20009Ool30004Ool20004Ool20005Ool40002Ool30004Ool20005Ool50003Ool20004Ool20005
Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool20002Ool01@00Oomoogoo00000Woo
00@007ooOol000Eoo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo
001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0
009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo0`001goo
00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01@00Oomoo`00Ool0
0`0000=oo`00Ool01Woo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00
77oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool00`00Oomo
o`030003Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomo
o`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<0
07ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool00`00Oomo
o`020003Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2
000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool30005Ool01000Oomoogoo1@000goo0P00
1Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`0/Ool20014
Ool001aoo`03001oogoo02Uoo`<004Ioo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000;Ool20004
Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000
Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Ioo`<000=oo`03001o
ogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol0
01Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000F
Ool20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomo
o`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00
M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03
001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07
Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(46259\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .32011 m
.008 .31887 L
.012 .31778 L
.016 .31764 L
.02 .31847 L
.024 .31869 L
.028 .31827 L
.032 .31814 L
.036 .3184 L
.04 .31857 L
.044 .31854 L
.048 .3185 L
.052 .31847 L
.056 .3184 L
.06 .31836 L
.064 .31839 L
.068 .31849 L
.072 .31858 L
.076 .31861 L
.08 .31858 L
.084 .31853 L
.088 .31852 L
.092 .31856 L
.096 .31863 L
.1 .31867 L
.104 .31864 L
.108 .31857 L
.112 .31851 L
.116 .31854 L
.12 .31865 L
.124 .31878 L
.128 .31886 L
.132 .31883 L
.136 .31872 L
.14 .31862 L
.144 .31858 L
.148 .31865 L
.152 .31876 L
.156 .31885 L
.16 .31888 L
.164 .31886 L
.168 .31883 L
.172 .31881 L
.176 .31882 L
.18 .31885 L
.184 .31888 L
.188 .31888 L
.192 .31885 L
.196 .31884 L
.2 .31885 L
Mistroke
.204 .3189 L
.208 .31897 L
.212 .31904 L
.216 .31909 L
.22 .31908 L
.224 .31899 L
.228 .31887 L
.232 .3188 L
.236 .31883 L
.24 .31897 L
.244 .31914 L
.248 .31925 L
.252 .31924 L
.256 .31909 L
.26 .31889 L
.264 .31878 L
.268 .31884 L
.272 .31903 L
.276 .31919 L
.28 .3192 L
.284 .31903 L
.288 .31878 L
.292 .3186 L
.296 .31855 L
.3 .31866 L
.304 .31883 L
.308 .31889 L
.312 .31869 L
.316 .31825 L
.32 .31774 L
.324 .31735 L
.328 .31717 L
.332 .31708 L
.336 .31694 L
.34 .31658 L
.344 .31587 L
.348 .31479 L
.352 .31344 L
.356 .31204 L
.36 .3107 L
.364 .30932 L
.368 .30758 L
.372 .30517 L
.376 .30198 L
.38 .29805 L
.384 .29354 L
.388 .28854 L
.392 .28311 L
.396 .27718 L
.4 .27052 L
Mistroke
.404 .26285 L
.408 .25408 L
.412 .24442 L
.416 .23437 L
.42 .22444 L
.424 .21494 L
.428 .20601 L
.432 .19776 L
.436 .19035 L
.44 .184 L
.444 .17902 L
.448 .17583 L
.452 .17494 L
.456 .17664 L
.46 .18083 L
.464 .18692 L
.468 .19411 L
.472 .20167 L
.476 .20906 L
.48 .21583 L
.484 .22149 L
.488 .22561 L
.492 .22785 L
.496 .22802 L
.5 .22604 L
.504 .22201 L
.508 .21641 L
.512 .21017 L
.516 .20455 L
.52 .20073 L
.524 .19946 L
.528 .20095 L
.532 .20497 L
.536 .21104 L
.54 .21851 L
.544 .22654 L
.548 .23428 L
.552 .24106 L
.556 .2466 L
.56 .251 L
.564 .25459 L
.568 .25779 L
.572 .26113 L
.576 .26539 L
.58 .27143 L
.584 .27981 L
.588 .29041 L
.592 .30229 L
.596 .31399 L
.6 .32404 L
Mistroke
.604 .33121 L
.608 .33463 L
.612 .33384 L
.616 .32901 L
.62 .32116 L
.624 .3121 L
.628 .30376 L
.632 .29751 L
.636 .29373 L
.64 .29211 L
.644 .29218 L
.648 .29359 L
.652 .29595 L
.656 .29862 L
.66 .30097 L
.664 .30286 L
.668 .30494 L
.672 .30814 L
.676 .31274 L
.68 .31781 L
.684 .3217 L
.688 .32303 L
.692 .32148 L
.696 .31767 L
.7 .31255 L
.704 .30695 L
.708 .30195 L
.712 .29918 L
.716 .30043 L
.72 .30649 L
.724 .31605 L
.728 .32597 L
.732 .33285 L
.736 .33492 L
.74 .33268 L
.744 .32799 L
.748 .32272 L
.752 .31794 L
.756 .31433 L
.76 .31286 L
.764 .31448 L
.768 .31923 L
.772 .32537 L
.776 .33003 L
.78 .33095 L
.784 .32806 L
.788 .32352 L
.792 .31996 L
.796 .31854 L
.8 .31847 L
Mistroke
.804 .31817 L
.808 .3171 L
.812 .3163 L
.816 .31735 L
.82 .32053 L
.824 .32423 L
.828 .32595 L
.832 .32428 L
.836 .32014 L
.84 .316 L
.844 .3143 L
.848 .31562 L
.852 .31874 L
.856 .32201 L
.86 .32421 L
.864 .32547 L
.868 .32612 L
.872 .32588 L
.876 .32441 L
.88 .32125 L
.884 .31744 L
.888 .31506 L
.892 .3154 L
.896 .31887 L
.9 .3233 L
.904 .32577 L
.908 .32503 L
.912 .32112 L
.916 .31685 L
.92 .3152 L
.924 .31675 L
.928 .32118 L
.932 .32542 L
.936 .32682 L
.94 .32539 L
.944 .32135 L
.948 .31758 L
.952 .31641 L
.956 .31748 L
.96 .32096 L
.964 .3243 L
.968 .32524 L
.972 .32423 L
.976 .32071 L
.98 .31696 L
.984 .31568 L
.988 .31652 L
.992 .3204 L
.996 .32505 L
1 .32718 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13544 m
.008 .13579 L
.012 .13579 L
.016 .13555 L
.02 .13557 L
.024 .13573 L
.028 .13569 L
.032 .13564 L
.036 .13564 L
.04 .13568 L
.044 .13565 L
.048 .13566 L
.052 .13565 L
.056 .13567 L
.06 .13566 L
.064 .13566 L
.068 .13565 L
.072 .13566 L
.076 .13565 L
.08 .13566 L
.084 .13566 L
.088 .13567 L
.092 .13566 L
.096 .13566 L
.1 .13566 L
.104 .13566 L
.108 .13566 L
.112 .13566 L
.116 .13566 L
.12 .13566 L
.124 .13566 L
.128 .13566 L
.132 .13566 L
.136 .13566 L
.14 .13566 L
.144 .13566 L
.148 .13566 L
.152 .13566 L
.156 .13566 L
.16 .13566 L
.164 .13566 L
.168 .13566 L
.172 .13566 L
.176 .13566 L
.18 .13566 L
.184 .13566 L
.188 .13566 L
.192 .13566 L
.196 .13566 L
.2 .13566 L
Mistroke
.204 .13566 L
.208 .13566 L
.212 .13567 L
.216 .13566 L
.22 .13566 L
.224 .13566 L
.228 .13566 L
.232 .13567 L
.236 .13567 L
.24 .13567 L
.244 .13567 L
.248 .13566 L
.252 .13566 L
.256 .13566 L
.26 .13567 L
.264 .13568 L
.268 .13568 L
.272 .13569 L
.276 .13569 L
.28 .13569 L
.284 .13569 L
.288 .13569 L
.292 .1357 L
.296 .13571 L
.3 .13573 L
.304 .13575 L
.308 .13577 L
.312 .13578 L
.316 .1358 L
.32 .13583 L
.324 .13586 L
.328 .1359 L
.332 .13595 L
.336 .13601 L
.34 .13608 L
.344 .13616 L
.348 .13626 L
.352 .13638 L
.356 .13652 L
.36 .13669 L
.364 .13689 L
.368 .13713 L
.372 .13742 L
.376 .13776 L
.38 .13817 L
.384 .13866 L
.388 .13924 L
.392 .13993 L
.396 .14073 L
.4 .14166 L
Mistroke
.404 .14273 L
.408 .14395 L
.412 .14534 L
.416 .14691 L
.42 .14866 L
.424 .1506 L
.428 .15272 L
.432 .15501 L
.436 .15745 L
.44 .16002 L
.444 .16269 L
.448 .16544 L
.452 .16821 L
.456 .17098 L
.46 .17371 L
.464 .17636 L
.468 .17891 L
.472 .18133 L
.476 .18361 L
.48 .18577 L
.484 .18781 L
.488 .18977 L
.492 .19168 L
.496 .19358 L
.5 .19552 L
.504 .19752 L
.508 .19961 L
.512 .20181 L
.516 .2041 L
.52 .20648 L
.524 .20891 L
.528 .21136 L
.532 .21379 L
.536 .21617 L
.54 .21846 L
.544 .22064 L
.548 .22269 L
.552 .22461 L
.556 .22643 L
.56 .22817 L
.564 .22984 L
.568 .23147 L
.572 .23305 L
.576 .23458 L
.58 .23601 L
.584 .23731 L
.588 .23844 L
.592 .23937 L
.596 .24009 L
.6 .24062 L
Mistroke
.604 .24101 L
.608 .24132 L
.612 .24161 L
.616 .24195 L
.62 .2424 L
.624 .24299 L
.628 .24371 L
.632 .24454 L
.636 .24546 L
.64 .24642 L
.644 .24739 L
.648 .24834 L
.652 .24925 L
.656 .25011 L
.66 .25091 L
.664 .25166 L
.668 .25234 L
.672 .25295 L
.676 .25347 L
.68 .2539 L
.684 .25426 L
.688 .25458 L
.692 .25493 L
.696 .25533 L
.7 .25582 L
.704 .25638 L
.708 .25701 L
.712 .25766 L
.716 .25826 L
.72 .25872 L
.724 .259 L
.728 .25906 L
.732 .25895 L
.736 .25871 L
.74 .25843 L
.744 .25816 L
.748 .25794 L
.752 .25776 L
.756 .25764 L
.76 .25755 L
.764 .25746 L
.768 .25736 L
.772 .25721 L
.776 .25701 L
.78 .25681 L
.784 .25663 L
.788 .2565 L
.792 .25641 L
.796 .25634 L
.8 .25628 L
Mistroke
.804 .25623 L
.808 .25622 L
.812 .25626 L
.816 .25634 L
.82 .25645 L
.824 .25654 L
.828 .25662 L
.832 .25669 L
.836 .25676 L
.84 .25683 L
.844 .25689 L
.848 .2569 L
.852 .25684 L
.856 .25672 L
.86 .25656 L
.864 .25639 L
.868 .25622 L
.872 .25608 L
.876 .25596 L
.88 .25586 L
.884 .25582 L
.888 .25581 L
.892 .25583 L
.896 .25585 L
.9 .25585 L
.904 .25585 L
.908 .25586 L
.912 .25592 L
.916 .25604 L
.92 .25617 L
.924 .25625 L
.928 .25623 L
.932 .25609 L
.936 .25586 L
.94 .25561 L
.944 .2554 L
.948 .25531 L
.952 .25529 L
.956 .25534 L
.96 .25539 L
.964 .25541 L
.968 .2554 L
.972 .2554 L
.976 .25541 L
.98 .25548 L
.984 .25555 L
.988 .25561 L
.992 .2556 L
.996 .25549 L
1 .2553 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16472 L
.012 .16122 L
.016 .15998 L
.02 .16117 L
.024 .16154 L
.028 .16117 L
.032 .161 L
.036 .16114 L
.04 .16116 L
.044 .16112 L
.048 .16107 L
.052 .1611 L
.056 .16108 L
.06 .16109 L
.064 .16106 L
.068 .16106 L
.072 .16104 L
.076 .16103 L
.08 .16101 L
.084 .16102 L
.088 .16101 L
.092 .16101 L
.096 .16099 L
.1 .16099 L
.104 .16096 L
.108 .16095 L
.112 .16094 L
.116 .16094 L
.12 .16093 L
.124 .16093 L
.128 .16092 L
.132 .16091 L
.136 .16089 L
.14 .16088 L
.144 .16087 L
.148 .16086 L
.152 .16085 L
.156 .16085 L
.16 .16083 L
.164 .16083 L
.168 .16082 L
.172 .16081 L
.176 .1608 L
.18 .16079 L
.184 .16078 L
.188 .16077 L
.192 .16076 L
.196 .16075 L
.2 .16074 L
Mistroke
.204 .16073 L
.208 .16072 L
.212 .16071 L
.216 .1607 L
.22 .1607 L
.224 .16068 L
.228 .16067 L
.232 .16066 L
.236 .16065 L
.24 .16064 L
.244 .16063 L
.248 .16062 L
.252 .1606 L
.256 .16059 L
.26 .16058 L
.264 .16058 L
.268 .16057 L
.272 .16056 L
.276 .16054 L
.28 .16052 L
.284 .16049 L
.288 .16047 L
.292 .16046 L
.296 .16044 L
.3 .16043 L
.304 .16041 L
.308 .16038 L
.312 .16034 L
.316 .16029 L
.32 .16025 L
.324 .16019 L
.328 .16013 L
.332 .16007 L
.336 .15999 L
.34 .1599 L
.344 .15978 L
.348 .15965 L
.352 .15949 L
.356 .15931 L
.36 .1591 L
.364 .15884 L
.368 .15852 L
.372 .15814 L
.376 .1577 L
.38 .15717 L
.384 .15655 L
.388 .15583 L
.392 .15498 L
.396 .15398 L
.4 .15282 L
Mistroke
.404 .15147 L
.408 .14993 L
.412 .14817 L
.416 .1462 L
.42 .14401 L
.424 .14158 L
.428 .13893 L
.432 .13608 L
.436 .13302 L
.44 .1298 L
.444 .12645 L
.448 .12302 L
.452 .11954 L
.456 .11608 L
.46 .11267 L
.464 .10935 L
.468 .10616 L
.472 .10313 L
.476 .10026 L
.48 .09754 L
.484 .09496 L
.488 .0925 L
.492 .09009 L
.496 .08771 L
.5 .08529 L
.504 .0828 L
.508 .08018 L
.512 .07743 L
.516 .07454 L
.52 .07153 L
.524 .06845 L
.528 .06535 L
.532 .06227 L
.536 .05929 L
.54 .05644 L
.544 .05374 L
.548 .05118 L
.552 .04876 L
.556 .04646 L
.56 .04424 L
.564 .0421 L
.568 .04002 L
.572 .038 L
.576 .03608 L
.58 .03429 L
.584 .03267 L
.588 .03126 L
.592 .03007 L
.596 .02912 L
.6 .0284 L
Mistroke
.604 .02786 L
.608 .02744 L
.612 .02704 L
.616 .02659 L
.62 .02603 L
.624 .0253 L
.628 .0244 L
.632 .02334 L
.636 .02214 L
.64 .02087 L
.644 .01959 L
.648 .01835 L
.652 .01718 L
.656 .01608 L
.66 .01506 L
.664 .01412 L
.668 .01328 L
.672 .01253 L
.676 .01187 L
.68 .01128 L
.684 .01075 L
.688 .01027 L
.692 .00979 L
.696 .00926 L
.7 .00863 L
.704 .00789 L
.708 .00706 L
.712 .00623 L
.716 .00547 L
.72 .00487 L
.724 .00449 L
.728 .00435 L
.732 .00445 L
.736 .00473 L
.74 .0051 L
.744 .00546 L
.748 .00573 L
.752 .00586 L
.756 .00588 L
.76 .00587 L
.764 .00589 L
.768 .00599 L
.772 .00617 L
.776 .00641 L
.78 .00669 L
.784 .00697 L
.788 .00721 L
.792 .00737 L
.796 .00742 L
.8 .00734 L
Mistroke
.804 .00719 L
.808 .00701 L
.812 .00688 L
.816 .0068 L
.82 .00675 L
.824 .0067 L
.828 .00664 L
.832 .00655 L
.836 .00645 L
.84 .00632 L
.844 .00616 L
.848 .006 L
.852 .00588 L
.856 .00587 L
.86 .00603 L
.864 .00636 L
.868 .00678 L
.872 .00717 L
.876 .00742 L
.88 .00746 L
.884 .00734 L
.888 .0071 L
.892 .00685 L
.896 .00665 L
.9 .0065 L
.904 .0064 L
.908 .00634 L
.912 .00632 L
.916 .00636 L
.92 .00646 L
.924 .00662 L
.928 .00682 L
.932 .00698 L
.936 .00709 L
.94 .0071 L
.944 .00702 L
.948 .0069 L
.952 .00674 L
.956 .00663 L
.96 .00655 L
.964 .00652 L
.968 .00653 L
.972 .00657 L
.976 .00664 L
.98 .00676 L
.984 .00688 L
.988 .00702 L
.992 .00712 L
.996 .00715 L
1 .00709 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02000ZOol00`00Oomoo`10Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0
00=oo`03001oogoo008002Uoo`<0045oo`002goo0P002Woo0P000goo0`000goo00<007ooOol0:7oo
00@007oo0000041oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00:7oo00D007oo
Oomoo`0000=oo`<003Yoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2
000=Ool30004Ool20007Ool30004Ool2000017oo001oogoo0P0000Aoo`00Oomoo`@000=oo`<000Ao
o`8000=oo`D000=oo`8000Aoo`8000Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo00000Woo
00@007ooOol000Moo`03001oogoo009oo`03001oogoo00800004Ool007ooOol40002Ool20002Ool0
1@00Oomoogoo00000Woo00@007ooOol000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo00<007ooOol00P0000Moo`00Oomoo`00Ool00003Ool00`00Ool00005Ool0
1000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oo`0000Eoo`04001oogoo0002Ool00`00
Oomoo`03Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Ao
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P00
17oo00<007ooOol02goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01@000goo00@007ooOol0009oo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000=oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo
0P002Woo0P0017oo00<007ooOol00Woo0P0037oo00<007ooOol017oo00@007ooOol000Ioo`8000Ao
o`04001oogoo0002Ool01000Oomoo`0017oo0P000Woo0P001Woo00@007ooOol0009oo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007oo
Ool000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007oo
Oomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<0
07ooOol08goo00<007ooOol047oo00<007ooOol0<goo000ROol2000SOol2000BOol00`00Oomoo`02
Ool3000^Ool0029oof<000aoo`008Woo9@000Woo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool00`00Oomoo`0200000goo00000003Ool01000Ool007oo0P0000Aoo`000000009oo`<00003Ool0
0000009oo`800004Ool00000Ool3000017oo001oo`0037oo000ROol2000iOol30005Ool20002Ool0
1`00Ool007oo001oo`00009oo`<00005Ool00000001oo`02000017oo000007oo0P0000=oo`000000
37oo000ROol00`00Oomoo`0hOol2000:Ool20003Ool00`00Oomoo`0POol0029oo`8006eoo`008Woo
0P00KGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`00
2goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03
Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0
029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:
Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool2
0003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029o
o`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04
001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P00
0goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009o
o`8000Aoob@004Eoo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol087oo1@00@Goo
000XOol00`00Oomoo`0TOol20010Ool002Qoo`03001oogoo02Ioo`8003ioo`002goo0P0017oo00<0
07ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol09goo0P00?Goo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol002]oo`8003]oo`000goo1@00
0Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol002aoo`<003Uo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo
0`0017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo
0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001o
ogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`000goo1@000goo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool0
1000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001o
ogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol00`000Woo00@007ooOol0009oo`05001o
ogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00eoo`04001o
ogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03
001oogoo00=oo`H0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<0
07ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol0
2Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00@007ooOomoo`@000=oob8000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo
00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001o
ogoo00Aoo`07001oogoo001oo`00Ool00`000Woo00@007ooOol0009oo`04001oogoo0002Ool01`00
Oomoogoo001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03
001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004
Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM
000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03
001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03
001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool20002
Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo
06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomo
ogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`00
2goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0AWoo800037oo000:Ool01000Oomo
o`001goo00D007ooOomoo`00009oo`03001oogoo045oo`H002]oo`000goo1@000Woo00@007ooOol0
00]oo`03001oogoo008003eoo`D0035oo`002Woo00@007ooOol000]oo`04001oogoo000kOol3000f
Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0gOol2000iOol000Yoo`04001oogoo0007
Ool00`00Oomoo`04Ool2000fOol2000kOol000]oo`8000Qoo`D0009oo`03001oogoo03Aoo`8003ao
o`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo
0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomo
ogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo
0P0000=oo`00Ool00Woo00D007ooOomoo`00009oo`04001oogoo0005Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00<007ooOol00`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Mo
o`03001oogoo009oo`04001oogoo0002Ool00`00Oomoo`020004Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomo
o`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oo`000005Ool01000Oomoogoo10000goo
00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001o
ogooOol007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@0
07ooOol000Qoo`8000Aoo`04001oogoo0002Ool200000goo001oo`03Ool20003Ool00`00Oomoo`04
Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L0
07ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000=Ool50003Ool2000:Ool00`00Oomo
o`03Ool20002Ool40006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`00
0Woo1@000goo0P001Woo000LOol00`00Oomoo`0YOol20017Ool001aoo`03001oogoo02Moo`8004Uo
o`0077ooJ@0037oo000LOol20002Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1b
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomo
o`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@0
07ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80
07=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007oo
Ool0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`00
5goo00<007ooOol00Woo00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009o
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007oo
Ool00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0
LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02
001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol0
17oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(46426\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31821 m
.008 .31779 L
.012 .31836 L
.016 .31848 L
.02 .31823 L
.024 .3183 L
.028 .3185 L
.032 .31844 L
.036 .31828 L
.04 .31827 L
.044 .31833 L
.048 .31837 L
.052 .31842 L
.056 .31848 L
.06 .31849 L
.064 .31848 L
.068 .31846 L
.072 .31847 L
.076 .31849 L
.08 .3185 L
.084 .31849 L
.088 .31848 L
.092 .31849 L
.096 .31854 L
.1 .31859 L
.104 .31863 L
.108 .31864 L
.112 .31862 L
.116 .3186 L
.12 .3186 L
.124 .31861 L
.128 .31864 L
.132 .31865 L
.136 .31865 L
.14 .31866 L
.144 .3187 L
.148 .31876 L
.152 .31881 L
.156 .31881 L
.16 .31875 L
.164 .31869 L
.168 .31867 L
.172 .31871 L
.176 .3188 L
.18 .31887 L
.184 .3189 L
.188 .31887 L
.192 .31882 L
.196 .3188 L
.2 .31885 L
Mistroke
.204 .31891 L
.208 .31895 L
.212 .31892 L
.216 .31886 L
.22 .3188 L
.224 .31879 L
.228 .31885 L
.232 .31895 L
.236 .31904 L
.24 .31907 L
.244 .31899 L
.248 .31884 L
.252 .3187 L
.256 .31863 L
.26 .31864 L
.264 .31872 L
.268 .31881 L
.272 .31882 L
.276 .31868 L
.28 .31841 L
.284 .31811 L
.288 .3179 L
.292 .31781 L
.296 .31776 L
.3 .31761 L
.304 .31726 L
.308 .31669 L
.312 .31595 L
.316 .31515 L
.32 .3144 L
.324 .3137 L
.328 .31285 L
.332 .3116 L
.336 .30979 L
.34 .30744 L
.344 .30469 L
.348 .30161 L
.352 .29823 L
.356 .29443 L
.36 .29005 L
.364 .28482 L
.368 .27854 L
.372 .27123 L
.376 .2631 L
.38 .25448 L
.384 .24554 L
.388 .23633 L
.392 .22683 L
.396 .21709 L
.4 .20735 L
Mistroke
.404 .19796 L
.408 .18944 L
.412 .18237 L
.416 .17728 L
.42 .1744 L
.424 .17362 L
.428 .17473 L
.432 .17753 L
.436 .18199 L
.44 .18802 L
.444 .1953 L
.448 .20329 L
.452 .21126 L
.456 .21837 L
.46 .22377 L
.464 .22674 L
.468 .227 L
.472 .22478 L
.476 .22077 L
.48 .21577 L
.484 .21046 L
.488 .20546 L
.492 .2014 L
.496 .19892 L
.5 .1986 L
.504 .20073 L
.508 .20532 L
.512 .21208 L
.516 .22042 L
.52 .22938 L
.524 .23784 L
.528 .2448 L
.532 .24981 L
.536 .25315 L
.54 .25567 L
.544 .2584 L
.548 .2623 L
.552 .26806 L
.556 .27601 L
.56 .28606 L
.564 .29752 L
.568 .30919 L
.572 .31966 L
.576 .32769 L
.58 .33245 L
.584 .33351 L
.588 .33086 L
.592 .3249 L
.596 .31664 L
.6 .3076 L
Mistroke
.604 .2995 L
.608 .29361 L
.612 .29044 L
.616 .28976 L
.62 .29096 L
.624 .29338 L
.628 .29644 L
.632 .29955 L
.636 .3023 L
.64 .30467 L
.644 .30717 L
.648 .31044 L
.652 .31456 L
.656 .31871 L
.66 .32149 L
.664 .32173 L
.668 .31922 L
.672 .31466 L
.676 .30922 L
.68 .30411 L
.684 .30061 L
.688 .30005 L
.692 .30344 L
.696 .31069 L
.7 .32002 L
.704 .32856 L
.708 .33367 L
.712 .33431 L
.716 .33127 L
.72 .32634 L
.724 .32117 L
.728 .31682 L
.732 .31411 L
.736 .31385 L
.74 .31648 L
.744 .32133 L
.748 .32636 L
.752 .32926 L
.756 .32889 L
.76 .32606 L
.764 .32279 L
.768 .32066 L
.772 .31969 L
.776 .31884 L
.78 .31735 L
.784 .31584 L
.788 .31573 L
.792 .31779 L
.796 .32116 L
.8 .3238 L
Mistroke
.804 .3241 L
.808 .32214 L
.812 .3195 L
.816 .31777 L
.82 .3175 L
.824 .31806 L
.828 .31874 L
.832 .31977 L
.836 .32178 L
.84 .32491 L
.844 .32781 L
.848 .32821 L
.852 .32508 L
.856 .31941 L
.86 .31438 L
.864 .31318 L
.868 .31629 L
.872 .32166 L
.876 .3255 L
.88 .32521 L
.884 .32156 L
.888 .31716 L
.892 .31536 L
.896 .31751 L
.9 .32174 L
.904 .32561 L
.908 .32656 L
.912 .32418 L
.916 .32068 L
.92 .31772 L
.924 .31705 L
.928 .31873 L
.932 .32082 L
.936 .32261 L
.94 .32292 L
.944 .32165 L
.948 .32041 L
.952 .31932 L
.956 .31925 L
.96 .32055 L
.964 .32161 L
.968 .32253 L
.972 .32259 L
.976 .32131 L
.98 .3205 L
.984 .32009 L
.988 .32053 L
.992 .32201 L
.996 .32239 L
1 .32167 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13116 m
.008 .13612 L
.012 .13773 L
.016 .13611 L
.02 .13554 L
.024 .13611 L
.028 .13628 L
.032 .13611 L
.036 .13603 L
.04 .1361 L
.044 .13611 L
.048 .13611 L
.052 .13609 L
.056 .13611 L
.06 .1361 L
.064 .1361 L
.068 .13609 L
.072 .1361 L
.076 .13609 L
.08 .13611 L
.084 .13611 L
.088 .13611 L
.092 .1361 L
.096 .1361 L
.1 .13609 L
.104 .1361 L
.108 .1361 L
.112 .13611 L
.116 .13611 L
.12 .13611 L
.124 .1361 L
.128 .1361 L
.132 .1361 L
.136 .1361 L
.14 .1361 L
.144 .1361 L
.148 .1361 L
.152 .1361 L
.156 .1361 L
.16 .1361 L
.164 .1361 L
.168 .1361 L
.172 .1361 L
.176 .1361 L
.18 .1361 L
.184 .1361 L
.188 .1361 L
.192 .1361 L
.196 .1361 L
.2 .1361 L
Mistroke
.204 .13611 L
.208 .13611 L
.212 .13611 L
.216 .13611 L
.22 .1361 L
.224 .1361 L
.228 .13611 L
.232 .13611 L
.236 .13612 L
.24 .13612 L
.244 .13612 L
.248 .13612 L
.252 .13613 L
.256 .13613 L
.26 .13614 L
.264 .13615 L
.268 .13616 L
.272 .13616 L
.276 .13617 L
.28 .13619 L
.284 .13621 L
.288 .13624 L
.292 .13627 L
.296 .1363 L
.3 .13634 L
.304 .13638 L
.308 .13643 L
.312 .13649 L
.316 .13657 L
.32 .13667 L
.324 .13679 L
.328 .13693 L
.332 .13709 L
.336 .13728 L
.34 .13751 L
.344 .13778 L
.348 .13811 L
.352 .13851 L
.356 .13898 L
.36 .13953 L
.364 .14018 L
.368 .14094 L
.372 .14183 L
.376 .14286 L
.38 .14404 L
.384 .14539 L
.388 .14691 L
.392 .1486 L
.396 .15048 L
.4 .15253 L
Mistroke
.404 .15476 L
.408 .15715 L
.412 .15968 L
.416 .16232 L
.42 .16505 L
.424 .16781 L
.428 .17059 L
.432 .17332 L
.436 .176 L
.44 .17858 L
.444 .18104 L
.448 .18338 L
.452 .18558 L
.456 .18767 L
.46 .18966 L
.464 .19158 L
.468 .19348 L
.472 .19539 L
.476 .19735 L
.48 .1994 L
.484 .20154 L
.488 .20379 L
.492 .20614 L
.496 .20856 L
.5 .21101 L
.504 .21345 L
.508 .21585 L
.512 .21816 L
.516 .22037 L
.52 .22246 L
.524 .22442 L
.528 .22628 L
.532 .22805 L
.536 .22975 L
.54 .23138 L
.544 .23296 L
.548 .23447 L
.552 .2359 L
.556 .23722 L
.56 .23841 L
.564 .23942 L
.568 .24024 L
.572 .24086 L
.576 .24132 L
.58 .24166 L
.584 .24195 L
.588 .24224 L
.592 .24261 L
.596 .24311 L
.6 .24376 L
Mistroke
.604 .24455 L
.608 .24546 L
.612 .24643 L
.616 .24742 L
.62 .2484 L
.624 .24933 L
.628 .2502 L
.632 .25101 L
.636 .25175 L
.64 .25244 L
.644 .25306 L
.648 .25362 L
.652 .25411 L
.656 .25451 L
.66 .25487 L
.664 .2552 L
.668 .25556 L
.672 .25598 L
.676 .25649 L
.68 .25707 L
.684 .25769 L
.688 .25831 L
.692 .25885 L
.696 .25924 L
.7 .25942 L
.704 .25939 L
.708 .25918 L
.712 .25887 L
.716 .25855 L
.72 .25826 L
.724 .25804 L
.728 .25791 L
.732 .25784 L
.736 .2578 L
.74 .25774 L
.744 .25762 L
.748 .25744 L
.752 .25721 L
.756 .25698 L
.76 .25679 L
.764 .25667 L
.768 .2566 L
.772 .25657 L
.776 .25657 L
.78 .25658 L
.784 .25661 L
.788 .25666 L
.792 .25671 L
.796 .25676 L
.8 .25682 L
Mistroke
.804 .25689 L
.808 .257 L
.812 .25712 L
.816 .25722 L
.82 .25728 L
.824 .25726 L
.828 .25716 L
.832 .25699 L
.836 .25678 L
.84 .25655 L
.844 .25633 L
.848 .25614 L
.852 .25602 L
.856 .25601 L
.86 .25608 L
.864 .25619 L
.868 .25628 L
.872 .25631 L
.876 .25628 L
.88 .25623 L
.884 .25623 L
.888 .25629 L
.892 .2564 L
.896 .25648 L
.9 .25648 L
.904 .25637 L
.908 .25618 L
.912 .25595 L
.916 .25576 L
.92 .25562 L
.924 .25557 L
.928 .25557 L
.932 .25561 L
.936 .25568 L
.94 .25576 L
.944 .25585 L
.948 .25593 L
.952 .25598 L
.956 .25598 L
.96 .25591 L
.964 .25578 L
.968 .25561 L
.972 .25544 L
.976 .2553 L
.98 .25522 L
.984 .25516 L
.988 .25517 L
.992 .25516 L
.996 .2552 L
1 .25524 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16127 L
.012 .16137 L
.016 .16119 L
.02 .16107 L
.024 .16112 L
.028 .16122 L
.032 .16114 L
.036 .16111 L
.04 .1611 L
.044 .16113 L
.048 .1611 L
.052 .1611 L
.056 .16107 L
.06 .16108 L
.064 .16105 L
.068 .16106 L
.072 .16104 L
.076 .16104 L
.08 .16102 L
.084 .16102 L
.088 .161 L
.092 .161 L
.096 .16098 L
.1 .16098 L
.104 .16096 L
.108 .16096 L
.112 .16095 L
.116 .16095 L
.12 .16093 L
.124 .16093 L
.128 .16091 L
.132 .1609 L
.136 .16088 L
.14 .16088 L
.144 .16087 L
.148 .16087 L
.152 .16086 L
.156 .16085 L
.16 .16083 L
.164 .16082 L
.168 .16081 L
.172 .16081 L
.176 .1608 L
.18 .16079 L
.184 .16077 L
.188 .16077 L
.192 .16076 L
.196 .16075 L
.2 .16074 L
Mistroke
.204 .16073 L
.208 .16072 L
.212 .16071 L
.216 .16069 L
.22 .16068 L
.224 .16067 L
.228 .16067 L
.232 .16065 L
.236 .16064 L
.24 .16063 L
.244 .16062 L
.248 .1606 L
.252 .16059 L
.256 .16057 L
.26 .16056 L
.264 .16054 L
.268 .16052 L
.272 .16049 L
.276 .16046 L
.28 .16043 L
.284 .1604 L
.288 .16037 L
.292 .16033 L
.296 .16029 L
.3 .16023 L
.304 .16015 L
.308 .16006 L
.312 .15997 L
.316 .15986 L
.32 .15974 L
.324 .1596 L
.328 .15943 L
.332 .15922 L
.336 .15896 L
.34 .15866 L
.344 .1583 L
.348 .15788 L
.352 .15738 L
.356 .15679 L
.36 .15609 L
.364 .15527 L
.368 .15431 L
.372 .15319 L
.376 .1519 L
.38 .15043 L
.384 .14874 L
.388 .14685 L
.392 .14472 L
.396 .14236 L
.4 .13978 L
Mistroke
.404 .13698 L
.408 .13399 L
.412 .13083 L
.416 .12754 L
.42 .12414 L
.424 .12068 L
.428 .11721 L
.432 .11377 L
.436 .11041 L
.44 .10717 L
.444 .10408 L
.448 .10115 L
.452 .09839 L
.456 .09577 L
.46 .09327 L
.464 .09085 L
.468 .08847 L
.472 .08606 L
.476 .08359 L
.48 .08103 L
.484 .07834 L
.488 .07552 L
.492 .07257 L
.496 .06954 L
.5 .06646 L
.504 .06338 L
.508 .06035 L
.512 .05743 L
.516 .05465 L
.52 .05202 L
.524 .04956 L
.528 .04723 L
.532 .04502 L
.536 .04289 L
.54 .04083 L
.544 .03881 L
.548 .03687 L
.552 .03502 L
.556 .03333 L
.56 .03183 L
.564 .03056 L
.568 .02954 L
.572 .02875 L
.576 .02816 L
.58 .02771 L
.584 .0273 L
.588 .02687 L
.592 .02635 L
.596 .02568 L
.6 .02485 L
Mistroke
.604 .02386 L
.608 .02273 L
.612 .02151 L
.616 .02024 L
.62 .01898 L
.624 .01777 L
.628 .01662 L
.632 .01556 L
.636 .01459 L
.64 .01371 L
.644 .01293 L
.648 .01224 L
.652 .01164 L
.656 .0111 L
.66 .0106 L
.664 .01012 L
.668 .00961 L
.672 .00902 L
.676 .00834 L
.68 .00757 L
.684 .00677 L
.688 .00599 L
.692 .00534 L
.696 .00487 L
.7 .00463 L
.704 .00461 L
.708 .00479 L
.712 .00511 L
.716 .00547 L
.72 .00579 L
.724 .00602 L
.728 .00614 L
.732 .00619 L
.736 .00622 L
.74 .00629 L
.744 .00641 L
.748 .00659 L
.752 .00681 L
.756 .00705 L
.76 .00728 L
.764 .00748 L
.768 .00759 L
.772 .0076 L
.776 .00752 L
.78 .00739 L
.784 .00725 L
.788 .00711 L
.792 .00698 L
.796 .00687 L
.8 .00677 L
Mistroke
.804 .00669 L
.808 .00665 L
.812 .00661 L
.816 .00654 L
.82 .00644 L
.824 .00632 L
.828 .00624 L
.832 .00626 L
.836 .00643 L
.84 .00672 L
.844 .00704 L
.848 .00732 L
.852 .0075 L
.856 .00754 L
.86 .00748 L
.864 .00734 L
.868 .00715 L
.872 .00695 L
.876 .00676 L
.88 .00663 L
.884 .00658 L
.888 .0066 L
.892 .00668 L
.896 .00678 L
.9 .00689 L
.904 .007 L
.908 .0071 L
.912 .00719 L
.916 .00724 L
.92 .0072 L
.924 .00709 L
.928 .00692 L
.932 .00678 L
.936 .00671 L
.94 .00677 L
.944 .00692 L
.948 .0071 L
.952 .00724 L
.956 .0073 L
.96 .00725 L
.964 .00716 L
.968 .00707 L
.972 .00701 L
.976 .007 L
.98 .00702 L
.984 .007 L
.988 .00699 L
.992 .00692 L
.996 .0069 L
1 .00691 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02000WOol20014Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008002Ioo`@004=oo`002goo0P002Woo0P000goo0`000goo00<007ooOol09Goo00@007oo
Ool004=oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P009Woo00D007ooOomoo`00
00=oo`<003aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000=Ool3
0004Ool20007Ool30004Ool20004Ool2000017oo001oogoo10000goo0`0017oo0P000goo1@000goo
0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01000Oomoo`001goo
00<007ooOol00Woo10000Woo00<007oo00000P000Woo00<007oo00000goo00D007ooOomoo`00009o
o`04001oogoo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009o
o`800005Ool007ooOol00002Ool00`00Oomoo`02Ool20007Ool01000Oomoo`000Woo00<007ooOol0
0Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool200001Goo001oogoo0000
0Woo00<007ooOol00Woo0P001goo00@007ooOol0009oo`03001oogoo00=oo`05001oogooOol00002
Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol017oo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;Ool40003Ool0
1000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool20002Ool40003
Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00H0
07ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool2
000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0004
Ool400000goo001oo`05Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool0
1000Oomoo`000goo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool50003
Ool20008Ool01P00Oomoogoo001oo`8000Aoo`8000Ioo`04001oo`00Ool50003Ool20004Ool30004
Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo025oo`03001oogoo011o
o`03001oogoo03Eoo`008Woo0P0087oo0P004goo00@007ooOomoo`<0035oo`008WooH`0037oo000R
OolR00000goo001oo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo0080
009oo`D00003Ool007oo00<00003Ool007oo00<00005Ool00000001oo`040002Ool200000goo0000
0003Ool00`00Oomoo`0:Ool0029oo`8003Ioo`03001oo`0000Eoo`80009oo`@00004Ool000000002
Ool200000goo00000004000017oo000007oo200037oo000ROol00`00Oomoo`0fOol00`00Oomoo`09
Ool2000XOol0029oo`8006eoo`008Woo0P00KGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0
K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo
00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol0
0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2
000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol0
0goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00
Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
1000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<0
07ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@00
0Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:
Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
06Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol0009oo`8000Aoob4004Qoo`004Goo0P002Woo0P0017oo00<007oo
Ool00Woo00<007ooOol07Woo1000A7oo000XOol00`00Oomoo`0QOol30012Ool002Qoo`03001oogoo
02=oo`80045oo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0
9Goo0P00?goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@0
07ooOol002Qoo`<003eoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOol002Yoo`<003]oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P0000=oo`000000
0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00
Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0Woo0P000goo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool0
1000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003
Ool40004Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`00
17oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P00
0Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`000goo00<007ooOol01P000Woo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03
001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@00003Ool0000000H00003Ool0000001T0
00=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool2
0004Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo00@0
009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04001o
ogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Ao
o`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo00mo
o`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yo
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=o
o`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00
Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eo
o`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool0
10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001o
o`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003
Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0
011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool0
1000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo
00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00
Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001o
ogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0
0P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007oo
Oomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol0
0Woo0`000goo00<007ooOol0@goo8`0037oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo03ioo`H002ioo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008003Yoo`D0
03Aoo`002Woo00@007ooOol000]oo`04001oogoo000hOol4000hOol000Yoo`04001oogoo0007Ool4
0003Ool00`00Oomoo`0dOol2000lOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2000dOol0
0`00Oomoo`0lOol000]oo`8000Qoo`D0009oo`03001oogoo035oo`8003moo`0077oo00<007ooOol0
3Goo0`0017oo0P002Goo0`0017oo0P0017oo0P000Woo00<007ooOol00`000goo0`0017oo0P001Goo
1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo0000
0Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool00`00Oomoo`020004Ool01@00
Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`00
77oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo
0002Ool01000Ool000001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo
009oo`04001oogoo0002Ool200000goo001oo`04Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`002Goo00<0
07ooOol00Woo00D007ooOol007oo0080009oo`03001oogoo00=oo`04001oogooOol40003Ool01000
Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomo
o`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomo
o`0027oo0P0017oo00<007ooOol00P0000Eoo`00Oomoo`0000Aoo`8000=oo`03001oogoo00Aoo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomo
ogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Yoo`03001oogoo00=o
o`<000=oo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool5
0003Ool20006Ool001aoo`03001oogoo02Ioo`8004Yoo`0077oo00<007ooOol097oo0`00Bgoo000L
OomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool0
1000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo
0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00
Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo
000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol0
0Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00
Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo
008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomo
o`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(46593\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31655 m
.008 .31767 L
.012 .31877 L
.016 .31889 L
.02 .31804 L
.024 .31789 L
.028 .31842 L
.032 .31858 L
.036 .31832 L
.04 .31819 L
.044 .31828 L
.048 .31837 L
.052 .31843 L
.056 .31848 L
.06 .31846 L
.064 .3184 L
.068 .31833 L
.072 .31832 L
.076 .31841 L
.08 .31852 L
.084 .31859 L
.088 .31858 L
.092 .31851 L
.096 .31844 L
.1 .31844 L
.104 .31849 L
.108 .31857 L
.112 .31862 L
.116 .31862 L
.12 .3186 L
.124 .31857 L
.128 .31857 L
.132 .31861 L
.136 .31865 L
.14 .31869 L
.144 .3187 L
.148 .3187 L
.152 .31868 L
.156 .31866 L
.16 .31865 L
.164 .31866 L
.168 .31871 L
.172 .31877 L
.176 .31883 L
.18 .31884 L
.184 .31881 L
.188 .31874 L
.192 .31868 L
.196 .31868 L
.2 .31875 L
Mistroke
.204 .31883 L
.208 .31886 L
.212 .31882 L
.216 .31875 L
.22 .31869 L
.224 .31868 L
.228 .31871 L
.232 .31874 L
.236 .31871 L
.24 .31858 L
.244 .3184 L
.248 .31824 L
.252 .31817 L
.256 .31817 L
.26 .31815 L
.264 .31803 L
.268 .31776 L
.272 .31734 L
.276 .31685 L
.28 .31633 L
.284 .31584 L
.288 .31537 L
.292 .3148 L
.296 .31398 L
.3 .31281 L
.304 .31128 L
.308 .30948 L
.312 .30743 L
.316 .30512 L
.32 .30245 L
.324 .29925 L
.328 .29534 L
.332 .29059 L
.336 .28502 L
.34 .27878 L
.344 .27198 L
.348 .26463 L
.352 .25657 L
.356 .24771 L
.36 .23811 L
.364 .22798 L
.368 .21767 L
.372 .20763 L
.376 .19831 L
.38 .19006 L
.384 .18306 L
.388 .1774 L
.392 .17323 L
.396 .17087 L
.4 .17068 L
Mistroke
.404 .17285 L
.408 .17729 L
.412 .18361 L
.416 .1912 L
.42 .19928 L
.424 .20704 L
.428 .21379 L
.432 .21911 L
.436 .22278 L
.44 .22462 L
.444 .22441 L
.448 .222 L
.452 .2176 L
.456 .21183 L
.46 .20566 L
.464 .20019 L
.468 .19648 L
.472 .19533 L
.476 .19715 L
.48 .20175 L
.484 .20844 L
.488 .21629 L
.492 .22448 L
.496 .23241 L
.5 .23966 L
.504 .24588 L
.508 .25091 L
.512 .25486 L
.516 .25822 L
.52 .26171 L
.524 .26614 L
.528 .27222 L
.532 .28041 L
.536 .29075 L
.54 .30257 L
.544 .31451 L
.548 .32478 L
.552 .33176 L
.556 .33444 L
.56 .33271 L
.564 .32722 L
.568 .31917 L
.572 .31005 L
.576 .30146 L
.58 .29471 L
.584 .29054 L
.588 .28898 L
.592 .28947 L
.596 .29127 L
.6 .29381 L
Mistroke
.604 .29677 L
.608 .29992 L
.612 .30309 L
.616 .30623 L
.62 .30947 L
.624 .31295 L
.628 .31652 L
.632 .31949 L
.636 .32086 L
.64 .31985 L
.644 .31644 L
.648 .31146 L
.652 .30619 L
.656 .30201 L
.66 .30014 L
.664 .30153 L
.668 .30658 L
.672 .31461 L
.676 .3237 L
.68 .33122 L
.684 .33494 L
.688 .33418 L
.692 .32991 L
.696 .32409 L
.7 .31863 L
.704 .31487 L
.708 .31357 L
.712 .31505 L
.716 .31895 L
.72 .32394 L
.724 .32797 L
.728 .32932 L
.732 .32765 L
.736 .32426 L
.74 .32108 L
.744 .31928 L
.748 .31864 L
.752 .31821 L
.756 .31751 L
.76 .31699 L
.764 .31749 L
.768 .31912 L
.772 .32096 L
.776 .32183 L
.78 .32134 L
.784 .32019 L
.788 .31946 L
.792 .31945 L
.796 .31963 L
.8 .31942 L
Mistroke
.804 .3191 L
.808 .31984 L
.812 .32229 L
.816 .32561 L
.82 .3276 L
.824 .32627 L
.828 .32188 L
.832 .31686 L
.836 .31436 L
.84 .31588 L
.844 .31991 L
.848 .32351 L
.852 .32418 L
.856 .32175 L
.86 .31853 L
.864 .31679 L
.868 .31767 L
.872 .32039 L
.876 .3229 L
.88 .32421 L
.884 .32406 L
.888 .32297 L
.892 .3218 L
.896 .32025 L
.9 .31855 L
.904 .31734 L
.908 .31709 L
.912 .31885 L
.916 .32185 L
.92 .32433 L
.924 .32514 L
.928 .32323 L
.932 .31996 L
.936 .31769 L
.94 .31736 L
.944 .31956 L
.948 .32258 L
.952 .32407 L
.956 .32372 L
.96 .3214 L
.964 .31874 L
.968 .31773 L
.972 .31818 L
.976 .3201 L
.98 .32227 L
.984 .32314 L
.988 .32297 L
.992 .32163 L
.996 .31991 L
1 .31913 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13583 m
.008 .13644 L
.012 .13668 L
.016 .13667 L
.02 .1365 L
.024 .13649 L
.028 .13653 L
.032 .13658 L
.036 .13654 L
.04 .13654 L
.044 .13653 L
.048 .13655 L
.052 .13654 L
.056 .13654 L
.06 .13654 L
.064 .13655 L
.068 .13654 L
.072 .13654 L
.076 .13654 L
.08 .13654 L
.084 .13654 L
.088 .13654 L
.092 .13654 L
.096 .13654 L
.1 .13654 L
.104 .13655 L
.108 .13654 L
.112 .13655 L
.116 .13654 L
.12 .13654 L
.124 .13654 L
.128 .13654 L
.132 .13654 L
.136 .13655 L
.14 .13655 L
.144 .13655 L
.148 .13654 L
.152 .13654 L
.156 .13654 L
.16 .13654 L
.164 .13654 L
.168 .13654 L
.172 .13654 L
.176 .13655 L
.18 .13655 L
.184 .13655 L
.188 .13655 L
.192 .13655 L
.196 .13655 L
.2 .13655 L
Mistroke
.204 .13655 L
.208 .13655 L
.212 .13655 L
.216 .13656 L
.22 .13656 L
.224 .13657 L
.228 .13657 L
.232 .13658 L
.236 .13658 L
.24 .13659 L
.244 .1366 L
.248 .13661 L
.252 .13663 L
.256 .13665 L
.26 .13667 L
.264 .1367 L
.268 .13673 L
.272 .13676 L
.276 .13681 L
.28 .13686 L
.284 .13693 L
.288 .137 L
.292 .13709 L
.296 .13719 L
.3 .13732 L
.304 .13747 L
.308 .13766 L
.312 .13789 L
.316 .13816 L
.32 .13848 L
.324 .13885 L
.328 .13929 L
.332 .13982 L
.336 .14044 L
.34 .14117 L
.344 .14202 L
.348 .14302 L
.352 .14415 L
.356 .14545 L
.36 .14691 L
.364 .14855 L
.368 .15036 L
.372 .15236 L
.376 .15454 L
.38 .15688 L
.384 .15936 L
.388 .16196 L
.392 .16465 L
.396 .1674 L
.4 .17017 L
Mistroke
.404 .17293 L
.408 .17563 L
.412 .17825 L
.416 .18075 L
.42 .18313 L
.424 .18537 L
.428 .1875 L
.432 .18952 L
.436 .19147 L
.44 .19337 L
.444 .19528 L
.448 .19722 L
.452 .19922 L
.456 .20131 L
.46 .20351 L
.464 .20581 L
.468 .20819 L
.472 .21063 L
.476 .21308 L
.48 .2155 L
.484 .21785 L
.488 .22011 L
.492 .22224 L
.496 .22424 L
.5 .22613 L
.504 .22791 L
.508 .22961 L
.512 .23125 L
.516 .23284 L
.52 .23436 L
.524 .23582 L
.528 .23717 L
.532 .2384 L
.536 .23946 L
.54 .24034 L
.544 .24103 L
.548 .24156 L
.552 .24195 L
.556 .24226 L
.56 .24256 L
.564 .2429 L
.568 .24333 L
.572 .2439 L
.576 .2446 L
.58 .24545 L
.584 .24639 L
.588 .24739 L
.592 .2484 L
.596 .24937 L
.6 .25029 L
Mistroke
.604 .25113 L
.608 .25189 L
.612 .25258 L
.616 .2532 L
.62 .25375 L
.624 .25425 L
.628 .2547 L
.632 .25509 L
.636 .25546 L
.64 .25582 L
.644 .25621 L
.648 .25667 L
.652 .25719 L
.656 .25777 L
.66 .25836 L
.664 .25892 L
.668 .25937 L
.672 .25966 L
.676 .25974 L
.68 .25963 L
.684 .25937 L
.688 .25903 L
.692 .25869 L
.696 .25841 L
.7 .25821 L
.704 .25809 L
.708 .25804 L
.712 .25801 L
.716 .25795 L
.72 .25784 L
.724 .25765 L
.728 .25742 L
.732 .25719 L
.736 .257 L
.74 .25687 L
.744 .25681 L
.748 .25679 L
.752 .25683 L
.756 .25689 L
.76 .25697 L
.764 .25705 L
.768 .25712 L
.772 .25716 L
.776 .2572 L
.78 .25725 L
.784 .25733 L
.788 .25741 L
.792 .25749 L
.796 .25752 L
.8 .2575 L
Mistroke
.804 .2574 L
.808 .25724 L
.812 .25702 L
.816 .25675 L
.82 .25649 L
.824 .25629 L
.828 .25621 L
.832 .25625 L
.836 .2564 L
.84 .25656 L
.844 .25668 L
.848 .25672 L
.852 .2567 L
.856 .25664 L
.86 .25661 L
.864 .2566 L
.868 .2566 L
.872 .25659 L
.876 .25654 L
.88 .25646 L
.884 .25635 L
.888 .25622 L
.892 .2561 L
.896 .256 L
.9 .25594 L
.904 .25593 L
.908 .25599 L
.912 .25607 L
.916 .25616 L
.92 .25621 L
.924 .25622 L
.928 .25618 L
.932 .25612 L
.936 .25604 L
.94 .25594 L
.944 .25581 L
.948 .25567 L
.952 .25552 L
.956 .25543 L
.96 .25539 L
.964 .25546 L
.968 .25559 L
.972 .25574 L
.976 .25585 L
.98 .25588 L
.984 .25583 L
.988 .25573 L
.992 .25559 L
.996 .25547 L
1 .25535 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15766 L
.012 .16122 L
.016 .16235 L
.02 .16118 L
.024 .16075 L
.028 .16116 L
.032 .16126 L
.036 .16114 L
.04 .16106 L
.044 .16112 L
.048 .16112 L
.052 .16111 L
.056 .16107 L
.06 .16107 L
.064 .16105 L
.068 .16106 L
.072 .16104 L
.076 .16105 L
.08 .16103 L
.084 .16102 L
.088 .161 L
.092 .16099 L
.096 .16098 L
.1 .16098 L
.104 .16097 L
.108 .16097 L
.112 .16095 L
.116 .16094 L
.12 .16092 L
.124 .16092 L
.128 .16091 L
.132 .1609 L
.136 .16089 L
.14 .16089 L
.144 .16088 L
.148 .16087 L
.152 .16085 L
.156 .16084 L
.16 .16083 L
.164 .16082 L
.168 .16081 L
.172 .16081 L
.176 .1608 L
.18 .16079 L
.184 .16077 L
.188 .16076 L
.192 .16075 L
.196 .16074 L
.2 .16073 L
Mistroke
.204 .16072 L
.208 .16071 L
.212 .16069 L
.216 .16068 L
.22 .16067 L
.224 .16066 L
.228 .16064 L
.232 .16063 L
.236 .16061 L
.24 .16058 L
.244 .16056 L
.248 .16053 L
.252 .16051 L
.256 .16048 L
.26 .16044 L
.264 .1604 L
.268 .16035 L
.272 .1603 L
.276 .16023 L
.28 .16016 L
.284 .16007 L
.288 .15997 L
.292 .15984 L
.296 .1597 L
.3 .15952 L
.304 .15932 L
.308 .15908 L
.312 .1588 L
.316 .15847 L
.32 .15807 L
.324 .15759 L
.328 .15701 L
.332 .15633 L
.336 .15554 L
.34 .15462 L
.344 .15356 L
.348 .15233 L
.352 .15091 L
.356 .14929 L
.36 .14745 L
.364 .14539 L
.368 .14311 L
.372 .1406 L
.376 .13788 L
.38 .13496 L
.384 .13185 L
.388 .1286 L
.392 .12523 L
.396 .12178 L
.4 .11832 L
Mistroke
.404 .11488 L
.408 .1115 L
.412 .10822 L
.416 .10508 L
.42 .10209 L
.424 .09925 L
.428 .09658 L
.432 .09404 L
.436 .0916 L
.44 .08921 L
.444 .08683 L
.448 .0844 L
.452 .08188 L
.456 .07924 L
.46 .07647 L
.464 .07358 L
.468 .07058 L
.472 .06753 L
.476 .06445 L
.48 .06141 L
.484 .05845 L
.488 .05562 L
.492 .05293 L
.496 .0504 L
.5 .04802 L
.504 .04577 L
.508 .04363 L
.512 .04156 L
.516 .03957 L
.52 .03764 L
.524 .0358 L
.528 .03407 L
.532 .0325 L
.536 .03113 L
.54 .02999 L
.544 .0291 L
.548 .02842 L
.552 .02793 L
.556 .02753 L
.56 .02715 L
.564 .02669 L
.568 .0261 L
.572 .02533 L
.576 .02439 L
.58 .02329 L
.584 .02209 L
.588 .02083 L
.592 .01957 L
.596 .01835 L
.6 .0172 L
Mistroke
.604 .01612 L
.608 .01512 L
.612 .01419 L
.616 .01336 L
.62 .01261 L
.624 .01197 L
.628 .0114 L
.632 .0109 L
.636 .01044 L
.64 .00996 L
.644 .00943 L
.648 .00881 L
.652 .0081 L
.656 .00732 L
.66 .00652 L
.664 .0058 L
.668 .00523 L
.672 .00489 L
.676 .00478 L
.68 .00489 L
.684 .00517 L
.688 .00553 L
.692 .00589 L
.696 .00618 L
.7 .00636 L
.704 .00645 L
.708 .00648 L
.712 .00652 L
.716 .00662 L
.72 .00677 L
.724 .00698 L
.728 .00722 L
.732 .00744 L
.736 .00763 L
.74 .00774 L
.744 .00778 L
.748 .00774 L
.752 .00765 L
.756 .00754 L
.76 .00743 L
.764 .00732 L
.768 .00721 L
.772 .00709 L
.776 .00697 L
.78 .00687 L
.784 .00679 L
.788 .00672 L
.792 .00665 L
.796 .00658 L
.8 .00654 L
Mistroke
.804 .00656 L
.808 .00667 L
.812 .00687 L
.816 .00712 L
.82 .00736 L
.824 .00755 L
.828 .00767 L
.832 .00771 L
.836 .00766 L
.84 .00754 L
.844 .00736 L
.848 .00718 L
.852 .00702 L
.856 .00691 L
.86 .00686 L
.864 .00684 L
.868 .00684 L
.872 .00687 L
.876 .00696 L
.88 .00712 L
.884 .00733 L
.888 .00751 L
.892 .0076 L
.896 .00755 L
.9 .00739 L
.904 .00718 L
.908 .00704 L
.912 .00701 L
.916 .00708 L
.92 .00721 L
.924 .00733 L
.928 .00739 L
.932 .00739 L
.936 .00734 L
.94 .00729 L
.944 .00725 L
.948 .00721 L
.952 .00718 L
.956 .00717 L
.96 .00716 L
.964 .00721 L
.968 .00729 L
.972 .00741 L
.976 .00751 L
.98 .00756 L
.984 .00754 L
.988 .00748 L
.992 .00736 L
.996 .00729 L
1 .00722 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02000TOol30016Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008002Aoo`03001oo`0004Ioo`002goo0P002Woo0P000goo0`000goo00<007ooOol08Woo
00D007ooOomoo`0000Aoo`03001oogoo03ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0P008goo00D007ooOomoo`0000=oo`<003moo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2000=Ool30004Ool20007Ool30002Ool01@00Ool00000Ool00P0000Aoo`00
001oo`80009oo`<000=oo`<000Aoo`8000=oo`D000=oo`8000Aoo`8000Aoo`D0009oo`<000Aoo`80
00Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`0;Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`04001oogooOol20002Ool00`00Ool00002
000017oo001oo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P0047oo00@007ooOol0009oo`03001oogoo00Eoo`04001oogooOol20002Ool01000Oomoo`00
0Woo00<007oo00000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000
Oomoo`000Woo00<007ooOol01Goo00H007ooOol007oo0002Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol02goo10000goo00@007oo
Ool000Moo`06001oo`00001oo`000Woo00@007ooOol0009oo`07001oogooOol007oo00000goo1000
0goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`06
001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo
0P0037oo00<007ooOol017oo00@007ooOol000Ioo`800005Ool007ooOol00002Ool01000Oomoo`00
0Woo00@007ooOomoo`<000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0
029oo`8000aoo`D000=oo`8000Qoo`03001oo`0000=oo`8000Aoo`8000Ioo`04001oogooOol50003
Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo01io
o`03001oogoo011oo`03001oogoo03Qoo`008Woo0P007Woo00<007ooOol04Goo00<007ooOol00Woo
0`00<goo000ROomS000<Ool0029oob0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00@007oo001oo`80009oo`03001oo`000080009oo`03001oo`000080009oo`<0009oo`03001oogoo
00800005Ool00000001oo`0500000goo00000002Ool00`00Oomoo`0:Ool0029oo`8003Aoo`8000Io
o`08001oogooOol007oo001oo`<0009oo`d00003Ool0000000L000eoo`008Woo00<007ooOol0<goo
0P002Woo0`00:Woo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P00
0goo0`000goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001o
ogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol0
00Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001o
ogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`00
2goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`00
0goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029o
o`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=o
o`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo
0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo
0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0002Ool20004OolN001;Ool0015oo`8000Yoo`8000Aoo`03
001oogoo009oo`03001oogoo01]oo`@004Moo`00:7oo00<007ooOol07goo0P00AGoo000XOol00`00
Oomoo`0QOol20013Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001o
ogoo029oo`80049oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=o
o`04001oogoo000VOol20010Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`04001oogoo000WOol3000nOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`<0009oo`<0
00=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007oo
Oomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007ooOol00P00
0Woo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo
00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00D007oo
Ool007oo00<000Moo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001o
ogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004
Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0003Ool700001Goo001oogoo00000Woo00<007ooOol00Woo
00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomo
o`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000Oomoo`001goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo2@0000=oo`0000007@000goo
00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Ao
o`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007oo00000`000goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol0
00Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@0
07ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<0
07ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`00
0goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`00
0goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003
Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006
Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo
06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0
06Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001W
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo
1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool3
0003Ool00`00Oomoo`11OolU000<Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<0
07ooOol0>goo1P00<Goo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00>7oo1@00=Woo
000:Ool01000Oomoo`002goo00@007ooOol003Eoo`@003]oo`002Woo00@007ooOol000Moo`@000=o
o`03001oogoo035oo`<003ioo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80035oo`80041o
o`002goo0P0027oo1@000Woo00<007ooOol0;Woo0P00@Woo000LOol00`00Oomoo`0=Ool30004Ool2
0009Ool30004Ool20004Ool30004Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool5
0002Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<0
07ooOol00Woo00@007ooOol0009oo`@000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00<0
07ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007ooOol007oo
0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomoo`000Woo
00<007ooOol01goo00<007ooOol00Woo00D007ooOol007oo0080009oo`03001oogoo00=oo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo
011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0200001Goo001o
ogoo00001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002
Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo
00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oo`000002Ool0
1000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001ao
o`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool40002Ool01000Oomoo`00
17oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo
1@000goo0P002Woo00<007ooOol00Woo0`0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<0
00Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<007ooOol08goo0P00CGoo000L
Ool00`00Oomoo`0QOol3001>Ool001aoofT000aoo`0077oo00D007ooOomoo`0000=oo`03001oogoo
009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo
009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00
Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`002goo0P0017oo00<0
07ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009o
o`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=oo`002Woo00@007ooOol0
00]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03001oogoo079oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol0
0`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol30003Ool00`00Oomoo`1b
Ool001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo0P00Lgoo000GOol0
0`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005Woo0P00
17oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo00<007ooOol01goo
00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@007ooOol007Aoo`00
2goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool40003Ool00`00Oomo
o`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<007ooOol01goo1@00
0Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(46760\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31799 m
.008 .31863 L
.012 .31822 L
.016 .3181 L
.02 .31825 L
.024 .31824 L
.028 .31821 L
.032 .31832 L
.036 .31837 L
.04 .3183 L
.044 .31825 L
.048 .31829 L
.052 .31836 L
.056 .31841 L
.06 .31841 L
.064 .31837 L
.068 .31833 L
.072 .31833 L
.076 .31839 L
.08 .31848 L
.084 .31853 L
.088 .31852 L
.092 .31845 L
.096 .3184 L
.1 .3184 L
.104 .31847 L
.108 .31855 L
.112 .3186 L
.116 .31859 L
.12 .31855 L
.124 .31852 L
.128 .31853 L
.132 .31858 L
.136 .31863 L
.14 .31863 L
.144 .31861 L
.148 .31858 L
.152 .31859 L
.156 .31863 L
.16 .31868 L
.164 .31871 L
.168 .31871 L
.172 .31868 L
.176 .31863 L
.18 .3186 L
.184 .31859 L
.188 .31861 L
.192 .31862 L
.196 .31863 L
.2 .31863 L
Mistroke
.204 .31861 L
.208 .31855 L
.212 .31844 L
.216 .31833 L
.22 .31823 L
.224 .31815 L
.228 .31806 L
.232 .31793 L
.236 .31775 L
.24 .31751 L
.244 .31722 L
.248 .31689 L
.252 .31652 L
.256 .31607 L
.26 .31545 L
.264 .31464 L
.268 .31364 L
.272 .31251 L
.276 .31125 L
.28 .30978 L
.284 .30798 L
.288 .30574 L
.292 .30294 L
.296 .29952 L
.3 .2955 L
.304 .29092 L
.308 .2858 L
.312 .28005 L
.316 .27353 L
.32 .26612 L
.324 .25783 L
.328 .24876 L
.332 .23912 L
.336 .22915 L
.34 .21914 L
.344 .20932 L
.348 .19986 L
.352 .19094 L
.356 .18288 L
.36 .17615 L
.364 .17125 L
.368 .16853 L
.372 .16814 L
.376 .16999 L
.38 .17385 L
.384 .17932 L
.388 .18599 L
.392 .19343 L
.396 .20121 L
.4 .20884 L
Mistroke
.404 .2156 L
.408 .22069 L
.412 .22346 L
.416 .22362 L
.42 .22132 L
.424 .21705 L
.428 .21156 L
.432 .20577 L
.436 .20059 L
.44 .19675 L
.444 .19476 L
.448 .1949 L
.452 .19743 L
.456 .20243 L
.46 .20966 L
.464 .21844 L
.468 .22774 L
.472 .23648 L
.476 .24384 L
.48 .24939 L
.484 .25326 L
.488 .25608 L
.492 .25891 L
.496 .26291 L
.5 .2689 L
.504 .27709 L
.508 .28711 L
.512 .2982 L
.516 .30938 L
.52 .31955 L
.524 .32753 L
.528 .33227 L
.532 .33314 L
.536 .33009 L
.54 .32367 L
.544 .31495 L
.548 .30536 L
.552 .2965 L
.556 .28986 L
.56 .2864 L
.564 .28619 L
.568 .28849 L
.572 .2921 L
.576 .29592 L
.58 .29931 L
.584 .30212 L
.588 .30461 L
.592 .30716 L
.596 .31014 L
.6 .31362 L
Mistroke
.604 .3172 L
.608 .31994 L
.612 .32072 L
.616 .3188 L
.62 .31436 L
.624 .30856 L
.628 .30314 L
.632 .29979 L
.636 .2997 L
.64 .30332 L
.644 .31022 L
.648 .31905 L
.652 .32769 L
.656 .33382 L
.66 .33578 L
.664 .33337 L
.668 .32791 L
.672 .32154 L
.676 .3163 L
.68 .3135 L
.684 .31361 L
.688 .31641 L
.692 .32099 L
.696 .3258 L
.7 .32905 L
.704 .32947 L
.708 .32708 L
.712 .32323 L
.716 .31969 L
.72 .3176 L
.724 .31691 L
.728 .31697 L
.732 .31728 L
.736 .31792 L
.74 .31908 L
.744 .32049 L
.748 .32138 L
.752 .32117 L
.756 .32009 L
.76 .31901 L
.764 .31869 L
.768 .31906 L
.772 .31955 L
.776 .31984 L
.78 .3204 L
.784 .32199 L
.788 .32452 L
.792 .3266 L
.796 .3264 L
.8 .32322 L
Mistroke
.804 .31852 L
.808 .31501 L
.812 .31478 L
.816 .31775 L
.82 .32164 L
.824 .32397 L
.828 .3236 L
.832 .3213 L
.836 .31893 L
.84 .31767 L
.844 .31775 L
.848 .31884 L
.852 .32045 L
.856 .32266 L
.86 .3249 L
.864 .32596 L
.868 .32478 L
.872 .32099 L
.876 .31637 L
.88 .31377 L
.884 .31486 L
.888 .31944 L
.892 .32455 L
.896 .32681 L
.9 .32522 L
.904 .32094 L
.908 .3173 L
.912 .31691 L
.916 .31935 L
.92 .32269 L
.924 .32419 L
.928 .32258 L
.932 .31964 L
.936 .31739 L
.94 .31754 L
.944 .32013 L
.948 .32279 L
.952 .324 L
.956 .32311 L
.96 .32071 L
.964 .31898 L
.968 .31872 L
.972 .31986 L
.976 .3217 L
.98 .32262 L
.984 .32238 L
.988 .32124 L
.992 .31973 L
.996 .31909 L
1 .31925 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14175 m
.008 .13697 L
.012 .13536 L
.016 .13701 L
.02 .13751 L
.024 .13698 L
.028 .13678 L
.032 .13699 L
.036 .13704 L
.04 .13699 L
.044 .13696 L
.048 .13699 L
.052 .13698 L
.056 .13698 L
.06 .13697 L
.064 .13699 L
.068 .13698 L
.072 .13699 L
.076 .13698 L
.08 .13698 L
.084 .13697 L
.088 .13698 L
.092 .13698 L
.096 .13699 L
.1 .13698 L
.104 .13698 L
.108 .13698 L
.112 .13698 L
.116 .13698 L
.12 .13698 L
.124 .13698 L
.128 .13699 L
.132 .13698 L
.136 .13699 L
.14 .13698 L
.144 .13698 L
.148 .13698 L
.152 .13698 L
.156 .13698 L
.16 .13699 L
.164 .13699 L
.168 .13699 L
.172 .13699 L
.176 .13699 L
.18 .13699 L
.184 .13699 L
.188 .13699 L
.192 .137 L
.196 .13701 L
.2 .13701 L
Mistroke
.204 .13701 L
.208 .13702 L
.212 .13703 L
.216 .13704 L
.22 .13705 L
.224 .13707 L
.228 .13708 L
.232 .1371 L
.236 .13713 L
.24 .13716 L
.244 .13719 L
.248 .13724 L
.252 .13729 L
.256 .13735 L
.26 .13742 L
.264 .1375 L
.268 .1376 L
.272 .13773 L
.276 .13788 L
.28 .13806 L
.284 .13827 L
.288 .13852 L
.292 .13882 L
.296 .13918 L
.3 .13961 L
.304 .14012 L
.308 .14072 L
.312 .14142 L
.316 .14223 L
.32 .14318 L
.324 .14426 L
.328 .1455 L
.332 .14692 L
.336 .14851 L
.34 .15028 L
.344 .15223 L
.348 .15434 L
.352 .15662 L
.356 .15904 L
.36 .1616 L
.364 .16426 L
.368 .167 L
.372 .16976 L
.376 .17253 L
.38 .17525 L
.384 .17789 L
.388 .18044 L
.392 .18286 L
.396 .18516 L
.4 .18733 L
Mistroke
.404 .18939 L
.408 .19135 L
.412 .19327 L
.416 .19516 L
.42 .19707 L
.424 .19905 L
.428 .2011 L
.432 .20326 L
.436 .20552 L
.44 .20786 L
.444 .21027 L
.448 .2127 L
.452 .21513 L
.456 .21751 L
.46 .21981 L
.464 .22199 L
.468 .22405 L
.472 .22598 L
.476 .22779 L
.48 .22951 L
.484 .23115 L
.488 .23272 L
.492 .23425 L
.496 .23571 L
.5 .23709 L
.504 .23836 L
.508 .23948 L
.512 .24043 L
.516 .2412 L
.52 .24179 L
.524 .24223 L
.528 .24256 L
.532 .24285 L
.536 .24316 L
.54 .24355 L
.544 .24406 L
.548 .24472 L
.552 .24551 L
.556 .24641 L
.56 .24738 L
.564 .24838 L
.568 .24937 L
.572 .25031 L
.576 .25119 L
.58 .252 L
.584 .25272 L
.588 .25337 L
.592 .25394 L
.596 .25445 L
.6 .2549 L
Mistroke
.604 .25529 L
.608 .25566 L
.612 .25603 L
.616 .25641 L
.62 .25685 L
.624 .25735 L
.628 .2579 L
.632 .25847 L
.636 .25902 L
.64 .2595 L
.644 .25984 L
.648 .26001 L
.652 .25999 L
.656 .2598 L
.66 .2595 L
.664 .25916 L
.668 .25884 L
.672 .25858 L
.676 .25842 L
.68 .25832 L
.684 .25827 L
.688 .25823 L
.692 .25815 L
.696 .25801 L
.7 .25782 L
.704 .2576 L
.708 .25739 L
.712 .25723 L
.716 .25713 L
.72 .25708 L
.724 .25709 L
.728 .25714 L
.732 .25722 L
.736 .25731 L
.74 .2574 L
.744 .25748 L
.748 .25754 L
.752 .25759 L
.756 .25763 L
.76 .25768 L
.764 .25772 L
.768 .25774 L
.772 .25773 L
.776 .25768 L
.78 .25759 L
.784 .25744 L
.788 .25723 L
.792 .25698 L
.796 .25674 L
.8 .25657 L
Mistroke
.804 .25651 L
.808 .25656 L
.812 .25669 L
.816 .25685 L
.82 .25697 L
.824 .25703 L
.828 .25704 L
.832 .25702 L
.836 .25697 L
.84 .25691 L
.844 .25684 L
.848 .25678 L
.852 .25671 L
.856 .25664 L
.86 .25657 L
.864 .25648 L
.868 .2564 L
.872 .25634 L
.876 .25633 L
.88 .25635 L
.884 .2564 L
.888 .25642 L
.892 .25641 L
.896 .25636 L
.9 .25632 L
.904 .2563 L
.908 .25631 L
.912 .2563 L
.916 .25626 L
.92 .25614 L
.924 .25599 L
.928 .25585 L
.932 .25578 L
.936 .25578 L
.94 .25587 L
.944 .25597 L
.948 .25605 L
.952 .25608 L
.956 .25606 L
.96 .256 L
.964 .25592 L
.968 .2558 L
.972 .25568 L
.976 .25554 L
.98 .25542 L
.984 .25534 L
.988 .25532 L
.992 .25537 L
.996 .25549 L
1 .25558 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16044 L
.012 .16104 L
.016 .16135 L
.02 .16129 L
.024 .1611 L
.028 .16111 L
.032 .16114 L
.036 .16116 L
.04 .16111 L
.044 .16111 L
.048 .1611 L
.052 .16111 L
.056 .16108 L
.06 .16108 L
.064 .16105 L
.068 .16106 L
.072 .16104 L
.076 .16104 L
.08 .16102 L
.084 .16102 L
.088 .161 L
.092 .161 L
.096 .16098 L
.1 .16098 L
.104 .16097 L
.108 .16096 L
.112 .16094 L
.116 .16093 L
.12 .16092 L
.124 .16092 L
.128 .16091 L
.132 .16091 L
.136 .16089 L
.14 .16088 L
.144 .16086 L
.148 .16086 L
.152 .16085 L
.156 .16084 L
.16 .16083 L
.164 .16082 L
.168 .16081 L
.172 .1608 L
.176 .16079 L
.18 .16077 L
.184 .16076 L
.188 .16075 L
.192 .16073 L
.196 .16072 L
.2 .16071 L
Mistroke
.204 .16069 L
.208 .16068 L
.212 .16065 L
.216 .16063 L
.22 .1606 L
.224 .16058 L
.228 .16055 L
.232 .16051 L
.236 .16047 L
.24 .16042 L
.244 .16037 L
.248 .16031 L
.252 .16024 L
.256 .16016 L
.26 .16006 L
.264 .15994 L
.268 .1598 L
.272 .15963 L
.276 .15944 L
.28 .15921 L
.284 .15894 L
.288 .15861 L
.292 .15822 L
.296 .15777 L
.3 .15722 L
.304 .15659 L
.308 .15583 L
.312 .15495 L
.316 .15392 L
.32 .15273 L
.324 .15135 L
.328 .14979 L
.332 .14803 L
.336 .14605 L
.34 .14385 L
.344 .14142 L
.348 .13877 L
.352 .1359 L
.356 .13285 L
.36 .12964 L
.364 .1263 L
.368 .12289 L
.372 .11944 L
.376 .11599 L
.38 .11259 L
.384 .10927 L
.388 .10608 L
.392 .10303 L
.396 .10015 L
.4 .09742 L
Mistroke
.404 .09484 L
.408 .09236 L
.412 .08996 L
.416 .08757 L
.42 .08517 L
.424 .08269 L
.428 .08012 L
.432 .07742 L
.436 .07459 L
.44 .07164 L
.444 .0686 L
.448 .06553 L
.452 .06247 L
.456 .05947 L
.46 .05659 L
.464 .05385 L
.468 .05127 L
.472 .04885 L
.476 .04656 L
.48 .04439 L
.484 .04231 L
.488 .04031 L
.492 .03838 L
.496 .03653 L
.5 .03478 L
.504 .03317 L
.508 .03174 L
.512 .03052 L
.516 .02953 L
.52 .02876 L
.524 .02818 L
.528 .02774 L
.532 .02735 L
.536 .02694 L
.54 .02643 L
.544 .02577 L
.548 .02492 L
.552 .0239 L
.556 .02273 L
.56 .02147 L
.564 .02018 L
.568 .01891 L
.572 .01771 L
.576 .01661 L
.58 .0156 L
.584 .01468 L
.588 .01384 L
.592 .01308 L
.596 .01238 L
.6 .01176 L
Mistroke
.604 .01121 L
.608 .01071 L
.612 .01024 L
.616 .00975 L
.62 .00921 L
.624 .00858 L
.628 .00787 L
.632 .0071 L
.636 .00634 L
.64 .00569 L
.644 .00521 L
.648 .00497 L
.652 .00497 L
.656 .00519 L
.66 .00555 L
.664 .00596 L
.668 .00633 L
.672 .0066 L
.676 .00674 L
.68 .00679 L
.684 .0068 L
.688 .00683 L
.692 .00692 L
.696 .00709 L
.7 .00732 L
.704 .00757 L
.708 .0078 L
.712 .00796 L
.716 .00803 L
.72 .00802 L
.724 .00793 L
.728 .0078 L
.732 .00768 L
.736 .00757 L
.74 .00747 L
.744 .00738 L
.748 .00728 L
.752 .00718 L
.756 .00707 L
.76 .00697 L
.764 .00688 L
.768 .00679 L
.772 .00673 L
.776 .00674 L
.78 .00684 L
.784 .00704 L
.788 .00729 L
.792 .00755 L
.796 .00776 L
.8 .00791 L
Mistroke
.804 .00795 L
.808 .0079 L
.812 .00778 L
.816 .00761 L
.82 .00743 L
.824 .00729 L
.828 .00721 L
.832 .00718 L
.836 .00715 L
.84 .00711 L
.844 .00708 L
.848 .00708 L
.852 .00718 L
.856 .00736 L
.86 .00759 L
.864 .00779 L
.868 .00788 L
.872 .00784 L
.876 .00769 L
.88 .00751 L
.884 .00735 L
.888 .00725 L
.892 .00723 L
.896 .00727 L
.9 .00736 L
.904 .00745 L
.908 .00755 L
.912 .00761 L
.916 .00762 L
.92 .00758 L
.924 .00753 L
.928 .00748 L
.932 .00748 L
.936 .00751 L
.94 .00756 L
.944 .0076 L
.948 .00763 L
.952 .00764 L
.956 .00764 L
.96 .00763 L
.964 .0076 L
.968 .00754 L
.972 .00747 L
.976 .00739 L
.98 .00734 L
.984 .00736 L
.988 .00747 L
.992 .00761 L
.996 .0078 L
1 .00789 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02000ROol20019Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo0080025oo`04001oogoo0018Ool000]oo`8000Yoo`8000=oo`<000=oo`03001oogoo01mo
o`05001oogooOol00004Ool20012Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`80
021oo`03001oogoo009oo`03001oogoo00@0045oo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2000=Ool30004Ool20007Ool40003Ool300000goo001oo`020005Ool30003
Ool30004Ool20003Ool50003Ool20004Ool20004Ool50002Ool30004Ool20006Ool000=oo`D0009o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol02goo00D007ooOomo
o`00009oo`04001oogoo0007Ool20003Ool00`00Oomoo`0200000goo001oo`020005Ool01@00Oomo
ogoo00000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo
00<007ooOol01Goo0P000goo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00<007ooOol00P0017oo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00=oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol017oo
00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004
Ool00`00Oomoo`0;Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`03
001oogoo00<000=oo`04001oogooOol40003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;
Ool2000:Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P00
17oo00@007ooOol0009oo`06001oogoo001oo`000Woo0P000goo00<007ooOol017oo00@007ooOol0
009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo
00001Woo00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P001goo0P001Goo0P0017oo0P000goo
00@007ooOol000=oo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Io
o`008Woo00<007ooOol06goo0P004Woo00<007ooOol00Woo00<007ooOol0=Goo000ROol2000KOol2
000COol01`00Oomoogoo001oo`0003Ioo`008WooH`0037oo000ROolL0003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`03001oogoo00800004Ool007oo0002Ool60002Ool20002Ool30000
0goo00000002Ool3000017oo000007oo0P000Woo100000Aoo`00Oomoo`8000aoo`008Woo0P00<Goo
00<007oo00001Goo0P000goo0`0000Aoo`000000009oo`H00004Ool00000Ool300000goo00000009
000=Ool0029oo`03001oogoo035oo`03001oogoo00Uoo`8002eoo`008Woo0P00KGoo000ROol2001]
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2
000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80
009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06ao
o`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo
00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`80
00=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=o
o`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<0
07ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00
Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007oo
Oomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool0
0`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P00
17oo6`00CWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0HOol50019Ool002Qo
o`03001oogoo01aoo`<004Moo`00:7oo00<007ooOol07Woo0P00AWoo000;Ool20004Ool00`00Oomo
o`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0OOol30014Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`008goo0P00@goo0003Ool50002Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`009Goo0`00@7oo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02000;Ool30004
Ool20007Ool30004Ool20002Ool40003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003
Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol0
07oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000Oomoo`001goo00<007ooOol0
0Woo00@007ooOol0009oo`@000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04
001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007oo
Ool007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo
00@007ooOol0009oo`03001oogoo0080009oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomo
ogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`05001oogoo001oo`060004
Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09
Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool0
1000Oomoogoo20000Woo7`000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol0
17oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`000Woo0P000goo00<007oo
Ool00goo1@0000=oo`00Ool00Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007oo
Ool00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0
009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000ao
o`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007oo
Ool047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007oo
Ool00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`05001oogoo001oo`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0
009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo
000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00
Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4
001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2
000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;
Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`0nOolX000<Ool000Yoo`04001oogoo0007
Ool01@00Oomoogoo00000Woo00<007ooOol0>7oo1`00<goo0003Ool50002Ool01000Oomoo`002goo
00<007ooOol00P00=Goo1@00>Goo000:Ool01000Oomoo`002goo00@007ooOol0039oo`@003ioo`00
2Woo00@007ooOol000Moo`@000=oo`03001oogoo02ioo`<0045oo`002Woo00@007ooOol000Moo`03
001oogoo00Aoo`8002ioo`8004=oo`002goo0P0027oo1@000Woo00<007ooOol0;7oo00<007ooOol0
@goo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20002Ool40005Ool30003Ool30004
Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eoo`05001o
ogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00<007ooOol010000Woo00<007ooOol0
0goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
1000Ool000000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool40002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo
00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo00@007ooOol000Uoo`04001o
ogooOol20002Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOomoo`@000=oo`04001oogoo
0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001o
o`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001oogoo00Aoo`04001oogoo0008
Ool20002Ool30002Ool01000Oomoo`000Woo00<007ooOol00Woo0P000goo00<007ooOol017oo00@0
07ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogoo
Ool007oo00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00@007oo0000009o
o`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool5
0003Ool20006Ool001aoo`03001oogoo021oo`<004moo`0077oo00<007ooOol07Woo0`00DGoo000L
OomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool0
1000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo
0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00
Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo
000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol0
0Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00
Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo
008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomo
o`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(46927\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31982 m
.008 .31883 L
.012 .31764 L
.016 .31747 L
.02 .31838 L
.024 .31863 L
.028 .31818 L
.032 .31808 L
.036 .31831 L
.04 .31836 L
.044 .31823 L
.048 .31819 L
.052 .31825 L
.056 .31833 L
.06 .31837 L
.064 .3184 L
.068 .3184 L
.072 .31838 L
.076 .31836 L
.08 .31835 L
.084 .31836 L
.088 .31838 L
.092 .3184 L
.096 .31844 L
.1 .31849 L
.104 .31853 L
.108 .31853 L
.112 .3185 L
.116 .31845 L
.12 .31842 L
.124 .31843 L
.128 .31849 L
.132 .31857 L
.136 .31861 L
.14 .3186 L
.144 .31854 L
.148 .31849 L
.152 .31848 L
.156 .31851 L
.16 .31855 L
.164 .31855 L
.168 .3185 L
.172 .31842 L
.176 .31836 L
.18 .31834 L
.184 .31835 L
.188 .31835 L
.192 .31828 L
.196 .31813 L
.2 .31793 L
Mistroke
.204 .31772 L
.208 .31753 L
.212 .31735 L
.216 .31715 L
.22 .31689 L
.224 .31652 L
.228 .31601 L
.232 .31537 L
.236 .31459 L
.24 .3137 L
.244 .31265 L
.248 .31141 L
.252 .30991 L
.256 .30808 L
.26 .30582 L
.264 .3031 L
.268 .29989 L
.272 .29617 L
.276 .29188 L
.28 .28689 L
.284 .28109 L
.288 .27446 L
.292 .26702 L
.296 .25885 L
.3 .25006 L
.304 .24075 L
.308 .23102 L
.312 .22096 L
.316 .21074 L
.32 .20067 L
.324 .19119 L
.328 .18277 L
.332 .17579 L
.336 .17055 L
.34 .16722 L
.344 .16592 L
.348 .16669 L
.352 .16949 L
.356 .17423 L
.36 .18068 L
.364 .18842 L
.368 .19675 L
.372 .20481 L
.376 .2118 L
.38 .21712 L
.384 .22039 L
.388 .22145 L
.392 .22034 L
.396 .21732 L
.4 .21279 L
Mistroke
.404 .20726 L
.408 .20145 L
.412 .19624 L
.416 .19267 L
.42 .1916 L
.424 .1935 L
.428 .19827 L
.432 .20533 L
.436 .21385 L
.44 .22287 L
.444 .23152 L
.448 .23916 L
.452 .24551 L
.456 .25066 L
.46 .2549 L
.464 .25865 L
.468 .26246 L
.472 .26705 L
.476 .2732 L
.48 .28141 L
.484 .29163 L
.488 .30314 L
.492 .31467 L
.496 .32463 L
.5 .33149 L
.504 .3341 L
.508 .3321 L
.512 .32605 L
.516 .31736 L
.52 .30776 L
.524 .29885 L
.528 .2918 L
.532 .28728 L
.536 .28548 L
.54 .28614 L
.544 .28866 L
.548 .29224 L
.552 .29618 L
.556 .30004 L
.56 .30365 L
.564 .30695 L
.568 .30995 L
.572 .31267 L
.576 .31513 L
.58 .31718 L
.584 .3184 L
.588 .31816 L
.592 .31597 L
.596 .31192 L
.6 .30689 L
Mistroke
.604 .30235 L
.608 .29991 L
.612 .30075 L
.616 .30528 L
.62 .31291 L
.624 .32206 L
.628 .3305 L
.632 .33591 L
.636 .3368 L
.64 .33313 L
.644 .32645 L
.648 .31925 L
.652 .31389 L
.656 .31185 L
.66 .31336 L
.664 .3176 L
.668 .32304 L
.672 .32781 L
.676 .33029 L
.68 .32965 L
.684 .32632 L
.688 .32182 L
.692 .31797 L
.696 .31588 L
.7 .31557 L
.704 .31635 L
.708 .3175 L
.712 .31872 L
.716 .31995 L
.72 .32097 L
.724 .32135 L
.728 .32086 L
.732 .31979 L
.736 .31882 L
.74 .31845 L
.744 .31866 L
.748 .31913 L
.752 .31984 L
.756 .32118 L
.76 .32341 L
.764 .3259 L
.768 .32715 L
.772 .32577 L
.776 .32179 L
.78 .31706 L
.784 .31408 L
.788 .31435 L
.792 .31736 L
.796 .3211 L
.8 .3236 L
Mistroke
.804 .32404 L
.808 .32277 L
.812 .32073 L
.816 .31861 L
.82 .31707 L
.824 .31689 L
.828 .31863 L
.832 .32215 L
.836 .3258 L
.84 .32722 L
.844 .32511 L
.848 .32019 L
.852 .31541 L
.856 .31386 L
.86 .31628 L
.864 .32094 L
.868 .32446 L
.872 .3246 L
.876 .32206 L
.88 .31916 L
.884 .31833 L
.888 .32006 L
.892 .32237 L
.896 .32332 L
.9 .32207 L
.904 .31955 L
.908 .31802 L
.912 .31831 L
.916 .31996 L
.92 .32171 L
.924 .3221 L
.928 .3215 L
.932 .32089 L
.936 .32081 L
.94 .32149 L
.944 .3218 L
.948 .32101 L
.952 .31963 L
.956 .31842 L
.96 .31862 L
.964 .32036 L
.968 .32235 L
.972 .32349 L
.976 .32283 L
.98 .32087 L
.984 .31918 L
.988 .31854 L
.992 .3196 L
.996 .32143 L
1 .32244 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13897 m
.008 .13754 L
.012 .13696 L
.016 .13733 L
.02 .13754 L
.024 .13749 L
.028 .13737 L
.032 .13739 L
.036 .13742 L
.04 .13744 L
.044 .13741 L
.048 .13742 L
.052 .13741 L
.056 .13742 L
.06 .13741 L
.064 .13742 L
.068 .13742 L
.072 .13743 L
.076 .13742 L
.08 .13742 L
.084 .13741 L
.088 .13742 L
.092 .13742 L
.096 .13743 L
.1 .13742 L
.104 .13742 L
.108 .13742 L
.112 .13742 L
.116 .13742 L
.12 .13743 L
.124 .13742 L
.128 .13743 L
.132 .13742 L
.136 .13742 L
.14 .13742 L
.144 .13743 L
.148 .13743 L
.152 .13743 L
.156 .13743 L
.16 .13744 L
.164 .13744 L
.168 .13744 L
.172 .13744 L
.176 .13745 L
.18 .13745 L
.184 .13746 L
.188 .13748 L
.192 .13749 L
.196 .1375 L
.2 .13752 L
Mistroke
.204 .13753 L
.208 .13756 L
.212 .13758 L
.216 .13762 L
.22 .13766 L
.224 .13771 L
.228 .13777 L
.232 .13784 L
.236 .13792 L
.24 .13802 L
.244 .13814 L
.248 .13828 L
.252 .13845 L
.256 .13865 L
.26 .13889 L
.264 .13918 L
.268 .13953 L
.272 .13994 L
.276 .14042 L
.28 .141 L
.284 .14167 L
.288 .14245 L
.292 .14335 L
.296 .1444 L
.3 .1456 L
.304 .14696 L
.308 .14849 L
.312 .1502 L
.316 .15208 L
.32 .15414 L
.324 .15637 L
.328 .15876 L
.332 .16128 L
.336 .16391 L
.34 .16661 L
.344 .16936 L
.348 .17211 L
.352 .17484 L
.356 .17752 L
.36 .18011 L
.364 .18258 L
.368 .18493 L
.372 .18714 L
.376 .18923 L
.38 .19123 L
.384 .19315 L
.388 .19505 L
.392 .19695 L
.396 .19889 L
.4 .20091 L
Mistroke
.404 .20302 L
.408 .20523 L
.412 .20753 L
.416 .20991 L
.42 .21234 L
.424 .21477 L
.428 .21717 L
.432 .2195 L
.436 .22172 L
.44 .22382 L
.444 .22579 L
.448 .22764 L
.452 .22939 L
.456 .23105 L
.46 .23263 L
.464 .23416 L
.468 .23562 L
.472 .237 L
.476 .2383 L
.48 .23947 L
.484 .24048 L
.488 .24133 L
.492 .24199 L
.496 .24249 L
.5 .24287 L
.504 .24317 L
.508 .24345 L
.512 .2438 L
.516 .24424 L
.52 .24483 L
.524 .24556 L
.528 .24642 L
.532 .24737 L
.536 .24838 L
.54 .24939 L
.544 .25035 L
.548 .25125 L
.552 .25208 L
.556 .25282 L
.56 .25349 L
.564 .25409 L
.568 .25463 L
.572 .2551 L
.576 .25553 L
.58 .25591 L
.584 .25627 L
.588 .25663 L
.592 .25702 L
.596 .25747 L
.6 .25799 L
Mistroke
.604 .25855 L
.608 .25912 L
.612 .25964 L
.616 .26004 L
.62 .26028 L
.624 .26034 L
.628 .26021 L
.632 .25994 L
.636 .2596 L
.64 .25925 L
.644 .25896 L
.648 .25875 L
.652 .25863 L
.656 .25857 L
.66 .25852 L
.664 .25846 L
.668 .25835 L
.672 .25818 L
.676 .25797 L
.68 .25776 L
.684 .25758 L
.688 .25746 L
.692 .2574 L
.696 .25739 L
.7 .25743 L
.704 .2575 L
.708 .25758 L
.712 .25766 L
.716 .25774 L
.72 .2578 L
.724 .25787 L
.728 .25792 L
.732 .25797 L
.736 .25802 L
.74 .25804 L
.744 .25803 L
.748 .25799 L
.752 .2579 L
.756 .25777 L
.76 .2576 L
.764 .25739 L
.768 .25717 L
.772 .25699 L
.776 .25687 L
.78 .25685 L
.784 .25691 L
.788 .25703 L
.792 .25715 L
.796 .25725 L
.8 .25731 L
Mistroke
.804 .25733 L
.808 .25731 L
.812 .25727 L
.816 .25722 L
.82 .25715 L
.824 .25707 L
.828 .25699 L
.832 .25688 L
.836 .25677 L
.84 .25667 L
.844 .25661 L
.848 .2566 L
.852 .25665 L
.856 .25672 L
.86 .25677 L
.864 .25676 L
.868 .25669 L
.872 .2566 L
.876 .25654 L
.88 .25652 L
.884 .25654 L
.888 .25655 L
.892 .25652 L
.896 .25645 L
.9 .25635 L
.904 .25625 L
.908 .25618 L
.912 .25614 L
.916 .25613 L
.92 .25615 L
.924 .25619 L
.928 .25623 L
.932 .25627 L
.936 .25626 L
.94 .25621 L
.944 .25611 L
.948 .25598 L
.952 .25585 L
.956 .25576 L
.96 .25572 L
.964 .25572 L
.968 .25575 L
.972 .2558 L
.976 .25584 L
.98 .25589 L
.984 .2559 L
.988 .25588 L
.992 .2558 L
.996 .25567 L
1 .25551 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16455 L
.012 .16115 L
.016 .16001 L
.02 .16121 L
.024 .16154 L
.028 .16115 L
.032 .161 L
.036 .16114 L
.04 .16115 L
.044 .16112 L
.048 .16108 L
.052 .1611 L
.056 .16108 L
.06 .16108 L
.064 .16106 L
.068 .16106 L
.072 .16104 L
.076 .16104 L
.08 .16102 L
.084 .16102 L
.088 .161 L
.092 .161 L
.096 .16098 L
.1 .16098 L
.104 .16096 L
.108 .16096 L
.112 .16094 L
.116 .16094 L
.12 .16093 L
.124 .16092 L
.128 .16091 L
.132 .1609 L
.136 .16088 L
.14 .16087 L
.144 .16086 L
.148 .16085 L
.152 .16085 L
.156 .16084 L
.16 .16082 L
.164 .16081 L
.168 .16078 L
.172 .16077 L
.176 .16075 L
.18 .16074 L
.184 .16072 L
.188 .16071 L
.192 .16068 L
.196 .16065 L
.2 .16062 L
Mistroke
.204 .16058 L
.208 .16054 L
.212 .1605 L
.216 .16045 L
.22 .16039 L
.224 .16032 L
.228 .16024 L
.232 .16015 L
.236 .16003 L
.24 .1599 L
.244 .15974 L
.248 .15956 L
.252 .15934 L
.256 .15907 L
.26 .15876 L
.264 .15839 L
.268 .15795 L
.272 .15743 L
.276 .15682 L
.28 .1561 L
.284 .15525 L
.288 .15426 L
.292 .15312 L
.296 .15181 L
.3 .15031 L
.304 .1486 L
.308 .14668 L
.312 .14454 L
.316 .14218 L
.32 .1396 L
.324 .13681 L
.328 .13383 L
.332 .13068 L
.336 .1274 L
.34 .124 L
.344 .12055 L
.348 .11709 L
.352 .11367 L
.356 .11032 L
.36 .1071 L
.364 .10401 L
.368 .10108 L
.372 .09829 L
.376 .09565 L
.38 .09313 L
.384 .0907 L
.388 .08832 L
.392 .08593 L
.396 .0835 L
.4 .08097 L
Mistroke
.404 .07833 L
.408 .07555 L
.412 .07265 L
.416 .06966 L
.42 .06661 L
.424 .06355 L
.428 .06053 L
.432 .0576 L
.436 .0548 L
.44 .05215 L
.444 .04967 L
.448 .04734 L
.452 .04514 L
.456 .04306 L
.46 .04106 L
.464 .03913 L
.468 .03727 L
.472 .0355 L
.476 .03385 L
.48 .03236 L
.484 .03106 L
.488 .02999 L
.492 .02913 L
.496 .02849 L
.5 .02799 L
.504 .02758 L
.508 .02719 L
.512 .02673 L
.516 .02613 L
.52 .02537 L
.524 .02443 L
.528 .02333 L
.532 .02211 L
.536 .02083 L
.54 .01954 L
.544 .0183 L
.548 .01714 L
.552 .01608 L
.556 .01512 L
.56 .01426 L
.564 .01349 L
.568 .01279 L
.572 .01217 L
.576 .0116 L
.58 .01107 L
.584 .01057 L
.588 .01007 L
.592 .00954 L
.596 .00896 L
.6 .00831 L
Mistroke
.604 .0076 L
.608 .00688 L
.612 .00621 L
.616 .00566 L
.62 .00529 L
.624 .00516 L
.628 .00525 L
.632 .00554 L
.636 .00594 L
.64 .00637 L
.644 .00673 L
.648 .00699 L
.652 .00711 L
.656 .00714 L
.66 .00713 L
.664 .00715 L
.668 .00724 L
.672 .00741 L
.676 .00764 L
.68 .00789 L
.684 .0081 L
.688 .00825 L
.692 .0083 L
.696 .00826 L
.7 .00814 L
.704 .00799 L
.708 .00784 L
.712 .00771 L
.716 .0076 L
.72 .0075 L
.724 .00742 L
.728 .00733 L
.732 .00725 L
.736 .00716 L
.74 .00708 L
.744 .00701 L
.748 .00698 L
.752 .00702 L
.756 .00716 L
.76 .00737 L
.764 .00764 L
.768 .0079 L
.772 .00812 L
.776 .00823 L
.78 .00823 L
.784 .00811 L
.788 .00792 L
.792 .00769 L
.796 .0075 L
.8 .00738 L
Mistroke
.804 .00735 L
.808 .00737 L
.812 .0074 L
.816 .00742 L
.82 .00742 L
.824 .00745 L
.828 .00753 L
.832 .00767 L
.836 .00783 L
.84 .00797 L
.844 .00803 L
.848 .008 L
.852 .00791 L
.856 .00776 L
.86 .00761 L
.864 .00749 L
.868 .00743 L
.872 .00745 L
.876 .00754 L
.88 .00765 L
.884 .00777 L
.888 .00785 L
.892 .00788 L
.896 .00788 L
.9 .00788 L
.904 .00787 L
.908 .00785 L
.912 .0078 L
.916 .00773 L
.92 .00767 L
.924 .00765 L
.928 .00768 L
.932 .00776 L
.936 .00784 L
.94 .00788 L
.944 .00784 L
.948 .00777 L
.952 .0077 L
.956 .00769 L
.96 .00775 L
.964 .00786 L
.968 .00796 L
.972 .00804 L
.976 .00805 L
.98 .00804 L
.984 .00797 L
.988 .00791 L
.992 .00783 L
.996 .00775 L
1 .00767 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02000OOol3001;Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008001ioo`04001oogoo001;Ool000]oo`8000Yoo`8000=oo`<000=oo`03001oogoo01eo
o`05001oogooOol00004Ool00`00Oomoo`13Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`8001eoo`03001oogoo009oo`07001oogooOol007oo0000A7oo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8000eoo`<000Aoo`8000Moo`<000=oo`@0009oo`<000Eo
o`<000=oo`<000Aoo`8000=oo`D000=oo`8000Aoo`8000Aoo`D0009oo`<000Aoo`8000Ioo`000goo
1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00
Oomoogoo00000Woo00@007ooOol000Ioo`8000Aoo`@0009oo`04001oogoo0005Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009o
o`03001oogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000@Ool01000Oomoo`000Woo00<0
07ooOol00goo00<007oo000017oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Ool0
0004Ool01000Oomoo`000Woo0P0000=oo`00Ool017oo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol0
17oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool2
0004Ool00`00Oomoo`0;Ool40003Ool01000Oomoo`0017oo00@007ooOol000Aoo`04001oogoo0002
Ool01000Ool000001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool0
00]oo`8000Yoo`8000Aoo`03001oogoo009oo`8000aoo`03001oogoo00Aoo`04001oogoo0004Ool0
1000Ool0000017oo00@007ooOol0009oo`04001oo`000004Ool20003Ool00`00Oomoo`04Ool01000
Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00L007ooOomo
o`00Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool50003Ool20004Ool01@00Oomoogoo0000
1Goo0P0017oo0P0000=oo`00Ool00goo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`80
00Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol067oo0P004Woo00<007ooOol00Woo0P00
>Goo000ROol2000IOol00`00Oomoo`0AOol00`00Oomoo`02Ool3000hOol0029oof<000aoo`008Woo
6P0000=oo`00Ool00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool200000goo00000003
Ool500000goo0000000400001Goo00000000Ool00`0000Eoo`00000007oo00D00004Ool007ooOol2
0002Ool2000017oo001oo`0037oo000ROol2000^Ool00`00Ool0000:Ool01000Ool007oo0`000Woo
0P0000=oo`0000000P0000Aoo`00001oo`D00003Ool0000000X000aoo`008Woo00<007ooOol0;Woo
0P002Woo0P000goo00<007ooOol0:Woo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001o
ogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`00
27oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@0
07ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001o
ogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04
001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000R
Ool2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00
Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<0
07ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001o
ogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool20004OolH001AOol0015oo`80
00Yoo`8000Aoo`03001oogoo009oo`03001oogoo01Eoo`D004aoo`00:7oo00<007ooOol06Woo0P00
BWoo000XOol00`00Oomoo`0KOol30018Ool000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=o
o`<000=oo`03001oogoo01eoo`8004Moo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00
Oomoo`00Ool000=oo`04001oogoo000POol30015Ool000=oo`D0009oo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000SOol20013Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`@0
009oo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`80
00Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007oo
Ool02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool00`00Oomoo`040002
Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00
Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`@0
00=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04
001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool2
0004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo
Ool00Woo00@007ooOol0009oo`03001oo`0000H000Ioo`04001oogoo0002Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo
0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000=oo`P000=oob8000=oo`04001oogoo0005Ool002Qo
o`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool01000Oomoo`000Woo00@0
07ooOol0009oo`8000=oo`04001oogooOol40002Ool00`00Ool00003Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomoo`001Goo000XOol00`00Oomo
o`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool01000Oomoogoo1@000goo0P00
0goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomo
o`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`1VOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`00J7oo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00J7oo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`02001WOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo06Ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo06Ioo`00
2goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo
0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`00J7oo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool2
0003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogooOol5001[Ool0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo03]o
ob/000aoo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`0fOol6000fOol0
00=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02000bOol5000lOol000Yoo`04001oogoo000;
Ool01000Oomoo`00<7oo1000@7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0;7oo0P00
A7oo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00:goo0`00AGoo000;Ool20008Ool50002
Ool00`00Oomoo`0YOol20017Ool001aoo`03001oogoo00eoo`<000Aoo`8000Uoo`<000Aoo`<000=o
o`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0009oo`<000Aoo`8000Io
o`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0009Ool00`00Oomoo`02Ool40002Ool0
1000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001oogoo0002
Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`07Ool01000
Oomoogoo0P000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool0
0`00Oomoo`07Ool00`00Oomoo`030002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo1000
0goo00@007ooOol000Uoo`03001oo`00009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007oo
Oomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo00aoo`03001o
ogoo00Aoo`04001oogoo0008Ool30003Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03
001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D000=oo`8000Uo
o`8000Eoo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool3
0002Ool50003Ool20006Ool001aoo`03001oogoo01ioo`80059oo`0077oo00<007ooOol06goo0`00
E7oo000LOomY000<Ool001aoo`80009oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool0
1000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo
0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00
Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo
000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol0
0Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00
Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo
008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomo
o`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(47094\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31869 m
.008 .31791 L
.012 .3181 L
.016 .31813 L
.02 .31811 L
.024 .31819 L
.028 .31819 L
.032 .31813 L
.036 .31819 L
.04 .3183 L
.044 .31833 L
.048 .31829 L
.052 .31824 L
.056 .31823 L
.06 .31825 L
.064 .31828 L
.068 .31832 L
.072 .31835 L
.076 .31835 L
.08 .31834 L
.084 .31835 L
.088 .31837 L
.092 .31839 L
.096 .31841 L
.1 .3184 L
.104 .31839 L
.108 .31837 L
.112 .31837 L
.116 .31839 L
.12 .31842 L
.124 .31845 L
.128 .31846 L
.132 .31844 L
.136 .3184 L
.14 .31834 L
.144 .31828 L
.148 .31824 L
.152 .31824 L
.156 .31824 L
.16 .31822 L
.164 .31814 L
.168 .318 L
.172 .31783 L
.176 .31766 L
.18 .31749 L
.184 .31731 L
.188 .31709 L
.192 .31677 L
.196 .31636 L
.2 .31586 L
Mistroke
.204 .31528 L
.208 .31461 L
.212 .31381 L
.216 .31281 L
.22 .31156 L
.224 .31002 L
.228 .30816 L
.232 .30596 L
.236 .30339 L
.24 .30036 L
.244 .29678 L
.248 .29256 L
.252 .28763 L
.256 .28195 L
.26 .2755 L
.264 .26828 L
.268 .26031 L
.272 .25164 L
.276 .24232 L
.28 .23246 L
.284 .22222 L
.288 .21188 L
.292 .20176 L
.296 .19218 L
.3 .18347 L
.304 .17595 L
.308 .16991 L
.312 .16563 L
.316 .16338 L
.32 .16334 L
.324 .16559 L
.328 .17003 L
.332 .17625 L
.336 .1837 L
.34 .19172 L
.344 .19968 L
.348 .207 L
.352 .21312 L
.356 .21754 L
.36 .21986 L
.364 .21987 L
.368 .21755 L
.372 .21321 L
.376 .2075 L
.38 .20139 L
.384 .19592 L
.388 .19202 L
.392 .1903 L
.396 .19111 L
.4 .1945 L
Mistroke
.404 .20024 L
.408 .20786 L
.412 .21669 L
.416 .22599 L
.42 .23496 L
.424 .24285 L
.428 .24911 L
.432 .25366 L
.436 .25703 L
.44 .26017 L
.444 .26414 L
.448 .26982 L
.452 .27763 L
.456 .28747 L
.46 .29862 L
.464 .30992 L
.468 .32 L
.472 .32763 L
.476 .33192 L
.48 .33238 L
.484 .32897 L
.488 .32213 L
.492 .3129 L
.496 .30283 L
.5 .29362 L
.504 .28674 L
.508 .28309 L
.512 .28286 L
.516 .28552 L
.52 .28998 L
.524 .29493 L
.528 .2993 L
.532 .30263 L
.536 .30514 L
.54 .30744 L
.544 .31005 L
.548 .31302 L
.552 .31597 L
.556 .31815 L
.56 .31877 L
.564 .31726 L
.568 .3136 L
.572 .30853 L
.576 .30347 L
.58 .30011 L
.584 .29981 L
.588 .30311 L
.592 .30956 L
.596 .31788 L
.6 .32628 L
Mistroke
.604 .33287 L
.608 .33611 L
.612 .33528 L
.616 .33081 L
.62 .32426 L
.624 .31778 L
.628 .31339 L
.632 .31222 L
.636 .31431 L
.64 .31873 L
.644 .32395 L
.648 .32827 L
.652 .33028 L
.656 .32934 L
.66 .32586 L
.664 .3212 L
.668 .31707 L
.672 .31469 L
.676 .31433 L
.68 .31545 L
.684 .31725 L
.688 .3191 L
.692 .32062 L
.696 .32155 L
.7 .32162 L
.704 .32085 L
.708 .3196 L
.712 .31851 L
.716 .31809 L
.72 .31839 L
.724 .31921 L
.728 .32044 L
.732 .32218 L
.736 .32435 L
.74 .32623 L
.744 .32664 L
.748 .32469 L
.752 .32073 L
.756 .31647 L
.76 .31398 L
.764 .31433 L
.768 .31705 L
.772 .32049 L
.776 .32308 L
.78 .32401 L
.784 .3233 L
.788 .32145 L
.792 .3191 L
.796 .31723 L
.8 .31699 L
Mistroke
.804 .31893 L
.808 .32244 L
.812 .32553 L
.816 .32599 L
.82 .32326 L
.824 .31881 L
.828 .31555 L
.832 .31559 L
.836 .31851 L
.84 .32207 L
.844 .32371 L
.848 .32261 L
.852 .32028 L
.856 .31873 L
.86 .31911 L
.864 .32088 L
.868 .32231 L
.872 .32255 L
.876 .32171 L
.88 .32058 L
.884 .31999 L
.888 .3196 L
.892 .31906 L
.896 .3186 L
.9 .31871 L
.904 .32018 L
.908 .32259 L
.912 .32431 L
.916 .32413 L
.92 .3217 L
.924 .31847 L
.928 .31677 L
.932 .31757 L
.936 .32031 L
.94 .32297 L
.944 .32357 L
.948 .32209 L
.952 .31986 L
.956 .3187 L
.96 .31959 L
.964 .32145 L
.968 .32278 L
.972 .32237 L
.976 .32024 L
.98 .31828 L
.984 .31765 L
.988 .31894 L
.992 .3217 L
.996 .32354 L
1 .32383 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13335 m
.008 .13791 L
.012 .13937 L
.016 .13784 L
.02 .13733 L
.024 .13789 L
.028 .13802 L
.032 .13785 L
.036 .13778 L
.04 .13787 L
.044 .13787 L
.048 .13787 L
.052 .13785 L
.056 .13786 L
.06 .13785 L
.064 .13786 L
.068 .13785 L
.072 .13786 L
.076 .13785 L
.08 .13786 L
.084 .13785 L
.088 .13786 L
.092 .13786 L
.096 .13786 L
.1 .13786 L
.104 .13786 L
.108 .13786 L
.112 .13786 L
.116 .13786 L
.12 .13787 L
.124 .13787 L
.128 .13787 L
.132 .13786 L
.136 .13787 L
.14 .13787 L
.144 .13788 L
.148 .13789 L
.152 .1379 L
.156 .1379 L
.16 .13791 L
.164 .13791 L
.168 .13793 L
.172 .13795 L
.176 .13797 L
.18 .13799 L
.184 .13802 L
.188 .13805 L
.192 .13809 L
.196 .13813 L
.2 .13819 L
Mistroke
.204 .13825 L
.208 .13834 L
.212 .13843 L
.216 .13855 L
.22 .13868 L
.224 .13884 L
.228 .13903 L
.232 .13926 L
.236 .13954 L
.24 .13987 L
.244 .14027 L
.248 .14073 L
.252 .14128 L
.256 .14192 L
.26 .14267 L
.264 .14354 L
.268 .14455 L
.272 .1457 L
.276 .14701 L
.28 .14848 L
.284 .15013 L
.288 .15196 L
.292 .15397 L
.296 .15615 L
.3 .15848 L
.304 .16095 L
.308 .16354 L
.312 .16622 L
.316 .16896 L
.32 .17171 L
.324 .17446 L
.328 .17715 L
.332 .17976 L
.336 .18227 L
.34 .18466 L
.344 .18692 L
.348 .18906 L
.352 .19109 L
.356 .19305 L
.36 .19495 L
.364 .19684 L
.368 .19875 L
.372 .20073 L
.376 .20279 L
.38 .20495 L
.384 .20722 L
.388 .20957 L
.392 .21198 L
.396 .21441 L
.4 .21682 L
Mistroke
.404 .21917 L
.408 .22143 L
.412 .22358 L
.416 .2256 L
.42 .22749 L
.424 .22927 L
.428 .23095 L
.432 .23254 L
.436 .23406 L
.44 .23553 L
.444 .23693 L
.448 .23824 L
.452 .23945 L
.456 .24052 L
.46 .24142 L
.464 .24215 L
.468 .24272 L
.472 .24314 L
.476 .24347 L
.48 .24376 L
.484 .24408 L
.488 .24447 L
.492 .24499 L
.496 .24564 L
.5 .24644 L
.504 .24736 L
.508 .24835 L
.512 .24937 L
.516 .25037 L
.52 .25131 L
.524 .25217 L
.528 .25294 L
.532 .25363 L
.536 .25424 L
.54 .25479 L
.544 .25528 L
.548 .25572 L
.552 .25613 L
.556 .2565 L
.56 .25687 L
.564 .25725 L
.568 .25767 L
.572 .25813 L
.576 .25864 L
.58 .25918 L
.584 .25971 L
.588 .26017 L
.592 .26049 L
.596 .26065 L
.6 .26062 L
Mistroke
.604 .26042 L
.608 .2601 L
.612 .25972 L
.616 .25936 L
.62 .25908 L
.624 .2589 L
.628 .25882 L
.632 .25879 L
.636 .25877 L
.64 .2587 L
.644 .25857 L
.648 .25838 L
.652 .25816 L
.656 .25794 L
.66 .25777 L
.664 .25768 L
.668 .25766 L
.672 .25771 L
.676 .25779 L
.68 .25787 L
.684 .25796 L
.688 .25803 L
.692 .25808 L
.696 .25813 L
.7 .25818 L
.704 .25823 L
.708 .25828 L
.712 .25832 L
.716 .25834 L
.72 .25832 L
.724 .25825 L
.728 .25814 L
.732 .25797 L
.736 .25777 L
.74 .25756 L
.744 .25735 L
.748 .25721 L
.752 .25714 L
.756 .25717 L
.76 .25726 L
.764 .25739 L
.768 .25751 L
.772 .2576 L
.776 .25763 L
.78 .25762 L
.784 .25758 L
.788 .25753 L
.792 .25747 L
.796 .25742 L
.8 .25736 L
Mistroke
.804 .25727 L
.808 .25715 L
.812 .25702 L
.816 .2569 L
.82 .25684 L
.824 .25685 L
.828 .25692 L
.832 .25702 L
.836 .25708 L
.84 .25709 L
.844 .25703 L
.848 .25695 L
.852 .25686 L
.856 .2568 L
.86 .25677 L
.864 .25674 L
.868 .25672 L
.872 .25668 L
.876 .25664 L
.88 .25658 L
.884 .25652 L
.888 .25646 L
.892 .25643 L
.896 .25642 L
.9 .25644 L
.904 .25648 L
.908 .25651 L
.912 .2565 L
.916 .25646 L
.92 .2564 L
.924 .25632 L
.928 .25624 L
.932 .25616 L
.936 .25607 L
.94 .25599 L
.944 .25594 L
.948 .25595 L
.952 .25601 L
.956 .2561 L
.96 .25616 L
.964 .25616 L
.968 .25609 L
.972 .25596 L
.976 .25581 L
.98 .2557 L
.984 .25563 L
.988 .25563 L
.992 .25565 L
.996 .2557 L
1 .25572 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16254 L
.012 .16136 L
.016 .16076 L
.02 .16108 L
.024 .16126 L
.028 .16121 L
.032 .16109 L
.036 .16112 L
.04 .16112 L
.044 .16113 L
.048 .16109 L
.052 .16109 L
.056 .16108 L
.06 .16108 L
.064 .16106 L
.068 .16106 L
.072 .16104 L
.076 .16104 L
.08 .16102 L
.084 .16102 L
.088 .161 L
.092 .161 L
.096 .16098 L
.1 .16098 L
.104 .16096 L
.108 .16095 L
.112 .16094 L
.116 .16093 L
.12 .16092 L
.124 .16091 L
.128 .1609 L
.132 .16089 L
.136 .16087 L
.14 .16086 L
.144 .16084 L
.148 .16083 L
.152 .16081 L
.156 .16079 L
.16 .16077 L
.164 .16074 L
.168 .16072 L
.172 .16069 L
.176 .16066 L
.18 .16063 L
.184 .16058 L
.188 .16053 L
.192 .16047 L
.196 .1604 L
.2 .16032 L
Mistroke
.204 .16023 L
.208 .16013 L
.212 .16 L
.216 .15985 L
.22 .15967 L
.224 .15946 L
.228 .1592 L
.232 .1589 L
.236 .15855 L
.24 .15813 L
.244 .15763 L
.248 .15705 L
.252 .15636 L
.256 .15555 L
.26 .1546 L
.264 .1535 L
.268 .15224 L
.272 .15079 L
.276 .14915 L
.28 .1473 L
.284 .14523 L
.288 .14294 L
.292 .14043 L
.296 .13771 L
.3 .13479 L
.304 .13169 L
.308 .12845 L
.312 .12509 L
.316 .12167 L
.32 .11822 L
.324 .11478 L
.328 .11141 L
.332 .10814 L
.336 .10499 L
.34 .10199 L
.344 .09916 L
.348 .09647 L
.352 .09392 L
.356 .09147 L
.36 .08908 L
.364 .0867 L
.368 .08428 L
.372 .08179 L
.376 .07919 L
.38 .07648 L
.384 .07364 L
.388 .07071 L
.392 .06769 L
.396 .06463 L
.4 .0616 L
Mistroke
.404 .05863 L
.408 .05577 L
.412 .05306 L
.416 .05052 L
.42 .04814 L
.424 .04591 L
.428 .0438 L
.432 .04179 L
.436 .03985 L
.44 .03799 L
.444 .03622 L
.448 .03455 L
.452 .03301 L
.456 .03165 L
.46 .03048 L
.464 .02954 L
.468 .0288 L
.472 .02824 L
.476 .02781 L
.48 .02743 L
.484 .02701 L
.488 .02649 L
.492 .02581 L
.496 .02494 L
.5 .02391 L
.504 .02273 L
.508 .02146 L
.512 .02017 L
.516 .0189 L
.52 .0177 L
.524 .0166 L
.528 .0156 L
.532 .01471 L
.536 .01391 L
.54 .01319 L
.544 .01254 L
.548 .01195 L
.552 .01142 L
.556 .01091 L
.56 .01042 L
.564 .00991 L
.568 .00936 L
.572 .00874 L
.576 .00807 L
.58 .00736 L
.584 .00668 L
.588 .00608 L
.592 .00565 L
.596 .00542 L
.6 .00542 L
Mistroke
.604 .00563 L
.608 .00598 L
.612 .00639 L
.616 .00679 L
.62 .00711 L
.624 .00732 L
.628 .00742 L
.632 .00744 L
.636 .00745 L
.64 .0075 L
.644 .0076 L
.648 .00777 L
.652 .00799 L
.656 .0082 L
.66 .00838 L
.664 .00849 L
.668 .00851 L
.672 .00845 L
.676 .00833 L
.68 .00818 L
.684 .00802 L
.688 .00787 L
.692 .00775 L
.696 .00764 L
.7 .00755 L
.704 .00747 L
.708 .0074 L
.712 .00734 L
.716 .0073 L
.72 .00727 L
.724 .00729 L
.728 .00737 L
.732 .00752 L
.736 .00773 L
.74 .00798 L
.744 .00822 L
.748 .00839 L
.752 .00847 L
.756 .00843 L
.76 .00828 L
.764 .00807 L
.768 .00784 L
.772 .00765 L
.776 .00754 L
.78 .00752 L
.784 .00756 L
.788 .00762 L
.792 .00768 L
.796 .00773 L
.8 .0078 L
Mistroke
.804 .00789 L
.808 .008 L
.812 .0081 L
.816 .00817 L
.82 .00818 L
.824 .00813 L
.828 .00804 L
.832 .00792 L
.836 .00781 L
.84 .00774 L
.844 .00773 L
.848 .00778 L
.852 .00786 L
.856 .00793 L
.86 .00799 L
.864 .00802 L
.868 .00805 L
.872 .00808 L
.876 .00813 L
.88 .00816 L
.884 .00813 L
.888 .00805 L
.892 .00794 L
.896 .00784 L
.9 .00781 L
.904 .00785 L
.908 .00794 L
.912 .00803 L
.916 .0081 L
.92 .00812 L
.924 .00813 L
.928 .00811 L
.932 .0081 L
.936 .00809 L
.94 .00807 L
.944 .00806 L
.948 .00808 L
.952 .0081 L
.956 .00814 L
.96 .00814 L
.964 .00813 L
.968 .00807 L
.972 .00801 L
.976 .00797 L
.98 .00798 L
.984 .00801 L
.988 .0081 L
.992 .00818 L
.996 .00826 L
1 .0083 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo00007Woo00<007ooOol0CGoo000:Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool00`00Oomoo`02000LOol3001>Ool000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`03001oogoo008001]oo`800003Ool0000004eoo`002goo0P002Woo0P000goo0`00
0goo00<007ooOol06Woo00D007ooOomoo`0000Aoo`8004Moo`002goo0P0017oo00<007ooOol00goo
0P000goo0`000goo0P006goo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo04Aoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000=Ool30004Ool20004Ool00`00
Oomoo`0400000goo000000030003Ool20005Ool30003Ool30004Ool20003Ool50003Ool20004Ool2
0004Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol02goo00D007ooOomoo`00009oo`04001oogoo0003Ool01@00Oomo
ogoo00000Woo0`000Woo0P0000Eoo`00Oomoo`0000Eoo`05001oogooOol00003Ool01000Oomoo`00
0Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`80011oo`04001oogoo0002Ool01000Oomoo`0017oo00<007oo
Ool00Woo00<007ooOol00P0000Eoo`00Oomoo`0000Eoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo0P0047oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomo
o`0200001Goo001oogoo00001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol017oo00@007ooOol0
009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomo
o`0;Ool40003Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo00D007ooOol007oo
0080009oo`03001oogoo00=oo`04001oogooOol40003Ool01000Oomoo`000Woo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`00
1Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`04Ool01P00Oomoo`00
Ool000Aoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@0
07ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogoo
Ool007oo00001Woo00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P0000=oo`0000001Goo00<0
07ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eo
o`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol05Woo00<007ooOol04Goo00@007ooOomoo`80
03aoo`008Woo0P005Woo00<007ooOol04Woo00L007ooOomoo`00Ool0000kOol0029oof<000aoo`00
8Woo5`0000Eoo`00Oomoo`0000=oo`05001oogooOol00003Ool02000Oomoogoo001oo`00Ool20002
Ool00`00Ool000020002Ool200000goo00000002Ool30002Ool20002Ool2000017oo000007oo0`00
00=oo`00Ool00`0000Aoo`00001oo`800004Ool007oo000<Ool0029oo`8002aoo`<000Yoo`04001o
o`00Ool30002Ool200001Goo00000000Ool00`0000Aoo`00001oo`h00003Ool0000000aoo`008Woo
00<007ooOol0;7oo00<007ooOol02Goo0P000goo00<007ooOol0;7oo000ROol2001]Ool0029oo`80
06eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool000]o
o`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo
0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04001o
ogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000R
Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P00
0goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000ROol0
0`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05
001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000
Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=o
o`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009oo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002Ool2
0004OolE001DOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`80019oo`L004ioo`00:7oo00<0
07ooOol05goo0`00C7oo000XOol00`00Oomoo`0IOol2001;Ool000]oo`8000Aoo`03001oogoo00=o
o`8000Aoo`8000=oo`<000=oo`03001oogoo01Yoo`<004Uoo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000NOol30017Ool000=oo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000POol20016Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`80
00Moo`<000=oo`<000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0
009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool0
10000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool0
1000Ool000000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H0
07ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol0
0Woo00<007ooOol010000Woo00D007ooOomoo`0000Moo`04001oogoo0002Ool01@00Oomoogoo0000
17oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`H00003Ool007oo00Ioo`04001oogoo
0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03
001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04
001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0009oo`T0009oob<000=o
o`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001oogoo0006Ool20004
Ool01000Oomoo`000Woo00@007ooOol0009oo`8000=oo`H00007Ool007ooOol007oo00000goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eo
o`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007oo
Oomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007oo
Ool047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo
00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo
00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool0
0`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool0
0`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo
0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Io
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qo
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00
Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003
Ool00`00Oomoo`0iOol]000<Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0<goo1P00>Goo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P00;goo1P00?Woo000:
Ool01000Oomoo`002goo00@007ooOol002eoo`@004=oo`002Woo00@007ooOol000Moo`@000=oo`03
001oogoo02Uoo`<004Ioo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8002Qoo`<004Qoo`00
2goo0P0027oo1@000Woo00<007ooOol09Woo0P00BWoo000LOol00`00Oomoo`0=Ool30004Ool20009
Ool30003Ool30004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002
Ool30004Ool20006Ool001aoo`8000eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007oo
Ool00`000Woo00@007ooOol0009oo`03001oogoo00=oo`05001oogooOol00003Ool01000Oomoo`00
0Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool01000Oomo
o`000Woo00<007ooOol01goo00H007oo000007oo0002Ool01000Oomoo`000Woo00<007ooOol00goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<0
07ooOol047oo00@007ooOol0009oo`03001oogoo00Moo`8000=oo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool0
1000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=o
o`0077oo0P003Goo10000goo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo
00aoo`03001oogoo00Aoo`04001oogoo0007Ool30004Ool01000Oomoo`000Woo00@007ooOol000Ao
o`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`8000eoo`D0
00=oo`8000Moo`04001oogoo0005Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`00
17oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`0KOol2001EOol001ao
o`03001oogoo01Uoo`<005Ioo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<007ooOol0
0Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol0
0Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001o
ogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000;Ool20004Ool00`00
Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo
00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000Oomoo`00
2goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`002Woo00@0
07ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Ioo`<000=oo`03001oogoo079o
o`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol001Moo`03
001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000FOol20004
Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2
001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomoo`07Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00M7oo000;
Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03001oogoo
079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07Ool50002
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(47261\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31644 m
.008 .31735 L
.012 .31867 L
.016 .31891 L
.02 .318 L
.024 .31775 L
.028 .31819 L
.032 .31829 L
.036 .31811 L
.04 .31812 L
.044 .31826 L
.048 .31829 L
.052 .31822 L
.056 .31818 L
.06 .31821 L
.064 .31825 L
.068 .31829 L
.072 .3183 L
.076 .31829 L
.08 .31827 L
.084 .31826 L
.088 .31828 L
.092 .31831 L
.096 .31831 L
.1 .31829 L
.104 .31825 L
.108 .31823 L
.112 .31824 L
.116 .31825 L
.12 .31824 L
.124 .31818 L
.128 .31809 L
.132 .31798 L
.136 .3179 L
.14 .31784 L
.144 .31778 L
.148 .31767 L
.152 .31749 L
.156 .31724 L
.16 .31695 L
.164 .31661 L
.168 .31625 L
.172 .31582 L
.176 .3153 L
.18 .31464 L
.184 .31382 L
.188 .3128 L
.192 .31157 L
.196 .31011 L
.2 .30836 L
Mistroke
.204 .30629 L
.208 .3038 L
.212 .30082 L
.216 .29727 L
.22 .2931 L
.224 .28828 L
.228 .28278 L
.232 .27656 L
.236 .26956 L
.24 .26177 L
.244 .25317 L
.248 .24384 L
.252 .23394 L
.256 .22368 L
.26 .21331 L
.264 .20306 L
.268 .19321 L
.272 .18407 L
.276 .17599 L
.28 .16931 L
.284 .16438 L
.288 .16146 L
.292 .16076 L
.296 .1623 L
.3 .16595 L
.304 .17144 L
.308 .17839 L
.312 .18631 L
.316 .19457 L
.32 .2025 L
.324 .20942 L
.328 .21468 L
.332 .21778 L
.336 .21846 L
.34 .21676 L
.344 .21306 L
.348 .20798 L
.352 .20224 L
.356 .19664 L
.36 .19197 L
.364 .18901 L
.368 .18838 L
.372 .19044 L
.376 .19525 L
.38 .20249 L
.384 .21147 L
.388 .22119 L
.392 .23061 L
.396 .23891 L
.4 .24569 L
Mistroke
.404 .25098 L
.408 .25518 L
.412 .25891 L
.416 .26294 L
.42 .268 L
.424 .2746 L
.428 .28294 L
.432 .29284 L
.436 .30373 L
.44 .3146 L
.444 .32407 L
.448 .33068 L
.452 .33323 L
.456 .33127 L
.46 .32519 L
.464 .31616 L
.468 .30583 L
.472 .296 L
.476 .28825 L
.48 .28351 L
.484 .28198 L
.488 .28322 L
.492 .28646 L
.496 .29085 L
.5 .29566 L
.504 .30027 L
.508 .30427 L
.512 .30752 L
.516 .31014 L
.52 .31235 L
.524 .31425 L
.528 .31574 L
.532 .31652 L
.536 .31623 L
.54 .31457 L
.544 .31144 L
.548 .30726 L
.552 .30306 L
.556 .30035 L
.56 .30059 L
.564 .30454 L
.568 .31184 L
.572 .32099 L
.576 .32977 L
.58 .33594 L
.584 .33789 L
.588 .33519 L
.592 .32887 L
.596 .3211 L
.6 .31451 L
Mistroke
.604 .31118 L
.608 .31189 L
.612 .31594 L
.616 .3216 L
.62 .32681 L
.624 .32992 L
.628 .33012 L
.632 .32757 L
.636 .3233 L
.64 .31884 L
.644 .31559 L
.648 .31429 L
.652 .31481 L
.656 .31634 L
.66 .31804 L
.664 .31938 L
.668 .32026 L
.672 .32074 L
.676 .32085 L
.68 .32053 L
.684 .31988 L
.688 .31917 L
.692 .31874 L
.696 .3188 L
.7 .31944 L
.704 .32067 L
.708 .32247 L
.712 .32454 L
.716 .32609 L
.72 .32608 L
.724 .32388 L
.728 .31997 L
.732 .31596 L
.736 .3137 L
.74 .31416 L
.744 .31692 L
.748 .32047 L
.752 .32322 L
.756 .32424 L
.76 .3234 L
.764 .32129 L
.768 .31883 L
.772 .31722 L
.776 .31751 L
.78 .31984 L
.784 .32316 L
.788 .32541 L
.792 .32487 L
.796 .32161 L
.8 .31752 L
Mistroke
.804 .31521 L
.808 .31611 L
.812 .31934 L
.816 .32265 L
.82 .32396 L
.824 .32288 L
.828 .32071 L
.832 .319 L
.836 .31862 L
.84 .31938 L
.844 .32048 L
.848 .32158 L
.852 .32244 L
.856 .32268 L
.86 .32197 L
.864 .32004 L
.868 .31768 L
.872 .31647 L
.876 .31743 L
.88 .32042 L
.884 .32363 L
.888 .32483 L
.892 .32341 L
.896 .32047 L
.9 .31826 L
.904 .31834 L
.908 .32011 L
.912 .32179 L
.916 .32185 L
.92 .32023 L
.924 .31866 L
.928 .31869 L
.932 .32049 L
.936 .32277 L
.94 .32354 L
.944 .32221 L
.948 .31978 L
.952 .31795 L
.956 .31813 L
.96 .31979 L
.964 .32154 L
.968 .32237 L
.972 .32169 L
.976 .32074 L
.98 .32055 L
.984 .32083 L
.988 .32165 L
.992 .32172 L
.996 .32043 L
1 .31935 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13589 m
.008 .13821 L
.012 .13901 L
.016 .13841 L
.02 .13806 L
.024 .13824 L
.028 .13835 L
.032 .13833 L
.036 .13827 L
.04 .13829 L
.044 .13829 L
.048 .13831 L
.052 .13829 L
.056 .1383 L
.06 .13829 L
.064 .1383 L
.068 .13829 L
.072 .1383 L
.076 .13829 L
.08 .1383 L
.084 .13829 L
.088 .1383 L
.092 .1383 L
.096 .1383 L
.1 .1383 L
.104 .13831 L
.108 .13831 L
.112 .13831 L
.116 .13832 L
.12 .13832 L
.124 .13833 L
.128 .13833 L
.132 .13834 L
.136 .13835 L
.14 .13836 L
.144 .13838 L
.148 .1384 L
.152 .13842 L
.156 .13844 L
.16 .13847 L
.164 .13851 L
.168 .13856 L
.172 .13861 L
.176 .13868 L
.18 .13875 L
.184 .13884 L
.188 .13894 L
.192 .13908 L
.196 .13923 L
.2 .13942 L
Mistroke
.204 .13965 L
.208 .13991 L
.212 .14022 L
.216 .1406 L
.22 .14104 L
.224 .14156 L
.228 .14218 L
.232 .1429 L
.236 .14374 L
.24 .14471 L
.244 .14581 L
.248 .14707 L
.252 .1485 L
.256 .15009 L
.26 .15186 L
.264 .15381 L
.268 .15594 L
.272 .15822 L
.276 .16064 L
.28 .16319 L
.284 .16584 L
.288 .16856 L
.292 .17131 L
.296 .17406 L
.3 .17677 L
.304 .17941 L
.308 .18195 L
.312 .18438 L
.316 .18669 L
.32 .18887 L
.324 .19094 L
.328 .19292 L
.332 .19484 L
.336 .19673 L
.34 .19863 L
.344 .20057 L
.348 .2026 L
.352 .20472 L
.356 .20693 L
.36 .20924 L
.364 .21161 L
.368 .21403 L
.372 .21645 L
.376 .21883 L
.38 .22114 L
.384 .22333 L
.388 .2254 L
.392 .22733 L
.396 .22913 L
.4 .23083 L
Mistroke
.404 .23243 L
.408 .23397 L
.412 .23545 L
.416 .23686 L
.42 .23819 L
.424 .23942 L
.428 .24052 L
.432 .24148 L
.436 .24228 L
.44 .24292 L
.444 .2434 L
.448 .24377 L
.452 .24407 L
.456 .24436 L
.46 .24471 L
.464 .24517 L
.468 .24576 L
.472 .2465 L
.476 .24737 L
.48 .24834 L
.484 .24935 L
.488 .25036 L
.492 .25133 L
.496 .25223 L
.5 .25304 L
.504 .25376 L
.508 .2544 L
.512 .25496 L
.516 .25546 L
.52 .25592 L
.524 .25633 L
.528 .25672 L
.532 .25709 L
.536 .25747 L
.54 .25787 L
.544 .2583 L
.548 .25878 L
.552 .2593 L
.556 .25981 L
.56 .26028 L
.564 .26066 L
.568 .26089 L
.572 .26095 L
.576 .26083 L
.58 .26057 L
.584 .26021 L
.588 .25983 L
.592 .2595 L
.596 .25924 L
.6 .25909 L
Mistroke
.604 .25903 L
.608 .259 L
.612 .25897 L
.616 .2589 L
.62 .25877 L
.624 .25858 L
.628 .25837 L
.632 .25816 L
.636 .25801 L
.64 .25793 L
.644 .25793 L
.648 .258 L
.652 .25811 L
.656 .25822 L
.66 .25833 L
.664 .2584 L
.668 .25845 L
.672 .25849 L
.676 .25851 L
.68 .25854 L
.684 .25857 L
.688 .25859 L
.692 .2586 L
.696 .25857 L
.7 .2585 L
.704 .25837 L
.708 .25818 L
.712 .25797 L
.716 .25775 L
.72 .25756 L
.724 .25744 L
.728 .25741 L
.732 .25747 L
.736 .2576 L
.74 .25775 L
.744 .25788 L
.748 .25796 L
.752 .25797 L
.756 .25793 L
.76 .25786 L
.764 .25778 L
.768 .2577 L
.772 .25764 L
.776 .25758 L
.78 .2575 L
.784 .2574 L
.788 .25729 L
.792 .25719 L
.796 .25714 L
.8 .25715 L
Mistroke
.804 .25722 L
.808 .2573 L
.812 .25736 L
.816 .25738 L
.82 .25734 L
.824 .25726 L
.828 .25718 L
.832 .2571 L
.836 .25703 L
.84 .25698 L
.844 .25693 L
.848 .2569 L
.852 .25686 L
.856 .25683 L
.86 .2568 L
.864 .25678 L
.868 .25678 L
.872 .25679 L
.876 .2568 L
.88 .25679 L
.884 .25676 L
.888 .25671 L
.892 .25666 L
.896 .25662 L
.9 .25659 L
.904 .25654 L
.908 .25647 L
.912 .25637 L
.916 .25628 L
.92 .25622 L
.924 .25622 L
.928 .25626 L
.932 .25634 L
.936 .25639 L
.94 .25641 L
.944 .25637 L
.948 .2563 L
.952 .25621 L
.956 .2561 L
.96 .25599 L
.964 .25591 L
.968 .25585 L
.972 .25586 L
.976 .2559 L
.98 .25597 L
.984 .25601 L
.988 .25602 L
.992 .25595 L
.996 .25585 L
1 .25573 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15807 L
.012 .16128 L
.016 .16224 L
.02 .16113 L
.024 .16077 L
.028 .16118 L
.032 .16125 L
.036 .16114 L
.04 .16107 L
.044 .16112 L
.048 .16111 L
.052 .16109 L
.056 .16107 L
.06 .16108 L
.064 .16106 L
.068 .16106 L
.072 .16104 L
.076 .16103 L
.08 .16102 L
.084 .16101 L
.088 .161 L
.092 .16099 L
.096 .16097 L
.1 .16096 L
.104 .16095 L
.108 .16094 L
.112 .16093 L
.116 .16092 L
.12 .16089 L
.124 .16088 L
.128 .16085 L
.132 .16084 L
.136 .16082 L
.14 .1608 L
.144 .16076 L
.148 .16073 L
.152 .16069 L
.156 .16065 L
.16 .1606 L
.164 .16055 L
.168 .16049 L
.172 .16041 L
.176 .16032 L
.18 .16022 L
.184 .16009 L
.188 .15995 L
.192 .15977 L
.196 .15957 L
.2 .15934 L
Mistroke
.204 .15905 L
.208 .15871 L
.212 .15831 L
.216 .15783 L
.22 .15726 L
.224 .1566 L
.228 .15582 L
.232 .15492 L
.236 .15387 L
.24 .15266 L
.244 .15127 L
.248 .14968 L
.252 .14789 L
.256 .14589 L
.26 .14367 L
.264 .14123 L
.268 .13858 L
.272 .13572 L
.276 .13269 L
.28 .12949 L
.284 .12618 L
.288 .12278 L
.292 .11933 L
.296 .11589 L
.3 .1125 L
.304 .10919 L
.308 .106 L
.312 .10295 L
.316 .10006 L
.32 .09732 L
.324 .09472 L
.328 .09224 L
.332 .08983 L
.336 .08745 L
.34 .08506 L
.344 .08261 L
.348 .08006 L
.352 .0774 L
.356 .07462 L
.36 .07172 L
.364 .06873 L
.368 .06569 L
.372 .06266 L
.376 .05967 L
.38 .05678 L
.384 .05402 L
.388 .05141 L
.392 .04897 L
.396 .04668 L
.4 .04453 L
Mistroke
.404 .0425 L
.408 .04057 L
.412 .03872 L
.416 .03694 L
.42 .03525 L
.424 .03368 L
.428 .03225 L
.432 .03101 L
.436 .02998 L
.44 .02916 L
.444 .02854 L
.448 .02806 L
.452 .02765 L
.456 .02726 L
.46 .02679 L
.464 .02619 L
.468 .02542 L
.472 .02446 L
.476 .02335 L
.48 .02211 L
.484 .02081 L
.488 .01951 L
.492 .01827 L
.496 .01712 L
.5 .01608 L
.504 .01516 L
.508 .01434 L
.512 .01361 L
.516 .01294 L
.52 .01233 L
.524 .01177 L
.528 .01125 L
.532 .01075 L
.536 .01025 L
.54 .00973 L
.544 .00916 L
.548 .00853 L
.552 .00786 L
.556 .00718 L
.56 .00655 L
.564 .00604 L
.568 .00571 L
.572 .0056 L
.576 .00572 L
.58 .00601 L
.584 .00643 L
.588 .00686 L
.592 .00725 L
.596 .00752 L
.6 .00767 L
Mistroke
.604 .00772 L
.608 .00772 L
.612 .00773 L
.616 .00779 L
.62 .00793 L
.624 .00814 L
.628 .00836 L
.632 .00856 L
.636 .00869 L
.64 .00874 L
.644 .0087 L
.648 .0086 L
.652 .00846 L
.656 .00831 L
.66 .00817 L
.664 .00804 L
.668 .00793 L
.672 .00782 L
.676 .00772 L
.68 .00763 L
.684 .00756 L
.688 .00751 L
.692 .0075 L
.696 .00753 L
.7 .00761 L
.704 .00773 L
.708 .00791 L
.712 .00812 L
.716 .00834 L
.72 .00852 L
.724 .00863 L
.728 .00866 L
.732 .00858 L
.736 .00841 L
.74 .0082 L
.744 .00799 L
.748 .00783 L
.752 .00776 L
.756 .00775 L
.76 .0078 L
.764 .00787 L
.768 .00793 L
.772 .008 L
.776 .00808 L
.78 .00818 L
.784 .00829 L
.788 .00838 L
.792 .00842 L
.796 .0084 L
.8 .00832 L
Mistroke
.804 .0082 L
.808 .00807 L
.812 .00798 L
.816 .00795 L
.82 .00799 L
.824 .00808 L
.828 .00818 L
.832 .00824 L
.836 .00826 L
.84 .00825 L
.844 .00824 L
.848 .00825 L
.852 .0083 L
.856 .00833 L
.86 .00834 L
.864 .00829 L
.868 .00822 L
.872 .00815 L
.876 .00811 L
.88 .00811 L
.884 .00814 L
.888 .0082 L
.892 .00826 L
.896 .00833 L
.9 .00839 L
.904 .00841 L
.908 .0084 L
.912 .00836 L
.916 .00831 L
.92 .00826 L
.924 .00825 L
.928 .00826 L
.932 .00828 L
.936 .00829 L
.94 .0083 L
.944 .00832 L
.948 .00836 L
.952 .00838 L
.956 .0084 L
.96 .00838 L
.964 .00835 L
.968 .00832 L
.972 .00833 L
.976 .00837 L
.98 .00844 L
.984 .00848 L
.988 .0085 L
.992 .00844 L
.996 .00837 L
1 .0083 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo00006goo0P00DGoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`02000IOol01000Ool00000D7oo000:Ool01000Oomoo`0027oo00H007oo
Ool007oo0003Ool00`00Oomoo`02000IOol01000Oomoo`00D7oo000;Ool2000:Ool20003Ool30003
Ool00`00Oomoo`0GOol00`00Oomoo`02Ool01000Oomoogoo0`00BGoo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2000HOol00`00Oomoo`02Ool00`00Oomoo`0200000goo001oo`18Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo0P0000=o
o`00Ool017oo10000goo0P0017oo0P001Goo0`000goo0`0017oo0P000goo1@000goo0P0017oo0P00
17oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool00`00Oomoo`020006Ool20003Ool2
00001Goo001oogoo00000Woo00<007ooOol00goo00D007ooOomoo`0000=oo`04001oogoo0002Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02Ool01P00Oomo
o`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P0047oo00@007ooOol0009oo`8000Ioo`03001oogoo009oo`800005
Ool007ooOol00002Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol0
0Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`80011oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Ool000000Woo00@0
07ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol02goo10000goo
00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomo
o`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003
Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo
009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool00`00Oomoo`0200001Goo001o
ogoo000017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001oogooOol00002Ool01000
Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`008Woo
0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0000Aoo`00Oomoo`8000Ioo`04001oogooOol5
0003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo
01=oo`03001oogoo015oo`03001oogoo009oo`8003ioo`008Woo0P004goo0P004goo00H007ooOomo
o`00Ool2000mOol0029oof<000aoo`008Woo5@000goo00@007ooOol000=oo`05001oogooOol00003
Ool02@00Oomoogoo001oo`00Ool00002Ool400000goo001oo`02Ool200001Goo00000000Ool00`00
00=oo`0000001@0000Aoo`00001oo`80009oo`800003Ool007oo00800003Ool0000000=oo`03001o
ogoo00Yoo`008Woo0P00:Goo00<007oo00002Woo00@007oo001oo`<0009oo`L00003Ool0000000X0
0004Ool00000Ool400000goo00000003000<Ool0029oo`03001oogoo02Uoo`8000Yoo`8000=oo`03
001oogoo02moo`008Woo0P00KGoo000ROol2001]Ool000]oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomo
o`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004
Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomo
o`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]o
o`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=o
o`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol0
0`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool5
0002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`80
00Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Io
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo4000FGoo000AOol2000:Ool20004Ool00`00
Oomoo`02Ool2000>Ool8001AOol002Qoo`03001oogoo01Eoo`8004moo`00:7oo00<007ooOol05Woo
0`00CGoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0HOol2
001<Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomo
o`0077oo0P00BWoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005
Ool01000Oomoo`007Goo0`00B7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool600000goo00000004Ool20003Ool30003Ool3
0004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol0
0002Ool01000Oomoo`001goo00@007ooOomoo`<00005Ool007ooOol00002Ool01@00Oomoogoo0000
0goo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomo
o`000Woo00<007ooOol01Goo00<007ooOol00Woo10000Woo00@007ooOol000=oo`03001oogoo00Eo
o`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00
Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002
Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0
1`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool0
1000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=o
o`00:7oo00<007ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002
Ool00`00Oomoo`0700000goo0000000200000goo0000000R0003Ool01000Oomoo`001Goo000XOol0
0`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001o
ogoo0002Ool20002Ool60002Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D0
00=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004
Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03
001oogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
00]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:
Ool20004Ool20002Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool0
0`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03
001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0=Woo2@000Woo
9@0037oo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo031oo`H000Uoo`80
00Moo`8002Qoo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008002eoo`D0045oo`002Woo
00@007ooOol000]oo`04001oogoo000ZOol50015Ool000Yoo`04001oogoo0007Ool40003Ool00`00
Oomoo`0VOol30019Ool000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2000UOol3001;Ool000]o
o`8000Qoo`D0009oo`03001oogoo02=oo`8004eoo`0077oo00<007ooOol03Goo0`0017oo0P002Goo
1@000Woo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo
0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`<0009oo`04
001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=o
o`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002Ool00`00
Oomoo`06Ool20004Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`04001oogoo0002
Ool00`00Oomoo`04Ool200000goo001oo`03Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`8000eo
o`@000=oo`04001oogoo0005Ool20002Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002
Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00Oomo
o`0<Ool00`00Oomoo`04Ool01000Oomoo`0017oo0P000Woo0P0017oo00@007ooOol0009oo`04001o
ogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2
000=Ool50003Ool20004Ool20004Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@00
0goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`0H
Ool2001HOol001aoo`03001oogoo01Ioo`<005Uoo`0077ooJ@0037oo000LOol01@00Oomoogoo0000
0goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000;
Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00
Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:
Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2
001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Ioo`<000=o
o`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2
001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0
LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool0
0`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000
Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@0
00=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00
Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(47428\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31712 m
.008 .3181 L
.012 .31823 L
.016 .31829 L
.02 .31815 L
.024 .318 L
.028 .31806 L
.032 .31816 L
.036 .31815 L
.04 .31812 L
.044 .31814 L
.048 .31817 L
.052 .31816 L
.056 .31814 L
.06 .31815 L
.064 .31819 L
.068 .31821 L
.072 .31819 L
.076 .31815 L
.08 .3181 L
.084 .31809 L
.088 .3181 L
.092 .3181 L
.096 .31808 L
.1 .318 L
.104 .31791 L
.108 .31782 L
.112 .31775 L
.116 .31766 L
.12 .31754 L
.124 .31735 L
.128 .31711 L
.132 .31683 L
.136 .31655 L
.14 .31624 L
.144 .31585 L
.148 .31532 L
.152 .31461 L
.156 .31375 L
.16 .31274 L
.164 .31158 L
.168 .31023 L
.172 .30861 L
.176 .3066 L
.18 .30414 L
.184 .30119 L
.188 .29772 L
.192 .29369 L
.196 .28904 L
.2 .28371 L
Mistroke
.204 .27762 L
.208 .27073 L
.212 .26302 L
.216 .25454 L
.22 .24535 L
.224 .23558 L
.228 .22538 L
.232 .21492 L
.236 .20446 L
.24 .19429 L
.244 .18473 L
.248 .17616 L
.252 .16895 L
.256 .16343 L
.26 .15988 L
.264 .15843 L
.268 .15916 L
.272 .16202 L
.276 .16686 L
.28 .17339 L
.284 .18112 L
.288 .18947 L
.292 .19772 L
.296 .20515 L
.3 .2111 L
.304 .21505 L
.308 .21673 L
.312 .21607 L
.316 .21327 L
.32 .2087 L
.324 .20302 L
.328 .19704 L
.332 .19169 L
.336 .18783 L
.34 .18623 L
.344 .18736 L
.348 .19132 L
.352 .19779 L
.356 .20613 L
.36 .21551 L
.364 .2251 L
.368 .23417 L
.372 .24212 L
.376 .24864 L
.38 .25376 L
.384 .25786 L
.388 .26158 L
.392 .26575 L
.396 .27122 L
.4 .2786 L
Mistroke
.404 .28799 L
.408 .29884 L
.412 .31002 L
.416 .32013 L
.42 .32774 L
.424 .33178 L
.428 .33167 L
.432 .3275 L
.436 .32 L
.44 .31043 L
.444 .30027 L
.448 .29102 L
.452 .28401 L
.456 .28016 L
.46 .27983 L
.464 .28262 L
.468 .28755 L
.472 .29333 L
.476 .2988 L
.48 .30323 L
.484 .30642 L
.488 .30865 L
.492 .31046 L
.496 .31233 L
.5 .31435 L
.504 .31607 L
.508 .31672 L
.512 .31563 L
.516 .31268 L
.52 .30844 L
.524 .30403 L
.528 .30086 L
.532 .3002 L
.536 .30286 L
.54 .30876 L
.544 .31687 L
.548 .32542 L
.552 .33246 L
.556 .33641 L
.56 .33649 L
.564 .33286 L
.568 .32663 L
.572 .31962 L
.576 .31394 L
.58 .31127 L
.584 .31232 L
.588 .31651 L
.592 .32226 L
.596 .32754 L
.6 .33063 L
Mistroke
.604 .33058 L
.608 .32752 L
.612 .32254 L
.616 .31734 L
.62 .31361 L
.624 .31235 L
.628 .31353 L
.632 .31621 L
.636 .31905 L
.64 .32103 L
.644 .32174 L
.648 .32136 L
.652 .32037 L
.656 .31928 L
.66 .31851 L
.664 .31833 L
.668 .31882 L
.672 .31982 L
.676 .32107 L
.68 .32235 L
.684 .32355 L
.688 .32451 L
.692 .3249 L
.696 .32416 L
.7 .32202 L
.704 .31885 L
.708 .31582 L
.712 .31427 L
.716 .31495 L
.72 .3175 L
.724 .32067 L
.728 .32308 L
.732 .32386 L
.736 .32291 L
.74 .32088 L
.744 .31875 L
.748 .31763 L
.752 .31829 L
.756 .32061 L
.76 .32341 L
.764 .32492 L
.768 .32386 L
.772 .32058 L
.776 .31691 L
.78 .3151 L
.784 .31623 L
.788 .31942 L
.792 .32266 L
.796 .32415 L
.8 .32344 L
Mistroke
.804 .32145 L
.808 .31944 L
.812 .31832 L
.816 .31835 L
.82 .31932 L
.824 .32093 L
.828 .3225 L
.832 .32311 L
.836 .32217 L
.84 .31985 L
.844 .31749 L
.848 .31681 L
.852 .31834 L
.856 .32117 L
.86 .32332 L
.864 .32326 L
.868 .32142 L
.872 .31947 L
.876 .31905 L
.88 .32036 L
.884 .32188 L
.888 .32204 L
.892 .32055 L
.896 .31857 L
.9 .3179 L
.904 .31907 L
.908 .32108 L
.912 .32241 L
.916 .32215 L
.92 .32096 L
.924 .32015 L
.928 .3203 L
.932 .32102 L
.936 .32109 L
.94 .32005 L
.944 .31881 L
.948 .31854 L
.952 .32005 L
.956 .32248 L
.96 .32376 L
.964 .32305 L
.968 .32053 L
.972 .31788 L
.976 .31743 L
.98 .31894 L
.984 .3212 L
.988 .32283 L
.992 .32212 L
.996 .32036 L
1 .31956 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14276 m
.008 .13868 L
.012 .13733 L
.016 .1388 L
.02 .1392 L
.024 .13871 L
.028 .13856 L
.032 .13876 L
.036 .13878 L
.04 .13873 L
.044 .1387 L
.048 .13874 L
.052 .13873 L
.056 .13874 L
.06 .13873 L
.064 .13874 L
.068 .13874 L
.072 .13874 L
.076 .13874 L
.08 .13875 L
.084 .13874 L
.088 .13875 L
.092 .13875 L
.096 .13876 L
.1 .13877 L
.104 .13878 L
.108 .13878 L
.112 .1388 L
.116 .13881 L
.12 .13883 L
.124 .13885 L
.128 .13888 L
.132 .1389 L
.136 .13894 L
.14 .13898 L
.144 .13903 L
.148 .13909 L
.152 .13917 L
.156 .13925 L
.16 .13936 L
.164 .13948 L
.168 .13963 L
.172 .13981 L
.176 .14002 L
.18 .14027 L
.184 .14057 L
.188 .14093 L
.192 .14136 L
.196 .14186 L
.2 .14245 L
Mistroke
.204 .14314 L
.208 .14394 L
.212 .14486 L
.216 .14593 L
.22 .14715 L
.224 .14853 L
.228 .15007 L
.232 .15179 L
.236 .15368 L
.24 .15574 L
.244 .15797 L
.248 .16035 L
.252 .16286 L
.256 .16547 L
.26 .16817 L
.264 .17091 L
.268 .17366 L
.272 .17638 L
.276 .17904 L
.28 .18162 L
.284 .18409 L
.288 .18644 L
.292 .18867 L
.296 .19078 L
.3 .19278 L
.304 .19472 L
.308 .19661 L
.312 .19851 L
.316 .20043 L
.32 .20242 L
.324 .20449 L
.328 .20666 L
.332 .20892 L
.336 .21127 L
.34 .21367 L
.344 .21609 L
.348 .21848 L
.352 .22081 L
.356 .22305 L
.36 .22516 L
.364 .22714 L
.368 .22899 L
.372 .23072 L
.376 .23235 L
.38 .23389 L
.384 .23536 L
.388 .23677 L
.392 .23811 L
.396 .23937 L
.4 .24052 L
Mistroke
.404 .24154 L
.408 .2424 L
.412 .2431 L
.416 .24364 L
.42 .24404 L
.424 .24436 L
.428 .24465 L
.432 .24498 L
.436 .24538 L
.44 .24592 L
.444 .24659 L
.448 .2474 L
.452 .24832 L
.456 .24932 L
.46 .25034 L
.464 .25134 L
.468 .25228 L
.472 .25313 L
.476 .25388 L
.48 .25454 L
.484 .25512 L
.488 .25564 L
.492 .25611 L
.496 .25654 L
.5 .25693 L
.504 .25731 L
.508 .25768 L
.512 .25807 L
.516 .25848 L
.52 .25893 L
.524 .25941 L
.528 .25992 L
.532 .2604 L
.536 .26082 L
.54 .26111 L
.544 .26125 L
.548 .26121 L
.552 .261 L
.556 .26068 L
.56 .2603 L
.564 .25993 L
.568 .25962 L
.572 .25941 L
.576 .2593 L
.58 .25926 L
.584 .25924 L
.588 .2592 L
.592 .25911 L
.596 .25896 L
.6 .25876 L
Mistroke
.604 .25856 L
.608 .25838 L
.612 .25827 L
.616 .25823 L
.62 .25826 L
.624 .25835 L
.628 .25845 L
.632 .25856 L
.636 .25866 L
.64 .25874 L
.644 .25879 L
.648 .25883 L
.652 .25886 L
.656 .25887 L
.66 .25888 L
.664 .25887 L
.668 .25885 L
.672 .25879 L
.676 .25869 L
.68 .25855 L
.684 .25837 L
.688 .25817 L
.692 .25797 L
.696 .25781 L
.7 .25771 L
.704 .2577 L
.708 .25778 L
.712 .25793 L
.716 .25809 L
.72 .25822 L
.724 .25829 L
.728 .2583 L
.732 .25824 L
.736 .25814 L
.74 .25804 L
.744 .25794 L
.748 .25786 L
.752 .25779 L
.756 .25771 L
.76 .25763 L
.764 .25754 L
.768 .25748 L
.772 .25746 L
.776 .25749 L
.78 .25756 L
.784 .25762 L
.788 .25766 L
.792 .25765 L
.796 .2576 L
.8 .25752 L
Mistroke
.804 .25743 L
.808 .25736 L
.812 .2573 L
.816 .25725 L
.82 .25721 L
.824 .25717 L
.828 .25712 L
.832 .25708 L
.836 .25706 L
.84 .25706 L
.844 .25709 L
.848 .25713 L
.852 .25714 L
.856 .25712 L
.86 .25705 L
.864 .25697 L
.868 .25689 L
.872 .25683 L
.876 .25679 L
.88 .25676 L
.884 .25671 L
.888 .25666 L
.892 .25662 L
.896 .25659 L
.9 .25659 L
.904 .2566 L
.908 .25661 L
.912 .25662 L
.916 .25662 L
.92 .25661 L
.924 .25657 L
.928 .25649 L
.932 .2564 L
.936 .25629 L
.94 .2562 L
.944 .25614 L
.948 .25613 L
.952 .25615 L
.956 .2562 L
.96 .25622 L
.964 .25624 L
.968 .25623 L
.972 .25619 L
.976 .25613 L
.98 .25604 L
.984 .25592 L
.988 .25584 L
.992 .25577 L
.996 .25579 L
1 .25583 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15926 L
.012 .16107 L
.016 .16176 L
.02 .16127 L
.024 .16096 L
.028 .16111 L
.032 .16119 L
.036 .16116 L
.04 .16109 L
.044 .16111 L
.048 .16109 L
.052 .1611 L
.056 .16107 L
.06 .16107 L
.064 .16105 L
.068 .16105 L
.072 .16103 L
.076 .16102 L
.08 .161 L
.084 .161 L
.088 .16098 L
.092 .16097 L
.096 .16094 L
.1 .16093 L
.104 .1609 L
.108 .16089 L
.112 .16086 L
.116 .16084 L
.12 .1608 L
.124 .16077 L
.128 .16072 L
.132 .16068 L
.136 .16063 L
.14 .16057 L
.144 .16049 L
.148 .16041 L
.152 .1603 L
.156 .16019 L
.16 .16005 L
.164 .15989 L
.168 .15969 L
.172 .15946 L
.176 .15918 L
.18 .15886 L
.184 .15847 L
.188 .15802 L
.192 .15748 L
.196 .15685 L
.2 .1561 L
Mistroke
.204 .15523 L
.208 .15422 L
.212 .15305 L
.216 .15171 L
.22 .15019 L
.224 .14847 L
.228 .14654 L
.232 .14439 L
.236 .14201 L
.24 .13943 L
.244 .13663 L
.248 .13365 L
.252 .13052 L
.256 .12724 L
.26 .12388 L
.264 .12045 L
.268 .11701 L
.272 .11359 L
.276 .11025 L
.28 .10702 L
.284 .10392 L
.288 .10097 L
.292 .09818 L
.296 .09554 L
.3 .09301 L
.304 .09058 L
.308 .0882 L
.312 .08582 L
.316 .0834 L
.32 .0809 L
.324 .0783 L
.328 .07557 L
.332 .07272 L
.336 .06977 L
.34 .06676 L
.344 .06373 L
.348 .06072 L
.352 .05779 L
.356 .05498 L
.36 .05231 L
.364 .04981 L
.368 .04747 L
.372 .04529 L
.376 .04323 L
.38 .04128 L
.384 .03942 L
.388 .03763 L
.392 .03593 L
.396 .03434 L
.4 .03288 L
Mistroke
.404 .03159 L
.408 .03048 L
.412 .02958 L
.416 .02886 L
.42 .02831 L
.424 .02788 L
.428 .02748 L
.432 .02706 L
.436 .02654 L
.44 .02585 L
.444 .02498 L
.448 .02394 L
.452 .02274 L
.456 .02146 L
.46 .02015 L
.464 .01887 L
.468 .01767 L
.472 .01659 L
.476 .01562 L
.48 .01476 L
.484 .014 L
.488 .01333 L
.492 .01271 L
.496 .01214 L
.5 .01161 L
.504 .0111 L
.508 .0106 L
.512 .01008 L
.516 .00953 L
.52 .00894 L
.524 .00831 L
.528 .00766 L
.532 .00703 L
.536 .00648 L
.54 .00607 L
.544 .00586 L
.548 .00586 L
.552 .00607 L
.556 .00644 L
.56 .00688 L
.564 .00731 L
.568 .00767 L
.572 .0079 L
.576 .00801 L
.58 .00803 L
.584 .00801 L
.588 .00802 L
.592 .0081 L
.596 .00825 L
.6 .00846 L
Mistroke
.604 .00869 L
.608 .00887 L
.612 .00898 L
.616 .00899 L
.62 .00891 L
.624 .00877 L
.628 .00859 L
.632 .00842 L
.636 .00828 L
.64 .00817 L
.644 .00808 L
.648 .008 L
.652 .00792 L
.656 .00785 L
.66 .00778 L
.664 .00773 L
.668 .00773 L
.672 .00778 L
.676 .00789 L
.68 .00806 L
.684 .00827 L
.688 .0085 L
.692 .0087 L
.696 .00884 L
.7 .00889 L
.704 .00884 L
.708 .0087 L
.712 .00851 L
.716 .0083 L
.72 .00813 L
.724 .00802 L
.728 .00799 L
.732 .00802 L
.736 .00808 L
.74 .00815 L
.744 .00821 L
.748 .00827 L
.752 .00834 L
.756 .00844 L
.76 .00853 L
.764 .00862 L
.768 .00865 L
.772 .00863 L
.776 .00853 L
.78 .0084 L
.784 .00826 L
.788 .00817 L
.792 .00816 L
.796 .00822 L
.8 .00833 L
Mistroke
.804 .00844 L
.808 .00851 L
.812 .00853 L
.816 .00852 L
.82 .00849 L
.824 .00848 L
.828 .00849 L
.832 .00851 L
.836 .00851 L
.84 .00849 L
.844 .00846 L
.848 .00842 L
.852 .0084 L
.856 .00839 L
.86 .0084 L
.864 .00843 L
.868 .00847 L
.872 .00852 L
.876 .00857 L
.88 .00859 L
.884 .00861 L
.888 .0086 L
.892 .0086 L
.896 .00858 L
.9 .00855 L
.904 .00851 L
.908 .00847 L
.912 .00844 L
.916 .00846 L
.92 .00852 L
.924 .0086 L
.928 .00867 L
.932 .0087 L
.936 .00866 L
.94 .00861 L
.944 .00855 L
.948 .00853 L
.952 .00854 L
.956 .00858 L
.96 .00861 L
.964 .00865 L
.968 .00867 L
.972 .00869 L
.976 .00871 L
.98 .00871 L
.984 .00867 L
.988 .00863 L
.992 .00856 L
.996 .00857 L
1 .00859 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo000067oo0`00Dgoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`02000GOol00`00Ool0001COol000Yoo`04001oogoo0008Ool01P00Oomo
o`00Ool000=oo`03001oogoo008001Ioo`05001oogooOol0001BOol000]oo`8000Yoo`8000=oo`<0
00=oo`03001oogoo01Eoo`05001oogooOol00003Ool3001<Ool000]oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`8001Eoo`03001oogoo00=oo`05001oogoo001oo`02001;Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P003Goo0`0017oo0P001Goo1@0000Aoo`00
Oomoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000=oo`D000=oo`8000Aoo`8000Aoo`D0009oo`<0
00Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`0;Ool01@00Oomoogoo00000Woo0P0000=oo`00Ool017oo00<007oo00000goo0P000Woo
00@007ooOol0009oo`03001oogoo00=oo`05001oogooOol00003Ool01000Oomoo`000Woo00D007oo
Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo00H007ooOol007oo
0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`80011oo`03001oogoo00800003Ool007oo00Ioo`04001oogooOol20002Ool0
1000Oomoo`000Woo00<007ooOol00goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009o
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2
000@Ool00`00Oomoo`0200000goo001oo`06Ool01000Oomoogoo0P000Woo00@007ooOol0009oo`03
001oogoo00=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol02goo10000goo
00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomo
o`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003
Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo
009oo`8000aoo`03001oogoo00Aoo`04001oogoo0006Ool20004Ool200001Goo001oogoo00000Woo
00<007ooOol00Woo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001oogooOol00002Ool0
1000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`00
8Woo0P0037oo1@0000=oo`00Ool00P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomo
o`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007oo
Ool04Goo00<007ooOol047oo0P000goo0`00@7oo000ROol2000@Ool2000DOol01`00Oomoogoo001o
o`00041oo`008WooH`0037oo000ROolB0002Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000=o
o`04001oogooOol20002Ool01000Oomoogoo1@0000=oo`00Ool00`0000=oo`0000000P0000Aoo`00
0000009oo`80009oo`800003Ool0000000<00004Ool00000Ool400001Goo001oo`00Ool00`0000=o
o`00Ool02goo000ROol2000WOol3000:Ool300001Goo00000000Ool00`0000Aoo`000000009oo`80
0004Ool00000Ool600000goo0000000200000goo00000004000017oo0000000037oo000ROol00`00
Oomoo`0VOol2000;Ool20003Ool00`00Oomoo`0aOol0029oo`8006eoo`008Woo0P00KGoo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P00
17oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06
001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo
0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo
06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]
Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2
001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06ao
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`00
00=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo
00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003
Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0
17oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo
000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004
Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`800003
Ool007oo06Aoo`004Goo0P002Woo0P0017oo00<007ooOol00Woo5P00Dgoo000XOol00`00Oomoo`0B
Ool3001AOol002Qoo`03001oogoo01Aoo`80051oo`002goo0P0017oo00<007ooOol00goo0P0017oo
0P000goo0`000goo00<007ooOol05Woo0P00CWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`000goo00@007ooOol001Uoo`<004aoo`000goo1@000Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol001]oo`8004]oo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`00
17oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`00
17oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool0
0`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`06001oo`00001oo`000Woo00@0
07ooOol0009oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogoo001oo`000goo00@007ooOol0
009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool0
00Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`0400001Goo001o
ogoo00000Woo00D007ooOomoo`0000Moo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007oo
Ool0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;
Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol0
1Goo00<007ooOol00Woo1`000Woo00D007ooOomoo`0000Moo`04001oogoo0002Ool00`00Oomoo`02
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001o
ogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool00`00
Oomoo`02Ool01000Oomoo`000Woo20000goo20000Woo7`000goo00@007ooOol000Eoo`00:7oo00<0
07ooOol02Goo00<007ooOol017oo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomo
o`000Woo2@000goo100000=oo`00Ool00Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo
00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`80
00Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
oed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo
00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00
:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo
00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80
009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007oo
Ool0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001o
ogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo
000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`0cOol90003Ool60002OolA0002
Ool30002Ool2000AOol000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0;Woo
1P0027oo0`001Woo0P001Goo0P002Woo0`000Woo0P0000=oo`000000100037oo0003Ool50002Ool0
1000Oomoo`002goo00<007ooOol00P00:Woo1@00A7oo000:Ool01000Oomoo`002goo00@007ooOol0
02Qoo`@004Qoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo02Aoo`8004aoo`002Woo00@0
07ooOol000Moo`03001oogoo00Aoo`8002=oo`8004ioo`002goo0P0027oo1@000Woo00<007ooOol0
8Goo0P00Cgoo000LOol00`00Oomoo`0=Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003
Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eo
o`05001oogooOol00002Ool01000Oomoo`001Woo100017oo00@007ooOol0009oo`04001oogoo0005
Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo
00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo00=oo`80009oo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`03001oogoo
009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo
10000goo00@007ooOol0009oo`8000Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001oogoo
00aoo`03001oogoo00Aoo`05001oogoo001oo`020005Ool20004Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`80
00eoo`D000=oo`800003Ool0000000Moo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol5
0003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oogoo
01Ioo`03001oogoo05Uoo`0077oo00<007ooOol04goo0`00G7oo000LOomY000<Ool001aoo`05001o
ogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2
001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol0
00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00Oomoo`02
001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo
00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool5
0002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
5Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001o
ogoo009oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool0
0`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001c
Ool000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo
00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007oo
Ool01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol0
00]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1b
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(47595\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31944 m
.008 .31874 L
.012 .31749 L
.016 .31733 L
.02 .31822 L
.024 .3184 L
.028 .31795 L
.032 .31787 L
.036 .3181 L
.04 .31816 L
.044 .31805 L
.048 .318 L
.052 .31802 L
.056 .318 L
.06 .31797 L
.064 .31796 L
.068 .31793 L
.072 .31788 L
.076 .3178 L
.08 .31772 L
.084 .31764 L
.088 .31756 L
.092 .31744 L
.096 .31727 L
.1 .31704 L
.104 .31677 L
.108 .31646 L
.112 .31613 L
.116 .31574 L
.12 .31525 L
.124 .31461 L
.128 .31382 L
.132 .31285 L
.136 .3117 L
.14 .31034 L
.144 .30871 L
.148 .30673 L
.152 .30437 L
.156 .30156 L
.16 .29825 L
.164 .29439 L
.168 .28987 L
.172 .28463 L
.176 .27861 L
.18 .27179 L
.184 .26422 L
.188 .25591 L
.192 .24692 L
.196 .23727 L
.2 .22709 L
Mistroke
.204 .21654 L
.208 .20589 L
.212 .19546 L
.216 .1856 L
.22 .17664 L
.224 .16894 L
.228 .16278 L
.232 .15845 L
.236 .15618 L
.24 .15612 L
.244 .1583 L
.248 .16258 L
.252 .16866 L
.256 .17611 L
.26 .18434 L
.264 .19271 L
.268 .20051 L
.272 .20712 L
.276 .21199 L
.28 .2147 L
.284 .21506 L
.288 .21309 L
.292 .20912 L
.296 .20371 L
.3 .19766 L
.304 .19189 L
.308 .18732 L
.312 .18477 L
.316 .18476 L
.32 .18751 L
.324 .19292 L
.328 .20058 L
.332 .20982 L
.336 .21977 L
.34 .22955 L
.344 .23837 L
.348 .24575 L
.352 .25154 L
.356 .25602 L
.36 .25983 L
.364 .26385 L
.368 .26891 L
.372 .27558 L
.376 .28403 L
.38 .29397 L
.384 .30467 L
.388 .31503 L
.392 .32378 L
.396 .3297 L
.4 .33185 L
Mistroke
.404 .32982 L
.408 .3238 L
.412 .3147 L
.416 .30401 L
.42 .29358 L
.424 .28513 L
.428 .27988 L
.432 .27828 L
.436 .28003 L
.44 .28426 L
.444 .28979 L
.448 .29551 L
.452 .30059 L
.456 .3047 L
.46 .30787 L
.464 .3103 L
.468 .31221 L
.472 .31367 L
.476 .31468 L
.48 .31508 L
.484 .3146 L
.488 .31298 L
.492 .31021 L
.496 .3067 L
.5 .30333 L
.504 .30123 L
.508 .3015 L
.512 .30487 L
.516 .31133 L
.52 .31991 L
.524 .32871 L
.528 .3355 L
.532 .33842 L
.536 .33672 L
.54 .33108 L
.544 .32337 L
.548 .31603 L
.552 .31131 L
.556 .31056 L
.56 .31371 L
.564 .31939 L
.568 .32539 L
.572 .32961 L
.576 .33078 L
.58 .32882 L
.584 .32468 L
.588 .31981 L
.592 .31568 L
.596 .31331 L
.6 .31304 L
Mistroke
.604 .31448 L
.608 .31677 L
.612 .31897 L
.616 .32047 L
.62 .32111 L
.624 .32107 L
.628 .32062 L
.632 .31995 L
.636 .31924 L
.64 .31872 L
.644 .3187 L
.648 .31939 L
.652 .32077 L
.656 .32258 L
.66 .32432 L
.664 .32541 L
.668 .3253 L
.672 .32365 L
.676 .32062 L
.68 .31704 L
.684 .31423 L
.688 .31343 L
.692 .31508 L
.696 .31849 L
.7 .3221 L
.704 .32435 L
.708 .32441 L
.712 .32253 L
.716 .3198 L
.72 .31762 L
.724 .31708 L
.728 .31856 L
.732 .32141 L
.736 .32416 L
.74 .32514 L
.744 .32346 L
.748 .31979 L
.752 .31609 L
.756 .31447 L
.76 .31587 L
.764 .31937 L
.768 .32296 L
.772 .32475 L
.776 .32414 L
.78 .32189 L
.784 .31936 L
.788 .31774 L
.792 .31763 L
.796 .31888 L
.8 .3209 L
Mistroke
.804 .32263 L
.808 .32301 L
.812 .32168 L
.816 .31927 L
.82 .31734 L
.824 .31732 L
.828 .31928 L
.832 .32188 L
.836 .32326 L
.84 .32251 L
.844 .3205 L
.848 .31894 L
.852 .31899 L
.856 .32039 L
.86 .32166 L
.864 .32171 L
.868 .32063 L
.872 .31942 L
.876 .31911 L
.88 .31966 L
.884 .32026 L
.888 .32036 L
.892 .32014 L
.896 .32038 L
.9 .32139 L
.904 .32243 L
.908 .32243 L
.912 .3209 L
.916 .31872 L
.92 .31763 L
.924 .31849 L
.928 .32077 L
.932 .32269 L
.936 .32266 L
.94 .32101 L
.944 .31917 L
.948 .31874 L
.952 .32024 L
.956 .32196 L
.96 .3223 L
.964 .32096 L
.968 .31867 L
.972 .31773 L
.976 .31925 L
.98 .32178 L
.984 .32384 L
.988 .32372 L
.992 .32092 L
.996 .31829 L
1 .31743 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14227 m
.008 .13927 L
.012 .13817 L
.016 .13908 L
.02 .13946 L
.024 .13923 L
.028 .13906 L
.032 .13916 L
.036 .13919 L
.04 .13919 L
.044 .13915 L
.048 .13918 L
.052 .13918 L
.056 .13919 L
.06 .13918 L
.064 .13919 L
.068 .13919 L
.072 .1392 L
.076 .1392 L
.08 .13922 L
.084 .13923 L
.088 .13925 L
.092 .13926 L
.096 .13928 L
.1 .1393 L
.104 .13933 L
.108 .13936 L
.112 .13941 L
.116 .13945 L
.12 .13951 L
.124 .13958 L
.128 .13967 L
.132 .13977 L
.136 .13989 L
.14 .14002 L
.144 .1402 L
.148 .1404 L
.152 .14064 L
.156 .14093 L
.16 .14128 L
.164 .14168 L
.168 .14216 L
.172 .14272 L
.176 .14338 L
.18 .14415 L
.184 .14505 L
.188 .14607 L
.192 .14724 L
.196 .14857 L
.2 .15006 L
Mistroke
.204 .15172 L
.208 .15356 L
.212 .15557 L
.216 .15774 L
.22 .16008 L
.224 .16254 L
.228 .16512 L
.232 .16778 L
.236 .1705 L
.24 .17325 L
.244 .17598 L
.248 .17867 L
.252 .18128 L
.256 .18379 L
.26 .18618 L
.264 .18845 L
.268 .19059 L
.272 .19263 L
.276 .19459 L
.28 .1965 L
.284 .19839 L
.288 .2003 L
.292 .20225 L
.296 .20428 L
.3 .20641 L
.304 .20863 L
.308 .21094 L
.312 .21331 L
.316 .21572 L
.32 .21812 L
.324 .22047 L
.328 .22275 L
.332 .22491 L
.336 .22694 L
.34 .22884 L
.344 .2306 L
.348 .23226 L
.352 .23381 L
.356 .23529 L
.36 .2367 L
.364 .23805 L
.368 .23932 L
.372 .2405 L
.376 .24156 L
.38 .24247 L
.384 .24324 L
.388 .24384 L
.392 .2443 L
.396 .24466 L
.4 .24496 L
Mistroke
.404 .24526 L
.408 .24562 L
.412 .24609 L
.416 .24669 L
.42 .24744 L
.424 .24832 L
.428 .2493 L
.432 .25033 L
.436 .25134 L
.44 .25231 L
.444 .25319 L
.448 .25398 L
.452 .25467 L
.456 .25528 L
.46 .25582 L
.464 .2563 L
.468 .25674 L
.472 .25714 L
.476 .25752 L
.48 .2579 L
.484 .25827 L
.488 .25867 L
.492 .2591 L
.496 .25956 L
.5 .26004 L
.504 .26051 L
.508 .26095 L
.512 .26129 L
.516 .2615 L
.52 .26154 L
.524 .26142 L
.528 .26115 L
.532 .26079 L
.536 .26039 L
.54 .26003 L
.544 .25976 L
.548 .25959 L
.552 .25951 L
.556 .25949 L
.56 .25948 L
.564 .25943 L
.568 .25932 L
.572 .25916 L
.576 .25895 L
.58 .25876 L
.584 .2586 L
.588 .25852 L
.592 .25852 L
.596 .25859 L
.6 .2587 L
Mistroke
.604 .25882 L
.608 .25893 L
.612 .25902 L
.616 .25907 L
.62 .25911 L
.624 .25914 L
.628 .25916 L
.632 .25918 L
.636 .25918 L
.64 .25916 L
.644 .25911 L
.648 .25902 L
.652 .25889 L
.656 .25872 L
.66 .25853 L
.664 .25834 L
.668 .25818 L
.672 .25807 L
.676 .25802 L
.68 .25805 L
.684 .25815 L
.688 .25829 L
.692 .25843 L
.696 .25854 L
.7 .25859 L
.704 .25858 L
.708 .25851 L
.712 .25841 L
.716 .2583 L
.72 .2582 L
.724 .2581 L
.728 .25802 L
.732 .25793 L
.736 .25786 L
.74 .25779 L
.744 .25776 L
.748 .25777 L
.752 .25783 L
.756 .2579 L
.76 .25795 L
.764 .25797 L
.768 .25793 L
.772 .25785 L
.776 .25775 L
.78 .25766 L
.784 .25759 L
.788 .25755 L
.792 .25752 L
.796 .2575 L
.8 .25747 L
Mistroke
.804 .25743 L
.808 .25738 L
.812 .25735 L
.816 .25735 L
.82 .25737 L
.824 .25741 L
.828 .25742 L
.832 .25739 L
.836 .25733 L
.84 .25725 L
.844 .25716 L
.848 .25709 L
.852 .25703 L
.856 .25699 L
.86 .25695 L
.864 .25693 L
.868 .25692 L
.872 .25693 L
.876 .25694 L
.88 .25694 L
.884 .25693 L
.888 .25691 L
.892 .25688 L
.896 .25683 L
.9 .25676 L
.904 .25669 L
.908 .25662 L
.912 .25656 L
.916 .25653 L
.92 .25651 L
.924 .2565 L
.928 .25649 L
.932 .25648 L
.936 .25646 L
.94 .25647 L
.944 .25646 L
.948 .25645 L
.952 .25641 L
.956 .25633 L
.96 .25623 L
.964 .25615 L
.968 .25608 L
.972 .25607 L
.976 .25608 L
.98 .25611 L
.984 .25611 L
.988 .25611 L
.992 .25608 L
.996 .25605 L
1 .25599 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16394 L
.012 .1611 L
.016 .1602 L
.02 .16124 L
.024 .16148 L
.028 .16113 L
.032 .16101 L
.036 .16115 L
.04 .16114 L
.044 .1611 L
.048 .16106 L
.052 .16108 L
.056 .16106 L
.06 .16106 L
.064 .16103 L
.068 .16102 L
.072 .16099 L
.076 .16098 L
.08 .16095 L
.084 .16094 L
.088 .16091 L
.092 .16088 L
.096 .16084 L
.1 .1608 L
.104 .16075 L
.108 .16071 L
.112 .16064 L
.116 .16058 L
.12 .16049 L
.124 .1604 L
.128 .16028 L
.132 .16015 L
.136 .15999 L
.14 .15981 L
.144 .15958 L
.148 .15932 L
.152 .15901 L
.156 .15864 L
.16 .1582 L
.164 .15769 L
.168 .15708 L
.172 .15636 L
.176 .15553 L
.18 .15456 L
.184 .15344 L
.188 .15216 L
.192 .15069 L
.196 .14902 L
.2 .14715 L
Mistroke
.204 .14507 L
.208 .14277 L
.212 .14025 L
.216 .13753 L
.22 .13462 L
.224 .13153 L
.228 .1283 L
.232 .12496 L
.236 .12155 L
.24 .11811 L
.244 .11469 L
.248 .11133 L
.252 .10806 L
.256 .10492 L
.26 .10192 L
.264 .09907 L
.268 .09637 L
.272 .0938 L
.276 .09134 L
.28 .08895 L
.284 .08658 L
.288 .08419 L
.292 .08173 L
.296 .07917 L
.3 .07649 L
.304 .0737 L
.308 .0708 L
.312 .06782 L
.316 .06479 L
.32 .06178 L
.324 .05882 L
.328 .05596 L
.332 .05324 L
.336 .05068 L
.34 .04829 L
.344 .04606 L
.348 .04397 L
.352 .04199 L
.356 .04012 L
.36 .03833 L
.364 .03662 L
.368 .03501 L
.372 .03352 L
.376 .03217 L
.38 .03099 L
.384 .03001 L
.388 .02922 L
.392 .02861 L
.396 .02814 L
.4 .02773 L
Mistroke
.404 .02732 L
.408 .02684 L
.412 .02623 L
.416 .02544 L
.42 .02448 L
.424 .02336 L
.428 .02211 L
.432 .02081 L
.436 .01951 L
.44 .01826 L
.444 .01711 L
.448 .01608 L
.452 .01519 L
.456 .0144 L
.46 .01371 L
.464 .01309 L
.468 .01252 L
.472 .01198 L
.476 .01146 L
.48 .01095 L
.484 .01043 L
.488 .0099 L
.492 .00934 L
.496 .00874 L
.5 .00812 L
.504 .00749 L
.508 .00692 L
.512 .00646 L
.516 .00616 L
.52 .00607 L
.524 .00619 L
.528 .00648 L
.532 .0069 L
.536 .00735 L
.54 .00776 L
.544 .00807 L
.548 .00825 L
.552 .00832 L
.556 .00832 L
.56 .0083 L
.564 .00833 L
.568 .00842 L
.572 .00858 L
.576 .00879 L
.58 .009 L
.584 .00916 L
.588 .00923 L
.592 .0092 L
.596 .00909 L
.6 .00892 L
Mistroke
.604 .00874 L
.608 .00856 L
.612 .00842 L
.616 .00831 L
.62 .00822 L
.624 .00816 L
.628 .0081 L
.632 .00805 L
.636 .00801 L
.64 .008 L
.644 .00802 L
.648 .00809 L
.652 .00821 L
.656 .00839 L
.66 .0086 L
.664 .00882 L
.668 .009 L
.672 .00912 L
.676 .00913 L
.68 .00904 L
.684 .00886 L
.688 .00864 L
.692 .00842 L
.696 .00825 L
.7 .00818 L
.704 .00819 L
.708 .00827 L
.712 .00837 L
.716 .00846 L
.72 .00853 L
.724 .00858 L
.728 .00862 L
.732 .00868 L
.736 .00876 L
.74 .00882 L
.744 .00886 L
.748 .00883 L
.752 .00874 L
.756 .00862 L
.76 .00849 L
.764 .00841 L
.768 .00839 L
.772 .00845 L
.776 .00856 L
.78 .00867 L
.784 .00875 L
.788 .00878 L
.792 .00877 L
.796 .00875 L
.8 .00874 L
Mistroke
.804 .00874 L
.808 .00873 L
.812 .00872 L
.816 .00869 L
.82 .00866 L
.824 .00863 L
.828 .00862 L
.832 .00863 L
.836 .00866 L
.84 .0087 L
.844 .00874 L
.848 .00877 L
.852 .00879 L
.856 .00879 L
.86 .0088 L
.864 .00881 L
.868 .00883 L
.872 .00884 L
.876 .00883 L
.88 .00878 L
.884 .00872 L
.888 .00867 L
.892 .00867 L
.896 .00871 L
.9 .00878 L
.904 .00884 L
.908 .00889 L
.912 .00891 L
.916 .0089 L
.92 .00887 L
.924 .00884 L
.928 .0088 L
.932 .00878 L
.936 .00877 L
.94 .00881 L
.944 .00886 L
.948 .00893 L
.952 .00897 L
.956 .00898 L
.96 .00894 L
.964 .00889 L
.968 .00882 L
.972 .00879 L
.976 .00878 L
.98 .00881 L
.984 .00886 L
.988 .00894 L
.992 .009 L
.996 .00907 L
1 .00907 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo00005Goo0`00EWoo000:Ool01000Oomoo`0027oo00H007ooOol0
07oo0003Ool00`00Oomoo`02000DOol01000Oomoo`00EGoo000:Ool01000Oomoo`0027oo00H007oo
Ool007oo0003Ool00`00Oomoo`02000COol20002Ool00`00Oomoo`03Ool00`00Oomoo`1=Ool000]o
o`8000Yoo`8000=oo`<000=oo`03001oogoo019oo`03001oogoo009oo`04001oogooOol3001>Ool0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`80019oo`03001oogoo00=oo`04001oogoo
0002Ool00`00Oomoo`1<Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P003Goo0`000Woo00@007oo000000=oo`<00004Ool000000004Ool20004Ool20005Ool30003Ool3
0004Ool20003Ool50003Ool20004Ool20004Ool50002Ool30004Ool20006Ool000=oo`D0009oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol02goo00H007ooOomoo`00
Ool20002Ool00`00Oomoo`05Ool20003Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogoo
Ool00003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
0Woo00<007ooOol00Woo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`04001oo`000002Ool0
0`00Oomoo`05Ool20003Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001o
ogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo0P0047oo0P0000Eoo`00Oomoo`0000Moo`03001oo`00009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol017oo00@007ooOol0
009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomo
o`0;Ool50002Ool01000Oomoo`001goo00H007oo000007oo0002Ool01000Oomoo`000Woo00<007oo
Ool00goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000aoo`05001oogooOol00002Ool01000Oomoo`001Woo0P000Woo
0`000Woo00@007ooOol0009oo`03001oogoo009oo`8000=oo`03001oogoo00Aoo`04001oogoo0002
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`00
00Ioo`04001oogoo0005Ool0029oo`8000aoo`D000=oo`8000Qoo`06001oogooOol007oo0P0017oo
0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`80
00Ioo`008Woo00<007ooOol03Woo00<007ooOol04Goo00@007ooOomoo`<004=oo`008Woo0P003Woo
0P004goo00H007ooOomoo`00Ool20012Ool0029oof<000aoo`008Woo3`0000=oo`00Ool00Woo00D0
07ooOomoo`00009oo`05001oogooOol00003Ool00`00Oomoo`030002Ool00`00Ool0000300000goo
00000002Ool20002Ool300000goo00000002Ool3000017oo000007oo0P000Woo0P0000=oo`000000
0P0000=oo`0000000Woo0P0000=oo`00Ool00P0000=oo`00000037oo000ROol2000TOol00`00Ool0
000:Ool01`00Ool007oo001oo`00009oo`L00003Ool0000000@00003Ool0000000<00004Ool00000
Ool600000goo0000000200000goo0000000=Ool0029oo`03001oogoo02Aoo`8000]oo`80009oo`03
001oogoo03Aoo`008Woo0P00KGoo000ROol2001]Ool000]oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomo
o`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`8006eoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0004
Ool01000Oomoogoo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomo
o`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]o
o`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03
001oogoo008006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool01000Oomoo`00KWoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=o
o`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo0P00KGoo000ROol0
0`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0JGoo0003Ool5
0002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`03001oogoo06Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`80
00Yoo`8000Aoo`04001oogooOol50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P00Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Io
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00Igoo000AOol2000:Ool20004Ool00`00
Oomoo`02OolC001FOol002Qoo`03001oogoo00moo`<005Aoo`00:7oo00<007ooOol04Woo0P00DWoo
000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool30003Ool00`00Oomoo`0COol2001AOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01000Oomoo`005goo
0P00Cgoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000
Oomoo`0067oo0`00CGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool0
0`00Oomoo`02000;Ool30004Ool20005Ool50004Ool20004Ool20003Ool30003Ool30004Ool20002
Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00D007ooOol007oo00@000=oo`03001oogoo00Uoo`05001oogooOol00002Ool01000
Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol0
0002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00@007ooOol0009oo`03001o
ogoo00Eoo`@00005Ool007ooOol00002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0
009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo
00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`0700001Goo001oogoo00000goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`00
0Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<0
07ooOol02Goo10000goo00@007ooOol000Moo`03001oogoo009oo`03001oogoo00P0009oo`04001o
ogooOol40003OolR0003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool0
1000Oomoo`001Woo0P0017oo00@007ooOol0009oo`03001oogoo00X0009oo`D00004Ool007oo0003
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool01000Oomo
o`001Goo000XOol00`00Oomoo`09Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20004Ool0
1000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P001Woo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7ooG@0037oo000XOol00`00Oomoo`0?Ool0
0`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool20003Ool3
0003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo
0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005
Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool0
0`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@0
00=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool0
00Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo
0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@0
07ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03
001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomo
o`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo0080
06Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04001oogoo
Ool5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001oogoo009o
o`<000=oo`03001oogoo035oo`P000=oo`H000=oo`@000=oo`8002Aoo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`0[Ool60007Ool50004Ool40003Ool400000goo0000000G
000<Ool000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02000XOol50016Ool000Yoo`04001o
ogoo000;Ool01000Oomoo`009Goo1000Bgoo000:Ool01000Oomoo`001goo10000goo00<007ooOol0
8Goo0P00Cgoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P0087oo0P00DGoo000;Ool20008
Ool50002Ool00`00Oomoo`0NOol2001BOol001aoo`03001oogoo00eoo`<000Aoo`8000Moo`03001o
o`00008000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Aoo`8000Eoo`D0
009oo`<000Aoo`8000Ioo`0077oo0P003Goo00D007ooOomoo`00009oo`04001oogoo0004Ool20003
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000
Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo
00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0@Ool0
1000Oomoo`000Woo00<007ooOol00`0017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000L
Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00@007oo000000Ioo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009o
o`03001oogoo00=oo`0077oo0P003Goo10000goo00<007ooOol00P0027oo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo10000goo00@007oo
Ool000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001o
ogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007oo
Ool000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007oo
Oomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00<0
07ooOol04goo0P00GGoo000LOol00`00Oomoo`0@Ool3001OOol001aoofT000aoo`0077oo0P000Woo
00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1b
Ool001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
2goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00D0
07ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]oo`03001oogoo008007=oo`00
2Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomo
o`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol000]oo`8000Qoo`D0009oo`03
001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo
0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000FOol30003
Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo
0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo
079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009oo`<000=oo`8007=oo`002goo
00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`002goo00<007ooOol02goo00@0
07ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo000;Ool00`00Oomoo`07Ool4
0003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03001oogoo079oo`002goo00<0
07ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(47762\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31906 m
.008 .31795 L
.012 .31763 L
.016 .31758 L
.02 .31793 L
.024 .31811 L
.028 .31794 L
.032 .31779 L
.036 .31781 L
.04 .31782 L
.044 .31775 L
.048 .31767 L
.052 .31762 L
.056 .31757 L
.06 .31746 L
.064 .31732 L
.068 .31715 L
.072 .31695 L
.076 .31671 L
.08 .31642 L
.084 .31608 L
.088 .31567 L
.092 .31516 L
.096 .31455 L
.1 .31381 L
.104 .3129 L
.108 .3118 L
.112 .31047 L
.116 .30886 L
.12 .30694 L
.124 .30465 L
.128 .30193 L
.132 .29873 L
.136 .29496 L
.14 .29055 L
.144 .28545 L
.148 .2796 L
.152 .27297 L
.156 .26557 L
.16 .25739 L
.164 .24847 L
.168 .23885 L
.172 .22867 L
.176 .2181 L
.18 .2074 L
.184 .19684 L
.188 .18673 L
.192 .17739 L
.196 .16912 L
.2 .16229 L
Mistroke
.204 .15721 L
.208 .15419 L
.212 .1534 L
.216 .15489 L
.22 .15853 L
.224 .16407 L
.228 .17109 L
.232 .17911 L
.236 .18754 L
.24 .19573 L
.244 .20299 L
.248 .2087 L
.252 .21233 L
.256 .21359 L
.26 .21246 L
.264 .20918 L
.268 .20426 L
.272 .19841 L
.276 .19247 L
.28 .18732 L
.284 .1838 L
.288 .18258 L
.292 .18408 L
.296 .18841 L
.3 .19532 L
.304 .2042 L
.308 .21422 L
.312 .22444 L
.316 .234 L
.32 .24225 L
.324 .24892 L
.328 .25414 L
.332 .25839 L
.336 .2624 L
.34 .26693 L
.344 .27268 L
.348 .28009 L
.352 .28919 L
.356 .29951 L
.36 .31013 L
.364 .31981 L
.368 .32719 L
.372 .33109 L
.376 .33078 L
.38 .32625 L
.384 .31824 L
.388 .30808 L
.392 .29741 L
.396 .28791 L
.4 .28094 L
Mistroke
.404 .27733 L
.408 .27727 L
.412 .2803 L
.416 .28554 L
.42 .29184 L
.424 .29811 L
.428 .30343 L
.432 .30734 L
.436 .30983 L
.44 .31132 L
.444 .31234 L
.448 .31323 L
.452 .314 L
.456 .31429 L
.46 .31363 L
.464 .31165 L
.468 .30845 L
.472 .30471 L
.476 .30167 L
.48 .30071 L
.484 .30283 L
.488 .30819 L
.492 .316 L
.496 .32468 L
.5 .33228 L
.504 .33702 L
.508 .33776 L
.512 .33447 L
.516 .32823 L
.52 .32091 L
.524 .31462 L
.528 .31108 L
.532 .31117 L
.536 .31467 L
.54 .32035 L
.544 .32626 L
.548 .33036 L
.552 .33129 L
.556 .32881 L
.56 .32386 L
.564 .31814 L
.568 .31347 L
.572 .31116 L
.576 .31162 L
.58 .31428 L
.584 .31784 L
.588 .32085 L
.592 .3223 L
.596 .32205 L
.6 .3207 L
Mistroke
.604 .31919 L
.608 .31825 L
.612 .31819 L
.616 .3189 L
.62 .32005 L
.624 .32131 L
.628 .32246 L
.632 .32334 L
.636 .32389 L
.64 .324 L
.644 .32347 L
.648 .32208 L
.652 .3198 L
.656 .31707 L
.66 .31478 L
.664 .31398 L
.668 .31524 L
.672 .31821 L
.676 .32166 L
.68 .32413 L
.684 .32462 L
.688 .32308 L
.692 .32044 L
.696 .31807 L
.7 .31717 L
.704 .31824 L
.708 .32073 L
.712 .32331 L
.716 .32441 L
.72 .32316 L
.724 .32001 L
.728 .31662 L
.732 .31491 L
.736 .31588 L
.74 .31895 L
.744 .3224 L
.748 .32442 L
.752 .32419 L
.756 .32219 L
.76 .31968 L
.764 .31791 L
.768 .31762 L
.772 .31875 L
.776 .32063 L
.78 .32217 L
.784 .3224 L
.788 .3211 L
.792 .31903 L
.796 .31759 L
.8 .31791 L
Mistroke
.804 .31983 L
.808 .32207 L
.812 .32305 L
.816 .32216 L
.82 .32029 L
.824 .31888 L
.828 .31884 L
.832 .31991 L
.836 .32096 L
.84 .32122 L
.844 .32076 L
.848 .32018 L
.852 .31997 L
.856 .31998 L
.86 .3198 L
.864 .31952 L
.868 .31956 L
.872 .32035 L
.876 .3216 L
.88 .32231 L
.884 .32178 L
.888 .32026 L
.892 .3189 L
.896 .31884 L
.9 .32002 L
.904 .32134 L
.908 .32154 L
.912 .32036 L
.916 .31903 L
.92 .31886 L
.924 .3202 L
.928 .32213 L
.932 .32286 L
.936 .32177 L
.94 .31975 L
.944 .31819 L
.948 .31843 L
.952 .32012 L
.956 .32156 L
.96 .32194 L
.964 .32109 L
.968 .3198 L
.972 .31973 L
.976 .32066 L
.98 .32143 L
.984 .32175 L
.988 .32059 L
.992 .31886 L
.996 .31871 L
1 .31945 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13614 m
.008 .1397 L
.012 .1408 L
.016 .13955 L
.02 .13918 L
.024 .13966 L
.028 .13976 L
.032 .13961 L
.036 .13956 L
.04 .13964 L
.044 .13964 L
.048 .13965 L
.052 .13964 L
.056 .13967 L
.06 .13967 L
.064 .13969 L
.068 .1397 L
.072 .13973 L
.076 .13976 L
.08 .1398 L
.084 .13983 L
.088 .13988 L
.092 .13993 L
.096 .14 L
.1 .14007 L
.104 .14018 L
.108 .14029 L
.112 .14043 L
.116 .14059 L
.12 .14078 L
.124 .14101 L
.128 .14129 L
.132 .14162 L
.136 .14201 L
.14 .14246 L
.144 .14301 L
.148 .14364 L
.152 .14438 L
.156 .14523 L
.16 .14622 L
.164 .14734 L
.168 .14862 L
.172 .15006 L
.176 .15167 L
.18 .15346 L
.184 .15541 L
.188 .15753 L
.192 .15981 L
.196 .16223 L
.2 .16477 L
Mistroke
.204 .16741 L
.208 .17011 L
.212 .17285 L
.216 .17559 L
.22 .17829 L
.224 .18092 L
.228 .18347 L
.232 .1859 L
.236 .18821 L
.24 .1904 L
.244 .19248 L
.248 .19447 L
.252 .19639 L
.256 .19827 L
.26 .20016 L
.264 .20209 L
.268 .20409 L
.272 .20618 L
.276 .20836 L
.28 .21063 L
.284 .21297 L
.288 .21536 L
.292 .21775 L
.296 .22012 L
.3 .22243 L
.304 .22463 L
.308 .22671 L
.312 .22866 L
.316 .23047 L
.32 .23216 L
.324 .23373 L
.328 .23523 L
.332 .23664 L
.336 .23799 L
.34 .23927 L
.344 .24047 L
.348 .24156 L
.352 .24253 L
.356 .24335 L
.36 .24402 L
.364 .24454 L
.368 .24494 L
.372 .24526 L
.376 .24555 L
.38 .24588 L
.384 .2463 L
.388 .24684 L
.392 .24752 L
.396 .24834 L
.4 .24928 L
Mistroke
.404 .25029 L
.408 .25131 L
.412 .25231 L
.416 .25324 L
.42 .25408 L
.424 .25481 L
.428 .25545 L
.432 .256 L
.436 .25648 L
.44 .25692 L
.444 .25733 L
.448 .25773 L
.452 .25811 L
.456 .25849 L
.46 .25888 L
.464 .25929 L
.468 .25971 L
.472 .26017 L
.476 .26063 L
.48 .26107 L
.484 .26145 L
.488 .26172 L
.492 .26184 L
.496 .26179 L
.5 .26159 L
.504 .26126 L
.508 .26087 L
.512 .26048 L
.516 .26015 L
.52 .25991 L
.524 .25978 L
.528 .25973 L
.532 .25973 L
.536 .25971 L
.54 .25965 L
.544 .25953 L
.548 .25936 L
.552 .25916 L
.556 .25898 L
.56 .25885 L
.564 .2588 L
.568 .25883 L
.572 .25893 L
.576 .25905 L
.58 .25919 L
.584 .25929 L
.588 .25937 L
.592 .25942 L
.596 .25944 L
.6 .25945 L
Mistroke
.604 .25946 L
.608 .25946 L
.612 .25945 L
.616 .25942 L
.62 .25935 L
.624 .25924 L
.628 .2591 L
.632 .25892 L
.636 .25872 L
.64 .25854 L
.644 .2584 L
.648 .25832 L
.652 .25832 L
.656 .25839 L
.66 .25852 L
.664 .25867 L
.668 .2588 L
.672 .25888 L
.676 .25889 L
.68 .25884 L
.684 .25874 L
.688 .25863 L
.692 .25853 L
.696 .25844 L
.7 .25836 L
.704 .25828 L
.708 .2582 L
.712 .25812 L
.716 .25806 L
.72 .25804 L
.724 .25806 L
.728 .25813 L
.732 .25821 L
.736 .25827 L
.74 .25828 L
.744 .25823 L
.748 .25812 L
.752 .258 L
.756 .25789 L
.76 .25782 L
.764 .25778 L
.768 .25778 L
.772 .25778 L
.776 .25777 L
.78 .25774 L
.784 .2577 L
.788 .25767 L
.792 .25765 L
.796 .25766 L
.8 .25767 L
Mistroke
.804 .25767 L
.808 .25764 L
.812 .25758 L
.816 .25751 L
.82 .25744 L
.824 .25737 L
.828 .25731 L
.832 .25727 L
.836 .25723 L
.84 .25721 L
.844 .2572 L
.848 .25721 L
.852 .25722 L
.856 .25723 L
.86 .25723 L
.864 .25721 L
.868 .25716 L
.872 .25709 L
.876 .257 L
.88 .25691 L
.884 .25685 L
.888 .25681 L
.892 .25681 L
.896 .25682 L
.9 .25684 L
.904 .25683 L
.908 .2568 L
.912 .25677 L
.916 .25673 L
.92 .2567 L
.924 .25665 L
.928 .2566 L
.932 .25655 L
.936 .2565 L
.94 .25647 L
.944 .25644 L
.948 .25643 L
.952 .25641 L
.956 .25639 L
.96 .25636 L
.964 .25633 L
.968 .25631 L
.972 .25631 L
.976 .25627 L
.98 .25623 L
.984 .25616 L
.988 .2561 L
.992 .25604 L
.996 .25601 L
1 .25599 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .1636 L
.012 .16132 L
.016 .16038 L
.02 .16109 L
.024 .16138 L
.028 .16119 L
.032 .16103 L
.036 .16109 L
.04 .1611 L
.044 .16109 L
.048 .16103 L
.052 .16103 L
.056 .161 L
.06 .16099 L
.064 .16094 L
.068 .16092 L
.072 .16087 L
.076 .16084 L
.08 .16078 L
.084 .16073 L
.088 .16066 L
.092 .16058 L
.096 .16048 L
.1 .16038 L
.104 .16025 L
.108 .1601 L
.112 .15992 L
.116 .15971 L
.12 .15945 L
.124 .15916 L
.128 .1588 L
.132 .15838 L
.136 .15789 L
.14 .15731 L
.144 .15662 L
.148 .15582 L
.152 .15489 L
.156 .15382 L
.16 .15258 L
.164 .15117 L
.168 .14956 L
.172 .14775 L
.176 .14574 L
.18 .14351 L
.184 .14106 L
.188 .13841 L
.192 .13555 L
.196 .13252 L
.2 .12934 L
Mistroke
.204 .12604 L
.208 .12265 L
.212 .11923 L
.216 .1158 L
.22 .11242 L
.224 .10911 L
.228 .10592 L
.232 .10287 L
.236 .09997 L
.24 .09723 L
.244 .09462 L
.248 .09212 L
.252 .08971 L
.256 .08733 L
.26 .08495 L
.264 .08252 L
.268 .08001 L
.272 .0774 L
.276 .07466 L
.28 .07181 L
.284 .06886 L
.288 .06586 L
.292 .06284 L
.296 .05985 L
.3 .05696 L
.304 .05419 L
.308 .05157 L
.312 .04912 L
.316 .04684 L
.32 .04471 L
.324 .04271 L
.328 .04082 L
.332 .03902 L
.336 .03731 L
.34 .03568 L
.344 .03416 L
.348 .03277 L
.352 .03153 L
.356 .03048 L
.36 .02962 L
.364 .02894 L
.368 .02841 L
.372 .02797 L
.376 .02757 L
.38 .02713 L
.384 .02658 L
.388 .02588 L
.392 .025 L
.396 .02394 L
.4 .02274 L
Mistroke
.404 .02146 L
.408 .02014 L
.412 .01886 L
.416 .01767 L
.42 .0166 L
.424 .01565 L
.428 .01482 L
.432 .0141 L
.436 .01346 L
.44 .01287 L
.444 .01233 L
.448 .01181 L
.452 .01131 L
.456 .01081 L
.46 .01029 L
.464 .00974 L
.468 .00915 L
.472 .00855 L
.476 .00794 L
.48 .00736 L
.484 .00687 L
.488 .00651 L
.492 .00633 L
.496 .00635 L
.5 .00656 L
.504 .00692 L
.508 .00736 L
.512 .00781 L
.516 .00819 L
.52 .00846 L
.524 .00859 L
.528 .00862 L
.532 .0086 L
.536 .00858 L
.54 .00862 L
.544 .00874 L
.548 .00892 L
.552 .00913 L
.556 .00931 L
.56 .00943 L
.564 .00946 L
.568 .00938 L
.572 .00924 L
.576 .00905 L
.58 .00886 L
.584 .0087 L
.588 .00857 L
.592 .00847 L
.596 .0084 L
.6 .00834 L
Mistroke
.604 .00829 L
.608 .00825 L
.612 .00823 L
.616 .00825 L
.62 .00831 L
.624 .00841 L
.628 .00856 L
.632 .00875 L
.636 .00895 L
.64 .00914 L
.644 .00928 L
.648 .00934 L
.652 .00931 L
.656 .00919 L
.66 .009 L
.664 .00879 L
.668 .00858 L
.672 .00844 L
.676 .00838 L
.68 .00841 L
.684 .0085 L
.688 .00862 L
.692 .00874 L
.696 .00883 L
.7 .00889 L
.704 .00893 L
.708 .00897 L
.712 .00901 L
.716 .00903 L
.72 .00903 L
.724 .00899 L
.728 .00891 L
.732 .00881 L
.736 .00871 L
.74 .00866 L
.744 .00867 L
.748 .00873 L
.752 .00882 L
.756 .00891 L
.76 .00897 L
.764 .009 L
.768 .009 L
.772 .00899 L
.776 .00899 L
.78 .00899 L
.784 .00898 L
.788 .00895 L
.792 .00891 L
.796 .00887 L
.8 .00883 L
Mistroke
.804 .00882 L
.808 .00884 L
.812 .00889 L
.816 .00896 L
.82 .00902 L
.824 .00905 L
.828 .00906 L
.832 .00905 L
.836 .00903 L
.84 .00903 L
.844 .00903 L
.848 .00903 L
.852 .00902 L
.856 .00899 L
.86 .00896 L
.864 .00893 L
.868 .00893 L
.872 .00896 L
.876 .009 L
.88 .00905 L
.884 .00909 L
.888 .00912 L
.892 .00914 L
.896 .00913 L
.9 .00911 L
.904 .00908 L
.908 .00905 L
.912 .00902 L
.916 .00903 L
.92 .00905 L
.924 .00909 L
.928 .00912 L
.932 .00915 L
.936 .00916 L
.94 .00916 L
.944 .00914 L
.948 .00911 L
.952 .00906 L
.956 .00904 L
.96 .00905 L
.964 .00912 L
.968 .0092 L
.972 .00929 L
.976 .00931 L
.98 .0093 L
.984 .00923 L
.988 .00916 L
.992 .00908 L
.996 .00906 L
1 .00905 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80019oo`8005Uoo`002Woo00@007ooOol0
00Qoo`04001oogoo0004Ool01@00Oomoogoo00004goo00<007oo0000F7oo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool00`00Oomoo`02000AOol01000Oomoo`00F7oo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02000AOol01@00Oomoogoo000017oo0P00DGoo
000;Ool2000:Ool20003Ool30003Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool20002Ool00`00Ool0
001AOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`80011oo`03001oogoo00=oo`04
001oo`000002Ool00`00Oomoo`1>Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo10000goo1@000goo100017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo
1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00]oo`03001oogoo0080009oo`04001oogoo
0006Ool20004Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomo
o`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo
00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8000moo`80009oo`04001oogoo0006Ool20004Ool01000
Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
3goo0P000Woo00@007ooOol000Ioo`8000Aoo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`000Woo
00<007ooOol017oo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0;Ool40003Ool01000Oomoo`001goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol0
009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogooOol007oo
10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo0P0037oo0P001Goo
00@007ooOol000Ioo`<000=oo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol0
17oo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07
001oogooOol007oo00001Woo00@007ooOol000Eoo`008Woo0P0037oo1@000goo0P0027oo00<007oo
00000goo0`000goo0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0
009oo`D000=oo`8000Ioo`008Woo00<007ooOol02goo0P004Woo00<007ooOol00Woo0`00AGoo000R
Ool2000;Ool2000COol01@00Oomoogoo00000Woo00<007ooOol0@goo000ROomS000<Ool0029oo`d0
00=oo`05001oogooOol00003Ool01000Oomoo`000goo00D007ooOomoo`00009oo`8000=oo`<00003
Ool00000009oo`80009oo`<00006Ool00000Ool007oo0`0000=oo`0000000`0000Aoo`00001oo`80
0004Ool000000003Ool200001goo000007oo001oo`00009oo`8000aoo`008Woo0P008Woo0P002Woo
00D007oo000007oo00<00005Ool00000001oo`0400000goo00000004000017oo000007oo5@0000=o
o`00Ool02goo000ROol00`00Oomoo`0QOol2000;Ool20003Ool00`00Oomoo`0fOol0029oo`8006eo
o`008Woo0P00KGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`80
06eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00
Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2
001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04
001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol0
0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2
000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]
Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo
1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo4000FGoo
000XOol00`00Oomoo`0=Ool3001FOol002Qoo`03001oogoo00moo`8005Eoo`002goo0P0017oo00<0
07ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol047oo0`00Dgoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol001Aoo`80059oo`000goo1@00
0Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol001Ioo`<004mo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P002goo
0`0017oo0P000goo0P000Woo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo
0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01@00Oomoogoo00000Woo00@007ooOol000=o
o`<00003Ool007oo00=oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo
00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool00`00
Oomoo`03Ool30004Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo
0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomo
o`0=Ool01000Oomoo`000Woo00<007ooOol01Goo1`0000Eoo`00Oomoo`00009oo`05001oogooOol0
0007Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomo
o`09Ool40003Ool01000Oomoo`001goo00<007ooOol00Woo200000=oo`00Ool00Woo00@007ooOomo
o`@0009oob<000=oo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`03001oogoo00Aoo`04001o
ogoo0006Ool20004Ool01000Oomoo`000Woo4`000Woo00<007oo00000goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007oo
Ool02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`80
00=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007oo
Ool03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1VOol0
00Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol0
00]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Io
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomo
o`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]o
o`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`0^
Ool60006Ool50004Ool2000]Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007oo
Ool0:7oo1`0017oo20000goo1@0000=oo`000000800037oo0003Ool50002Ool01000Oomoo`002goo
00<007ooOol00P009Goo1@00BGoo000:Ool01000Oomoo`002goo00@007ooOol0029oo`D004eoo`00
2Woo00@007ooOol000Moo`@000=oo`03001oogoo01ioo`<0055oo`002Woo00@007ooOol000Moo`03
001oogoo00Aoo`8001ioo`03001oogoo059oo`002goo0P0027oo1@000Woo00<007ooOol06goo0P00
EGoo000LOol00`00Oomoo`0=Ool30004Ool20004Ool20003Ool30004Ool20004Ool20005Ool30003
Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000eo
o`05001oogooOol00002Ool01@00Oomoo`00Ool00P001Woo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001o
ogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0
009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007ooOol0009oo`<000Moo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00D007ooOol007oo008000Uoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo
Ool017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo10000goo10002Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol000Ao
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo1000
0goo00@007ooOol000Eoo`0077oo00<007ooOol037oo00<007ooOol017oo0P0000=oo`00Ool01goo
0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool0
0006Ool01000Oomoo`001Goo000LOol2000=Ool700000goo0000000:Ool00`00Oomoo`03Ool20004
Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo
0P001Woo000LOol00`00Oomoo`0@Ool2001POol001aoo`03001oogoo00ioo`80069oo`0077ooJ@00
37oo000LOol20002Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<0
07ooOol00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Mo
o`@000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo
0P0027oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2
001cOol001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000G
Ool00`00Oomoo`02Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007oo
Ool00Woo00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo
079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`00
0goo0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool0
0`00Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]o
o`03001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007oo
Ool0LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(47929\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3165 m
.008 .31696 L
.012 .31809 L
.016 .3182 L
.02 .31735 L
.024 .31716 L
.028 .31753 L
.032 .3175 L
.036 .31715 L
.04 .31694 L
.044 .31686 L
.048 .31667 L
.052 .31637 L
.056 .31603 L
.06 .31562 L
.064 .3151 L
.068 .31448 L
.072 .31378 L
.076 .31294 L
.08 .3119 L
.084 .3106 L
.088 .30902 L
.092 .30713 L
.096 .3049 L
.1 .30229 L
.104 .2992 L
.108 .29555 L
.112 .29126 L
.116 .28627 L
.12 .28054 L
.124 .27407 L
.128 .26683 L
.132 .25881 L
.136 .25001 L
.14 .24049 L
.144 .23036 L
.148 .2198 L
.152 .20902 L
.156 .19829 L
.16 .1879 L
.164 .17816 L
.168 .16942 L
.172 .16204 L
.176 .15635 L
.18 .15263 L
.184 .15107 L
.188 .15174 L
.192 .15461 L
.196 .15948 L
.2 .16606 L
Mistroke
.204 .17389 L
.208 .1824 L
.212 .19089 L
.216 .19867 L
.22 .20504 L
.224 .20949 L
.228 .21167 L
.232 .21147 L
.236 .20904 L
.24 .20476 L
.244 .19921 L
.248 .19318 L
.252 .18752 L
.256 .18315 L
.26 .18087 L
.264 .18123 L
.268 .18448 L
.272 .19048 L
.276 .19873 L
.28 .20849 L
.284 .21889 L
.288 .22902 L
.292 .23818 L
.296 .2459 L
.3 .25206 L
.304 .25691 L
.308 .26102 L
.312 .26518 L
.316 .27019 L
.32 .27668 L
.324 .28491 L
.328 .29465 L
.332 .30517 L
.336 .31533 L
.34 .32377 L
.344 .32924 L
.348 .33083 L
.352 .32822 L
.356 .32175 L
.36 .31239 L
.364 .30159 L
.368 .29108 L
.372 .28247 L
.376 .27697 L
.38 .27519 L
.384 .27706 L
.388 .28181 L
.392 .28823 L
.396 .29499 L
.4 .301 L
Mistroke
.404 .30563 L
.408 .30879 L
.412 .31075 L
.416 .31197 L
.42 .31281 L
.424 .31344 L
.428 .31367 L
.432 .31317 L
.436 .31166 L
.44 .30918 L
.444 .30615 L
.448 .30334 L
.452 .30173 L
.456 .30226 L
.46 .30557 L
.464 .31161 L
.468 .31955 L
.472 .32786 L
.476 .33467 L
.48 .3383 L
.484 .33775 L
.488 .33315 L
.492 .3258 L
.496 .31792 L
.5 .31194 L
.504 .30964 L
.508 .31153 L
.512 .3167 L
.516 .3232 L
.52 .32873 L
.524 .33146 L
.528 .33056 L
.532 .32654 L
.536 .32092 L
.54 .31561 L
.544 .31216 L
.548 .31124 L
.552 .31259 L
.556 .31532 L
.56 .31833 L
.564 .32068 L
.568 .32182 L
.572 .32175 L
.576 .32088 L
.58 .31978 L
.584 .31893 L
.588 .31858 L
.592 .3188 L
.596 .31959 L
.6 .32089 L
Mistroke
.604 .32251 L
.608 .32405 L
.612 .32494 L
.616 .32474 L
.62 .32323 L
.624 .32064 L
.628 .31757 L
.632 .31491 L
.636 .31359 L
.64 .31421 L
.644 .31669 L
.648 .32017 L
.652 .32324 L
.656 .32467 L
.66 .32398 L
.664 .32168 L
.668 .31905 L
.672 .31743 L
.676 .31761 L
.68 .31943 L
.684 .32192 L
.688 .32372 L
.692 .32371 L
.696 .32165 L
.7 .31844 L
.704 .3157 L
.708 .31498 L
.712 .31679 L
.716 .32022 L
.72 .32344 L
.724 .3248 L
.728 .32376 L
.732 .32114 L
.736 .31847 L
.74 .31712 L
.744 .31761 L
.748 .31946 L
.752 .32155 L
.756 .3227 L
.76 .32219 L
.764 .32028 L
.768 .31806 L
.772 .31695 L
.776 .31781 L
.78 .32019 L
.784 .32264 L
.788 .3236 L
.792 .32255 L
.796 .32036 L
.8 .31854 L
Mistroke
.804 .3181 L
.808 .319 L
.812 .32029 L
.816 .32112 L
.82 .32122 L
.824 .32083 L
.828 .32033 L
.832 .31982 L
.836 .31935 L
.84 .3192 L
.844 .31964 L
.848 .32065 L
.852 .32164 L
.856 .3218 L
.86 .32094 L
.864 .31969 L
.868 .31907 L
.872 .31963 L
.876 .32081 L
.88 .32148 L
.884 .32097 L
.888 .31965 L
.892 .31873 L
.896 .31905 L
.9 .32034 L
.904 .32162 L
.908 .32183 L
.912 .32106 L
.916 .32019 L
.92 .31985 L
.924 .32018 L
.928 .3205 L
.932 .32011 L
.936 .31949 L
.94 .3193 L
.944 .31994 L
.948 .32136 L
.952 .32226 L
.956 .32183 L
.96 .32071 L
.964 .31941 L
.968 .31899 L
.972 .31992 L
.976 .32058 L
.98 .32062 L
.984 .32028 L
.988 .31946 L
.992 .31984 L
.996 .3214 L
1 .32229 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .13631 m
.008 .14001 L
.012 .14126 L
.016 .14016 L
.02 .13968 L
.024 .14005 L
.028 .14021 L
.032 .14014 L
.036 .14007 L
.04 .14014 L
.044 .14017 L
.048 .1402 L
.052 .14021 L
.056 .14026 L
.06 .14029 L
.064 .14036 L
.068 .14041 L
.072 .14049 L
.076 .14058 L
.08 .1407 L
.084 .14082 L
.088 .14098 L
.092 .14116 L
.096 .14139 L
.1 .14165 L
.104 .14197 L
.108 .14234 L
.112 .14278 L
.116 .14329 L
.12 .1439 L
.124 .14461 L
.128 .14543 L
.132 .14638 L
.136 .14746 L
.14 .14869 L
.144 .15008 L
.148 .15164 L
.152 .15337 L
.156 .15527 L
.16 .15734 L
.164 .15956 L
.168 .16194 L
.172 .16444 L
.176 .16705 L
.18 .16973 L
.184 .17245 L
.188 .17519 L
.192 .1779 L
.196 .18056 L
.2 .18313 L
Mistroke
.204 .18561 L
.208 .18796 L
.212 .19019 L
.216 .19231 L
.22 .19432 L
.224 .19626 L
.228 .19816 L
.232 .20004 L
.236 .20195 L
.24 .20392 L
.244 .20596 L
.248 .20809 L
.252 .21032 L
.256 .21263 L
.26 .215 L
.264 .2174 L
.268 .21978 L
.272 .22211 L
.276 .22434 L
.28 .22647 L
.284 .22846 L
.288 .23031 L
.292 .23204 L
.296 .23365 L
.3 .23516 L
.304 .23659 L
.308 .23795 L
.312 .23923 L
.316 .24044 L
.32 .24156 L
.324 .24256 L
.328 .24344 L
.332 .24417 L
.336 .24475 L
.34 .2452 L
.344 .24555 L
.348 .24585 L
.352 .24616 L
.356 .24653 L
.36 .24701 L
.364 .24763 L
.368 .24839 L
.372 .24927 L
.376 .25026 L
.38 .25128 L
.384 .2523 L
.388 .25327 L
.392 .25415 L
.396 .25493 L
.4 .2556 L
Mistroke
.404 .25617 L
.408 .25668 L
.412 .25712 L
.416 .25754 L
.42 .25793 L
.424 .25831 L
.428 .25869 L
.432 .25907 L
.436 .25947 L
.44 .25989 L
.444 .26033 L
.448 .26078 L
.452 .26121 L
.456 .2616 L
.46 .2619 L
.464 .26208 L
.468 .26211 L
.472 .26199 L
.476 .26172 L
.48 .26136 L
.484 .26096 L
.488 .26058 L
.492 .26028 L
.496 .26008 L
.5 .25998 L
.504 .25996 L
.508 .25997 L
.512 .25995 L
.516 .25988 L
.52 .25974 L
.524 .25956 L
.528 .25937 L
.532 .25921 L
.536 .25911 L
.54 .2591 L
.544 .25916 L
.548 .25928 L
.552 .25942 L
.556 .25955 L
.56 .25965 L
.564 .25971 L
.568 .25975 L
.572 .25976 L
.576 .25976 L
.58 .25976 L
.584 .25974 L
.588 .25971 L
.592 .25966 L
.596 .25957 L
.6 .25944 L
Mistroke
.604 .25928 L
.608 .2591 L
.612 .25892 L
.616 .25877 L
.62 .25865 L
.624 .25861 L
.628 .25864 L
.632 .25873 L
.636 .25887 L
.64 .25902 L
.644 .25914 L
.648 .2592 L
.652 .25919 L
.656 .25911 L
.66 .25899 L
.664 .25886 L
.668 .25874 L
.672 .25865 L
.676 .25858 L
.68 .25852 L
.684 .25847 L
.688 .25842 L
.692 .25838 L
.696 .25836 L
.7 .25838 L
.704 .25843 L
.708 .2585 L
.712 .25854 L
.716 .25855 L
.72 .25849 L
.724 .25839 L
.728 .25827 L
.732 .25816 L
.736 .25808 L
.74 .25804 L
.744 .25803 L
.748 .25803 L
.752 .25804 L
.756 .25803 L
.76 .25801 L
.764 .25799 L
.768 .25797 L
.772 .25796 L
.776 .25795 L
.78 .25793 L
.784 .25788 L
.788 .25782 L
.792 .25775 L
.796 .25769 L
.8 .25764 L
Mistroke
.804 .2576 L
.808 .25757 L
.812 .25754 L
.816 .25751 L
.82 .2575 L
.824 .25749 L
.828 .25749 L
.832 .25749 L
.836 .2575 L
.84 .25748 L
.844 .25744 L
.848 .25737 L
.852 .25728 L
.856 .25719 L
.86 .25712 L
.864 .25709 L
.868 .25708 L
.872 .2571 L
.876 .25711 L
.88 .25712 L
.884 .2571 L
.888 .25707 L
.892 .25703 L
.896 .25697 L
.9 .2569 L
.904 .25684 L
.908 .25678 L
.912 .25675 L
.916 .25675 L
.92 .25675 L
.924 .25676 L
.928 .25674 L
.932 .25671 L
.936 .25666 L
.94 .25661 L
.944 .25655 L
.948 .25651 L
.952 .25647 L
.956 .25645 L
.96 .25643 L
.964 .25642 L
.968 .25639 L
.972 .25637 L
.976 .25631 L
.98 .25627 L
.984 .25623 L
.988 .25621 L
.992 .2562 L
.996 .2562 L
1 .25618 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15886 L
.012 .1613 L
.016 .16195 L
.02 .16107 L
.024 .16081 L
.028 .16113 L
.032 .16114 L
.036 .16102 L
.04 .16095 L
.044 .16097 L
.048 .16092 L
.052 .16087 L
.056 .16079 L
.06 .16074 L
.064 .16066 L
.068 .16058 L
.072 .16047 L
.076 .16036 L
.08 .1602 L
.084 .16003 L
.088 .15982 L
.092 .15958 L
.096 .15929 L
.1 .15896 L
.104 .15856 L
.108 .15809 L
.112 .15752 L
.116 .15687 L
.12 .1561 L
.124 .15521 L
.128 .15418 L
.132 .15299 L
.136 .15163 L
.14 .15008 L
.144 .14834 L
.148 .14639 L
.152 .14422 L
.156 .14184 L
.16 .13925 L
.164 .13646 L
.168 .13349 L
.172 .13036 L
.176 .1271 L
.18 .12375 L
.184 .12033 L
.188 .11691 L
.192 .11351 L
.196 .11018 L
.2 .10695 L
Mistroke
.204 .10385 L
.208 .1009 L
.212 .0981 L
.216 .09544 L
.22 .0929 L
.224 .09046 L
.228 .08808 L
.232 .08571 L
.236 .08331 L
.24 .08084 L
.244 .07827 L
.248 .07559 L
.252 .07279 L
.256 .06988 L
.26 .06691 L
.264 .06391 L
.268 .06091 L
.272 .05799 L
.276 .05516 L
.28 .05249 L
.284 .04997 L
.288 .04763 L
.292 .04545 L
.296 .04342 L
.3 .04151 L
.304 .03971 L
.308 .03799 L
.312 .03635 L
.316 .03481 L
.32 .03338 L
.324 .03209 L
.328 .03098 L
.332 .03004 L
.336 .02929 L
.34 .0287 L
.344 .02823 L
.348 .02781 L
.352 .02739 L
.356 .0269 L
.36 .02627 L
.364 .02547 L
.368 .02449 L
.372 .02336 L
.376 .0221 L
.38 .02079 L
.384 .01949 L
.388 .01825 L
.392 .01712 L
.396 .01612 L
.4 .01525 L
Mistroke
.404 .01449 L
.408 .01383 L
.412 .01324 L
.416 .01269 L
.42 .01217 L
.424 .01166 L
.428 .01116 L
.432 .01064 L
.436 .01011 L
.44 .00956 L
.444 .00898 L
.448 .00839 L
.452 .00781 L
.456 .00729 L
.46 .00687 L
.464 .00661 L
.468 .00654 L
.472 .00667 L
.476 .00697 L
.48 .0074 L
.484 .00786 L
.488 .00828 L
.492 .00861 L
.496 .00881 L
.5 .0089 L
.504 .0089 L
.508 .00887 L
.512 .00887 L
.516 .00893 L
.52 .00906 L
.524 .00925 L
.528 .00945 L
.532 .0096 L
.536 .00968 L
.54 .00967 L
.544 .00956 L
.548 .00938 L
.552 .00918 L
.556 .00898 L
.56 .00883 L
.564 .00871 L
.568 .00864 L
.572 .00859 L
.576 .00855 L
.58 .00851 L
.584 .00849 L
.588 .00848 L
.592 .00852 L
.596 .0086 L
.6 .00873 L
Mistroke
.604 .0089 L
.608 .0091 L
.612 .00929 L
.616 .00945 L
.62 .00955 L
.624 .00956 L
.628 .00948 L
.632 .00933 L
.636 .00912 L
.64 .00891 L
.644 .00873 L
.648 .00863 L
.652 .00861 L
.656 .00867 L
.66 .00878 L
.664 .0089 L
.668 .00901 L
.672 .00909 L
.676 .00915 L
.68 .0092 L
.684 .00924 L
.688 .00927 L
.692 .00928 L
.696 .00925 L
.7 .00918 L
.704 .00908 L
.708 .00897 L
.712 .00889 L
.716 .00888 L
.72 .00892 L
.724 .00901 L
.728 .00912 L
.732 .0092 L
.736 .00924 L
.74 .00923 L
.744 .00921 L
.748 .00918 L
.752 .00918 L
.756 .0092 L
.76 .00921 L
.764 .0092 L
.768 .00916 L
.772 .00911 L
.776 .00906 L
.78 .00903 L
.784 .00905 L
.788 .00911 L
.792 .00919 L
.796 .00926 L
.8 .00931 L
Mistroke
.804 .00933 L
.808 .00931 L
.812 .00929 L
.816 .00926 L
.82 .00924 L
.824 .00922 L
.828 .0092 L
.832 .00918 L
.836 .00916 L
.84 .00916 L
.844 .00919 L
.848 .00923 L
.852 .00928 L
.856 .00931 L
.86 .00934 L
.864 .00935 L
.868 .00935 L
.872 .00933 L
.876 .00931 L
.88 .00929 L
.884 .00928 L
.888 .00928 L
.892 .00929 L
.896 .0093 L
.9 .00931 L
.904 .00932 L
.908 .00934 L
.912 .00936 L
.916 .00938 L
.92 .00939 L
.924 .00938 L
.928 .00935 L
.932 .00933 L
.936 .00933 L
.94 .00936 L
.944 .0094 L
.948 .00944 L
.952 .00945 L
.956 .00945 L
.96 .00943 L
.964 .00942 L
.968 .00939 L
.972 .00937 L
.976 .00934 L
.98 .00934 L
.984 .00935 L
.988 .00942 L
.992 .00949 L
.996 .00958 L
1 .0096 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80011oo`8005]oo`002Woo00@007ooOol0
00Qoo`04001oogoo0004Ool01@00Oomoogoo000047oo00<007oo0000Fgoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool00`00Oomoo`02000?Ool01000Oomoo`00FWoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02000>Ool01@00Oomoogoo000017oo0P00E7oo
000;Ool2000:Ool20003Ool30003Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`020000
0goo001oo`1BOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8000eoo`03001oogoo
00=oo`800005Ool007ooOol0001COol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo0P003Goo0`0017oo0P000goo00@007ooOomoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<0
00Aoo`8000=oo`D000=oo`8000Aoo`8000Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool20002Ool01000Oomo
o`000Woo00D007ooOomoo`0000=oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00D007ooOomoo`0000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04
001oogoo0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0037oo00D007oo
Oomoo`00009oo`04001oogoo0003Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000aoo`05001oogooOol00002
Ool01000Oomoo`0017oo00@007ooOol000Aoo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`000Woo
00<007ooOol017oo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`0:Ool50003Ool01000Oomoo`0017oo0P00
00=oo`00Ool00goo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007oo
Ool0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogooOol0
07oo10000goo00@007ooOol000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo0P002goo0P00
1Woo00@007ooOol000Eoo`<000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007oo
Ool017oo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=o
o`07001oogooOol007oo00001Woo00@007ooOol000Eoo`008Woo0P002Woo00<007oo000010000goo
0P001goo0P0017oo0`0017oo0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`80
00Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol027oo0P004goo00L007ooOomoo`00Ool0
0018Ool0029oo`8000Uoo`03001oogoo019oo`05001oogooOol00002Ool00`00Oomoo`15Ool0029o
of<000aoo`008Woo2@000goo00D007ooOomoo`0000=oo`05001oogooOol00002Ool02@00Oomoogoo
001oo`00Ool00003Ool500000goo001oo`0500001Goo00000000Ool00`0000Eoo`00000007oo0080
0005Ool00000001oo`0500000goo00000002Ool00`00Oomoo`030002Ool01@00Ool007oo00000goo
00<007ooOol02Woo000ROol2000OOol3000:Ool01000Ool007oo0`000Woo1`0000=oo`0000001000
00Aoo`00001ooaX000aoo`008Woo00<007ooOol07goo00<007ooOol02Woo0P000Woo0P00>Woo000R
Ool2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007oo
Ool0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool2
0004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P00
17oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2
001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo
0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo
000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008
Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03
001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006io
o`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`00
8Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04
001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@0
07ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0
IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
2Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qo
o`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009o
o`h005]oo`00:7oo00<007ooOol02Woo0`00FGoo000XOol00`00Oomoo`0<Ool3001GOol000]oo`80
00Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo00ioo`8005Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000AOol3001DOol0
00=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000C
Ool3001BOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo
008000]oo`<000Aoo`D000Aoo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=o
o`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`05001oogoo001o
o`020004Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007oo
Oomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo
00@007ooOomoo`<00003Ool007oo00=oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol0
1Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0
009oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`03Ool600001Goo001oogoo00000Woo
00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00
Oomoo`03Ool002Qoo`03001oogoo00Uoo`@000=oo`04001oogoo0007Ool01000Oomoogoo1P0000Eo
o`00Oomoo`0000=oo`04001oogooOol800000goo0000000N0003Ool01000Oomoo`001Goo000XOol0
0`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P0017oo00D007ooOol007oo01400003
Ool0000000<00003Ool007oo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=o
o`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qoo`03001o
ogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004Ool3
0002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM000<
Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001o
ogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001o
ogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool20002Ool5
0002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004
Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Io
o`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20003
Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00D0
07ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo
1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`002goo
0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
2goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0;7oo1@0027oo0P00=goo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo02Ioo`H000Aoo`T0009oob/000aoo`000goo
1@000Woo00@007ooOol000]oo`03001oogoo0080029oo`D004aoo`002Woo00@007ooOol000]oo`04
001oogoo000OOol5001@Ool000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0KOol3001DOol0
00Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2000KOol2001FOol000]oo`8000Qoo`D0009oo`03
001oogoo01Uoo`03001oogoo05Ioo`0077oo00<007ooOol03Goo0`0017oo0P0000=oo`0000001Woo
0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo
0`0017oo0P001Woo000LOol2000=Ool01@00Oomoogoo00000Woo00@007oo000000Uoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00
Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo011oo`03001oogoo00@0
00Uoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo00@007oo0000
009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`0077oo0P003Goo
100000Aoo`000000009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001aoo`03001o
ogoo00aoo`04001oogooOol200001Goo001oogoo000027oo0P0017oo00@007ooOol0009oo`04001o
ogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2
000=Ool50003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P00
1Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`0=Ool2001S
Ool001aoo`03001oogoo00]oo`<006Aoo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03
001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo
00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000;Ool20004
Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool01000
Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079oo`00
2Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol0
01aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Ioo`<000=oo`03001o
ogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001cOol0
01Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000F
Ool20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00Oomo
o`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomoo`00
M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=oo`03
001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomoo`07
Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(48096\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31563 m
.008 .31674 L
.012 .31714 L
.016 .31704 L
.02 .31636 L
.024 .31592 L
.028 .31587 L
.032 .31562 L
.036 .31504 L
.04 .31438 L
.044 .31374 L
.048 .31295 L
.052 .31193 L
.056 .31067 L
.06 .30914 L
.064 .30732 L
.068 .30516 L
.072 .30262 L
.076 .29964 L
.08 .29611 L
.084 .29194 L
.088 .28708 L
.092 .28149 L
.096 .27517 L
.1 .26808 L
.104 .26021 L
.108 .25154 L
.112 .24212 L
.116 .23205 L
.12 .22151 L
.124 .2107 L
.128 .19985 L
.132 .18922 L
.136 .17914 L
.14 .16994 L
.144 .162 L
.148 .15567 L
.152 .15125 L
.156 .14894 L
.16 .14885 L
.164 .15097 L
.168 .1552 L
.172 .16127 L
.176 .16878 L
.18 .17718 L
.184 .1858 L
.188 .19396 L
.192 .20098 L
.196 .2063 L
.2 .20947 L
Mistroke
.204 .21028 L
.208 .20873 L
.212 .20508 L
.216 .19986 L
.22 .19382 L
.224 .18785 L
.228 .18287 L
.232 .17972 L
.236 .17902 L
.24 .1811 L
.244 .18598 L
.248 .19337 L
.252 .20268 L
.256 .21309 L
.26 .22373 L
.264 .23372 L
.268 .24243 L
.272 .2495 L
.276 .25504 L
.28 .25949 L
.284 .26359 L
.288 .26816 L
.292 .27391 L
.296 .28127 L
.3 .29021 L
.304 .30025 L
.308 .31046 L
.312 .31965 L
.316 .32654 L
.32 .33003 L
.324 .32944 L
.328 .32469 L
.332 .31644 L
.336 .30593 L
.34 .29484 L
.344 .28491 L
.348 .27768 L
.352 .27409 L
.356 .27439 L
.36 .27805 L
.364 .28405 L
.368 .29109 L
.372 .29795 L
.376 .30369 L
.38 .30785 L
.384 .31044 L
.388 .31181 L
.392 .31241 L
.396 .31264 L
.4 .31265 L
Mistroke
.404 .3124 L
.408 .31162 L
.412 .31006 L
.416 .3077 L
.42 .30495 L
.424 .30265 L
.428 .30187 L
.432 .30355 L
.436 .30814 L
.44 .31529 L
.444 .32378 L
.448 .33174 L
.452 .33723 L
.456 .33883 L
.46 .33617 L
.464 .33009 L
.468 .32239 L
.472 .31528 L
.476 .31078 L
.48 .31005 L
.484 .31308 L
.488 .31865 L
.492 .32481 L
.496 .32955 L
.5 .33137 L
.504 .32976 L
.508 .32529 L
.512 .31939 L
.516 .31393 L
.52 .31053 L
.524 .31002 L
.528 .31216 L
.532 .31585 L
.536 .31963 L
.54 .32224 L
.544 .32303 L
.548 .32213 L
.552 .32028 L
.556 .31854 L
.56 .31774 L
.564 .31815 L
.568 .3195 L
.572 .32116 L
.576 .3226 L
.58 .32354 L
.584 .32392 L
.588 .32375 L
.592 .32299 L
.596 .32161 L
.6 .31965 L
Mistroke
.604 .31737 L
.608 .31526 L
.612 .31406 L
.616 .31441 L
.62 .3165 L
.624 .31981 L
.628 .32312 L
.632 .32506 L
.636 .3248 L
.64 .32256 L
.644 .3195 L
.648 .31719 L
.652 .31676 L
.656 .31836 L
.66 .32108 L
.664 .32339 L
.668 .32392 L
.672 .32217 L
.676 .3189 L
.68 .31579 L
.684 .31459 L
.688 .31608 L
.692 .31958 L
.696 .32328 L
.7 .32528 L
.704 .32463 L
.708 .32188 L
.712 .31862 L
.716 .31656 L
.72 .31659 L
.724 .31845 L
.728 .32096 L
.732 .32267 L
.736 .32265 L
.74 .32097 L
.744 .31866 L
.748 .31717 L
.752 .31748 L
.756 .31943 L
.76 .32182 L
.764 .32317 L
.768 .32275 L
.772 .32103 L
.776 .31921 L
.78 .31833 L
.784 .31864 L
.788 .31957 L
.792 .3204 L
.796 .32077 L
.8 .3207 L
Mistroke
.804 .3204 L
.808 .32002 L
.812 .31968 L
.816 .31961 L
.82 .31997 L
.824 .32063 L
.828 .32114 L
.832 .32101 L
.836 .32026 L
.84 .3195 L
.844 .3194 L
.848 .32012 L
.852 .32101 L
.856 .32126 L
.86 .32057 L
.864 .3195 L
.868 .31895 L
.872 .31934 L
.876 .32024 L
.88 .32093 L
.884 .32096 L
.888 .32065 L
.892 .32054 L
.896 .3207 L
.9 .3208 L
.904 .32038 L
.908 .31949 L
.912 .31898 L
.916 .31935 L
.92 .3204 L
.924 .3214 L
.928 .32141 L
.932 .32052 L
.936 .31986 L
.94 .31997 L
.944 .32083 L
.948 .32159 L
.952 .32087 L
.956 .31919 L
.96 .31798 L
.964 .31811 L
.968 .32024 L
.972 .32279 L
.976 .32347 L
.98 .32236 L
.984 .3201 L
.988 .31819 L
.992 .31858 L
.996 .32016 L
1 .32098 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14335 m
.008 .14053 L
.012 .13961 L
.016 .14072 L
.02 .14098 L
.024 .14063 L
.028 .14056 L
.032 .14077 L
.036 .14082 L
.04 .14084 L
.044 .14089 L
.048 .14101 L
.052 .1411 L
.056 .14123 L
.06 .14137 L
.064 .14156 L
.068 .14176 L
.072 .14202 L
.076 .14231 L
.08 .14267 L
.084 .14309 L
.088 .14359 L
.092 .14417 L
.096 .14485 L
.1 .14564 L
.104 .14655 L
.108 .14759 L
.112 .14878 L
.116 .15012 L
.12 .15163 L
.124 .1533 L
.128 .15515 L
.132 .15716 L
.136 .15933 L
.14 .16166 L
.144 .16412 L
.148 .16669 L
.152 .16934 L
.156 .17205 L
.16 .17479 L
.164 .17751 L
.168 .18018 L
.172 .18279 L
.176 .1853 L
.18 .18769 L
.184 .18997 L
.188 .19212 L
.192 .19417 L
.196 .19613 L
.2 .19804 L
Mistroke
.204 .19993 L
.208 .20182 L
.212 .20375 L
.216 .20576 L
.22 .20785 L
.224 .21004 L
.228 .21231 L
.232 .21466 L
.236 .21703 L
.24 .21942 L
.244 .22176 L
.248 .22403 L
.252 .2262 L
.256 .22825 L
.26 .23015 L
.264 .23192 L
.268 .23356 L
.272 .23509 L
.276 .23653 L
.28 .23789 L
.284 .23919 L
.288 .24041 L
.292 .24155 L
.296 .24259 L
.3 .24351 L
.304 .24429 L
.308 .24492 L
.312 .24542 L
.316 .24582 L
.32 .24614 L
.324 .24645 L
.328 .24679 L
.332 .24722 L
.336 .24777 L
.34 .24846 L
.344 .24929 L
.348 .25023 L
.352 .25124 L
.356 .25228 L
.36 .25327 L
.364 .2542 L
.368 .25502 L
.372 .25573 L
.376 .25634 L
.38 .25687 L
.384 .25733 L
.388 .25774 L
.392 .25813 L
.396 .25851 L
.4 .25889 L
Mistroke
.404 .25927 L
.408 .25967 L
.412 .26007 L
.416 .26049 L
.42 .26092 L
.424 .26135 L
.428 .26175 L
.432 .26208 L
.436 .26231 L
.44 .26241 L
.444 .26235 L
.448 .26214 L
.452 .26182 L
.456 .26143 L
.46 .26103 L
.464 .26068 L
.468 .26043 L
.472 .26028 L
.476 .26022 L
.48 .26021 L
.484 .26021 L
.488 .26018 L
.492 .26009 L
.496 .25994 L
.5 .25977 L
.504 .25959 L
.508 .25946 L
.512 .2594 L
.516 .25941 L
.52 .2595 L
.524 .25963 L
.528 .25978 L
.532 .25991 L
.536 .26 L
.54 .26005 L
.544 .26007 L
.548 .26007 L
.552 .26005 L
.556 .26004 L
.56 .26001 L
.564 .25996 L
.568 .25989 L
.572 .25978 L
.576 .25964 L
.58 .25947 L
.584 .25929 L
.588 .25913 L
.592 .259 L
.596 .25892 L
.6 .25892 L
Mistroke
.604 .25898 L
.608 .25909 L
.612 .25924 L
.616 .25937 L
.62 .25946 L
.624 .2595 L
.628 .25946 L
.632 .25936 L
.636 .25923 L
.64 .2591 L
.644 .25898 L
.648 .25889 L
.652 .25882 L
.656 .25877 L
.66 .25872 L
.664 .25869 L
.668 .25867 L
.672 .25867 L
.676 .25871 L
.68 .25876 L
.684 .25881 L
.688 .25883 L
.692 .2588 L
.696 .25873 L
.7 .25862 L
.704 .25851 L
.708 .25842 L
.712 .25836 L
.716 .25833 L
.72 .25833 L
.724 .25832 L
.728 .25831 L
.732 .2583 L
.736 .25827 L
.74 .25826 L
.744 .25826 L
.748 .25826 L
.752 .25825 L
.756 .25822 L
.76 .25816 L
.764 .25808 L
.768 .25799 L
.772 .25793 L
.776 .25788 L
.78 .25786 L
.784 .25786 L
.788 .25785 L
.792 .25783 L
.796 .25781 L
.8 .25779 L
Mistroke
.804 .25777 L
.808 .25776 L
.812 .25775 L
.816 .25773 L
.82 .25769 L
.824 .25763 L
.828 .25756 L
.832 .25748 L
.836 .25742 L
.84 .25738 L
.844 .25737 L
.848 .25737 L
.852 .25738 L
.856 .25738 L
.86 .25737 L
.864 .25734 L
.868 .2573 L
.872 .25725 L
.876 .25719 L
.88 .25712 L
.884 .25707 L
.888 .25703 L
.892 .25702 L
.896 .25702 L
.9 .25702 L
.904 .25702 L
.908 .257 L
.912 .25696 L
.916 .25691 L
.92 .25683 L
.924 .25677 L
.928 .25671 L
.932 .25669 L
.936 .25668 L
.94 .25669 L
.944 .25669 L
.948 .25668 L
.952 .25664 L
.956 .2566 L
.96 .25655 L
.964 .2565 L
.968 .25645 L
.972 .25641 L
.976 .25638 L
.98 .25637 L
.984 .25635 L
.988 .25634 L
.992 .25631 L
.996 .25627 L
1 .2562 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15831 L
.012 .16104 L
.016 .16198 L
.02 .16111 L
.024 .16066 L
.028 .16089 L
.032 .16093 L
.036 .16079 L
.04 .16064 L
.044 .16058 L
.048 .16046 L
.052 .16032 L
.056 .16013 L
.06 .15995 L
.064 .15971 L
.068 .15945 L
.072 .15911 L
.076 .15874 L
.08 .15827 L
.084 .15774 L
.088 .1571 L
.092 .15638 L
.096 .15552 L
.1 .15454 L
.104 .15338 L
.108 .15208 L
.112 .15058 L
.116 .1489 L
.12 .14701 L
.124 .14492 L
.128 .1426 L
.132 .14008 L
.136 .13736 L
.14 .13445 L
.144 .13137 L
.148 .12815 L
.152 .12483 L
.156 .12144 L
.16 .11801 L
.164 .11461 L
.168 .11125 L
.172 .10799 L
.176 .10484 L
.18 .10184 L
.184 .09898 L
.188 .09628 L
.192 .0937 L
.196 .09124 L
.2 .08884 L
Mistroke
.204 .08647 L
.208 .08409 L
.212 .08165 L
.216 .07913 L
.22 .0765 L
.224 .07375 L
.228 .0709 L
.232 .06795 L
.236 .06496 L
.24 .06197 L
.244 .05901 L
.248 .05615 L
.252 .05343 L
.256 .05086 L
.26 .04846 L
.264 .04622 L
.268 .04415 L
.272 .04221 L
.276 .04038 L
.28 .03865 L
.284 .03701 L
.288 .03546 L
.292 .03401 L
.296 .03268 L
.3 .0315 L
.304 .0305 L
.308 .02967 L
.312 .02901 L
.316 .02849 L
.32 .02806 L
.324 .02765 L
.328 .0272 L
.332 .02663 L
.336 .02591 L
.34 .02501 L
.344 .02394 L
.348 .02274 L
.352 .02145 L
.356 .02013 L
.36 .01886 L
.364 .01768 L
.368 .01662 L
.372 .01569 L
.376 .01489 L
.38 .01421 L
.384 .0136 L
.388 .01305 L
.392 .01253 L
.396 .01202 L
.4 .01152 L
Mistroke
.404 .01101 L
.408 .01049 L
.412 .00995 L
.416 .00939 L
.42 .00881 L
.424 .00825 L
.428 .00771 L
.432 .00726 L
.436 .00694 L
.44 .00679 L
.444 .00683 L
.448 .00705 L
.452 .00741 L
.456 .00787 L
.46 .00833 L
.464 .00873 L
.468 .00902 L
.472 .00917 L
.476 .00921 L
.48 .00917 L
.484 .00913 L
.488 .00914 L
.492 .00922 L
.496 .00937 L
.5 .00957 L
.504 .00976 L
.508 .00989 L
.512 .00992 L
.516 .00986 L
.52 .0097 L
.524 .0095 L
.528 .00929 L
.532 .00911 L
.536 .00897 L
.54 .00888 L
.544 .00882 L
.548 .00878 L
.552 .00876 L
.556 .00874 L
.56 .00873 L
.564 .00875 L
.568 .00881 L
.572 .00891 L
.576 .00906 L
.58 .00924 L
.584 .00943 L
.588 .00961 L
.592 .00973 L
.596 .00979 L
.6 .00976 L
Mistroke
.604 .00965 L
.608 .00946 L
.612 .00924 L
.616 .00904 L
.62 .00889 L
.624 .00882 L
.628 .00885 L
.632 .00894 L
.636 .00907 L
.64 .00921 L
.644 .00931 L
.648 .00939 L
.652 .00942 L
.656 .00945 L
.66 .00947 L
.664 .00948 L
.668 .00948 L
.672 .00945 L
.676 .00938 L
.68 .00928 L
.684 .00918 L
.688 .00911 L
.692 .0091 L
.696 .00916 L
.7 .00926 L
.704 .00938 L
.708 .00947 L
.712 .00951 L
.716 .0095 L
.72 .00946 L
.724 .00941 L
.728 .00939 L
.732 .00938 L
.736 .00939 L
.74 .00939 L
.744 .00938 L
.748 .00935 L
.752 .00932 L
.756 .0093 L
.76 .00931 L
.764 .00935 L
.768 .00942 L
.772 .00948 L
.776 .00953 L
.78 .00956 L
.784 .00956 L
.788 .00954 L
.792 .00951 L
.796 .00948 L
.8 .00944 L
Mistroke
.804 .0094 L
.808 .00937 L
.812 .00936 L
.816 .00938 L
.82 .00942 L
.824 .00949 L
.828 .00955 L
.832 .00959 L
.836 .00961 L
.84 .0096 L
.844 .00957 L
.848 .00953 L
.852 .0095 L
.856 .00948 L
.86 .00949 L
.864 .00951 L
.868 .00953 L
.872 .00956 L
.876 .00957 L
.88 .00958 L
.884 .00958 L
.888 .00959 L
.892 .00959 L
.896 .00959 L
.9 .00958 L
.904 .00957 L
.908 .00958 L
.912 .0096 L
.916 .00963 L
.92 .00965 L
.924 .00966 L
.928 .00964 L
.932 .00963 L
.936 .00962 L
.94 .00962 L
.944 .00962 L
.948 .00963 L
.952 .00963 L
.956 .00964 L
.96 .00965 L
.964 .00968 L
.968 .0097 L
.972 .00973 L
.976 .00972 L
.98 .00973 L
.984 .00971 L
.988 .00971 L
.992 .00969 L
.996 .00968 L
1 .00965 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000eoo`8005ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0004Ool01@00Oomoogoo00003Goo0P0000=oo`00Ool0G7oo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02000<Ool01000Oomoo`00GGoo000:Ool01000
Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02000;Ool00`00Oomoo`02Ool01000Oomo
ogoo0`00EWoo000;Ool2000:Ool20003Ool30003Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01`00
Oomoogoo001oo`0005Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P002goo00<0
07ooOol00goo00<007oo00000goo00<007ooOol0Dgoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`8000Yoo`03001oogoo00<0009oo`06001oo`00001oo`001Goo0`0017oo
0P0017oo0P001Goo0`000goo0`0017oo0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo
0P001Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo00Uoo`03001oo`0000=oo`04001oogoo0002Ool20006Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo00H007ooOol007oo0003Ool01000
Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`8000Uoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Ool00005Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
0P002Goo00<007ooOol017oo00@007ooOol0009oo`03001oo`0000Eoo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol017oo00@007ooOol0
009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomo
o`08Ool00`00Oomoo`040003Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol0009oo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogooOol007oo10000goo00@007oo
Ool000Eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo0P0027oo00D007ooOomoo`0000Ioo`04
001oogoo0002Ool20002Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001o
ogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003
Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0029oo`8000Qoo`04001oogooOol50003
Ool20004Ool20002Ool01000Ool000000Woo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ao
o`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol01Woo00<007oo
Ool04Goo00<007ooOol00Woo00<007oo0000BWoo000ROol20006Ool00`00Oomoo`0BOol01@00Oomo
ogoo00000Woo00<007ooOol0B7oo000ROomS000<Ool0029oo`L00003Ool007oo009oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000Woo00<007ooOol00`000Woo00<007ooOol00`000Woo00<007oo
Ool00`0000Eoo`00000007oo008000=oo`H00003Ool00000009oo`800004Ool00000Ool30003Ool0
0`00Oomoo`020002Ool20002Ool2000017oo0000000037oo000ROol2000MOol2000:Ool02@00Oomo
o`00Ool007oo001oo`0800000goo00000004000017oo000007oo0P0000Aoo`00001ooaH000aoo`00
8Woo00<007ooOol077oo00<007ooOol02Woo0P000goo00<007ooOol0>goo000ROol2001]Ool0029o
o`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool0
00]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol0
0goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qo
o`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo
000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo
0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000R
Ool00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo
00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`/005ioo`00:7oo
00<007ooOol027oo0`00Fgoo000XOol00`00Oomoo`0:Ool2001JOol000]oo`8000Aoo`03001oogoo
00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo00]oo`8005Uoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000?Ool2001GOol000=oo`D0009oo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000AOol2001EOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Ao
o`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=o
o`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00
Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`03001oogoo008000Ioo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo
00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`04001oogoo0002Ool40004Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomo
ogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomo
o`000Woo00@007ooOomoo`H000=oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo
10000goo00@007ooOol000Moo`L00005Ool007ooOol00002Ool01@00Oomoogoo00000goo10000goo
8P000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Io
o`8000Aoo`03001oo`0001H0009oo`<000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qo
o`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool2
0004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
OomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00mo
o`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Ao
o`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool2
0002Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000A
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001o
ogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03
Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000
Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eo
o`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0:Goo1@00A7oo000:Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo02=oo`L000=oocT000aoo`000goo1@000Woo
00@007ooOol000]oo`03001oogoo0080021oo`@004moo`002Woo00@007ooOol000]oo`04001oogoo
000MOol4001COol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`0IOol2001GOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool2000HOol2001IOol000]oo`8000Qoo`D0009oo`03001oogoo
01Ioo`03001oogoo05Uoo`0077oo00<007ooOol03Goo0`0017oo0P002Goo0`0017oo0P0017oo0P00
1Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000L
Ool2000=Ool01@00Oomoogoo00000Woo0P0000=oo`00Ool027oo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo00<007ooOol047oo10000Woo00<007ooOol01goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0?Ool300001Goo001oogoo00002Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol2000=Ool40003Ool01000Oomoo`00
2Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@0
07ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogoo
Ool007oo10000goo00@007ooOol000Eoo`0077oo00<007ooOol037oo0`0017oo00@007ooOol000Qo
o`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo
00001Woo00@007ooOol000Eoo`0077oo0P003Goo1@000goo0P002Woo00<007ooOol00goo0P0017oo
0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`80
00Ioo`0077oo00<007ooOol02Woo0`00IGoo000LOol00`00Oomoo`08Ool3001WOol001aoofT000ao
o`0077oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001aoo`03001o
ogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo079oo`002Woo00@007ooOol000]o
o`03001oogoo008007=oo`002Woo00@007ooOol000]oo`04001oogoo001dOol000Yoo`04001oogoo
0007Ool40003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2001cOol0
00]oo`8000Qoo`D0009oo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001ao
o`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000FOol30003Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`03001oogoo079o
o`005goo00<007ooOol00Woo0P00Lgoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03
001oogoo009oo`03001oogoo079oo`005Woo0P0017oo0P00Lgoo000GOol00`00Oomoo`02Ool00`00
Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol000Yoo`<000Aoo`03001oogoo009o
o`<000=oo`8007=oo`002goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo079oo`00
2goo00<007ooOol02goo00@007ooOol007Aoo`002goo00<007ooOol02goo00<007ooOol00P00Lgoo
000;Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`1bOol000Yoo`8000Uoo`03001oogoo00Aoo`03
001oogoo079oo`002goo00<007ooOol01goo1@000Woo0P00Lgoo000LOol00`00Oomoo`1bOol001ao
o`03001oogoo079oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol00001\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(48263\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .3155 m
.008 .31493 L
.012 .31343 L
.016 .31271 L
.02 .31271 L
.024 .31191 L
.028 .31038 L
.032 .30893 L
.036 .3074 L
.04 .30535 L
.044 .30281 L
.048 .2999 L
.052 .29651 L
.056 .29251 L
.06 .28781 L
.064 .28241 L
.068 .27625 L
.072 .2693 L
.076 .26155 L
.08 .253 L
.084 .2437 L
.088 .23374 L
.092 .22326 L
.096 .21244 L
.1 .20148 L
.104 .19065 L
.108 .18025 L
.112 .17064 L
.116 .16219 L
.12 .15525 L
.124 .15014 L
.128 .14708 L
.132 .14621 L
.136 .14758 L
.14 .15111 L
.144 .15662 L
.148 .16374 L
.152 .17196 L
.156 .18065 L
.16 .18912 L
.164 .19669 L
.168 .20276 L
.172 .20685 L
.176 .20863 L
.18 .20801 L
.184 .20513 L
.188 .20044 L
.192 .19461 L
.196 .18849 L
.2 .183 L
Mistroke
.204 .17898 L
.208 .17717 L
.212 .17805 L
.216 .1818 L
.22 .1883 L
.224 .19707 L
.228 .20736 L
.232 .21825 L
.236 .22883 L
.24 .23834 L
.244 .24632 L
.248 .25271 L
.252 .2578 L
.256 .26215 L
.26 .26653 L
.264 .27165 L
.268 .2781 L
.272 .2861 L
.276 .29547 L
.28 .30553 L
.284 .31523 L
.288 .32327 L
.292 .3284 L
.296 .32968 L
.3 .32675 L
.304 .31992 L
.308 .31018 L
.312 .29905 L
.316 .28828 L
.32 .27953 L
.324 .27401 L
.328 .27237 L
.332 .27451 L
.336 .27971 L
.34 .28676 L
.344 .29431 L
.348 .30115 L
.352 .30645 L
.356 .30991 L
.36 .31167 L
.364 .31226 L
.368 .31223 L
.372 .31203 L
.376 .31176 L
.38 .31125 L
.384 .31019 L
.388 .30843 L
.392 .30611 L
.396 .30379 L
.4 .30239 L
Mistroke
.404 .30289 L
.408 .30599 L
.412 .31173 L
.416 .31938 L
.42 .32753 L
.424 .3344 L
.428 .33837 L
.432 .33839 L
.436 .33443 L
.44 .32755 L
.444 .31968 L
.448 .31305 L
.452 .30952 L
.456 .31002 L
.46 .31423 L
.464 .32065 L
.468 .32702 L
.472 .33116 L
.476 .33169 L
.48 .32851 L
.484 .3228 L
.488 .31649 L
.492 .31156 L
.496 .30938 L
.5 .31023 L
.504 .31337 L
.508 .31736 L
.512 .32073 L
.516 .32254 L
.52 .32264 L
.524 .32153 L
.528 .31998 L
.532 .31874 L
.536 .31827 L
.54 .31868 L
.544 .31977 L
.548 .32118 L
.552 .32254 L
.556 .32361 L
.56 .32417 L
.564 .324 L
.568 .32288 L
.572 .3208 L
.576 .31811 L
.58 .3155 L
.584 .31382 L
.588 .31372 L
.592 .31537 L
.596 .31833 L
.6 .32163 L
Mistroke
.604 .32412 L
.608 .32485 L
.612 .32362 L
.616 .3211 L
.62 .31856 L
.624 .31723 L
.628 .3177 L
.632 .31959 L
.636 .32177 L
.64 .32299 L
.644 .32248 L
.648 .32037 L
.652 .31764 L
.656 .3157 L
.66 .31566 L
.664 .31771 L
.668 .32091 L
.672 .32368 L
.676 .32461 L
.68 .3233 L
.684 .32055 L
.688 .31791 L
.692 .31673 L
.696 .31745 L
.7 .31944 L
.704 .32144 L
.708 .3223 L
.712 .32158 L
.716 .31977 L
.72 .31799 L
.724 .31736 L
.728 .31837 L
.732 .32048 L
.736 .32246 L
.74 .32312 L
.744 .32206 L
.748 .32003 L
.752 .31831 L
.756 .31787 L
.76 .31878 L
.764 .32021 L
.768 .32119 L
.772 .32122 L
.776 .32047 L
.78 .31953 L
.784 .31897 L
.788 .31904 L
.792 .31973 L
.796 .32071 L
.8 .3215 L
Mistroke
.804 .32163 L
.808 .32089 L
.812 .31968 L
.816 .31876 L
.82 .31877 L
.824 .31972 L
.828 .32089 L
.832 .32141 L
.836 .32098 L
.84 .32002 L
.844 .31932 L
.848 .31926 L
.852 .31968 L
.856 .32015 L
.86 .32041 L
.864 .32061 L
.868 .3209 L
.872 .32108 L
.876 .32082 L
.88 .32005 L
.884 .31919 L
.888 .31901 L
.892 .3197 L
.896 .32069 L
.9 .32115 L
.904 .32062 L
.908 .31971 L
.912 .31953 L
.916 .32031 L
.92 .32148 L
.924 .32187 L
.928 .32066 L
.932 .31884 L
.936 .31794 L
.94 .31862 L
.944 .3207 L
.948 .32238 L
.952 .32222 L
.956 .32086 L
.96 .31943 L
.964 .31914 L
.968 .32042 L
.972 .32148 L
.976 .32098 L
.98 .31954 L
.984 .31798 L
.988 .31793 L
.992 .32032 L
.996 .3227 L
1 .32345 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14561 m
.008 .14146 L
.012 .14002 L
.016 .14141 L
.02 .14195 L
.024 .14164 L
.028 .14154 L
.032 .14182 L
.036 .14203 L
.04 .1422 L
.044 .14239 L
.048 .1427 L
.052 .14303 L
.056 .14344 L
.06 .14389 L
.064 .14446 L
.068 .1451 L
.072 .14586 L
.076 .14673 L
.08 .14773 L
.084 .14887 L
.088 .15017 L
.092 .15163 L
.096 .15325 L
.1 .15504 L
.104 .157 L
.108 .15912 L
.112 .1614 L
.116 .16381 L
.12 .16635 L
.124 .16897 L
.128 .17166 L
.132 .17438 L
.136 .17711 L
.14 .1798 L
.144 .18243 L
.148 .18497 L
.152 .18741 L
.156 .18972 L
.16 .19192 L
.164 .194 L
.168 .196 L
.172 .19792 L
.176 .19981 L
.18 .20169 L
.184 .20361 L
.188 .20558 L
.192 .20763 L
.196 .20977 L
.2 .21201 L
Mistroke
.204 .21432 L
.208 .21668 L
.212 .21905 L
.216 .22141 L
.22 .22371 L
.224 .22592 L
.228 .22801 L
.232 .22996 L
.236 .23177 L
.24 .23345 L
.244 .23501 L
.248 .23648 L
.252 .23785 L
.256 .23916 L
.26 .24039 L
.264 .24154 L
.268 .2426 L
.272 .24356 L
.276 .24439 L
.28 .24508 L
.284 .24564 L
.288 .24608 L
.292 .24643 L
.296 .24673 L
.3 .24705 L
.304 .24744 L
.308 .24794 L
.312 .24857 L
.316 .24934 L
.32 .25023 L
.324 .25121 L
.328 .25224 L
.332 .25325 L
.336 .25422 L
.34 .25509 L
.344 .25585 L
.348 .2565 L
.352 .25706 L
.356 .25753 L
.36 .25795 L
.364 .25834 L
.368 .25871 L
.372 .25909 L
.376 .25947 L
.38 .25986 L
.384 .26026 L
.388 .26067 L
.392 .26108 L
.396 .2615 L
.4 .2619 L
Mistroke
.404 .26225 L
.408 .26251 L
.412 .26266 L
.416 .26267 L
.42 .26253 L
.424 .26226 L
.428 .2619 L
.432 .2615 L
.436 .26112 L
.44 .2608 L
.444 .26059 L
.448 .26048 L
.452 .26045 L
.456 .26046 L
.46 .26046 L
.464 .26042 L
.468 .26031 L
.472 .26015 L
.476 .25997 L
.48 .25981 L
.484 .25971 L
.488 .25969 L
.492 .25975 L
.496 .25986 L
.5 .26001 L
.504 .26015 L
.508 .26026 L
.512 .26033 L
.516 .26037 L
.52 .26037 L
.524 .26036 L
.528 .26034 L
.532 .26032 L
.536 .26027 L
.54 .26021 L
.544 .26011 L
.548 .25998 L
.552 .25983 L
.556 .25966 L
.56 .25949 L
.564 .25935 L
.568 .25925 L
.572 .25921 L
.576 .25924 L
.58 .25933 L
.584 .25946 L
.588 .2596 L
.592 .25972 L
.596 .25978 L
.6 .25978 L
Mistroke
.604 .25971 L
.608 .25959 L
.612 .25945 L
.616 .25932 L
.62 .25921 L
.624 .25913 L
.628 .25907 L
.632 .25903 L
.636 .259 L
.64 .25898 L
.644 .25897 L
.648 .25898 L
.652 .25902 L
.656 .25906 L
.66 .25911 L
.664 .25911 L
.668 .25908 L
.672 .25899 L
.676 .25887 L
.68 .25875 L
.684 .25866 L
.688 .25861 L
.692 .2586 L
.696 .25861 L
.7 .25862 L
.704 .25862 L
.708 .2586 L
.712 .25857 L
.716 .25854 L
.72 .25853 L
.724 .25852 L
.728 .25851 L
.732 .25849 L
.736 .25843 L
.74 .25836 L
.744 .25827 L
.748 .2582 L
.752 .25814 L
.756 .25812 L
.76 .25811 L
.764 .25812 L
.768 .25812 L
.772 .25812 L
.776 .2581 L
.78 .25808 L
.784 .25805 L
.788 .25802 L
.792 .25798 L
.796 .25793 L
.8 .25787 L
Mistroke
.804 .25781 L
.808 .25775 L
.812 .25771 L
.816 .25769 L
.82 .25768 L
.824 .25767 L
.828 .25767 L
.832 .25765 L
.836 .25763 L
.84 .25759 L
.844 .25756 L
.848 .25751 L
.852 .25746 L
.856 .25742 L
.86 .25737 L
.864 .25734 L
.868 .25731 L
.872 .25729 L
.876 .25729 L
.88 .25728 L
.884 .25726 L
.888 .25722 L
.892 .25717 L
.896 .25711 L
.9 .25706 L
.904 .25701 L
.908 .25698 L
.912 .25697 L
.916 .25696 L
.92 .25695 L
.924 .25694 L
.928 .25691 L
.932 .25688 L
.936 .25684 L
.94 .2568 L
.944 .25673 L
.948 .25668 L
.952 .25663 L
.956 .25661 L
.96 .25659 L
.964 .2566 L
.968 .25659 L
.972 .25656 L
.976 .25652 L
.98 .25648 L
.984 .25643 L
.988 .25641 L
.992 .25637 L
.996 .25634 L
1 .25631 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16285 L
.012 .16084 L
.016 .16017 L
.02 .16079 L
.024 .16075 L
.028 .16032 L
.032 .16005 L
.036 .15993 L
.04 .15965 L
.044 .15931 L
.048 .15891 L
.052 .1585 L
.056 .15797 L
.06 .15737 L
.064 .15665 L
.068 .15584 L
.072 .15487 L
.076 .15378 L
.08 .15251 L
.084 .15108 L
.088 .14944 L
.092 .14763 L
.096 .14559 L
.1 .14335 L
.104 .14089 L
.108 .13823 L
.112 .13538 L
.116 .13236 L
.12 .12919 L
.124 .12591 L
.128 .12253 L
.132 .11912 L
.136 .1157 L
.14 .11233 L
.144 .10904 L
.148 .10586 L
.152 .10281 L
.156 .0999 L
.16 .09714 L
.164 .09452 L
.168 .09201 L
.172 .0896 L
.176 .08722 L
.18 .08486 L
.184 .08245 L
.188 .07997 L
.192 .07738 L
.196 .07469 L
.2 .07188 L
Mistroke
.204 .06898 L
.208 .06601 L
.212 .06302 L
.216 .06006 L
.22 .05717 L
.224 .05439 L
.228 .05176 L
.232 .0493 L
.236 .04701 L
.24 .04488 L
.244 .04291 L
.248 .04106 L
.252 .03932 L
.256 .03767 L
.26 .0361 L
.264 .03463 L
.268 .03327 L
.272 .03205 L
.276 .03098 L
.28 .03009 L
.284 .02937 L
.288 .02879 L
.292 .02832 L
.296 .0279 L
.3 .02746 L
.304 .02695 L
.308 .02631 L
.312 .0255 L
.316 .02451 L
.32 .02336 L
.324 .0221 L
.328 .02079 L
.332 .01948 L
.336 .01825 L
.34 .01713 L
.344 .01615 L
.348 .01531 L
.352 .01459 L
.356 .01397 L
.36 .0134 L
.364 .01288 L
.368 .01238 L
.372 .01188 L
.376 .01137 L
.38 .01086 L
.384 .01033 L
.388 .00978 L
.392 .00923 L
.396 .00867 L
.4 .00814 L
Mistroke
.404 .00767 L
.408 .0073 L
.412 .00708 L
.416 .00703 L
.42 .00717 L
.424 .00747 L
.428 .00789 L
.432 .00836 L
.436 .0088 L
.44 .00916 L
.444 .00939 L
.448 .00948 L
.452 .00948 L
.456 .00944 L
.46 .0094 L
.464 .00943 L
.468 .00953 L
.472 .00969 L
.476 .00987 L
.48 .01004 L
.484 .01013 L
.488 .01013 L
.492 .01003 L
.496 .00985 L
.5 .00963 L
.504 .00941 L
.508 .00923 L
.512 .0091 L
.516 .00903 L
.52 .009 L
.524 .00899 L
.528 .00899 L
.532 .00899 L
.536 .009 L
.54 .00903 L
.544 .00911 L
.548 .00923 L
.552 .00939 L
.556 .00957 L
.56 .00976 L
.564 .00991 L
.568 .01 L
.572 .01001 L
.576 .00994 L
.58 .00979 L
.584 .00959 L
.588 .00937 L
.592 .00919 L
.596 .00907 L
.6 .00904 L
Mistroke
.604 .0091 L
.608 .00922 L
.612 .00936 L
.616 .0095 L
.62 .0096 L
.624 .00967 L
.628 .0097 L
.632 .0097 L
.636 .0097 L
.64 .00969 L
.644 .00967 L
.648 .00963 L
.652 .00956 L
.656 .00947 L
.66 .00939 L
.664 .00935 L
.668 .00936 L
.672 .00943 L
.676 .00953 L
.68 .00964 L
.684 .00971 L
.688 .00974 L
.692 .00973 L
.696 .00969 L
.7 .00965 L
.704 .00962 L
.708 .00961 L
.712 .0096 L
.716 .0096 L
.72 .00958 L
.724 .00955 L
.728 .00954 L
.732 .00955 L
.736 .00958 L
.74 .00964 L
.744 .0097 L
.748 .00974 L
.752 .00977 L
.756 .00977 L
.76 .00975 L
.764 .00973 L
.768 .00972 L
.772 .0097 L
.776 .00968 L
.78 .00965 L
.784 .00962 L
.788 .0096 L
.792 .0096 L
.796 .00964 L
.8 .00971 L
Mistroke
.804 .00978 L
.808 .00985 L
.812 .00987 L
.816 .00986 L
.82 .00982 L
.824 .00976 L
.828 .0097 L
.832 .00968 L
.836 .00968 L
.84 .00971 L
.844 .00976 L
.848 .0098 L
.852 .00983 L
.856 .00985 L
.86 .00985 L
.864 .00984 L
.868 .00982 L
.872 .0098 L
.876 .00978 L
.88 .00977 L
.884 .00979 L
.888 .00983 L
.892 .00987 L
.896 .0099 L
.9 .00991 L
.904 .0099 L
.908 .00987 L
.912 .00984 L
.916 .00983 L
.92 .00982 L
.924 .00984 L
.928 .00986 L
.932 .0099 L
.936 .00993 L
.94 .00995 L
.944 .00995 L
.948 .00994 L
.952 .00992 L
.956 .00991 L
.96 .00989 L
.964 .0099 L
.968 .00991 L
.972 .00993 L
.976 .00994 L
.98 .00997 L
.984 .00997 L
.988 .00998 L
.992 .00997 L
.996 .00998 L
1 .00997 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Yoo`<0061oo`002Woo00@007ooOol0
00Qoo`04001oogoo0004Ool01@00Oomoogoo00002Woo0P0000=oo`000000Ggoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool00`00Oomoo`020009Ool01@00Oomoogoo0000Ggoo000:Ool0
1000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`020009Ool01@00Oomoogoo000017oo
0P00FGoo000;Ool2000:Ool20003Ool30003Ool00`00Oomoo`07Ool00`00Oomoo`03Ool01000Oomo
o`000Woo00<007ooOol0EWoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool20008Ool0
0`00Oomoo`03Ool30003Ool00`00Oomoo`1FOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P0027oo00<007ooOol00Woo10000goo0P001goo0`0017oo0P0017oo0P001Goo
0`000goo0`0017oo0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool5
0002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo009oo`05001oogooOol00002Ool01000Ool000001goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`05001oogooOol00002Ool0
1000Oomoo`000Woo00@007ooOol0009oo`03001oogoo009oo`06001oogoo001oo`000goo00@007oo
Ool0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool20007Ool00`00Oomoo`06Ool01@00Oomoo`00Ool00P001goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Ioo`03
001oogoo00Moo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol01Goo00<0
07ooOol00goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Goo00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yo
o`8000Aoo`03001oogoo009oo`8000Ioo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo0080
00Eoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007oo
Ool0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol0
07oo00001Woo00@007ooOol000Eoo`008Woo0P001Goo00<007ooOol017oo1@000goo0P000Woo00<0
07ooOol00goo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Ao
o`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol00goo00<007ooOol04Woo
00L007ooOomoo`00Ool0001=Ool0029oo`8000=oo`8001Aoo`05001oogooOol00002Ool00`00Oomo
o`1:Ool0029oof<000aoo`008Woo1@000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
0`00Oomoo`0200000goo00000003Ool60002Ool300000goo0000000500000goo00000003000017oo
000007oo1@0000Aoo`00001oo`80009oo`800003Ool007oo0080009oo`80009oo`<00006Ool007oo
001oo`0037oo000ROol2000JOol3000:Ool01000Ool007oo0`000Woo1`000Woo0P0000Aoo`00001o
o`T00003Ool0000001H000aoo`008Woo00<007ooOol06Woo00<007ooOol02Goo0`000Woo0P00?goo
000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<0
07ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo
0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogoo
Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P00
0goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eo
o`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol0
06ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06ao
o`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo
00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007oo
Ool0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Io
o`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo
009oo`T0061oo`00:7oo00<007ooOol01Goo0`00GWoo000XOol00`00Oomoo`07Ool2001MOol000]o
o`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo00Uoo`8005]oo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo000<Ool3001I
Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo
000>Ool3001GOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo008000]oo`<00003Ool0000000<000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80
009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`@0
00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomoogoo
00000Woo00<007oo00000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001oogoo00eoo`05001oogoo001oo`030006
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo
0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol00goo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomo
o`0=Ool01000Oomoo`000Woo1`0000=oo`00Ool00goo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo
0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol0
0`00Oomoo`09Ool40003Ool01000Oomoo`001Goo20000Woo00@007ooOol0009oo`05001oogooOol0
0003Ool40003Ool00`00Oomoo`0O0003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool00`00
Oomoo`04Ool01000Oomoo`001Woo0P000goo7@0000=oo`00Ool00Woo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol0
2Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=o
o`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol0
3goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`00
2Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1VOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]o
o`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`00
0Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`80
00Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P00
0goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`0WOol4
0017Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol087oo1`000goo?000
37oo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P007Goo1@00DGoo000:Ool01000Oomo
o`002goo00@007ooOol001Yoo`@005Ioo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo01Io
o`<005Uoo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8001Eoo`8005aoo`002goo0P0027oo
1@000Woo00<007ooOol04goo0P00GGoo000LOol00`00Oomoo`0=Ool3000017oo000007oo0P002Goo
0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo
0`0017oo0P001Woo000LOol2000=Ool01000Oomoogoo0P0000Eoo`00Oomoo`0000Uoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00
Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo00ioo`<0009oo`04001o
ogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04
001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Io
o`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo00eoo`800005
Ool007ooOol00002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool0
01aoo`8000eoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol00`00
Oomoo`0:Ool30006Ool01000Oomoo`0027oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool2
0003Ool00`00Oomoo`04Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool0
1000Oomoo`0017oo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000LOol2000:Ool20000
0goo000000030003Ool2000:Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo
0P001Woo0`0017oo0P0017oo0P001Woo0`000Woo1@000goo0P001Woo000LOol00`00Oomoo`08Ool2
001XOol001aoo`03001oogoo00Eoo`<006Yoo`0077ooJ@0037oo000LOol01@00Oomoogoo00000goo
00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001cOol001ao
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000;Ool2
0004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo000:Ool0
1000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Ioo`<000=oo`03
001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool2001c
Ool001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo
000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<007ooOol0
LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;Ool00`00
Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool01000Oomo
o`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Moo`@000=o
o`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool00`00Oomo
o`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(48430\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .30758 m
.008 .30525 L
.012 .303 L
.016 .30089 L
.02 .29898 L
.024 .29612 L
.028 .29212 L
.032 .28761 L
.036 .28265 L
.04 .27684 L
.044 .27008 L
.048 .2625 L
.052 .25418 L
.056 .24508 L
.06 .23527 L
.064 .22487 L
.068 .21406 L
.072 .20304 L
.076 .19204 L
.08 .18141 L
.084 .17146 L
.088 .16256 L
.092 .15506 L
.096 .14927 L
.1 .14545 L
.104 .1438 L
.108 .1444 L
.112 .14724 L
.116 .15215 L
.12 .15882 L
.124 .16677 L
.128 .17542 L
.132 .18409 L
.136 .19213 L
.14 .1989 L
.144 .20386 L
.148 .20661 L
.152 .20694 L
.156 .2049 L
.16 .20085 L
.164 .19536 L
.168 .18924 L
.172 .18337 L
.176 .17864 L
.18 .17584 L
.184 .17556 L
.188 .17814 L
.192 .1836 L
.196 .1916 L
.2 .20151 L
Mistroke
.204 .21245 L
.208 .2235 L
.212 .2338 L
.216 .24277 L
.22 .25011 L
.224 .25594 L
.228 .26066 L
.232 .26496 L
.236 .2696 L
.24 .27529 L
.244 .28246 L
.248 .29115 L
.252 .30088 L
.256 .31072 L
.26 .31948 L
.264 .32589 L
.268 .32888 L
.272 .32783 L
.276 .32274 L
.28 .31425 L
.284 .30356 L
.288 .29231 L
.292 .28222 L
.296 .27484 L
.3 .27119 L
.304 .2716 L
.308 .27565 L
.312 .2823 L
.316 .29018 L
.32 .29787 L
.324 .30428 L
.328 .30878 L
.332 .31135 L
.336 .31234 L
.34 .31234 L
.344 .31189 L
.348 .31132 L
.352 .31069 L
.356 .30985 L
.36 .30856 L
.364 .30681 L
.368 .30484 L
.372 .3033 L
.376 .303 L
.38 .30472 L
.384 .30891 L
.388 .31538 L
.392 .32323 L
.396 .33092 L
.4 .3367 L
Mistroke
.404 .3391 L
.408 .33742 L
.412 .33205 L
.416 .3244 L
.42 .31664 L
.424 .31097 L
.428 .30898 L
.432 .31107 L
.436 .31636 L
.44 .32297 L
.444 .32866 L
.448 .33157 L
.452 .33079 L
.456 .32664 L
.46 .32055 L
.464 .31446 L
.468 .31018 L
.472 .30875 L
.476 .31026 L
.48 .31387 L
.484 .31817 L
.488 .32171 L
.492 .3235 L
.496 .32331 L
.5 .32168 L
.504 .31959 L
.508 .31804 L
.512 .31764 L
.516 .31852 L
.52 .32028 L
.524 .32225 L
.528 .32376 L
.532 .32436 L
.536 .32397 L
.54 .32277 L
.544 .32105 L
.548 .31905 L
.552 .31701 L
.556 .31526 L
.56 .31427 L
.564 .31446 L
.568 .31602 L
.572 .31867 L
.576 .32171 L
.58 .32413 L
.584 .32502 L
.588 .32399 L
.592 .32147 L
.596 .3186 L
.6 .31677 L
Mistroke
.604 .31686 L
.608 .31874 L
.612 .32129 L
.616 .32303 L
.62 .32288 L
.624 .32077 L
.628 .31772 L
.632 .31534 L
.636 .31502 L
.64 .31714 L
.644 .32079 L
.648 .32417 L
.652 .32554 L
.656 .32417 L
.66 .32083 L
.664 .31732 L
.668 .31545 L
.672 .31607 L
.676 .31861 L
.68 .32151 L
.684 .32315 L
.688 .3227 L
.692 .32056 L
.696 .31804 L
.7 .31668 L
.704 .31729 L
.708 .31955 L
.712 .32214 L
.716 .32357 L
.72 .32302 L
.724 .32093 L
.728 .31856 L
.732 .31726 L
.736 .31757 L
.74 .31904 L
.744 .32063 L
.748 .32147 L
.752 .32128 L
.756 .32039 L
.76 .31943 L
.764 .31893 L
.768 .31915 L
.772 .31992 L
.776 .32083 L
.78 .32133 L
.784 .32111 L
.788 .3203 L
.792 .31942 L
.796 .31905 L
.8 .31936 L
Mistroke
.804 .32 L
.808 .32045 L
.812 .32043 L
.816 .32012 L
.82 .3199 L
.824 .31995 L
.828 .32012 L
.832 .32017 L
.836 .32009 L
.84 .32008 L
.844 .3203 L
.848 .32054 L
.852 .32051 L
.856 .3201 L
.86 .31963 L
.864 .31961 L
.868 .32009 L
.872 .32059 L
.876 .32057 L
.88 .31991 L
.884 .3193 L
.888 .31951 L
.892 .32053 L
.896 .32157 L
.9 .32164 L
.904 .32041 L
.908 .3189 L
.912 .31835 L
.916 .31915 L
.92 .32077 L
.924 .32174 L
.928 .32128 L
.932 .32019 L
.936 .3194 L
.94 .31965 L
.944 .32076 L
.948 .32125 L
.952 .32055 L
.956 .31939 L
.96 .31856 L
.964 .31903 L
.968 .32072 L
.972 .3218 L
.976 .32167 L
.98 .32082 L
.984 .31955 L
.988 .31947 L
.992 .32059 L
.996 .32099 L
1 .32067 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14098 m
.008 .14312 L
.012 .14381 L
.016 .14314 L
.02 .14315 L
.024 .14375 L
.028 .1441 L
.032 .1444 L
.036 .14487 L
.04 .14553 L
.044 .14621 L
.048 .14703 L
.052 .14796 L
.056 .14906 L
.06 .15029 L
.064 .15169 L
.068 .15325 L
.072 .15498 L
.076 .15688 L
.08 .15895 L
.084 .16116 L
.088 .16354 L
.092 .16602 L
.096 .16862 L
.1 .17128 L
.104 .17399 L
.108 .17671 L
.112 .17942 L
.116 .18207 L
.12 .18464 L
.124 .18711 L
.128 .18946 L
.132 .1917 L
.136 .19383 L
.14 .19585 L
.144 .1978 L
.148 .19969 L
.152 .20157 L
.156 .20346 L
.16 .20541 L
.164 .20742 L
.168 .20953 L
.172 .21172 L
.176 .214 L
.18 .21633 L
.184 .2187 L
.188 .22106 L
.192 .22338 L
.196 .22562 L
.2 .22775 L
Mistroke
.204 .22976 L
.208 .23162 L
.212 .23334 L
.216 .23494 L
.22 .23642 L
.224 .23781 L
.228 .23912 L
.232 .24036 L
.236 .24152 L
.24 .24261 L
.244 .2436 L
.248 .24447 L
.252 .24521 L
.256 .24582 L
.26 .24631 L
.264 .24669 L
.268 .24702 L
.272 .24733 L
.276 .24769 L
.28 .24813 L
.284 .2487 L
.288 .2494 L
.292 .25024 L
.296 .25119 L
.3 .2522 L
.304 .25323 L
.308 .25422 L
.312 .25514 L
.316 .25595 L
.32 .25664 L
.324 .25723 L
.328 .25773 L
.332 .25816 L
.336 .25855 L
.34 .25893 L
.344 .25929 L
.348 .25967 L
.352 .26005 L
.356 .26044 L
.36 .26084 L
.364 .26125 L
.368 .26166 L
.372 .26206 L
.376 .26242 L
.38 .26271 L
.384 .2629 L
.388 .26297 L
.392 .26289 L
.396 .26268 L
.4 .26236 L
Mistroke
.404 .26197 L
.408 .26157 L
.412 .26121 L
.416 .26094 L
.42 .26078 L
.424 .26071 L
.428 .2607 L
.432 .26072 L
.436 .26071 L
.44 .26065 L
.444 .26053 L
.448 .26036 L
.452 .26019 L
.456 .26006 L
.46 .25999 L
.464 .26 L
.468 .26009 L
.472 .26022 L
.476 .26038 L
.48 .26051 L
.484 .26062 L
.488 .26067 L
.492 .26069 L
.496 .26067 L
.5 .26064 L
.504 .26061 L
.508 .26056 L
.512 .26051 L
.516 .26044 L
.52 .26033 L
.524 .26019 L
.528 .26003 L
.532 .25985 L
.536 .2597 L
.54 .25958 L
.544 .25951 L
.548 .25951 L
.552 .25958 L
.556 .25969 L
.56 .25983 L
.564 .25995 L
.568 .26005 L
.572 .26008 L
.576 .26005 L
.58 .25995 L
.584 .25982 L
.588 .25967 L
.592 .25954 L
.596 .25944 L
.6 .25937 L
Mistroke
.604 .25933 L
.608 .25931 L
.612 .25929 L
.616 .25928 L
.62 .25928 L
.624 .25929 L
.628 .25932 L
.632 .25936 L
.636 .25939 L
.64 .25938 L
.644 .25933 L
.648 .25924 L
.652 .25912 L
.656 .259 L
.66 .25892 L
.664 .25888 L
.668 .25887 L
.672 .25889 L
.676 .25891 L
.68 .25891 L
.684 .25889 L
.688 .25886 L
.692 .25884 L
.696 .25882 L
.7 .2588 L
.704 .25878 L
.708 .25874 L
.712 .25868 L
.716 .25861 L
.72 .25853 L
.724 .25847 L
.728 .25843 L
.732 .25841 L
.736 .2584 L
.74 .2584 L
.744 .25839 L
.748 .25839 L
.752 .25838 L
.756 .25836 L
.76 .25834 L
.764 .25831 L
.768 .25826 L
.772 .2582 L
.776 .25812 L
.78 .25805 L
.784 .258 L
.788 .25797 L
.792 .25797 L
.796 .25798 L
.8 .25799 L
Mistroke
.804 .25798 L
.808 .25795 L
.812 .2579 L
.816 .25785 L
.82 .2578 L
.824 .25775 L
.828 .25772 L
.832 .25769 L
.836 .25767 L
.84 .25764 L
.844 .25762 L
.848 .25759 L
.852 .25757 L
.856 .25754 L
.86 .25751 L
.864 .25747 L
.868 .25742 L
.872 .25738 L
.876 .25734 L
.88 .25731 L
.884 .25729 L
.888 .25728 L
.892 .25726 L
.896 .25723 L
.9 .2572 L
.904 .25717 L
.908 .25713 L
.912 .2571 L
.916 .25706 L
.92 .25701 L
.924 .25697 L
.928 .25693 L
.932 .25691 L
.936 .25688 L
.94 .25687 L
.944 .25684 L
.948 .25682 L
.952 .25679 L
.956 .25677 L
.96 .25673 L
.964 .25671 L
.968 .25666 L
.972 .25662 L
.976 .25657 L
.98 .25653 L
.984 .2565 L
.988 .25648 L
.992 .25646 L
.996 .25644 L
1 .2564 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16396 L
.012 .16052 L
.016 .15896 L
.02 .15952 L
.024 .15938 L
.028 .15854 L
.032 .15774 L
.036 .15713 L
.04 .15633 L
.044 .15537 L
.048 .15425 L
.052 .15304 L
.056 .15163 L
.06 .15006 L
.064 .14826 L
.068 .1463 L
.072 .1441 L
.076 .14171 L
.08 .13911 L
.084 .13632 L
.088 .13334 L
.092 .13023 L
.096 .12697 L
.1 .12363 L
.104 .12023 L
.108 .11682 L
.112 .11343 L
.116 .11011 L
.12 .10689 L
.124 .10379 L
.128 .10083 L
.132 .09802 L
.136 .09535 L
.14 .09281 L
.144 .09036 L
.148 .08798 L
.152 .08562 L
.156 .08323 L
.16 .08078 L
.164 .07825 L
.168 .07561 L
.172 .07285 L
.176 .06999 L
.18 .06706 L
.184 .06408 L
.188 .06111 L
.192 .05819 L
.196 .05537 L
.2 .05269 L
Mistroke
.204 .05016 L
.208 .04781 L
.212 .04564 L
.216 .04362 L
.22 .04174 L
.224 .03998 L
.228 .03832 L
.232 .03674 L
.236 .03525 L
.24 .03387 L
.244 .03261 L
.248 .0315 L
.252 .03054 L
.256 .02974 L
.26 .0291 L
.264 .02859 L
.268 .02815 L
.272 .02773 L
.276 .02726 L
.28 .02668 L
.284 .02594 L
.288 .02503 L
.292 .02395 L
.296 .02274 L
.3 .02144 L
.304 .02013 L
.308 .01886 L
.312 .01769 L
.316 .01664 L
.32 .01574 L
.324 .01497 L
.328 .01432 L
.332 .01375 L
.336 .01323 L
.34 .01274 L
.344 .01224 L
.348 .01174 L
.352 .01123 L
.356 .0107 L
.36 .01016 L
.364 .00962 L
.368 .00908 L
.372 .00855 L
.376 .00808 L
.38 .00768 L
.384 .0074 L
.388 .00727 L
.392 .00733 L
.396 .00755 L
.4 .00792 L
Mistroke
.404 .00838 L
.408 .00884 L
.412 .00926 L
.416 .00956 L
.42 .00973 L
.424 .00978 L
.428 .00975 L
.432 .0097 L
.436 .00967 L
.44 .00971 L
.444 .00983 L
.448 .01 L
.452 .01017 L
.456 .01031 L
.46 .01037 L
.464 .01032 L
.468 .01018 L
.472 .00997 L
.476 .00974 L
.48 .00953 L
.484 .00937 L
.488 .00927 L
.492 .00922 L
.496 .0092 L
.5 .00921 L
.504 .00921 L
.508 .00923 L
.512 .00927 L
.516 .00933 L
.52 .00943 L
.524 .00957 L
.528 .00973 L
.532 .0099 L
.536 .01006 L
.54 .01018 L
.544 .01023 L
.548 .01021 L
.552 .0101 L
.556 .00993 L
.56 .00972 L
.564 .00951 L
.568 .00935 L
.572 .00927 L
.576 .00928 L
.58 .00937 L
.584 .00951 L
.588 .00966 L
.592 .0098 L
.596 .00989 L
.6 .00994 L
Mistroke
.604 .00995 L
.608 .00994 L
.612 .00992 L
.616 .0099 L
.62 .00987 L
.624 .00982 L
.628 .00974 L
.632 .00967 L
.636 .0096 L
.64 .00958 L
.644 .00962 L
.648 .0097 L
.652 .00981 L
.656 .00991 L
.66 .00997 L
.664 .00998 L
.668 .00995 L
.672 .0099 L
.676 .00985 L
.68 .00983 L
.684 .00982 L
.688 .00983 L
.692 .00983 L
.696 .00981 L
.7 .00979 L
.704 .00977 L
.708 .00978 L
.712 .00982 L
.716 .00988 L
.72 .00995 L
.724 .01 L
.728 .01002 L
.732 .01001 L
.736 .00998 L
.74 .00994 L
.744 .00991 L
.748 .00989 L
.752 .00988 L
.756 .00987 L
.76 .00987 L
.764 .00987 L
.768 .00988 L
.772 .00991 L
.776 .00996 L
.78 .01001 L
.784 .01005 L
.788 .01008 L
.792 .01008 L
.796 .01005 L
.8 .01 L
Mistroke
.804 .00995 L
.808 .00992 L
.812 .00991 L
.816 .00993 L
.82 .00997 L
.824 .01001 L
.828 .01005 L
.832 .01009 L
.836 .0101 L
.84 .0101 L
.844 .01007 L
.848 .01004 L
.852 .01 L
.856 .00999 L
.86 .01 L
.864 .01003 L
.868 .01008 L
.872 .01013 L
.876 .01015 L
.88 .01015 L
.884 .01013 L
.888 .01009 L
.892 .01006 L
.896 .01004 L
.9 .01005 L
.904 .01007 L
.908 .01011 L
.912 .01015 L
.916 .01018 L
.92 .01019 L
.924 .01019 L
.928 .01017 L
.932 .01015 L
.936 .01012 L
.94 .01011 L
.944 .01011 L
.948 .01014 L
.952 .01017 L
.956 .01021 L
.96 .01023 L
.964 .01025 L
.968 .01022 L
.972 .0102 L
.976 .01018 L
.98 .01018 L
.984 .01018 L
.988 .01021 L
.992 .01023 L
.996 .01025 L
1 .01025 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P0027oo0P00Hgoo0003Ool50002
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Qoo`8006=oo`002Woo00@0
07ooOol000Qoo`04001oogoo0004Ool01@00Oomoogoo000027oo00@007ooOol0069oo`002Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P001Woo00@007ooOomoo`8000Aoo`03
001oogoo05Yoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P001Woo
00<007ooOol00Woo00@007ooOomoo`<005]oo`002goo0P002Woo0P000goo0`000goo00<007ooOol0
1Goo00<007ooOol00Woo00<007ooOol00P0000=oo`00Ool0FWoo000;Ool20004Ool00`00Oomoo`03
Ool20003Ool30003Ool20005Ool00`00Oomoo`04Ool30003Ool00`00Oomoo`1HOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P001Goo00<007ooOol01Goo0`000Woo00@0
07oo000000Moo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000=oo`D000=oo`8000Aoo`80
00Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01P00Oomoogoo001oo`80009oo`03001o
ogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=o
o`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00
Oomoo`02Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P0017oo00<007ooOol02Goo00@007ooOol0
009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`09Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00
Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`8000Aoo`03001oogoo009oo`03001oogoo00Ioo`@000=oo`800003Ool0
07oo00Ioo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=o
o`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0003Ool01P00
Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`80
00=oo`03001oogoo00Ioo`03001oogoo00Aoo`@000Ioo`8000Aoo`04001oogoo0002Ool01000Oomo
o`0017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomo
o`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`008Woo0P00
0Woo00<007ooOol01goo1@000goo0`0017oo0P0000=oo`00Ool017oo0P0017oo0P001Woo00@007oo
Oomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<0
07ooOol00P004goo00<007ooOol00Woo00<007oo0000Cgoo000ROol4000DOol01@00Oomoogoo0000
0Woo00<007ooOol0CGoo000ROomS000<Ool0029oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`800003Ool007oo009oo`D0009oo`800005Ool00000001oo`030002
Ool20002Ool3000017oo000007oo0P000Woo0P0000=oo`0000000`0000=oo`0000000Woo00D007oo
Oomoo`0000=oo`03001oogoo008000=oo`05001oogooOol0000<Ool0029oo`8001Moo`<000Yoo`08
001oogoo001oo`00Ool0009oo`800004Ool000000002Ool3000017oo000007oo0P0000=oo`000000
100000=oo`0000003P0000=oo`0000001`0037oo000ROol00`00Oomoo`0TOol20003Ool00`00Oomo
o`10Ool0029oo`8006eoo`008Woo0P00KGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003
Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo
000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@0
07ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:
Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo
0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomo
o`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000
Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool2
0004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool0
0`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Mo
o`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<0
07ooOol00Woo1P00Hgoo000XOol00`00Oomoo`03Ool2001QOol002Qoo`03001oogoo00Eoo`8005mo
o`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol01goo0P00GGoo
000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol000Yo
o`8005aoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOol000aoo`8005Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol00P002goo10000goo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P00
0Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool01000Oomoogoo10000Woo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo0000
0goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001o
ogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo00<007oo00000P00
00=oo`00Ool01Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@00
0Woo00<007ooOol03Goo00D007ooOol007oo00D000Aoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001o
ogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007ooOol000=oo`H000=oo`04001oogoo0002
Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`05001oogoo001oo`0M0003Ool01000Oomoo`00
1Goo000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`001Woo90000goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo
00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D0
00=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo
00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007oo
Ool0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007oo
Ool006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0
06Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00
Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomo
o`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomo
o`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001o
ogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00
Oomoo`0TOol4001:Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol07Goo
1`000goo?`0037oo0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P006Woo1@00E7oo000:
Ool01000Oomoo`002goo00@007ooOol001Moo`D005Qoo`002Woo00@007ooOol000Moo`@000=oo`03
001oogoo01=oo`<005aoo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`80019oo`<005ioo`00
2goo0P0027oo1@000Woo00<007ooOol047oo0P00H7oo000LOol00`00Oomoo`0=Ool40003Ool20009
Ool30004Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002
Ool30004Ool20006Ool001aoo`8000eoo`<00005Ool007ooOol00002Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`00
0Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000LOol00`00Oomoo`0;Ool30002Ool0
1000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000LOol0
0`00Oomoo`0:Ool20004Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol01Goo00D0
07ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01000Oomoo`00
0Woo00<007ooOol00goo000LOol2000:Ool200000goo000000020003Ool01000Oomoo`002Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol0
00Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`06001oogooOol007oo
10000goo00@007ooOol000Eoo`0077oo00<007ooOol027oo00D007ooOomoo`0000Ioo`04001oogoo
0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001o
ogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo
001oo`0000Ioo`04001oogoo0005Ool001aoo`8000Moo`8000Aoo`D000=oo`8000Yoo`03001oogoo
00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002
Ool50003Ool20006Ool001aoo`03001oogoo00Eoo`8006]oo`0077oo00<007ooOol00goo0`00K7oo
000LOomY000<Ool001aoo`80009oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol0
0`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001ao
o`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079o
o`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo
000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000
Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00
Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1b
Ool001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomo
o`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000G
Ool00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol00Woo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomo
o`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1b
Ool000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo0080
07=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04
Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo
000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(48597\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .27723 m
.008 .27403 L
.012 .27071 L
.016 .26554 L
.02 .25861 L
.024 .25122 L
.028 .2433 L
.032 .23422 L
.036 .22425 L
.04 .21386 L
.044 .2032 L
.048 .19236 L
.052 .18169 L
.056 .17159 L
.06 .16242 L
.064 .15449 L
.068 .14815 L
.072 .1437 L
.076 .14136 L
.08 .14126 L
.084 .14341 L
.088 .14771 L
.092 .15387 L
.096 .16149 L
.1 .17002 L
.104 .17885 L
.108 .18731 L
.112 .19473 L
.116 .20052 L
.12 .20419 L
.124 .20546 L
.128 .20432 L
.132 .20099 L
.136 .196 L
.14 .19004 L
.144 .18396 L
.148 .17864 L
.152 .17494 L
.156 .17355 L
.16 .17495 L
.164 .17931 L
.168 .18642 L
.172 .19576 L
.176 .20654 L
.18 .21785 L
.184 .2288 L
.188 .23867 L
.192 .247 L
.196 .2537 L
.2 .25901 L
Mistroke
.204 .2635 L
.208 .2679 L
.212 .27299 L
.216 .27934 L
.22 .2872 L
.224 .29633 L
.228 .30604 L
.232 .31525 L
.236 .32275 L
.24 .32734 L
.244 .32818 L
.248 .32492 L
.252 .31784 L
.256 .30789 L
.26 .29654 L
.264 .28555 L
.268 .27663 L
.272 .27111 L
.276 .26964 L
.28 .27215 L
.284 .27788 L
.288 .28556 L
.292 .29379 L
.296 .30126 L
.3 .30706 L
.304 .31079 L
.308 .31253 L
.312 .31275 L
.316 .31208 L
.32 .31111 L
.324 .31018 L
.328 .30932 L
.332 .30838 L
.336 .30717 L
.34 .30567 L
.344 .30419 L
.348 .30339 L
.352 .30407 L
.356 .30693 L
.36 .31216 L
.364 .31927 L
.368 .32711 L
.372 .33402 L
.376 .33836 L
.38 .33895 L
.384 .33557 L
.388 .32904 L
.392 .32114 L
.396 .31401 L
.4 .30961 L
Mistroke
.404 .3091 L
.408 .31246 L
.412 .31845 L
.416 .32503 L
.42 .33001 L
.424 .33177 L
.428 .32975 L
.432 .32464 L
.436 .31807 L
.44 .31211 L
.444 .30854 L
.448 .30823 L
.452 .31089 L
.456 .31528 L
.46 .31977 L
.464 .32291 L
.468 .32395 L
.472 .32303 L
.476 .32098 L
.48 .31894 L
.484 .31783 L
.488 .31803 L
.492 .31931 L
.496 .32109 L
.5 .32272 L
.504 .32375 L
.508 .32398 L
.512 .3234 L
.516 .32212 L
.52 .32031 L
.524 .31817 L
.528 .31602 L
.532 .31434 L
.536 .31371 L
.54 .31455 L
.544 .31688 L
.548 .3201 L
.552 .32316 L
.556 .32496 L
.56 .32486 L
.564 .32299 L
.568 .32019 L
.572 .31771 L
.576 .31665 L
.58 .31743 L
.584 .31953 L
.588 .3217 L
.592 .32266 L
.596 .32178 L
.6 .31945 L
Mistroke
.604 .31689 L
.608 .31548 L
.612 .31609 L
.616 .31855 L
.62 .32176 L
.624 .3242 L
.628 .32464 L
.632 .32287 L
.636 .31982 L
.64 .31705 L
.644 .31594 L
.648 .31691 L
.652 .3192 L
.656 .32142 L
.66 .32235 L
.664 .32159 L
.668 .31977 L
.672 .31806 L
.676 .31751 L
.68 .31848 L
.684 .32039 L
.688 .32214 L
.692 .3227 L
.696 .32173 L
.7 .31986 L
.704 .31819 L
.708 .31767 L
.712 .31845 L
.716 .31987 L
.72 .32094 L
.724 .32105 L
.728 .32029 L
.732 .31932 L
.736 .31884 L
.74 .31916 L
.744 .32005 L
.748 .32098 L
.752 .3214 L
.756 .32107 L
.76 .32014 L
.764 .31914 L
.768 .31864 L
.772 .31894 L
.776 .31985 L
.78 .32075 L
.784 .32104 L
.788 .32055 L
.792 .31969 L
.796 .31908 L
.8 .31913 L
Mistroke
.804 .3197 L
.808 .3204 L
.812 .32082 L
.816 .32087 L
.82 .32063 L
.824 .32018 L
.828 .31962 L
.832 .31916 L
.836 .31909 L
.84 .31964 L
.844 .32053 L
.848 .32115 L
.852 .32099 L
.856 .32009 L
.86 .31918 L
.864 .31905 L
.868 .31981 L
.872 .32081 L
.876 .32117 L
.88 .32054 L
.884 .31958 L
.888 .31916 L
.892 .31958 L
.896 .32049 L
.9 .32094 L
.904 .32057 L
.908 .31992 L
.912 .31956 L
.916 .31988 L
.92 .32057 L
.924 .32074 L
.928 .32026 L
.932 .31967 L
.936 .31937 L
.94 .3198 L
.944 .32061 L
.948 .32084 L
.952 .32054 L
.956 .32016 L
.96 .31984 L
.964 .3202 L
.968 .32073 L
.972 .32047 L
.976 .32 L
.98 .31954 L
.984 .3193 L
.988 .32008 L
.992 .32093 L
.996 .32084 L
1 .32054 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .14262 m
.008 .14729 L
.012 .14903 L
.016 .14798 L
.02 .14796 L
.024 .14916 L
.028 .1502 L
.032 .15112 L
.036 .15226 L
.04 .15374 L
.044 .15534 L
.048 .15712 L
.052 .15905 L
.056 .16118 L
.06 .16346 L
.064 .16588 L
.068 .1684 L
.072 .17103 L
.076 .17369 L
.08 .1764 L
.084 .17909 L
.088 .18175 L
.092 .18433 L
.096 .18684 L
.1 .18922 L
.104 .1915 L
.108 .19365 L
.112 .19571 L
.116 .19767 L
.12 .19958 L
.124 .20145 L
.128 .20334 L
.132 .20525 L
.136 .20724 L
.14 .2093 L
.144 .21145 L
.148 .21369 L
.152 .21599 L
.156 .21834 L
.16 .22071 L
.164 .22304 L
.168 .22531 L
.172 .22748 L
.176 .22953 L
.18 .23144 L
.184 .23321 L
.188 .23484 L
.192 .23636 L
.196 .23777 L
.2 .23909 L
Mistroke
.204 .24034 L
.208 .24151 L
.212 .24261 L
.216 .24363 L
.22 .24453 L
.224 .24532 L
.228 .24598 L
.232 .24652 L
.236 .24695 L
.24 .2473 L
.244 .24762 L
.248 .24795 L
.252 .24835 L
.256 .24886 L
.26 .2495 L
.264 .25028 L
.268 .25118 L
.272 .25217 L
.276 .2532 L
.28 .25421 L
.284 .25516 L
.288 .25602 L
.292 .25676 L
.296 .2574 L
.3 .25792 L
.304 .25837 L
.308 .25877 L
.312 .25913 L
.316 .25949 L
.32 .25986 L
.324 .26023 L
.328 .26062 L
.332 .26102 L
.336 .26143 L
.34 .26183 L
.344 .26222 L
.348 .26258 L
.352 .26289 L
.356 .26312 L
.36 .26324 L
.364 .26322 L
.368 .26308 L
.372 .2628 L
.376 .26244 L
.38 .26203 L
.384 .26164 L
.388 .26132 L
.392 .2611 L
.396 .26098 L
.4 .26095 L
Mistroke
.404 .26096 L
.408 .26098 L
.412 .26095 L
.416 .26088 L
.42 .26074 L
.424 .26058 L
.428 .26043 L
.432 .26032 L
.436 .26028 L
.44 .26033 L
.444 .26044 L
.448 .26059 L
.452 .26075 L
.456 .26088 L
.46 .26096 L
.464 .26099 L
.468 .26099 L
.472 .26095 L
.476 .26091 L
.48 .26087 L
.484 .26081 L
.488 .26075 L
.492 .26065 L
.496 .26053 L
.5 .26038 L
.504 .26022 L
.508 .26006 L
.512 .25993 L
.516 .25983 L
.52 .2598 L
.524 .25983 L
.528 .25992 L
.532 .26004 L
.536 .26018 L
.54 .2603 L
.544 .26037 L
.548 .26037 L
.552 .26031 L
.556 .26018 L
.56 .26003 L
.564 .25988 L
.568 .25976 L
.572 .25967 L
.576 .25963 L
.58 .2596 L
.584 .25959 L
.588 .25958 L
.592 .25958 L
.596 .25958 L
.6 .2596 L
Mistroke
.604 .25963 L
.608 .25966 L
.612 .25967 L
.616 .25965 L
.62 .25958 L
.624 .25948 L
.628 .25936 L
.632 .25925 L
.636 .25918 L
.64 .25915 L
.644 .25916 L
.648 .25918 L
.652 .2592 L
.656 .2592 L
.66 .25918 L
.664 .25915 L
.668 .25912 L
.672 .25909 L
.676 .25907 L
.68 .25905 L
.684 .259 L
.688 .25894 L
.692 .25887 L
.696 .25879 L
.7 .25873 L
.704 .2587 L
.708 .25869 L
.712 .25869 L
.716 .2587 L
.72 .2587 L
.724 .25868 L
.728 .25866 L
.732 .25863 L
.736 .2586 L
.74 .25856 L
.744 .25852 L
.748 .25847 L
.752 .2584 L
.756 .25833 L
.76 .25828 L
.764 .25824 L
.768 .25823 L
.772 .25824 L
.776 .25826 L
.78 .25826 L
.784 .25824 L
.788 .2582 L
.792 .25814 L
.796 .25808 L
.8 .25802 L
Mistroke
.804 .25797 L
.808 .25794 L
.812 .25792 L
.816 .25791 L
.82 .25791 L
.824 .25789 L
.828 .25787 L
.832 .25783 L
.836 .25778 L
.84 .25772 L
.844 .25767 L
.848 .25762 L
.852 .2576 L
.856 .25759 L
.86 .25759 L
.864 .25758 L
.868 .25756 L
.872 .25753 L
.876 .25748 L
.88 .25743 L
.884 .25738 L
.888 .25734 L
.892 .2573 L
.896 .25728 L
.9 .25725 L
.904 .25723 L
.908 .25721 L
.912 .25719 L
.916 .25716 L
.92 .25712 L
.924 .25709 L
.928 .25705 L
.932 .25702 L
.936 .25699 L
.94 .25697 L
.944 .25694 L
.948 .25691 L
.952 .25687 L
.956 .25683 L
.96 .25678 L
.964 .25675 L
.968 .25671 L
.972 .2567 L
.976 .25668 L
.98 .25667 L
.984 .25665 L
.988 .25663 L
.992 .25658 L
.996 .25654 L
1 .25648 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15879 L
.012 .15897 L
.016 .15796 L
.02 .1561 L
.024 .15455 L
.028 .15323 L
.032 .15152 L
.036 .14959 L
.04 .14753 L
.044 .14535 L
.048 .14292 L
.052 .14031 L
.056 .13751 L
.06 .13456 L
.064 .13143 L
.068 .1282 L
.072 .12485 L
.076 .12145 L
.08 .11802 L
.084 .11461 L
.088 .11125 L
.092 .10798 L
.096 .10483 L
.1 .10182 L
.104 .09894 L
.108 .09623 L
.112 .09363 L
.116 .09116 L
.12 .08875 L
.124 .08638 L
.128 .08401 L
.132 .08159 L
.136 .0791 L
.14 .07651 L
.144 .0738 L
.148 .07099 L
.152 .06808 L
.156 .06513 L
.16 .06216 L
.164 .05923 L
.168 .05637 L
.172 .05364 L
.176 .05105 L
.18 .04864 L
.184 .04641 L
.188 .04434 L
.192 .04243 L
.196 .04064 L
.2 .03896 L
Mistroke
.204 .03738 L
.208 .03588 L
.212 .03448 L
.216 .03318 L
.22 .03202 L
.224 .03101 L
.228 .03015 L
.232 .02945 L
.236 .02889 L
.24 .02842 L
.244 .02799 L
.248 .02754 L
.252 .02701 L
.256 .02634 L
.26 .02551 L
.264 .02451 L
.268 .02336 L
.272 .0221 L
.276 .02079 L
.28 .01949 L
.284 .01827 L
.288 .01716 L
.292 .0162 L
.296 .01538 L
.3 .01469 L
.304 .0141 L
.308 .01357 L
.312 .01308 L
.316 .01259 L
.32 .0121 L
.324 .0116 L
.328 .01109 L
.332 .01056 L
.336 .01002 L
.34 .00948 L
.344 .00896 L
.348 .00847 L
.352 .00805 L
.356 .00773 L
.36 .00755 L
.364 .00754 L
.368 .00769 L
.372 .00799 L
.376 .0084 L
.38 .00887 L
.384 .00932 L
.388 .00968 L
.392 .00993 L
.396 .01005 L
.4 .01006 L
Mistroke
.404 .01001 L
.408 .00995 L
.412 .00994 L
.416 .01 L
.42 .01013 L
.424 .0103 L
.428 .01046 L
.432 .01057 L
.436 .01058 L
.44 .01049 L
.444 .01031 L
.448 .01009 L
.452 .00986 L
.456 .00966 L
.46 .00952 L
.464 .00944 L
.468 .00941 L
.472 .00942 L
.476 .00944 L
.48 .00947 L
.484 .0095 L
.488 .00955 L
.492 .00963 L
.496 .00974 L
.5 .00989 L
.504 .01006 L
.508 .01022 L
.512 .01036 L
.516 .01044 L
.52 .01045 L
.524 .01038 L
.528 .01023 L
.532 .01004 L
.536 .00984 L
.54 .00966 L
.544 .00954 L
.548 .0095 L
.552 .00954 L
.556 .00965 L
.56 .0098 L
.564 .00996 L
.568 .01008 L
.572 .01017 L
.576 .0102 L
.58 .0102 L
.584 .01018 L
.588 .01014 L
.592 .0101 L
.596 .01006 L
.6 .01 L
Mistroke
.604 .00993 L
.608 .00987 L
.612 .00983 L
.616 .00983 L
.62 .00988 L
.624 .00997 L
.628 .01008 L
.632 .01017 L
.636 .01022 L
.64 .01022 L
.644 .01018 L
.648 .01012 L
.652 .01006 L
.656 .01004 L
.66 .01003 L
.664 .01004 L
.668 .01005 L
.672 .01004 L
.676 .01003 L
.68 .01002 L
.684 .01004 L
.688 .01007 L
.692 .01013 L
.696 .01019 L
.7 .01023 L
.704 .01025 L
.708 .01024 L
.712 .0102 L
.716 .01016 L
.72 .01013 L
.724 .01011 L
.728 .01009 L
.732 .01008 L
.736 .01008 L
.74 .0101 L
.744 .01013 L
.748 .01018 L
.752 .01023 L
.756 .01027 L
.76 .0103 L
.764 .0103 L
.768 .01027 L
.772 .01023 L
.776 .01019 L
.78 .01016 L
.784 .01016 L
.788 .01017 L
.792 .0102 L
.796 .01023 L
.8 .01025 L
Mistroke
.804 .01027 L
.808 .01029 L
.812 .0103 L
.816 .01031 L
.82 .0103 L
.824 .01028 L
.828 .01026 L
.832 .01024 L
.836 .01024 L
.84 .01026 L
.844 .01029 L
.848 .01033 L
.852 .01036 L
.856 .01037 L
.86 .01037 L
.864 .01034 L
.868 .01031 L
.872 .01029 L
.876 .01028 L
.88 .0103 L
.884 .01033 L
.888 .01036 L
.892 .01039 L
.896 .01041 L
.9 .01042 L
.904 .01042 L
.908 .0104 L
.912 .01038 L
.916 .01036 L
.92 .01035 L
.924 .01036 L
.928 .01038 L
.932 .01042 L
.936 .01044 L
.94 .01046 L
.944 .01046 L
.948 .01045 L
.952 .01044 L
.956 .01043 L
.96 .01042 L
.964 .01043 L
.968 .01043 L
.972 .01046 L
.976 .01047 L
.98 .0105 L
.984 .01051 L
.988 .01052 L
.992 .0105 L
.996 .01049 L
1 .01047 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P001Goo0P00IWoo0003Ool50002
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Aoo`800003Ool007oo06Ao
o`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01@00Oomoogoo00001Goo00D007ooOomoo`00
06Aoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P0017oo00D007oo
Oomoo`0000Aoo`8005ioo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol0
0P000goo00<007ooOol00Woo00@007ooOomoo`<005ioo`002goo0P002Woo0P000goo0`000goo00<0
07ooOol00Woo00<007ooOol00goo00@007oo0000009oo`03001oogoo05]oo`002goo0P0017oo00<0
07ooOol00goo0P000goo0`000goo0P000Woo00<007ooOol017oo0`000goo00<007ooOol0Fgoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80009oo`03001oogoo00Qoo`<0
00Aoo`8000Moo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000=oo`D000=oo`8000Aoo`80
00Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool0
0`00Oomoo`02Ool01@00Oomoogoo00002Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`00
0Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo00H0
07ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`800003Ool007oo00eoo`04001oogoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P0000=oo`00Ool03Goo0P0000Eoo`00Oomoo`0000Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol017oo00@0
07ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool0
0`00Ool0000;Ool4000017oo001oo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool01000Oomoogoo10000goo00@007ooOol0009oo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogooOol007oo10000goo00@007ooOol000Eo
o`002goo0P002Woo0P0017oo00<007ooOol00Woo0`002goo00<007ooOol00goo0P000Woo00<007oo
Ool017oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000
Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00L007ooOomo
o`00Ool00006Ool01000Oomoo`001Goo000ROol2000<Ool50002Ool30002Ool30003Ool00`00Oomo
o`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo0P0017oo0P001Goo0`00
0Woo1@000goo0P001Woo000ROol00`00Oomoo`0BOol20003Ool00`00Ool0001BOol0029oo`8001Ao
o`04001oogoo0003Ool00`00Oomoo`1?Ool0029oof<000aoo`008Woo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000Woo0`0000Aoo`00Oomoo`<0009oo`80009oo`80009o
o`<00003Ool00000009oo`<00005Ool00000001oo`0200001Woo00000000Ool0009oo`800003Ool0
07oo0080009oo`03001oogoo00800003Ool007oo0080009oo`09001oogooOol007oo001oo`0000ao
o`008Woo0P005Goo0P002goo00<007oo00000Woo0P000Woo1`000Woo0P0000Eoo`00000007oo0080
0004Ool00000Ool2000017oo000007oo0P0000=oo`0000005@0037oo000ROol00`00Oomoo`0QOol3
0002Ool20014Ool0029oo`8006eoo`008Woo0P00KGoo000;Ool20004Ool00`00Oomoo`03Ool20003
Ool30003Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`8006eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007oo
Ool0K7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
17oo00@007ooOomoo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007oo
Ool00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;
Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007oo
Ool00goo0P000goo0`000goo0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
0`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool0
1000Oomoo`001Goo00<007ooOol00P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo
00<007ooOol0K7oo000ROol2001]Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo
1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2
000:Ool20004Ool01000Oomoogoo1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool3
0003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00<007ooOol0IWoo0009Ool50002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1V
Ool0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@
Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P00
17oo00<007ooOol00Woo0`00IWoo000XOol00`00Oomoo`03001SOol002Qoo`03001oogoo009oo`<0
065oo`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol017oo0P00
H7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol0
00Moo`<005ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOol000Uoo`<005aoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol00P002Woo100017oo0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo
0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool00`00Ool000020002Ool0
1000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo
00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05
001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol03Goo10000Woo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo
00<007ooOol03Goo00<007oo000010001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04
001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo
000XOol00`00Oomoo`09Ool40003Ool00`00Oomoo`0700000goo001oo`03Ool01000Oomoo`000Woo
00@007ooOol000=oo`04001oogooOol40003Ool01@00Oomoo`00Ool07@000goo00@007ooOol000Eo
o`00:7oo00<007ooOol02Goo00<007ooOol017oo00@007ooOol000Ioob@000=oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005Ool002Qoo`03
001oogoo00Uoo`D000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003
Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03
001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo
06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo
001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001X
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Mo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0
IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0
IWoo000;Ool2000:Ool20004Ool20002Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomo
o`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<0
07ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo
000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol0
00Qoo`04001oogoo0003Ool01000Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000=oo`03001oogoo06eoo`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007oo
Ool08Goo1000CGoo000:Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo01]oo`L0
009ood8000aoo`000goo1@000Woo00@007ooOol000]oo`03001oogoo008001Qoo`D005Ioo`002Woo
00@007ooOol000]oo`04001oogoo000DOol5001KOol000Yoo`04001oogoo0007Ool40003Ool00`00
Oomoo`0@Ool3001OOol000Yoo`04001oogoo0007Ool00`00Oomoo`04Ool2000@Ool2001QOol000]o
o`8000Qoo`D0009oo`03001oogoo00eoo`8006=oo`0077oo00<007ooOol037oo100017oo0P002Goo
0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo
0`0017oo0P001Woo000LOol2000;Ool30003Ool01000Oomoo`000Woo00<007ooOol01goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009o
o`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo
001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol02Goo0P001Goo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<0
07ooOol01goo0P001goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001o
ogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009o
o`03001oogoo00=oo`0077oo0P001goo0P0017oo10000goo00@007ooOol000Uoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04
001oogoo0005Ool001aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo
0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001o
ogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo
001oo`0000Ioo`04001oogoo0005Ool001aoo`8000Eoo`8000Ioo`D000=oo`8000Yoo`03001oogoo
00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002
Ool50003Ool20006Ool001aoo`03001oogoo009oo`8006ioo`0077oo00<007ooOol00`00Kgoo000L
OomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo
00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo
079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool0
1000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo
0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00
Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00
Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo
000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol0
0Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00
Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomo
o`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo
008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomo
o`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0
LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(48764\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .2054 m
.008 .20051 L
.012 .19435 L
.016 .18676 L
.02 .1778 L
.024 .16915 L
.028 .16124 L
.032 .15362 L
.036 .14659 L
.04 .14091 L
.044 .13698 L
.048 .13489 L
.052 .1348 L
.056 .13685 L
.06 .14102 L
.064 .14708 L
.068 .15466 L
.072 .1633 L
.076 .17242 L
.08 .18138 L
.084 .1895 L
.088 .19616 L
.092 .20084 L
.096 .20318 L
.1 .20306 L
.104 .20063 L
.108 .19629 L
.112 .19065 L
.116 .18451 L
.12 .17877 L
.124 .1743 L
.128 .17191 L
.132 .17219 L
.136 .17542 L
.14 .18154 L
.144 .19015 L
.148 .20056 L
.152 .21194 L
.156 .22337 L
.16 .23405 L
.164 .24338 L
.168 .25104 L
.172 .2571 L
.176 .26198 L
.18 .26635 L
.184 .27102 L
.188 .27667 L
.192 .28372 L
.196 .29214 L
.2 .30147 L
Mistroke
.204 .31083 L
.208 .31908 L
.212 .32501 L
.216 .3276 L
.22 .3262 L
.224 .32079 L
.228 .31198 L
.232 .30101 L
.236 .28955 L
.24 .27936 L
.244 .272 L
.248 .2685 L
.252 .26918 L
.256 .27362 L
.26 .28078 L
.264 .28929 L
.268 .29768 L
.272 .30473 L
.276 .30969 L
.28 .31235 L
.284 .31306 L
.288 .31246 L
.292 .31127 L
.296 .31003 L
.3 .309 L
.304 .3081 L
.308 .30714 L
.312 .30598 L
.316 .30473 L
.32 .30384 L
.324 .30397 L
.328 .30583 L
.332 .30983 L
.336 .31588 L
.34 .32324 L
.344 .33058 L
.348 .33633 L
.352 .33907 L
.356 .338 L
.36 .33326 L
.364 .32598 L
.368 .31807 L
.372 .3117 L
.376 .30861 L
.38 .30958 L
.384 .31414 L
.388 .32072 L
.392 .32711 L
.396 .33117 L
.4 .33155 L
Mistroke
.404 .32814 L
.408 .32209 L
.412 .31534 L
.416 .30997 L
.42 .30749 L
.424 .30837 L
.428 .31195 L
.432 .31677 L
.436 .32114 L
.44 .3238 L
.444 .32424 L
.448 .32286 L
.452 .32059 L
.456 .31856 L
.46 .31761 L
.464 .31805 L
.468 .31961 L
.472 .32164 L
.476 .32337 L
.48 .32425 L
.484 .32405 L
.488 .32286 L
.492 .32094 L
.496 .3187 L
.5 .31656 L
.504 .31493 L
.508 .31412 L
.512 .31437 L
.516 .31576 L
.52 .3181 L
.524 .3209 L
.528 .32338 L
.532 .32473 L
.536 .32445 L
.54 .32265 L
.544 .32004 L
.548 .31769 L
.552 .31658 L
.556 .31713 L
.56 .319 L
.564 .32114 L
.568 .32232 L
.572 .32177 L
.576 .31967 L
.58 .3171 L
.584 .31552 L
.588 .31596 L
.592 .3184 L
.596 .32177 L
.6 .32443 L
Mistroke
.604 .32502 L
.608 .32316 L
.612 .31973 L
.616 .31646 L
.62 .31499 L
.624 .31599 L
.628 .31877 L
.632 .3217 L
.636 .32316 L
.64 .32246 L
.644 .32017 L
.648 .31776 L
.652 .31668 L
.656 .31758 L
.66 .31991 L
.664 .32234 L
.668 .32344 L
.672 .32258 L
.676 .32024 L
.68 .31777 L
.684 .31655 L
.688 .31715 L
.692 .31906 L
.696 .32105 L
.7 .322 L
.704 .32152 L
.708 .32011 L
.712 .31876 L
.716 .31826 L
.72 .31883 L
.724 .32006 L
.728 .3212 L
.732 .32162 L
.736 .32109 L
.74 .31995 L
.744 .31883 L
.748 .31835 L
.752 .31872 L
.756 .31962 L
.76 .32049 L
.764 .32084 L
.768 .3206 L
.772 .32007 L
.776 .31963 L
.78 .31947 L
.784 .31959 L
.788 .31987 L
.792 .32019 L
.796 .32045 L
.8 .32051 L
Mistroke
.804 .32025 L
.808 .31975 L
.812 .31931 L
.816 .31928 L
.82 .31971 L
.824 .32028 L
.828 .32053 L
.832 .32031 L
.836 .31992 L
.84 .3198 L
.844 .32006 L
.848 .3204 L
.852 .32033 L
.856 .31977 L
.86 .31922 L
.864 .31923 L
.868 .31991 L
.872 .32083 L
.876 .32121 L
.88 .32077 L
.884 .31994 L
.888 .31928 L
.892 .31922 L
.896 .31968 L
.9 .32011 L
.904 .32033 L
.908 .32039 L
.912 .32034 L
.916 .32034 L
.92 .32028 L
.924 .31997 L
.928 .31978 L
.932 .31989 L
.936 .32011 L
.94 .32044 L
.944 .32043 L
.948 .31992 L
.952 .31969 L
.956 .31985 L
.96 .32025 L
.964 .32081 L
.968 .32068 L
.972 .31986 L
.976 .31944 L
.98 .31954 L
.984 .32016 L
.988 .32118 L
.992 .32124 L
.996 .32025 L
1 .31956 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .15971 m
.008 .15865 L
.012 .15873 L
.016 .16006 L
.02 .16112 L
.024 .16221 L
.028 .16373 L
.032 .16563 L
.036 .1676 L
.04 .16975 L
.044 .17205 L
.048 .17451 L
.052 .17699 L
.056 .17953 L
.06 .18206 L
.064 .18457 L
.068 .18699 L
.072 .18934 L
.076 .19158 L
.08 .19373 L
.084 .19577 L
.088 .19773 L
.092 .19961 L
.096 .20148 L
.1 .20332 L
.104 .20521 L
.108 .20714 L
.112 .20915 L
.116 .21125 L
.12 .21344 L
.124 .2157 L
.128 .21803 L
.132 .22037 L
.136 .22271 L
.14 .225 L
.144 .22721 L
.148 .22929 L
.152 .23125 L
.156 .23307 L
.16 .23475 L
.164 .23629 L
.168 .23773 L
.172 .23906 L
.176 .24032 L
.18 .2415 L
.184 .24262 L
.188 .24365 L
.192 .24459 L
.196 .24542 L
.2 .24612 L
Mistroke
.204 .24671 L
.208 .24718 L
.212 .24756 L
.216 .2479 L
.22 .24822 L
.224 .24859 L
.228 .24905 L
.232 .24963 L
.236 .25034 L
.24 .25119 L
.244 .25214 L
.248 .25315 L
.252 .25418 L
.256 .25516 L
.26 .25607 L
.264 .25687 L
.268 .25754 L
.272 .25811 L
.276 .25858 L
.28 .25898 L
.284 .25935 L
.288 .2597 L
.292 .26006 L
.296 .26043 L
.3 .26081 L
.304 .2612 L
.308 .2616 L
.312 .262 L
.316 .26238 L
.32 .26275 L
.324 .26307 L
.328 .26333 L
.332 .26348 L
.336 .26352 L
.34 .26343 L
.344 .26321 L
.348 .26289 L
.352 .2625 L
.356 .2621 L
.36 .26174 L
.364 .26146 L
.368 .26128 L
.372 .2612 L
.376 .26119 L
.38 .26122 L
.384 .26123 L
.388 .2612 L
.392 .26111 L
.396 .26097 L
.4 .26081 L
Mistroke
.404 .26067 L
.408 .26059 L
.412 .26058 L
.416 .26066 L
.42 .2608 L
.424 .26097 L
.428 .26112 L
.432 .26123 L
.436 .26129 L
.44 .2613 L
.444 .26128 L
.448 .26123 L
.452 .26117 L
.456 .26111 L
.46 .26105 L
.464 .26097 L
.468 .26087 L
.472 .26074 L
.476 .26059 L
.48 .26043 L
.484 .26028 L
.488 .26016 L
.492 .2601 L
.496 .2601 L
.5 .26016 L
.504 .26027 L
.508 .26041 L
.512 .26053 L
.516 .26063 L
.52 .26067 L
.524 .26064 L
.528 .26055 L
.532 .26041 L
.536 .26025 L
.54 .26011 L
.544 .25999 L
.548 .25991 L
.552 .25988 L
.556 .25987 L
.56 .25987 L
.564 .25988 L
.568 .25989 L
.572 .2599 L
.576 .25991 L
.58 .25993 L
.584 .25994 L
.588 .25993 L
.592 .25989 L
.596 .25982 L
.6 .25972 L
Mistroke
.604 .25961 L
.608 .25951 L
.612 .25945 L
.616 .25943 L
.62 .25944 L
.624 .25947 L
.628 .25949 L
.632 .25949 L
.636 .25946 L
.64 .25943 L
.644 .2594 L
.648 .25937 L
.652 .25934 L
.656 .25931 L
.66 .25926 L
.664 .2592 L
.668 .25913 L
.672 .25905 L
.676 .259 L
.68 .25897 L
.684 .25897 L
.688 .25898 L
.692 .25899 L
.696 .25898 L
.7 .25897 L
.704 .25894 L
.708 .25891 L
.712 .25887 L
.716 .25883 L
.72 .25877 L
.724 .25872 L
.728 .25865 L
.732 .2586 L
.736 .25856 L
.74 .25854 L
.744 .25853 L
.748 .25854 L
.752 .25854 L
.756 .25853 L
.76 .2585 L
.764 .25846 L
.768 .2584 L
.772 .25835 L
.776 .2583 L
.78 .25826 L
.784 .25822 L
.788 .2582 L
.792 .25818 L
.796 .25817 L
.8 .25816 L
Mistroke
.804 .25814 L
.808 .25811 L
.812 .25807 L
.816 .25802 L
.82 .25795 L
.824 .2579 L
.828 .25786 L
.832 .25784 L
.836 .25784 L
.84 .25785 L
.844 .25785 L
.848 .25782 L
.852 .25778 L
.856 .25772 L
.86 .25766 L
.864 .2576 L
.868 .25755 L
.872 .25753 L
.876 .25751 L
.88 .25751 L
.884 .2575 L
.888 .25749 L
.892 .25746 L
.896 .25742 L
.9 .25737 L
.904 .25732 L
.908 .25727 L
.912 .25724 L
.916 .25722 L
.92 .2572 L
.924 .25718 L
.928 .25716 L
.932 .25713 L
.936 .25708 L
.94 .25704 L
.944 .257 L
.948 .25697 L
.952 .25694 L
.956 .25693 L
.96 .2569 L
.964 .25689 L
.968 .25686 L
.972 .25683 L
.976 .25678 L
.98 .25673 L
.984 .25668 L
.988 .25664 L
.992 .2566 L
.996 .2566 L
1 .25658 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15472 L
.012 .15497 L
.016 .15293 L
.02 .14866 L
.024 .14492 L
.028 .14193 L
.032 .13859 L
.036 .13496 L
.04 .13129 L
.044 .1277 L
.048 .12403 L
.052 .12037 L
.056 .11673 L
.06 .11321 L
.064 .10976 L
.068 .10645 L
.072 .10328 L
.076 .10029 L
.08 .09744 L
.084 .09475 L
.088 .09218 L
.092 .08972 L
.096 .0873 L
.1 .08492 L
.104 .0825 L
.108 .08003 L
.112 .07746 L
.116 .07479 L
.12 .07201 L
.124 .06914 L
.128 .0662 L
.132 .06324 L
.136 .06029 L
.14 .0574 L
.144 .05462 L
.148 .05198 L
.152 .0495 L
.156 .04721 L
.16 .04509 L
.164 .04313 L
.168 .04131 L
.172 .03961 L
.176 .03801 L
.18 .0365 L
.184 .03508 L
.188 .03377 L
.192 .03257 L
.196 .0315 L
.2 .03059 L
Mistroke
.204 .02982 L
.208 .0292 L
.212 .02869 L
.216 .02825 L
.22 .02782 L
.224 .02732 L
.228 .02672 L
.232 .02597 L
.236 .02504 L
.24 .02395 L
.244 .02274 L
.248 .02144 L
.252 .02013 L
.256 .01887 L
.26 .01771 L
.264 .01668 L
.268 .01581 L
.272 .01507 L
.276 .01445 L
.28 .0139 L
.284 .01341 L
.288 .01294 L
.292 .01246 L
.296 .01198 L
.3 .01147 L
.304 .01094 L
.308 .01041 L
.312 .00988 L
.316 .00936 L
.32 .00887 L
.324 .00844 L
.328 .00809 L
.332 .00785 L
.336 .00777 L
.34 .00784 L
.344 .00808 L
.348 .00845 L
.352 .0089 L
.356 .00937 L
.36 .00978 L
.364 .0101 L
.368 .01028 L
.372 .01035 L
.376 .01032 L
.38 .01025 L
.384 .01021 L
.388 .01022 L
.392 .0103 L
.396 .01044 L
.4 .0106 L
Mistroke
.404 .01073 L
.408 .01079 L
.412 .01076 L
.416 .01063 L
.42 .01043 L
.424 .0102 L
.428 .00998 L
.432 .0098 L
.436 .00968 L
.44 .00963 L
.444 .00963 L
.448 .00965 L
.452 .00969 L
.456 .00973 L
.46 .00978 L
.464 .00984 L
.468 .00994 L
.472 .01007 L
.476 .01022 L
.48 .01038 L
.484 .01053 L
.488 .01063 L
.492 .01068 L
.496 .01064 L
.5 .01053 L
.504 .01037 L
.508 .01017 L
.512 .00998 L
.516 .00982 L
.52 .00974 L
.524 .00974 L
.528 .00982 L
.532 .00995 L
.536 .01012 L
.54 .01027 L
.544 .01037 L
.548 .01043 L
.552 .01044 L
.556 .01042 L
.56 .01039 L
.564 .01035 L
.568 .01031 L
.572 .01026 L
.576 .0102 L
.58 .01014 L
.584 .01008 L
.588 .01006 L
.592 .01008 L
.596 .01014 L
.6 .01025 L
Mistroke
.604 .01035 L
.608 .01044 L
.612 .01047 L
.616 .01045 L
.62 .01039 L
.624 .01032 L
.628 .01027 L
.632 .01025 L
.636 .01025 L
.64 .01026 L
.644 .01027 L
.648 .01028 L
.652 .01027 L
.656 .01027 L
.66 .01029 L
.664 .01033 L
.668 .01038 L
.672 .01044 L
.676 .01047 L
.68 .01048 L
.684 .01046 L
.688 .01042 L
.692 .01037 L
.696 .01034 L
.7 .01032 L
.704 .01032 L
.708 .01032 L
.712 .01033 L
.716 .01035 L
.72 .01037 L
.724 .01042 L
.728 .01047 L
.732 .01051 L
.736 .01054 L
.74 .01053 L
.744 .0105 L
.748 .01045 L
.752 .0104 L
.756 .01037 L
.76 .01037 L
.764 .0104 L
.768 .01044 L
.772 .01049 L
.776 .01052 L
.78 .01054 L
.784 .01054 L
.788 .01052 L
.792 .01051 L
.796 .01049 L
.8 .01048 L
Mistroke
.804 .01048 L
.808 .01049 L
.812 .01051 L
.816 .01053 L
.82 .01055 L
.824 .01057 L
.828 .01057 L
.832 .01057 L
.836 .01056 L
.84 .01055 L
.844 .01054 L
.848 .01054 L
.852 .01055 L
.856 .01056 L
.86 .01058 L
.864 .01059 L
.868 .0106 L
.872 .01061 L
.876 .01063 L
.88 .01063 L
.884 .01064 L
.888 .01063 L
.892 .01061 L
.896 .0106 L
.9 .0106 L
.904 .01061 L
.908 .01063 L
.912 .01065 L
.916 .01066 L
.92 .01067 L
.924 .01068 L
.928 .01068 L
.932 .01068 L
.936 .01068 L
.94 .01068 L
.944 .01067 L
.948 .01068 L
.952 .01068 L
.956 .0107 L
.96 .01071 L
.964 .01073 L
.968 .01073 L
.972 .01074 L
.976 .01073 L
.98 .01074 L
.984 .01073 L
.988 .01073 L
.992 .01072 L
.996 .01075 L
1 .01075 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P000Woo0`00J7oo0003Ool50002
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`800004Ool00000Ool2001WOol0
00Yoo`04001oogoo0008Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`05001oogooOol0001W
Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo00<000Eoo`04001oogoo
Ool2001QOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo00<000Eoo`03
001oogoo00800003Ool007oo05moo`002goo0P002Woo0P000goo0`000goo0`001Goo00@007ooOol0
009oo`03001oogoo05ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P001goo0`00
0goo00<007ooOol0GGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
00eoo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000=oo`D000=oo`80
00Aoo`8000Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool20002Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007oo
Ool0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo009o
o`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2000>Ool00`00Ool00002Ool01000Oomoo`001goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8000ioo`03001oo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0002
Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0
2goo10000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00@007ooOomoo`@000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04
001oogoo0003Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool000]oo`8000Yoo`8000Ao
o`03001oogoo009oo`8000aoo`03001oogoo0080009oo`04001oogoo0006Ool20004Ool01000Oomo
o`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo
0005Ool0029oo`8000aoo`D000=oo`@000Ioo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogoo
Ool50003Ool20004Ool30004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001o
ogoo011oo`03001oogoo009oo`8005Eoo`008Woo0P004Goo00D007ooOomoo`00009oo`03001oogoo
059oo`008WooH`0037oo000ROol01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`09001oogoo
Ool007oo001oo`00009oo`<00005Ool00000001oo`0900000goo001oo`050002Ool200000goo0000
000600001Woo00000000Ool0009oo`8000=oo`08001oo`00Ool007oo001oo`80009oo`05001oogoo
Ool00003Ool00`00Oomoo`0:Ool0029oo`8001=oo`8000Yoo`08001oogoo001oo`00Ool0009oo`80
0004Ool000000002Ool3000017oo000007oo0`0000=oo`0000000`0000Aoo`00001oo`800003Ool0
000001L000aoo`008Woo00<007ooOol07goo0P000goo00<007ooOol0AGoo000ROol2001]Ool0029o
o`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool0
00]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol0
0goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qo
o`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo
000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo
0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000R
Ool00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo
00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Io
o`00:7oo0`00IWoo000XOol00`00Ool00002001TOol000]oo`8000Aoo`03001oogoo00=oo`8000Ao
o`8000=oo`<000=oo`04001oogooOol3001ROol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0003Ool01000Oomoo`001Goo0P00HGoo0003Ool50002Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`001Woo0`00Ggoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`020008Ool2000017oo0000000017oo
0P001goo0`0017oo0P0017oo0P000goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo
1@000Woo0`0017oo0P001Woo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001o
o`040003Ool00`00Oomoo`08Ool30002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool0
0003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`001Woo00<007ooOol02Woo10000Woo00@007ooOol000Moo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`05001oogoo
Ool00004Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool0
0`00Oomoo`03Ool000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo00aoo`D0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo
10000goo1`0017oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo
10000goo00L007ooOol007oo001oo`0K0003Ool01000Oomoo`001Goo000XOol00`00Oomoo`09Ool0
0`00Oomoo`04Ool01000Oomoo`000goo:@0000Eoo`00Oomoo`00009oo`04001oogoo0002Ool01000
Oomoo`000goo00<007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P00
27oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Ao
o`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol0
3goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P00
17oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Ao
o`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<0
07ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001o
ogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04
001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0
KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`0OOol3001@Ool000Yoo`04
001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol067oo1`000gooA00037oo0003Ool50002
Ool01000Oomoo`002goo00<007ooOol00P005Goo1@00FGoo000:Ool01000Oomoo`002goo00@007oo
Ool0019oo`D005eoo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo00eoo`<0069oo`002Woo
00@007ooOol000Moo`03001oogoo00Aoo`8000eoo`8006Aoo`002goo0P0027oo1@000Woo00<007oo
Ool02Woo0`00IGoo000LOol00`00Oomoo`09Ool20002Ool30004Ool20009Ool30004Ool20004Ool2
0005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool0
01aoo`8000Uoo`80009oo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo
00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo
00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol01Woo0P0027oo00@007ooOol0009o
o`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol01Goo
00<007ooOol027oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03
001oogoo00=oo`0077oo0P0017oo0P001goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001o
ogoo0005Ool001aoo`03001oogoo009oo`8000Qoo`03001oogoo00Aoo`04001oogoo0008Ool20004
Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Io
o`04001oogoo0005Ool001aoo`80009oo`8000Uoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Ao
o`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool2
0006Ool001aoo`03001oogoo0080071oo`0077oo00@007oo0000075oo`0077ooJ@0037oo000LOol0
1@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001ao
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007oo
Ool00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@0
00=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P00
27oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol0
0`00Oomoo`02Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol0
0Woo00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000L
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo
0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00
Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03
001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0
LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(48931\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .10311 m
.008 .0989 L
.012 .09524 L
.016 .09417 L
.02 .09554 L
.024 .0986 L
.028 .10336 L
.032 .11043 L
.036 .11934 L
.04 .12958 L
.044 .1407 L
.048 .15231 L
.052 .16372 L
.056 .17423 L
.06 .18324 L
.064 .19022 L
.068 .19477 L
.072 .19668 L
.076 .19601 L
.08 .19309 L
.084 .18848 L
.088 .18293 L
.092 .17732 L
.096 .17256 L
.1 .16954 L
.104 .16892 L
.108 .17115 L
.112 .17632 L
.116 .18418 L
.12 .19417 L
.124 .20553 L
.128 .21736 L
.132 .22877 L
.136 .23904 L
.14 .24771 L
.144 .25465 L
.148 .26014 L
.152 .26476 L
.156 .26926 L
.16 .27438 L
.164 .28066 L
.168 .2883 L
.172 .29707 L
.176 .30631 L
.18 .31502 L
.184 .32202 L
.188 .32617 L
.192 .32661 L
.196 .32298 L
.2 .31559 L
Mistroke
.204 .30539 L
.208 .29388 L
.212 .28282 L
.216 .27389 L
.22 .26841 L
.224 .26708 L
.228 .26988 L
.232 .27607 L
.236 .28441 L
.24 .29339 L
.244 .30156 L
.248 .30787 L
.252 .31177 L
.256 .31335 L
.26 .31313 L
.264 .31185 L
.268 .31024 L
.272 .30878 L
.276 .30764 L
.28 .30674 L
.284 .30591 L
.288 .30506 L
.292 .30437 L
.296 .30426 L
.3 .30535 L
.304 .30818 L
.308 .31301 L
.312 .31954 L
.316 .32686 L
.32 .33356 L
.324 .3381 L
.328 .33924 L
.332 .3365 L
.336 .33045 L
.34 .32259 L
.344 .315 L
.348 .30975 L
.352 .30824 L
.356 .31075 L
.36 .31633 L
.364 .32311 L
.368 .32883 L
.372 .33164 L
.376 .33061 L
.38 .32608 L
.384 .31948 L
.388 .31288 L
.392 .30825 L
.396 .30683 L
.4 .30877 L
Mistroke
.404 .31313 L
.408 .31829 L
.412 .32257 L
.416 .32476 L
.42 .32457 L
.424 .32259 L
.428 .31997 L
.432 .31795 L
.436 .31733 L
.44 .31824 L
.444 .32021 L
.448 .3224 L
.452 .32398 L
.456 .32439 L
.46 .32358 L
.464 .32183 L
.468 .31962 L
.472 .31742 L
.476 .31557 L
.48 .31436 L
.484 .31402 L
.488 .31474 L
.492 .31651 L
.496 .3191 L
.5 .32191 L
.504 .32416 L
.508 .32505 L
.512 .3242 L
.516 .32188 L
.52 .31902 L
.524 .31682 L
.528 .31621 L
.532 .31733 L
.536 .3195 L
.54 .32151 L
.544 .32222 L
.548 .32115 L
.552 .31881 L
.556 .31647 L
.56 .31549 L
.564 .31662 L
.568 .31947 L
.572 .32269 L
.576 .32467 L
.58 .3244 L
.584 .32199 L
.588 .31861 L
.592 .31591 L
.596 .31517 L
.6 .31663 L
Mistroke
.604 .31938 L
.608 .32186 L
.612 .32277 L
.616 .32174 L
.62 .31957 L
.624 .31767 L
.628 .31719 L
.632 .31838 L
.636 .32049 L
.64 .32228 L
.644 .3227 L
.648 .32153 L
.652 .31944 L
.656 .3176 L
.66 .317 L
.664 .31786 L
.668 .31954 L
.672 .32098 L
.676 .32137 L
.68 .32067 L
.684 .31951 L
.688 .31876 L
.692 .31889 L
.696 .31974 L
.7 .32069 L
.704 .32111 L
.708 .32076 L
.712 .31987 L
.716 .31899 L
.72 .31862 L
.724 .31895 L
.728 .31972 L
.732 .32043 L
.736 .32061 L
.74 .3202 L
.744 .31951 L
.748 .31908 L
.752 .31923 L
.756 .31986 L
.76 .32054 L
.764 .32084 L
.768 .32059 L
.772 .31999 L
.776 .31938 L
.78 .31903 L
.784 .31908 L
.788 .31948 L
.792 .3201 L
.796 .32064 L
.8 .3208 L
Mistroke
.804 .32041 L
.808 .31966 L
.812 .31905 L
.816 .31907 L
.82 .31973 L
.824 .32057 L
.828 .32092 L
.832 .32049 L
.836 .31964 L
.84 .31904 L
.844 .31913 L
.848 .31983 L
.852 .32057 L
.856 .32086 L
.86 .32062 L
.864 .32007 L
.868 .31957 L
.872 .31935 L
.876 .31934 L
.88 .31959 L
.884 .32 L
.888 .32039 L
.892 .32063 L
.896 .32057 L
.9 .32022 L
.904 .31995 L
.908 .31989 L
.912 .31987 L
.916 .31985 L
.92 .31963 L
.924 .31939 L
.928 .31972 L
.932 .32044 L
.936 .32107 L
.94 .32121 L
.944 .32038 L
.948 .31922 L
.952 .31886 L
.956 .31935 L
.96 .32037 L
.964 .32118 L
.968 .3208 L
.972 .31979 L
.976 .31938 L
.98 .31961 L
.984 .32046 L
.988 .32125 L
.992 .32064 L
.996 .31944 L
1 .31895 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .18762 m
.008 .183 L
.012 .18179 L
.016 .18404 L
.02 .18548 L
.024 .1861 L
.028 .18718 L
.032 .18879 L
.036 .19036 L
.04 .1919 L
.044 .19347 L
.048 .19512 L
.052 .19672 L
.056 .19831 L
.06 .19985 L
.064 .20141 L
.068 .20296 L
.072 .20456 L
.076 .2062 L
.08 .20793 L
.084 .20974 L
.088 .21168 L
.092 .21371 L
.096 .21586 L
.1 .21807 L
.104 .22035 L
.108 .22263 L
.112 .22489 L
.116 .22709 L
.12 .22919 L
.124 .23116 L
.128 .23301 L
.132 .23471 L
.136 .23629 L
.14 .23773 L
.144 .23908 L
.148 .24034 L
.152 .24153 L
.156 .24265 L
.16 .24369 L
.164 .24465 L
.168 .24551 L
.172 .24625 L
.176 .24688 L
.18 .2474 L
.184 .24782 L
.188 .24817 L
.192 .2485 L
.196 .24884 L
.2 .24926 L
Mistroke
.204 .24978 L
.208 .25044 L
.212 .25123 L
.216 .25213 L
.22 .25312 L
.224 .25414 L
.228 .25515 L
.232 .25609 L
.236 .25694 L
.24 .25767 L
.244 .25828 L
.248 .25878 L
.252 .25921 L
.256 .25958 L
.26 .25992 L
.264 .26027 L
.268 .26062 L
.272 .26099 L
.276 .26138 L
.28 .26177 L
.284 .26217 L
.288 .26256 L
.292 .26293 L
.296 .26325 L
.3 .26352 L
.304 .26371 L
.308 .2638 L
.312 .26376 L
.316 .2636 L
.32 .26332 L
.324 .26296 L
.328 .26256 L
.332 .26217 L
.336 .26184 L
.34 .26161 L
.344 .26148 L
.348 .26144 L
.352 .26146 L
.356 .26149 L
.36 .26149 L
.364 .26144 L
.368 .26133 L
.372 .26119 L
.376 .26104 L
.38 .26093 L
.384 .26088 L
.388 .26091 L
.392 .26102 L
.396 .26117 L
.4 .26133 L
Mistroke
.404 .26147 L
.408 .26157 L
.412 .26161 L
.416 .2616 L
.42 .26156 L
.424 .26149 L
.428 .26142 L
.432 .26135 L
.436 .26127 L
.44 .26118 L
.444 .26107 L
.448 .26094 L
.452 .26079 L
.456 .26064 L
.46 .26051 L
.464 .26042 L
.468 .26039 L
.472 .26042 L
.476 .26051 L
.48 .26063 L
.484 .26076 L
.488 .26087 L
.492 .26094 L
.496 .26095 L
.5 .26089 L
.504 .26078 L
.508 .26062 L
.512 .26046 L
.516 .26032 L
.52 .26022 L
.524 .26017 L
.528 .26015 L
.532 .26015 L
.536 .26017 L
.54 .26018 L
.544 .26019 L
.548 .2602 L
.552 .26021 L
.556 .26022 L
.56 .26022 L
.564 .2602 L
.568 .26015 L
.572 .26006 L
.576 .25995 L
.58 .25985 L
.584 .25977 L
.588 .25973 L
.592 .25972 L
.596 .25974 L
.6 .25977 L
Mistroke
.604 .25978 L
.608 .25977 L
.612 .25974 L
.616 .2597 L
.62 .25966 L
.624 .25964 L
.628 .25961 L
.632 .25957 L
.636 .25952 L
.64 .25946 L
.644 .25939 L
.648 .25932 L
.652 .25927 L
.656 .25925 L
.66 .25925 L
.664 .25927 L
.668 .25928 L
.672 .25927 L
.676 .25925 L
.68 .25922 L
.684 .25918 L
.688 .25914 L
.692 .25909 L
.696 .25903 L
.7 .25898 L
.704 .25892 L
.708 .25887 L
.712 .25883 L
.716 .25882 L
.72 .25882 L
.724 .25883 L
.728 .25883 L
.732 .25882 L
.736 .25878 L
.74 .25873 L
.744 .25866 L
.748 .2586 L
.752 .25856 L
.756 .25852 L
.76 .2585 L
.764 .25849 L
.768 .25848 L
.772 .25846 L
.776 .25843 L
.78 .2584 L
.784 .25837 L
.788 .25832 L
.792 .25828 L
.796 .25823 L
.8 .25819 L
Mistroke
.804 .25816 L
.808 .25814 L
.812 .25813 L
.816 .25812 L
.82 .2581 L
.824 .25808 L
.828 .25804 L
.832 .25799 L
.836 .25794 L
.84 .25789 L
.844 .25785 L
.848 .25781 L
.852 .25778 L
.856 .25777 L
.86 .25776 L
.864 .25775 L
.868 .25774 L
.872 .25771 L
.876 .25767 L
.88 .25761 L
.884 .25756 L
.888 .25751 L
.892 .25747 L
.896 .25745 L
.9 .25744 L
.904 .25743 L
.908 .25741 L
.912 .25738 L
.916 .25734 L
.92 .2573 L
.924 .25726 L
.928 .25722 L
.932 .25719 L
.936 .25716 L
.94 .25714 L
.944 .25711 L
.948 .25709 L
.952 .25706 L
.956 .25703 L
.96 .25698 L
.964 .25694 L
.968 .2569 L
.972 .25687 L
.976 .25685 L
.98 .25684 L
.984 .25681 L
.988 .25679 L
.992 .25676 L
.996 .25673 L
1 .25668 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15605 L
.012 .14963 L
.016 .14389 L
.02 .13875 L
.024 .13337 L
.028 .12807 L
.032 .1231 L
.036 .11848 L
.04 .11401 L
.044 .10984 L
.048 .10593 L
.052 .10235 L
.056 .09897 L
.06 .09585 L
.064 .09288 L
.068 .09009 L
.072 .08736 L
.076 .0847 L
.08 .08202 L
.084 .07931 L
.088 .07652 L
.092 .07366 L
.096 .07072 L
.1 .06772 L
.104 .06469 L
.108 .06167 L
.112 .05871 L
.116 .05584 L
.12 .05311 L
.124 .05054 L
.128 .04816 L
.132 .04596 L
.136 .04393 L
.14 .04206 L
.144 .04031 L
.148 .03869 L
.152 .03716 L
.156 .03573 L
.16 .03438 L
.164 .03315 L
.168 .03203 L
.172 .03106 L
.176 .03023 L
.18 .02956 L
.184 .029 L
.188 .02853 L
.192 .02809 L
.196 .02762 L
.2 .02707 L
Mistroke
.204 .02638 L
.208 .02553 L
.212 .02452 L
.216 .02336 L
.22 .0221 L
.224 .02079 L
.228 .0195 L
.232 .01829 L
.236 .0172 L
.24 .01626 L
.244 .01546 L
.248 .0148 L
.252 .01424 L
.256 .01374 L
.26 .01328 L
.264 .01281 L
.268 .01234 L
.272 .01184 L
.276 .01133 L
.28 .0108 L
.284 .01027 L
.288 .00975 L
.292 .00926 L
.296 .00882 L
.3 .00844 L
.304 .00817 L
.308 .00803 L
.312 .00804 L
.316 .00821 L
.32 .00852 L
.324 .00894 L
.328 .0094 L
.332 .00984 L
.336 .01022 L
.34 .01048 L
.344 .01061 L
.348 .01063 L
.352 .01057 L
.356 .0105 L
.36 .01046 L
.364 .01048 L
.368 .01058 L
.372 .01073 L
.376 .01088 L
.38 .01099 L
.384 .01101 L
.388 .01094 L
.392 .01077 L
.396 .01054 L
.4 .0103 L
Mistroke
.404 .01009 L
.408 .00994 L
.412 .00986 L
.416 .00984 L
.42 .00986 L
.424 .0099 L
.428 .00995 L
.432 .01 L
.436 .01006 L
.44 .01014 L
.444 .01025 L
.448 .01039 L
.452 .01054 L
.456 .0107 L
.46 .01082 L
.464 .01089 L
.468 .01089 L
.472 .01082 L
.476 .01068 L
.48 .01049 L
.484 .0103 L
.488 .01012 L
.492 .01 L
.496 .00996 L
.5 .01 L
.504 .01011 L
.508 .01026 L
.512 .01042 L
.516 .01056 L
.52 .01065 L
.524 .01069 L
.528 .01068 L
.532 .01064 L
.536 .01059 L
.54 .01054 L
.544 .01049 L
.548 .01045 L
.552 .0104 L
.556 .01035 L
.56 .01032 L
.564 .01031 L
.568 .01034 L
.572 .01041 L
.576 .01051 L
.58 .01061 L
.584 .01068 L
.588 .01071 L
.592 .01068 L
.596 .01062 L
.6 .01054 L
Mistroke
.604 .01048 L
.608 .01045 L
.612 .01046 L
.616 .01048 L
.62 .0105 L
.624 .01051 L
.628 .01052 L
.632 .01053 L
.636 .01055 L
.64 .01058 L
.644 .01063 L
.648 .01068 L
.652 .0107 L
.656 .0107 L
.66 .01067 L
.664 .01063 L
.668 .01059 L
.672 .01056 L
.676 .01054 L
.68 .01054 L
.684 .01056 L
.688 .01057 L
.692 .0106 L
.696 .01063 L
.7 .01067 L
.704 .01071 L
.708 .01075 L
.712 .01076 L
.716 .01075 L
.72 .01071 L
.724 .01067 L
.728 .01063 L
.732 .0106 L
.736 .01061 L
.74 .01064 L
.744 .01068 L
.748 .01072 L
.752 .01075 L
.756 .01077 L
.76 .01077 L
.764 .01076 L
.768 .01074 L
.772 .01072 L
.776 .01071 L
.78 .0107 L
.784 .01071 L
.788 .01073 L
.792 .01076 L
.796 .0108 L
.8 .01082 L
Mistroke
.804 .01083 L
.808 .01081 L
.812 .01078 L
.816 .01075 L
.82 .01074 L
.824 .01074 L
.828 .01077 L
.832 .01081 L
.836 .01084 L
.84 .01086 L
.844 .01086 L
.848 .01085 L
.852 .01084 L
.856 .01083 L
.86 .01083 L
.864 .01083 L
.868 .01084 L
.872 .01085 L
.876 .01087 L
.88 .01087 L
.884 .01088 L
.888 .01087 L
.892 .01087 L
.896 .01087 L
.9 .01088 L
.904 .0109 L
.908 .01092 L
.912 .01093 L
.916 .01094 L
.92 .01093 L
.924 .01093 L
.928 .01091 L
.932 .01091 L
.936 .01091 L
.94 .01092 L
.944 .01094 L
.948 .01096 L
.952 .01097 L
.956 .01099 L
.96 .01098 L
.964 .01098 L
.968 .01097 L
.972 .01097 L
.976 .01097 L
.98 .01098 L
.984 .01099 L
.988 .01101 L
.992 .01102 L
.996 .01104 L
1 .01103 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo00@006]oo`002goo0P002Woo0P000goo0`000goo00@007ooOol006]oo`00
8Woo0P000Woo00<007ooOol0J7oo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool01@00
Oomoogoo0000JWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool20002
Ool00`00Oomoo`1XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P000goo00<007ooOol0Igoo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`05001oogoo
Ool00004Ool00`00Oomoo`1WOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001o
ogoo008000Aoo`04001oogooOol2001SOol000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=o
o`03001oogoo008000Aoo`06001oogoo001oo`00Hgoo000;Ool2000:Ool20003Ool30003Ool00`00
Oomoo`03Ool30003Ool00`00Oomoo`1POol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=o
o`8000Eoo`03001oogoo009oo`03001oogoo061oo`002Woo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2000:Ool00`00Oomoo`030004Ool20007Ool30004Ool20004Ool20005Ool3
0003Ool30004Ool20003Ool50003Ool20004Ool20004Ool50002Ool30004Ool20006Ool000=oo`D0
009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol02Woo0P000goo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00
Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P002goo00<0
07ooOol00Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo
00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2000;Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`00009o
o`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol0
0goo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00]oo`@000=oo`04
001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol4
0003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo
00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool00`00Oomoo`02
Ool2000<Ool20005Ool200000goo001oo`05Ool20004Ool01000Oomoo`000Woo00@007ooOol000Ao
o`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0029oo`8000aoo`D0
009oo`<000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20004Ool30004
Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo00eoo`8000=oo`03001o
o`0005Moo`008Woo0P003goo00@007ooOol000=oo`03001oogoo05Aoo`008WooH`0037oo000ROol0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oo`00Ool00003Ool40002Ool20002Ool2
0002Ool300000goo00000002Ool30002Ool2000017oo000007oo0`0000Aoo`00001oo`D00004Ool0
0000Ool200000goo0000000300000goo001oo`02Ool01P00Oomoogoo001oo`<000=oo`03001oogoo
00Yoo`008Woo0P0047oo0P002goo00<007oo00000Woo0`0000=oo`0000001@000Woo0P0000=oo`00
0000100000=oo`0000009@003Goo000ROol00`00Oomoo`0LOol30002Ool20019Ool0029oo`8006eo
o`008Woo0P00KGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/Ool0
00Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`80
06eoo`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00
Oomoo`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2
001]Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04
001oogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001o
ogoo0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol0
0P00KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2
000:Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]
Ool0029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0
00=oo`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo
1@000Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<0
07ooOol0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool0009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol0
0goo0P0017oo0P000goo0`000goo0P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06
001oogoo001oo`000goo00<007ooOol01@00I7oo0003Ool50002Ool01000Oomoo`0027oo00@007oo
Ool0009oo`04001oogoo0005Ool01000Oomoo`000goo0`00HWoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`020005Ool20004Ool30004Ool20007Ool30004
Ool20004Ool20003Ool30003Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004
Ool20006Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`03
001oogoo00Ioo`800003Ool007oo009oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`00
00=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0006Ool00`00Oomoo`08Ool30002Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0
2Woo1@0000Eoo`00Oomoo`0000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomo
o`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo
00<007ooOol02Goo100000=oo`0000001@001Woo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0003Ool01000Oomoogoo10000goo00L007ooOol007oo001oo`0K0003Ool01000Oomoo`001Goo
000XOol00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`0_0002Ool01000Oomoo`000Woo00@0
07ooOol0009oo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo
1@000goo0P0027oo00<007ooOol00goo0P0017oo0P0017oo00@007ooOomoo`D000=oo`8000=oo`<0
00Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`8000Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol002Qooed000aoo`00:7oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo
00<007ooOol03goo00<007ooOol047oo00<007ooOol02Woo000XOol00`00Oomoo`1VOol002Qoo`03
001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Io
o`002goo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`1VOol000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`80
00Yoo`8000Aoo`80009oo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00
Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo
0P0017oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Ao
o`03001oogoo00=oo`8000=oo`<000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool01@00Oomoogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007oo
Ool000=oo`04001oogooOol4001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo
00<007ooOol0KGoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`0LOol3001C
Ool000Yoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol05Woo1`000WooA`0037oo
0003Ool50002Ool01000Oomoo`002goo00<007ooOol00P004Woo1@00G7oo000:Ool01000Oomoo`00
2goo00@007ooOol000moo`D0061oo`002Woo00@007ooOol000Moo`@000=oo`03001oogoo00]oo`<0
06Aoo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8000Yoo`8006Moo`002goo0P0027oo1@00
0Woo00<007ooOol027oo0P00J7oo000LOol00`00Oomoo`07Ool20004Ool30004Ool20009Ool30004
Ool20004Ool20005Ool30003Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004
Ool20006Ool001aoo`8000Ioo`8000Eoo`05001oogooOol00002Ool01000Oomoo`002Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009o
o`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo
001oo`000goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol017oo0P002Woo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`001Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<0
07ooOol00goo00<007ooOol02Woo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eo
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo0P000Woo0P002Goo10000goo00@007ooOol000Uoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@0
00=oo`04001oogoo0005Ool001aoo`05001oogooOol0000:Ool00`00Oomoo`04Ool01000Oomoo`00
27oo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00Oomoo`04Ool01000Oomo
o`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00L007ooOomoo`00
Ool00006Ool01000Oomoo`001Goo000LOol200000goo001oo`0:Ool50003Ool2000:Ool00`00Oomo
o`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P001Woo0`0017oo0P0017oo0P001Woo0`00
0Woo1@000goo0P001Woo000LOol00`00Ool0001bOol001aoo`8007=oo`0077ooJ@0037oo000LOol0
1@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo
000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001ao
o`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001o
ogoo0007Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007oo
Ool00P00Lgoo000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@0
00=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P00
27oo1@000Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001Ioo`<000=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol0
0`00Oomoo`02Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol0
0Woo00<007ooOol0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079o
o`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000L
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo
0P00Lgoo000;Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00
Oomoo`0;Ool01000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03
001oogoo00Moo`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0
LWoo000;Ool00`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007oo
Ool0LWoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(49098\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .06319 m
.008 .06615 L
.012 .07214 L
.016 .0814 L
.02 .09338 L
.024 .1059 L
.028 .11797 L
.032 .12986 L
.036 .14072 L
.04 .14963 L
.044 .15598 L
.048 .15992 L
.052 .16147 L
.056 .161 L
.06 .15904 L
.064 .15647 L
.068 .15414 L
.072 .15293 L
.076 .1536 L
.08 .15672 L
.084 .16253 L
.088 .17097 L
.092 .18163 L
.096 .19383 L
.1 .20674 L
.104 .21946 L
.108 .23122 L
.112 .24141 L
.116 .24978 L
.12 .25643 L
.124 .26179 L
.128 .26656 L
.132 .27149 L
.136 .27725 L
.14 .28424 L
.144 .29245 L
.148 .30146 L
.152 .31045 L
.156 .31829 L
.16 .32379 L
.164 .32595 L
.168 .32416 L
.172 .31841 L
.176 .30937 L
.18 .29828 L
.184 .28678 L
.188 .2766 L
.192 .26929 L
.196 .2659 L
.2 .26679 L
Mistroke
.204 .27162 L
.208 .27937 L
.212 .28856 L
.216 .29765 L
.22 .30526 L
.224 .31056 L
.228 .31329 L
.232 .31377 L
.236 .31269 L
.24 .31085 L
.244 .30895 L
.248 .30739 L
.252 .30629 L
.256 .30554 L
.26 .30499 L
.264 .30457 L
.268 .3045 L
.272 .30519 L
.276 .30719 L
.28 .31095 L
.284 .31651 L
.288 .32333 L
.292 .33031 L
.296 .33601 L
.3 .33902 L
.304 .33843 L
.308 .3342 L
.312 .32726 L
.316 .31933 L
.32 .31248 L
.324 .30853 L
.328 .30849 L
.332 .31223 L
.336 .31849 L
.34 .3252 L
.344 .33018 L
.348 .33176 L
.352 .32939 L
.356 .3238 L
.36 .31674 L
.364 .31041 L
.368 .30668 L
.372 .30651 L
.376 .30965 L
.38 .3148 L
.384 .32014 L
.388 .32399 L
.392 .32543 L
.396 .32447 L
.4 .322 L
Mistroke
.404 .31929 L
.408 .31753 L
.412 .31735 L
.416 .31868 L
.42 .32085 L
.424 .32295 L
.428 .3242 L
.432 .32419 L
.436 .32294 L
.44 .32084 L
.444 .31842 L
.448 .31621 L
.452 .31459 L
.456 .31383 L
.46 .31409 L
.464 .31541 L
.468 .31763 L
.472 .32035 L
.476 .32291 L
.48 .32458 L
.484 .32481 L
.488 .32348 L
.492 .32104 L
.496 .31837 L
.5 .31651 L
.504 .31617 L
.508 .31739 L
.512 .31945 L
.516 .32125 L
.52 .32182 L
.524 .32081 L
.528 .31873 L
.532 .3167 L
.536 .3159 L
.54 .31698 L
.544 .31962 L
.548 .32262 L
.552 .32449 L
.556 .3242 L
.56 .32179 L
.564 .31839 L
.568 .31562 L
.572 .31479 L
.576 .31622 L
.58 .31909 L
.584 .32186 L
.588 .32311 L
.592 .32227 L
.596 .31998 L
.6 .31769 L
Mistroke
.604 .31678 L
.608 .31777 L
.612 .32004 L
.616 .32221 L
.62 .32301 L
.624 .32195 L
.628 .31964 L
.632 .31734 L
.636 .3163 L
.64 .31702 L
.644 .31901 L
.648 .32107 L
.652 .32206 L
.656 .32155 L
.66 .32004 L
.664 .31858 L
.668 .31809 L
.672 .31876 L
.676 .32007 L
.68 .32117 L
.684 .32138 L
.688 .32062 L
.692 .31937 L
.696 .31833 L
.7 .31807 L
.704 .31868 L
.708 .31976 L
.712 .3207 L
.716 .32098 L
.72 .32054 L
.724 .31974 L
.728 .3191 L
.732 .31897 L
.736 .31935 L
.74 .31996 L
.744 .32044 L
.748 .32058 L
.752 .32031 L
.756 .31977 L
.76 .3192 L
.764 .3189 L
.768 .31905 L
.772 .31963 L
.776 .32031 L
.78 .32071 L
.784 .32058 L
.788 .32005 L
.792 .31952 L
.796 .31931 L
.8 .31948 L
Mistroke
.804 .31975 L
.808 .31986 L
.812 .31983 L
.816 .31982 L
.82 .31999 L
.824 .32029 L
.828 .32042 L
.832 .32022 L
.836 .31978 L
.84 .31936 L
.844 .31925 L
.848 .3195 L
.852 .3199 L
.856 .32026 L
.86 .3204 L
.864 .32025 L
.868 .31996 L
.872 .31967 L
.876 .31958 L
.88 .31989 L
.884 .32035 L
.888 .32055 L
.892 .32028 L
.896 .31955 L
.9 .3189 L
.904 .31904 L
.908 .31987 L
.912 .32085 L
.916 .32128 L
.92 .32069 L
.924 .31969 L
.928 .3192 L
.932 .3194 L
.936 .32005 L
.94 .32045 L
.944 .32003 L
.948 .31943 L
.952 .31949 L
.956 .32014 L
.96 .32105 L
.964 .32134 L
.968 .32033 L
.972 .31909 L
.976 .31868 L
.98 .31918 L
.984 .32046 L
.988 .32132 L
.992 .32074 L
.996 .31977 L
1 .31941 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .21777 m
.008 .2181 L
.012 .21803 L
.016 .21757 L
.02 .21736 L
.024 .21724 L
.028 .21692 L
.032 .21661 L
.036 .21641 L
.04 .21633 L
.044 .21633 L
.048 .21651 L
.052 .21687 L
.056 .21747 L
.06 .21827 L
.064 .21932 L
.068 .22056 L
.072 .22202 L
.076 .22362 L
.08 .22536 L
.084 .22714 L
.088 .22896 L
.092 .23074 L
.096 .23248 L
.1 .23412 L
.104 .23566 L
.108 .2371 L
.112 .23844 L
.116 .23968 L
.12 .24086 L
.124 .24197 L
.128 .24302 L
.132 .24402 L
.136 .24494 L
.14 .24579 L
.144 .24654 L
.148 .24718 L
.152 .24772 L
.156 .24816 L
.16 .24852 L
.164 .24884 L
.168 .24916 L
.172 .24954 L
.176 .25 L
.18 .25059 L
.184 .25132 L
.188 .25216 L
.192 .25311 L
.196 .25412 L
.2 .25513 L
Mistroke
.204 .25611 L
.208 .257 L
.212 .25778 L
.216 .25844 L
.22 .25898 L
.224 .25942 L
.228 .2598 L
.232 .26015 L
.236 .26048 L
.24 .26083 L
.244 .26118 L
.248 .26156 L
.252 .26194 L
.256 .26234 L
.26 .26273 L
.264 .2631 L
.268 .26344 L
.272 .26372 L
.276 .26394 L
.28 .26406 L
.284 .26407 L
.288 .26396 L
.292 .26373 L
.296 .2634 L
.3 .26302 L
.304 .26262 L
.308 .26226 L
.312 .26198 L
.316 .26179 L
.32 .2617 L
.324 .26169 L
.328 .26172 L
.332 .26175 L
.336 .26174 L
.34 .26168 L
.344 .26156 L
.348 .26142 L
.352 .26129 L
.356 .2612 L
.36 .26118 L
.364 .26125 L
.368 .26138 L
.372 .26154 L
.376 .26171 L
.38 .26183 L
.384 .2619 L
.388 .26192 L
.392 .26188 L
.396 .26182 L
.4 .26174 L
Mistroke
.404 .26166 L
.408 .26158 L
.412 .2615 L
.416 .2614 L
.42 .26127 L
.424 .26114 L
.428 .26099 L
.432 .26086 L
.436 .26075 L
.44 .2607 L
.444 .2607 L
.448 .26076 L
.452 .26086 L
.456 .26098 L
.46 .26111 L
.464 .2612 L
.468 .26124 L
.472 .26122 L
.476 .26113 L
.48 .26099 L
.484 .26083 L
.488 .26068 L
.492 .26055 L
.496 .26047 L
.5 .26043 L
.504 .26043 L
.508 .26044 L
.512 .26047 L
.516 .26048 L
.52 .2605 L
.524 .2605 L
.528 .26051 L
.532 .26051 L
.536 .26049 L
.54 .26046 L
.544 .26039 L
.548 .2603 L
.552 .2602 L
.556 .2601 L
.56 .26003 L
.564 .26 L
.568 .26 L
.572 .26003 L
.576 .26006 L
.58 .26008 L
.584 .26006 L
.588 .26003 L
.592 .25998 L
.596 .25993 L
.6 .25989 L
Mistroke
.604 .25986 L
.608 .25983 L
.612 .25978 L
.616 .25972 L
.62 .25966 L
.624 .25959 L
.628 .25955 L
.632 .25953 L
.636 .25953 L
.64 .25955 L
.644 .25956 L
.648 .25956 L
.652 .25954 L
.656 .2595 L
.66 .25945 L
.664 .2594 L
.668 .25934 L
.672 .25929 L
.676 .25923 L
.68 .25918 L
.684 .25914 L
.688 .25911 L
.692 .2591 L
.696 .25911 L
.7 .25911 L
.704 .25911 L
.708 .25909 L
.712 .25905 L
.716 .25899 L
.72 .25893 L
.724 .25887 L
.728 .25882 L
.732 .25879 L
.736 .25878 L
.74 .25876 L
.744 .25875 L
.748 .25874 L
.752 .25872 L
.756 .25868 L
.76 .25864 L
.764 .25859 L
.768 .25854 L
.772 .25849 L
.776 .25845 L
.78 .25843 L
.784 .25842 L
.788 .25842 L
.792 .25841 L
.796 .25839 L
.8 .25835 L
Mistroke
.804 .2583 L
.808 .25824 L
.812 .25819 L
.816 .25815 L
.82 .25812 L
.824 .2581 L
.828 .25808 L
.832 .25807 L
.836 .25804 L
.84 .25802 L
.844 .25799 L
.848 .25796 L
.852 .25792 L
.856 .25789 L
.86 .25785 L
.864 .25781 L
.868 .25777 L
.872 .25774 L
.876 .25771 L
.88 .25768 L
.884 .25766 L
.888 .25763 L
.892 .25761 L
.896 .25758 L
.9 .25755 L
.904 .25752 L
.908 .25748 L
.912 .25744 L
.916 .2574 L
.92 .25737 L
.924 .25734 L
.928 .25732 L
.932 .2573 L
.936 .25727 L
.94 .25724 L
.944 .2572 L
.948 .25717 L
.952 .25713 L
.956 .2571 L
.96 .25707 L
.964 .25704 L
.968 .25701 L
.972 .25699 L
.976 .25696 L
.98 .25693 L
.984 .25689 L
.988 .25686 L
.992 .25681 L
.996 .25679 L
1 .25675 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15799 L
.012 .14791 L
.016 .14025 L
.02 .1351 L
.024 .12944 L
.028 .12329 L
.032 .11765 L
.036 .11258 L
.04 .10769 L
.044 .10297 L
.048 .09846 L
.052 .09418 L
.056 .08999 L
.06 .08592 L
.064 .08189 L
.068 .07795 L
.072 .07406 L
.076 .07026 L
.08 .06655 L
.084 .06298 L
.088 .05957 L
.092 .05636 L
.096 .05337 L
.1 .05062 L
.104 .04809 L
.108 .04579 L
.112 .04369 L
.116 .04176 L
.12 .03998 L
.124 .03833 L
.128 .03679 L
.132 .03536 L
.136 .03403 L
.14 .03283 L
.144 .03176 L
.148 .03085 L
.152 .03008 L
.156 .02945 L
.16 .02892 L
.164 .02844 L
.168 .02797 L
.172 .02745 L
.176 .02681 L
.18 .02603 L
.184 .02509 L
.188 .02398 L
.192 .02276 L
.196 .02146 L
.2 .02015 L
Mistroke
.204 .0189 L
.208 .01776 L
.212 .01675 L
.216 .01589 L
.22 .01518 L
.224 .01458 L
.228 .01407 L
.232 .01361 L
.236 .01316 L
.24 .0127 L
.244 .01222 L
.248 .01171 L
.252 .01119 L
.256 .01066 L
.26 .01015 L
.264 .00965 L
.268 .0092 L
.272 .00881 L
.276 .0085 L
.28 .00832 L
.284 .00827 L
.288 .00837 L
.292 .00862 L
.296 .00899 L
.3 .00943 L
.304 .00989 L
.308 .01031 L
.312 .01063 L
.316 .01083 L
.32 .01091 L
.324 .01088 L
.328 .0108 L
.332 .01073 L
.336 .01071 L
.34 .01076 L
.344 .01087 L
.348 .01102 L
.352 .01115 L
.356 .01122 L
.36 .0112 L
.364 .01109 L
.368 .01089 L
.372 .01066 L
.376 .01042 L
.38 .01023 L
.384 .0101 L
.388 .01004 L
.392 .01005 L
.396 .0101 L
.4 .01016 L
Mistroke
.404 .01023 L
.408 .0103 L
.412 .01037 L
.416 .01045 L
.42 .01057 L
.424 .0107 L
.428 .01085 L
.432 .01099 L
.436 .01109 L
.44 .01113 L
.444 .01109 L
.448 .01098 L
.452 .01081 L
.456 .01062 L
.46 .01043 L
.464 .01028 L
.468 .0102 L
.472 .0102 L
.476 .01028 L
.48 .01041 L
.484 .01057 L
.488 .01073 L
.492 .01085 L
.496 .01092 L
.5 .01094 L
.504 .01091 L
.508 .01085 L
.512 .01079 L
.516 .01073 L
.52 .01069 L
.524 .01064 L
.528 .0106 L
.532 .01057 L
.536 .01055 L
.54 .01056 L
.544 .01061 L
.548 .01069 L
.552 .01078 L
.556 .01087 L
.56 .01093 L
.564 .01093 L
.568 .01089 L
.572 .01082 L
.576 .01075 L
.58 .0107 L
.584 .01068 L
.588 .01069 L
.592 .01071 L
.596 .01073 L
.6 .01075 L
Mistroke
.604 .01076 L
.608 .01077 L
.612 .0108 L
.616 .01084 L
.62 .01089 L
.624 .01092 L
.628 .01094 L
.632 .01092 L
.636 .01088 L
.64 .01083 L
.644 .01079 L
.648 .01077 L
.652 .01077 L
.656 .01078 L
.66 .0108 L
.664 .01083 L
.668 .01085 L
.672 .01088 L
.676 .01091 L
.68 .01095 L
.684 .01097 L
.688 .01098 L
.692 .01096 L
.696 .01093 L
.7 .01088 L
.704 .01085 L
.708 .01083 L
.712 .01085 L
.716 .01088 L
.72 .01093 L
.724 .01097 L
.728 .01099 L
.732 .011 L
.736 .01099 L
.74 .01098 L
.744 .01096 L
.748 .01094 L
.752 .01094 L
.756 .01094 L
.76 .01095 L
.764 .01097 L
.768 .011 L
.772 .01102 L
.776 .01104 L
.78 .01105 L
.784 .01103 L
.788 .01101 L
.792 .01099 L
.796 .01098 L
.8 .01098 L
Mistroke
.804 .011 L
.808 .01103 L
.812 .01106 L
.816 .01108 L
.82 .0111 L
.824 .0111 L
.828 .01109 L
.832 .01107 L
.836 .01105 L
.84 .01104 L
.844 .01104 L
.848 .01106 L
.852 .01108 L
.856 .01111 L
.86 .01113 L
.864 .01114 L
.868 .01113 L
.872 .01111 L
.876 .0111 L
.88 .0111 L
.884 .01111 L
.888 .01114 L
.892 .01116 L
.896 .01118 L
.9 .01118 L
.904 .01117 L
.908 .01116 L
.912 .01114 L
.916 .01113 L
.92 .01114 L
.924 .01116 L
.928 .01119 L
.932 .01122 L
.936 .01123 L
.94 .01124 L
.944 .01123 L
.948 .01122 L
.952 .0112 L
.956 .01119 L
.96 .01119 L
.964 .01121 L
.968 .01123 L
.972 .01126 L
.976 .01127 L
.98 .01128 L
.984 .01127 L
.988 .01127 L
.992 .01125 L
.996 .01126 L
1 .01125 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oo`0006aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`03001/Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo00<006aoo`002goo0P002Woo0P000goo0`000goo00<007oo0000K7oo000R
Ool200000goo001oo`1ZOol000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`04001oogoo
001[Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`80009oo`03001o
ogoo06Qoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20002
Ool00`00Oomoo`02001VOol000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00D007ooOomoo`00
00=oo`<00003Ool007oo06Eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007oo
Ool00P001goo00<007ooOol0Hgoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00
Oomoo`020007Ool00`00Oomoo`1SOol000]oo`8000Yoo`8000=oo`<000=oo`03001oogoo00Moo`03
001oogoo069oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P0027oo00<007ooOol0
HWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Qoo`03001oogoo
009oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000=oo`D000=oo`80
00Aoo`8000Aoo`D0009oo`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`07Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`00
00=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool0
0`00Oomoo`02Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P002Goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20009Ool00`00Oomoo`04Ool01000Oomoo`00
0Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`00009oo`04001oogoo0002Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomo
o`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo00Qoo`800003Ool00000008000=oo`04001o
ogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003
Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00H0
07ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool2
000:Ool30004Ool30002Ool00`00Oomoo`04Ool20004Ool01000Oomoo`000Woo00@007ooOol000Ao
o`8000=oo`03001oogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo0003Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool0029oo`8000]oo`P0
0003Ool0000000Qoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20004Ool3
0004Ool20004Ool20005Ool30002Ool50003Ool20006Ool0029oo`03001oogoo00]oo`07001oogoo
Ool007oo0000FWoo000ROol2000<Ool01@00Oomoogoo00000Woo00<007ooOol0Egoo000ROomS000<
Ool0029oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo0`000Woo00<007oo00000P000Woo
0P000Woo0`0000Eoo`00000007oo00<00003Ool0000000T00006Ool00000001oo`000Woo0P0000Ao
o`00001oo`@0009oo`80009oo`05001oogooOol00003Ool01000Ool007oo0P000Woo0`0000=oo`00
Ool02goo000ROol2000>Ool2000:Ool01@00Oomoo`00Ool00`000Woo0P0000Aoo`000000009oo`<0
0004Ool00000Ool3000017oo000007oo0P0000Aoo`00001ooaH00003Ool0000000@00004Ool00000
000<Ool0029oo`03001oogoo01Yoo`8000=oo`03001oogoo04Yoo`008Woo0P00KGoo000ROol2001]
Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo06aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo0P00KGoo000;Ool2
000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`80
009oo`D0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo
0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06ao
o`002Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoogoo0P00KGoo000:Ool01000Oomo
o`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=oo`<000=oo`8006eoo`008Woo
00<007ooOol0K7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool2001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0005Ool01000Oomoo`00KWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`80
00=oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`04001oogoo001^Ool000]oo`8000Yoo`8000=o
o`<000=oo`8006eoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<0
07ooOol0K7oo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001o
ogoo00=oo`8000=oo`<000=oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00
Oomoogoo00000goo00<007ooOol0JGoo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007oo
Oomoo`@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20003Ool0
0`00Oomoo`04Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`04001oogooOol50002Ool00`00
Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
015oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol000Uoo`D0009oo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00Igoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P00
17oo00<007ooOol0IWoo000AOol2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool2
0003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007oo
Ool007oo0003Ool01000Oomoo`00J7oo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04
001oogoo0005Ool00`00Oomoo`02000;Ool30004Ool20007Ool30004Ool20004Ool20003Ool30003
Ool30004Ool20002Ool50003Ool20004Ool20003Ool50002Ool30004Ool20006Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`000Woo00D007ooOol007oo00@000=oo`P000Aoo`05001oogooOol00002
Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomo
ogoo00000goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009o
o`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool0
1000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol01Goo0`001Goo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0goo00<007ooOol01Goo00@007ooOol0009oo`05001oogooOol00004Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool000]oo`8000Yoo`80
00Aoo`80009oo`D0009oo`03001oogoo00Moo`D00005Ool007ooOol00002Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00=oo`03001o
ogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool002Qoo`03001oogoo00Uoo`T00003Ool007oo
00Ioo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=oo`06
001oogoo001oo`000Woo6P000goo00@007ooOol000Eoo`00:7oo00<007ooOol02Goo00<007ooOol0
17oo<00000Eoo`00Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo00001Woo
00@007ooOol000Eoo`00:7oo00<007ooOol02Goo1@000goo0P0027oo00<007ooOol00goo0P0017oo
0P0017oo00@007ooOomoo`D000=oo`8000=oo`<000Aoo`8000Aoo`8000Aoo`<0009oo`D000=oo`80
00Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qooed000aoo`00:7oo00<007oo
Ool03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007oo
Ool02Woo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P0017oo
0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001o
ogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo
001oo`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007oo
Ool007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009oo`03001oogoo
06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03001oogoo00=o
o`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`80
06Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0
011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000AOol2000:Ool2
0004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`<000=o
o`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomoogoo00000goo
00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00
Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007oo
Ool0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/Ool000Yoo`04
001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:Ool20004Ool0
1000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo
002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004Ool00`00
Oomoo`02Ool30003Ool00`00Oomoo`0JOol2001FOol000Yoo`04001oogoo0007Ool01@00Oomoogoo
00000Woo00<007ooOol04goo1`0000=oo`000000B@0037oo0003Ool50002Ool01000Oomoo`002goo
00<007ooOol00P0047oo1000Ggoo000:Ool01000Oomoo`002goo00@007ooOol000aoo`H0069oo`00
2Woo00@007ooOol000Moo`@000=oo`03001oogoo00Qoo`<006Moo`002Woo00@007ooOol000Moo`03
001oogoo00Aoo`8000Qoo`8006Uoo`002goo0P0027oo1@000Woo00<007ooOol01Goo0P00Jgoo000L
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003
Ool30004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000Ao
o`8000Moo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001o
ogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007ooOol0
009oo`03001oogoo00=oo`0077oo00<007ooOol00goo00<007ooOol02Woo00@007ooOol0009oo`03
001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo
00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol00Woo00<0
07ooOol02goo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001o
ogoo00=oo`0077oo0P000Woo00<007ooOol027oo10000goo00@007ooOol000Uoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04
001oogoo0005Ool001aoo`03001oogoo008000Yoo`03001oogoo00Aoo`04001oogoo0008Ool20004
Ool01000Oomoo`000Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Io
o`04001oogoo0005Ool001aoo`800003Ool007oo00Yoo`D000=oo`8000Yoo`03001oogoo00=oo`80
00Aoo`8000Ioo`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003
Ool20006Ool001aoo`03001oo`00079oo`0077oo0P00Lgoo000LOomY000<Ool001aoo`05001oogoo
Ool00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001c
Ool000]oo`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Mo
o`05001oogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001c
Ool000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<0
07ooOol0LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002
Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol0
01aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`005Woo
0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo
009oo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00
Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol0
0`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001o
ogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol0
00]oo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]o
o`04001oogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol0
1goo10000goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]o
o`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(49265\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12643 m
.008 .13021 L
.012 .13295 L
.016 .13281 L
.02 .13026 L
.024 .12607 L
.028 .12081 L
.032 .11462 L
.036 .10859 L
.04 .10375 L
.044 .10089 L
.048 .10068 L
.052 .10365 L
.056 .11016 L
.06 .12 L
.064 .13281 L
.068 .14779 L
.072 .16414 L
.076 .18074 L
.08 .19671 L
.084 .21121 L
.088 .22378 L
.092 .23428 L
.096 .24299 L
.1 .25042 L
.104 .25735 L
.108 .26449 L
.112 .2724 L
.116 .28133 L
.12 .29107 L
.124 .30101 L
.128 .31019 L
.132 .31747 L
.136 .32176 L
.14 .32227 L
.144 .3187 L
.148 .31141 L
.152 .30137 L
.156 .29004 L
.16 .27916 L
.164 .27041 L
.168 .26515 L
.172 .26414 L
.176 .26738 L
.18 .27416 L
.184 .28318 L
.188 .29284 L
.192 .30163 L
.196 .3084 L
.2 .31256 L
Mistroke
.204 .31412 L
.208 .31359 L
.212 .31178 L
.216 .30949 L
.22 .30741 L
.224 .30589 L
.228 .30499 L
.232 .30457 L
.236 .30444 L
.24 .30456 L
.244 .30515 L
.248 .30664 L
.252 .30953 L
.256 .31409 L
.26 .32014 L
.264 .32695 L
.268 .33329 L
.272 .33775 L
.276 .33915 L
.28 .33693 L
.284 .33144 L
.288 .32391 L
.292 .31619 L
.296 .31029 L
.3 .30778 L
.304 .30926 L
.308 .31417 L
.312 .3209 L
.316 .32724 L
.32 .33111 L
.324 .33122 L
.328 .32748 L
.332 .32105 L
.336 .31394 L
.34 .30831 L
.344 .30577 L
.348 .30687 L
.352 .31097 L
.356 .31655 L
.36 .32177 L
.364 .32512 L
.368 .32588 L
.372 .32432 L
.376 .32148 L
.38 .31872 L
.384 .31715 L
.388 .31732 L
.392 .319 L
.396 .32139 L
.4 .32348 L
Mistroke
.404 .32445 L
.408 .32394 L
.412 .32214 L
.416 .3196 L
.42 .317 L
.424 .31494 L
.428 .3138 L
.432 .31371 L
.436 .31465 L
.44 .31645 L
.444 .31883 L
.448 .32137 L
.452 .32353 L
.456 .32471 L
.46 .32449 L
.464 .32285 L
.468 .3203 L
.472 .31772 L
.476 .31608 L
.48 .31597 L
.484 .31735 L
.488 .3195 L
.492 .32128 L
.496 .32173 L
.5 .32058 L
.504 .31846 L
.508 .31656 L
.512 .31604 L
.516 .31741 L
.52 .32018 L
.524 .32303 L
.528 .32451 L
.532 .32374 L
.536 .32096 L
.54 .31749 L
.544 .31501 L
.548 .31472 L
.552 .31665 L
.556 .31971 L
.56 .32228 L
.564 .32307 L
.568 .32183 L
.572 .31943 L
.576 .31736 L
.58 .31686 L
.584 .3182 L
.588 .32052 L
.592 .3224 L
.596 .32269 L
.6 .3212 L
Mistroke
.604 .3188 L
.608 .31684 L
.612 .31636 L
.616 .31752 L
.62 .31957 L
.624 .32132 L
.628 .32185 L
.632 .32101 L
.636 .31951 L
.64 .31838 L
.644 .31831 L
.648 .31926 L
.652 .3205 L
.656 .32116 L
.66 .32084 L
.664 .31977 L
.668 .31864 L
.672 .31813 L
.676 .31848 L
.68 .31941 L
.684 .32032 L
.688 .3207 L
.692 .3204 L
.696 .31969 L
.7 .3191 L
.704 .31902 L
.708 .31948 L
.712 .32012 L
.716 .32049 L
.72 .32034 L
.724 .31979 L
.728 .3192 L
.732 .31894 L
.736 .31912 L
.74 .3196 L
.744 .32009 L
.748 .32036 L
.752 .32028 L
.756 .31989 L
.76 .31941 L
.764 .31914 L
.768 .31928 L
.772 .31979 L
.776 .32035 L
.78 .32054 L
.784 .32015 L
.788 .31942 L
.792 .31887 L
.796 .31894 L
.8 .31965 L
Mistroke
.804 .32052 L
.808 .32098 L
.812 .32073 L
.816 .31991 L
.82 .31903 L
.824 .31859 L
.828 .31881 L
.832 .31956 L
.836 .32041 L
.84 .3209 L
.844 .32081 L
.848 .32024 L
.852 .31957 L
.856 .31927 L
.86 .3194 L
.864 .31974 L
.868 .31995 L
.872 .31983 L
.876 .31961 L
.88 .31972 L
.884 .32013 L
.888 .32054 L
.892 .32053 L
.896 .31991 L
.9 .31925 L
.904 .3192 L
.908 .31976 L
.912 .32053 L
.916 .32076 L
.92 .32008 L
.924 .31921 L
.928 .31897 L
.932 .31953 L
.936 .32056 L
.94 .32111 L
.944 .3206 L
.948 .31975 L
.952 .31926 L
.956 .31938 L
.96 .32005 L
.964 .32039 L
.968 .31994 L
.972 .31954 L
.976 .31965 L
.98 .3202 L
.984 .32104 L
.988 .3211 L
.992 .31999 L
.996 .31902 L
1 .31881 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .24572 m
.008 .25047 L
.012 .25179 L
.016 .24976 L
.02 .24865 L
.024 .24855 L
.028 .24805 L
.032 .2472 L
.036 .24651 L
.04 .24604 L
.044 .24563 L
.048 .2453 L
.052 .2451 L
.056 .24502 L
.06 .24502 L
.064 .2451 L
.068 .24521 L
.072 .24537 L
.076 .24554 L
.08 .24574 L
.084 .24595 L
.088 .24619 L
.092 .24645 L
.096 .24677 L
.1 .24712 L
.104 .24751 L
.108 .24791 L
.112 .24833 L
.116 .24871 L
.12 .24907 L
.124 .24936 L
.128 .24961 L
.132 .2498 L
.136 .24997 L
.14 .25015 L
.144 .25039 L
.148 .25071 L
.152 .25117 L
.156 .25176 L
.16 .25249 L
.164 .25334 L
.168 .25429 L
.172 .25527 L
.176 .25624 L
.18 .25714 L
.184 .25795 L
.188 .25865 L
.192 .25922 L
.196 .25969 L
.2 .26008 L
Mistroke
.204 .26042 L
.208 .26074 L
.212 .26106 L
.216 .2614 L
.22 .26175 L
.224 .26213 L
.228 .26252 L
.232 .26291 L
.236 .26328 L
.24 .26362 L
.244 .26392 L
.248 .26415 L
.252 .2643 L
.256 .26435 L
.26 .26429 L
.264 .26411 L
.268 .26383 L
.272 .26347 L
.276 .26308 L
.28 .26269 L
.284 .26237 L
.288 .26213 L
.292 .26199 L
.296 .26194 L
.3 .26196 L
.304 .262 L
.308 .26202 L
.312 .262 L
.316 .26192 L
.32 .26179 L
.324 .26165 L
.328 .26154 L
.332 .26148 L
.336 .26151 L
.34 .2616 L
.344 .26175 L
.348 .26191 L
.352 .26207 L
.356 .26217 L
.36 .26222 L
.364 .26221 L
.368 .26215 L
.372 .26207 L
.376 .26198 L
.38 .26189 L
.384 .2618 L
.388 .26171 L
.392 .2616 L
.396 .26148 L
.4 .26135 L
Mistroke
.404 .26121 L
.408 .26109 L
.412 .26101 L
.416 .26098 L
.42 .26101 L
.424 .2611 L
.428 .26122 L
.432 .26134 L
.436 .26145 L
.44 .26152 L
.444 .26152 L
.448 .26146 L
.452 .26135 L
.456 .2612 L
.46 .26104 L
.464 .2609 L
.468 .26079 L
.472 .26072 L
.476 .2607 L
.48 .26071 L
.484 .26074 L
.488 .26077 L
.492 .26079 L
.496 .2608 L
.5 .2608 L
.504 .2608 L
.508 .26078 L
.512 .26076 L
.516 .26071 L
.52 .26063 L
.524 .26054 L
.528 .26044 L
.532 .26035 L
.536 .2603 L
.54 .26028 L
.544 .2603 L
.548 .26033 L
.552 .26036 L
.556 .26036 L
.56 .26034 L
.564 .2603 L
.568 .26025 L
.572 .2602 L
.576 .26016 L
.58 .26012 L
.584 .26008 L
.588 .26004 L
.592 .25998 L
.596 .25992 L
.6 .25986 L
Mistroke
.604 .25983 L
.608 .25982 L
.612 .25983 L
.616 .25984 L
.62 .25984 L
.624 .25983 L
.628 .25981 L
.632 .25976 L
.636 .25971 L
.64 .25966 L
.644 .25961 L
.648 .25955 L
.652 .2595 L
.656 .25945 L
.66 .25941 L
.664 .25939 L
.668 .25938 L
.672 .25939 L
.676 .2594 L
.68 .2594 L
.684 .25937 L
.688 .25932 L
.692 .25926 L
.696 .25919 L
.7 .25913 L
.704 .25909 L
.708 .25906 L
.712 .25905 L
.716 .25905 L
.72 .25904 L
.724 .25902 L
.728 .25899 L
.732 .25895 L
.736 .25891 L
.74 .25886 L
.744 .25881 L
.748 .25877 L
.752 .25873 L
.756 .25871 L
.76 .2587 L
.764 .25869 L
.768 .25868 L
.772 .25866 L
.776 .25863 L
.78 .25858 L
.784 .25852 L
.788 .25846 L
.792 .25842 L
.796 .25839 L
.8 .25837 L
Mistroke
.804 .25836 L
.808 .25835 L
.812 .25833 L
.816 .25831 L
.82 .25828 L
.824 .25823 L
.828 .25818 L
.832 .25814 L
.836 .2581 L
.84 .25807 L
.844 .25805 L
.848 .25803 L
.852 .25801 L
.856 .25798 L
.86 .25794 L
.864 .2579 L
.868 .25786 L
.872 .25783 L
.876 .25781 L
.88 .25779 L
.884 .25777 L
.888 .25773 L
.892 .2577 L
.896 .25765 L
.9 .25761 L
.904 .25757 L
.908 .25754 L
.912 .25752 L
.916 .2575 L
.92 .25749 L
.924 .25746 L
.928 .25743 L
.932 .25739 L
.936 .25735 L
.94 .25731 L
.944 .25727 L
.948 .25724 L
.952 .25721 L
.956 .2572 L
.96 .25717 L
.964 .25715 L
.968 .25712 L
.972 .25708 L
.976 .25704 L
.98 .257 L
.984 .25696 L
.988 .25694 L
.992 .25691 L
.996 .25689 L
1 .25686 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15612 L
.012 .15106 L
.016 .14565 L
.02 .14012 L
.024 .13465 L
.028 .12904 L
.032 .12315 L
.036 .11712 L
.04 .11104 L
.044 .10491 L
.048 .09875 L
.052 .09268 L
.056 .08675 L
.06 .08104 L
.064 .0756 L
.068 .07051 L
.072 .06576 L
.076 .06142 L
.08 .05744 L
.084 .05384 L
.088 .05057 L
.092 .04762 L
.096 .04492 L
.1 .04249 L
.104 .04027 L
.108 .03827 L
.112 .03646 L
.116 .03487 L
.12 .03349 L
.124 .03232 L
.128 .03133 L
.132 .03051 L
.136 .0298 L
.14 .02916 L
.144 .02851 L
.148 .0278 L
.152 .02698 L
.156 .02603 L
.16 .02492 L
.164 .02369 L
.168 .02237 L
.172 .02102 L
.176 .0197 L
.18 .01848 L
.184 .01738 L
.188 .01643 L
.192 .01564 L
.196 .015 L
.2 .01445 L
Mistroke
.204 .01398 L
.208 .01353 L
.212 .01308 L
.216 .01261 L
.22 .01211 L
.224 .0116 L
.228 .01107 L
.232 .01055 L
.236 .01005 L
.24 .00958 L
.244 .00917 L
.248 .00884 L
.252 .00862 L
.256 .00852 L
.26 .00857 L
.264 .00875 L
.268 .00907 L
.272 .00948 L
.276 .00993 L
.28 .01037 L
.284 .01075 L
.288 .01101 L
.292 .01115 L
.296 .01118 L
.3 .01112 L
.304 .01104 L
.308 .01098 L
.312 .01097 L
.316 .01103 L
.32 .01115 L
.324 .01129 L
.328 .0114 L
.332 .01144 L
.336 .01138 L
.34 .01123 L
.344 .01101 L
.348 .01076 L
.352 .01054 L
.356 .01037 L
.36 .01027 L
.364 .01026 L
.368 .01029 L
.372 .01036 L
.376 .01044 L
.38 .01051 L
.384 .01059 L
.388 .01067 L
.392 .01077 L
.396 .01089 L
.4 .01102 L
Mistroke
.404 .01116 L
.408 .01127 L
.412 .01133 L
.416 .01133 L
.42 .01126 L
.424 .01113 L
.428 .01095 L
.432 .01076 L
.436 .01058 L
.44 .01046 L
.444 .01042 L
.448 .01045 L
.452 .01056 L
.456 .01072 L
.46 .01089 L
.464 .01104 L
.468 .01114 L
.472 .01118 L
.476 .01117 L
.48 .01112 L
.484 .01105 L
.488 .01098 L
.492 .01093 L
.496 .01088 L
.5 .01085 L
.504 .01082 L
.508 .0108 L
.512 .0108 L
.516 .01082 L
.52 .01088 L
.524 .01096 L
.528 .01105 L
.532 .01112 L
.536 .01116 L
.54 .01115 L
.544 .0111 L
.548 .01103 L
.552 .01096 L
.556 .01091 L
.56 .0109 L
.564 .01091 L
.568 .01094 L
.572 .01097 L
.576 .01099 L
.58 .01101 L
.584 .01102 L
.588 .01105 L
.592 .01108 L
.596 .01112 L
.6 .01116 L
Mistroke
.604 .01116 L
.608 .01114 L
.612 .0111 L
.616 .01105 L
.62 .011 L
.624 .01098 L
.628 .01099 L
.632 .01101 L
.636 .01104 L
.64 .01108 L
.644 .01111 L
.648 .01114 L
.652 .01117 L
.656 .01119 L
.66 .0112 L
.664 .01119 L
.668 .01117 L
.672 .01114 L
.676 .0111 L
.68 .01108 L
.684 .01107 L
.688 .01109 L
.692 .01113 L
.696 .01117 L
.7 .01121 L
.704 .01123 L
.708 .01123 L
.712 .01122 L
.716 .0112 L
.72 .01118 L
.724 .01117 L
.728 .01117 L
.732 .01117 L
.736 .01119 L
.74 .01121 L
.744 .01124 L
.748 .01126 L
.752 .01127 L
.756 .01127 L
.76 .01125 L
.764 .01123 L
.768 .01121 L
.772 .0112 L
.776 .01122 L
.78 .01124 L
.784 .01128 L
.788 .0113 L
.792 .01132 L
.796 .01132 L
.8 .01131 L
Mistroke
.804 .0113 L
.808 .01129 L
.812 .01129 L
.816 .01129 L
.82 .01129 L
.824 .0113 L
.828 .01131 L
.832 .01133 L
.836 .01134 L
.84 .01135 L
.844 .01136 L
.848 .01136 L
.852 .01136 L
.856 .01135 L
.86 .01135 L
.864 .01135 L
.868 .01136 L
.872 .01138 L
.876 .01139 L
.88 .0114 L
.884 .0114 L
.888 .0114 L
.892 .01139 L
.896 .01139 L
.9 .01139 L
.904 .0114 L
.908 .01142 L
.912 .01143 L
.916 .01146 L
.92 .01147 L
.924 .01147 L
.928 .01146 L
.932 .01144 L
.936 .01142 L
.94 .01143 L
.944 .01143 L
.948 .01146 L
.952 .01148 L
.956 .0115 L
.96 .01151 L
.964 .01152 L
.968 .01151 L
.972 .0115 L
.976 .01149 L
.98 .01149 L
.984 .01149 L
.988 .01151 L
.992 .01152 L
.996 .01155 L
1 .01155 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo0080009oo`8006Uoo`002goo0P002Woo0P000goo0`000goo00L007ooOomo
o`00Ool0001XOol0029oo`800005Ool007ooOol0001XOol000]oo`8000Aoo`03001oogoo00=oo`80
009oo`D0009oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`000Woo0P0017oo00<007ooOol0IWoo0003Ool50002Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`8000Eoo`03001oogoo06Eoo`002Woo00@007ooOol000Qoo`04001o
ogoo0004Ool01@00Oomoogoo00001Woo00<007ooOol0IGoo000:Ool01000Oomoo`0027oo00H007oo
Ool007oo0003Ool00`00Oomoo`020005Ool00`00Oomoo`1UOol000Yoo`04001oogoo0008Ool01P00
Oomoo`00Ool000=oo`03001oogoo008000Ioo`03001oogoo06Aoo`002goo0P002Woo0P000goo0`00
0goo00<007ooOol01Goo00<007ooOol0I7oo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003
Ool20006Ool00`00Oomoo`1TOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo0P001Woo00<007ooOol017oo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`00
17oo0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo009oo`05
001oogooOol00002Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`00
0Woo00@007ooOol0009oo`03001oogoo009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03
001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20007Ool0
0`00Oomoo`06Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo
Ool00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Qoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol01goo00@007oo
Oomoo`@000=oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eo
o`04001oogooOol40003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool0
1000Oomoo`000goo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:Ool20004
Ool00`00Oomoo`02Ool20009Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oogoo00Ao
o`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0
009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo
00001Woo00@007ooOol000Eoo`008Woo0P002Goo00<007ooOol01@000goo0P0027oo00<007ooOol0
0goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009o
o`D000=oo`8000Ioo`008Woo00<007ooOol027oo00<007ooOol00Woo00<007oo0000G7oo000ROol2
000:Ool01000Oomoo`000Woo00<007ooOol0FWoo000ROomS000<Ool0029oo`05001oogooOol00003
Ool01000Oomoogoo1@000goo0P000Woo0P0000=oo`00Ool00`0000Eoo`00000007oo00<00004Ool0
00000002Ool200001Goo00000000Ool01@0000Aoo`00001oo`800004Ool00000Ool5000017oo0000
07oo0P0000]oo`00000007oo001oo`00Ool007oo00800003Ool00000009oo`8000aoo`008Woo0P00
2goo0P002Woo0P0000Aoo`00Oomoo`80009oo`<00004Ool000000002Ool3000017oo000007oo0P00
00=oo`000000100000Aoo`00001ooaP00003Ool0000000L000eoo`008Woo00<007ooOol05goo0`00
0Woo0P00CWoo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo
0`000goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo
06aoo`002goo0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Ao
o`04001oogooOol2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo
0P002Woo0P000goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo
00=oo`8000=oo`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<0
07ooOol00P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@0
07ooOol000Eoo`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03
001oogoo06aoo`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0
009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000
Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P00
2Woo0P0017oo00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol0
0`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo06Ioo`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2
001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo
000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo
00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Ao
o`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
00]oo`8000Aoo`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0
009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Ao
o`8000Moo`<000Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=o
o`D0009oo`<000Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00
Ool010000goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`00
00=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00H007ooOol007oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D0
07ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0
009oo`03001oogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol020001Goo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000
Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00
:7oo10001Woo200000Eoo`00Oomoo`0000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00@007ooOomoo`@000=oo`06001oogoo001oo`000goo6@000goo00@007ooOol000Eoo`00
:7oo00<007ooOol02Goo00<007ooOol00goo<`000Woo00@007ooOol0009oo`04001oogoo0002Ool0
1`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool002Qoo`03001oogoo00Uoo`D000=oo`8000Qo
o`03001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool2
0004Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000X
OomM000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00mo
o`03001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0
02Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Ao
o`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool2
0002Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000A
Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001o
ogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomo
o`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03
Ool20003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000
Oomoogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eo
o`002goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol067oo00<007ooOol0Egoo000:
Ool01000Oomoo`001goo00D007ooOomoo`00009oo`03001oogoo011ooeH000aoo`000goo1@000Woo
00@007ooOol000]oo`03001oogoo008000ioo`@0065oo`002Woo00@007ooOol000]oo`04001oogoo
000;Ool4001UOol000Yoo`04001oogoo0007Ool40003Ool00`00Oomoo`07Ool2001YOol000Yoo`04
001oogoo0007Ool00`00Oomoo`04Ool20007Ool2001ZOol000]oo`8000Qoo`D0009oo`03001oogoo
00Eoo`03001oogoo06Yoo`0077oo00<007ooOol017oo00<007ooOol01Woo0`0017oo0P002Goo0`00
17oo0P0017oo0P001Goo0`000goo0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`00
17oo0P001Woo000LOol20004Ool00`00Oomoo`06Ool01@00Oomoogoo00000Woo00@007ooOol000Uo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool0
1P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo00=oo`03
001oogoo00Yoo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`03001oogoo009oo`03001oogoo00]oo`04001oogoo0002Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Eoo`03001o
ogoo00Aoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`80009oo`03001oogoo00Qoo`@000=o
o`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo
Ool40003Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
17oo00H007ooOomoo`00Ool40003Ool01000Oomoo`001Goo000LOol01@00Oomoogoo00002Woo00<0
07ooOol017oo00@007ooOol000Qoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0017oo0P000goo
00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`07001oogooOol007oo00001Woo00@007ooOol000Eoo`0077oo0P0000=oo`00Ool02Woo
1@000goo0P002Woo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D000=oo`8000Ioo`<0
00Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Ioo`0077oo00@007oo0000075oo`0077oo0`00
LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol0
2Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=o
o`0077oo00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=oo`03
001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000Yo
o`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00M7oo
000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<007oo
Ool017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079oo`00
77oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol0
0`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomoo`02
Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol00Woo00<007oo
Ool0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo00<0
07ooOol00Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007oo
Ool0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool30004
Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002Ool0
0`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]oo`03
001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009Ool0
0`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(49432\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .12869 m
.008 .12647 L
.012 .12313 L
.016 .11895 L
.02 .11429 L
.024 .11182 L
.028 .11207 L
.032 .11442 L
.036 .11898 L
.04 .12591 L
.044 .13491 L
.048 .14495 L
.052 .15544 L
.056 .16567 L
.06 .17527 L
.064 .18389 L
.068 .19166 L
.072 .19895 L
.076 .20632 L
.08 .2144 L
.084 .22365 L
.088 .2344 L
.092 .24646 L
.096 .25935 L
.1 .27209 L
.104 .28355 L
.108 .29248 L
.112 .29787 L
.116 .2991 L
.12 .29619 L
.124 .28977 L
.128 .28107 L
.132 .27172 L
.136 .26348 L
.14 .25793 L
.144 .25617 L
.148 .25862 L
.152 .26492 L
.156 .27405 L
.16 .28455 L
.164 .2948 L
.168 .30343 L
.172 .3095 L
.176 .3127 L
.18 .31328 L
.184 .31196 L
.188 .30965 L
.192 .30722 L
.196 .30528 L
.2 .30411 L
Mistroke
.204 .30366 L
.208 .30371 L
.212 .30408 L
.216 .3048 L
.22 .30611 L
.224 .30846 L
.228 .31221 L
.232 .31744 L
.236 .32374 L
.24 .33021 L
.244 .3356 L
.248 .33865 L
.252 .33845 L
.256 .33478 L
.26 .32831 L
.264 .32051 L
.268 .31332 L
.272 .30861 L
.276 .30762 L
.28 .31055 L
.284 .31639 L
.288 .32326 L
.292 .32892 L
.296 .3315 L
.3 .33014 L
.304 .3252 L
.308 .31821 L
.312 .3113 L
.316 .30654 L
.32 .30523 L
.324 .30757 L
.328 .31259 L
.332 .31855 L
.336 .32355 L
.34 .32623 L
.344 .32614 L
.348 .32385 L
.352 .32063 L
.356 .31794 L
.36 .31681 L
.364 .31754 L
.368 .31964 L
.372 .32211 L
.376 .32392 L
.38 .32435 L
.384 .32324 L
.388 .32097 L
.392 .31824 L
.396 .31576 L
.4 .31407 L
Mistroke
.404 .31343 L
.408 .31387 L
.412 .31529 L
.416 .31743 L
.42 .31995 L
.424 .32238 L
.428 .32417 L
.432 .32481 L
.436 .32404 L
.44 .322 L
.444 .31932 L
.448 .31692 L
.452 .31566 L
.456 .31598 L
.46 .31761 L
.464 .31973 L
.468 .32126 L
.472 .32144 L
.476 .32018 L
.48 .31818 L
.484 .31659 L
.488 .31643 L
.492 .31801 L
.496 .32069 L
.5 .32318 L
.504 .32417 L
.508 .32305 L
.512 .3202 L
.516 .31692 L
.52 .31477 L
.524 .31476 L
.528 .31685 L
.532 .31992 L
.536 .32241 L
.54 .3231 L
.544 .32182 L
.548 .31944 L
.552 .31737 L
.556 .31679 L
.56 .31799 L
.564 .32023 L
.568 .32216 L
.572 .3226 L
.576 .32125 L
.58 .31886 L
.584 .31675 L
.588 .31607 L
.592 .31711 L
.596 .31923 L
.6 .32124 L
Mistroke
.604 .32211 L
.608 .32151 L
.612 .31996 L
.616 .31848 L
.62 .31794 L
.624 .31856 L
.628 .31984 L
.632 .32089 L
.636 .32104 L
.64 .32022 L
.644 .31899 L
.648 .31809 L
.652 .31802 L
.656 .31875 L
.66 .31982 L
.664 .32064 L
.668 .32082 L
.672 .32034 L
.676 .31956 L
.68 .31895 L
.684 .31885 L
.688 .31924 L
.692 .31984 L
.696 .32025 L
.7 .32025 L
.704 .31989 L
.708 .31939 L
.712 .31902 L
.716 .31897 L
.72 .31925 L
.724 .31975 L
.728 .32021 L
.732 .3204 L
.736 .3202 L
.74 .3197 L
.744 .3192 L
.748 .31902 L
.752 .31925 L
.756 .3197 L
.76 .32007 L
.764 .32013 L
.768 .31993 L
.772 .31969 L
.776 .31961 L
.78 .31968 L
.784 .31977 L
.788 .31976 L
.792 .31963 L
.796 .31951 L
.8 .31953 L
Mistroke
.804 .31968 L
.808 .31989 L
.812 .32 L
.816 .31994 L
.82 .31977 L
.824 .31963 L
.828 .31966 L
.832 .31992 L
.836 .3202 L
.84 .32022 L
.844 .31984 L
.848 .31918 L
.852 .31876 L
.856 .31902 L
.86 .3199 L
.864 .32086 L
.868 .3212 L
.872 .32059 L
.876 .31952 L
.88 .3188 L
.884 .31886 L
.888 .31958 L
.892 .32026 L
.896 .32033 L
.9 .32001 L
.904 .31974 L
.908 .31979 L
.912 .32014 L
.916 .32026 L
.92 .31987 L
.924 .31943 L
.928 .31934 L
.932 .31973 L
.936 .32039 L
.94 .32057 L
.944 .32006 L
.948 .31948 L
.952 .31927 L
.956 .31961 L
.96 .32036 L
.964 .32064 L
.968 .32022 L
.972 .31978 L
.976 .31954 L
.98 .31964 L
.984 .32013 L
.988 .32014 L
.992 .31968 L
.996 .31963 L
1 .31986 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .27614 m
.008 .27674 L
.012 .27719 L
.016 .27751 L
.02 .27776 L
.024 .27815 L
.028 .27857 L
.032 .27887 L
.036 .27893 L
.04 .27881 L
.044 .27847 L
.048 .27789 L
.052 .27705 L
.056 .27599 L
.06 .27476 L
.064 .27339 L
.068 .27194 L
.072 .27044 L
.076 .26894 L
.08 .26747 L
.084 .26603 L
.088 .26465 L
.092 .26332 L
.096 .26205 L
.1 .26083 L
.104 .25969 L
.108 .25863 L
.112 .2577 L
.116 .25691 L
.12 .25632 L
.124 .25593 L
.128 .25579 L
.132 .25587 L
.136 .25617 L
.14 .25663 L
.144 .25723 L
.148 .25789 L
.152 .25856 L
.156 .25919 L
.16 .25974 L
.164 .26021 L
.168 .26058 L
.172 .26088 L
.176 .26114 L
.18 .26137 L
.184 .26161 L
.188 .26188 L
.192 .26218 L
.196 .2625 L
.2 .26286 L
Mistroke
.204 .26321 L
.208 .26357 L
.212 .2639 L
.216 .26419 L
.22 .26443 L
.224 .26459 L
.228 .26467 L
.232 .26464 L
.236 .2645 L
.24 .26426 L
.244 .26393 L
.248 .26355 L
.252 .26315 L
.256 .26279 L
.26 .2625 L
.264 .26231 L
.268 .26221 L
.272 .2622 L
.276 .26223 L
.28 .26228 L
.284 .26229 L
.288 .26225 L
.292 .26216 L
.296 .26203 L
.3 .2619 L
.304 .26181 L
.308 .26179 L
.312 .26184 L
.316 .26196 L
.32 .26212 L
.324 .26228 L
.328 .26242 L
.332 .2625 L
.336 .26252 L
.34 .26249 L
.344 .26241 L
.348 .26231 L
.352 .26221 L
.356 .26211 L
.36 .26202 L
.364 .26192 L
.368 .26181 L
.372 .26169 L
.376 .26156 L
.38 .26143 L
.384 .26134 L
.388 .26129 L
.392 .26129 L
.396 .26134 L
.4 .26144 L
Mistroke
.404 .26157 L
.408 .26169 L
.412 .26178 L
.416 .26182 L
.42 .26179 L
.424 .26171 L
.428 .26157 L
.432 .26141 L
.436 .26125 L
.44 .26111 L
.444 .26102 L
.448 .26098 L
.452 .26098 L
.456 .26101 L
.46 .26105 L
.464 .26107 L
.468 .26109 L
.472 .26109 L
.476 .26109 L
.48 .26108 L
.484 .26105 L
.488 .26102 L
.492 .26096 L
.496 .26088 L
.5 .26078 L
.504 .26069 L
.508 .26061 L
.512 .26057 L
.516 .26056 L
.52 .26059 L
.524 .26062 L
.528 .26065 L
.532 .26065 L
.536 .26062 L
.54 .26057 L
.544 .26052 L
.548 .26046 L
.552 .26042 L
.556 .26038 L
.56 .26034 L
.564 .26029 L
.568 .26024 L
.572 .26019 L
.576 .26014 L
.58 .26011 L
.584 .26011 L
.588 .26011 L
.592 .26013 L
.596 .26013 L
.6 .26011 L
Mistroke
.604 .26008 L
.608 .26003 L
.612 .25997 L
.616 .25991 L
.62 .25986 L
.624 .25981 L
.628 .25976 L
.632 .25973 L
.636 .2597 L
.64 .25968 L
.644 .25967 L
.648 .25967 L
.652 .25967 L
.656 .25967 L
.66 .25964 L
.664 .25959 L
.668 .25953 L
.672 .25946 L
.676 .2594 L
.68 .25936 L
.684 .25934 L
.688 .25933 L
.692 .25932 L
.696 .25931 L
.7 .2593 L
.704 .25927 L
.708 .25923 L
.712 .25918 L
.716 .25913 L
.72 .25908 L
.724 .25903 L
.728 .259 L
.732 .25899 L
.736 .25898 L
.74 .25897 L
.744 .25896 L
.748 .25894 L
.752 .25889 L
.756 .25884 L
.76 .25878 L
.764 .25873 L
.768 .25869 L
.772 .25867 L
.776 .25865 L
.78 .25864 L
.784 .25862 L
.788 .2586 L
.792 .25858 L
.796 .25854 L
.8 .2585 L
Mistroke
.804 .25846 L
.808 .25842 L
.812 .25838 L
.816 .25834 L
.82 .25831 L
.824 .25829 L
.828 .25827 L
.832 .25825 L
.836 .25822 L
.84 .25819 L
.844 .25815 L
.848 .25811 L
.852 .25808 L
.856 .25805 L
.86 .25802 L
.864 .258 L
.868 .25797 L
.872 .25794 L
.876 .25791 L
.88 .25787 L
.884 .25783 L
.888 .25779 L
.892 .25776 L
.896 .25774 L
.9 .25772 L
.904 .2577 L
.908 .25768 L
.912 .25764 L
.916 .2576 L
.92 .25756 L
.924 .25751 L
.928 .25747 L
.932 .25745 L
.936 .25742 L
.94 .25741 L
.944 .2574 L
.948 .25738 L
.952 .25734 L
.956 .25729 L
.96 .25724 L
.964 .2572 L
.968 .25716 L
.972 .25714 L
.976 .25712 L
.98 .2571 L
.984 .25708 L
.988 .25706 L
.992 .25703 L
.996 .25699 L
1 .25694 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15272 L
.012 .15113 L
.016 .14713 L
.02 .14079 L
.024 .1351 L
.028 .13015 L
.032 .12484 L
.036 .11925 L
.04 .1137 L
.044 .10827 L
.048 .10284 L
.052 .09745 L
.056 .09215 L
.06 .08696 L
.064 .0819 L
.068 .07696 L
.072 .07218 L
.076 .06758 L
.08 .06319 L
.084 .05904 L
.088 .05517 L
.092 .0516 L
.096 .04836 L
.1 .04546 L
.104 .04287 L
.108 .04058 L
.112 .03851 L
.116 .03663 L
.12 .03484 L
.124 .03311 L
.128 .03137 L
.132 .0296 L
.136 .02779 L
.14 .02597 L
.144 .02417 L
.148 .02244 L
.152 .02083 L
.156 .0194 L
.16 .01815 L
.164 .0171 L
.168 .01622 L
.172 .01551 L
.176 .01489 L
.18 .01435 L
.184 .01383 L
.188 .01331 L
.192 .01278 L
.196 .01223 L
.2 .01167 L
Mistroke
.204 .01112 L
.208 .01058 L
.212 .01008 L
.216 .00964 L
.22 .00927 L
.224 .009 L
.228 .00885 L
.232 .00883 L
.236 .00895 L
.24 .0092 L
.244 .00956 L
.248 .00999 L
.252 .01044 L
.256 .01085 L
.26 .01118 L
.264 .01138 L
.268 .01146 L
.272 .01143 L
.276 .01135 L
.28 .01127 L
.284 .01122 L
.288 .01123 L
.292 .01131 L
.296 .01143 L
.3 .01156 L
.304 .01163 L
.308 .01163 L
.312 .01153 L
.316 .01135 L
.32 .01111 L
.324 .01087 L
.328 .01067 L
.332 .01053 L
.336 .01047 L
.34 .01048 L
.344 .01054 L
.348 .01063 L
.352 .01072 L
.356 .01081 L
.36 .01089 L
.364 .01098 L
.368 .01108 L
.372 .0112 L
.376 .01132 L
.38 .01144 L
.384 .01153 L
.388 .01157 L
.392 .01153 L
.396 .01142 L
.4 .01126 L
Mistroke
.404 .01107 L
.408 .01089 L
.412 .01074 L
.416 .01066 L
.42 .01066 L
.424 .01074 L
.428 .01087 L
.432 .01103 L
.436 .0112 L
.44 .01133 L
.444 .01141 L
.448 .01143 L
.452 .0114 L
.456 .01133 L
.46 .01125 L
.464 .01118 L
.468 .01112 L
.472 .01107 L
.476 .01105 L
.48 .01103 L
.484 .01103 L
.488 .01105 L
.492 .01109 L
.496 .01115 L
.5 .01123 L
.504 .01131 L
.508 .01137 L
.512 .01139 L
.516 .01136 L
.52 .0113 L
.524 .01123 L
.528 .01116 L
.532 .01113 L
.536 .01112 L
.54 .01115 L
.544 .01118 L
.548 .01122 L
.552 .01124 L
.556 .01126 L
.56 .01127 L
.564 .01129 L
.568 .01133 L
.572 .01136 L
.576 .01139 L
.58 .01138 L
.584 .01136 L
.588 .01131 L
.592 .01126 L
.596 .01122 L
.6 .01121 L
Mistroke
.604 .01122 L
.608 .01125 L
.612 .01129 L
.616 .01133 L
.62 .01136 L
.624 .01139 L
.628 .01141 L
.632 .01143 L
.636 .01143 L
.64 .01141 L
.644 .01138 L
.648 .01135 L
.652 .01131 L
.656 .01129 L
.66 .0113 L
.664 .01133 L
.668 .01138 L
.672 .01142 L
.676 .01145 L
.68 .01146 L
.684 .01145 L
.688 .01143 L
.692 .01141 L
.696 .0114 L
.7 .01139 L
.704 .0114 L
.708 .01142 L
.712 .01144 L
.716 .01146 L
.72 .01148 L
.724 .01149 L
.728 .01149 L
.732 .01149 L
.736 .01147 L
.74 .01145 L
.744 .01144 L
.748 .01144 L
.752 .01145 L
.756 .01148 L
.76 .01151 L
.764 .01154 L
.768 .01155 L
.772 .01155 L
.776 .01154 L
.78 .01152 L
.784 .01151 L
.788 .0115 L
.792 .01151 L
.796 .01152 L
.8 .01154 L
Mistroke
.804 .01156 L
.808 .01157 L
.812 .01158 L
.816 .01158 L
.82 .01158 L
.824 .01157 L
.828 .01157 L
.832 .01158 L
.836 .01159 L
.84 .0116 L
.844 .01161 L
.848 .01161 L
.852 .01161 L
.856 .01161 L
.86 .01161 L
.864 .01161 L
.868 .01162 L
.872 .01163 L
.876 .01165 L
.88 .01166 L
.884 .01166 L
.888 .01166 L
.892 .01166 L
.896 .01166 L
.9 .01167 L
.904 .01167 L
.908 .01168 L
.912 .01168 L
.916 .01169 L
.92 .01168 L
.924 .01169 L
.928 .01169 L
.932 .0117 L
.936 .01171 L
.94 .01173 L
.944 .01174 L
.948 .01175 L
.952 .01175 L
.956 .01174 L
.96 .01173 L
.964 .01173 L
.968 .01173 L
.972 .01175 L
.976 .01176 L
.98 .01178 L
.984 .01178 L
.988 .0118 L
.992 .01179 L
.996 .0118 L
1 .01178 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00@007oo000006]oo`00
8Woo1@00JWoo000;Ool20004Ool00`00Oomoo`03Ool20002Ool50002Ool20002Ool00`00Oomoo`1X
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`80009oo`03001oogoo
06Qoo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20003Ool0
0`00Oomoo`1WOol000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00D007ooOomoo`0000Aoo`03
001oogoo06Moo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P0017oo
00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`020004
Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000=oo`<000=oo`03001oogoo00Aoo`03001oogoo06Eo
o`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P001Goo0P00IWoo000:Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Ioo`03001oogoo00Aoo`<000Aoo`8000Mo
o`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000=oo`D000=oo`8000Aoo`8000Aoo`D0009o
o`<000Aoo`8000Ioo`000goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`05Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02Ool01P00
Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo0P001goo00<007ooOol01Woo00@007ooOol0009oo`03001oogoo
00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007oo
Ool0009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool20007Ool00`00Oomoo`06Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000Aoo`03001oogoo00Ioo`03001oogoo009oo`@000=oo`04001oogoo0007Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`000Woo
00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00H007ooOomoo`00Ool40003
Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool20008Ool00`00Oomoo`03
0005Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool20003Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
0goo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000ROol20008Ool00`00Oomoo`060003
Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo0P0017oo0`0017oo
0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`07Ool01000Oomoo`000Woo
00<007ooOol0G7oo000ROol20009Ool20003Ool00`00Oomoo`1LOol0029oof<000aoo`008Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool300000goo001oo`0300001Goo00000000Ool00`00
0Woo0P0000=oo`0000000P0000Eoo`00000007oo00800005Ool00000001oo`0200000goo00000006
00000goo00000002Ool00`00Oomoo`020003Ool01000Oomoogoo0`0000=oo`00Ool00Woo00<007oo
Ool00P000goo00<007ooOol02Woo000ROol2000EOol01@00Ool00000Ool00`000Woo0P0000Aoo`00
0000009oo`<00003Ool0000000@00003Ool0000000<0009oo`@00005Ool00000001oo`02000017oo
000007oo2@0000Aoo`00001oo``000aoo`008Woo00<007ooOol05Goo0P000goo00<007ooOol0Cgoo
000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<0
07ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`00
2Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool2001]Ool000]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo
0P0017oo00<007ooOol00goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007oo
Ool0009oo`04001oogoo0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogoo
Ool2001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P00
0goo0`000goo0P00KGoo000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=o
o`<000=oo`8006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00
KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo
0008Ool01000Oomoo`000goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eo
o`03001oogoo008006eoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol0
06ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06ao
o`008Woo0P00KGoo000ROol00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool01000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo
00@007ooOomoo`D0009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007oo
Ool0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Io
o`002Goo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011o
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol0
00Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo
009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Ao
o`03001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qo
o`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<0
00Aoo`8000Aoo`8000=oo`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<0
00Aoo`8000Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo
00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol0
07oo0006Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`00
00Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001o
ogoo00=oo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009o
o`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol0
1Goo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<0
07ooOol00goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol0
1goo1P000goo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo
00@007ooOomoo`@000=oo`06001oogoo001oo`000goo00<007oo00005P000goo00@007ooOol000Eo
o`00:7oo00<007ooOol017oo100000=oo`00Ool0>00000Eoo`00Oomoo`00009oo`04001oogoo0002
Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool002Qoo`P000Aoo`D000=oo`8000Qoo`03
001oogoo00=oo`8000Aoo`8000Aoo`04001oogooOol50003Ool20003Ool30004Ool20004Ool20004
Ool30002Ool50003Ool20006Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOomM
000<Ool002Qoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03
001oogoo011oo`03001oogoo00Yoo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03
001oogoo00=oo`8000Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04
001oogoo0002Ool01P00Oomoo`00Ool000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol000Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@0
07ooOol0009oo`06001oogoo001oo`001Woo00<007ooOol0IWoo000;Ool2000:Ool20004Ool20002
Ool50002Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000AOol2
0004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003
Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`03001oogoo
06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool2
0003Ool30003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00D007ooOomoo`0000=oo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo00Eoo`03001oogoo06Uoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01000Oomo
ogoo1000K7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000=oo`03001oogoo06eoo`00
2goo0P002Woo0P0017oo00@007ooOomoo`D006]oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`002goo0P0017oo00<007ooOol00Woo0`000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo
00D007ooOomoo`00009oo`03001oogoo00iooeP000aoo`000goo1@000Woo00@007ooOol000]oo`03
001oogoo008000aoo`<006Aoo`002Woo00@007ooOol000]oo`04001oogoo000;Ool3001VOol000Yo
o`04001oogoo0007Ool40003Ool00`00Oomoo`08Ool2001XOol000Yoo`04001oogoo0007Ool00`00
Oomoo`04Ool20007Ool2001ZOol000]oo`8000Qoo`D0009oo`03001oogoo00Eoo`8006]oo`0077oo
00<007ooOol01Goo00<007ooOol01Goo0`0017oo0P002Goo0`0017oo0P0017oo0P001Goo0`000goo
0`0017oo0P001Goo1@000goo0P0017oo0P001Goo1@000Woo0`0017oo0P001Woo000LOol20005Ool0
0`00Oomoo`05Ool01@00Oomoogoo00000Woo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool01P00Oomoo`00Ool000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo00=oo`03001oogoo00Yoo`04001oogoo0002
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo
Ool000Ioo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`03Ool001aoo`03001oogoo009o
o`8000aoo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`03Ool001aoo`80009oo`8000Uoo`@000=oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool01000Oomoo`0017oo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00H007ooOomoo`00Ool40003Ool01000Oomoo`00
1Goo000LOol01@00Oomoogoo00002Woo00<007ooOol017oo00@007ooOol000Qoo`8000Aoo`04001o
ogoo0002Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`07001oogooOol007oo00001Woo00@007oo
Ool000Eoo`0077oo0P0000=oo`0000002Woo1@000goo0P002Woo00<007ooOol00goo0P0017oo0P00
1Woo00@007ooOomoo`D000=oo`8000Ioo`<000Aoo`8000Aoo`8000Ioo`<0009oo`D000=oo`8000Io
o`0077oo00@007oo0000075oo`0077oo0`00LWoo000LOomY000<Ool001aoo`05001oogooOol00003
Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00<007ooOol00Woo00<007ooOol02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`00
77oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo
000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol000]o
o`8000Aoo`03001oogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001o
ogooOol00002Ool00`00Oomoo`1bOol000Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yo
o`04001oogoo000;Ool01000Oomoo`00M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0
LWoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00
Oomoo`1bOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo
00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`80
07=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1b
Ool001Ioo`8000Aoo`8007=oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000LOol00`00Oomo
o`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079o
o`0077oo00<007ooOol0LWoo000:Ool30004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03
001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001o
ogoo001dOol000]oo`03001oogoo00]oo`03001oogoo008007=oo`002goo00<007ooOol01goo1000
0goo00<007ooOol0LWoo000:Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001o
ogoo00Moo`D0009oo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00
TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00
TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(49599\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .10002 m
.008 .10622 L
.012 .11541 L
.016 .12803 L
.02 .14281 L
.024 .15829 L
.028 .1731 L
.032 .18676 L
.036 .19801 L
.04 .20681 L
.044 .21309 L
.048 .21764 L
.052 .22103 L
.056 .22412 L
.06 .22769 L
.064 .23212 L
.068 .23752 L
.072 .2434 L
.076 .2491 L
.08 .25358 L
.084 .25596 L
.088 .25549 L
.092 .25195 L
.096 .24564 L
.1 .23746 L
.104 .22875 L
.108 .2211 L
.112 .21608 L
.116 .21491 L
.12 .21824 L
.124 .22597 L
.128 .23728 L
.132 .25075 L
.136 .26474 L
.14 .27758 L
.144 .28802 L
.148 .29532 L
.152 .29945 L
.156 .30089 L
.16 .30053 L
.164 .29937 L
.168 .29825 L
.172 .29771 L
.176 .29791 L
.18 .29875 L
.184 .30001 L
.188 .30154 L
.192 .30341 L
.196 .30589 L
.2 .30937 L
Mistroke
.204 .31406 L
.208 .31987 L
.212 .32627 L
.216 .33228 L
.22 .33669 L
.224 .33839 L
.228 .33674 L
.232 .33184 L
.236 .32469 L
.24 .31696 L
.244 .31063 L
.248 .30735 L
.252 .30799 L
.256 .31224 L
.26 .31874 L
.264 .3254 L
.268 .33008 L
.272 .33126 L
.276 .32848 L
.28 .32257 L
.284 .3153 L
.288 .30887 L
.292 .30517 L
.296 .3052 L
.3 .30876 L
.304 .31454 L
.308 .32063 L
.312 .32518 L
.316 .32704 L
.32 .32608 L
.324 .32318 L
.328 .31978 L
.332 .3173 L
.336 .31662 L
.34 .31781 L
.344 .32018 L
.348 .32264 L
.352 .32415 L
.356 .32411 L
.36 .3225 L
.364 .31983 L
.368 .31691 L
.372 .31451 L
.376 .31318 L
.38 .31314 L
.384 .31428 L
.388 .31629 L
.392 .31876 L
.396 .32124 L
.4 .32328 L
Mistroke
.404 .32445 L
.408 .32445 L
.412 .32321 L
.416 .32102 L
.42 .31848 L
.424 .3164 L
.428 .31549 L
.432 .31604 L
.436 .31774 L
.44 .31978 L
.444 .32117 L
.448 .32125 L
.452 .32 L
.456 .31814 L
.46 .31675 L
.464 .31675 L
.468 .31837 L
.472 .32094 L
.476 .32321 L
.48 .32391 L
.484 .32252 L
.488 .31955 L
.492 .31633 L
.496 .31441 L
.5 .3147 L
.504 .31706 L
.508 .32029 L
.512 .32276 L
.516 .3233 L
.52 .32177 L
.524 .31919 L
.528 .31706 L
.532 .31659 L
.536 .31796 L
.54 .32031 L
.544 .3222 L
.548 .32248 L
.552 .32094 L
.556 .31843 L
.56 .31635 L
.564 .31588 L
.568 .31723 L
.572 .31957 L
.576 .32158 L
.58 .32222 L
.584 .32131 L
.588 .31957 L
.592 .31814 L
.596 .31782 L
.6 .31869 L
Mistroke
.604 .32008 L
.608 .32101 L
.612 .32086 L
.616 .31974 L
.62 .31839 L
.624 .31768 L
.628 .31803 L
.632 .31917 L
.636 .32038 L
.64 .32096 L
.644 .32066 L
.648 .31977 L
.652 .31891 L
.656 .31858 L
.66 .31893 L
.664 .31967 L
.668 .32028 L
.672 .32036 L
.676 .31988 L
.68 .31919 L
.684 .31873 L
.688 .31879 L
.692 .3193 L
.696 .31992 L
.7 .32029 L
.704 .32023 L
.708 .31982 L
.712 .31932 L
.716 .31901 L
.72 .31907 L
.724 .31946 L
.728 .31994 L
.732 .3202 L
.736 .32004 L
.74 .31956 L
.744 .3191 L
.748 .31902 L
.752 .31944 L
.756 .32008 L
.76 .32049 L
.764 .32033 L
.768 .31964 L
.772 .31887 L
.776 .31852 L
.78 .31886 L
.784 .31971 L
.788 .32056 L
.792 .32091 L
.796 .32056 L
.8 .31975 L
Mistroke
.804 .31898 L
.808 .31872 L
.812 .31908 L
.816 .31975 L
.82 .32023 L
.824 .32021 L
.828 .31982 L
.832 .31947 L
.836 .31945 L
.84 .31975 L
.844 .32003 L
.848 .31997 L
.852 .3197 L
.856 .31952 L
.86 .31965 L
.864 .31999 L
.868 .32011 L
.872 .31978 L
.876 .31929 L
.88 .3191 L
.884 .31948 L
.888 .32026 L
.892 .32075 L
.896 .32053 L
.9 .31983 L
.904 .31914 L
.908 .31896 L
.912 .31941 L
.916 .31995 L
.92 .32021 L
.924 .32022 L
.928 .32005 L
.932 .31993 L
.936 .31995 L
.94 .31979 L
.944 .31951 L
.948 .31947 L
.952 .31962 L
.956 .31998 L
.96 .3204 L
.964 .3203 L
.968 .31987 L
.972 .31964 L
.976 .31953 L
.98 .31973 L
.984 .3201 L
.988 .32003 L
.992 .31984 L
.996 .31994 L
1 .32006 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .31153 m
.008 .30675 L
.012 .30506 L
.016 .3064 L
.02 .3066 L
.024 .30566 L
.028 .30502 L
.032 .30468 L
.036 .30416 L
.04 .30348 L
.044 .30275 L
.048 .302 L
.052 .30111 L
.056 .30008 L
.06 .29888 L
.064 .2975 L
.068 .2959 L
.072 .29409 L
.076 .29208 L
.08 .2899 L
.084 .28761 L
.088 .28527 L
.092 .28295 L
.096 .28072 L
.1 .27865 L
.104 .27678 L
.108 .27514 L
.112 .27373 L
.116 .27253 L
.12 .27151 L
.124 .27063 L
.128 .26984 L
.132 .26911 L
.136 .26841 L
.14 .26774 L
.144 .26711 L
.148 .26652 L
.152 .26601 L
.156 .26559 L
.16 .26527 L
.164 .26506 L
.168 .26496 L
.172 .26494 L
.176 .26499 L
.18 .26509 L
.184 .26521 L
.188 .26533 L
.192 .26543 L
.196 .26549 L
.2 .26549 L
Mistroke
.204 .2654 L
.208 .26523 L
.212 .26496 L
.216 .26462 L
.22 .26422 L
.224 .26379 L
.228 .26338 L
.232 .26302 L
.236 .26276 L
.24 .26259 L
.244 .26253 L
.248 .26253 L
.252 .26257 L
.256 .2626 L
.26 .26259 L
.264 .26252 L
.268 .26241 L
.272 .26229 L
.276 .26217 L
.28 .26211 L
.284 .26211 L
.288 .26219 L
.292 .26233 L
.296 .26249 L
.3 .26265 L
.304 .26277 L
.308 .26282 L
.312 .26281 L
.316 .26275 L
.32 .26265 L
.324 .26254 L
.328 .26243 L
.332 .26233 L
.336 .26223 L
.34 .26213 L
.344 .26202 L
.348 .2619 L
.352 .26178 L
.356 .26168 L
.36 .2616 L
.364 .26157 L
.368 .2616 L
.372 .26168 L
.376 .26179 L
.38 .26192 L
.384 .26203 L
.388 .26209 L
.392 .2621 L
.396 .26204 L
.4 .26193 L
Mistroke
.404 .26177 L
.408 .26161 L
.412 .26146 L
.416 .26135 L
.42 .26128 L
.424 .26126 L
.428 .26127 L
.432 .26131 L
.436 .26135 L
.44 .26138 L
.444 .26139 L
.448 .26139 L
.452 .26138 L
.456 .26135 L
.46 .26131 L
.464 .26126 L
.468 .26119 L
.472 .26111 L
.476 .26103 L
.48 .26094 L
.484 .26088 L
.488 .26085 L
.492 .26085 L
.496 .26088 L
.5 .26091 L
.504 .26093 L
.508 .26093 L
.512 .2609 L
.516 .26084 L
.52 .26078 L
.524 .26072 L
.528 .26067 L
.532 .26063 L
.536 .26059 L
.54 .26055 L
.544 .2605 L
.548 .26046 L
.552 .26042 L
.556 .2604 L
.56 .26039 L
.564 .2604 L
.568 .26041 L
.572 .26041 L
.576 .26039 L
.58 .26035 L
.584 .26029 L
.588 .26023 L
.592 .26017 L
.596 .26012 L
.6 .26007 L
Mistroke
.604 .26003 L
.608 .26 L
.612 .25997 L
.616 .25996 L
.62 .25996 L
.624 .25996 L
.628 .25996 L
.632 .25994 L
.636 .2599 L
.64 .25985 L
.644 .25978 L
.648 .25972 L
.652 .25967 L
.656 .25964 L
.66 .25962 L
.664 .25961 L
.668 .2596 L
.672 .25959 L
.676 .25956 L
.68 .25953 L
.684 .25949 L
.688 .25944 L
.692 .2594 L
.696 .25935 L
.7 .25931 L
.704 .25928 L
.708 .25926 L
.712 .25925 L
.716 .25925 L
.72 .25923 L
.724 .2592 L
.728 .25916 L
.732 .25911 L
.736 .25905 L
.74 .259 L
.744 .25896 L
.748 .25894 L
.752 .25892 L
.756 .25891 L
.76 .2589 L
.764 .25888 L
.768 .25885 L
.772 .25881 L
.776 .25877 L
.78 .25873 L
.784 .25868 L
.788 .25865 L
.792 .25862 L
.796 .25859 L
.8 .25857 L
Mistroke
.804 .25855 L
.808 .25852 L
.812 .25849 L
.816 .25845 L
.82 .25842 L
.824 .25839 L
.828 .25836 L
.832 .25833 L
.836 .2583 L
.84 .25827 L
.844 .25823 L
.848 .2582 L
.852 .25817 L
.856 .25814 L
.86 .25811 L
.864 .25808 L
.868 .25805 L
.872 .25802 L
.876 .25799 L
.88 .25796 L
.884 .25793 L
.888 .2579 L
.892 .25787 L
.896 .25784 L
.9 .25781 L
.904 .25777 L
.908 .25773 L
.912 .2577 L
.916 .25767 L
.92 .25765 L
.924 .25763 L
.928 .2576 L
.932 .25757 L
.936 .25754 L
.94 .2575 L
.944 .25746 L
.948 .25742 L
.952 .25738 L
.956 .25736 L
.96 .25733 L
.964 .25732 L
.968 .2573 L
.972 .25728 L
.976 .25724 L
.98 .2572 L
.984 .25714 L
.988 .25711 L
.992 .25707 L
.996 .25705 L
1 .25702 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .15485 L
.012 .14973 L
.016 .14462 L
.02 .1393 L
.024 .13419 L
.028 .1295 L
.032 .12515 L
.036 .12101 L
.04 .117 L
.044 .11318 L
.048 .10944 L
.052 .10576 L
.056 .10206 L
.06 .09836 L
.064 .09464 L
.068 .09091 L
.072 .08715 L
.076 .08339 L
.08 .07961 L
.084 .07582 L
.088 .07199 L
.092 .06811 L
.096 .06417 L
.1 .06016 L
.104 .05609 L
.108 .052 L
.112 .04793 L
.116 .04395 L
.12 .04012 L
.124 .03653 L
.128 .03321 L
.132 .03024 L
.136 .0276 L
.14 .02532 L
.144 .02334 L
.148 .02164 L
.152 .02015 L
.156 .01883 L
.16 .01762 L
.164 .0165 L
.168 .01544 L
.172 .01445 L
.176 .01352 L
.18 .01266 L
.184 .01188 L
.188 .01119 L
.192 .01061 L
.196 .01015 L
.2 .00982 L
Mistroke
.204 .00964 L
.208 .00961 L
.212 .00973 L
.216 .00998 L
.22 .01033 L
.224 .01073 L
.228 .01112 L
.232 .01145 L
.236 .01169 L
.24 .01181 L
.244 .01182 L
.248 .01175 L
.252 .01164 L
.256 .01155 L
.26 .0115 L
.264 .01153 L
.268 .01161 L
.272 .01173 L
.276 .01183 L
.28 .01187 L
.284 .01182 L
.288 .01168 L
.292 .01147 L
.296 .01123 L
.3 .01099 L
.304 .01081 L
.308 .01071 L
.312 .01069 L
.316 .01073 L
.32 .01081 L
.324 .01092 L
.328 .01102 L
.332 .01111 L
.336 .01119 L
.34 .01129 L
.344 .01139 L
.348 .01151 L
.352 .01162 L
.356 .01172 L
.36 .01178 L
.364 .01177 L
.368 .0117 L
.372 .01157 L
.376 .0114 L
.38 .01121 L
.384 .01104 L
.388 .01093 L
.392 .01088 L
.396 .01092 L
.4 .01102 L
Mistroke
.404 .01118 L
.408 .01135 L
.412 .0115 L
.416 .01162 L
.42 .01167 L
.424 .01166 L
.428 .0116 L
.432 .01152 L
.436 .01144 L
.44 .01137 L
.444 .01132 L
.448 .01129 L
.452 .01127 L
.456 .01127 L
.46 .01127 L
.464 .0113 L
.468 .01135 L
.472 .01142 L
.476 .0115 L
.48 .01157 L
.484 .01161 L
.488 .01161 L
.492 .01157 L
.496 .0115 L
.5 .01143 L
.504 .01137 L
.508 .01134 L
.512 .01135 L
.516 .01139 L
.52 .01143 L
.524 .01147 L
.528 .01149 L
.532 .0115 L
.536 .01152 L
.54 .01154 L
.544 .01157 L
.548 .0116 L
.552 .01161 L
.556 .0116 L
.56 .01157 L
.564 .01152 L
.568 .01148 L
.572 .01144 L
.576 .01144 L
.58 .01145 L
.584 .01149 L
.588 .01154 L
.592 .01158 L
.596 .01161 L
.6 .01163 L
Mistroke
.604 .01165 L
.608 .01165 L
.612 .01165 L
.616 .01163 L
.62 .0116 L
.624 .01156 L
.628 .01154 L
.632 .01153 L
.636 .01154 L
.64 .01157 L
.644 .01162 L
.648 .01166 L
.652 .01169 L
.656 .0117 L
.66 .01169 L
.664 .01166 L
.668 .01163 L
.672 .01161 L
.676 .01161 L
.68 .01163 L
.684 .01165 L
.688 .01168 L
.692 .0117 L
.696 .01172 L
.7 .01173 L
.704 .01172 L
.708 .01171 L
.712 .01168 L
.716 .01167 L
.72 .01166 L
.724 .01167 L
.728 .01169 L
.732 .01173 L
.736 .01176 L
.74 .01178 L
.744 .01179 L
.748 .01178 L
.752 .01176 L
.756 .01174 L
.76 .01173 L
.764 .01173 L
.768 .01174 L
.772 .01175 L
.776 .01177 L
.78 .01179 L
.784 .0118 L
.788 .01181 L
.792 .01181 L
.796 .01181 L
.8 .0118 L
Mistroke
.804 .0118 L
.808 .0118 L
.812 .01181 L
.816 .01182 L
.82 .01184 L
.824 .01185 L
.828 .01185 L
.832 .01185 L
.836 .01184 L
.84 .01184 L
.844 .01184 L
.848 .01185 L
.852 .01186 L
.856 .01188 L
.86 .0119 L
.864 .01191 L
.868 .01191 L
.872 .0119 L
.876 .01189 L
.88 .01188 L
.884 .01188 L
.888 .01189 L
.892 .01191 L
.896 .01193 L
.9 .01194 L
.904 .01195 L
.908 .01195 L
.912 .01194 L
.916 .01194 L
.92 .01194 L
.924 .01195 L
.928 .01196 L
.932 .01198 L
.936 .01199 L
.94 .01199 L
.944 .01198 L
.948 .01198 L
.952 .01197 L
.956 .01198 L
.96 .01198 L
.964 .01201 L
.968 .01202 L
.972 .01204 L
.976 .01204 L
.98 .01205 L
.984 .01203 L
.988 .01203 L
.992 .01202 L
.996 .01203 L
1 .01203 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo0P00KGoo000ROol2001]
Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oo`0006aoo`002Woo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0`00K7oo0003Ool50002Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`<006aoo`002Woo00@007ooOol000Qoo`04001oogoo
0004Ool01`00Oomoogoo001oo`0006aoo`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo
00<007ooOol00P0000=oo`00Ool0JWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool0
0`00Oomoo`0200000goo001oo`1ZOol000]oo`8000Yoo`8000=oo`<000=oo`04001oogoo001[Ool0
00]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`80009oo`03001oogoo06Qoo`002Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20002Ool00`00Oomoo`04Ool01000Oomo
ogoo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo0`0017oo0P000goo1@000goo0P00
17oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo009oo`8000Aoo`800003Ool007oo009oo`04001oogoo0002
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogoo
Ool00003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
0Woo00<007ooOol00Woo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8000Aoo`07001oogooOol007oo
00001Goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=o
o`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool20005Ool01000Oomoo`00
0Woo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`05001o
ogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol017oo00@007ooOol0009o
o`03001oogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`05
Ool20003Ool50003Ool01000Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool01000Oomoogoo10000goo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`00
0Woo00@007ooOol000=oo`06001oogooOol007oo10000goo00@007ooOol000Eoo`002goo0P002Woo
0P0017oo00<007ooOol00Woo0P002goo0P001Woo00@007ooOol000Ioo`8000Aoo`04001oogoo0002
Ool01000Oomoo`0017oo0P000goo00<007ooOol017oo00@007ooOol0009oo`05001oogooOol00002
Ool01000Oomoo`000Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00@007ooOol000Eo
o`008Woo0P0037oo1@000goo0P0027oo00<007ooOol00goo0P0017oo0P001Woo00@007ooOomoo`D0
00=oo`8000Aoo`<000Aoo`8000Aoo`8000Eoo`<0009oo`D000=oo`8000Ioo`008Woo00<007ooOol0
2goo00<007ooOol0GWoo000ROol2000=Ool01000Ool00000G7oo000ROomS000<Ool0029oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`800004Ool00000Ool40000
0goo0000000300001Goo00000000Ool01@0000Aoo`00001oo`80009oo`800006Ool00000Ool007oo
0`0000Aoo`00Oomoo`@00003Ool00000009oo`03001oogoo00800004Ool000000003Ool01@00Oomo
ogoo000037oo000ROol2000BOol2000017oo001oogoo0P000Woo0`0000Aoo`000000009oo`<00004
Ool00000Ool3000017oo000007oo0P0000Aoo`00001oo`800004Ool00000Ool200000goo00000006
000017oo000007oo4`0037oo000ROol00`00Oomoo`0BOol30002Ool2001COol0029oo`8006eoo`00
8Woo0P00KGoo000;Ool20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1/Ool000Yo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`8000Aoo`8006eo
o`002goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20002Ool50002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool0009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1/Ool000Yoo`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`8006eoo`002Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomoo`00
27oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:Ool20003Ool30003Ool2001]
Ool0029oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0P00KGoo
000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02001]Ool000Yoo`04001o
ogoo0008Ool01000Oomoo`001Goo00@007ooOol006ioo`002Woo00@007ooOol000Qoo`04001oogoo
0003Ool20003Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00
KGoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool01000Oomoo`00KWoo000;Ool2000:
Ool20003Ool30003Ool2001]Ool0029oo`8006eoo`008Woo00<007ooOol0K7oo000ROol2001]Ool0
029oo`03001oogoo06aoo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool20004
Ool00`00Oomoo`03Ool20003Ool30003Ool3001/Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`03001oogoo06Uoo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`04001oogooOol40003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo
0P000goo00<007ooOol017oo00<007ooOol0IWoo000;Ool2000:Ool20004Ool01000Oomoogoo1@00
0Woo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000AOol20004Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomoo`1VOol0011oo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo0009Ool50002Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006Moo`0047oo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol0
009oo`8000Aoo`03001oogoo06Ioo`004Goo0P002Woo0P0017oo00<007ooOol00Woo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo
0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`06001oogoo001oo`000goo00@007ooOol006Qoo`000goo1@000Woo00@007ooOol000Qoo`04001o
ogoo0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol00P002goo0`0017oo0P001goo0`0017oo0P0017oo0P00
0goo0`000goo0`0017oo0P000Woo1@000goo0P0017oo0P000goo1@000Woo0`0017oo0P001Woo000:
Ool01000Oomoo`0027oo00@007ooOol0009oo`05001oogoo001oo`040003Ool00`00Oomoo`09Ool0
1@00Oomoogoo00000Woo00@007ooOol000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000goo00@007ooOol0009oo`03001o
ogoo00=oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`03001o
ogoo00eoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0
009oo`04001oogoo0004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo000;Ool2
000:Ool20004Ool20002Ool50002Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000XOol00`00Oomoo`09Ool40003Ool01000
Oomoo`001goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool01000Oomoogoo1000
0goo00H007ooOol007oo0003Ool00`00Oomoo`0F0003Ool01000Oomoo`001Goo000XOol00`00Oomo
o`09Ooll0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000Ioo`04001oogoo0005
Ool002Qoo`03001oogoo00Ioo`P000=oo`8000Qoo`03001oogoo00=oo`8000Aoo`8000Aoo`04001o
ogooOol50003Ool20003Ool30004Ool20004Ool20004Ool30002Ool50003Ool20006Ool002Qoo`03
001oogoo00Aoo`<005moo`00:7oo00@007ooOomoo`@0065oo`00:7ooG@0037oo000XOol00`00Oomo
o`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomo
o`0:Ool002Qoo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qo
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000;Ool20004Ool00`00Oomoo`03Ool20004Ool2
0003Ool30003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007oo
Ool007oo0003Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0005Ool01000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00D007ooOol0
07oo00@000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomo
o`00Ool000Ioo`03001oogoo06Ioo`002goo0P002Woo0P0017oo0P000Woo1@000Woo00<007ooOol0
IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`004Goo0P0017oo00<007ooOol00goo
0P000goo0`000goo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo0P00
Igoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`00
47oo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`80
00Aoo`03001oogoo009oo`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1V
Ool002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo0`000goo
00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`05001oogooOol00003Ool0
1000Oomoo`00J7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001o
ogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`1YOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00@007ooOomoo`@006aoo`002Woo00@0
07ooOol000Qoo`04001oogoo0002Ool20003Ool00`00Oomoo`1]Ool000]oo`8000Yoo`8000Aoo`04
001oogooOol5001[Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol000]oo`8000Aoo`03001o
ogoo009oo`<000=oo`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool0
0`00Oomoo`0>OomH000<Ool000=oo`D0009oo`04001oogoo000;Ool00`00Oomoo`02000<Ool3001T
Ool000Yoo`04001oogoo000;Ool01000Oomoo`0037oo0P00IWoo000:Ool01000Oomoo`001goo1000
0goo00<007ooOol02Goo0P00Igoo000:Ool01000Oomoo`001goo00<007ooOol017oo0P002Goo0P00
J7oo000;Ool20008Ool50002Ool00`00Oomoo`07Ool2001YOol001aoo`03001oogoo00Ioo`8000Eo
o`<000Aoo`8000Uoo`<000Aoo`8000Aoo`8000Eoo`<000=oo`<000Aoo`8000Eoo`D000=oo`8000Ao
o`8000Eoo`D0009oo`<000Aoo`8000Ioo`0077oo0P001Woo00<007ooOol017oo00D007ooOomoo`00
009oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001o
ogooOol00003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`001Goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol00goo000L
Ool00`00Oomoo`04Ool2000:Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00goo000LOol00`00Oomoo`03Ool00`00Oomoo`0:Ool01000Oomoo`000Woo00<0
07ooOol01goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool0
1000Oomoo`000Woo00<007ooOol01Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000LOol20003Ool20008Ool4
0003Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool01000
Oomoogoo10000goo00@007ooOol000Aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`06001oogooOol007oo10000goo00@007ooOol000Eoo`0077oo00D007ooOomoo`0000Yo
o`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`000Woo00@007ooOol000Aoo`80
00=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04
001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005Ool001aoo`800003Ool00000
00Yoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Ioo`04001oogooOol50003Ool20006
Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool001aoo`03001oo`00079oo`0077oo
0`00LWoo000LOomY000<Ool001aoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007oo
Ool02Woo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00
Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`80
07=oo`0077oo00<007ooOol0LWoo000LOol2001cOol000]oo`8000Aoo`03001oogoo009oo`<000=o
o`03001oogoo079oo`002Woo00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`1bOol0
00Yoo`04001oogoo000;Ool00`00Oomoo`02001cOol000Yoo`04001oogoo000;Ool01000Oomoo`00
M7oo000:Ool01000Oomoo`001goo10000goo00<007ooOol0LWoo000:Ool01000Oomoo`001goo00<0
07ooOol017oo0P00Lgoo000;Ool20008Ool50002Ool00`00Oomoo`1bOol001aoo`03001oogoo079o
o`0077oo0P00Lgoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool00`00Oomoo`1bOol001aoo`8007=oo`005Woo0`000goo00<007ooOol0LWoo000GOol00`00Oomo
o`02Ool00`00Oomoo`1bOol001Moo`03001oogoo009oo`8007=oo`005goo00<007ooOol00Woo00<0
07ooOol0LWoo000GOol00`00Oomoo`02Ool00`00Oomoo`1bOol001Ioo`8000Aoo`8007=oo`005goo
00<007ooOol00Woo00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000:Ool3
0004Ool00`00Oomoo`02Ool30003Ool2001cOol000]oo`03001oogoo00Moo`05001oogooOol00002
Ool00`00Oomoo`1bOol000]oo`03001oogoo00]oo`04001oogoo001dOol000]oo`03001oogoo00]o
o`03001oogoo008007=oo`002goo00<007ooOol01goo10000goo00<007ooOol0LWoo000:Ool20009
Ool00`00Oomoo`04Ool00`00Oomoo`1bOol000]oo`03001oogoo00Moo`D0009oo`8007=oo`0077oo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo0000\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(49766\)], "Print",
  CellLabel->"From In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 7.92351 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 .07131 -30 -4.5 ]
[-0.0125 .07131 0 4.5 ]
[-0.0125 .15055 -30 -4.5 ]
[-0.0125 .15055 0 4.5 ]
[-0.0125 .22978 -30 -4.5 ]
[-0.0125 .22978 0 4.5 ]
[-0.0125 .38825 -24 -4.5 ]
[-0.0125 .38825 0 4.5 ]
[-0.0125 .46749 -24 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .54672 -24 -4.5 ]
[-0.0125 .54672 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 .07131 m
.00625 .07131 L
s
[(-0.03)] -0.0125 .07131 1 0 Mshowa
0 .15055 m
.00625 .15055 L
s
[(-0.02)] -0.0125 .15055 1 0 Mshowa
0 .22978 m
.00625 .22978 L
s
[(-0.01)] -0.0125 .22978 1 0 Mshowa
0 .38825 m
.00625 .38825 L
s
[(0.01)] -0.0125 .38825 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(0.02)] -0.0125 .46749 1 0 Mshowa
0 .54672 m
.00625 .54672 L
s
[(0.03)] -0.0125 .54672 1 0 Mshowa
.125 Mabswid
0 .08716 m
.00375 .08716 L
s
0 .10301 m
.00375 .10301 L
s
0 .11885 m
.00375 .11885 L
s
0 .1347 m
.00375 .1347 L
s
0 .16639 m
.00375 .16639 L
s
0 .18224 m
.00375 .18224 L
s
0 .19809 m
.00375 .19809 L
s
0 .21393 m
.00375 .21393 L
s
0 .24563 m
.00375 .24563 L
s
0 .26148 m
.00375 .26148 L
s
0 .27732 m
.00375 .27732 L
s
0 .29317 m
.00375 .29317 L
s
0 .32486 m
.00375 .32486 L
s
0 .34071 m
.00375 .34071 L
s
0 .35656 m
.00375 .35656 L
s
0 .37241 m
.00375 .37241 L
s
0 .4041 m
.00375 .4041 L
s
0 .41995 m
.00375 .41995 L
s
0 .43579 m
.00375 .43579 L
s
0 .45164 m
.00375 .45164 L
s
0 .48333 m
.00375 .48333 L
s
0 .49918 m
.00375 .49918 L
s
0 .51503 m
.00375 .51503 L
s
0 .53088 m
.00375 .53088 L
s
0 .05546 m
.00375 .05546 L
s
0 .03962 m
.00375 .03962 L
s
0 .02377 m
.00375 .02377 L
s
0 .00792 m
.00375 .00792 L
s
0 .56257 m
.00375 .56257 L
s
0 .57842 m
.00375 .57842 L
s
0 .59426 m
.00375 .59426 L
s
0 .61011 m
.00375 .61011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .1975 m
.008 .20242 L
.012 .20506 L
.016 .20687 L
.02 .20897 L
.024 .21021 L
.028 .21196 L
.032 .21571 L
.036 .22214 L
.04 .23055 L
.044 .24035 L
.048 .25077 L
.052 .26027 L
.056 .26753 L
.06 .27106 L
.064 .27035 L
.068 .26506 L
.072 .2559 L
.076 .24399 L
.08 .23108 L
.084 .21905 L
.088 .20963 L
.092 .20416 L
.096 .20323 L
.1 .20672 L
.104 .21373 L
.108 .22292 L
.112 .23269 L
.116 .24163 L
.12 .24869 L
.124 .25343 L
.128 .256 L
.132 .257 L
.136 .25733 L
.14 .25787 L
.144 .25928 L
.148 .26181 L
.152 .26542 L
.156 .2698 L
.16 .2746 L
.164 .27963 L
.168 .28491 L
.172 .29066 L
.176 .29713 L
.18 .30442 L
.184 .31229 L
.188 .32005 L
.192 .3267 L
.196 .3311 L
.2 .33235 L
Mistroke
.204 .33014 L
.208 .32494 L
.212 .31806 L
.216 .31132 L
.22 .30658 L
.224 .30521 L
.228 .30765 L
.232 .31318 L
.236 .32016 L
.24 .32647 L
.244 .33015 L
.248 .33001 L
.252 .32604 L
.256 .31942 L
.26 .31217 L
.264 .30649 L
.268 .30407 L
.272 .30554 L
.276 .31028 L
.28 .31667 L
.284 .32267 L
.288 .32656 L
.292 .32748 L
.296 .32568 L
.3 .32228 L
.304 .31884 L
.308 .3167 L
.312 .31652 L
.316 .31816 L
.32 .32073 L
.324 .32309 L
.328 .32423 L
.332 .32365 L
.336 .32151 L
.34 .31849 L
.344 .31553 L
.348 .31343 L
.352 .31266 L
.356 .31328 L
.36 .31503 L
.364 .31743 L
.368 .32 L
.372 .32229 L
.376 .32392 L
.38 .32457 L
.384 .32407 L
.388 .32243 L
.392 .32003 L
.396 .31753 L
.4 .31572 L
Mistroke
.404 .31521 L
.408 .31613 L
.412 .31806 L
.416 .3201 L
.42 .3213 L
.424 .32112 L
.428 .31971 L
.432 .31789 L
.436 .31675 L
.44 .31706 L
.444 .31885 L
.448 .32134 L
.452 .32327 L
.456 .32352 L
.46 .32177 L
.464 .31869 L
.468 .31569 L
.472 .31419 L
.476 .31494 L
.48 .31756 L
.484 .32076 L
.488 .32299 L
.492 .32323 L
.496 .32151 L
.5 .3189 L
.504 .3169 L
.508 .31658 L
.512 .31804 L
.516 .32032 L
.52 .32204 L
.524 .32215 L
.528 .32055 L
.532 .31813 L
.536 .31624 L
.54 .31593 L
.544 .31734 L
.548 .31967 L
.552 .32164 L
.556 .32223 L
.56 .3213 L
.564 .31954 L
.568 .31807 L
.572 .31769 L
.576 .31847 L
.58 .31979 L
.584 .32075 L
.588 .32074 L
.592 .31979 L
.596 .31852 L
.6 .31773 L
Mistroke
.604 .31789 L
.608 .31888 L
.612 .32009 L
.616 .32083 L
.62 .32076 L
.624 .32004 L
.628 .31917 L
.632 .31863 L
.636 .31866 L
.64 .31913 L
.644 .31971 L
.648 .32005 L
.652 .31998 L
.656 .3196 L
.66 .31917 L
.664 .31895 L
.668 .31904 L
.672 .31937 L
.676 .31972 L
.68 .31994 L
.684 .31994 L
.688 .31974 L
.692 .31944 L
.696 .31918 L
.7 .3191 L
.704 .31925 L
.708 .31956 L
.712 .31984 L
.716 .31992 L
.72 .31977 L
.724 .31953 L
.728 .3194 L
.732 .31944 L
.736 .31957 L
.74 .31962 L
.744 .31953 L
.748 .31937 L
.752 .31931 L
.756 .31942 L
.76 .31969 L
.764 .31993 L
.768 .31999 L
.772 .31985 L
.776 .3196 L
.78 .31944 L
.784 .31946 L
.788 .31961 L
.792 .31971 L
.796 .3196 L
.8 .31931 L
Mistroke
.804 .31911 L
.808 .3193 L
.812 .31987 L
.816 .32051 L
.82 .32071 L
.824 .32019 L
.828 .31926 L
.832 .31854 L
.836 .31857 L
.84 .31935 L
.844 .32028 L
.848 .32069 L
.852 .3204 L
.856 .3197 L
.86 .31917 L
.864 .31917 L
.868 .3195 L
.872 .31983 L
.876 .31995 L
.88 .31987 L
.884 .31981 L
.888 .31986 L
.892 .31983 L
.896 .31967 L
.9 .31949 L
.904 .31941 L
.908 .3196 L
.912 .32 L
.916 .32022 L
.92 .32015 L
.924 .31987 L
.928 .31949 L
.932 .31933 L
.936 .31948 L
.94 .31967 L
.944 .31996 L
.948 .32024 L
.952 .32023 L
.956 .32007 L
.96 .31977 L
.964 .31932 L
.968 .31923 L
.972 .3196 L
.976 .32003 L
.98 .3204 L
.984 .32042 L
.988 .31992 L
.992 .31948 L
.996 .31949 L
1 .31963 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.309017 20.6011 [
[.2 .29652 -6 -9 ]
[.2 .29652 6 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -9 -9 ]
[1 .29652 9 0 ]
[-0.0125 0 -36 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -36 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(50)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(100)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(150)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(200)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(250)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04 .30902 m
.04 .31277 L
s
.08 .30902 m
.08 .31277 L
s
.12 .30902 m
.12 .31277 L
s
.16 .30902 m
.16 .31277 L
s
.24 .30902 m
.24 .31277 L
s
.28 .30902 m
.28 .31277 L
s
.32 .30902 m
.32 .31277 L
s
.36 .30902 m
.36 .31277 L
s
.44 .30902 m
.44 .31277 L
s
.48 .30902 m
.48 .31277 L
s
.52 .30902 m
.52 .31277 L
s
.56 .30902 m
.56 .31277 L
s
.64 .30902 m
.64 .31277 L
s
.68 .30902 m
.68 .31277 L
s
.72 .30902 m
.72 .31277 L
s
.76 .30902 m
.76 .31277 L
s
.84 .30902 m
.84 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92 .30902 m
.92 .31277 L
s
.96 .30902 m
.96 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-0.015)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-0.01)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-0.005)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.005)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.01)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.015)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .33431 m
.008 .3328 L
.012 .33188 L
.016 .33156 L
.02 .33093 L
.024 .32981 L
.028 .32849 L
.032 .3271 L
.036 .32565 L
.04 .32406 L
.044 .3224 L
.048 .32071 L
.052 .31902 L
.056 .31735 L
.06 .31572 L
.064 .31418 L
.068 .31272 L
.072 .31138 L
.076 .31012 L
.08 .30894 L
.084 .3078 L
.088 .30666 L
.092 .30545 L
.096 .30414 L
.1 .30265 L
.104 .30099 L
.108 .29912 L
.112 .29707 L
.116 .29488 L
.12 .29259 L
.124 .29026 L
.128 .28796 L
.132 .28574 L
.136 .28364 L
.14 .2817 L
.144 .27993 L
.148 .27833 L
.152 .2769 L
.156 .2756 L
.16 .27444 L
.164 .27338 L
.168 .27241 L
.172 .2715 L
.176 .27062 L
.18 .26977 L
.184 .26891 L
.188 .26806 L
.192 .26722 L
.196 .2664 L
.2 .26564 L
Mistroke
.204 .26497 L
.208 .26442 L
.212 .26399 L
.216 .26371 L
.22 .26353 L
.224 .26344 L
.228 .26337 L
.232 .26331 L
.236 .26321 L
.24 .26307 L
.244 .26291 L
.248 .26275 L
.252 .26262 L
.256 .26255 L
.26 .26256 L
.264 .26265 L
.268 .26278 L
.272 .26293 L
.276 .26307 L
.28 .26315 L
.284 .26316 L
.288 .26311 L
.292 .26302 L
.296 .2629 L
.3 .26278 L
.304 .26266 L
.308 .26256 L
.312 .26245 L
.316 .26235 L
.32 .26224 L
.324 .26212 L
.328 .26202 L
.332 .26193 L
.336 .26188 L
.34 .26188 L
.344 .26193 L
.348 .26203 L
.352 .26215 L
.356 .26226 L
.36 .26235 L
.364 .26238 L
.368 .26236 L
.372 .26227 L
.376 .26214 L
.38 .26198 L
.384 .26182 L
.388 .26168 L
.392 .26158 L
.396 .26154 L
.4 .26154 L
Mistroke
.404 .26157 L
.408 .26161 L
.412 .26166 L
.416 .26168 L
.42 .26169 L
.424 .26167 L
.428 .26165 L
.432 .26161 L
.436 .26157 L
.44 .26151 L
.444 .26144 L
.448 .26136 L
.452 .26127 L
.456 .2612 L
.46 .26115 L
.464 .26113 L
.468 .26115 L
.472 .26118 L
.476 .26121 L
.48 .26122 L
.484 .26121 L
.488 .26116 L
.492 .2611 L
.496 .26104 L
.5 .26098 L
.504 .26093 L
.508 .26089 L
.512 .26086 L
.516 .26081 L
.52 .26077 L
.524 .26072 L
.528 .26069 L
.532 .26068 L
.536 .26068 L
.54 .26069 L
.544 .2607 L
.548 .26069 L
.552 .26066 L
.556 .26061 L
.56 .26055 L
.564 .26048 L
.568 .26042 L
.572 .26038 L
.576 .26033 L
.58 .2603 L
.584 .26028 L
.588 .26026 L
.592 .26025 L
.596 .26024 L
.6 .26024 L
Mistroke
.604 .26023 L
.608 .26021 L
.612 .26016 L
.616 .26011 L
.62 .26004 L
.624 .25998 L
.628 .25994 L
.632 .25991 L
.636 .25989 L
.64 .25989 L
.644 .25988 L
.648 .25987 L
.652 .25984 L
.656 .2598 L
.66 .25975 L
.664 .2597 L
.668 .25966 L
.672 .25962 L
.676 .25959 L
.68 .25957 L
.684 .25955 L
.688 .25954 L
.692 .25952 L
.696 .2595 L
.7 .25947 L
.704 .25942 L
.708 .25937 L
.712 .25932 L
.716 .25927 L
.72 .25924 L
.724 .25922 L
.728 .25921 L
.732 .25919 L
.736 .25917 L
.74 .25915 L
.744 .25912 L
.748 .25908 L
.752 .25904 L
.756 .259 L
.76 .25896 L
.764 .25892 L
.768 .25889 L
.772 .25887 L
.776 .25884 L
.78 .25882 L
.784 .25879 L
.788 .25876 L
.792 .25873 L
.796 .25869 L
.8 .25866 L
Mistroke
.804 .25863 L
.808 .2586 L
.812 .25857 L
.816 .25854 L
.82 .25851 L
.824 .25848 L
.828 .25844 L
.832 .25841 L
.836 .25837 L
.84 .25834 L
.844 .25832 L
.848 .2583 L
.852 .25828 L
.856 .25825 L
.86 .25821 L
.864 .25817 L
.868 .25813 L
.872 .2581 L
.876 .25806 L
.88 .25804 L
.884 .25801 L
.888 .25799 L
.892 .25796 L
.896 .25793 L
.9 .2579 L
.904 .25786 L
.908 .25783 L
.912 .25779 L
.916 .25777 L
.92 .25774 L
.924 .25771 L
.928 .25768 L
.932 .25765 L
.936 .25761 L
.94 .25758 L
.944 .25755 L
.948 .25753 L
.952 .2575 L
.956 .25747 L
.96 .25744 L
.964 .25741 L
.968 .25736 L
.972 .25733 L
.976 .25729 L
.98 .25727 L
.984 .25724 L
.988 .25723 L
.992 .2572 L
.996 .25718 L
1 .25713 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.004 0.161226 0.26871 [
[.2 .14873 -6 -9 ]
[.2 .14873 6 0 ]
[.4 .14873 -9 -9 ]
[.4 .14873 9 0 ]
[.6 .14873 -9 -9 ]
[.6 .14873 9 0 ]
[.8 .14873 -9 -9 ]
[.8 .14873 9 0 ]
[1 .14873 -9 -9 ]
[1 .14873 9 0 ]
[-0.0125 .02687 -24 -4.5 ]
[-0.0125 .02687 0 4.5 ]
[-0.0125 .29558 -18 -4.5 ]
[-0.0125 .29558 0 4.5 ]
[-0.0125 .42994 -6 -4.5 ]
[-0.0125 .42994 0 4.5 ]
[-0.0125 .56429 -18 -4.5 ]
[-0.0125 .56429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16123 m
.2 .16748 L
s
[(50)] .2 .14873 0 1 Mshowa
.4 .16123 m
.4 .16748 L
s
[(100)] .4 .14873 0 1 Mshowa
.6 .16123 m
.6 .16748 L
s
[(150)] .6 .14873 0 1 Mshowa
.8 .16123 m
.8 .16748 L
s
[(200)] .8 .14873 0 1 Mshowa
1 .16123 m
1 .16748 L
s
[(250)] 1 .14873 0 1 Mshowa
.125 Mabswid
.04 .16123 m
.04 .16498 L
s
.08 .16123 m
.08 .16498 L
s
.12 .16123 m
.12 .16498 L
s
.16 .16123 m
.16 .16498 L
s
.24 .16123 m
.24 .16498 L
s
.28 .16123 m
.28 .16498 L
s
.32 .16123 m
.32 .16498 L
s
.36 .16123 m
.36 .16498 L
s
.44 .16123 m
.44 .16498 L
s
.48 .16123 m
.48 .16498 L
s
.52 .16123 m
.52 .16498 L
s
.56 .16123 m
.56 .16498 L
s
.64 .16123 m
.64 .16498 L
s
.68 .16123 m
.68 .16498 L
s
.72 .16123 m
.72 .16498 L
s
.76 .16123 m
.76 .16498 L
s
.84 .16123 m
.84 .16498 L
s
.88 .16123 m
.88 .16498 L
s
.92 .16123 m
.92 .16498 L
s
.96 .16123 m
.96 .16498 L
s
.25 Mabswid
0 .16123 m
1 .16123 L
s
0 .02687 m
.00625 .02687 L
s
[(-0.5)] -0.0125 .02687 1 0 Mshowa
0 .29558 m
.00625 .29558 L
s
[(0.5)] -0.0125 .29558 1 0 Mshowa
0 .42994 m
.00625 .42994 L
s
[(1)] -0.0125 .42994 1 0 Mshowa
0 .56429 m
.00625 .56429 L
s
[(1.5)] -0.0125 .56429 1 0 Mshowa
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .13436 m
.00375 .13436 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .24184 m
.00375 .24184 L
s
0 .26871 m
.00375 .26871 L
s
0 .32245 m
.00375 .32245 L
s
0 .34932 m
.00375 .34932 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .45681 m
.00375 .45681 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.004 .16123 m
.008 .16083 L
.012 .15374 L
.016 .14886 L
.02 .14613 L
.024 .14256 L
.028 .13817 L
.032 .13408 L
.036 .13028 L
.04 .12652 L
.044 .12281 L
.048 .11934 L
.052 .11609 L
.056 .11301 L
.06 .11005 L
.064 .10715 L
.068 .10426 L
.072 .10125 L
.076 .09809 L
.08 .0947 L
.084 .09109 L
.088 .08724 L
.092 .08321 L
.096 .07903 L
.1 .07477 L
.104 .0705 L
.108 .06627 L
.112 .06213 L
.116 .05811 L
.12 .0542 L
.124 .05042 L
.128 .04676 L
.132 .04321 L
.136 .03978 L
.14 .03648 L
.144 .03333 L
.148 .03036 L
.152 .02758 L
.156 .02502 L
.16 .0227 L
.164 .02063 L
.168 .01883 L
.172 .01731 L
.176 .01605 L
.18 .01508 L
.184 .01436 L
.188 .01388 L
.192 .01361 L
.196 .01349 L
.2 .01346 L
Mistroke
.204 .01346 L
.208 .01345 L
.212 .01337 L
.216 .01321 L
.22 .013 L
.224 .01275 L
.228 .01251 L
.232 .01231 L
.236 .0122 L
.24 .01217 L
.244 .0122 L
.248 .01225 L
.252 .01228 L
.256 .01225 L
.26 .01213 L
.264 .01193 L
.268 .01169 L
.272 .01142 L
.276 .0112 L
.28 .01103 L
.284 .01095 L
.288 .01095 L
.292 .01102 L
.296 .01112 L
.3 .01123 L
.304 .01134 L
.308 .01143 L
.312 .01151 L
.316 .0116 L
.32 .0117 L
.324 .01181 L
.328 .01191 L
.332 .01198 L
.336 .012 L
.34 .01197 L
.344 .01187 L
.348 .01171 L
.352 .01153 L
.356 .01135 L
.36 .01121 L
.364 .01113 L
.368 .01112 L
.372 .0112 L
.376 .01133 L
.38 .0115 L
.384 .01166 L
.388 .0118 L
.392 .01188 L
.396 .01191 L
.4 .01187 L
Mistroke
.404 .0118 L
.408 .01171 L
.412 .01163 L
.416 .01156 L
.42 .01152 L
.424 .01149 L
.428 .01149 L
.432 .0115 L
.436 .01153 L
.44 .01157 L
.444 .01162 L
.448 .01169 L
.452 .01176 L
.456 .01181 L
.46 .01184 L
.464 .01183 L
.468 .01178 L
.472 .01171 L
.476 .01164 L
.48 .01158 L
.484 .01156 L
.488 .01158 L
.492 .01163 L
.496 .01167 L
.5 .01172 L
.504 .01174 L
.508 .01176 L
.512 .01177 L
.516 .01178 L
.52 .0118 L
.524 .01182 L
.528 .01183 L
.532 .01182 L
.536 .01178 L
.54 .01174 L
.544 .0117 L
.548 .01167 L
.552 .01167 L
.556 .01169 L
.56 .01174 L
.564 .01178 L
.568 .01183 L
.572 .01186 L
.576 .01188 L
.58 .01188 L
.584 .01188 L
.588 .01187 L
.592 .01184 L
.596 .01181 L
.6 .01178 L
Mistroke
.604 .01176 L
.608 .01176 L
.612 .01178 L
.616 .01182 L
.62 .01187 L
.624 .01191 L
.628 .01193 L
.632 .01193 L
.636 .01191 L
.64 .01188 L
.644 .01185 L
.648 .01184 L
.652 .01184 L
.656 .01186 L
.66 .01189 L
.664 .01191 L
.668 .01194 L
.672 .01195 L
.676 .01196 L
.68 .01195 L
.684 .01193 L
.688 .01191 L
.692 .01189 L
.696 .01189 L
.7 .0119 L
.704 .01192 L
.708 .01196 L
.712 .012 L
.716 .01202 L
.72 .01202 L
.724 .01201 L
.728 .01198 L
.732 .01196 L
.736 .01195 L
.74 .01195 L
.744 .01196 L
.748 .01198 L
.752 .01201 L
.756 .01203 L
.76 .01204 L
.764 .01205 L
.768 .01204 L
.772 .01203 L
.776 .01202 L
.78 .01202 L
.784 .01203 L
.788 .01204 L
.792 .01206 L
.796 .01207 L
.8 .01207 L
Mistroke
.804 .01208 L
.808 .01207 L
.812 .01207 L
.816 .01207 L
.82 .01208 L
.824 .01208 L
.828 .0121 L
.832 .01211 L
.836 .01212 L
.84 .01212 L
.844 .01213 L
.848 .01213 L
.852 .01213 L
.856 .01212 L
.86 .01212 L
.864 .01213 L
.868 .01213 L
.872 .01214 L
.876 .01216 L
.88 .01217 L
.884 .01218 L
.888 .01218 L
.892 .01219 L
.896 .01218 L
.9 .01218 L
.904 .01217 L
.908 .01218 L
.912 .01219 L
.916 .01221 L
.92 .01222 L
.924 .01223 L
.928 .01223 L
.932 .01222 L
.936 .01221 L
.94 .01222 L
.944 .01222 L
.948 .01224 L
.952 .01226 L
.956 .01228 L
.96 .01228 L
.964 .01229 L
.968 .01227 L
.972 .01226 L
.976 .01224 L
.98 .01225 L
.984 .01226 L
.988 .0123 L
.992 .01231 L
.996 .01234 L
1 .01234 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{145.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A00017a000`40O003h00OTGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095o
o`00TGoo002AOol0095oo`00TGoo000ROol00`00Oomoo`1/Ool0029oo`8006eoo`008Woo00<007oo
Ool0K7oo000ROol2001]Ool0029oo`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`00
0goo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003Ool00`00Oomoo`02
001]Ool000=oo`D0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00P00KGoo000:
Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`03001oogoo06aoo`002Woo00@007ooOol0
00Qoo`04001oogoo0005Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00
Ool000=oo`03001oogoo008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000R
Ool2001]Ool000]oo`8000Aoo`03001oogoo00=oo`80009oo`D0009oo`03001oogoo06aoo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0P00KGoo0003Ool50002Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04
001oogoo0004Ool01@00Oomoogoo0000KWoo000:Ool01000Oomoo`0027oo00H007ooOol007oo0003
Ool00`00Oomoo`02001]Ool000Yoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo
008006eoo`002goo0P002Woo0P000goo0`000goo00<007ooOol0K7oo000;Ool20004Ool00`00Oomo
o`03Ool20003Ool30003Ool20007Ool2001TOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo10001Goo0P0017oo0`0017oo0P001goo0`0017oo0P0017oo0P001Goo0`000goo
0`0017oo0P000goo1@000goo0P0017oo0P0017oo1@000Woo0`0017oo0P001Woo0003Ool50002Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`05001oogooOol00003Ool01000Oomo
o`000Woo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo00H007ooOol007oo0003Ool01000Oomo
o`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009o
o`80009oo`05001oogooOol00002Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`80009oo`05001oogooOol00002Ool00`00Oomoo`04Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`05
Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00
Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00goo000:Ool01000Oomoo`00
27oo00@007ooOol0009oo`8000Aoo`03001oogoo009oo`03001oo`0000Aoo`H000=oo`04001oogoo
0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogooOol40003Ool0
1000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00H007oo
Oomoo`00Ool40003Ool01000Oomoo`001Goo000;Ool2000:Ool20004Ool00`00Oomoo`02Ool20003
Ool30006Ool20005Ool01000Oomoo`001Woo0P0017oo00@007ooOol0009oo`04001oogoo0004Ool2
0003Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool0
1000Oomoo`000goo00L007ooOomoo`00Ool00006Ool01000Oomoo`001Goo000ROol20004Ool00`00
Oomoo`05Ool50003Ool20008Ool00`00Oomoo`03Ool20004Ool20006Ool01000Oomoogoo1@000goo
0P0017oo0`0017oo0P0017oo0P001Goo0`000Woo1@000goo0P001Woo000ROol00`00Oomoo`0=Ool2
001MOol0029oo`8000moo`03001oogoo05]oo`008WooH`0037oo000ROol01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`04001oo`00Ool200001Woo00000000Ool0009oo`800003Ool000000080
009oo`800004Ool00000Ool300000goo00000003000017oo000007oo0P0000Aoo`00001oo`<00004
Ool000000003Ool01000Oomoogoo0P0000Moo`00001oo`00Ool00003Ool01@00Oomoogoo00000goo
00<007ooOol02Woo000ROol2000@Ool30002Ool30002Ool2000017oo000000000Woo0`000Woo0P00
00Aoo`00001oo`800005Ool00000001oo`02000017oo000007oo0P0000Aoo`00001oo`l00003Ool0
000000l000aoo`008Woo00<007ooOol047oo0P000goo00<007ooOol0E7oo000ROol2001]Ool0029o
o`8006eoo`002goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0K7oo000:Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`8006eoo`002Woo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`02Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo009oo`8006eoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool20004Ool2001]Ool0
00]oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06aoo`002goo0P0017oo00<007ooOol0
0goo0P000Woo1@000Woo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0002Ool2001]Ool000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0K7oo000:Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oogooOol2001]Ool000Yoo`04
001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo008006eoo`002Woo00@007ooOol000Qo
o`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo0P000goo0`000goo0P00KGoo
000ROol00`00Oomoo`1/Ool000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<000=oo`8006eoo`00
2Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00P00KGoo000:Ool01000Oomo
o`0027oo00@007ooOol000Eoo`04001oogoo001^Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0goo0P000goo0P00KGoo000:Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008006eo
o`002Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol006ioo`002goo0P002Woo
0P000goo0`000goo0P00KGoo000ROol2001]Ool0029oo`03001oogoo06aoo`008Woo0P00KGoo000R
Ool00`00Oomoo`1/Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`002goo0P0017oo
00<007ooOol00goo0P000goo0`000goo0`00K7oo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`05001oogooOol00003Ool00`00Oomoo`1YOol000=oo`D0009oo`04001oogoo0008Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo008006Moo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool0
1000Oomoogoo10000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0009oo`80
00=oo`03001oogoo00Aoo`03001oogoo06Ioo`002goo0P002Woo0P0017oo00@007ooOomoo`D0009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo
06Ioo`004Goo0P0017oo00<007ooOol00goo0P000goo0`000goo00<007ooOol0IWoo000@Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo06Ioo`002Goo1@000Woo00@0
07ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool2001WOol0011oo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo0002
Ool20004Ool00`00Oomoo`1VOol0015oo`8000Yoo`8000Aoo`03001oogoo009oo`03001oogoo06Io
o`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`80
00Aoo`8000=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1P00Oomoo`00Ool000=oo`04001oogoo001XOol000=oo`D0009oo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000Eoo`04001oogoo001XOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol000Eoo`03001oogoo008000]oo`<000Aoo`8000Moo`<000Aoo`8000Aoo`8000=o
o`<000=oo`<000Aoo`80009oo`D000=oo`8000Aoo`8000=oo`D0009oo`<000Aoo`8000Ioo`002Woo
00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool010000goo00<007ooOol02Goo00D0
07ooOomoo`00009oo`04001oogoo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00=oo`05001oogooOol00003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomo
o`03Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo00H007ooOol007oo0006Ool00`00Oomo
o`0=Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo0003Ool00`00Oomoo`05Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001oogoo0002
Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`002goo0P00
2Woo0P0017oo0P000Woo1@000Woo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00goo00<007oo
Ool017oo00@007ooOol0009oo`03001oogoo00=oo`00:7oo00<007ooOol02Goo10000goo00@007oo
Ool000Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOomoo`@000=o
o`06001oogoo001oo`000goo00<007ooOol05P000goo00@007ooOol000Eoo`00:7oo00<007ooOol0
2Goo00<007ooOol00Woo=`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00006Ool0
1000Oomoo`001Goo000XOol00`00Oomoo`09Ool60002Ool20008Ool00`00Oomoo`03Ool20004Ool2
0004Ool01000Oomoogoo1@000goo0P000goo0`0017oo0P0017oo0P0017oo0`000Woo1@000goo0P00
1Woo000XOol00`00Oomoo`08Ool3001KOol002Qoo`03001oogoo00Moo`8005eoo`00:7ooG@0037oo
000XOol01000Oomoogoo0`002goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<0
07ooOol047oo00<007ooOol02Woo000XOol4001UOol002Qoo`03001oogoo06Ioo`00:7oo00<007oo
Ool0IWoo000XOol00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`002goo0P0017oo00<007ooOol0
0goo0P0017oo0P000goo0`000goo00<007ooOol0IWoo000:Ool01000Oomoo`0027oo00@007ooOol0
009oo`06001oogoo001oo`000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`001Goo00<007ooOol00P00Igoo000:Ool01000Oomoo`0027oo00@007ooOol0009o
o`05001oogoo001oo`040003Ool00`00Oomoo`1VOol000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00H007ooOol007oo0006Ool00`00Oomoo`1VOol000]oo`8000Yoo`8000Aoo`80009oo`D0009o
o`03001oogoo06Ioo`00:7oo00<007ooOol0IWoo000XOol00`00Oomoo`1VOol0015oo`8000Aoo`03
001oogoo00=oo`8000=oo`<000=oo`03001oogoo06Ioo`0047oo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol0IWoo000@Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo009oo`8006Moo`0047oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol0011oo`04001oogoo0008Ool01000Oomoo`000Woo0P0017oo00<007ooOol0IWoo000A
Ool2000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`1VOol002Qoo`03001oogoo06Ioo`00:7oo
00<007ooOol0IWoo000XOol00`00Oomoo`1VOol000]oo`8000Aoo`03001oogoo00=oo`8000=oo`<0
00=oo`<000=oo`03001oogoo06Ioo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool01@00Oomo
ogoo00000goo00@007ooOol006Qoo`002Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`05Ool00`00Oomoo`02001WOol000Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
1Goo00<007ooOol0JGoo000:Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol4001/
Ool000Yoo`04001oogoo0008Ool01000Oomoo`000Woo0P000goo00<007ooOol0KGoo000;Ool2000:
Ool20004Ool01000Oomoogoo1@00Jgoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0
095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo000;Ool2
0004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool01@00Oomo
ogoo00000Woo00<007ooOol03gooE`0037oo0003Ool50002Ool01000Oomoo`002goo00<007ooOol0
0P003Woo0`00HWoo000:Ool01000Oomoo`002goo00@007ooOol000ioo`8006Aoo`002Woo00@007oo
Ool000Moo`@000=oo`03001oogoo00Yoo`8006Ioo`002Woo00@007ooOol000Moo`03001oogoo00Ao
o`8000]oo`03001oogoo06Eoo`002goo0P0027oo1@000Woo00<007ooOol027oo0P00J7oo000LOol0
0`00Oomoo`08Ool00`00Oomoo`02Ool30004Ool20009Ool30004Ool20004Ool20005Ool30003Ool3
0004Ool20005Ool50003Ool20004Ool20005Ool50002Ool30004Ool20006Ool001aoo`8000Qoo`03
001oogoo009oo`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`06001oogoo001oo`000goo00@007oo
Ool0009oo`03001oogoo00=oo`0077oo00<007ooOol01Goo0P002Goo00@007ooOol0009oo`03001o
ogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo00@0
07ooOol0009oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo
00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00=oo`0077oo00<007ooOol017oo0P002Woo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
1Goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool01000
Oomoo`000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00=oo`00
77oo0P0017oo0P001goo10000goo00@007ooOol000Uoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00@007ooOomoo`@000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`04001oogoo0004Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0005Ool001ao
o`03001oogoo009oo`8000Qoo`03001oogoo00Aoo`04001oogoo0008Ool20004Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`8000=oo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0005
Ool001aoo`80009oo`03001oogoo00Qoo`D000=oo`8000Yoo`03001oogoo00=oo`8000Aoo`8000Io
o`04001oogooOol50003Ool20006Ool30004Ool20004Ool20006Ool30002Ool50003Ool20006Ool0
01aoo`04001oogoo001aOol001aoo`03001oo`00079oo`0077ooJ@0037oo000LOol01@00Oomoogoo
00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`0077oo00<007ooOol0LWoo000LOol2001c
Ool001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo
079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo
000;Ool20004Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`1bOol000Yoo`04001oogoo0007Ool0
1@00Oomoogoo00000Woo00<007ooOol0LWoo000:Ool01000Oomoo`002goo00<007ooOol00P00Lgoo
000:Ool01000Oomoo`002goo00@007ooOol007Aoo`002Woo00@007ooOol000Moo`@000=oo`03001o
ogoo079oo`002Woo00@007ooOol000Moo`03001oogoo00Aoo`8007=oo`002goo0P0027oo1@000Woo
00<007ooOol0LWoo000LOol00`00Oomoo`1bOol001aoo`8007=oo`0077oo00<007ooOol0LWoo000L
Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo000LOol2001cOol001Ioo`<0
00=oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007ooOol0LWoo000GOol00`00Oomoo`02
Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`005goo00<007ooOol00Woo00<007oo
Ool0LWoo000FOol20004Ool2001cOol001Moo`03001oogoo009oo`03001oogoo079oo`0077oo00<0
07ooOol0LWoo000LOol2001cOol001aoo`03001oogoo079oo`0077oo0P00Lgoo000LOol00`00Oomo
o`1bOol001aoo`03001oogoo079oo`002Woo0`0017oo00<007ooOol00Woo0`000goo0P00Lgoo000;
Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol0LWoo000;Ool00`00Oomoo`0;Ool0
1000Oomoo`00M7oo000;Ool00`00Oomoo`0;Ool00`00Oomoo`02001cOol000]oo`03001oogoo00Mo
o`@000=oo`03001oogoo079oo`002Woo0P002Goo00<007ooOol017oo00<007ooOol0LWoo000;Ool0
0`00Oomoo`07Ool50002Ool2001cOol001aoo`03001oogoo079oo`0077oo00<007ooOol0LWoo002A
Ool0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002AOol0095oo`00TGoo002A
Ool0095oo`00TGoo002AOol0095oo`00\
\>"],
  ImageRangeCache->{{{0, 144.562}, {286.875, 0}} -> {-0.0250052, -0.0529842, \
0.00726337, 0.00726337}, {{3.4375, 141.062}, {279.562, 194.438}} -> \
{-88.9458, -0.0646218, 2.56657, 0.00129567}, {{3.4375, 141.062}, {185.938, \
100.875}} -> {-110.902, -0.076127, 2.73282, 0.000530616}, {{3.4375, 141.062}, \
{92.375, 7.25}} -> {-69.508, -8.01878, 2.41938, 0.0360147}}],

Cell[BoxData[
    \(49933\)], "Print",
  CellLabel->"From In[44]:="],

Cell[BoxData[
    \({125478.90000000001`\ Second, Null}\)], "Output",
  CellLabel->"Out[44]="],

Cell[BoxData[
    \("Fertig !"\)], "Print",
  CellLabel->"From In[44]:="]
}, Closed]],

Cell["\<\
This shows the voltage between line 1 and 2, sampled at the right \
end of the pigtail (1m), as it would appear on a scope \[Dash] leading edge \
is to the left \[Dash] :\
\>", "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[uout, AxesLabel -> {"\<time [ps]\>", "\<Ampl\>"}]\)], "Input",
  CellLabel->"In[46]:="],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P00025A000`40O003h00OogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo001?Ool0
0`00Oomoo`3oOoooOoooOolAOol004moo`03001oogoo0?mooomooomooa5oo`00Cgoo00<007ooOol0
ogooogooogoo4Goo001?Ool00`00Oomoo`3oOoooOoooOolAOol004moo`03001oogoo0?mooomooomo
oa5oo`00Cgoo00<007ooOol0ogooogooogoo4Goo001?Ool00`00Oomoo`3oOoooOoooOolAOol004mo
o`03001oogoo0?mooomooomooa5oo`00Cgoo00<007ooOol0ogooogoo17oo0`00ogoo2Woo001?Ool0
0`00Oomoo`3oOoooOol3Ool6003oOol8Ool004moo`<00?mooomoo`=oo`L000=oo`<00?moo`5oo`00
Cgoo00<007ooOol0ogooogoo0Woo2@0000=oo`0000000`00ogoo001?Ool00`00Oomoo`3oOoooOol2
OolC003kOol004moo`03001oogoo0?mooomoo`9oo`@00003Ool0000001T00>ioo`00Cgoo00<007oo
Ool0ogooogoo0Woo100000=oo`0000009000hgoo001?Ool00`00Oomoo`3oOoooOol2Ool40002Oolb
003FOol004moo`03001oogoo0?mooomoo`9oo`@000=oo`D00003Ool0000003<00<aoo`00Cgoo00<0
07ooOol0ogooogoo0Woo10005goo:000bgoo001?Ool00`00Oomoo`3oOoooOol1Ool5000UOolJ003;
Ool001Uoo`@000ioo`<000eoo`H000ioo`03001oogoo0?mooomoo`5oo`D0039oo``00<aoo`005goo
20002goo1@002Woo2P0037oo00<007ooOol0ogooogoo0Goo1000ogoo37oo000GOol20004Ool2000;
Ool5000:Ool30005Ool3000;Ool00`00Oomoo`3POol5003oOolKOol4003oOol<Ool001Ioo`8000Io
o`8000Yoo`D001=oo`8000]oo`03001oogoo0=moo`L00?mooaYoo`@00?moo`aoo`005Woo0P001Woo
0P002goo0`005Goo0P002Woo00<007ooOol0ggoo20000Woo0`000goo0P00ogoo3goo1000ogoo37oo
0002Ool=0006Ool20008Ool2000ROol2000:Ool00`00Oomoo`3OOolG003oOol9Ool5003oOol<Ool0
009oo`d000Ioo`8000Qoo`80029oo`8000Yoo`03001oogoo0=ioobL00?Uoo`D00?moo`aoo`000Woo
3@001Woo0P0027oo0P008Woo0P002Woo1@00g7oo>000j7oo1000ogoo3Goo000EOol20008Ool2000R
Ool2000:Ool00`00Oomoo`3NOol40002Oom2003HOol4003oOol=Ool001Eoo`8000Qoo`80025oo`80
00]oo`03001oogoo0=ioo`@000=oo`@0009oo`@00005Ool00000001oo`130036Ool5003oOol=Ool0
01Eoo`8000Qoo`8001Uoo`8000Eoo`<000]oo`03001oogoo0=ioo`@001moodL00;Eoo`D00?moo`eo
o`005Goo0P0027oo0P006Goo2@0037oo00<007ooOol0gWoo1000<Woo@P00Ygoo1000ogoo3Woo000E
Ool20008Ool2000IOol200000goo00000003000=Ool00`00Oomoo`3NOol40012Oole002TOol4003o
Ool>Ool001Ioo`8000Ioo`8001Yoo`8001=oo`03001oogoo0=eoo`D005=oobD00:=oo`@00?moo`io
o`005Woo0P001Woo0P006Woo0P004goo00<007ooOol0gGoo1@00I7oo5@00XWoo1000ogoo3Woo000G
Ool20004Ool2000KOol2000COol00`00Oomoo`3MOol4001cOol7002QOol5003oOol>Ool001Moo`P0
01]oo`X000]oo`03001oogoo0=eoo`@007Ioo`D00:1oo`D00?moo`ioo`006Goo10007Goo2P002goo
00<007ooOol0gGoo1000MWoo1@00X7oo1000ogoo3goo001?Ool00`00Oomoo`3LOol5001gOol4002P
Ool4003oOol?Ool004moo`03001oogoo0=aoo`D007Moo`D009moo`@00?moo`moo`00Cgoo00<007oo
Ool0g7oo1000N7oo1@00Wgoo1000ogoo3goo001?Ool00`00Oomoo`3KOol5001iOol4002OOol4003o
Ool?Ool004moo`03001oogoo0=]oo`D007Uoo`@009moo`@00?moo`moo`00Cgoo00<007ooOol0fgoo
1000NWoo1@00WWoo1000ogoo3goo001?Ool3003KOol4001jOol5002MOol5003oOol?Ool004moo`03
001oogoo0=]oo`@007]oo`@009eoo`D00?moo`moo`00Cgoo00<007ooOol0fgoo1000Ngoo1000WGoo
1000ogoo47oo001?Ool00`00Oomoo`3KOol4001kOol4002MOol4003oOol@Ool004moo`03001oogoo
0=Yoo`D007]oo`@009eoo`@00?mooa1oo`00Cgoo00<007ooOol0fWoo1000O7oo1@00W7oo1000ogoo
47oo001?Ool00`00Oomoo`3JOol4001lOol5002LOol4003oOol@Ool004moo`03001oogoo0=Yoo`@0
07eoo`@009aoo`@00?mooa1oo`00Cgoo00<007ooOol0fWoo1000OGoo1000W7oo1000ogoo47oo001?
Ool00`00Oomoo`3JOol4001mOol4002KOol5003oOol@Ool004moo`03001oogoo0=Yoo`@007eoo`@0
09]oo`D00?mooa1oo`00Cgoo00<007ooOol0fWoo1000OGoo1000Vgoo1000ogoo4Goo001?Ool00`00
Oomoo`3JOol4001mOol4002KOol4003oOolAOol004moo`03001oogoo0=Uoo`D007eoo`D009Yoo`@0
0?mooa5oo`00Cgoo00<007ooOol0fGoo1000OWoo1@00VWoo1000ogoo4Goo001?Ool00`00Oomoo`3I
Ool4001oOol4002JOol4003oOolAOol004moo`<00=Uoo`@007moo`@009Uoo`D00?mooa5oo`00Cgoo
00<007ooOol0fGoo1000Ogoo1000VGoo1000ogoo4Woo001?Ool00`00Oomoo`3IOol4001oOol4002I
Ool4003oOolBOol004moo`03001oogoo0=Uoo`@007moo`@009Uoo`@00?mooa9oo`00Cgoo00<007oo
Ool0f7oo1@00Ogoo1000VGoo1000ogoo4Woo001?Ool00`00Oomoo`3HOol5001oOol5002GOol5003o
OolBOol004moo`03001oogoo0=Qoo`@0081oo`D009Moo`@00?mooa=oo`00Cgoo00<007ooOol0f7oo
1000PGoo1000Ugoo1000ogoo4goo001?Ool00`00Oomoo`3HOol40021Ool4002GOol4003oOolCOol0
04moo`03001oogoo0=Moo`D0085oo`@009Moo`@00?mooa=oo`00Cgoo00<007ooOol0egoo1@00PGoo
1000UWoo1@00ogoo4goo001?Ool00`00Oomoo`3GOol40022Ool4002FOol5003oOolCOol004moo`03
001oogoo0=Moo`@0089oo`@009Ioo`@00?mooaAoo`00Cgoo00<007ooOol0egoo1000PWoo1000UWoo
1000ogoo57oo001?Ool00`00Oomoo`3FOol50022Ool5002EOol4003oOolDOol004moo`03001oogoo
0=Ioo`D0089oo`D009Eoo`@00?mooaAoo`00Cgoo00<007ooOol0eWoo1000Q7oo1000UGoo1000ogoo
57oo001?Ool3003FOol40024Ool4002EOol4003oOolDOol004moo`03001oogoo0=Ioo`@008Aoo`@0
09Eoo`@00?mooaAoo`00Cgoo00<007ooOol0eWoo1000Q7oo1000UGoo1000ogoo57oo001?Ool00`00
Oomoo`18Ool:000;Ool4000>Ool4000>Ool4000>Ool4000SOol<000;Ool90009Ool4000>Ool4000>
Ool4000WOol5000>Ool4000>Ool40003Ool40007Ool4000>Ool4000YOol7000:Ool4000>Ool4000>
Ool4000>Ool40004Ool4000NOol6000>Ool4000>Ool4000>Ool4000>Ool4002WOol004moo`03001o
ogoo04Qoo`X000Uoo`P000Yoo`P000Yoo`P000Yoo`P0025oo``000Uoo`/000Moo`P000Yoo`P000Yo
o`P002=oo`T000Yoo`P000Yoo`P00003Ool0000000<000Aoo`P000Yoo`P002Moo`L000Qoo`P000Yo
o`P000Yoo`P000Yoo`P0009oo`@001aoo`X000Yoo`P000Yoo`P000Yoo`P000Yoo`P00:Eoo`00Cgoo
00<007ooOol0C7oo0P003Goo0P0017oo0P002Woo0P0017oo0P002Woo0P0017oo0P002Woo0P0017oo
0P008Woo0`001Woo0P002Goo0P0017oo100027oo0P0017oo0P002Woo0P0017oo0P002Woo0P0017oo
0P008Woo100017oo0`002Goo0P0017oo0P002Woo0P0017oo0P0000=oo`0000000`0017oo0P0017oo
0P002Woo0P0017oo0P00:Woo0P002Woo0P0017oo0P002Woo0P0017oo0P002Woo0P0017oo0P002Woo
0P0017oo0P0000=oo`0000000`0077oo0`001Goo0`002Goo0P0017oo0P002Woo0P0017oo0P002Woo
0P0017oo0P002Woo0P0017oo0P00YGoo001?Ool00`00Oomoo`1<Ool2000<Ool20006Ool20008Ool2
0006Ool20008Ool20006Ool20008Ool20006Ool2000ROol3000?Ool20005Ool40007Ool20006Ool2
0008Ool20006Ool20008Ool20006Ool2000QOol20007Ool30007Ool20006Ool20008Ool20006Ool2
00000goo000000020003Ool20006Ool20008Ool20006Ool2000YOol20009Ool20006Ool20008Ool2
0006Ool20008Ool20006Ool20008Ool20006Ool7000UOol20008Ool20006Ool20008Ool20006Ool2
0008Ool20006Ool20008Ool20006Ool2002TOol004moo`03001oogoo04aoo`8000aoo`8000Ioo`80
00Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8002=oo`<000ioo`8000Eoo`@000Moo`80
00Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8002]oo`8000Moo`8000Ioo`8000Qoo`8000Ioo`80
0003Ool00000008000=oo`8000Ioo`8000Qoo`8000Ioo`8002Uoo`8000Uoo`8000Ioo`8000Qoo`80
00Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`H002Moo`8000Moo`8000Ioo`8000Qoo`8000Ioo`80
00Qoo`8000Ioo`8000Qoo`8000Ioo`800:Aoo`00Cgoo00<007ooOol0C7oo0P002goo0P0027oo0P00
1Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P008goo0`0037oo0P001Woo10001Woo0P00
27oo0P001Woo0P0027oo0P001Woo0P0027oo0P00:Woo0P001Woo0P0027oo0P001Woo0P0027oo1P00
0Woo0P0027oo0P001Woo0P0027oo0P0087oo30001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P00
27oo0P001Woo0P0027oo1@009goo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P00
1Woo0P0027oo0P00Xgoo001?Ool00`00Oomoo`1<Ool2000;Ool20008Ool20006Ool20008Ool20006
Ool20008Ool20006Ool20008Ool2000TOol3000;Ool20006Ool40006Ool20008Ool20006Ool20008
Ool20006Ool20008Ool2000ZOol20006Ool20008Ool20006Ool20008Ool60002Ool20008Ool20006
Ool20008Ool2000POol<0006Ool20008Ool20006Ool20008Ool20006Ool20008Ool20006Ool20008
Ool5000WOol20006Ool20008Ool20006Ool20008Ool20006Ool20008Ool20006Ool20008Ool2002S
Ool004moo`03001oogoo04aoo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Io
o`8000Qoo`8002Eoo`<000Yoo`8000Ioo`@000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qo
o`8002Uoo`<000Ioo`8000Qoo`8000Ioo`8000Qoo`H0009oo`8000Qoo`8000Ioo`8000Qoo`80021o
o`8000Ioo`800003Ool007oo00Eoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`80
00Qoo`D002Moo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`80
0:=oo`00Cgoo00<007ooOol0C7oo0P002goo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P00
1Woo0P0027oo0P009Woo0`002Goo0P001Woo10001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P00
27oo0P00:7oo0`001goo0P0027oo0P001Woo0P0027oo1`0000=oo`00000027oo0P001Woo0P0027oo
0P008Goo0P001Goo0P0027oo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo
1@009goo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P00Xgoo
001?Ool00`00Oomoo`1<Ool2000;Ool20008Ool20006Ool20008Ool20006Ool20008Ool20006Ool2
0008Ool2000WOol30008Ool20006Ool40006Ool20008Ool20006Ool20008Ool20006Ool20008Ool2
000UOol50008Ool20008Ool20006Ool20008Ool700000goo00000008Ool20006Ool20008Ool2000Q
Ool30004Ool20008Ool20008Ool20006Ool20008Ool20006Ool20008Ool20006Ool20008Ool5000V
Ool20007Ool20008Ool20006Ool20008Ool20006Ool20008Ool20006Ool20008Ool2002SOol004mo
o`03001oogoo04aoo`8000]oo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qo
o`8002Qoo`8000Qoo`8000Ioo`@000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8002Eo
o`@000Uoo`8000Qoo`8000Ioo`8000Qoo`800003Ool0000000800003Ool0000000Qoo`8000Ioo`80
00Qoo`80029oo`8000Aoo`8000Qoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`80
00Qoo`D001ioo`8000Eoo`<000Moo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`80
00Qoo`800:=oo`00Cgoo00<007ooOol0C7oo0P002goo0P0027oo0P001Woo0P0027oo0P001Woo0P00
27oo0P001Woo0P0027oo0P00:Goo0P001goo0P001Woo10001Woo0P0027oo0P001Woo0P0027oo0P00
1Woo0P0027oo0P00:7oo0P0027oo0P0027oo0P001Woo0P0027oo0P0000=oo`0000000P0000=oo`00
000027oo0P001Woo0P0027oo0P008goo0P000goo0P0027oo0P0027oo0P001Woo0P0027oo0P001Woo
0P0027oo0P001Woo0P0027oo1@007Woo2@0027oo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo
0P001Woo0P0027oo0P00Xgoo001?Ool00`00Oomoo`1<Ool2000;Ool20008Ool20006Ool20008Ool2
0006Ool20008Ool20006Ool20008Ool2000YOol20007Ool20006Ool40006Ool20008Ool20006Ool2
0008Ool20006Ool20008Ool2000YOol20007Ool20008Ool20006Ool20008Ool200000goo00000002
00000goo00000008Ool20006Ool20008Ool2000SOol30002Ool20008Ool20008Ool20006Ool20008
Ool20006Ool20008Ool20006Ool20008Ool5000NOol200000goo000000030009Ool20008Ool20006
Ool20008Ool20006Ool20008Ool20006Ool20008Ool2002SOol004moo`<004aoo`8000aoo`8000Io
o`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`80025oo`8000Moo`8000Qoo`8000Ao
o`D000Moo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8002Yoo`8000Qoo`8000Ioo`8000Qo
o`8000Ioo`80009oo`@0009oo`8000Ioo`8000Qoo`8000Ioo`8002Eoo`80009oo`8000Uoo`8000Io
o`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`H001ioo`80011oo`8000Ioo`8000Qo
o`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`800:Aoo`00Cgoo00<007ooOol0C7oo0P0037oo
0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P008Goo0`001Woo0P0027oo
0P0017oo1@001goo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P008Woo0P001Woo0P0027oo
0P001Woo0P0027oo0P001Woo0P000Woo1@0000=oo`0000001Woo0P0027oo0P001Woo0P009Woo0P00
00=oo`0000002Goo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo1P007Woo
0P0047oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P00Y7oo001?Ool0
0`00Oomoo`18Ool300000goo0000000=Ool20004Ool2000:Ool20004Ool2000:Ool20004Ool2000:
Ool20004Ool2000ROol40004Ool2000:Ool20003Ool40009Ool20004Ool2000:Ool20004Ool2000:
Ool20004Ool2000SOol30004Ool30009Ool20004Ool2000:Ool20004Ool20003Ool50002Ool20004
Ool2000:Ool20004Ool2000XOol4000:Ool20004Ool2000:Ool20004Ool2000:Ool20004Ool2000:
Ool20004Ool200000goo00000002000NOol2000AOol20004Ool2000:Ool20004Ool2000:Ool20004
Ool2000:Ool20004Ool2001MOol50007Ool9000NOol5000@Ool004moo`03001oogoo04Qoo`H000eo
o`P000Yoo`P000Yoo`P000Yoo`P002=oo`P000]oo`T000Uoo`P000Yoo`P000Yoo`P002Aoo`P000Yo
o`P000Yoo`P000Aoo`@0009oo`P000Yoo`P002Qoo`@000Yoo`P000Yoo`P000Yoo`P000Yoo`P00003
Ool00000008001ioo`X000Uoo`P000Yoo`P000Yoo`P000Yoo`P005eoo`D000Moo`T001ioo`D0011o
o`00Cgoo00<007ooOol0Bgoo0`003goo10003Woo10003Woo10003Woo10009goo1@003Woo1`002goo
10003Woo10003Woo10009goo1@003Woo10003Woo10001Woo100017oo10003Woo1000:goo0`0037oo
10003Woo10003Woo10003Woo10000goo10007Woo2P002goo10003Woo10003Woo10003Woo1000Ggoo
0P0037oo0P009Woo0P0047oo001?Ool00`00Oomoo`3DOol40029Ool4002AOol4003<Ool2000<Ool2
000VOol2000@Ool004moo`03001oogoo0=Aoo`@008Uoo`@0095oo`@00<aoo`8000aoo`8002Ioo`80
011oo`00Cgoo00<007ooOol0e7oo1000RGoo1@00T7oo1000c7oo0P0037oo0P009Woo0P0047oo001?
Ool00`00Oomoo`3DOol40029Ool5002?Ool5001aOol60007Ool>0002Ool60002Ool40002Ool40005
Ool8000OOol2000<Ool20002Ool60007Ool200000goo00000005000=Ool2000@Ool004moo`03001o
ogoo0=Aoo`@008Yoo`@008moo`D0071oo`T000Eoo`h0009oo`H0009oo`@0009oo`@000Aoo`/001eo
o`8000aoo`800003Ool0000000L000Eoo``000]oo`80011oo`00Cgoo00<007ooOol0e7oo1000RWoo
1000Sgoo1000L7oo0`0017oo10002Woo0P002Woo0P0017oo0P0017oo0P001Goo0P001goo100077oo
0P0037oo1@0017oo100017oo10001Woo0`002Woo0P0047oo001?Ool00`00Oomoo`3DOol4002:Ool4
002?Ool4001`Ool20007Ool2000:Ool2000:Ool20004Ool20004Ool20004Ool2000XOol2000<Ool3
0008Ool20004Ool20009Ool2000:Ool2000@Ool004moo`03001oogoo0=Aoo`@008Yoo`@008moo`@0
071oo`8001=oo`8000Yoo`8000Aoo`8000Aoo`8000=oo`8002Uoo`8000aoo`<000Qoo`<000=oo`80
00Uoo`8000Yoo`80011oo`00Cgoo00<007ooOol0e7oo1000RWoo1000Sgoo1000L7oo0P004goo0P00
2Woo0P0017oo0P0017oo0P000goo0P00:Goo0P0037oo0P002Woo0P003Goo0`002Woo0P0047oo001?
Ool00`00Oomoo`3DOol4002:Ool5002>Ool4001`Ool2000COol2000:Ool20004Ool20004Ool20003
Ool?000LOol2000<Ool2000:Ool20006Ool9000;Ool2000@Ool004ioodL0095oo`@008Yoo`D008io
o`@0071oo`8001=oo`8000Yoo`8000Aoo`8000Aoo`8000=oo`l001aoo`8000aoo`8000Yoo`8000Ao
o`X000aoo`80011oo`00@Gooo`00o`00H`006Goo0P004goo0P002Woo0P0017oo0P0017oo0P000goo
0P002goo0P0077oo0P0037oo0P002Woo0P000goo10004goo0P0047oo001=Oom:000EOol00`00Oomo
o`0DOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomo
o`03Ool4000=Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0DOol0
0`00Oomoo`0DOol00`00Oomoo`07Ool40009Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomo
o`0EOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0>Ool40002Ool00`00Oomoo`0DOol0
0`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0UOol2000COol2000:Ool20004Ool20004Ool2
0003Ool3000:Ool2000LOol2000<Ool30008Ool30003Ool20008Ool2000;Ool2000@Ool004ioodX0
01Aoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo
01Aoo`03001oogoo009oo`D000eoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo01Eoo`03
001oogoo01Aoo`03001oogoo01Aoo`03001oogoo00Moo`@000Uoo`03001oogoo01Aoo`03001oogoo
01Aoo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo00ioo`@0009oo`03
001oogoo01Aoo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo02Eoo`8001=oo`8000Yoo`80
00Aoo`8000Aoo`8000Aoo`8000Uoo`8001eoo`8000aoo`<000Qoo`8000Aoo`8000Moo`<000]oo`80
011oo`00Cgoo00<007ooOol057oo00<007ooOol057oo00<007ooOol04goo1@0057oo00<007ooOol0
57oo00<007ooOol057oo00<007ooOol057oo00<007ooOol05Goo00<007ooOol057oo00<007ooOol0
0Woo10003Woo00<007ooOol057oo00<007ooOol057oo00<007ooOol05Goo00<007ooOol057oo00<0
07ooOol057oo00<007ooOol01goo10002Goo00<007ooOol057oo00<007ooOol057oo00<007ooOol0
5Goo00<007ooOol057oo00<007ooOol057oo00<007ooOol03Woo10000Woo00<007ooOol057oo00<0
07ooOol05Goo00<007ooOol057oo00<007ooOol08Goo3@0037oo0P002Woo0`000Woo10000Woo0`00
1Goo0`001Goo0`007Woo0P0037oo1@0017oo0`001Goo0`001Goo10002goo0P0047oo001?Ool00`00
Oomoo`12Ool4000[Ool00`00Oomoo`1OOol4000>Ool00`00Oomoo`1aOol00`00Oomoo`07Ool4001V
Ool00`00Oomoo`0UOol40018Ool00`00Oomoo`0QOol=0008Ool60008Ool?0007Ool9000OOol2000:
Ool400000goo000000060007Ool;000;Ool2000@Ool004moo`03001oogoo049oo`D008aoo`@008ao
o`@008ioo`@0071oo`8000moo`H000Qoo`@00003Ool000000080009oo`<000Yoo`H0021oo`8000Yo
o`@0009oo`H000Yoo`H00003Ool0000000]oo`80011oo`00Cgoo00<007ooOol0@Woo1@00S7oo1000
S7oo1000SWoo1000L7oo0P00Fgoo0P00=7oo0P0047oo001?Ool00`00Oomoo`13Ool4002<Ool4002<
Ool5002=Ool4001`Ool2001KOol2000dOol2000@Ool004moo`03001oogoo04=oo`@008aoo`@008ao
o`D008eoo`@0071oo`8005]oo`8003Aoo`80011oo`00Cgoo00<007ooOol0@goo1000S7oo1000SGoo
1000SGoo1000L7oo0P004Woo0`00AWoo1@00;Woo1@0047oo001?Ool00`00Oomoo`13Ool4002<Ool4
002=Ool4002=Ool40024Ool30016Ool5000^Ool5000@Ool004moo`03001oogoo04=oo`@008aoo`@0
08eoo`@008eoo`@008Aoo`<008ioo`00Cgoo00<007ooOol0@goo1@00Rgoo1000SGoo1000S7oo1@00
Q7oo0`00SWoo001?Ool00`00Oomoo`13Ool5002;Ool4002=Ool4002<Ool5003oOolFOol004moo`03
001oogoo04Aoo`@008]oo`@008eoo`@008aoo`@00?mooaMoo`00Cgoo00<007ooOol0A7oo1000Rgoo
1000SGoo1000S7oo1000ogoo5goo001?Ool00`00Oomoo`14Ool4002;Ool4002=Ool5002;Ool4003o
OolGOol004moo`<004Aoo`@008]oo`@008eoo`D008]oo`@00?mooaMoo`00Cgoo00<007ooOol0A7oo
1000Rgoo1000SWoo1000Rgoo1000ogoo5goo001?Ool00`00Oomoo`14Ool4002;Ool4002>Ool4002;
Ool4003oOolGOol004moo`03001oogoo04Aoo`@008Yoo`D008ioo`@008]oo`@00?mooaMoo`00Cgoo
00<007ooOol0A7oo1000RWoo1000Sgoo1000Rgoo1000ogoo5goo001?Ool00`00Oomoo`14Ool4002:
Ool4002?Ool4002;Ool4003oOolGOol004moo`03001oogoo04Aoo`@008Yoo`@008moo`@008]oo`@0
0?mooaMoo`00Cgoo00<007ooOol0A7oo1@00RGoo1000Sgoo1000Rgoo1000ogoo5goo001?Ool00`00
Oomoo`14Ool50029Ool4002?Ool4002;Ool4003oOolGOol004moo`03001oogoo04Eoo`@008Uoo`@0
08moo`@008]oo`@00?mooaMoo`00Cgoo00<007ooOol0AGoo1000RGoo1000Sgoo1000Rgoo1000ogoo
5goo001?Ool00`00Oomoo`15Ool40029Ool4002?Ool5002:Ool4003oOolGOol004moo`03001oogoo
04Eoo`@008Uoo`@008moo`D008Yoo`@00?mooaMoo`00Cgoo00<007ooOol0AGoo1000RGoo1000T7oo
1000RWoo1000ogoo5goo001?Ool00`00Oomoo`15Ool40029Ool4002@Ool4002:Ool4003oOolGOol0
04moo`03001oogoo04Eoo`@008Uoo`@0091oo`@008Uoo`D00?mooaMoo`00Cgoo0`00AGoo1000RGoo
1000T7oo1000RGoo1@00ogoo5goo001?Ool00`00Oomoo`15Ool40029Ool4002@Ool40029Ool4003o
OolHOol004moo`03001oogoo04Eoo`@008Uoo`@0091oo`@008Uoo`@00?mooaQoo`00Cgoo00<007oo
Ool0AGoo1000RGoo1000T7oo1000RGoo1000ogoo67oo001?Ool00`00Oomoo`15Ool40029Ool4002@
Ool40029Ool4003oOolHOol004moo`03001oogoo04Eoo`@008Qoo`D0091oo`@008Uoo`@00?mooaQo
o`00Cgoo00<007ooOol0AGoo1000R7oo1@00T7oo1000RGoo1000ogoo67oo001?Ool00`00Oomoo`15
Ool40028Ool4002AOol40029Ool4003oOolHOol004moo`03001oogoo04Eoo`@008Qoo`@0095oo`@0
08Uoo`@00?mooaQoo`00Cgoo00<007ooOol0AGoo1000R7oo1000TGoo1000RGoo1000ogoo67oo001?
Ool00`00Oomoo`15Ool50027Ool4002AOol40029Ool4003oOolHOol004moo`03001oogoo04Eoo`D0
08Moo`@0095oo`D008Qoo`@00?mooaQoo`00Cgoo00<007ooOol0AWoo1000Qgoo1000TGoo1@00R7oo
1000ogoo67oo001?Ool00`00Oomoo`16Ool40027Ool4002BOol40028Ool4003oOolHOol004moo`03
001oogoo04Ioo`@008Moo`@0099oo`@008Qoo`@00?mooaQoo`00Cgoo00<007ooOol0AWoo1000Qgoo
1000TWoo1000R7oo1000ogoo67oo001?Ool00`00Oomoo`16Ool40027Ool4002BOol40028Ool4003o
OolHOol004moo`<004Ioo`@008Moo`@0099oo`@008Qoo`@00?mooaQoo`00Cgoo00<007ooOol0AWoo
1000Qgoo1000TWoo1000R7oo1000ogoo67oo001?Ool00`00Oomoo`16Ool40027Ool4002BOol40028
Ool4003oOolHOol004moo`03001oogoo04Ioo`@008Moo`@0099oo`@008Qoo`@00?mooaQoo`00Cgoo
00<007ooOol0AWoo1000Qgoo1000TWoo1000R7oo1000ogoo67oo001?Ool00`00Oomoo`16Ool40027
Ool4002BOol40027Ool5003oOolHOol004moo`03001oogoo04Ioo`@008Moo`@0099oo`@008Moo`@0
0?mooaUoo`00Cgoo00<007ooOol0AWoo1000Qgoo1000TWoo1000Qgoo1000ogoo6Goo001?Ool00`00
Oomoo`16Ool40027Ool4002BOol40027Ool4003oOolIOol004moo`03001oogoo04Ioo`@008Ioo`D0
099oo`@008Moo`@00?mooaUoo`00Cgoo00<007ooOol0AWoo1000QWoo1@00TWoo1000Qgoo1000ogoo
6Goo001?Ool00`00Oomoo`16Ool40026Ool4002COol40027Ool4003oOolIOol004moo`03001oogoo
04Ioo`@008Ioo`@009=oo`@008Moo`@00?mooaUoo`00Cgoo00<007ooOol0AWoo1000QWoo1000Tgoo
1000Qgoo1000ogoo6Goo001?Ool00`00Oomoo`16Ool40026Ool4002COol40027Ool4003oOolIOol0
04moo`03001oogoo04Ioo`@008Ioo`@009=oo`@008Moo`@00?mooaUoo`00Cgoo0`00AWoo1000QWoo
1000Tgoo1@00QWoo1000ogoo6Goo001?Ool00`00Oomoo`16Ool50025Ool4002COol50026Ool4003o
OolIOol004moo`03001oogoo04Moo`@008Eoo`@009Aoo`@008Ioo`@00?mooaUoo`00Cgoo00<007oo
Ool0Agoo1000QGoo1000U7oo1000QWoo1000ogoo6Goo001?Ool00`00Oomoo`17Ool40025Ool4002D
Ool40026Ool4003oOolIOol004moo`03001oogoo04Moo`@008Eoo`@009Aoo`@008Ioo`@00?mooaUo
o`00Cgoo00<007ooOol0Agoo1000QGoo1000U7oo1000QWoo1000ogoo6Goo001?Ool00`00Oomoo`17
Ool40025Ool4002DOol40026Ool4003oOolIOol004moo`03001oogoo04Moo`@008Eoo`@009Aoo`@0
08Ioo`@00?mooaUoo`00Cgoo00<007ooOol0Agoo1000QGoo1000U7oo1000QWoo1000ogoo6Goo000I
Ool4000>Ool3000=Ool6000>Ool00`00Oomoo`17Ool40025Ool4002DOol40026Ool4003oOolIOol0
01Moo`P000]oo`D000Yoo`X000aoo`03001oogoo04Moo`@008Eoo`@009Aoo`@008Ioo`@00?mooaUo
o`005goo0P0017oo0P002goo1@002Woo0`001Goo0`002goo00<007ooOol0Agoo1000QGoo1000U7oo
1000QGoo1@00ogoo6Goo000FOol20006Ool2000:Ool5000COol2000;Ool00`00Oomoo`17Ool40025
Ool4002DOol40025Ool5003oOolIOol001Ioo`8000Ioo`8000]oo`<001Eoo`8000Yoo`03001oogoo
04Moo`@008Aoo`D009Aoo`@008Eoo`@00?mooaYoo`005Goo0P0027oo0P008Woo0P002Woo00<007oo
Ool0Agoo1000Q7oo1@00U7oo1000QGoo1000ogoo6Woo000EOol20008Ool2000ROol2000:Ool00`00
Oomoo`17Ool40024Ool4002EOol40025Ool4003oOolJOol001Eoo`8000Qoo`80029oo`8000Yoo`D0
04Eoo`@008Aoo`@009Eoo`@008Eoo`@00?mooaYoo`005Goo0P0027oo0P008Woo0P002Woo00<007oo
Ool0Agoo1000Q7oo1000UGoo1000QGoo1000ogoo6Woo000EOol20008Ool2000QOol2000;Ool00`00
Oomoo`17Ool40024Ool4002EOol40025Ool4003oOolJOol001Eoo`8000Qoo`8001Uoo`8000Eoo`<0
00]oo`03001oogoo04Moo`@008Aoo`@009Eoo`@008Eoo`@00?mooaYoo`005Goo0P0027oo0P006Goo
2@0037oo00<007ooOol0Agoo1000Q7oo1000UGoo1000QGoo1000ogoo6Woo000EOol20008Ool2000I
Ool200000goo00000003000=Ool00`00Oomoo`17Ool40024Ool4002EOol40025Ool4003oOolJOol0
01Ioo`8000Ioo`8001Yoo`8001=oo`03001oogoo04Moo`D008=oo`@009Eoo`@008Eoo`@00?mooaYo
o`005Woo0P001Woo0P006Woo0P004goo00<007ooOol0Agoo1@00Pgoo1000UGoo1000QGoo1000ogoo
6Woo000GOol20004Ool2000KOol2000COol00`00Oomoo`18Ool40023Ool4002EOol50024Ool4003o
OolJOol001Moo`P001]oo`X000]oo`03001oogoo04Qoo`@008=oo`@009Eoo`D008Aoo`@00?mooaYo
o`006Goo10007Goo2P002goo00<007ooOol0B7oo1000Pgoo1000UWoo1000Q7oo1000ogoo6Woo001?
Ool00`00Oomoo`18Ool40023Ool4002FOol40024Ool4003oOolJOol004moo`03001oogoo04Qoo`@0
08=oo`@009Ioo`@008Aoo`@00?mooaYoo`00Cgoo00<007ooOol0B7oo1000Pgoo1000UWoo1000Q7oo
1000ogoo6Woo001?Ool00`00Oomoo`18Ool40023Ool4002FOol40024Ool4003oOolJOol004moo`03
001oogoo04Qoo`@0089oo`D009Ioo`@008=oo`D00?mooaYoo`00Cgoo0`00B7oo1000PWoo1000Ugoo
1000Pgoo1@00ogoo6Woo001?Ool00`00Oomoo`18Ool40022Ool4002GOol40023Ool4003oOolKOol0
04moo`03001oogoo04Qoo`@0089oo`@009Moo`@008=oo`@00?mooa]oo`00Cgoo00<007ooOol0B7oo
1000PWoo1000Ugoo1000Pgoo1000ogoo6goo001?Ool00`00Oomoo`18Ool40022Ool4002GOol40023
Ool4003oOolKOol004moo`03001oogoo04Qoo`@0089oo`@009Moo`@008=oo`@00?mooa]oo`00Cgoo
00<007ooOol0B7oo1000PWoo1000Ugoo1000Pgoo1000ogoo6goo001?Ool00`00Oomoo`18Ool40022
Ool4002GOol40023Ool4003oOolKOol004moo`03001oogoo04Qoo`D0085oo`@009Moo`@008=oo`@0
0?mooa]oo`00Cgoo00<007ooOol0B7oo1@00PGoo1000Ugoo1000Pgoo1000ogoo6goo001?Ool00`00
Oomoo`19Ool40021Ool4002GOol40023Ool4003oOolKOol004moo`03001oogoo04Uoo`@0085oo`@0
09Moo`@008=oo`@00?mooa]oo`00Cgoo00<007ooOol0BGoo1000PGoo1000Ugoo1000Pgoo1000ogoo
6goo001?Ool00`00Oomoo`19Ool40021Ool4002GOol40023Ool4003oOolKOol004moo`03001oogoo
04Uoo`@0085oo`@009Moo`@008=oo`@00?mooa]oo`00Cgoo00<007ooOol0BGoo1000P7oo1@00Ugoo
1000Pgoo1000ogoo6goo001?Ool00`00Oomoo`19Ool40020Ool5002GOol50022Ool4003oOolKOol0
04moo`<004Uoo`@0081oo`@009Uoo`@0089oo`@00?mooa]oo`00Cgoo00<007ooOol0BGoo1000P7oo
1000VGoo1000PGoo1@00ogoo6goo001?Ool00`00Oomoo`19Ool40020Ool4002IOol40021Ool4003o
OolLOol004moo`03001oogoo04Uoo`@0081oo`@009Uoo`@0085oo`@00?mooaaoo`00Cgoo00<007oo
Ool0BGoo1000P7oo1000VGoo1000PGoo1000ogoo77oo001?Ool00`00Oomoo`19Ool40020Ool4002I
Ool40021Ool4003oOolLOol004moo`03001oogoo04Uoo`@0081oo`@009Uoo`@0085oo`@00?mooaao
o`00Cgoo00<007ooOol0BGoo1000P7oo1000VGoo1000PGoo1000ogoo77oo001?Ool00`00Oomoo`19
Ool5001oOol4002IOol40021Ool4003oOolLOol004moo`03001oogoo04Yoo`@007moo`@009Uoo`@0
085oo`@00?mooaaoo`00Cgoo00<007ooOol0BWoo1000Ogoo1000VGoo1000PGoo1000ogoo77oo001?
Ool00`00Oomoo`1:Ool4001oOol4002IOol40021Ool4003oOolLOol004moo`03001oogoo04Yoo`@0
07moo`@009Uoo`@0085oo`@00?mooaaoo`00Cgoo00<007ooOol0BWoo1000Ogoo1000VGoo1000PGoo
1000ogoo77oo001?Ool00`00Oomoo`1:Ool4001oOol4002IOol40021Ool4003oOolLOol004moo`03
001oogoo04Yoo`@007moo`@009Uoo`@0085oo`@00?mooaaoo`00Cgoo0`00BWoo1000Ogoo1000VGoo
1000PGoo1000ogoo77oo001?Ool00`00Oomoo`1:Ool4001oOol4002IOol40021Ool4003oOolLOol0
04moo`03001oogoo04Yoo`@007ioo`D009Uoo`D0081oo`@00?mooaaoo`00Cgoo00<007ooOol0BWoo
1000OWoo1@00VGoo1@00P7oo1000ogoo77oo001?Ool00`00Oomoo`1:Ool4001nOol4002KOol40020
Ool4003oOolLOol004moo`03001oogoo04Yoo`@007ioo`@009]oo`@0081oo`@00?mooaaoo`00Cgoo
00<007ooOol0BWoo1000OWoo1000Vgoo1000Ogoo1@00ogoo77oo001?Ool00`00Oomoo`1:Ool4001n
Ool4002KOol4001oOol5003oOolLOol004moo`03001oogoo04Yoo`@007ioo`@009]oo`@007moo`@0
0?mooaeoo`00Cgoo00<007ooOol0BWoo1000OWoo1000Vgoo1000Ogoo1000ogoo7Goo001?Ool00`00
Oomoo`1:Ool5001mOol4002KOol4001oOol4003oOolMOol004moo`03001oogoo04Yoo`D007eoo`@0
09]oo`@007moo`@00?mooaeoo`00Cgoo00<007ooOol0Bgoo1000OGoo1000Vgoo1000Ogoo1000ogoo
7Goo001?Ool00`00Oomoo`1;Ool4001mOol4002KOol4001oOol4003oOolMOol004moo`03001oogoo
04]oo`@007eoo`@009]oo`@007moo`@00?mooaeoo`00Cgoo00<007ooOol0Bgoo1000OGoo1000Vgoo
1000Ogoo1000ogoo7Goo001?Ool3001;Ool4001mOol4002KOol4001oOol4003oOolMOol004moo`03
001oogoo04]oo`@007eoo`@009]oo`@007moo`@00?mooaeoo`00Cgoo00<007ooOol0Bgoo1000OGoo
1000Vgoo1000Ogoo1000ogoo7Goo001?Ool00`00Oomoo`1;Ool4001mOol4002KOol4001oOol4003o
OolMOol004moo`03001oogoo04]oo`@007eoo`@009]oo`@007moo`@00?mooaeoo`00Cgoo00<007oo
Ool0Bgoo1000OGoo1000Vgoo1@00OWoo1000ogoo7Goo001?Ool00`00Oomoo`1;Ool4001mOol4002L
Ool4001nOol4003oOolMOol004moo`03001oogoo04]oo`@007eoo`@009aoo`@007ioo`@00?mooaeo
o`00Cgoo00<007ooOol0Bgoo1000OGoo1000W7oo1000OWoo1000ogoo7Goo001?Ool00`00Oomoo`1;
Ool4001lOol5002LOol4001nOol4003oOolMOol003Yoo`X000]oo`03001oogoo04]oo`@007aoo`D0
09aoo`@007ioo`@00?mooaeoo`00>Woo2P002goo00<007ooOol0Bgoo1000O7oo1000WGoo1000OWoo
1000ogoo7Goo000nOol2000?Ool00`00Oomoo`1;Ool4001lOol4002MOol4001nOol4003oOolMOol0
03ioo`8000moo`03001oogoo04]oo`@007aoo`@009eoo`@007ioo`@00?mooaeoo`00?Woo0P003goo
00<007ooOol0Bgoo1000O7oo1000WGoo1000OWoo1000ogoo7Goo000nOol2000?Ool00`00Oomoo`1;
Ool5001kOol4002MOol4001nOol4003oOolMOol003ioo`8000moo`03001oogoo04aoo`@007]oo`@0
09eoo`@007eoo`D00?mooaeoo`00?Woo0P003goo1@00BWoo1000Ngoo1000WGoo1000OGoo1@00ogoo
7Goo000nOol2000?Ool00`00Oomoo`1<Ool4001kOol4002MOol4001mOol4003oOolNOol003ioo`80
00moo`03001oogoo04aoo`@007]oo`@009eoo`@007eoo`@00?mooaioo`00?Woo0P003goo00<007oo
Ool0C7oo1000Ngoo1000WGoo1000OGoo1000ogoo7Woo000nOol2000?Ool00`00Oomoo`1<Ool4001k
Ool4002MOol4001mOol4003oOolNOol003ioo`8000moo`03001oogoo04aoo`@007]oo`@009eoo`@0
07eoo`@00?mooaioo`00?Woo0P003goo00<007ooOol0C7oo1000Ngoo1000WGoo1000OGoo1000ogoo
7Woo000nOol2000?Ool00`00Oomoo`1<Ool4001kOol4002MOol4001mOol4003oOolNOol003Yoo`<0
0003Ool0000000moo`03001oogoo04aoo`@007]oo`@009eoo`@007eoo`@00?mooaioo`00>Woo1P00
3goo00<007ooOol0C7oo1000Ngoo1000WGoo1@00O7oo1000ogoo7Woo000mOol3000?Ool00`00Oomo
o`1<Ool4001kOol4002MOol5001lOol4003oOolNOol004moo`03001oogoo04aoo`@007]oo`@009io
o`@007aoo`@00?mooaioo`00Cgoo00<007ooOol0C7oo1000Ngoo1000WWoo1000O7oo1000ogoo7Woo
001?Ool00`00Oomoo`1<Ool4001kOol4002NOol4001lOol4003oOolNOol004moo`03001oogoo04ao
o`@007Yoo`D009ioo`@007aoo`@00?mooaioo`00Cgoo00<007ooOol0C7oo1000NWoo1@00WWoo1000
O7oo1000ogoo7Woo001?Ool3001<Ool5001iOol4002OOol4001lOol4003oOolNOol004moo`03001o
ogoo04aoo`D007Uoo`@009moo`@007aoo`@00?mooaioo`00Cgoo00<007ooOol0CGoo1000NGoo1000
Wgoo1000O7oo1000ogoo7Woo001?Ool00`00Oomoo`1=Ool4001iOol4002OOol4001lOol4003oOolN
Ool004moo`03001oogoo04eoo`@007Uoo`@009moo`@007aoo`@00?mooaioo`00Cgoo00<007ooOol0
CGoo1000NGoo1000Wgoo1000O7oo1000ogoo7Woo001?Ool00`00Oomoo`1=Ool4001iOol4002OOol4
001lOol4003oOolNOol004moo`03001oogoo04eoo`@007Uoo`@009moo`@007aoo`@00?mooaioo`00
Cgoo00<007ooOol0CGoo1000NGoo1000Wgoo1000O7oo1000ogoo7Woo001?Ool00`00Oomoo`1=Ool4
001iOol4002OOol4001kOol5003oOolNOol004moo`03001oogoo04eoo`@007Uoo`@009moo`@007]o
o`D00?mooaioo`00Cgoo00<007ooOol0CGoo1000NGoo1000Wgoo1000Ngoo1000ogoo7goo001?Ool0
0`00Oomoo`1=Ool4001iOol4002OOol4001kOol4003oOolOOol004moo`03001oogoo04eoo`@007Uo
o`@009moo`@007]oo`@00?mooamoo`00Cgoo00<007ooOol0CGoo1000NGoo1000Wgoo1000Ngoo1000
ogoo7goo001?Ool00`00Oomoo`1=Ool4001iOol4002OOol4001kOol4003oOolOOol004moo`03001o
ogoo04eoo`D007Moo`D009moo`D007Yoo`@00?mooamoo`00Cgoo0`00CGoo1@00Mgoo1000X7oo1@00
NWoo1000ogoo7goo001?Ool00`00Oomoo`1>Ool4001gOol4002QOol4001jOol4003oOolOOol004mo
o`03001oogoo04ioo`@007Moo`@00:5oo`@007Yoo`@00?mooamoo`00Cgoo00<007ooOol0CWoo1000
Mgoo1000XGoo1000NWoo1000ogoo7goo001?Ool00`00Oomoo`1>Ool4001gOol4002QOol4001jOol4
003oOolOOol004moo`03001oogoo04ioo`@007Moo`@00:5oo`@007Yoo`@00?mooamoo`00Cgoo00<0
07ooOol0CWoo1000Mgoo1000XGoo1000NWoo1000ogoo7goo001?Ool00`00Oomoo`1>Ool4001gOol4
002QOol4001jOol4003oOolOOol004moo`03001oogoo04ioo`@007Moo`@00:5oo`@007Yoo`@00?mo
oamoo`00Cgoo00<007ooOol0CWoo1000MWoo1@00XGoo1000NWoo1000ogoo7goo001?Ool00`00Oomo
o`1>Ool4001fOol5002QOol4001jOol4003oOolOOol004moo`03001oogoo04ioo`@007Ioo`@00:9o
o`@007Yoo`@00?mooamoo`00Cgoo00<007ooOol0CWoo1000MWoo1000XWoo1000NWoo1000ogoo7goo
001?Ool00`00Oomoo`1>Ool5001eOol4002ROol4001iOol5003oOolOOol004moo`03001oogoo04io
o`D007Aoo`D00:9oo`@007Uoo`D00?mooamoo`00Cgoo00<007ooOol0Cgoo1000M7oo1@00XWoo1000
NGoo1000ogoo87oo001?Ool3001?Ool4001cOol5002SOol4001iOol4003oOolPOol004moo`03001o
ogoo04moo`@005mooaT00:=oo`@007Uoo`@00?moob1oo`00Cgoo00<007ooOol0Cgoo100000Aoo`00
000003ioocH00:=oo`@007Uoo`@00?moob1oo`00Cgoo00<007ooOol0Cgoo30007WooD@00Y7oo1@00
N7oo1000ogoo87oo001?Ool00`00Oomoo`1?Oomi002WOol4001hOol4003oOolPOol004moo`03001o
ogoo04moofD00;]oo`@007Qoo`@00?moob1oo`00Cgoo00<007ooOol0CgooB000f7oo1000N7oo1000
ogoo87oo001?Ool00`00Oomoo`1?Ool/003dOol4001hOol4003oOolPOol004moo`03001oogoo04mo
oaP00?moo`Uoo`@007Qoo`@00?moob1oo`00Cgoo00<007ooOol0Cgoo3P00ogoo4goo1000N7oo1000
ogoo87oo001?Ool00`00Oomoo`1?Ool700000goo0000003oOolGOol4001hOol4003oOolPOol004mo
o`03001oogoo051oo`D00?mooa]oo`@007Qoo`@00?moob1oo`00Cgoo00<007ooOol0D7oo1@00ogoo
6goo1000Mgoo1@00ogoo87oo001?Ool00`00Oomoo`1@Ool5003oOolKOol4001gOol4003oOolQOol0
04moo`03001oogoo055oo`<00?mooaaoo`@007Moo`@00?moob5oo`00Cgoo00<007ooOol0ogooL7oo
1000Mgoo1000ogoo8Goo001?Ool00`00Oomoo`3oOom`Ool4001gOol4003oOolQOol004moo`<00?mo
og1oo`@007Moo`@00?moob5oo`00Cgoo00<007ooOol0ogooL7oo1@00MWoo1000ogoo8Goo001?Ool0
0`00Oomoo`3oOom`Ool5001fOol4003oOolQOol004moo`03001oogoo0?moog5oo`@007Eoo`D00?mo
ob5oo`00Cgoo00<007ooOol0ogooLGoo1000MGoo1@00ogoo8Goo001?Ool00`00Oomoo`3oOomaOol4
001eOol4003oOolROol004moo`03001oogoo0?moog5oo`@007Eoo`@00?moob9oo`00Cgoo00<007oo
Ool0ogooLGoo1000M7oo1@00ogoo8Woo001?Ool00`00Oomoo`3oOomaOol4001dOol5003oOolROol0
01Ioo`X000]oo`<000eoo`H000ioo`03001oogoo0?moog5oo`@007Aoo`@00?moob=oo`005Woo2P00
2Woo1@002Woo2P0037oo00<007ooOol0ogooLGoo1000Lgoo1@00ogoo8goo000JOol2000>Ool5000:
Ool30005Ool3000;Ool00`00Oomoo`3oOomaOol4001^Ool:003oOolSOol001Yoo`8000ioo`D001=o
o`8000]oo`03001oogoo0?moog5oo`@0065ooaH00?moobAoo`006Woo0P003goo0`005Goo0P002Woo
00<007ooOol0ogooLGoo1000Dgoo8`00ogoo9Goo000JOol2000WOol2000:Ool00`00Oomoo`3oOoma
Ool40015Ool`003oOolVOol001Yoo`8002Moo`8000Yoo`03001oogoo0?moog5oo`@003QoocP00?mo
ob]oo`006Woo0P009goo0P002Woo1@00ogooKgoo1@0000Aoo`00000002IoocP00?moocQoo`006Woo
0P009goo0P002Woo00<007ooOol0ogooLWoo2@005goo>000ogooAWoo000JOol2000VOol2000;Ool0
0`00Oomoo`3oOombOol<000017oo000000000goo=`00ogooE7oo000JOol2000NOol20005Ool3000;
Ool00`00Oomoo`3oOombOolm003oOomQOol001Yoo`8001ioo`T000aoo`03001oogoo0?moog9ooc00
0?moofioo`006Woo0P007Woo0P0000=oo`0000000`003Goo00<007ooOol0ogooLWoo8P00ogooO7oo
000JOol2000NOol2000COol00`00Oomoo`3oOombOolH003oOon6Ool001Yoo`8001ioo`8001=oo`03
001oogoo0?moog9oo`h00?mooi1oo`005Woo0`0000=oo`0000007Woo0P004goo00<007ooOol0ogoo
LWoo2`00ogooTgoo000FOol6000NOol:000;Ool00`00Oomoo`3oOombOol6000017oo00000000ogoo
U7oo000IOol3000NOol:000;Ool00`00Oomoo`3oOombOol6003oOonHOol004moo`03001oogoo0?mo
og9oo`H00?mooiQoo`00Cgoo00<007ooOol0ogooLgoo1@00ogooV7oo001?Ool00`00Oomoo`3oOomc
Ool5003oOonHOol004moo`03001oogoo0?moogAoo`<00?mooiUoo`00Cgoo00<007ooOol0ogooogoo
ogoo4Goo001?Ool3003oOoooOoooOolAOol004moo`03001oogoo0?mooomooomooa5oo`00Cgoo00<0
07ooOol0ogooogooogoo4Goo001?Ool00`00Oomoo`3oOoooOoooOolAOol004moo`03001oogoo0?mo
oomooomooa5oo`00Cgoo00<007ooOol0ogooogooogoo4Goo001?Ool00`00Oomoo`3oOoooOoooOolA
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol0055oo`T00?mooomooomoo`Uoo`00DGoo2@00ogooogooogoo2Goo001COol2
003oOoooOoooOol>Ool005=oo`800?mooomooomoo`ioo`00Dgoo0P00ogooogooogoo3Woo001COol2
003oOoooOoooOol>Ool002]oo`L000Aoo`d0009oo`@0009oo`@000Aoo`80009oo`H000Moo`d00?mo
oomooo5oo`00:goo1`0017oo3@000Woo10000Woo100017oo0P0000=oo`0000001`001Goo3@00ogoo
ogoolGoo000]Ool2000:Ool20004Ool20004Ool20004Ool20006Ool50004Ool40009Ool2003oOooo
OoogOol002eoo`8000Yoo`8000Aoo`8000Aoo`8000Aoo`8000Ioo`<000Qoo`8000Uoo`800?mooomo
ooMoo`00;Woo0P0027oo0P001Goo0P0017oo0P0017oo0P001Woo0`0027oo0`0027oo0P00ogooogoo
mgoo000^Ool20008Ool20005Ool20004Ool20004Ool20006Ool2000:Ool20008Ool2003oOoooOoog
Ool002ioo``000Eoo`8000Aoo`8000Aoo`8000Ioo`8000Yoo`8000Qoo`800?mooomoooMoo`00;goo
2P001Woo0P0017oo0P0017oo0P001Woo0P002Woo0P0027oo0P00ogooogoomgoo000_Ool20006Ool2
0006Ool20004Ool20004Ool20006Ool2000:Ool20008Ool2003oOoooOoogOol0031oo`8000Aoo`80
00Moo`8000Aoo`8000Aoo`8000Ioo`<000Qoo`<000Qoo`800?mooomoooMoo`00<7oo0P0017oo0P00
1goo0P0017oo0P0017oo0P001Woo0`0027oo0P002Goo0P00ogooogoomgoo000`Ool20003Ool30007
Ool30002Ool40002Ool30006Ool50004Ool3000:Ool2003oOoooOoogOol0035oo`80009oo`8000Io
o`l000Eoo`@00003Ool0000000H000]oo`800?mooomoooMoo`00<Goo0P000Woo0P001Woo100000=o
o`0000000P000Woo0`001Woo10000Woo1P0037oo0P00ogooogoomgoo000aOol5000cOol2003oOooo
OoogOol002ioo`P003=oo`800?mooomoooMoo`00;Woo1`00=7oo0P00ogooogoomgoo001TOol7003o
OoooOoogOol006Aoo`L00?mooomoooMoo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomo
oomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogoo
Hgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol0
0?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogoo
ogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOooo
OomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=o
o`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003o
OoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomo
oomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogoo
Hgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol0
0?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogoo
ogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOooo
OomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=o
o`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003o
OoooOoooOomSOol00?mooomooomoof=oo`00\
\>"], "Graphics",
  CellLabel->"From In[46]:=",
  Evaluatable->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[46]="]
}, Open  ]],

Cell["\<\
Below is shown the corresponding crosstalk on  lines 3 and 4, \
sampled at the right end of the pigtail, as it would appear on a scope:\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[uout1, PlotRange \[Rule] All, 
      AxesLabel -> {"\<time [ps]\>", "\<Crosstalk\>"}]\)], "Input",
  CellLabel->"In[47]:="],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P00025A000`40O003h00OogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00ogooogooogooHgoo001QOol00`00Oomoo`3oOoooOoonOol0065oo`03001oogoo0?mooomo
ooioo`00HGoo00<007ooOol0ogooogoooWoo001QOol00`00Oomoo`3oOoooOoonOol0065oo`03001o
ogoo0?mooomoooioo`00HGoo00<007ooOol0ogooogoooWoo001QOol00`00Oomoo`3oOoooOoonOol0
065oo`03001oogoo0?mooomoooioo`00HGoo00<007ooOol0ogoohGoo0P00ogoo6goo001QOol00`00
Oomoo`3oOooPOol4003oOolJOol0065oo`03001oogoo0?moommoo`D00?mooaYoo`00HGoo00<007oo
Ool0ogooggoo1@00ogoo6Woo000IOol4000>Ool3000?Ool4000?Ool7000:Ool00`00Oomoo`3oOooO
Ool5003oOolJOol001Moo`P000]oo`D000aoo`P000eoo`L000Yoo`03001oogoo0?moommoo`D00?mo
oaYoo`005goo0P0017oo0P002goo1@0037oo0P0017oo0P0047oo0P0037oo00<007ooOol0ogooggoo
1@00ogoo6Woo000FOol20006Ool2000:Ool5000;Ool20006Ool2000?Ool2000<Ool00`00Oomoo`3o
OooOOol5003oOolJOol001Ioo`8000Ioo`8000]oo`<000aoo`8000Ioo`8000moo`8000aoo`03001o
ogoo0?moommoo`D00?mooaYoo`000Woo3@001Woo0P0027oo0P0067oo0P0027oo0P001Woo30002Woo
00<007ooOol0ogooggoo1@00ogoo6Woo0002Ool=0006Ool20008Ool2000HOol20008Ool20006Ool<
000:Ool00`00Oomoo`3oOooOOol5003oOolJOol0009oo`d000Ioo`8000Qoo`8001Qoo`8000Qoo`80
00Ioo`8000Ioo`800003Ool007oo00Uoo`D00<Aoo`<00?mooaIoo`D00?mooaYoo`005Goo0P0027oo
0P0067oo0P0027oo0P001goo0P001Goo0P0037oo00<007ooOol0aGoo1@00ogoo5Goo1P00ogoo6Goo
000EOol20008Ool2000HOol20008Ool20007Ool30004Ool2000<Ool00`00Oomoo`35Ool5003oOolE
Ool6003oOolIOol001Eoo`8000Qoo`8001Qoo`8000Qoo`8000Qoo`8000Aoo`8000aoo`03001oogoo
0<Eoo`D00?mooaEoo`H00?mooaUoo`005Goo0P0027oo0P0067oo0P0027oo0P002Goo0P000goo0P00
37oo00<007ooOol0aGoo1@00ogoo5Goo1P00ogoo6Goo000EOol20008Ool2000HOol20008Ool20009
Ool30002Ool2000<Ool00`00Oomoo`35Ool5003oOolEOol6003oOolIOol001Ioo`8000Ioo`8001Yo
o`8000Ioo`8000]oo`80009oo`8000aoo`03001oogoo0<Eoo`D00?mooaEoo`H00?mooaUoo`005Woo
0P001Woo0P006Woo0P001Woo0P0037oo0P0000=oo`00000037oo00<007ooOol0aGoo1@00ogoo5Goo
1P00ogoo6Goo000GOol20004Ool2000LOol20004Ool2000>Ool4000<Ool00`00Oomoo`35Ool5003o
OolEOol6003oOolIOol001Moo`P001aoo`P000ioo`@000aoo`03001oogoo0<Eoo`D00?mooaEoo`H0
0?mooaUoo`006Goo100087oo10004Goo0`0037oo00<007ooOol0aGoo1@00ogoo5Goo1P00ogoo6Goo
001QOol00`00Oomoo`35Ool5003oOolEOol6003oOolIOol0065oo`03001oogoo0<Eoo`D00?mooaEo
o`T00?mooaIoo`00HGoo00<007ooOol0aGoo1@00ogoo5Goo2P00ogoo5Goo001QOol00`00Oomoo`35
Ool5003oOolEOol:003oOolEOol0065oo`03001oogoo0<Eoo`D00?mooaEoo`X00?mooaEoo`00HGoo
00<007ooOol0aGoo1@00ogoo5Goo2P00ogoo5Goo001QOol00`00Oomoo`35Ool5003oOolEOol:003o
OolEOol0065oo`03001oogoo0<Eoo`D00003Ool000000?mooa9oo`X00?mooaEoo`00HGoo00<007oo
Ool0a7oo2P00ogoo4Goo2P00ogoo5Goo001QOol00`00Oomoo`34Ool:003oOolAOol:003oOolEOol0
065oo`<00<Aoo`X00?mooa5oo`X00?mooaEoo`00HGoo00<007ooOol0a7oo2P00ogoo47oo2`00ogoo
5Goo001QOol00`00Oomoo`34Ool:003oOol@Ool;003oOolEOol0065oo`03001oogoo0<Aoo`/00?mo
o`moo`/00?mooaEoo`00HGoo00<007ooOol0a7oo2`00ogoo3goo2`00ogoo5Goo001QOol00`00Oomo
o`34Ool;003oOol?Ool;003oOolEOol0065oo`03001oogoo0<Aoo`/00?moo`moo`/00?mooaEoo`00
HGoo00<007ooOol0a7oo2`00ogoo3goo2`00ogoo5Goo001QOol00`00Oomoo`34Ool;003oOol?Ool;
003oOolEOol0065oo`03001oogoo0<Aoo`/00?moo`moo`/00?mooaEoo`00HGoo00<007ooOol0a7oo
2`00ogoo3goo2`00ogoo5Goo001QOol00`00Oomoo`34Ool;003oOol?Ool;003oOolEOol0065oo`03
001oogoo0<Aoo`/00?moo`moo`/00?mooaEoo`00HGoo00<007ooOol0a7oo2`00ogoo3goo2`00ogoo
5Goo001QOol00`00Oomoo`34Ool;003oOol?Ool;003oOolEOol0065oo`03001oogoo0<Aoo`/00?mo
o`moo``00?mooaAoo`00HGoo00<007ooOol0a7oo2`00ogoo3goo3000ogoo57oo001QOol00`00Oomo
o`34Ool;003oOol?Ool<003oOolDOol0065oo`03001oogoo0<Aoo`/00?moo`moo``00?mooaAoo`00
HGoo00<007ooOol0a7oo2`00ogoo3goo3000ogoo57oo001QOol30034Ool;003oOol?Ool<003oOolD
Ool0065oo`03001oogoo0<Aoo`/00?moo`moo``00?mooaAoo`00HGoo00<007ooOol0a7oo2`00ogoo
3goo3000ogoo57oo001QOol00`00Oomoo`34Ool;003oOol?Ool<003oOolDOol0065oo`03001oogoo
0<Aoo`/00?moo`moo``00?mooaAoo`00HGoo00<007ooOol0a7oo2`00ogoo3goo3000ogoo57oo001Q
Ool00`00Oomoo`34Ool;003oOol?Ool<003oOolDOol0065oo`03001oogoo0<Aoo`/00?moo`moo``0
0?mooaAoo`00HGoo00<007ooOol0a7oo2`00ogoo3goo3000ogoo57oo001QOol00`00Oomoo`34Ool;
003oOol?Ool<003oOolDOol0065oo`03001oogoo0<Aoo`/00?moo`moo``00?mooaAoo`00HGoo00<0
07ooOol0a7oo2`00ogoo3goo3000ogoo57oo001QOol00`00Oomoo`34Ool;003oOol?Ool<003oOolD
Ool0065oo`03001oogoo0<Aoo``00?moo`ioo``00?mooaAoo`00HGoo00<007ooOol0a7oo3000ogoo
3Woo100000=oo`0000001@00ogoo57oo001QOol00`00Oomoo`34Ool<003oOol>Ool40004Ool4003o
OolDOol0065oo`03001oogoo0<Aoo``00?moo`ioo`@000Aoo`D00?mooa=oo`00HGoo00<007ooOol0
a7oo3000ogoo3Woo100017oo1P00ogoo4Woo001QOol00`00Oomoo`34Ool<003oOol>Ool40004Ool6
003oOolBOol0065oo`03001oogoo0<Aoo``00?moo`ioo`@000Eoo`D00?mooa9oo`00HGoo00<007oo
Ool0a7oo3000ogoo3Woo10001Woo1000ogoo4Woo001QOol30034Ool<003oOol>Ool40006Ool4003o
OolBOol0065oo`03001oogoo0<=oo`D00004Ool00000Ool5003oOol=Ool40006Ool4003oOolBOol0
065oo`03001oogoo0<=oo`D000Aoo`D00?moo`eoo`@000Ioo`@00?mooa9oo`00HGoo00<007ooOol0
`goo10001Goo1@00ogoo3Goo10001Woo1000ogoo4Woo001QOol00`00Oomoo`33Ool40005Ool5003o
Ool=Ool40006Ool4003oOolBOol0065oo`03001oogoo0<=oo`@000Ioo`D00?moo`aoo`@000Ioo`@0
0?mooa9oo`00HGoo00<007ooOol0`goo10001Woo1@00ogoo37oo10001Woo1000ogoo4Woo001QOol0
0`00Oomoo`33Ool40007Ool4003oOol<Ool40006Ool4003oOolBOol0065oo`03001oogoo0<=oo`@0
00Moo`@00?moo`]oo`D000Ioo`@00?mooa9oo`00HGoo00<007ooOol0`goo10001goo1000ogoo2goo
1@001Woo1000ogoo4Woo001QOol00`00Oomoo`33Ool40007Ool4003oOol;Ool40007Ool4003oOolB
Ool0065oo`03001oogoo0<=oo`@000Moo`@00?moo`]oo`@000Moo`@00?mooa9oo`00HGoo00<007oo
Ool0`goo10001goo1000ogoo2goo10001goo1000ogoo4Woo001QOol00`00Oomoo`33Ool40007Ool4
003oOol;Ool40007Ool4003oOolBOol001Uoo`@000ioo`<000moo`@000Uoo``000]oo`03001oogoo
0<=oo`@000Moo`@00?moo`]oo`@000Moo`@00?mooa9oo`005goo20002goo1@0037oo20001goo3000
2goo00<007ooOol0`goo10001goo1000ogoo2goo10001goo1000ogoo4Woo000GOol20004Ool2000;
Ool5000<Ool20004Ool20008Ool30006Ool2000;Ool00`00Oomoo`33Ool40007Ool4003oOol;Ool4
0007Ool4003oOolBOol001Ioo`8000Ioo`8000Yoo`D000]oo`8000Ioo`8000Qoo`<0019oo`03001o
ogoo0<=oo`@000Moo`@00?moo`]oo`@000Moo`@00?mooa9oo`005Woo0P001Woo0P002goo0`0037oo
0P001Woo0P002Goo0`004Goo00<007ooOol0`goo10001goo1000ogoo2goo10001goo1000ogoo4Woo
0002Ool=0006Ool20008Ool2000HOol20008Ool20009Ool3000@Ool00`00Oomoo`33Ool40007Ool4
003oOol;Ool40007Ool4003oOolBOol0009oo`d000Ioo`8000Qoo`8001Qoo`8000Qoo`8000Yoo`<0
00moo`03001oogoo0<=oo`@000Moo`@00?moo`]oo`@000Moo`@00?mooa9oo`000Woo3@001Woo0P00
27oo0P0067oo0P0027oo0P002goo0`003Woo1@00`Goo10001goo1000ogoo2goo10001goo1000ogoo
4Woo000EOol20008Ool2000HOol20008Ool2000<Ool3000=Ool00`00Oomoo`33Ool40007Ool4003o
Ool;Ool40007Ool4003oOolBOol001Eoo`8000Qoo`8001Qoo`8000Qoo`8000eoo`<000aoo`03001o
ogoo0<=oo`@000Moo`@00?moo`]oo`@000Moo`@00?mooa9oo`005Goo0P0027oo0P0067oo0P0027oo
0P003Woo0P0037oo00<007ooOol0`goo10001goo1000ogoo2goo10001goo1000ogoo4Woo000EOol2
0008Ool2000HOol20008Ool2000?Ool2000;Ool00`00Oomoo`33Ool40007Ool4003oOol;Ool40007
Ool4003oOolBOol001Eoo`8000Qoo`8001Qoo`8000Qoo`8000moo`8000]oo`03001oogoo0<=oo`@0
00Moo`@00?moo`]oo`@000Moo`@00?mooa9oo`005Woo0P001Woo0P006Woo0P001Woo0P001goo0P00
1goo0P002goo00<007ooOol0`goo10001goo1000ogoo2goo10001goo1000ogoo4Woo000FOol20006
Ool2000JOol20006Ool20007Ool30006Ool2000;Ool00`00Oomoo`33Ool40007Ool4003oOol;Ool4
0007Ool4003oOolBOol001Moo`8000Aoo`8001aoo`8000Aoo`8000Qoo`@000Aoo`8000aoo`03001o
ogoo0<=oo`@000Moo`@00?moo`]oo`@000Moo`@00?mooa9oo`005goo200077oo20002Goo20003Goo
00<007ooOol0`goo10001goo1000ogoo2goo10001goo1@00ogoo4Goo000IOol4000POol4000=Ool5
000>Ool00`00Oomoo`33Ool40007Ool4003oOol;Ool40008Ool4003oOolAOol0065oo`03001oogoo
0<=oo`@000Moo`@00?moo`]oo`@000Qoo`@00?mooa5oo`00HGoo00<007ooOol0`goo10001goo1000
ogoo2goo100027oo1000ogoo4Goo001QOol00`00Oomoo`33Ool40007Ool4003oOol;Ool40008Ool4
003oOolAOol0065oo`03001oogoo0<=oo`@000Moo`@00?moo`]oo`@000Qoo`@00?mooa5oo`00HGoo
00<007ooOol0`goo10001goo1000ogoo2goo100027oo1000ogoo4Goo001QOol00`00Oomoo`33Ool4
0007Ool4003oOol;Ool40008Ool4003oOolAOol0065oo`03001oogoo0<=oo`@000Moo`@00?moo`]o
o`@000Qoo`@00?mooa5oo`00HGoo00<007ooOol0`goo10001goo1000ogoo2goo100027oo1000ogoo
4Goo001QOol00`00Oomoo`33Ool40007Ool4003oOol;Ool40008Ool4003oOolAOol0065oo`03001o
ogoo0<=oo`@000Moo`@00?moo`]oo`@000Qoo`@00?mooa5oo`00HGoo0`00`goo10001goo1000ogoo
2goo100027oo1000ogoo4Goo001QOol00`00Oomoo`33Ool40007Ool4003oOol;Ool40008Ool4003o
OolAOol0065oo`03001oogoo0<=oo`@000Moo`@00?moo`]oo`@000Qoo`@00?mooa5oo`00HGoo00<0
07ooOol0`goo10001goo1000ogoo2goo100027oo1000ogoo4Goo001QOol00`00Oomoo`32Ool50007
Ool4003oOol;Ool40008Ool4003oOolAOol0065oo`03001oogoo0<9oo`D000Moo`@00?moo`]oo`@0
00Qoo`@00?mooa5oo`00HGoo00<007ooOol0`Woo100027oo1000ogoo2goo100027oo1000ogoo4Goo
001QOol00`00Oomoo`32Ool40008Ool4003oOol;Ool40008Ool4003oOolAOol0065oo`03001oogoo
0<9oo`@000Qoo`@00?moo`Yoo`D000Qoo`@00?mooa5oo`00HGoo00<007ooOol0`Woo100027oo1000
ogoo2Woo1@0027oo1000ogoo4Goo001QOol00`00Oomoo`32Ool40008Ool4003oOol:Ool40009Ool4
003oOolAOol0065oo`03001oogoo0<9oo`@000Qoo`@00?moo`Yoo`@000Uoo`@00?mooa5oo`00HGoo
00<007ooOol0`Woo100027oo1000ogoo2Woo10002Goo1000ogoo4Goo001QOol00`00Oomoo`32Ool4
0008Ool4003oOol:Ool40009Ool4003oOolAOol0065oo`03001oogoo0<9oo`@000Qoo`D00?moo`Uo
o`@000Uoo`@00?mooa5oo`00HGoo00<007ooOol0`Woo10002Goo1000ogoo2Goo10002Goo1000ogoo
4Goo001QOol00`00Oomoo`32Ool40009Ool4003oOol9Ool40009Ool4003oOolAOol0065oo`03001o
ogoo0<9oo`@000Uoo`@00?moo`Uoo`@000Uoo`@00?mooa5oo`00HGoo00<007ooOol0`Woo10002Goo
1000ogoo2Goo10002Goo1000ogoo4Goo001QOol00`00Oomoo`32Ool40009Ool4003oOol9Ool40009
Ool4003oOolAOol0065oo`03001oogoo0<9oo`@000Uoo`@00?moo`Uoo`@000Uoo`@00?mooa5oo`00
HGoo0`00`Woo10002Goo1000ogoo2Goo10002Goo1000ogoo4Goo001QOol00`00Oomoo`32Ool40009
Ool4003oOol9Ool40009Ool4003oOolAOol0065oo`03001oogoo0<9oo`@000Uoo`@009Ioo`80071o
o`@000Uoo`@00?mooa5oo`00HGoo00<007ooOol0`Woo10002Goo1000UGoo1000Kgoo10002Goo1000
ogoo4Goo001QOol00`00Oomoo`32Ool40009Ool4002EOol4001_Ool40009Ool4003oOolAOol0065o
o`03001oogoo0<9oo`@000Uoo`@009Eoo`D006ioo`@000Uoo`@00?mooa5oo`00HGoo00<007ooOol0
D7oo0P00L7oo10002Goo1000UGoo1@00KWoo10002Goo1000ogoo4Goo001QOol00`00Oomoo`1?Ool4
001_Ool40009Ool4002EOol5001^Ool40009Ool4003oOolAOol0065oo`03001oogoo04moo`@006mo
o`@000Uoo`@009Eoo`D00003Ool0000006]oo`@000Uoo`@0009oo`800?moo`eoo`00HGoo00<007oo
Ool0CWoo1@00Kgoo10002Goo1000UGoo2@00JWoo10002Goo100000=oo`0000000P00ogoo37oo001Q
Ool00`00Oomoo`1>Ool50002Ool2001[Ool40009Ool4000017oo00000000TGoo2@00JWoo10002Goo
100000=oo`0000000P00ogoo37oo001QOol00`00Oomoo`1>Ool500000goo00000002001ZOol40009
Ool9002@Ool:001YOol40009Ool400000goo00000002003oOol<Ool0065oo`03001oogoo04ioo`D0
0003Ool00000008006Yoo`@000Uoo`T008moo`/006Uoo`@000Uoo`@00003Ool0000000800?moo`ao
o`00HGoo00<007ooOol0A7oo3`0000=oo`0000000P0000=oo`0000000P003Woo10003Woo10003Woo
100087oo30000Woo1@0017oo100000=oo`0000001`0017oo10003Woo10003Woo100097oo1@003Woo
10003Woo10003Woo100017oo3P009Goo1`002Woo10003Woo10003Woo100027oo10000Woo10000goo
2@005goo1P003Woo10003Woo10003Woo10003Woo1000YWoo001QOol00`00Oomoo`14OolK000:Ool8
000:Ool8000:Ool8000NOol<0002Ool50002Ool@0002Ool8000:Ool8000:Ool8000POol9000:Ool8
000:Ool8000:Ool80002Ool@000SOol70008Ool8000:Ool8000:Ool80005Ool=00000goo00000007
000EOol:000:Ool8000:Ool8000:Ool8000:Ool8002TOol0065oo`03001oogoo04Qoo`8000Aoo`/0
00Aoo`8000Yoo`8000Aoo`8000Yoo`8000Aoo`8000Yoo`8000Aoo`8001moo`<000Ioo`80009oo`@0
00=oo`8000Aoo`X0009oo`8000Aoo`8000Yoo`8000Aoo`8000Yoo`8000Aoo`8001moo`@000Aoo`<0
00Uoo`8000Aoo`8000Yoo`8000Aoo`8000Yoo`8000Aoo`80009oo`/000=oo`8002Ioo`8000Yoo`80
00Aoo`8000Yoo`8000Aoo`8000Yoo`8000Aoo`8000Eoo`@00003Ool0000000Aoo`800003Ool00000
00L001Eoo`<000Eoo`<000Uoo`8000Aoo`8000Yoo`8000Aoo`8000Yoo`8000Aoo`8000Yoo`8000Ao
o`800:Aoo`00HGoo00<007ooOol0B7oo0P0017oo2P001Woo0P0027oo0P001Woo0P0027oo0P001Woo
0P0027oo0P001Woo0P007goo0`002Goo10000Woo0P001Woo2@0000=oo`0000001Woo0P0027oo0P00
1Woo0P0027oo0P001Woo0P007Woo0P001goo0`001goo0P001Woo0P0027oo0P001Woo0P0027oo0P00
1Woo0P0000=oo`0000002@0017oo0P009Goo0P002Goo0P001Woo0P0027oo0P001Woo0P0027oo0P00
1Woo0P0017oo1P001Woo2`007Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P00
27oo0P001Woo0P00Xgoo001QOol00`00Oomoo`18Ool20004Ool:0006Ool20008Ool20006Ool20008
Ool20006Ool20008Ool20006Ool2000POol30008Ool40002Ool20006Ool900000goo00000006Ool2
0008Ool20006Ool20008Ool20006Ool2000XOol20007Ool20006Ool20008Ool20006Ool20008Ool2
0006Ool200000goo000000090004Ool2000UOol20009Ool20006Ool20008Ool20006Ool20008Ool2
0006Ool20004Ool60006Ool;000OOol20007Ool20006Ool20008Ool20006Ool20008Ool20006Ool2
0008Ool20006Ool2002SOol0065oo`03001oogoo04Qoo`8000Aoo`X000Moo`8000Ioo`8000Qoo`80
00Ioo`8000Qoo`8000Ioo`8000Qoo`80021oo`<000Moo`@00003Ool0000000Moo`/000Qoo`8000Io
o`8000Qoo`8000Ioo`8000Qoo`8002Moo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qo
o`d000Eoo`8001aoo``000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000=oo`D000Qo
o`X001moo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`800:9o
o`00HGoo00<007ooOol0B7oo0P0017oo2P001goo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo
0P0027oo0P008Goo0`001Woo100000=oo`0000001goo2`0027oo0P001Woo0P0027oo0P001Woo0P00
27oo0P009goo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo3@001Goo0P0077oo3000
1Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P000goo1@0027oo2P007goo0P001Woo0P00
27oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P00XWoo001QOol00`00Oomoo`18
Ool20004Ool:0007Ool20006Ool20008Ool20006Ool20008Ool20006Ool20008Ool2000ROol30005
Ool400000goo00000007Ool<0007Ool20006Ool20008Ool20006Ool20008Ool2000VOol30006Ool2
0008Ool20006Ool20008Ool20006Ool20008Ool=0005Ool2000LOol20006Ool200000goo001oo`05
Ool20008Ool20006Ool20008Ool20006Ool20008Ool20003Ool50008Ool=000LOol20006Ool20008
Ool20006Ool20008Ool20006Ool20008Ool20006Ool20008Ool2002ROol0065oo`<004Qoo`8000Ao
o`X000Moo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8002=oo`<000Aoo`@00003
Ool0000000Moo``000Moo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8002Eoo`<000Moo`8000Qoo`80
00Ioo`8000Qoo`8000Ioo`8000Qoo`l000=oo`8001eoo`8000Eoo`8000Qoo`8000Qoo`8000Ioo`80
00Qoo`8000Ioo`8000Qoo`8000=oo`D000Qoo`h001]oo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`80
00Ioo`8000Qoo`8000Ioo`8000Qoo`800:9oo`00HGoo00<007ooOol0B7oo0P0017oo2P001goo0P00
1Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P0097oo0`000goo100000=oo`0000001goo
30001goo0P001Woo0P0027oo0P001Woo0P0027oo0P008Woo1@0027oo0P0027oo0P001Woo0P0027oo
0P001Woo0P0027oo40000Woo0P007Goo0`0017oo0P0027oo0P0027oo0P001Woo0P0027oo0P001Woo
0P0027oo0P000goo1@0027oo3P006Woo0P001goo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo
0P001Woo0P0027oo0P00XWoo001QOol00`00Oomoo`18Ool20004Ool<0005Ool20006Ool20008Ool2
0006Ool20008Ool20006Ool20008Ool2000UOol20003Ool400000goo00000007Ool<0007Ool20006
Ool20008Ool20006Ool20008Ool2000ROol40009Ool20008Ool20006Ool20008Ool20006Ool20008
Ool@0002Ool2000NOol20004Ool20008Ool20008Ool20006Ool20008Ool20006Ool20008Ool20003
Ool50008Ool>000BOol20005Ool30007Ool20008Ool20006Ool20008Ool20006Ool20008Ool20006
Ool20008Ool2002ROol0065oo`03001oogoo04Qoo`8000Aoo`d000Aoo`8000Ioo`8000Qoo`8000Io
o`8000Qoo`8000Ioo`8000Qoo`8002Ioo`80009oo`@00003Ool0000000Moo``000Moo`8000Ioo`80
00Qoo`8000Ioo`8000Qoo`8002Eoo`8000Qoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qooa00
009oo`80009oo`8001]oo`8000=oo`8000Qoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`80
00=oo`D000Qoo`h0019oo`T000Qoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`80
00Qoo`800:9oo`00HGoo00<007ooOol0B7oo0P0017oo3@0017oo0P001Woo0P0027oo0P001Woo0P00
27oo0P001Woo0P0027oo0P009Woo0P000Woo100000=oo`0000001goo30001goo0P001Woo0P0027oo
0P001Woo0P0027oo0P009Woo0P001goo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo40000Woo
1`006Woo0`000Woo0P0027oo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P000goo1@0027oo
3P004Woo0P0000=oo`0000000`002Goo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo
0P0027oo0P00XWoo001QOol00`00Oomoo`18Ool20004Ool>0002Ool20008Ool20006Ool20008Ool2
0006Ool20008Ool20006Ool2000NOol20007Ool20002Ool40002Ool20006Ool<0006Ool20008Ool2
0006Ool20008Ool20006Ool2000WOol20008Ool20006Ool20008Ool20006Ool20008Ool20006Ool2
00000goo0000000<00000goo00000006000KOol20002Ool20009Ool20006Ool20008Ool20006Ool2
0008Ool20006Ool20004Ool60006Ool?000BOol2000@Ool20006Ool20008Ool20006Ool20008Ool2
0006Ool20008Ool20006Ool2002SOol0065oo`03001oogoo04Qoo`8000Aoo`h0009oo`<00003Ool0
000000Aoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8001ioo`<000Ioo`80009oo`@0009o
o`8000Ioo``000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8001moo`8000Ioo`8000Qoo`8000Io
o`8000Qoo`8000Ioo`8000Qoo`8000Ioo`800003Ool0000000`00003Ool0000000H001aoo`800003
Ool0000000Uoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000=oo`L000Ioo`l0019oo`80
011oo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`800:=oo`00HGoo00<0
07ooOol0A7oo0`0000=oo`00000017oo3P0000=oo`0000001`000goo0P0017oo0P002Woo0P0017oo
0P002Woo0P0017oo0P007goo100017oo0P000goo10000goo0P0017oo3P0017oo0P002Woo0P0017oo
0P002Woo0P0017oo0P0087oo0`0017oo0`002Goo0P0017oo0P002Woo0P0017oo0P002Woo0P0017oo
0P000Woo6`006Goo10002Woo0P0017oo0P002Woo0P0017oo0P002Woo0P0017oo0P0017oo1@0000=o
o`00000017oo0P0000=oo`0000002`004Woo0P004Goo0P0017oo0P002Woo0P0017oo0P002Woo0P00
17oo0P002Woo0P0017oo0P00G7oo1@001goo2@007Woo1@0047oo001QOol00`00Oomoo`14Ool60004
OolI0002Ool8000:Ool8000:Ool8000POol80003Ool50003OolJ000:Ool8000:Ool8000QOol8000:
Ool8000:Ool8000:Ool80002OolL000HOol4000:Ool8000:Ool8000:Ool80004Ool40002Ool80000
0goo0000000;000BOol:0009Ool8000:Ool8000:Ool8000:Ool8001LOol50007Ool9000NOol5000@
Ool0065oo`03001oogoo04Moo`<000Aooa/0009oo`@000ioo`@000ioo`@002Aoo`D000Aoo`D000Eo
o`@00003Ool0000000l000ioo`@000ioo`@002Aoo`D000ioo`@000ioo`@000ioo`@000Aooa`001Uo
o`<000aoo`@000ioo`@000ioo`@000Ioo`@000Aoo`@000=oo`d0019oo`X000]oo`@000ioo`@000io
o`@000ioo`@005ioo`8000aoo`8002Ioo`80011oo`00HGoo00<007ooOol0CWoo7000EWoo10002goo
3@00Rgoo8000DWoo10002goo3@00_goo0P0037oo0P009Woo0P0047oo001QOol00`00Oomoo`1>OolM
001EOol4000;Ool=002;OolQ001@Ool5000;Ool=002oOol2000<Ool2000VOol2000@Ool0065oo`03
001oogoo04ioob00059oo`@000]oo`d008]oob<004ioo`D000]oo`d00;moo`8000aoo`8002Ioo`80
011oo`00HGoo00<007ooOol0CWoo8@00DGoo10002goo3@00Rgoo=`0017oo0P00=7oo100037oo3@00
I7oo1P001goo3P000Woo1P000Woo10000Woo10001Goo20007goo0P0037oo0P000Woo1P001goo0P00
00=oo`0000001@003Goo0P0047oo001QOol00`00Oomoo`1>Ool`0011Ool5000;Ool=002;Oom<0005
Ool2000MOol5000<Ool=001SOol90005Ool>0002Ool60002Ool40002Ool40004Ool;000MOol2000<
Ool200000goo000000070005Ool<000;Ool2000@Ool0065oo`03001oogoo04iood40031oo`D000]o
o`d008]oogD000aoo`d000Ioo`8005Yoo`<000Aoo`@000Yoo`8000Yoo`8000Aoo`8000Aoo`8000Eo
o`8000Moo`@001aoo`8000aoo`D000Aoo`@000Aoo`@000Ioo`<000Yoo`80011oo`00HGoo00<007oo
Ool0CWooM@0037oo3@001Woo0P00PgooM0003Woo30001Goo1000FGoo0P001goo0P002Woo0P002Woo
0P0017oo0P0017oo0P0017oo0P00:7oo0P0037oo0`0027oo0P0017oo0P002Goo0P002Woo0P0047oo
001QOol00`00Oomoo`1>Oome000<Ool=0005Ool60020Oomc000?Ool<0005Ool4001IOol2000COol2
000:Ool20004Ool20004Ool20003Ool2000YOol2000<Ool30008Ool30003Ool20009Ool2000:Ool2
000@Ool0065oo`03001oogoo04ioogD000aoo`d000=oo`X007ioog80011oo``000Eoo`P005Eoo`80
01=oo`8000Yoo`8000Aoo`8000Aoo`8000=oo`8002Uoo`8000aoo`8000Yoo`8000eoo`<000Yoo`80
011oo`00HGoo00<007ooOol0CWooM0003Goo3@000Woo3000OGoo8`001Woo0P0017oo0`000Woo0P00
C7oo30000goo2`00E7oo0P004goo0P002Woo0P0017oo0P0017oo0P000goo3`0077oo0P0037oo0P00
2Woo0P001Woo2@002goo0P0047oo001POom4000>Ooln0013OolL001lOolR001POol<0002Ool=001C
Ool2000COol2000:Ool20004Ool20004Ool20003Ool?000LOol2000<Ool2000:Ool20004Ool:000<
Ool2000@Ool005=oool00?l0058001Qoo`8001=oo`8000Yoo`8000Aoo`8000Aoo`8000=oo`8000]o
o`8001aoo`8000aoo`8000Yoo`8000=oo`@001=oo`80011oo`00GgooAP003Goo80005Woo00<007oo
Ool04goo00<007ooOol057oo00<007ooOol04goo00<007ooOol01Goo7`001Woo00<007ooOol057oo
00<007ooOol057oo00<007ooOol04goo00<007ooOol057oo00<007ooOol04goo00<007oo00007000
3Woo00<007ooOol057oo00<007ooOol04goo00<007ooOol057oo00<007ooOol047oo7@004goo00<0
07ooOol057oo00<007ooOol097oo0P004goo0P002Woo0P0017oo0P0017oo0P000goo0`002Woo0P00
77oo0P0037oo0`0027oo0`000goo0P0027oo0P002goo0P0047oo001POom6000<OolM0002Ool00`00
Oomoo`0DOol00`00Oomoo`0COol00`00Oomoo`0DOol00`00Oomoo`0COol00`00Oomoo`05OolR0003
Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0COol00`00Oomoo`0DOol00`00Oomoo`0C
Ool00`00Ool0000J000@Ool00`00Oomoo`0DOol00`00Oomoo`0COol00`00Oomoo`0DOol00`00Oomo
o`0@OolN00000goo0000000?Ool00`00Oomoo`0DOol00`00Oomoo`0TOol2000COol2000:Ool20004
Ool20004Ool20004Ool20009Ool2000MOol2000<Ool30008Ool20004Ool20007Ool3000;Ool2000@
Ool0065oo`03001oogoo03eoo`D000aooa`000=oo`03001oogoo05moob@0009oo`D0009oo`D0009o
o`@004Qoo`03001oogoo01EooaX003ioo`03001oogoo02Moob8000Ioo`<000Aoo`8001Ioo`03001o
ogoo021oo`d000aoo`8000Yoo`<0009oo`@0009oo`<000Eoo`<000Eoo`<001ioo`8000aoo`D000Ao
o`<000Eoo`<000Eoo`@000]oo`80011oo`00HGoo00<007ooOol0?Woo100037oo6`0017oo00<007oo
Ool0GgooO`0000=oo`00Ool05Woo3`000Woo1`00@7oo00<007ooOol09goo<P0000=oo`0000000`00
00=oo`0000000`0000=oo`0000000`0000Aoo`000000029oo`d000Qoo`H000Qoo`l000Moo`T001mo
o`8000Yoo`@00003Ool0000000H000Moo`/000]oo`80011oo`00HGoo00<007ooOol0?Woo1@002goo
3P0000=oo`0000002@00IgooP00067oo3@0017oo1@00K7ooB@009Goo0P003goo1P0027oo100000=o
o`0000000P000Woo0`002Woo1P0087oo0P002Woo10000Woo1P002Woo1P0000=oo`0000002goo0P00
47oo001QOol00`00Oomoo`0nOol5000;Ool<0004Ool8001YOon1000GOol=0005Ool4001/Oom9000U
Ool2001KOol2000dOol2000@Ool0065oo`03001oogoo03moo`@000Yoo`d000Ioo`D006Yooh8001Io
o``000Moo`8006eoodT002Eoo`8005]oo`8003Aoo`80011oo`00HGoo00<007ooOol0?goo10002Woo
3@00MGooAP0000=oo`0000000`00<Goo1P005Goo3000MWooB0009Woo0P00Fgoo0P00=7oo0P0047oo
001QOol00`00Oomoo`0oOol4000:Ool=001eOolc0002Ool20017Ool5000EOol<001fOolm0004Ool2
000[Ool2000BOol30016Ool5000^Ool5000@Ool0065oo`03001oogoo03moo`@000Yoo`d007Eoob<0
05aoo`D0009oo`@000ioo``007Ioob8000=oo`L0009oo`8000Aoo`8004aoo`<004Ioo`D002ioo`D0
011oo`00HGoo00<007ooOol0?goo10002Woo3@00MGoo8000Ggoo1@0000=oo`00000010003Goo3000
MWoo8@00HGoo0`00SWoo001QOol00`00Oomoo`0oOol4000:Ool=001fOolM001ROol<000<Ool<001f
OolP001ROol3002>Ool0065oo`03001oogoo03moo`@000Yoo`@00003Ool0000000H007Iooa/006Ao
o``000aoo``007Iooad00?Ioo`00HGoo00<007ooOol0?goo10002Woo100000=oo`0000001P00MWoo
6`00IGoo2`0037oo3000MWoo7000mgoo001QOol00`00Oomoo`0oOol50009Ool400000goo00000006
001fOolJ001VOol<000;Ool<001fOolL003gOol0065oo`03001oogoo03moo`D000Uoo`@00003Ool0
000000H007IooaP006Uoo`D00003Ool0000000<000]oo`/007Mooa/00?Qoo`00HGoo00<007ooOol0
@7oo10002Goo100000=oo`0000001P00MWoo3@001Goo1000K7oo0`000goo10002goo2@00NGoo3@00
00=oo`0000000Woo1@00o7oo001QOol00`00Oomoo`10Ool40009Ool400000goo00000005001gOol<
0007Ool2001cOol4000;Ool9001iOol=0005Ool5003lOol0065oo`03001oogoo041oo`@000Uoo`@0
0003Ool00000008007Yoo`X007ioo`@000]oo`T007Uoo`d000Eoo`D00?aoo`00HGoo00<007ooOol0
@7oo10002Goo100000=oo`0000000P00NWoo2P00OWoo10002goo2@00NGoo30001goo0`00oGoo001Q
Ool30010Ool40009Ool400000goo00000002001jOol:001nOol4000;Ool9001iOol:003oOol:Ool0
065oo`03001oogoo041oo`@000Uoo`@00003Ool00000008007Yoo`@00003Ool0000000<007ioo`D0
00Yoo`T007Uoo`D00003Ool0000000800?moo`Yoo`00HGoo00<007ooOol0@7oo10002Goo100000=o
o`0000000P00Ngoo0P000Woo1@00OWoo1@002Woo2@00NGoo1@0000=oo`0000000P00ogoo2Woo001Q
Ool00`00Oomoo`10Ool40009Ool40002Ool20020Ool5001oOol4000:Ool4000017oo00000000Ngoo
0`000Woo1000ogoo2Woo001QOol00`00Oomoo`10Ool40009Ool40025Ool30020Ool4000:Ool40025
Ool2003oOol;Ool0065oo`03001oogoo041oo`@000Uoo`@00?moo`Uoo`@000Yoo`@00?mooi9oo`00
HGoo00<007ooOol0@7oo10002Goo1000ogoo2Goo10002Woo1000ogooTWoo001QOol00`00Oomoo`10
Ool40009Ool4003oOol9Ool4000:Ool4003oOonBOol0065oo`03001oogoo041oo`@000Uoo`@00?mo
o`Uoo`@000Yoo`@00?mooi9oo`00HGoo00<007ooOol0@7oo10002Goo1000ogoo2Goo10002Woo1000
ogooTWoo001QOol00`00Oomoo`10Ool40009Ool4003oOol9Ool40009Ool5003oOonBOol0065oo`03
001oogoo041oo`@000Uoo`@00?moo`Uoo`@000Uoo`@00?mooi=oo`00HGoo00<007ooOol0@7oo1000
2Goo1000ogoo2Goo10002Goo1000ogooTgoo001QOol00`00Oomoo`10Ool40009Ool4003oOol9Ool4
0009Ool4003oOonCOol0065oo`03001oogoo041oo`@000Uoo`@00?moo`Uoo`@000Uoo`@00?mooi=o
o`00HGoo00<007ooOol0@7oo10002Goo1000ogoo2Goo10002Goo1000ogooTgoo001QOol00`00Oomo
o`10Ool50008Ool4003oOol9Ool40009Ool4003oOonCOol0065oo`03001oogoo045oo`@000Qoo`@0
0?moo`Uoo`D000Qoo`@00?mooi=oo`00HGoo00<007ooOol0@Goo100027oo1000ogoo2Goo1@0027oo
1000ogooTgoo001QOol00`00Oomoo`11Ool40008Ool4003oOol:Ool40008Ool4003oOonCOol0065o
o`03001oogoo045oo`@000Qoo`@00?moo`Yoo`@000Qoo`@00?mooi=oo`00HGoo0`00@Goo100027oo
1000ogoo2Woo100027oo1000ogooTgoo001QOol00`00Oomoo`11Ool40008Ool4003oOol:Ool40008
Ool4003oOonCOol0065oo`03001oogoo045oo`@000Qoo`@00?moo`Yoo`@000Qoo`@00?mooi=oo`00
HGoo00<007ooOol0@Goo100027oo1000ogoo2Woo100027oo1000ogooTgoo001QOol00`00Oomoo`11
Ool40008Ool4003oOol:Ool40008Ool4003oOonCOol0065oo`03001oogoo045oo`@000Qoo`@00?mo
o`Yoo`@000Qoo`@00?mooi=oo`00HGoo00<007ooOol0@Goo100027oo1000ogoo2Woo100027oo1000
ogooTgoo001QOol00`00Oomoo`11Ool40008Ool4003oOol:Ool40008Ool4003oOonCOol0065oo`03
001oogoo045oo`@000Qoo`@00?moo`Yoo`@000Qoo`@00?mooi=oo`00HGoo00<007ooOol0@Goo1000
27oo1000ogoo2Woo100027oo1000ogooTgoo001QOol00`00Oomoo`11Ool40008Ool4003oOol:Ool4
0008Ool4003oOonCOol0065oo`03001oogoo045oo`@000Qoo`@00?moo`Yoo`@000Qoo`@00?mooi=o
o`00HGoo00<007ooOol0@Goo100027oo1000ogoo2Woo100027oo1000ogooTgoo001QOol00`00Oomo
o`11Ool40008Ool4003oOol:Ool40008Ool4003oOonCOol0065oo`03001oogoo045oo`@000Qoo`@0
0?moo`Yoo`@000Qoo`@00?mooi=oo`00HGoo00<007ooOol0@Goo100027oo1000ogoo2Woo100027oo
1000ogooTgoo001QOol00`00Oomoo`11Ool40008Ool4003oOol:Ool40008Ool4003oOonCOol0065o
o`03001oogoo045oo`@000Qoo`@00?moo`Yoo`@000Qoo`@00?mooi=oo`00HGoo00<007ooOol0@Goo
100027oo1000ogoo2Woo100027oo1000ogooTgoo001QOol00`00Oomoo`11Ool40008Ool4003oOol:
Ool40008Ool4003oOonCOol0065oo`03001oogoo045oo`@000Qoo`@00?moo`Yoo`@000Qoo`@00?mo
oi=oo`00HGoo0`00@Goo100027oo1000ogoo2Woo100027oo1000ogooTgoo001QOol00`00Oomoo`11
Ool40008Ool4003oOol:Ool40008Ool4003oOonCOol0065oo`03001oogoo045oo`@000Qoo`@00?mo
o`Yoo`@000Qoo`@00?mooi=oo`00HGoo00<007ooOol0@Goo100027oo1000ogoo2Woo100027oo1000
ogooTgoo001QOol00`00Oomoo`11Ool40008Ool4003oOol:Ool40008Ool4003oOonCOol0065oo`03
001oogoo045oo`@000Qoo`@00?moo`Yoo`D000Moo`@00?mooi=oo`00HGoo00<007ooOol0@Goo1000
27oo1000ogoo2Woo1@001goo1000ogooTgoo001QOol00`00Oomoo`11Ool40008Ool4003oOol;Ool4
0007Ool4003oOonCOol0065oo`03001oogoo045oo`@000Qoo`@00?moo`]oo`@000Moo`@00?mooi=o
o`00HGoo00<007ooOol0@Goo100027oo1000ogoo2goo10001goo1000ogooTgoo001QOol00`00Oomo
o`11Ool40008Ool4003oOol;Ool40007Ool4003oOonCOol0065oo`03001oogoo045oo`D000Ioo`D0
0?moo`]oo`@000Moo`@00?mooi=oo`00HGoo00<007ooOol0@Woo10001Woo1000ogoo37oo10001goo
1000ogooTgoo001QOol00`00Oomoo`12Ool40006Ool4003oOol<Ool40007Ool4003oOonCOol001Uo
o`@000ioo`<000moo`@000Uoo``000]oo`03001oogoo049oo`@000Ioo`@00?moo`aoo`@000Moo`@0
0?mooi=oo`005goo20002goo1@0037oo20001goo30002goo00<007ooOol0@Woo10001Woo1000ogoo
37oo10001goo1000ogooTgoo000GOol20004Ool2000;Ool5000<Ool20004Ool20008Ool30006Ool2
000;Ool00`00Oomoo`12Ool40006Ool4003oOol<Ool40007Ool4003oOonCOol001Ioo`8000Ioo`80
00Yoo`D000]oo`8000Ioo`8000Qoo`<0019oo`03001oogoo049oo`@000Ioo`@00?moo`aoo`@000Mo
o`@00?mooi=oo`005Woo0P001Woo0P002goo0`0037oo0P001Woo0P002Goo0`004Goo00<007ooOol0
@Woo10001Woo1000ogoo37oo10001goo1000ogooTgoo000EOol20008Ool2000HOol20008Ool20009
Ool3000@Ool00`00Oomoo`12Ool40006Ool4003oOol<Ool40007Ool4003oOonCOol001Eoo`8000Qo
o`8001Qoo`8000Qoo`8000Yoo`<000moo`03001oogoo049oo`@000Ioo`@00?moo`aoo`@000Moo`@0
0?mooi=oo`005Goo0P0027oo0P0067oo0P0027oo0P002goo0`003Woo1@00@7oo10001Woo1000ogoo
37oo10001goo1000ogooTgoo000EOol20008Ool2000HOol20008Ool2000<Ool3000=Ool00`00Oomo
o`12Ool40006Ool4003oOol<Ool40007Ool4003oOonCOol001Eoo`8000Qoo`8001Qoo`8000Qoo`80
00eoo`<000aoo`03001oogoo049oo`@000Ioo`@00?moo`aoo`@000Moo`@00?mooi=oo`005Goo0P00
27oo0P0067oo0P0027oo0P003Woo0P0037oo00<007ooOol0@Woo10001Woo1000ogoo37oo10001goo
1000ogooTgoo000EOol20008Ool2000HOol20008Ool2000?Ool2000;Ool00`00Oomoo`12Ool40006
Ool4003oOol<Ool40006Ool5003oOonCOol001Eoo`8000Qoo`8001Qoo`8000Qoo`8000moo`8000]o
o`03001oogoo049oo`@000Ioo`@00?moo`aoo`@000Ioo`D00?mooi=oo`005Woo0P001Woo0P006Woo
0P001Woo0P001goo0P001goo0P002goo00<007ooOol0@Woo10001Woo1000ogoo37oo10001Woo1000
ogooU7oo000FOol20006Ool2000JOol20006Ool20007Ool30006Ool2000;Ool00`00Oomoo`12Ool4
0006Ool4003oOol<Ool40006Ool4003oOonDOol001Moo`8000Aoo`8001aoo`8000Aoo`8000Qoo`@0
00Aoo`8000aoo`03001oogoo049oo`@000Ioo`@00?moo`aoo`@000Ioo`@00?mooiAoo`005goo2000
77oo20002Goo20003Goo00<007ooOol0@Woo10001Woo1000ogoo37oo10001Woo1000ogooU7oo000I
Ool4000POol4000=Ool5000>Ool00`00Oomoo`12Ool40006Ool4003oOol<Ool40006Ool4003oOonD
Ool0065oo`03001oogoo049oo`@000Eoo`D00?moo`aoo`@000Ioo`@00?mooiAoo`00HGoo00<007oo
Ool0@Woo10001Goo1@00ogoo37oo10001Goo1@00ogooU7oo001QOol00`00Oomoo`12Ool40005Ool5
003oOol<Ool40005Ool5003oOonDOol0065oo`03001oogoo049oo`@000Aoo`D00?moo`eoo`@000Eo
o`D00?mooiAoo`00HGoo00<007ooOol0@Woo100017oo1@00ogoo3Goo10001Goo1000ogooUGoo001Q
Ool00`00Oomoo`12Ool40004Ool4003oOol>Ool40005Ool4003oOonEOol0065oo`03001oogoo049o
o`@0009oo`H00?moo`ioo`@000Eoo`@00?mooiEoo`00HGoo00<007ooOol0@Woo100000=oo`000000
1@00ogoo3Woo10001Goo1000ogooUGoo001QOol00`00Oomoo`12Ool<003oOol>Ool40005Ool4003o
OonEOol0065oo`03001oogoo049oo``00?moo`ioo`@000Eoo`@00?mooiEoo`00HGoo0`00@Woo3000
ogoo3Woo10001Goo1000ogooUGoo001QOol00`00Oomoo`12Ool<003oOol>Ool40005Ool4003oOonE
Ool0065oo`03001oogoo049oo``00?moo`ioo`@000Eoo`@00?mooiEoo`00HGoo00<007ooOol0@Woo
3000ogoo3Woo10000Woo1`00ogooUGoo001QOol00`00Oomoo`12Ool<003oOol>Ool400000goo0000
0006003oOonEOol0065oo`03001oogoo049oo``00?moo`ioo`@00003Ool0000000D00?mooiIoo`00
HGoo00<007ooOol0@Woo3000ogoo3Woo100000=oo`0000001@00ogooUWoo001QOol00`00Oomoo`12
Ool<003oOol>Ool400000goo00000005003oOonFOol0065oo`03001oogoo049oo``00?moo`ioo``0
0?mooiIoo`00HGoo00<007ooOol0@Woo3000ogoo3goo2`00ogooUWoo001QOol00`00Oomoo`12Ool<
003oOol?Ool;003oOonFOol0065oo`03001oogoo049oo``00?moo`moo`/00?mooiIoo`00HGoo00<0
07ooOol0@Woo3000ogoo3goo2`00ogooUWoo001QOol00`00Oomoo`12Ool<003oOol?Ool;003oOonF
Ool0065oo`03001oogoo049oo``00?moo`moo`/00?mooiIoo`00HGoo00<007ooOol0@Woo3000ogoo
3goo2`00ogooUWoo001QOol00`00Oomoo`12Ool<003oOol?Ool;003oOonFOol0065oo`03001oogoo
049oo``00?moo`moo`/00?mooiIoo`00HGoo00<007ooOol0@goo2`00ogoo3goo2`00ogooUWoo001Q
Ool00`00Oomoo`13Ool;003oOol?Ool;003oOonFOol0065oo`03001oogoo04=oo`/00?moo`moo`/0
0?mooiIoo`00HGoo0`00@goo2`00ogoo3goo2`00ogooUWoo001QOol00`00Oomoo`13Ool;003oOol?
Ool;003oOonFOol0065oo`03001oogoo04=oo`X00?mooa1oo`/00?mooiIoo`00HGoo00<007ooOol0
@goo2P00ogoo47oo2`00ogooUWoo001QOol00`00Oomoo`13Ool:003oOol@Ool;003oOonFOol0065o
o`03001oogoo04=oo`X00?mooa1oo`/00?mooiIoo`00HGoo00<007ooOol0@goo2P00ogoo47oo2`00
ogooUWoo001QOol00`00Oomoo`13Ool:003oOol@Ool;003oOonFOol0065oo`03001oogoo04=oo`X0
0?mooa1oo`/00?mooiIoo`00HGoo00<007ooOol0@goo2P00ogoo47oo2`00ogooUWoo001QOol00`00
Oomoo`13Ool:003oOol@Ool;003oOonFOol0065oo`03001oogoo04=oo`X00?mooa1oo`/00?mooiIo
o`00HGoo00<007ooOol0@goo2P00ogoo47oo2`00ogooUWoo001QOol00`00Oomoo`13Ool:003oOol@
Ool;003oOonFOol0065oo`03001oogoo04=oo`X00?mooa1oo`/00?mooiIoo`00HGoo00<007ooOol0
@goo2P00ogoo47oo2`00ogooUWoo001QOol00`00Oomoo`13Ool:003oOol@Ool:003oOonGOol0065o
o`03001oogoo04=oo`X00?mooa1oo`X00?mooiMoo`00HGoo00<007ooOol0@goo2P00ogoo47oo2P00
ogooUgoo001QOol00`00Oomoo`13Ool9003oOolAOol:003oOonGOol0065oo`03001oogoo04=oo`H0
0?mooaAoo`X00?mooiMoo`00HGoo0`00@goo1P00ogoo57oo2P00ogooUgoo001QOol00`00Oomoo`13
Ool6003oOolDOol:003oOonGOol0065oo`03001oogoo04=oo`H00?mooaAoo`H00003Ool000000?mo
oiQoo`00HGoo00<007ooOol0@goo1P00ogoo57oo1P00ogooVgoo001QOol00`00Oomoo`13Ool6003o
OolDOol6003oOonKOol0065oo`03001oogoo04=oo`H00?mooaAoo`H00?mooi]oo`00HGoo00<007oo
Ool0@goo1P00ogoo57oo1P00ogooVgoo001QOol00`00Oomoo`13Ool6003oOolDOol6003oOonKOol0
065oo`03001oogoo04=oo`H00?mooaAoo`H00?mooi]oo`00HGoo00<007ooOol0@goo1P00ogoo57oo
1P00ogooVgoo001QOol00`00Oomoo`13Ool6003oOolEOol5003oOonKOol0065oo`03001oogoo04=o
o`H00?mooaEoo`D00?mooi]oo`00HGoo00<007ooOol0A7oo1000ogoo5Woo1@00ogooVgoo001QOol0
0`00Oomoo`14Ool4003oOolFOol5003oOonKOol001Uoo`@000ioo`<000moo`@000moo`L000Yoo`03
001oogoo04Aoo`@00?mooaIoo`D00?mooi]oo`005goo20002goo1@0037oo20003Goo1`002Woo00<0
07ooOol0A7oo1000ogoo5Woo1@00ogooVgoo000GOol20004Ool2000;Ool5000<Ool20004Ool2000@
Ool2000<Ool00`00Oomoo`14Ool4003oOolFOol5003oOonKOol001Ioo`8000Ioo`8000Yoo`D000]o
o`8000Ioo`8000moo`8000aoo`03001oogoo04Aoo`@00?mooaIoo`D00?mooi]oo`005Woo0P001Woo
0P002goo0`0037oo0P001Woo0P003goo0P0037oo00<007ooOol0AGoo0P00ogoo5goo1@00ogooVgoo
000EOol20008Ool2000HOol20008Ool20006Ool<000:Ool00`00Oomoo`3oOomNOol5003oOonKOol0
01Eoo`8000Qoo`8001Qoo`8000Qoo`8000Ioo``000Yoo`03001oogoo0?mooeioo`D00?mooi]oo`00
5Goo0P0027oo0P0067oo0P0027oo0P001Woo0P001Woo0P0000=oo`00Ool02Goo1@00ogooG7oo1@00
ogooVgoo000EOol20008Ool2000HOol20008Ool20007Ool20005Ool2000<Ool00`00Oomoo`3oOomN
Ool5003oOonKOol001Eoo`8000Qoo`8001Qoo`8000Qoo`8000Moo`<000Aoo`8000aoo`03001oogoo
0?mooeioo`D00?mooi]oo`005Goo0P0027oo0P0067oo0P0027oo0P0027oo0P0017oo0P0037oo00<0
07ooOol0ogooGWoo1@00ogooVgoo000EOol20008Ool2000HOol20008Ool20009Ool20003Ool2000<
Ool00`00Oomoo`3oOomOOol3003oOonLOol001Eoo`8000Qoo`8001Qoo`8000Qoo`8000Uoo`<0009o
o`8000aoo`03001oogoo0?mooomoooioo`005Woo0P001Woo0P006Woo0P001Woo0P002goo0P000Woo
0P0037oo00<007ooOol0ogooogoooWoo000FOol20006Ool2000JOol20006Ool2000<Ool200000goo
0000000<Ool00`00Oomoo`3oOoooOoonOol001Moo`8000Aoo`8001aoo`8000Aoo`8000ioo`@000ao
o`03001oogoo0?mooomoooioo`005goo200077oo20003Woo100037oo00<007ooOol0ogooogoooWoo
000IOol4000POol4000AOol3000<Ool00`00Oomoo`3oOoooOoonOol0065oo`03001oogoo0?mooomo
ooioo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`005Woo1P001goo30002Woo1`00
2Goo0P0000=oo`0000001@0027oo0P0000=oo`0000001@0037oo1P002Woo1@000goo100017oo3@00
0goo1@001Goo1P00ogooogoo/Goo000DOol;0004Ool<0009Ool90008Ool<0006Ool<0009Ool90006
Ool900000goo000000020004Ool=0003Ool50005Ool6003oOoooOonaOol001=oo`<000Ioo`@000Mo
o`8000ioo`<000Eoo`<000Moo`@000Ioo`<000Eoo`@000Ioo`<000Moo`<000Aoo`@000Aoo`<000Eo
o`D000]oo`8000aoo`8000Eoo`<00?mooomookAoo`004Woo0`002Goo0P001goo0P003Goo0P002Goo
0P001Woo0P002Goo0P001Goo0P002Goo0P001goo0P001goo0P0017oo0P0027oo0`002goo0P0037oo
0P0017oo0`00ogooogoo]Goo000BOol2000COol2000<Ool30009Ool30005Ool20009Ool20005Ool2
0009Ool20007Ool2000=Ool20009Ool2000;Ool2000<Ool20004Ool2003oOoooOonfOol0015oo`<0
01=oo`8000aoo`8000]oo`8000moo`<000moo`<000Moo`8000eoo`8000Uoo`8000]oo`8000aoo`80
00=oo`800?mooomookMoo`004Goo0P0057oo0P0037oo0P002goo0P0027oo2@002Goo2@0027oo0P00
3Woo0`001goo0P002goo0P0037oo0`0000=oo`000000ogooogoo^7oo000AOol2000DOol2000<Ool2
000;Ool20006Ool:0008Ool:0009Ool2000?Ool;000;Ool2000<Ool6003oOoooOonhOol0015oo`80
01Aoo`8000aoo`8000]oo`8000Eoo`@000ioo`@0011oo`80015oo`T000]oo`8000aoo`D00?mooomo
okUoo`004Goo0P0057oo0`002goo0`002Goo0`001Goo0P0027oo0P001Woo0P0027oo0P0027oo0P00
67oo0P002goo0P0037oo0P0000Aoo`0000000?mooomookQoo`004Goo0P0057oo10002goo0P002Goo
0P001Woo0P001goo0`001Woo0P001goo0`0027oo0P0067oo0P002goo0P0037oo0P000Woo0`00ogoo
ogoo]goo000BOol2000:Ool20007Ool200000goo00000004Ool20005Ool30005Ool30007Ool30005
Ool40006Ool30005Ool40004Ool=0008Ool30005Ool2000<Ool2000<Ool20004Ool3003oOoooOone
Ool0019oo`8000Yoo`8000Aoo`D0009oo`L000Ioo`T000Uoo`/000Moo`/000Aoo`d000Qoo`X000ao
o`8000aoo`8000Aoo`H00?mooomook9oo`004goo0P0027oo0`0017oo1@0017oo100027oo1`0037oo
1P0000=oo`0000002Goo1P0000=oo`00000027oo0P004Goo1P003Woo0P0037oo0P0017oo1P00ogoo
ogoo/Woo000COol40005Ool4001?Ool2000UOol2000<Ool2003oOoooOonlOol001Eoo`/004moo`80
02Eoo`8000aoo`800?mooomookaoo`005goo1P0000=oo`000000Cgoo0P009Goo0P0037oo0P00ogoo
ogoo_7oo001_Ool2000POol70009Ool5003oOoooOonlOol0095oo`L000Uoo`D00?mooomookaoo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00\
\>"], "Graphics",
  CellLabel->"From In[47]:=",
  Evaluatable->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[47]="]
}, Open  ]],

Cell["\<\
In both 'scope' pictures above the displayed pulses already contain \
a reflected part from the right end, where they are sampled. This is why \
\[Dash] you see it clearly in the animation \[Dash] the second pulse in the \
first picture is larger and has a lower baseline.\
\>", "Text"],

Cell["\<\
\tIn the next plot we see the amplitude of the crosstalk signal as \
function of time during its motion from left to right \[Dash] it is shown \
before it has reached the right end and is therefore not yet disturbed by \
reflection, because the simulated wires in this special run were more than 12 \
m long \[Dash] as it rises from zero to its steady state value (horizontal \
unit is 1\[NonBreakingSpace]ps):\
\>", "Text",
  PageBreakAbove->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P00025A000`40O003h00OogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003/Ool<000;Ool4000>Ool4000>Ool4
000>Ool4001XOol7000:Ool4000>Ool4000>Ool4000>Ool4001XOol5000=Ool4000>Ool4000>Ool4
000>Ool4001VOol6000=Ool4000>Ool4000>Ool4000>Ool40009Ool00>aoo``000Uoo`P000Yoo`P0
00Yoo`P000Yoo`P006Ioo`L000Qoo`P000Yoo`P000Yoo`P000Yoo`P006Aoo`P000Yoo`P000Yoo`P0
00Yoo`P000Yoo`P006=oo`P000Yoo`P000Yoo`P000Yoo`P000Yoo`P000Moo`00kGoo0`001Woo0P00
2Goo0P0017oo0P002Woo0P0017oo0P002Woo0P0017oo0P002Woo0P0017oo0P00JGoo0P002Woo0P00
17oo0P002Woo0P0017oo0P002Woo0P0017oo0P002Woo0P0017oo0P00I7oo0P0017oo0`002Goo0P00
17oo0P002Woo0P0017oo0P002Woo0P0017oo0P002Woo0P0017oo0P00HWoo0`0017oo0`002Goo0P00
17oo0P002Woo0P0017oo0P002Woo0P0017oo0P002Woo0P0017oo0P001goo003^Ool3000?Ool20006
Ool20008Ool20006Ool20008Ool20006Ool20008Ool20006Ool2001XOol20009Ool20006Ool20008
Ool20006Ool20008Ool20006Ool20008Ool20006Ool2001ROol20006Ool30007Ool20006Ool20008
Ool20006Ool20008Ool20006Ool20008Ool20006Ool2001POol30006Ool30007Ool20006Ool20008
Ool20006Ool20008Ool20006Ool20008Ool20006Ool20006Ool00>moo`<000ioo`8000Ioo`8000Qo
o`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8006Qoo`8000Uoo`8000Ioo`8000Qoo`8000Io
o`8000Qoo`8000Ioo`8000Qoo`8000Ioo`80065oo`8000Qoo`8000Moo`8000Ioo`8000Qoo`8000Io
o`8000Qoo`8000Ioo`8000Qoo`8000Ioo`80061oo`8000Qoo`8000Moo`8000Ioo`8000Qoo`8000Io
o`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Ioo`00l7oo0`0037oo0P0027oo0P001Woo0P0027oo
0P001Woo0P0027oo0P001Woo0P0027oo0P00Ggoo30001Woo0P0027oo0P001Woo0P0027oo0P001Woo
0P0027oo0P001Woo0P0027oo0P00H7oo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo
0P0027oo0P001Woo0P0027oo0P00Ggoo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo
0P0027oo0P001Woo0P0027oo0P001Goo003aOol3000;Ool20008Ool20006Ool20008Ool20006Ool2
0008Ool20006Ool20008Ool2001OOol<0006Ool20008Ool20006Ool20008Ool20006Ool20008Ool2
0006Ool20008Ool2001POol20008Ool20006Ool20008Ool20006Ool20008Ool20006Ool20008Ool2
0006Ool20008Ool2001OOol20008Ool20006Ool20008Ool20006Ool20008Ool20006Ool20008Ool2
0006Ool20008Ool20005Ool00?9oo`<000Yoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`80
00Ioo`8000Qoo`8005moo`8000Ioo`800003Ool007oo00Eoo`8000Qoo`8000Ioo`8000Qoo`8000Io
o`8000Qoo`8000Ioo`8000Qoo`80061oo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Io
o`8000Qoo`8000Ioo`8000Qoo`8005moo`<000Ioo`<000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Io
o`8000Qoo`8000Ioo`8000Qoo`8000Eoo`00lgoo0`002Goo0P0027oo0P001Woo0P0027oo0P001Woo
0P0027oo0P001Woo0P0027oo0P00H7oo0P001Goo0P0027oo0P0027oo0P001Woo0P0027oo0P001Woo
0P0027oo0P001Woo0P0027oo0P00H7oo0`001Woo0`001Woo0P0027oo0P001Woo0P0027oo0P001Woo
0P0027oo0P001Woo0P0027oo0P00H7oo0`0017oo0`001goo0P0027oo0P001Woo0P0027oo0P001Woo
0P0027oo0P001Woo0P0027oo0P001Goo003dOol30008Ool20008Ool20006Ool20008Ool20006Ool2
0008Ool20006Ool20008Ool2001POol30004Ool20008Ool20008Ool20006Ool20008Ool20006Ool2
0008Ool20006Ool20008Ool2001POol40004Ool30007Ool20008Ool20006Ool20008Ool20006Ool2
0008Ool20006Ool20008Ool2001QOol80008Ool20008Ool20006Ool20008Ool20006Ool20008Ool2
0006Ool20008Ool20005Ool00?Eoo`8000Qoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`80
00Ioo`8000Qoo`80065oo`8000Aoo`8000Qoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`80
00Ioo`8000Qoo`80061oo`800003Ool0000000D000Qoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`80
00Qoo`8000Ioo`8000Qoo`80065oo`P000Qoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`80
00Ioo`8000Qoo`8000Eoo`00mWoo0P001goo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P00
1Woo0P0027oo0P00HWoo0P000goo0P0027oo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P00
1Woo0P0027oo0P00HGoo00<007ooOol01@002Goo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo
0P001Woo0P0027oo0P00H7oo0`0017oo0`001goo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo
0P001Woo0P0027oo0P001Goo003fOol20007Ool20008Ool20006Ool20008Ool20006Ool20008Ool2
0006Ool20008Ool2001ROol30002Ool20008Ool20008Ool20006Ool20008Ool20006Ool20008Ool2
0006Ool20008Ool2001QOol2000?Ool20008Ool20006Ool20008Ool20006Ool20008Ool20006Ool2
0008Ool2001OOol20008Ool20006Ool20008Ool20006Ool20008Ool20006Ool20008Ool20006Ool2
0008Ool20005Ool00>eoo`8000Moo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`80
00Qoo`8000Ioo`8006Aoo`80009oo`8000Uoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`80
00Qoo`8000Ioo`80069oo`<000moo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`80
00Ioo`80061oo`8000Qoo`8000Moo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`80
00Ioo`8000Ioo`00kGoo0`001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P00
27oo0P001Woo0P00IGoo0P0000=oo`0000002Goo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo
0P0027oo0P001Woo0P00Hgoo0`003Woo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo
0P001Woo0P00H7oo0P0027oo0P001goo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo
0P001Woo0P001Woo003]Ool40004Ool2000:Ool20004Ool2000:Ool20004Ool2000:Ool20004Ool2
000:Ool20004Ool2001WOol4000:Ool20004Ool2000:Ool20004Ool2000:Ool20004Ool2000:Ool2
0004Ool2001UOol3000>Ool20004Ool2000:Ool20004Ool2000:Ool20004Ool2000:Ool20004Ool2
001ROol30004Ool40008Ool20004Ool2000:Ool20004Ool2000:Ool20004Ool2000:Ool20004Ool2
0007Ool00>ioo`P000]oo`P000Yoo`P000Yoo`P000Yoo`P006Moo`@000Yoo`P000Yoo`P000Yoo`P0
00Yoo`P006Ioo`P000Qoo`P000Yoo`P000Yoo`P000Yoo`P0069oo`X000Uoo`P000Yoo`P000Yoo`P0
00Yoo`P000Moo`00l7oo1@003Woo10003Woo10003Woo10003Woo1000JWoo0`0037oo10003Woo1000
3Woo10003Woo1000JWoo1P002Woo10003Woo10003Woo10003Woo1000IWoo1P003Goo10003Woo1000
3Woo10003Woo10002Goo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo001S
Ool00`00Oomoo`3oOoooOoolOol006=oo`03001oogoo0?mooomoooaoo`00Hgoo00<007ooOol0ogoo
ogooo7oo001SOol00`00Oomoo`3oOoooOoolOol006=oo`03001oogoo0?mooomoooaoo`00Hgoo00<0
07ooOol0ogooogooo7oo001SOol00`00Oomoo`3oOoooOoolOol006=oo`03001oogoo0?mooomoooao
o`00HGoo1@00ogooogooo7oo001POol7003oOoooOookOol0061oo`P00?mooomoooYoo`00DGooo`00
o`00m@0077oo001POol:000VOol00`00Oomoo`0ZOol00`00Oomoo`0ZOol00`00Oomoo`0ZOol00`00
Oomoo`0YOol00`00Oomoo`0ZOol00`00Oomoo`0ZOol00`00Oomoo`0ZOol00`00Oomoo`0ZOol00`00
Oomoo`0ZOol00`00Oomoo`0ZOol00`00Oomoo`0ZOol00`00Oomoo`0ZOol00`00Oomoo`0ZOol00`00
Oomoo`0ZOol00`00Oomoo`0YOol00`00Oomoo`0/Ool0065oo`X002Eoo`03001oogoo02Yoo`03001o
ogoo02Yoo`03001oogoo02Yoo`03001oogoo02Uoo`03001oogoo02Yoo`03001oogoo02Yoo`03001o
ogoo02Yoo`03001oogoo02Yoo`03001oogoo02Yoo`03001oogoo02Yoo`03001oogoo02Yoo`03001o
ogoo02Yoo`03001oogoo02Yoo`03001oogoo02Yoo`03001oogoo02Uoo`03001oogoo02aoo`00HWoo
2P0097oo00<007ooOol0:Woo00<007ooOol0:Woo00<007ooOol0:Woo00<007ooOol0:Goo00<007oo
Ool0:Woo00<007ooOol0:Woo00<007ooOol0:Woo00<007ooOol0:Woo00<007ooOol0:Woo00<007oo
Ool0:Woo00<007ooOol0:Woo00<007ooOol0:Woo00<007ooOol0:Woo00<007ooOol0:Woo00<007oo
Ool0:Goo00<007ooOol0;7oo001SOol:002ZOol00`00Oomoo`2`Ool00`00Oomoo`2aOol00`00Oomo
o`2`Ool00`00Oomoo`0/Ool006=oo`/00?mooomoooAoo`00Hgoo00<007oo00002@00ogooogoolgoo
001SOol00`00Oomoo`09003oOoooOoocOol006=oo`04001oogooOol9003oOoooOoobOol006=oo`03
001oogoo009oo`T00?mooomooo5oo`00Hgoo00<007ooOol00goo2@00ogooogool7oo001SOol00`00
Oomoo`03Ool:003oOoooOoo_Ool006=oo`@000=oo`X00?mooomoonioo`00Hgoo00<007ooOol01Goo
2P00ogooogookGoo001SOol00`00Oomoo`06Ool9003oOoooOoo]Ool006=oo`03001oogoo00Moo`T0
0?mooomoonaoo`00Hgoo00<007ooOol027oo2@00ogooogoojgoo001SOol00`00Oomoo`09Ool9003o
OoooOooZOol006=oo`03001oogoo00Uoo`X00?mooomoonUoo`00Hgoo00<007ooOol02Woo2P00ogoo
ogooj7oo001SOol00`00Oomoo`0;Ool9003oOoooOooXOol006=oo`03001oogoo00aoo`T00?mooomo
onMoo`00Hgoo00<007ooOol03Goo2@00ogooogooiWoo001SOol00`00Oomoo`0>Ool9003oOoooOooU
Ool006=oo`@000eoo`X00?mooomoonAoo`00Hgoo00<007ooOol03goo2P00ogooogoohgoo001SOol0
0`00Oomoo`0@Ool:003oOoooOooROol006=oo`03001oogoo015oo`T00?mooomoon9oo`00Hgoo00<0
07ooOol04Woo2@00ogooogoohGoo001SOol00`00Oomoo`0COol9003oOoooOooPOol006=oo`03001o
ogoo01Aoo`T00?mooomoommoo`00Hgoo00<007ooOol057oo2P00ogooogoogWoo001SOol00`00Oomo
o`0EOol:003oOoooOooMOol006=oo`03001oogoo01Ioo`T00?mooomoomeoo`00Hgoo00<007ooOol0
5goo2@00ogooogoog7oo001SOol00`00Oomoo`0HOol9003oOoooOooKOol006=oo`@001Qoo`T00?mo
oomoomYoo`00Hgoo00<007ooOol06Goo2P00ogooogoofGoo001SOol00`00Oomoo`0JOol:003oOooo
OooHOol006=oo`03001oogoo01]oo`X00?mooomoomMoo`00Hgoo00<007ooOol077oo2P00ogooogoo
eWoo001SOol00`00Oomoo`0MOol9003oOoooOooFOol006=oo`03001oogoo01ioo`T00?mooomoomEo
o`00Hgoo00<007ooOol07goo2@00ogooogooe7oo001SOol00`00Oomoo`0OOol:003oOoooOooCOol0
06=oo`03001oogoo021oo`X00?mooomoom9oo`00Hgoo00<007ooOol08Goo2P00ogooogoodGoo001S
Ool00`00Oomoo`0ROol:003oOoooOoo@Ool006=oo`@0029oo`T00?mooomoom1oo`00Hgoo00<007oo
Ool097oo2@00ogooogoocgoo001SOol00`00Oomoo`0UOol9003oOoooOoo>Ool006=oo`03001oogoo
02Ioo`T00?mooomooleoo`00Hgoo00<007ooOol09Woo2P00ogooogooc7oo0007Ool4000>Ool3000?
Ool40009Ool<0009Ool6000@Ool00`00Oomoo`0WOol:003oOoooOoo;Ool000Eoo`P000]oo`D000ao
o`P000Moo``000Moo`X000ioo`03001oogoo02Qoo`X00?mooomoolYoo`001Goo0P0017oo0P002goo
1@0037oo0P0017oo0P0027oo0`001Woo0P001goo0`001Goo0`003Goo00<007ooOol0:Goo2P00ogoo
ogoobGoo0004Ool20006Ool2000:Ool5000;Ool20006Ool20008Ool3000GOol2000=Ool00`00Oomo
o`0ZOol9003oOoooOoo9Ool000Aoo`8000Ioo`8000]oo`<000aoo`8000Ioo`8000Uoo`<001Moo`80
00aoo`03001oogoo02]oo`T00?mooomoolQoo`000goo0P0027oo0P0067oo0P0027oo0P002Goo0`00
5Woo0P0037oo00<007ooOol0;7oo2@00ogooogooagoo0003Ool20008Ool2000HOol20008Ool2000:
Ool3000EOol2000<Ool00`00Oomoo`0/Ool:003oOoooOoo6Ool000=oo`8000Qoo`8001Qoo`8000Qo
o`8000]oo`<001Aoo`8000aoo`H002Yoo`X00?mooomoolEoo`000goo0P0027oo0P0067oo0P0027oo
0P0037oo0`004goo0P0037oo00<007ooOol0;Woo2P00ogooogooa7oo0003Ool20008Ool2000HOol2
0008Ool2000=Ool3000AOol2000=Ool00`00Oomoo`0_Ool:003oOoooOoo3Ool000=oo`8000Qoo`80
01Qoo`8000Qoo`8000ioo`8000Uoo`8000Eoo`<000eoo`03001oogoo031oo`X00?mooomool9oo`00
0goo0P0027oo0P0067oo0P0027oo0P003goo0P0027oo2@003Woo00<007ooOol0<Goo2@00ogooogoo
`Woo0003Ool20008Ool2000HOol20008Ool2000?Ool20008Ool200000goo00000003000?Ool00`00
Oomoo`0bOol9003oOoooOoo1Ool000Aoo`8000Ioo`8001Yoo`8000Ioo`8000Moo`8000Moo`8000Qo
o`8001Eoo`03001oogoo03=oo`T00?mooomool1oo`0017oo0P001Woo0P006Woo0P001Woo0P001goo
0`001Woo0P0027oo0P005Goo00<007ooOol0<goo2P00ogooogoo_goo0005Ool20004Ool2000LOol2
0004Ool20008Ool40004Ool20009Ool2000EOol00`00Oomoo`0dOol:003oOoooOonnOol000Eoo`P0
01aoo`P000Uoo`P000Yoo`X000eoo`03001oogoo03Eoo`X00?mooomookeoo`001goo100087oo1000
3Goo1@002goo2P003Goo00<007ooOol0=Woo2P00ogooogoo_7oo001SOol00`00Oomoo`0gOol:003o
OoooOonkOol006=oo`@003Moo`X00?mooomookYoo`00Hgoo00<007ooOol0>Goo2@00ogooogoo^Woo
001SOol00`00Oomoo`0jOol9003oOoooOoniOol006=oo`03001oogoo03]oo`T00?mooomookQoo`00
Hgoo00<007ooOol0?7oo2@00ogooogoo]goo001SOol00`00Oomoo`0lOol:003oOoooOonfOol006=o
o`03001oogoo03eoo`X00?mooomookEoo`00Hgoo00<007ooOol0?Woo2P00ogooogoo]7oo001SOol0
0`00Oomoo`0oOol:003oOoooOoncOol006=oo`03001oogoo041oo`X00?mooomook9oo`00Hgoo00<0
07ooOol0@Goo2P00ogooogoo/Goo001SOol00`00Oomoo`12Ool9003oOoooOonaOol006=oo`@0049o
o`T00?mooomook1oo`00Hgoo00<007ooOol0@goo2P00ogooogoo[goo001SOol00`00Oomoo`14Ool:
003oOoooOon^Ool006=oo`03001oogoo04Eoo`X00?mooomoojeoo`00Hgoo00<007ooOol0AWoo2P00
ogooogoo[7oo001SOol00`00Oomoo`17Ool:003oOoooOon[Ool006=oo`03001oogoo04Qoo`X00?mo
oomoojYoo`00Hgoo00<007ooOol0BGoo2P00ogooogooZGoo001SOol00`00Oomoo`1:Ool:003oOooo
OonXOol006=oo`03001oogoo04]oo`X00?mooomoojMoo`00Hgoo00<007ooOol0C7oo2@00ogooogoo
Ygoo001SOol00`00Oomoo`1=Ool9003oOoooOonVOol006=oo`@004eoo`T00?mooomoojEoo`00Hgoo
00<007ooOol0Cgoo2@00ogooogooY7oo001SOol00`00Oomoo`1?Ool:003oOoooOonSOol006=oo`03
001oogoo051oo`X00?mooomooj9oo`00Hgoo00<007ooOol0DGoo2P00ogooogooXGoo001SOol00`00
Oomoo`1BOol:003oOoooOonPOol006=oo`03001oogoo05=oo`X00?mooomooimoo`00Hgoo00<007oo
Ool0E7oo2P00ogooogooWWoo001SOol00`00Oomoo`1EOol:003oOoooOonMOol006=oo`03001oogoo
05Ioo`X00?mooomooiaoo`00Hgoo00<007ooOol0Egoo2P00ogooogooVgoo001SOol00`00Oomoo`1H
Ool:003oOoooOonJOol006=oo`@005Qoo`T00?mooomooiYoo`00Hgoo00<007ooOol0FWoo2@00ogoo
ogooVGoo001SOol00`00Oomoo`1KOol9003oOoooOonHOol006=oo`03001oogoo05]oo`X00?mooomo
oiMoo`00Hgoo00<007ooOol0G7oo2P00ogooogooUWoo000IOol4000>Ool3000?Ool4000<Ool6000@
Ool00`00Oomoo`1MOol:003oOoooOonEOol001Moo`P000]oo`D000aoo`P000Qoo`X000ioo`03001o
ogoo05ioo`X00?mooomooiAoo`005goo0P0017oo0P002goo1@0037oo0P0017oo0P0027oo0`001Goo
0`003Goo00<007ooOol0Ggoo2P00ogooogooTgoo000FOol20006Ool2000:Ool5000;Ool20006Ool2
000@Ool2000=Ool00`00Oomoo`1POol:003oOoooOonBOol001Ioo`8000Ioo`8000]oo`<000aoo`80
00Ioo`80015oo`8000aoo`03001oogoo065oo`X00?mooomooi5oo`005Goo0P0027oo0P0067oo0P00
27oo0P0047oo0P0037oo00<007ooOol0HWoo2P00ogooogooT7oo000EOol20008Ool2000HOol20008
Ool2000@Ool2000<Ool00`00Oomoo`1SOol:003oOoooOon?Ool001Eoo`8000Qoo`8001Qoo`8000Qo
o`80011oo`8000aoo`H0065oo`X00?mooomoohioo`005Goo0P0027oo0P0067oo0P0027oo0P0047oo
0P0037oo00<007ooOol0IGoo2P00ogooogooSGoo000EOol20008Ool2000HOol20008Ool2000?Ool2
000=Ool00`00Oomoo`1VOol:003oOoooOon<Ool001Eoo`8000Qoo`8001Qoo`8000Qoo`8000Moo`80
00Eoo`<000eoo`03001oogoo06Moo`X00?mooomooh]oo`005Goo0P0027oo0P0067oo0P0027oo0P00
1goo2@003Woo00<007ooOol0J7oo2P00ogooogooRWoo000EOol20008Ool2000HOol20008Ool20007
Ool200000goo00000003000?Ool00`00Oomoo`1YOol:003oOoooOon9Ool001Ioo`8000Ioo`8001Yo
o`8000Ioo`8000Qoo`8001Eoo`03001oogoo06Yoo`X00?mooomoohQoo`005Woo0P001Woo0P006Woo
0P001Woo0P0027oo0P005Goo00<007ooOol0Jgoo2P00ogooogooQgoo000GOol20004Ool2000LOol2
0004Ool20009Ool2000EOol00`00Oomoo`1/Ool:003oOoooOon6Ool001Moo`P001aoo`P000Uoo`X0
00eoo`03001oogoo06eoo`X00?mooomoohEoo`006Goo100087oo10002goo2P003Goo00<007ooOol0
KWoo2P00ogooogooQ7oo001SOol00`00Oomoo`1_Ool:003oOoooOon3Ool006=oo`@006ioo`X00?mo
oomooh=oo`00Hgoo00<007ooOol0L7oo2P00ogooogooPWoo001SOol00`00Oomoo`1aOol:003oOooo
Oon1Ool006=oo`03001oogoo079oo`X00?mooomooh1oo`00Hgoo00<007ooOol0Lgoo2P00ogooogoo
Ogoo001SOol00`00Oomoo`1dOol:003oOoooOomnOol006=oo`03001oogoo07Eoo`X00?mooomoogeo
o`00Hgoo00<007ooOol0MWoo2P00ogooogooO7oo001SOol00`00Oomoo`1gOol:003oOoooOomkOol0
06=oo`03001oogoo07Qoo`X00?mooomoogYoo`00Hgoo00<007ooOol0NGoo2P00ogooogooNGoo001S
Ool00`00Oomoo`1jOol:003oOoooOomhOol006=oo`@007Yoo`X00?mooomoogMoo`00Hgoo00<007oo
Ool0O7oo2P00ogooogooMWoo001SOol00`00Oomoo`1mOol:003oOoooOomeOol006=oo`03001oogoo
07ioo`X00?mooomoogAoo`00Hgoo00<007ooOol0Ogoo2P00ogooogooLgoo001SOol00`00Oomoo`20
Ool:003oOoooOombOol006=oo`03001oogoo085oo`X00?mooomoog5oo`00Hgoo00<007ooOol0PWoo
2`00ogooogooKgoo001SOol00`00Oomoo`23Ool;003oOoooOom^Ool006=oo`03001oogoo08Aoo`/0
0?mooomoofeoo`00Hgoo00<007ooOol0QGoo2`00ogooogooK7oo001SOol00`00Oomoo`26Ool;003o
OoooOom[Ool006=oo`@008Ioo`/00?mooomoofYoo`00Hgoo00<007ooOol0R7oo2`00ogooogooJGoo
001SOol00`00Oomoo`29Ool;003oOoooOomXOol006=oo`03001oogoo08Yoo`/00?mooomoofMoo`00
Hgoo00<007ooOol0Rgoo2`00ogooogooIWoo001SOol00`00Oomoo`2<Ool;003oOoooOomUOol006=o
o`03001oogoo08eoo`/00?mooomoofAoo`00Hgoo00<007ooOol0SWoo2`00ogooogooHgoo001SOol0
0`00Oomoo`2@Ool:003oOoooOomROol006=oo`03001oogoo095oo`X00?mooomoof5oo`00Hgoo00<0
07ooOol0TWoo2P00ogooogooH7oo001SOol00`00Oomoo`2COol:003oOoooOomOOol006=oo`@009=o
o`X00?mooomooeioo`00Hgoo00<007ooOol0UGoo2P00ogooogooGGoo001SOol00`00Oomoo`2FOol:
003oOoooOomLOol006=oo`03001oogoo09Moo`X00?mooomooe]oo`00Hgoo00<007ooOol0V7oo2P00
ogooogooFWoo0007Ool4000>Ool3000?Ool4000>Ool3000=Ool6000@Ool00`00Oomoo`2IOol:003o
OoooOomIOol000Eoo`P000]oo`D000aoo`P000aoo`<000]oo`X000ioo`03001oogoo09Yoo`X00?mo
oomooeQoo`001Goo0P0017oo0P002goo1@0037oo0P0017oo0P003Goo0P002goo0`001Goo0`003Goo
00<007ooOol0Vgoo2P00ogooogooEgoo0004Ool20006Ool2000:Ool5000;Ool20006Ool2000<Ool3
000COol2000=Ool00`00Oomoo`2LOol;003oOoooOomEOol000Aoo`8000Ioo`8000]oo`<000aoo`80
00Ioo`8000aoo`<001Aoo`8000aoo`03001oogoo09eoo`/00?mooomooeAoo`000goo0P0027oo0P00
67oo0P0027oo0P0037oo0P0057oo0P0037oo00<007ooOol0WWoo2`00ogooogooDgoo0003Ool20008
Ool2000HOol20008Ool2000<Ool3000COol2000<Ool00`00Oomoo`2OOol;003oOoooOomBOol000=o
o`8000Qoo`8001Qoo`8000Qoo`8000eoo`8001=oo`8000aoo`H009eoo`/00?mooomooe5oo`000goo
0P0027oo0P0067oo0P0027oo0P003Goo0P004goo0P0037oo00<007ooOol0XGoo2`00ogooogooD7oo
0003Ool20008Ool2000HOol20008Ool2000=Ool3000AOol2000=Ool00`00Oomoo`2ROol;003oOooo
Oom?Ool000=oo`8000Qoo`8001Qoo`8000Qoo`8000ioo`8000Uoo`8000Eoo`<000eoo`03001oogoo
0:Aoo`X00?mooomoodioo`000goo0P0027oo0P0067oo0P0027oo0P003Woo0P002Goo2@003Woo00<0
07ooOol0YGoo2P00ogooogooCGoo0003Ool20008Ool2000HOol20008Ool2000?Ool20008Ool20000
0goo00000003000?Ool00`00Oomoo`2VOol:003oOoooOom<Ool000Aoo`8000Ioo`8001Yoo`8000Io
o`80011oo`8000Qoo`8001Eoo`03001oogoo0:Moo`X00?mooomood]oo`0017oo0P001Woo0P006Woo
0P001Woo0P001goo0P001goo0P0027oo0P005Goo00<007ooOol0Z7oo2`00ogooogooBGoo0005Ool2
0004Ool2000LOol20004Ool20008Ool20008Ool20007Ool2000EOol00`00Oomoo`2YOol;003oOooo
Oom8Ool000Eoo`P001aoo`P000Qoo``000Moo`X000eoo`03001oogoo0:Yoo`/00?mooomoodMoo`00
1goo100087oo10002Woo30001goo2P003Goo00<007ooOol0Zgoo2`00ogooogooAWoo001SOol00`00
Oomoo`2/Ool;003oOoooOom5Ool006=oo`@00:aoo`/00?mooomoodAoo`00Hgoo00<007ooOol0[Woo
2`00ogooogoo@goo001SOol00`00Oomoo`2_Ool;003oOoooOom2Ool006=oo`03001oogoo0;5oo`X0
0?mooomood5oo`00Hgoo00<007ooOol0/Woo2P00ogooogoo@7oo001SOol00`00Oomoo`2cOol;003o
OoooOolnOol006=oo`03001oogoo0;Aoo`/00?mooomooceoo`00Hgoo00<007ooOol0]Goo2`00ogoo
ogoo?7oo001SOol00`00Oomoo`2fOol;003oOoooOolkOol006=oo`03001oogoo0;Moo`/00?mooomo
ocYoo`00Hgoo00<007ooOol0^7oo2`00ogooogoo>Goo001SOol00`00Oomoo`2jOol:003oOoooOolh
Ool006=oo`@00;Yoo`/00?mooomoocIoo`00Hgoo00<007ooOol0_7oo2`00ogooogoo=Goo001SOol0
0`00Oomoo`2mOol;003oOoooOoldOol006=oo`03001oogoo0;ioo`/00?mooomooc=oo`00Hgoo00<0
07ooOol0_goo2`00ogooogoo<Woo001SOol00`00Oomoo`30Ool;003oOoooOolaOol006=oo`03001o
ogoo0<5oo`/00?mooomooc1oo`00Hgoo00<007ooOol0`goo2P00ogooogoo;goo001SOol00`00Oomo
o`34Ool;003oOoooOol]Ool006=oo`03001oogoo0<Eoo`/00?mooomoobaoo`00Hgoo00<007ooOol0
aWoo2`00ogooogoo:goo001SOol00`00Oomoo`37Ool;003oOoooOolZOol006=oo`03001oogoo0<Qo
o`/00?mooomoobUoo`00Hgoo1000b7oo3000ogooogoo9goo001SOol00`00Oomoo`3;Ool;003oOooo
OolVOol006=oo`03001oogoo0<aoo`/00?mooomoobEoo`00Hgoo00<007ooOol0cGoo2`00ogooogoo
97oo001SOol00`00Oomoo`3>Ool;003oOoooOolSOol006=oo`03001oogoo0<moo`/00?mooomoob9o
o`00Hgoo00<007ooOol0d7oo3000ogooogoo87oo001SOol00`00Oomoo`3BOol;003oOoooOolOOol0
06=oo`03001oogoo0==oo`/00?mooomooaioo`00Hgoo00<007ooOol0e7oo2`00ogooogoo7Goo001S
Ool00`00Oomoo`3EOol<003oOoooOolKOol006=oo`03001oogoo0=Moo`/00?mooomooaYoo`00Hgoo
1000egoo2`00ogooogoo6Goo001SOol00`00Oomoo`3IOol;003oOoooOolHOol006=oo`03001oogoo
0=Yoo`/00?mooomooaMoo`00Hgoo00<007ooOol0fgoo3000ogooogoo5Goo001SOol00`00Oomoo`3L
Ool<003oOoooOolDOol002]oo`@000ioo`<000aoo`X000eoo`03001oogoo0=ioo`/00?mooomooa=o
o`00:Goo20002goo1@002goo2P003Goo00<007ooOol0ggoo2`00ogooogoo4Woo000YOol20004Ool2
000;Ool5000?Ool2000AOol00`00Oomoo`3POol<003oOoooOol@Ool002Qoo`8000Ioo`8000Yoo`D0
00moo`80015oo`03001oogoo0>5oo``00?mooomoo`moo`00:7oo0P001Woo0P002goo0`0047oo0P00
4Goo00<007ooOol0hgoo2`00ogooogoo3Woo000WOol20008Ool2000MOol2000AOol00`00Oomoo`3T
Ool;003oOoooOol=Ool002Moo`8000Qoo`8001eoo`80015oo`03001oogoo0>Eoo``00?mooomoo`]o
o`009goo0P0027oo0P007Goo0P004Goo1P00hgoo3000ogooogoo2Woo000WOol20008Ool2000MOol2
000AOol00`00Oomoo`3XOol;003oOoooOol9Ool002Moo`8000Qoo`8001eoo`80015oo`03001oogoo
0>Uoo`/00?mooomoo`Qoo`009goo0P0027oo0P007Goo0P004Goo00<007ooOol0jWoo3000ogooogoo
1Woo000WOol20008Ool2000MOol2000AOol00`00Oomoo`3[Ool<003oOoooOol5Ool002Moo`8000Qo
o`8001eoo`80015oo`03001oogoo0>eoo`/00?mooomoo`Aoo`00:7oo0P001Woo0P007Woo0P004Goo
00<007ooOol0kWoo3000ogooogoo0Woo000XOol20006Ool2000NOol2000AOol00`00Oomoo`3_Ool<
003oOoooOol1Ool002Uoo`8000Aoo`8001]oo`<00003Ool00000015oo`03001oogoo0?1oo``00?mo
oomoo`00:Goo20006goo1P004Goo00<007ooOol0lWoo2`00ogoooWoo000[Ool4000POol3000AOol0
0`00Oomoo`3cOol<003oOoolOol006=oo`03001oogoo0?Aoo``00?mooo]oo`00Hgoo1000m7oo3000
ogoonWoo001SOol00`00Oomoo`3gOol<003oOoohOol006=oo`03001oogoo0?Qoo``00?moooMoo`00
Hgoo00<007ooOol0nGoo3000ogoomWoo001SOol00`00Oomoo`3kOol<003oOoodOol006=oo`03001o
ogoo0?aoo``00?mooo=oo`00Hgoo00<007ooOol0oGoo3000ogoolWoo001SOol00`00Oomoo`3nOol=
003oOoo`Ool006=oo`03001oogoo0?moo`5oo``00?moonmoo`00Hgoo00<007ooOol0ogoo0Woo3000
ogookWoo001SOol00`00Oomoo`3oOol3Ool=003oOoo/Ool006=oo`03001oogoo0?moo`Eoo``00?mo
on]oo`00Hgoo1000ogoo1Goo3000ogoojWoo001SOol00`00Oomoo`3oOol8Ool<003oOooXOol006=o
o`03001oogoo0?moo`Uoo``00?moonMoo`00Hgoo00<007ooOol0ogoo2Woo3000ogooiWoo001SOol0
0`00Oomoo`3oOol<Ool<003oOooTOol006=oo`03001oogoo0?moo`eoo``00?moon=oo`00Hgoo00<0
07ooOol0ogoo3Woo3@00ogoohGoo001SOol00`00Oomoo`3oOol@Ool<003oOooPOol006=oo`03001o
ogoo0?mooa5oo``00?moommoo`00Hgoo00<007ooOol0ogoo4Woo3@00ogoogGoo001SOol00`00Oomo
o`3oOolDOol<003oOooLOol006=oo`03001oogoo0?mooaEoo`d00?moomYoo`00Hgoo1000ogoo5Woo
3000ogoofGoo001SOol00`00Oomoo`3oOolHOol=003oOooGOol006=oo`03001oogoo0?mooaUoo`d0
0?moomIoo`00Hgoo00<007ooOol0ogoo6goo3000ogooeGoo001SOol00`00Oomoo`3oOolLOol=003o
OooCOol006=oo`03001oogoo0?mooaioo``00?moom9oo`00Hgoo00<007ooOol0ogoo7goo3@00ogoo
d7oo001SOol00`00Oomoo`3oOolPOol=003oOoo?Ool006=oo`03001oogoo0?moob9oo`d00?mooleo
o`00Hgoo00<007ooOol0ogoo8goo3@00ogooc7oo001SOol00`00Oomoo`3oOolUOol=003oOoo:Ool0
06=oo`03001oogoo0?moobIoo`d00?moolUoo`00Hgoo1000ogoo9goo3@00ogooagoo001SOol00`00
Oomoo`3oOolYOol=003oOoo6Ool006=oo`03001oogoo0?moobYoo`h00?moolAoo`00Hgoo00<007oo
Ool0ogoo;7oo3@00ogoo`goo001SOol00`00Oomoo`3oOol]Ool>003oOoo1Ool000Moo`@000ioo`<0
00aoo`X000Ioo``000Uoo`H0011oo`03001oogoo0?moobmoo`d00?mool1oo`001Goo20002goo1@00
2goo2P001Woo30001goo2P003Woo00<007ooOol0ogoo<7oo3P00ogoo_Woo0005Ool20004Ool2000;
Ool5000?Ool2000;Ool30006Ool20007Ool30005Ool3000=Ool00`00Oomoo`3oOolbOol=003oOonm
Ool000Aoo`8000Ioo`8000Yoo`D000moo`8000aoo`<001Moo`8000eoo`03001oogoo0?mooc=oo`h0
0?mook]oo`0017oo0P001Woo0P002goo0`0047oo0P003Goo0`005goo0P0037oo00<007ooOol0ogoo
=Goo3@00ogoo^Woo0003Ool20008Ool2000MOol2000>Ool3000FOol2000<Ool00`00Oomoo`3oOolf
Ool>003oOonhOol000=oo`8000Qoo`8001eoo`8000moo`<001Eoo`8000aoo`03001oogoo0?moocQo
o`d00?mookMoo`000goo0P0027oo0P007Goo0P0047oo0`0057oo0P0037oo1P00ogoo=Woo3P00ogoo
]Goo0003Ool20008Ool2000MOol2000AOol3000COol2000<Ool00`00Oomoo`3oOolkOol=003oOond
Ool000=oo`8000Qoo`8001eoo`80019oo`<0015oo`8000eoo`03001oogoo0?moocaoo`h00?mook9o
o`000goo0P0027oo0P007Goo0P004goo0P002Goo0P001Goo0`003Goo00<007ooOol0ogoo?Woo3P00
ogoo/7oo0003Ool20008Ool2000MOol2000DOol20008Ool9000>Ool00`00Oomoo`3oOom0Ool=003o
Oon_Ool000=oo`8000Qoo`8001eoo`8001Aoo`8000Qoo`800003Ool0000000<000moo`03001oogoo
0?mood5oo`h00?moojeoo`0017oo0P001Woo0P007Woo0P002goo0P001goo0P0027oo0P005Goo00<0
07ooOol0ogoo@goo3@00ogoo[7oo0004Ool20006Ool2000NOol2000;Ool30006Ool20008Ool2000E
Ool00`00Oomoo`3oOom4Ool>003oOonZOol000Eoo`8000Aoo`8001]oo`<00003Ool0000000]oo`@0
00Aoo`8000Uoo`8001Eoo`03001oogoo0?moodIoo`h00?moojQoo`001Goo20006goo1P0037oo2000
2Woo2P003Goo00<007ooOol0ogooAgoo3P00ogooYgoo0007Ool4000POol3000>Ool5000;Ool:000=
Ool00`00Oomoo`3oOom9Ool>003oOonUOol006=oo`03001oogoo0?mood]oo`d00?moojAoo`00Hgoo
1000ogooBgoo3P00ogooXWoo001SOol00`00Oomoo`3oOom>Ool>003oOonPOol006=oo`03001oogoo
0?moodmoo`h00?mooimoo`00Hgoo00<007ooOol0ogooDGoo3P00ogooWGoo001SOol00`00Oomoo`3o
OomCOol>003oOonKOol006=oo`03001oogoo0?mooeAoo`h00?mooiYoo`00Hgoo00<007ooOol0ogoo
EWoo3P00ogooV7oo001SOol00`00Oomoo`3oOomHOol>003oOonFOol006=oo`03001oogoo0?mooeUo
o`l00?mooiAoo`00Hgoo00<007ooOol0ogooFgoo3P00ogooTgoo001SOol00`00Oomoo`3oOomLOol?
003oOonAOol006=oo`03001oogoo0?mooeioo`l00?moohmoo`00Hgoo1000ogooGgoo3`00ogooSGoo
001SOol00`00Oomoo`3oOomROol>003oOon<Ool006=oo`03001oogoo0?moof=oo`l00?moohYoo`00
Hgoo00<007ooOol0ogooIGoo3`00ogooR7oo001SOol00`00Oomoo`3oOomWOol>003oOon7Ool006=o
o`03001oogoo0?moofQoo`l00?moohEoo`00Hgoo00<007ooOol0ogooJWoo3`00ogooPgoo001SOol0
0`00Oomoo`3oOom/Ool?003oOon1Ool006=oo`03001oogoo0?moofioo`l00?moogmoo`00Hgoo00<0
07ooOol0ogooKgoo3`00ogooOWoo001SOol00`00Oomoo`3oOomaOol?003oOomlOol006=oo`03001o
ogoo0?moog=oo`l00?moogYoo`00Hgoo1000ogooM7oo3`00ogooN7oo001SOol00`00Oomoo`3oOomg
Ool?003oOomfOol006=oo`03001oogoo0?moogQooa000?moogAoo`00Hgoo00<007ooOol0ogooNWoo
4000ogooLWoo001SOol00`00Oomoo`3oOomlOol@003oOom`Ool006=oo`03001oogoo0?moogioo`l0
0?moofmoo`00Hgoo00<007ooOol0ogooP7oo3`00ogooKGoo001SOol00`00Oomoo`3oOon2Ool?003o
Oom[Ool006=oo`03001oogoo0?mooh=ooa000?moofUoo`00Hgoo00<007ooOol0ogooQGoo4000ogoo
Igoo001SOol00`00Oomoo`3oOon7Ool@003oOomUOol006=oo`03001oogoo0?moohUooa000?moof=o
o`00Hgoo1000ogooRWoo4000ogooHGoo001SOol00`00Oomoo`3oOon=Ool@003oOomOOol006=oo`03
001oogoo0?moohmooa000?mooeeoo`00Hgoo00<007ooOol0ogooTGoo4000ogooFgoo001SOol00`00
Oomoo`3oOonCOol@003oOomIOol001Uoo`@000ioo`<000aoo`X000Uoo`H0011oo`03001oogoo0?mo
oiEooa000?mooeMoo`005goo20002goo1@002goo2P001goo2P003Woo00<007ooOol0ogooUgoo4000
ogooEGoo000GOol20004Ool2000;Ool5000?Ool2000;Ool30005Ool3000=Ool00`00Oomoo`3oOonI
Ool@003oOomCOol001Ioo`8000Ioo`8000Yoo`D000moo`8001Aoo`8000eoo`03001oogoo0?mooi]o
oa000?mooe5oo`005Woo0P001Woo0P002goo0`0047oo0P005Goo0P0037oo00<007ooOol0ogooWGoo
4@00ogooCWoo000EOol20008Ool2000MOol2000EOol2000<Ool00`00Oomoo`3oOonOOolA003oOom<
Ool001Eoo`8000Qoo`8001eoo`8001Eoo`8000aoo`03001oogoo0?mooj5ooa400?moodYoo`005Goo
0P0027oo0P007Goo0P005Goo0P0037oo1P00ogooX7oo4@00ogooB7oo000EOol20008Ool2000MOol2
000EOol2000<Ool00`00Oomoo`3oOonUOolA003oOom6Ool001Eoo`8000Qoo`8001eoo`8001Aoo`80
00eoo`03001oogoo0?moojMooa400?moodAoo`005Goo0P0027oo0P007Goo0P0037oo0P001Goo0`00
3Goo00<007ooOol0ogooZGoo4P00ogoo@Goo000EOol20008Ool2000MOol2000<Ool9000>Ool00`00
Oomoo`3oOon[OolB003oOoloOol001Eoo`8000Qoo`8001eoo`8000aoo`800003Ool0000000<000mo
o`03001oogoo0?moojeooa800?mooceoo`005Woo0P001Woo0P007Woo0P0037oo0P005Goo00<007oo
Ool0ogoo/7oo4@00ogoo>goo000FOol20006Ool2000NOol2000<Ool2000EOol00`00Oomoo`3oOonb
OolB003oOolhOol001Moo`8000Aoo`8001]oo`<00003Ool0000000aoo`8001Eoo`03001oogoo0?mo
okAooa800?moocIoo`005goo20006goo1P0037oo2P003Goo00<007ooOol0ogoo]Woo4P00ogoo=7oo
000IOol4000POol3000<Ool:000=Ool00`00Oomoo`3oOonhOolB003oOolbOol006=oo`03001oogoo
0?mook]ooa800?moobmoo`00Hgoo1000ogoo_7oo4P00ogoo;Goo001SOol00`00Oomoo`3oOonoOolB
003oOol[Ool006=oo`03001oogoo0?mool5ooa<00?moobQoo`00Hgoo00<007ooOol0ogooa7oo4P00
ogoo9Woo001SOol00`00Oomoo`3oOoo6OolC003oOolSOol006=oo`03001oogoo0?moolQooa<00?mo
ob5oo`00Hgoo00<007ooOol0ogoobgoo4`00ogoo7Woo001SOol00`00Oomoo`3oOoo=OolC003oOolL
Ool006=oo`03001oogoo0?moolmooa@00?mooaUoo`00Hgoo00<007ooOol0ogoodWoo4`00ogoo5goo
001SOol00`00Oomoo`3oOooDOolD003oOolDOol006=oo`03001oogoo0?moomMooa<00?mooa9oo`00
Hgoo1000ogoof7oo5000ogoo3goo001SOol00`00Oomoo`3oOooLOolC003oOol=Ool006=oo`03001o
ogoo0?moomiooa@00?moo`Yoo`00Hgoo00<007ooOol0ogoohGoo5000ogoo1goo001SOol00`00Oomo
o`3oOooSOolD003oOol5Ool006=oo`03001oogoo0?moonIooa@00?moo`9oo`00Hgoo00<007ooOol0
ogooj7oo5@00oWoo001SOol00`00Oomoo`3oOoo[OolE003kOol006=oo`03001oogoo0?mooniooaD0
0?Qoo`00Hgoo00<007ooOol0ogool7oo5P00mGoo001SOol00`00Oomoo`3oOoocOolE003cOol006=o
o`03001oogoo0?moooIooaD00?1oo`00Hgoo1000ogoon7oo5@00kGoo001SOol00`00Oomoo`3oOook
OolF003ZOol006=oo`03001oogoo0?moooiooaH00>Moo`00Hgoo00<007ooOol0ogooogoo0Woo5P00
i7oo001SOol00`00Oomoo`3oOoooOol5OolF003QOol006=oo`03001oogoo0?mooomoo`QooaH00=io
o`00Hgoo00<007ooOol0ogooogoo2goo5`00fWoo001SOol00`00Oomoo`3oOoooOol>OolG003GOol0
06=oo`03001oogoo0?mooomooa5ooaL00=Aoo`00Hgoo00<007ooOol0ogooogoo57oo5`00dGoo001S
Ool00`00Oomoo`3oOoooOolGOolH003=Ool006=oo`03001oogoo0?mooomooaYooaP00<Yoo`00Hgoo
1000ogooogoo77oo6000agoo001SOol00`00Oomoo`3oOoooOolPOolI0033Ool006=oo`03001oogoo
0?mooomoob=ooaX00;moo`00Hgoo00<007ooOol0ogooogoo9goo6@00_7oo001SOol00`00Oomoo`3o
OoooOolZOolJ002hOol000Moo`@000ioo`<000aoo`X000]oo`<000eoo`H0011oo`03001oogoo0?mo
oomoobiooaT00;Eoo`001Goo20002goo1@002goo2P002goo0`002goo2P003Woo00<007ooOol0ogoo
ogoo<Goo6P00/Goo0005Ool20004Ool2000;Ool5000?Ool2000@Ool2000;Ool30005Ool3000=Ool0
0`00Oomoo`3oOoooOoldOolK002]Ool000Aoo`8000Ioo`8000Yoo`D000moo`80011oo`<001=oo`80
00eoo`03001oogoo0?mooomoocQooa/00:Uoo`0017oo0P001Woo0P002goo0`0047oo0P0047oo0`00
57oo0P0037oo00<007ooOol0ogooogoo>goo7000YGoo0003Ool20008Ool2000MOol2000AOol2000D
Ool2000<Ool00`00Oomoo`3oOoooOoloOolL002QOol000=oo`8000Qoo`8001eoo`80015oo`<001=o
o`8000aoo`03001oogoo0?mooomood=ooa`009eoo`000goo0P0027oo0P007Goo0P004Woo0P004goo
0P0037oo1P00ogooogooA7oo7000VGoo0003Ool20008Ool2000MOol2000BOol2000COol2000<Ool0
0`00Oomoo`3oOoooOom:OolN002DOol000=oo`8000Qoo`8001eoo`80019oo`<0015oo`8000eoo`03
001oogoo0?mooomoodiooah0091oo`000goo0P0027oo0P007Goo0P004goo0P002Goo0P001Goo0`00
3Goo00<007ooOol0ogooogooDWoo7P00S7oo0003Ool20008Ool2000MOol2000COol20009Ool9000>
Ool00`00Oomoo`3oOoooOomFOolO0027Ool000=oo`8000Qoo`8001eoo`8001Aoo`8000Qoo`800003
Ool0000000<000moo`03001oogoo0?mooomooeYooal008=oo`0017oo0P001Woo0P007Woo0P0057oo
0P0027oo0P005Goo00<007ooOol0ogooogooGWoo8000OWoo0004Ool20006Ool2000NOol2000;Ool2
0007Ool20008Ool2000EOol00`00Oomoo`3oOoooOomSOolP001iOol000Eoo`8000Aoo`8001]oo`<0
0003Ool0000000]oo`8000Qoo`8000Moo`8001Eoo`03001oogoo0?mooomoofMoob4007Aoo`001Goo
20006goo1P002goo30001goo2P003Goo00<007ooOol0ogooogooJgoo8P00Kgoo0007Ool4000POol3
000;Ool<0007Ool:000=Ool00`00Oomoo`3oOoooOom`OolR001ZOol006=oo`03001oogoo0?mooomo
ogEoob<006Aoo`00Hgoo1000ogooogooN7oo9@00GWoo001SOol00`00Oomoo`3oOoooOomnOolU001I
Ool006=oo`03001oogoo0?mooomooh=oobH005=oo`00Hgoo00<007ooOol0ogooogooR7oo:000C7oo
001SOol00`00Oomoo`3oOoooOon>OolX0016Ool006=oo`03001oogoo0?mooomooi=oobX003moo`00
Hgoo00<007ooOol0ogooogooVGoo:`00>7oo001SOol00`00Oomoo`3oOoooOonNOol]000aOol006=o
o`03001oogoo0?mooomoojAoob`002aoo`00Hgoo00<007ooOol0ogooogooZWoo9`00:goo001SOol0
0`00Oomoo`3oOoooOonaOolP000[Ool006=oo`03001oogoo0?mooomookQooaT002]oo`00Hgoo1000
ogooogoo_Woo4P00:goo001SOol00`00Oomoo`3oOoooOoo6Ool:000/Ool006=oo`03001oogoo0?mo
oomoooaoo`00Hgoo00<007ooOol0ogooogooo7oo001SOol00`00Oomoo`3oOoooOoolOol006=oo`03
001oogoo0?mooomoooaoo`00Hgoo00<007ooOol0ogooogooo7oo001SOol00`00Oomoo`3oOoooOool
Ool006=oo`03001oogoo0?mooomoooaoo`00Hgoo00<007ooOol0ogooogooo7oo001SOol00`00Oomo
o`3oOoooOoolOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomo
oomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogoo
Hgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol0
0?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogoo
ogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo0000\
\>"], "Graphics",
  CellLabel->"From In[42]:=",
  Evaluatable->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Why might the crosstalk be increasing ? For an explanation look at Fig. 9 \
(",
  StyleBox["Ref. 11",
    FontWeight->"Bold"],
  ", p. 206) :"
}], "Text"],

Cell[GraphicsData["PICT", "\<\
W`X000000Bh1X`0A0_l<0?on0001;0000B`000000004j`KD0000002Q09H02P40
000000000000X02H0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G
0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40000000000000X02H
0:00V@2P09L0X@2F00X10000000000000:00V02P09T0X02G0:40UP0:0@000000
0000002P09P0X02I0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F
00X10000000000000:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I
0:00U`2Q09H02P40000000000000X02H0:00V@2P09L0X@2F00X1000000000000
0:00V02P09T0X02G0:40UP0:0@0000000000002P09P0X02I0:00U`2Q09H02P40
000000000000X02H0:00V@2P09L07P0100X000001>/6e00/00T00`I7IFiUMV40
00<00`0=00`0;P04003o000[0@41800Y004P00070000000S0000X02n0:40`00=
HgEbLVE^M71_JFid3@00X02o0281;P6M0000X02n0:40`03=HgEbLVE^M71_JFid
838PJFiTIGPPLgER86EhHfPP<b1YKVAUN21cMF8=83@a<b0PI6Uf86EhHfPP3B0c
<38P86AYMR0c86U^I6Eh80dP<20PLgER83<PJFiTIGPP3B0`821cMF8P=20b879_
K6`P=B1YKVAUN20e86U^I6Eh87AbHFicK65dI@e^IFLPLf=QK6D==20b879_K6`P
KVEW86EhHfPPKVEW86EhHfPPM79QKW=/HGAU80dP<c0b821cMF8PM79QKW=/HGAU
3@00X@300D@U8E1C;D5TKf9U;C<^<215D5=6;C<^<0dU9D9_MFiTJFiW@Vmh>R0P
<20`83@a<b0c<38P3BDUE6UdK6Dj82QSM2i3CUHY80dU9D=bIF5dKg8j84=QKWIQ
Lb0X=bh`;S8Y80dU9D=bIF5dJFm^A65dICXP:30d;c8c;c0a840P<C8j<CPPD4dY
80dU9DA_HgE]IFidD79_He=UM7<j84AUKVERHEm3HFifHG=3MG=dKfe3Kfa_LW<=
9BD[84=FA6USM0dU9DA_HgE]IFidAVm^M7<j80dU9DA_HgE]IFidCVEUI6ETAVm^
M7<j84MUKVEfH@d=9BE4Kf=eKFE^M51bKf=ULg=3Kfa_LW<j84=iHFhPCF5WIFid
HB1IIFa/KgLP@VaQHf/=9BE5KVA3Kfe]IFidL`dU9D9UIfU^D79_K6mW80d0X@30
@00U9D9UIfU^DVEcKgEbHfDj871bKf=cIG@P@eI4JF=d3BDUE6UdK6Dj84AUKVER
HB1cM65^I65bI21WLV5`J6USL`dU9EIULW=YKfhj834^<38=9BE3LVEQM6U_KTAQ
M6Dj834`;c4d;cTi3BDU@fm`NG9YIfQd>R0X@bTP<CTi=2`P<CTi>B14IFiUHV4P
DgUcM6E]LbhP@Fa/859YIfQdLb1BIG=ULWIUI0eeLfEbI6USM20_@eI4JF=d838`
<21TJF=d871eM0e3ETAYHg@PHVEWJFh=;fU^MV5/JFASKfa_LWAQHVaU?b1dLWEU
86AUIR0P80d_K6EfIF`b82m/HFiWMF5WIFaUMVE/87MXIG9U87]`Kg0PK65^IgEQ
IfE/IGIUK20b86MUOG]VHFacIGdPJFIUK7=U86AUIPe/IGIUK38PKVmd87/P;gQc
J6mg87/=<21SMG9bIFidL6mYKW@P=B0]<B1bKfa/87]`Kg0PL6m`86e_MVEdKb1T
MG0P<B1QI6@P<b0a879_K6`PIGQSJ21TMG0P=20a879_K6`PIGQSJ21WIG@P<21b
KFmfIGA_86=eLW9UKWA`KfU^M7dPIGQSJ21[LfQ_M`e`Kg0PL6m`871_L21`Kg1m
86AUIR1m86UV3BmYKVUdJF5/JGYU3G]3ETAYHg@=NfAeL21hHfQUHf]kHVU^I7eY
IR1`Kg0PL6m`OFI_LV5/K0eSMG9bIFidLf=bIFE^82mOLg0PIGQSJ21TIFHP;emc
HB1UN6=X86AUIR0_Gg=V86EhHfPPI6EV3Bm4IFIQMFadDf=bIFE^NemcIR1OLf4P
;emcL21/Kf5TOFAUIPd_A6EVHGE/M5=SLVEUKU1bKf=k82mOLg0PK6mQI7eTIFH=
;g=UM7=dLVm[IF5TJWEcM21gJ6EbIG]`Kg0PM79eIGekIV5/LfEmJFIUK7=U3G/_
Lf4P;g=UM7=dLVm[IF5TJWEcM21/Kf5T86AUIPd_K6TP;faYKVEdKb1/Kf5T86AU
IPd_KG@P;fe_MVEdKb1/Kf5T86AUIPd_Hg@P;f=eLWIUM6lPK6mQI21TIFH=;faX
87/PHgEbLVE^M71_JFid86EhHfPPL6m`86aYKVEdKgeRJFiT86AUIPd_K7HPNb1S
MG9bIFidL6mYKW@PL6m`86EhHfPPK6U^IGA_OF9YKV@PI6EVO@ek;g=QNg]SMG9b
IFidI6USM21CM79_JfE1I6YeLgA4JF=d86iUNe=dLVm[ID5TJWEcM4AYHg@PHVEW
JFimJFImNb1SMG9bIFidI6USM21CM79_JfE1I6YeLgA4JF=d86EaNfE^I7eYIWeY
IVE/LfEm869YKV@PI6EV3GEcIG9TJF=d82mCM79_JfE1I6YeLgA4JF=d834`<21T
JF=d871eM0eCM79_JfE1I6YeLgA4JF=d869UIfU^3BmON6`=NgAbHFicIVmbK@d^
<SDPLgER879_MFiT82hb=B1QI6@PIGQSJ0d^<SDPLgER879_MFiT82hb=B1QI6@P
IGQSJ0eYM79QKW=VKg9]3GeRJFiT86AUIPd_K6Uk85mhK21/JFiUM6mmHVU^I21T
IFH=;fedNb1ON6`PKFmfIGA_OF9YKV@PI6EV3BmSM7/PGgQ/86=eLWIUM6mmHVU^
I21TIFH=;faX87/PI7E`85mhK21`Kg0PHgEbLVE^M71_JFid86EhHfPPL6m`86aY
KVEdKgeRJFiT86AUIPd_K7HPNb1TMG0PGgQ/871_L21SMG9bIFidL6mYKW@PL6m`
86EhHfPPK6U^IGA_OF9YKV@PI6EV3BmbL7]ON6`_HgIOHR1hI6H_HgIOLR1hI6H=
GgQ/;f=fGg@PN6AV;f=fGf`PN6AV3F=fGf`PHgIOM21]KgIUM6l=HgIOLR1SMUmd
86aYKVEdK`eSMUmb86=fGf8PK6U^IGA_3F=fGf`PHgIOHR1/JFiUM6l=Hfa_LfE`
HGAX3GeRJFiT86AUIPeUKVAmJFIUK7=UOFAUIPd_M6EbKFU^HGAU3G]eLfEbI6US
M20_DgAbKf]U@FAZMG=dA6USM21[KVmgKR1kHgEbLVE^M6AYHg@PDgAbKf]U@FAZ
MG=dA6USM21ULG]UKVAmJFImJFH=HgEbLVE^M6AYHg@P@eI4JF=d86EaNfE^I7eY
IWeTIFH=;fehCF5h83Hd86AUIPd_KGQCM6/PFfehCF5h87]]HGAbJGQm879UL6EQ
M5eTIFH=;fehBFAh830PI6EV3BmcM6ekKGQCM6/PKGQ9I7PP<21/M21k;fehBFAh
830PLgA_LVEmJFHPKGQ9I7PPIfEd86=eLW9UKWA]HGAbJGPPL6m`82m]N4UTN21]
N4UTN20a865TI21cM6mbIGeTIFH=;g9dKG]]N4UTN20a86MU87/_KGQ9I7PPKGQ9
I7PP<B1cMF8PLgA_LVDPKGQCM6/PKGQ9I7PPIfEd87=UM6eQM79YN7eYIR1mI6EV
3BmcHf`PNb0g<R1TJGHPIGQSJ20g<R1TJGHPIGQSJ21cHf5/IB1m86AUIPd_Lf=/
JB1k83Lb86EhHfPPI6Uf86EhHfPP=c8PIGQSJ21TJGHPIGQSJ21cHf5/IB1m86AU
IPd_Gf=fKGAh86eQM79YN21TIFH=;emdN7A]M7PPKF5dLVUh86AUIPd_GfU^JGA]
M7PPKF5dLVUh86AUIPd_N6AVNfEhHfPPI6EVOFAUIPd_KFU^Nc8PHfm`NB1WM7]U
N6=XOFUV871_L7eTIFH=;feQN7/b86=_L7TPK7AkIGQSJ7eYIR1`Kg1mI6EV3Bm3
EWIUHb0b=CHPHG9bHGTPI6EV3BmD87AbMFDPI6EV3Bm686IQK7=U86AUIPd_GfUT
830PI6EV3BmOIFiSKfAYKVAUN20`86AUIPd_GfE^HfmT@G9b83<PHG9bHGTPI6EV
3BmOIV@P<21TIFH=;emdIGQdDf5fIB1^MFa/86AUIPd_GfaUM7AULU=`HF=U830P
I6EV3BmOLg1QHfEHM79Q830PI6EV3BmOD65WIE=QMVDPKWE/K21TIFH=;em`IFiX
834^<21TIFH=;em`IFif834^<21TIFH=;g=QMVD`86ieK6`PI6EV3BmOMb0`86AU
IPd_GfPP<21TIFH=;emTLb0`86AUIPd_J6=d86IQK7=U86AUIPd_L7LP<21TIFH=
;gMTJFHP<21TIFH=;gAUKG0P<21TIFH=;f=eLW9_M20`86AUIPd_Lf5fIFQQKVA/
IG8PKWE/K21TIFH=;fUQ830PI6EV3BmYN20`86AUIPd_JGQ^834PI6EV3Bm=MFad
JG1/IDAQM65CKgEbHfEc86IQK7=U86AUIR0=;fAUHWEW3G]TMG0P;bAUL7<PIGQS
J21^Kg@PI6EVNbmcHGIUJ65^I6aULR1ULW9_LVAYHg@P;fQQKVA/IFEbLVmb86MU
M21TIFH=IG9bKg9TJF=d3BmXHFiTK6EULW9_LW/TIG9bKg8PHVEWJFh=KVEgIG9b
Kg9k;fiUMfEbLVmb86IQK7=U86AUIPecJ6mgL65WI@dg<R0g<R1cHf5/I@d_B6E/
MVEdJF=Q86IYKVAVKfid82hb87=SHFaUIVm^M21cIGAVKfid3Bhb=B0i;SHPKFmf
IGA_3BQ5LW9_LSXP:G=XKgL=IG9bKg9^HFeU3G]TMG0PM7U`IBmcM79YKVMdNG1U
86iU3G/XHfm^MVEbM6ET86EbLVmb86iQKFDPMfU/K21UKV@PMG0PJFhPM6QYLb1c
M79YKVLYHgIcOFUV3G=XKgMmIGQUH`d^<SDP>Bhd86e_MVEdK`dXCfIVIFiTJFiW
84=_KFeQKV@j82UcJ6mg3BmSKfe]HFiT86a_HF@=NfAeL21dNG1U;g=dLVU^IgAi
L6DPKVD=NbQSKfifIG9dIF@PHfm]KF5^I21^HFeU87MYK6`PIFiT87E`86U^87AX
JG<PLgAbJFiW:F=fLgeYIPecJ6mgOFEhIF<=;S8e83T^<R1]KgIUM6l=:5=dHF=[
>R0YLfQ_M`e_LgAQHf/=Nbhb=B1SMG9bIFidL6mYKW@P;S8PLgER86EhHfPPL6m`
86e_MVEdK`eTMG0PM7U`IBmcM79YKVMdNG1U86iUNfAeL21dNG1U;fU^M6EWIG9d
NG1U86Ea3C4PJFiTIGPPM7U`IBmbIF5/M7U`IB1ULB1_LPda86U^I6Eh87AiL6D_
KV5]IGAiL6DPIG4PKg8=KVmd87]dNG1UOFUV3BQSKfifIG9dIF@PLgAQHf/PMfU/
K21UKV@PMG0PJFhPM6QYLb1cM79YKVLYHgIcOFUV3G=XKgMmIVmbHFa/3G=XKgM`
HFMU3D=FA6USM20_Lf5fIFQQKVA/IG8PIfEd86EhIF=mJFH=IFiTOG1eM7eYIWeT
IFH=;faSNg=UM6aYKVESHG1mI6EV3Bm/JW]cIGA/JFiUJVmYKWeTIFH=;fa]Ng=U
M6eYM6EbK6U]JGAmI6EV3Bm/IW]cIGAVK65dOFAUIPd_Hg1kHfa_LfE`HGAXOFAU
IPd_KW1kKVEgL65dJ7eTIFH=;bA`LgXP<c0PHG9bHGTPI6EV3BlTL6Uh830PI6EV
3BmWLg]WLf5fIB0TL7=j86AeL20TL6Uh85m`IFiX871eM20TL6Uh834PHFAT85m`
IFif871eM20_971YN20TL6Uh838PHFAT86AUIWeTIFH=;fMbNfMbIG=dKg9U;bA`
JGPP971YN20b87=eHR1TIFHP971cNR1TMG0P971YN21WIG@P;em`IFiX86EhHfPP
I6EV82A`JGPP<B1QI6@PIfEd82mOL6E^MR1UN6=X86AUIWeTIFH=;faYNfaYKVEd
KgdPI6EV3Bm/J7]SMG9bIFidL6mYKW@PIGQSJ21`Kg0PK6U^IGA_OFAUIPd_K7Ik
HgEbLVE^M71_JFid871_L21UN6=X86aYKVEdKgeTIFH=;fedNfe_MVEdKgdPI6EV
3BmOHgIOKFQkHgEbLVE^M71_JFid86EhHfPPL6m`86e_MVEdKgeTIFH=;emSMUm]
MW]SMG9bIFidL6mYKW@PL6m`86EhHfPPKFmfIGA_OFAUIPd_HgAkHgEbMVEdKgdP
I6EV3BmbM7/d82db879_K6`PKFmfIGA_3FAeL20`86EhHfPPLVaYKVEdK`eUN6=X
830PLVaYKVEdK`e^IFLP<21UN6=X879/JFiUM6l=Hfa_LfE`HGAXOFAUIPd_GfQb
3G/=Nbm0IG9b86IQK7=U86AUIR1SMG9bIFidIVaQM21TMG1kIg=QMVEkIFmSK6U`
OG=dKg1`IFAkIg9ULgA_LVDP<R1]MF`PI7E`87=UM6I/HG@PI7E`838`<21WIG/X
9BDP@f5^MV5c>T=/JG0PIV5YK6ETG78YL79YKW@P;d1ULW8PM79eIB1TIFHPL6m`
86EhJGAmJFImNfMbIG=dKg9U87=UM6I/HG@PIGQYM7eYIVE/LfEmK6m_L210IG9b
86i_M21kIFmSK6U`OFUV87=UM6I/HGAm3G/_@6EbLR1VHFacIB1TIFHPHgEbLVE^
M6I/HG@PI7E`NfMcHGIUNf=/JG1mLgA_L71UI7]WLVEcM6mbIB0b86eeK21TMG0P
LfEdIVaQM21TMG0P<S0`86MUNbPU9B13HFifHG<j@faYL21VHFU/IFALLRU`LVU^
M20_@6EbLR1dLWEU86AUIR1`Kg0PIGQYM7eYIWekIg9ULgA_LVDPLfEdIVaQM21U
N6UdOFUVIFacIGe/Kfm`841ULW8PKVmd87]SK6U`OFUV87=UM6I/HGAm3GeTIFH=
;emSLb1^MFa/86AUIPd_IVMkLfEdIg9QNGeTIFH=;g=UM6=]NF]SKfa_LR1gJ6Eb
IB1kL6m`87AbMFEmNfIQK7=UOFUVIFacI@ek;fHdNb1cIGASKGU[Hfm/Kg9mI6EV
OG/_ISAk<B1cMF8P=20a879_K6`P<g/c86U^I6Eh865TI21^IFLPI7E`830PK7Ak
L6m`831mJFHP<b0a879_K6amLVE`IF5d87=UM79WHV=_K6mb871_L7eTIFImJFIU
K7=U3BmcIGASKfa_LW=`HF=U87MXIG9U87]`Kg0PM79eIGekIV5/LfEmJFIUK7=U
3G/_Lf=cNb1TMG0PLfEdHfm/Kg9cL65SIB0_Gf=c86EhHfPPI6EVOFAUIRmV<g/P
Gf=c87=UM6=_K6mbLg1QHfDPLfEdHfm/Kg9mI6EV3Gek;fHcNb1cIGAbIf9SKfa_
LWeTIFH_Lf=cNb1`Kg1mI6EVOFUVIFacI@d_96=S83DPHG9bHGTPI6EV3BmVJFiT
HfeiJf=eLgA_KF=_K6mb87MXIG9U87]`Kg0PM79eIGekIV5/LfEmJFIUK7=U3Fi_
M21k;fIYKVASKGU[HgEcM6m]Hfm/Kg9k96=S865cM6mbIGeTIFImJFH=;g=UM6=e
LgA_KF=_K6mb87MXIG9U87]`Kg0PM79eIGekIV5/LfEmJFIUK7=U3Fi_M7/_LfEd
HgEcM6m]Hfm/Kg9kIGQSJ21QK6mQI21`Kg0PL6m`83Ak=21YKVAUN21]MF`P=20a
879_K6amLVE`IF5d87=UM6=]NF]SKfa_LR1`Kg1mI6EVOFUV3BmVHg/f834PLVm/
K21VJFiTHfeiJf=eLgA_KF=_K6mb86EhHfPPLfEdHgEcM6m]Hfm/Kg9mI6EV3Bmc
IGAcIG1QLV5dJFm^Ig9QNB1gJ6EbIB1kL6m`87AbMFEmNfIQK7=UOFUVIFacI@e^
KgAk;g=UM7=UL65bHGAYKfiWLV5i87]cNG=dIFeTJF=d82mcIGAWLV5i86MUM21U
N6ESOB1TIFImJFH=;g=WNb1cIGAcIG1QLV5dJFm^Ig9QNGeTIFH=;g=`NbmOL6E^
MR1hI6H_Gg1UKVPPN6AVOFAUIPd_LW0=NbmSMUmR87QTIRmSMUmb87QTIPd_HgIO
M21hI6H_HgIOK21hI6H=HgIOK21SMUmd86e_MVEdK`eSMUmb86=fGg@PK6U^IGA_
3F=fGg8PHgIOHR1/JFiUM6l=HgIOK21SMUmR86aYKVEdK`eSK6mcIG1QM6QmI6EV
3BmbLW/_NG9QI6UeLb1hI6H=;gQbHFAYMG<PN6AV3BmSMUmR87QTIPd_HgIOLR1h
I6H=;f=fGg@PN6AV3BmSMUm/87QTIPeSMUm/87QbHFAYMG<PHFAT86=fGg@PKFmf
IGA_3F=fGg8PN79QI6UeLb1cMF8PHgIOM21/JFiUM6l=Gf=fKGAh86=eLW9UKWA]
HGAbJGPPL6m`3F=eLW9UKWA`KfU^M21dLV5^LfaQM6D=N79QI6UeLb1iLV5TJGEc
87=SHFaU3C4P<20a834P<B1QLV=dKb0dNg1_L7ebIG1UHG@=Gf=fKGAh87=UM6eQ
M79YN0eSMUmb86=fGf8PNG9QI6UeLb1cMF8PK6U^IGA_3EmSMVedN21SMG9bIFid
KF5dLVUh871_L0eSMG9bIFidL6mYKW@PM79QKW=/HGAU3GQbHFAYMG<PNG9QI6Ue
Lb1cHf5/I@d`834P;C4P<B0a865bHgA_83AkL6m`OG9UL6EQM0eOHgI]M7PPLfEd
KF5dLVUh3F=fGf`PN79QI6UeLb1QI6@PHgIOHR1/JFiUM6l=Gf=fKGAh86=eLW9U
KWA]HGAbJGPPL6m`3F=eLW9UKWA`KfU^M21dLV5^LfaQM6D=N79QI6UeLb1iLV5T
JGEc87=SHFaU3Bda830P;C4P;C4P<B1QLV=dKb0dNg1_L7ebIG1UHG@=Gf=fKGAh
87=UM6eQM79YN0eSMUm/86=fGg@PNG9QI6UeLb1QI6@PK6U^IGA_3EmSMVedN21S
MG9bIFidKF5dLVUh871_L0eSMG9bIFidL6mYKW@PM79QKW=/HGAU3GQbHFAYMG<P
NG9QI6UeLb1cHf5/I@d`82da834P;C4P<B1QLV=dKb0dNg1_L7ebIG1UHG@=Gf=f
KGAh87=UM6eQM79YN0eSK6mcIG1QM6QmI6EV3BmUL7]OHgI]M7PPHgEbLVE^M6eQ
M79YN21`Kg0=M79QKW=/HGAU3G=SHFaU3C4P<21]KgIUM6l=<20`834P<20c=S0P
HG9S3F=/Kg=UL65dJ0eOHgI]M7PPLfEdKF5dLVUhOFAUIPd_MfAkGf=fKGAh86=e
LW9UKWA]HGAbJGPPL6m`3GAbHFicK65dI@ecHf5/I@d`830PKFmfIGA_3C0P<20a
83DP;C8PLVm/K21QLV=^3F=/Kg=UL65dJ0eOHgI]M7PPLfEdKF5dLVUhOFAUIPd_
HG=kGf=fKGAh86=eLW9UKWA]HGAbJGPPL6m`3GAbHFicK65dI@ecHf5/I@d`830P
<B0e82db879_K6`PHG9SKPeOHgI]M7PPLfEdKF5dLVUhOFAUIPd_I7<=Nem`IFif
85m`IFiX86iU86AeL7]cM6dPGg1UKVPPI7E`830PK6EkL6m`835mJFHPGg1UKWHP
I7E`830PK6EkL6m`835mJFHPLf=QK6EmNem`IFiX87=UM6aYKVEgJFAdJ7eYIVE/
LfDPLgAbKf]U87]bM6emJFImI6EV3BmTIW]VJFa/OFAUIPd_I6EkIFmVJFa/OFAU
IPd_GfMcM6/P=B1QLW9QNB1TIFH=;emWLgA[Hb0`86AUIPd_GfMcM7/P>B1TJF=d
869UIfU^86aUMVE/<W/_Gf=SLb1SMG9bIFidHfm/Kg9cL65SIB1TIFHP;emSHb1K
HgEbLVE^M6=_K6mbGB1TIFImNbmOHf<PFf=eLW9UKWAbIf9SKfa_LUeTIFImJFIU
K7=U87]SMG9bIFidL6mYKWAmLgA_L71UI21k;emSL21^MFa/86AUIWek838PHG9b
HGTPHG=dKg9U82mOHg0PIGQSJ21TIFImJFIUK7=U82mOHfHPHgEbLVE^M6I_KW@P
I6EV3BmOHfag86=eLW9UKWA/JFiUMfUTM6PPI6EV82mOHfaS86=eLW9UKWA/JFiU
Hf5`86AUIR0_Gf=/JR1SMG9bIFidK6U^IFY_JFhPI6EV82mOHfe/86=eLW9UKWA]
JGAULVaYKFUd86AUIR1SMG9bIFidI6USM21UKVAmI6EV3BmXLg]^IGM`HGAX86Mc
HGIU87=dKGeTIFH=;fQSNbmOJ78PK6mQI21UN6=X86MUM21UN6ES86iUMg1QM6Qm
I6EV3BmXIG]OIg=dJb1OIg=dJf<PGfMcM21`MG@P;emWLgA[Hb1OIg=dJf<P<B1Q
I6@PLgA_LVDP3FMbIG=dKg9U879dKB0_GfMcM6]S85mWLgA[Hb0a87=eHR1cM6mb
IB1OIg=dJb1OIg=dJf<PIfEd86aUMVE/<W]TMG0P;emSHg<PIfEd87=UM6=_K6mb
Lg1QHfDPI7E`82mOHf<PIfEd865/Kf5T871_L21cIGASKfa_LWekI7E`82mOHf<P
IfEd865/Kf5T871_L21cIGAbIf9SKfa_LWeYIVE/LfDPI7E`82mOHg0PIfEd86Ae
L21^MFa/86Ea80e^KgAkHFa_HF@PL6m`86e_MVEdKgekL6m`OFUVIFacIB1TMG0P
;emSIR1WIG@PLfEdIVm^M0eTMG0_Gf=/Mb1WIG@PLfEdK6U^IGMYI7AX86AeL2mO
HfaS86MUM21cIGA/JFiUHf5`86AeL2mOHfaZ86MUM21cIGA/JFiUJVmYKR1TMG0_
Gf=]K21WIG@PLfEdKFUdIG9/JFeYM21`Kg1mI6EV3BmYI7/P;emYI21hI6ImI6EV
3BmOJFeQM79YN7]OMb0`830PGfPPGfUT830PKVEkKVEW830PGfQmNc0P<7eYIVE/
LfDPGf=fKGAh865cM6mbIGeTIFH=9B13Kg1iLVUWJ7@P:4<Y834i>C0/834i>C4P
HWTP@FA_HVDPDgUcM6E]Lb19KV=_LW1_LV5dIF@^3BDP@Fa/879YIfQdLb1bIG=U
LWIUI2h=K6EfIF`b87/PLf5fIB0_I6m^M6a_HFA/IGIUK34PN6AV87eYIPd_LgAQ
LWA^Kfa_HFAkNbm^Kfa_HF@PLf5fIB1TIFIm86UVOFAUIPd_IFiTKVm/Kf5TNg]^
Kfa_HF@PLVEcM6mbIGeYIR1mI6EV3BmdIG=dLgUcM6E]I6USM7]gJ6EbIG]cNG=d
IFeTJF=d86EaNgAbMFEmNfIQK7=UOFUVIFacIGekIV5/LfEmJFIUK7=UOFAUIPd_
KV=_K6mbLb0a86AUIPd_Hfm/Kg9YKF5WIB1gJ6EbIG]`Kg0PM79eIGekIV5/LfEm
JFIUK7=UNbm^Hfm/Kg9c830=LgAQM7EcI6USM21RIFMYKR0=;g1bKf=ULg=SKfa_
LW<PMfQULVEkL6m`871_L21`LVmSIG=cHfm/Kg9cOG/_I6EfJF=UJFiVKb1gJ6Eb
IG]`Kg0PI6EfJF=UJFiVKb0_@fm/Kg9c86]^KgM^3G]`Kg0PNfAUMVUSIFU^IVlP
;d=_K6mbLb1WIGAmOFUVOFUVOFUVIFacIB1UKV@PI6EV3FiSKfa_LW<P<21^IG/_
Hfm/Kg9YKF5WIB1dIG=dLgUcM6E]I6USM0d_LfEdHfm/Kg9dLV5^LfIULR1dIG=d
LgUcM6E]I6USM0d_HgEbLVE^M6=_K6mbM79QKW=VIG8PM6EcM7=iLgAUKFAYHg@=
;f=eLW9UKWASKGU[Hfm/Kg8PM6EcM7=iLgAUKFAYHg@=HFiT865^I21QKV@PKVmd
Nbm^Hfm/Kg9c830PI6EVOFUVOFUVOFUV3FiSKfa_LW<PI7E`834PKVDPIGQSJ21T
MG0P<b1^IB1UN6=X83@PKVDPHFiT865^I21k;fiSKfa_LW<P<21TIFImJFH=KV=_
K6mbLb0a86Ea86AeL21TMG0PKVmd87=dHG9dKVm/Kf5T3G/_I6mSK7EdJFeQIfEk
Fg/b=CDPKGE/879_MFiT86=fJB1RMf=/MG@PIGQSJ21WIG@P<SDe86AYMWdP;fEh
IF<PK6mQI21TMG0PHgEbLVE^M7AbHFicIVEb86EhHfQM80eSMWPPHVU^I21cIGAd
LV5^LfIULR1OMb1OJ20h85mYKF5dLVUh85mTLb1YKF5WIGeTIFImJFH=KVmd86E^
I6i_K6mQI0e^Hfm/Kg9c86AeL20c86Ea86EhHfPP=21ULB1_LPeTMG0PI7E`86i_
M21cM65bM6i_K6mQI0ek;fieK6a`LVmSNg]mOFAUIRmSKfiSHGAeM6U/NbmUN6ES
86a_HF@==b0]<B1bKfa/82mUN6ES86a_HFAmI6EV3BmTIFIcMF9SK7Ed3G/a865T
I21WIGAYKWAULWIQK21TIFImI6EV3BmcL6=_KV=QM7AbHFicIVEb820P3G/_A6=/
MG@PIGQSJ21TIFH_@f=/MG@PIGQSJ21TIFH_@V=/MG@PIGQSJ21TIFH_@F=/MG@P
IGQSJ21TIFH_KV=_KG1eM6DPIGQSJ21/I0eSMG9bIFidHfm/Kg9dLV5^LfIULPeK
Nd5SK7Ed86iSKfe`MGAUOF=_KV=QM7EdJFaM86=fN0eKNd9SK7Ed86iSKfe`MGAU
OF=_KV=QM7EdJFaM86=fN0eKNd=SK7Ed86iSKfe`MGAUOF=_KV=QM7EdJFaM86=f
N0eKNdASK7Ed86iSKfe`MGAUOF=_KV=QM7EdJFaM86=fN0ecIGASKfa_LWAbHFic
IVEbOFAUIPd_LfEdMG1bIf9SK7EdL`ek;f9YM3=h879WHV=/MG@PK6E^IgAX83<P
LgER86AUIPd_HVUd<GPPHVUd<gPP<b1YI6Uf86AUIRmbHfaeM21bIf9SK7Ed86AU
IPd_If=/MG@PLV=/MG@P<B1RJG@cN21TIFIcMF9SK7Ed;f9SK7Ed879SK7Ed838P
HVUd<gPPI6EVLgERHfaeM7eTIFImJFHPKVmd820=IFiTKVm/Kf5T86iSKfa_LW<P
<b1ULB1TMG0PI7E`86i_M21cM65bM6i_K6mQI0ek;c=SKfe`MGAUNfEhHfPPHVUd
<gPPKGE/3G9_MFiT86=fJB1WIG@P<SDe86AYMWeTIFH=;fA_HfaeM6U]HFMUNbD_
LVMRHfaeM21hI6HPL6m`80ecIGAeL79WHV=/MGAc;c=SKfe`MGAU879SK7Ed86MS
K7Ed869SK7Ed86AeL0ecL6=_KV=QM7AbHFicIVEb85mg85mX83PPGfU]HGAbJGP=
FbmOI7<PK6mQI20_IGQUHb1/Kf5T82mTMG0PK6mQI21TMG1MHgIh3FieK6a`LVmS
86ieK6a`LVmS87AbMFDP<b1SKfa_LVU]HFMUOFAUIWeYIR1^Kg@PIFiTKVm/Kf5T
86iSKfa_LW<P=21ULB1TMG0PI7E`86i_M21cM65bM6i_K6mQI0ek;g=dMFIVHfae
M7]SKGU[JFiTIGPP<b0]<B1bKfa/871eM7eTIFH=;fIdKfU^M7/a86EhHfPPLgER
838e=B1]MF`PLVmeKV@PHgIYOFAUIPd_=6=_KG1eM6DPNb1UN6=X869YM3Ah86ee
K21bKgE^I21SMVTPIfEd838e=B1TJGHPOB1TIFH=;f=_KG1eM6ESKGU[HfaeM7]c
IGAeL79WHV=/MGAc;f9YM3Ah879WHV=/MG@PK6E^IgAX83<PJFAYMR0d86eeK20d
87=eHR1TIFH=;f=]NF]SK7Ed869YM3Ah83@PHFAT87=dLVU^Ib1TIFH=;f=SK7Ed
86=]NF]SK7Ed86AUIPd_KF=/MG@PHf=/MG@P<B1RJG@dN21TIFIcMF9SK7Ed3Bmi
HfaeM21SHfaeM20b869YM3Ah86AUIW=eHV=/MG@=;f]SK7Ed86=SK7Ed83<PHVUd
=7PPI6EVLgERHfaeM0d_HfeiJfU^I6Eh830PI6EV3C0P<B1RJG@aN0ekI7E`82mS
KGU[JFiTIGPPIGQSJ21RJG@aN21UN6=X87=eHR0d86eeK21TIFH=<b1]MF`PI7E`
879SK7Ed86EhHfPPIfEd838e=B1TJGHPIGQSJ21TMG0PIf=/MG@PIGQSJ21WIG@P
<SDe86AYMPeUN6=X869SK7Ed86EhHfPPIfEd838e=B1TJGH=LfEdLVMRHfm/Kg8P
HgEbLVE^M6=]NF]SKfa_LPeVM6mYKW@PJf=/MG@PLgAeIVISK7Ed3FIdKfU^M21i
HfaeM21cM7EVIV=/MG@=IWA_JFid86eSK7Ed87=dMFIVHfaeM0eVM6mYKW@PHf=/
MG@PLgAeIVISK7Ed3GeVKg9mI6EV3BmTKf=/MGAYKF5WIG]YKWIQK6UTHfm/Kg9d
HF9/ICmkHfm]L7EdIF=]NF]SK7EdOFUV3BldHfm]L7EdIB1SHfaeM21]HfaeM21i
HfaeM21[HfaeM21cL6=_KV=QM7AbHFicIVEb3Emg85mX83PPGfU]HGAbJGQK;emT
Lb1/Kf5T82mUN6ES86a_HF@_I7E`86a_HF@PI7E`86AeL5dPHgIh80e^MFa/L79_
Hb1^MFa/L79_Hb1^MFa/L79_Hb1dLWEU83@PHfm/Kg9YKF5WIGeTIFImJFH=KVmd
86E^I6i_K6mQI0e^Hfm/Kg9c830PIG4=I7E`86AeL21^Kg@PLgAQLWA^Kfa_HF@=
NbmSKfa_LVEhL65^I7]]NG=dLVU^IfEhL20`879WHV=/MG@=<b1SKg1i3CLP;C4P
LVm/K0ek<b1]MF`P<b1WIGAYKWAULWIQK21`MGAYKWAULWIQK21UN6=X83<PHFAT
86EhHfPP<b1SKg1iOFI_LV5/K0e`Kg0PL6m`871_L21`Kg0PL6m`OFAUIPd_Hg9U
HGAUIGQ`HFiTLgAbNbm]NG=dLVU^IfEhL21UN6=X87=d<21/IFiWM6PPKGE/87=d
LVU^Ib1TIFImI6EV3BmTKf=/MGAYKF5WIG/_LVMRHfaeM21hI6HPL6m`83<PHg9U
HGAUIGQ`HFiTLgAb85mg85mX83PPGfU]HGAbJGP=FbmOI7<PK6mQI20_IGQUHb1/
Kf5T82mSKfa_LVEhL65^I21/Kf5T82mUN6ES86a_HFAM86=fN0eVHFacIB0c86=_
K6mbJFeQIfEmI6EVOFUV86i_M21UKVA^Kfa_HF@=K6EfIF`b87/PI6m^M6a_HFA/
IGIUK34PLVEcM6mbIB1mJFH=K6EfIF`b86i_M7/PLf5fIB0_I6m^M6a_HFA/IGIU
K38PN6AV87eYIPd_LVMRHfaeM20`86AUIPd_I6mSK7EdJFeQIfEk;fQYMV5/838e
=B1TIFHP3E/_BFiTIGQUI20_A6EfJF=UDTM286QYMV5/879WHV=/MGAM87=UM6=_
K6mbLg1QHfD=GfU]HFMUI6USM21TMG0PHVEWJFhP3BmGJFAdJ21OMb1TIFHP3Bm8
IFUWJ7@PGfPPI6EV820=;dAUHfmTIB1K<21XJGIQK5dPI6EV820=;dU]HFMUCF5d
LVUh85mYKF5dLVUh86AUIPd_@VUdLe1ULT=_KG1_KVE^M20h86AUIR0=;dU^M6Eb
L6m/HGAU86IQK7=U86AUIPeUKV@PJFeQIfEmI6EV3FaUMVE/<R1^KgAk86A_KWA/
Kf5TK6EfIF`b879ULgA_LVDPOFUV3BDUAFiTD79_He=UM0d_GfU]HFMUI6USM20a
=B1TJF=d869UIfU^82m9KF5WIEAiL6DP<B1TIFH_@VUdLe1ULT=_KG1_KVE^M20h
86AUIRm9KWAULW1_K65dIB1VHFacIB1TIFHPHgEbLVE^M6AYHg@PIFiT86AUIPd_
J65cHfm/Kg8PM79eIB1TIFH=;faUMVE/<R1cNG=dIFeTJF=d82m/HFiWMF5WIFaU
MVE/86]^KgM^3G]/HFiWMF5WIFaUMVE/838PIfEmNfIQK7=UOFUVIFacIB1TIFH=
;fI_MG9ULB1k=21YKVAUN21ULB0h834PLVm/K0dd86U^I6Eh86Ea83PP<B1bKfa/
3C@PJFiTIGPPIG4P>20a879_K6`==21YKVAUN21ULB0h834PLVm/K0e`Kg0PL6m`
871_L21`Kg0PHFiT865^I21QKVAm86AUIPd_LfEdMG1RHFiTLg]WLf5fI@d_Gg=U
M7AbHFicIVEb87=iLgAUKFAYHg@P;g=UM7AbHFicIVEb86MUM21TIFH=;emSMG9b
IFidM79QKW=VIG8PLgUcM6E]I6USM20_HgEbLVE^M7AbHFicIVEb86MUM21TIFH=
;emYKF5WIB1cNG=dIFeTJF=d82mYKF5WIB1WIG@PI6EV3BmRK65^Jb0`85mSMG9b
IFidM79QKW=VIG8PIGQUH`da85mSMG9bIFidM79QKW=VIG8PIGQUHb1ULB1TIFH=
;fiUIf5dJGIU869/HFi[Nc0PGf=eLW9UKWAdLV5^LfIULR1UN6ES830^=B1/M7d=
Nc0PGf=eLW9UKWAdLV5^LfIULR1UN6ES834PGf=eLW9UKWAdLV5^LfIULR1UN6ES
86MdOFUVIFacIB1TIFH=;fU^MVEbM6ET?b1^IFMQM6UfIB1TIFH=;emSMG9bIFid
Ig9QNB1cNG=dIFeTJF=d82mSMG9bIFidIg9QNB1WIG@PI6EV3FQQLf=_K6mbNblT
HR0`86AUIWdPNblTHR0e86AUIWdPJFIUK7=U3BmcIGASKGU[Hfm/Kg8PMfQULVEk
L6m`834P<20`830PLfEdHfeiJf=_K6mb85mSMG9bIFidIg9QNB0a86EhHfPPLgER
3C0P<B0`830PLfEdHfeiJf=_K6mb85mSMG9bIFidIg9QNB0a86EhHfPPLgER3C0P
<20a830PLfEdHfeiJf=_K6mb85mSMG9bIFidIg9QNB0a86EhHfPPLgER3C0P<20`
834PLfEdHfeiJf=_K6mb85mSMG9bIFidIg9QNB0a86EhHfPPLgER3C@PNc@PHfm`
NGdPLVE`IF5d3C4P<20`830PIVmeLVEaNblTHR0a87=dKg9UOFUV3C0P<B0`830P
IVmeLVEaNblTHR0b87=dKg9UOFUV3C0P<20a830PIVmeLVEaNblTHR0c87=dKg9U
OFUV3C0P<20`834PIVmeLVEaNblTHR0d87=dKg9UOFUV3C0P<20`830PIVmeLVEa
NblTHR0f87=dKg9UOFUVOFUV3F9/HFi[NblTHR0f87=dKg9UOFUV3BAR830PIG4P
968P=B1ULB1_LW/_96Ad830PI6EVOFUV;bATM20]<B1TIFHPIg9ULgA_LVEmI6EV
3BmTKfU]HFMUN`e/IGIUK39kJFeQIfEmNf9UIfU^3EMYI7AX84QUJFMXM212JGAc
D6Eb@fm]L6m^IFid84U]HFMUCF5dLVUh3DAUHfmTIB1/IFiWM6PP<R1UL@ek;dAQ
M65CKgEbHfDPK6mQI21UKV@PJFeQIfEmN`e4IF=_I6DPK6E^IgAX83HPIG4=Ndee
K7AYL6aUA65dHE=_MG9SIG=kA65dHE=_MG9SIB0`86MUM214HGAQDfmeLV=U834P
IfEd84AQM65CKgEbHfDP<R1WIGAmNbm4HGAQDfmeLV=U86a_HFAmJFIUK7=U3Dee
K7AYL6aUA65dHE=_MG9SIG<P<b1UKV@PA5=9@fm/Kg99KF5WIGek3DAUHfmTIB1/
IFiWM6PP>21ULG]=MFadJG1/IDAQM65CKgEbHfEcNdAQM65CKgEbHfDP<21WIG@P
A65dHE=_MG9SIB0a86MUM0e4HGAQDfmeLV=U838PIfEd84AQM65CKgEbHfDP<b1W
IGAmNbm4HGAQDfmeLV=U86a_HFAmJFIUK7=U3DeeK7AYL6aUA65dHE=_MG9SIG<P
=21UKV@PA5=9@fm/Kg99KF5WIGeYIWeYIVE/LfD=OFUVIFacI@emJFIUK7=UOFAU
IPd_I7Ak;g9WHV=/MG@PN6AV82mRMf=/MG@PN6AVOFAUIPd_Hfak96TPLfEdKF5d
LVUh87AbHFicK65dIB1cHf5/I@d_GgLPGfU]HFMUI6USM20_EfUTM6PPIfEd86AU
IPd_GfPPGfU]HFMUI6USM20_B6EYIfQd86MUM21TIFH=;emTLb1OJFeQIfETJF=d
82m4HGAQDfmeLV=U86MUM21TIFH=I6mSK7EdJFeQIfEm86AUIPd_HfAk96TPLfEd
KF5dLVUh87AbHFicK65dIB1cHf5/I@e/IGIUK39kGfU]HFMUI6USM20_@fm/Kg9C
L65SIB1WIG@PLfEdHfm/Kg9cL65SIGeYIPd_GgLPGfU]HFMUI6USM20_EfUTM6PP
IfEd86AUIPd_GfPPGfU]HFMUI6USM20_B6EYIfQd86MUM21TIFH=;emTLb1OJFeQ
IfETJF=d82m4HGAQDfmeLV=U86MUM21TIFH=GfU]HFMUI6USM21RIFMYKPd_BFeQ
IfE=HGAbJGPPGfU]HGAbJGPPI6EV3F=eLW9UKWATJF=d86E^I0eTKfU]HFMUOB1T
IFH=;fU]NbAY87=UM6eQM79YN21dLV5^LfaQM6DPLf=QK6DP3FaUMVE/<W/_A6Ef
JF=UAg9QNB1cIGASKfa_LW=`HF=U830PLfEdIg9QNGeYIPd_GgLPGfU]HFMUI6US
M20_EfUTM6PPIfEd86AUIPd_GfPPGfU]HFMUI6USM20_B6EYIfQd86MUM21TIFH=
;emTLb1OJFeQIfETJF=d82m4HGAQDfmeLV=U86MUM21TIFH=GfU]HFMUI6USM21R
IFMYKPdU;dAUHfmTIB1K<20aGB1TIFHP80dU;eMYI7AX85mg86AUIPdU;dQUJFMX
M21OJ21TIFH=;dU]HFMUCF5dLVUh85mYKF5dLVUh86AUIPeSMG9bIFidI6USM21U
KV@P3FA_JFeQIfDPOFAUIPd_Hfm/Kg9YKF5WIB1gJ6EbIG]`Kg0_A5=9@fm/Kg99
KF5WIB1kHfm/Kg9YKF5WIGdPI6EVOG/_A5=9@fm/Kg99KF5WIG/=;bA^Hb1hI6HP
L6m`82m`LVmS<21hI6HP<b1YKVAUN20b86U^I6Eh86eeK20g865TI20h86AYMR1S
MVTPLgAbJFiW82mcM34PN6AV3BA^Hb0c86EaNg]`LVmS<21TMG0_Lg@`87QTIR0`
86EhHfPP<b1UN6=X86aUKVMdJ20c87=eHPekI7E`87=d<21UN6=X86MUM20^<b1]
MF`P<B1YKVAUN20a865TI21cM30PIGQSJ21WIG@P;SDi86eeK21QI6@P<B1YKVAU
N20b865TI21cM30PIGQSJ21WIG@P;S4a86eeK21QI6@=HgIY86EhHfPP<b1TJGHP
HgIY86EhHfPPLg@a83<P<B1bKfa/871eM7eVKg8PLg@aOGekNg1bKf<`86AeL2mc
M30PN6AV830PIGQSJ20d86EhHfPPK6E^IgAX83@PLgERNfAeL0ecM30PIGQSJ21W
IG@P;S<PKGE/3C4PJFiTIGPP<B1QI6@PLg@`86EhHfPPIfEd82he>B1]MF`PHFAT
3C4PJFiTIGPP<R1QI6@PLg@`86EhHfPPIfEd82ha<B1]MF`PHFAT3C4PJFiTIGPP
<b1QI6@PLg@`86EhHfPPIfEd865TI21TMG0P<SDe;S0PIgAkL6m`838e=Bh`OFUV
3C8e=Bh`86EhHfPPLgER86=fJ@eUN6=X83@PI6Uf86=fJB1UN6=X3G=d<B0c834P
LVm/K21`MGAmIVmb87=d<GemJFIUK7=U3FU]HFMUOFAUIWeYIVE/LfD=;dm@BFU]
HFMUNfU]HFMUOFAUIPd_96TPKF5dLVUh86AUIPd_HVUkLf=QK6DPM79QKW=/HGAU
82AY86=eLW9UKWA]HGAbJGPPL6m`87AbHFicK65dIB1cHf5/IB1cIGAeL69QKVAc
OFAUIPd_IFUk96TPLfEdKF5dLVUhOFAUIPd_JF]k96TPLfEdKF5dLVUh87AbHFic
K65dIB1cHf5/IB0=;emg85mYKF5WIFAYHg@P;eMYI7AX86MUM21TIFH=;emX85mY
KF5WIFAYHg@P;dQUJFMXM21WIG@PI6EV3BmOI7<PGfU]HFMUI6USM20_A65dHE=_
MG9SIB1WIG@PI6EV3Emg85mX86IQK7=U85mYKF5dLVUh83DP;C4PLVm/K21OI7<P
JFeQIfE]HG=[OFAUIPd_LW=k<R1SKg1i87AbHFicK65dI@dc82da879_K6`PKVEW
879_M65dI@e^IFLPIGQSJ21^IFLPIGQSJ21dLV5^LfaQM6D=OFAUIPd_Hg=kGf=f
KGAh865cM6mbIB1SKfiSHGAm86AUIPd_IVAk;emVI21hI6ImI6EV3BmOIVm^M4eQ
M79YN7/a830P<21OIV@P<21^IG/]<B0`831mNc4P<20`OFUVIFacIB1OHgI]M7PP
HG=dKg9UOFAUIPd_LVIk;emUKV=_I6U^I6Eh87QTIPe6KfidA6UbIF=dKg9i86Eh
HfPPJfi_MfhPN`eVJFiTIVm^M21TMG0PK6E^IgAX834PHFAT86AYHg@PHVEWJFik
<B1YKVAUN2m6BD@PKVEkI6EVOG]`Kg0PL6m`OFUVIFacIGeVKg9QK6`=I7E`82m6
KfidCV5]IB1UN6=X86AUIR16KfidE7U`IB0`86iUNbm5KV=_I6U^Ib15KV=_I6U^
Ib0b=CHPHG9bHGTPHfm`NB1TIFH=GfE^HfmTJFiTIGPP<21WIG/`85mUKV=_I45b
LR1OIFiSKfAYKVAUN21WIGAkI7E`87AiL6D_KV5]IGAiL6DPIG5kAFiSKfAYKVLP
<R1YKVAUN20b86U^I6Eh871eM21`Kg0P<B1QI6Am3G]UN6=X871_L7eYIVE/LfEm
IVmbHFa/871_L7eYIWeYIPeSMG9bIFidI6USM21UKV@=I6EVJFiUIVm^M21`Kg0P
OG]`Kg0PL6m`OFUVIFacIGdPI6EV3BmSMW=VNb1VJFiTIVm^M21VM5=YNVDP<20`
86IdDfUjIB1OIV@P<21^IG/]<B1]MFamJFHP<20`85mSMVedN21QLgA_LVDP3FeQ
JfEVKfid87=UM6I_KWAmI6EV3Bm]IW/c82da879_K6`PIVU^I6I_KW@P<b0a879_
K6`PIGQSJ21VM5=YNVDPKGE/86EhHfPPIWACJGYU86eeK20`86EhHfPP<21UN6=X
80eOIV@P<21^IG/]<B1]MFamJFHP<20`85mSMVedN21QLgA_LVDPKF5[IFI_KW@P
LfEdIVm^M7eTIFH=;gMbJc4P:20Y86AUIPd_MfAYHg@P<CHPI6USM21TIFH=;eM_
LV/g=B0g=B1cM79YKVLPI6EV3Bm>KF]kEfmbJcLe86=fLb1TMG1mI6EV3Bm>L7Ak
L7Ed86=fKWeTIFH=;fAXCfAXNdi]Jb0b83Li84i`M7eTIFH=;fAX@VAXNdi]Jb0b
834a<B1>L7AmI6EV3BmTJ5=TJ7]>KF/P<R0h<b1>L7AmI6EV3BmcIUMYI7AXNfMc
HGIU830P<21]KgIUM6lP<20`86aYKVEdKb0`830PK6U^IGA_830P<21/JFiUM6lP
Hfa_LfE`HGAX86=/JG0PLgAbJFiWMfUTM6PPIg9ULgA_LVEmI6EV3BmVM7=k;fId
DfUjIB1UN6=X86AUIWeTIFH=;fe[AUAkI7E`;dI_KWADNG1U86MUM20`86EaNfAe
L21]HGQ/IFiWM6PPI6USM21RIFMYKPek<B1YKVAUN2m6BD@PKVDP<R1YKVAUN20_
EFiYLGEUBD@PKVDPHFiTNfAUIWekL6m`871_L7eYIVE/LfEmIVmbHFa/3F=eLW9U
KWATJF=d86E^I0eTMG0_ATAUL5IUHgA_LR0b86=_L7TPIfEd3E]UN6=X83HPJFiT
IGPPIGQSJ20f86U^I6Eh86EhHfQkKF]6E20c834PLVm/K7eVKg9QK6`PL6m`871_
L5dPL7Ed86AeL7ek;gAUKG16E20a<R1TJF=d86AUIPedIFe`AU@PHVEWJFh=;dI_
KWA=HGAbJGPPFc4P<20`834P<20`GB1TIFH=;dI_KWADNG1U83<PI6EV3FAeL2m5
KV=_I6U^Ib1WIG@_AFiSKfAYKVLPIGQSJ21TIFH=;g1bKf<b838PJFiTIGPPI6EV
3FAeL2mVM34PIGQSJ21TIFH=;fId<R0a865bLV5i86AUIPd_AVm^M492KgPPFc0P
<20a835M86AUIPd_@WEYK6A3J65bNd=FA6USM21RIFMYKPeUN6=X86AeL2mVM6Ad
87QTIR1RIFMYKPegI6USM21RIFMYKPd_HfQb87QTIRmSJ79cM21gLV/a86AeL20`
86=XLR1`MG@PI6EV3FId<R0`86MUM21^MFa/86EaNfId<B1TMG0PK6E^IgAX838P
HFAT86AYHg@PHVEWJFh=Nc4PJFiTIGP_ATU486iU838PJFiTIGPP;eE^JG5eIDU4
86iU865^I7]TIFImNg1_L21`Kg1mJFIUK7=UOFI_LV5/K0d_D65YKWADNG1U838P
I6EV;e=dLVm[IEMYI7AX82h`<S@P<216KfidCF5dLVUh86UTM79QKW=VKg9]871_
L21TIFH=HgEbLVE^M6AYHg@PIFiT3Bma86EhHfPPI6EVJFiUIVm^M0eVM38PIGQS
J20`86EhHfPPL7EdOFUV3FIdI7@_L79_Hc8PIfEd86EhIF<PIFiT86E^I21UKVAm
I6EV86E^I21dIFe`AUAmJFIUK7=U3C<PJFiTIGPPIGQSJ0eTIFIYKVEVKfid86Eh
HfPPL6m`OFAUIPd_KF9kI7E`86AX@VAX84I_KWA4JG9UHgA_LWTP<B1YKVAUN21[
KVmgKPekIGQSJ21`Kg1mNfAe02<0002Q0<0oog0P<R1YKVAUN0eVJFiTIVm^M7]R
KfaTL79_HgdPIGQSJ0e]JdID871_L21`Kg0PL6m`86EhHfPPL6m`3GeYIVE/LfDP
OFAUIPd_KFmkI7E`86AXCfAX84I_KWA4JG9UHgA_LWTP<B1YKVAUN21[KVmgKPek
IGQSJ21`Kg1mNfAeL20b86U^I6Eh3FIYKVAVKfidNfmeM71bKf=m86EhHfP=KF]6
E21`Kg0PL6m`871_L21UN6=X871_L0emJFIUK7=U87eTIFH=;fecNfAeL21TJ5=T
J216KfidA6UbIF=dKg9i834PJFiTIGPPJfi_Mfh=NfEhHfPPL6m`OG]TMG0P<R1Y
KVAUN0eVJFiTIVm^M7]CJ65T@fQQLWdPIGQSJ0e]JdID821`Kg0PL6m`871_L21U
N6=X871_L0emJFIUK7=U87eTIFH=;fmeM71bKf=kIW@a87=UM6I_KW@=Ig=QMVDP
HfQbLg@PLfIGJFAdJ21WLVEcM6mbI@ecIGASJ65bMfUTM6PPI69/LfQmI6EV3BmR
KfaTL79_Hg]VM34PLfEdIVm^M0eWLf5fI@eSJ79cM21cIUMYI7AX834PJFiTIGPP
<21^IG]UN6=X82h`=B1QI6@PIGQSJ7eYIPeWLVEcM6mbI@ecIGASJ65bMfUTM6P=
IW@a82m@HFU^M5AiL6DPIfEd838PKVD=Nc0P<21]KgIUM6lPIg=QMVDPIW@b830P
IfEd87=UM6I_KW@PHfQbLg@PLfQ_Mb1WLVEcM6mbIB1SJ79cM21cJ6mgO@ek<20`
86e_MVEdKb1WLf5fIB1SJ79cM21cJ6mg86MbIG=dKg9U82h`=B0`86e_MVEdKb1S
J79cM21cJ6mgOFUVIFacIGeTIFH=;fARK7=XNf=eLW9UKWASKfa_LR1SMG9bIFid
Hfm/Kg9cL65SIB0a;S0PLfEdIg9QN@eSJ79cM20`830PKFmfIGA_87=XKgLPLfEd
Hfm/Kg9cL65SIB1cIGASKfa_LPeVM38P<21WIG@PLfEdIVm^M21SJ79cM20`830P
KFmfIGA_87=XKgMmI6EV3BmCJ65T@fQQLW/=IW@a87=UM6I_KW@=Ig=QMVD=HfQb
Lg@PLfIGJFAdJ20a86U^I6Eh830PKVEkIGQSJ20^<3DPHFAT86EhHfQmJFH=Ig9U
LgA_LVD=LfEdHfQQLWMYI7AX3F=XLW=d82h`=R0`86e_MVEdKb1cJ6mg3C0P;S0e
87AbHFicK65dIB1THVacJ7eTIFH=;gAcNg=XKgMmI6EV3BmdHG/_GfaUM7AULU=`
HF=U87QTIRmOLg1QHfEHM79Q87QTIWeTIFH=;gAVNbmOM6EhM5MYI7AX87QTIPd_
GfieKE=`HF=ULb1hI6H=;emcM79YKVM<IFiWM6PPN6AV3FAeL0UcM79YKVMgJFAd
J21`Kg0=GfaUM7AULU=`HF=U85mcM79YKVM<IFiWM6PP<B1cMF8PKGE/865TI0eO
Lg1QHfEHM79Q85m^MFeCL65SIG<PKGE/865TI0eOM6EhM5MYI7AX86EhHfPPLgER
82mgI6UV87QTIPeOLg1QHfEHM79Q830P<c8=MfAYIR1OLgAbJFiWC6E^IgAX86AY
MPeOK6EdM6EbDg1QHfDPHFAT3C0P=R0]<B1bKfa/865gJFAdJ7=XKgMmI6EV3Bm`
HW/_Ge1QIfECHGIU87=QMVDPI6EV;g=XKgM`HFMUNgeTIFImI6EV3Bm`IG]OD65W
IE=QMVDPLVEcM6mbIGeTIFH=;g1]Nem`KB1SMG9bIFidKF5dLVUh871_L7eTIFH=
;em`KB1]HGAbJGPPI6EV3Bm`Lg]cJ6mgL65WIB1OL6dPLfEdKF5dLVUhOFAUIPe/
IGIUK39k;fEV87]WLf5fIB0f865bLV5i865cM6mbIB1SKfiSHG@PI7E`86EhIF=V
Kg9]86MbIG=dKg9UOFAUIWd=NbmUIW]WLf5fIB0f865bLV5i865cM6mbIB1SKfiS
HG@PKVEgL65dJ21TMG0PHVEWJFhPCF5dLVUh86=_KV=QM0e2@Vmh86AeL21TMG0P
<21WIG@PIGQSJ20a86MUM21]KgIUM6l=I7E`86AeL20`86MUM21UN6=X83<PIfEd
86aYKVEdK`eTMG0PI7E`838PIfEd86EhHfPP<b1WIG@PK6U^IGA_3FAeL20b86MU
M21UN6=X834PIfEd86aYKVEdKb1SK6mcIG1QM6P=HfaYL21^IGM`HGAX851QJFid
D79_Hb1UKV@PIg9ULgA_LVEmI6EVOFUVIFacI@d_HV=kLf5fIB0a<B0a879_K6`P
<C0PI6USM21RIFMYKR0_@T9_N20e834PLVm/K20d865bLV5i865cM6mbIB1TIFH=
;deQM79YN20g834PLVm/K20f865bLV5i865cM6mbIB1TIFHP;dI_LVeDNG1U834P
I6EV;e1QJFidD79_Hg/_L70PIfEd86EhIF=mI6EVOFAUIPd_IF=kL6m`879ULgA_
LVEmI6EV3Bm`LVU^M7I]Nc4PMVebIF=/HFU]87I]LgAQM7Ec871_L21UN6=X871_
L20X820P820P820P820P820P820P820P820P82USMW<PL79YKW@P:5a^:G1bJFid
86I/MG=XOFAUIPd_LfEdKgIULW1bJFid87MXIG9U87]`Kg1mNbmcIGA_MVEbL79Y
KWAkL6m`OFAUIWeYIVE/LfD=;g=cM78PNb0_97=cM79c86EhHfPPI6EV82lTLg=d
LR1UN6=X86AUIR0_97=cM79i86EhHfPPI6EV82lTLg=dLWPPIGQSJ21TIFHP;d=_
MG9YIG8PIVU^I6I_KW@P97=cM79c80ecHf5/IFI_KW@PLfEdIVm^M20TLg=dLWPP
97=cM79i86ed87=dKB0a82da87=SHFaU82AcLgAb87=XKgLPLWA]87dPI6EV3Bm4
DdU2IFMYKU1QJFidD79_Hg/_L70PKF5bJg]SMG9bIFidIVU/IB1dKf]UKR1^KgAk
OFUV86AeL2m4DdU5KVA@HFU^M51bKf<=2FEaNg1_L21SKgE^M7A_KF5bJb1QLW9Q
NB1QLgA_LVDPHgIh869YKV@P;fEhIF<PK6mQI5eSMWPPI6EV84ACBDE^I51QJFid
D79_Hb1UN6UdO@d9Nf=_MFidM6m]HG9[83<`<21WM7]SKgE^M7A_KF5bJb1QLW9Q
NB1QLgA_LVDPHgIh869YKV@P;fEhIF<PK6mQI7eYIWeYIVE/LfEmK6m_L7eTIFH=
;dACBDE^I51QJFidD79_Hg]SMG9bIFidI6USM21UKVAmI6EV3Bm4DdU2IFMYKU1Q
JFidDgERD79_Hb1kLf5fIB0a<B0a879_K6`P<C0PI6USM21TMG0P;g1486EhHfPP
I6EV869UIfU^80d9;d92KgPP=B0a879_K6`P=21QLW9QNB1QLgA_LVDPI6EV82m=
HGAbJGPP=b0a879_K6`P=R1QLW9QNB1QLgA_LVDPI6EV80d9;dI_LVeDNG1U834P
I6EV82m@HFU^M51bKf<PNb0_L70PIfEd86EhIF<POB1TIFHP;g1`OB1TIFH=;dAC
BDE^I51QJFidDgERD79_Hb1kHVU^I21TIFHPIFiT8714OB1TIFH=;fUQHB1k;fUh
86Uh86UhKR1QI6@PI6EVOB1TIFH=;fUQLc8PNbmYIf5`86EhHfPPI6EV82mOLg@`
86UQ86Uh86UWHG0PHFAT86MUM21TIFHPGg=d<7dPI6EV3BmYHG<PNbmcM30PJF4P
JGPPIfEd86AUIR1YHF4PLg@`OB1TIFH=;fTh=G<PNc0PJF5c<R0_@E=3BDTh=DAU
HfmTIB1VJFadIG8PLg@`879UHFAcM79YKVLPL6m`86UQHGdPI6EV3BmYLVaULb1k
<21YHG<b82m1Dd=9BCPeA6ESKfAU86IYK7AULR0_DWE^C6E^IgAXA6ESKfAU86IY
K7AULR1cM30PLVEQI7=dLVU^Ib1`Kg0PJF5QOB1TIFH=JFiYM6UQK6UjI@eUKV@=
9BE5KVABIG=_MG9SI@e3ETAYHg@PHVEWJFhP<21YI20a86IT3EmUKV=_I45bLR0`
3E/=<cT_LGE_M6EcJFiWK6DP>CH_Ig9QMVD=<C8h;f9eK6aUM2mRMFa/IG@_LGE_
M6EcJFiWK69QLfD_IVa_LVU^;g5eKgAUI69/HV5cIBmUK6aYL7=YLbmTHFMWIG8_
I65WIfEbI69/;f=YLV=eKFI/IGP_L6EbM6Q_MG=QKV@_Df=QLVm^;fMeJFacJFiW
K6aUIW@_CdD_HWE/K6Ed;f9eK6aUM2mRMFa/IG@=;f9eK6aUM2maMFmdIFaUIW@_
LGE_M6EbJFMXM2maMFmdIFARK6aUIW@_LGE_M6ETHVabJFMXM2mRMFa/IG@_IFiT
HG=X;fE]I65cJ2mdJFaTIBmdLV5TIFeQLV/=;g=SHG9_KPd_IgEYK7=YKVM/LVUW
J7@_KfD_HWE/K6Ed;f9eK6aUM2mII6UULVEcJG<=;f9eK6aUM2mUN6=/HFeTKgM^
;f=UKW@_LgAULVaYKVL_HgEbLVE^HgT_NFE^;f9bKf]UKV9QLRmcIF=dJFm^;fAY
IG9ULfUc;f=_L7UbJFMXM2m_LVAVIFeYKVU^IBmWMFU/K6E]KgA/IFId;fa_IfUS
HFa^Kg@_J7U`J6E^;g9UIfUcM6EbIF@_KF5SLVm^3BmTIFMbIFD_L6aeLfeYKWEc
;gAgKg=eL6EbJFmb;gAXLVEULgE`IG9YKg8_HF=eM6D_KGD_L65bHFMbHG1X;g1U
LVU_I6=UKWAULVET;f=UI6U/K64_KfiULgE`IG9YKg8_Kg9TKF5cHgE/JFiU;fMe
JFa/IFe_M79YIfQd;fm^IG5eHG9dIG8_KfiUJ65/IRmdJ79UIG5eHG9dIG9c;g5e
IG=dJFm^I6mgKPd_@FMbHGIU;d5QHgEdIBm1HfUbHgE]IVaUN2m1M6U/I6D_@FAY
IG9ULfUc3Bm1LVU^I`d_@DD_@f=UI6U/K64_AFMbHGIU;dEQHgEdIBm5Ig9QMVD_
AFAYIG9ULfUc;dUWLV5fIBm9HF=eM6D_BF=YLV=eKFI/IGP_BFAYIG9ULfUc3Bm5
M6P_CWAYK6AU;dmWLV5fIBm?HF=eM6D_Cf=YLV=eKFI/IGP_CgAYK6AU;dmTJFEb
IG=YLbm]MFadJG1/NBm?LfaQLfP_EFMbHGIU;eEQHgEdIBmEHfUbHgE]IVaUN2mE
I6UULVEcJG<_FF5SMGAU;eAXKg9^;fMULVeQKVARK7<=;f5WLV5fIBmQHF=eM6D_
HF=YLV=eKFI/IGP_HGAYK6AU;f5TJFEbIG=YL`d_HG9YKVL=;f5U;f=SIFAYK6aQ
;fEWLV5fIBmUHF=eM6D_IF=YLV=eKFI/IGP_IFAYIG9ULfUc3BmYIg9QMVD=;fUQ
HgEdI@d_JF=YLV=eKFI/IGP=;fUTJFEbIG=YL`d_IGAX;fidJFaTIBm_Ig9QMVD_
Kf5SMGAU;fmSJG9SMFeVK6Eh;fmdJFaTIBm_I6UULVEcJG<_I6UfJFAU;fmcK65c
J2meIg9QMVD_MF5SMGAU;gESJG9SMFeVK6Eh;gETJFEbIG=YLbmiHF=eM6D_M6Q_
LVh_NFAYIG9ULfUc3EdPL7Ed3EmUKV=_I45bLR0a3E/=<cT_LGE_M6EcJFiWK6DP
>CH_Ig9QMVD=<C8h;d5TJFEbIG=YLbm1LVU^Ibm3HfETJFa/HBm5HF=eM6D_CWAY
K6AU;dmTJFEbIG=YLbmEI6UULVEcJG<_HF5SMGAU3BmQIg9QMVD_HF=YLV=eKFI/
IGP_HFAYIG9ULfUc;f5dJFaTIBmQLVU^IbmSHfETJFa/HBmUHF=eM6D_IFMbHGIU
3BmUHfUbHgE]IVaUN2mUI6UULVEcJG<_JF5SMGAU;fUWLV5fIBmYHfUbHgE]IVaU
N2mYI6UULVEcJG<_KWAYK6AU;fmQHgEdI@d_KfMbHGIU;fmSJG9SMFeVK6Eh;fmT
JFEbIG=YLbm_M6U/I6D_MF5SMGAU;gEWLV5fIBmeHfUbHgE]IVaUN2meI6UULVEc
JG<=;fAQIfMULRmTIFMbIFD_HfE^M2mcM6EbK6U^IbmcIF=dJFm^;f9eK6aUM2m`
HG9QIg9QL6P_IfEbKF5^I69/L`d_LVEWJG=dIG9UI2mSKg1iLVUWJ7@_M79QI6E]
HG9[;f5SMGAU;fAYIG9ULfUc;fi_M6EaMF5/;d55;dmcK65cJ0d_JFiVJFiYM7T_
L6aeLfeYKWEc;faULg=ULGEQK2mWLVEQM6EbIG5eHF`_NFE^;fee;g1QLWAYHFaT
JFIV;g=eKFeQM6U_KPd_L79_I7ESM2m`JBmYKWAUIg9QK2m_LVAVIFeYKVU^IBm_
LVA]HG=SMFaYKVD_CfeUIf4_HFD_Kg=/HG=X3BmaMFEcM6U_KVA_Mfh_IGQSK65]
I6mgKRm/KfMYHf5/KVmd;g9QI6USHF`_IVa_LVU^;f5`L79_N6EaMF5/;dAUK7AQ
;fMeJFa/IFe_M6aUIW@=;fMeJFa/IFe_M79YIfQd;fE/K6U`LfUc;f9/HFi[;d5W
LV5fIBm1M6U/I6D_CgAYK6AU;dm5;fmU3BmUKVAQLfP_IFeTHG=X;g5eKgAUI69/
K6EVM2maMFmdIFARK79YIfQd;g5eKgAUK6EVM2maMFmdIG9YIfQd;fAYMVUTIBm/
KgYUKVMU3BmiI6UULVEcJG<_FFAYIG9ULfUc;fIbHF=dJFm^;f=eLW9UKV=i;fMe
JFacJFiWK6aUIW@_IgEYK7=YKVM/LVUWJ7@_IVT_IV`=;fAQIfMULVARK2m`IG9Y
KfASIFidIG9UI2maMFmdIG=YKVM/HV5cIBmaMFmdIFARK69QLfD_L6EbM6Q_MG=Q
KV@_@F=YLV=eKFI/IGP_AF=YLV=eKFI/IGP_@F5SMGAU3Bm5I6UULVEcJG<_AFMb
HGIU;dUQHgEdIBm9HfUbHgE]IVaUN2m9I6UULVEcJG<_BFMbHGIU;dmQHgEdIBm?
HfUbHgE]IVaUN0d_HG1`K6D_CfMbHGIU;eEQHgEdIBmEHfUbHgE]IVaUN2mEIg9Q
MVD_I6mdK6EcLfT_HfUbHgE]IVaUN2mdJFaTI@d_KF5SLVm^;f9bIGIU;fA_M65S
HfE^M2mbJFiW;f=UI6U/K64_J7E^If5bMFe/HGEd;fmWKfiUJbmSHG9_KPeM871e
M0eUKV@=9BE5KVA@LVm/KfLP3BDU@VEWJFiCIGAeL20=@eI4JF=d869UIfU^3@dU
9D9UIfU^DVEcKgEbHfDj86I_KW@PAfE^IGIQ3C4d86AYHg@PHVEWJFh=;dI_KWA>
HFeU82m7IFiUMV4PI6EV3Bm6KfidCF5dLVUh85/`;S0`<B0`830P<2h`<34P<20`
GB1TIFH=;dI_KWA9KVI_834`86AYHg@PI7E`869UIfU^3Bm6MFa/CV5]IB0XAfE^
IGIQ:B1TIFH=;dIQKFU/NDiQKFDP:4MUKVEfHBTPI6EV3BmEKVAULVaYKVE@Kg=Y
M6U_KR0]<C0`86AUIPd_EFiTIG9/JFiUE6QYHf]^IG=c83D`86AUIPd_DgAbJF]U
KgEdD6mcJGAYKfhP<c0`86AUIPd_DgAbJF]UKgEdE6QYHf]^IG=c838e86AUIPd_
EfEYIfQd82Q=IFAYMFdY86AUIPd_BGAQK6US@FiWK6DP<21TIFH=;fUcAVUhIFA@
JGASJ21VHFacIB1TIFH=IFiT86AUIPd_GfM/NG1X82QH820Y86AUIPd_IgP=N`d9
<B1UN6=XN`d92FAeL20a=R0X820Y86=fLW<PGfM/NG1X86EhHfPP<B1UN6=X871e
M6U^M6EbMV5/834PJFiTIGPPIGQSJ0d92EmWK7U`J21SMVhPL7Ed3@T9OFI_LPem
I6EV3Bm@HFU^M5AiL6DP<21TIFH=;dI_KWADNG1U834PI6EV3Bm5KV=_I6U^Ib0b
=CHPHG9bHGT=<20a838e=B1k834PJFiTIGPPIGQSJ20_;Vi_M6AUIR1`MG@POB1V
Kg8=<c0P<SDe86Mh3FAUIPd_AVm^M492KgPPFb0`830P<20`85dPI6EV3F=eLW9U
KWATJF=d86E^I0eTMG0P;e1bJGIQM6DP>21TJF=d86AeL21RIFMYKPd_DTAkLgAb
JFiW86=eLW9UKWAVJFaU86EhHfPPLVEQI6QUN7=dLVU^Ib1`Kg1mI6EV3Bm>A7]T
IFImI6EV3Bm>D7]`MGAmI6EV3Bm2K7EUEV5/MFEcFb0]<SD`830P<S8`<20b<S0`
GB1TIFH=;deYKTIUHGAeLVDPNb0a=R0a=WdPI6EV3Bm`HG=cMfmbI20e>3<i86AU
IPd_DgERLW<P=3<PHG9bHGT=CT@=<R1YKVAUN20_@fQQLU=dLVU^Ig<P<SDf86AY
Hg@PI7E`869UIfU^3Bl^KVmdI6EV820a<21BA20b=4E3@T@`=C=5@d54<cDbASDh
<B1>A0d_F30a820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;eP`
<R0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<3<P834b8594
838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F30d820a<R1BA20b=4E3@T@`
=C=5@SU1<3LeA44d>4=3ADDPCT@=;eP`=B0P<C8PDT@P<SA5@d94<3DcAD8i@C0g
=DA1=3Q3@dE584i43BmH<3HP834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5
AB1>A0d_F30g820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;eP`
>20P<C4PDT@P<SA5@d94<3DcAD=1A3<e<THe>3He<R1>A0d_F30i820a<R1BA20b
=4E3@T@`=C=5@SHe@d@i@S4a=48`@DDPCT@=;eP`@B0P<C8PDT@P<SA5@d94<3Dc
AD8i@C0g=DA1=3Q3@dE584i43BmH<48P834b8594838dAD=2A30e<dE2>D4`=cE4
@C@h@d=5AB1>A0d_F313820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDP
CT@=;eP`A20P<C8PDT@P<SA5@d94<3DcAD8f=D=4>D8a<CA2<45584i43BmH<4DP
834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F316820a<R1BA20b
=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePa<20P<C8PDT@P<SA5@d94<3Dc
AD8i@C0g=DA1=3Q3@dE584i43BmH<C4P834b8594838dAD=2A30e<dE2>D4`=cE4
@C@h@d=5AB1>A0d_F34b820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDP
CT@=;ePa<b0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<C@P
834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F34e820a<R1BA20b
=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePa=R0P<C8PDT@P<SA5@d94<3Dc
AD8i@C0g=DA1=3Q3@dE584i43BmH<CLP834b8594838dAD=2A30e<dE2>D4`=cE4
@C@h@d=5AB1>A0d_F34h820a<R1BA20b=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDP
CT@=;ePa>B0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH<D4P
834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F352820a<R1BA20b
=4E3@T@`=C=5@SU1<3LeA44d>4=3ADDPCT@=;ePa@b0P<C8PDT@P<SA5@d94<3Dc
AD8i@C0g=DA1=3Q3@dE584i43BmH<D@P834a8594838dAD=2A30e<dE3@D@c=C96
=CPf=C8PCT@=;ePaAB0P<C8PDT@P<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i4
3BmH<DHP834b8594838dAD=2A30e<dE2>D4`=cE4@C@h@d=5AB1>A0d_F38`820a
<R1BA20b=4E3@T@`=C=5@SHe@d@i@S4a=48`@DDPCT@=;ePb<B0P=34PDT@P<SA5
@d94<3DcAD8f=dDc<cI1@C@g<CDa=3A4@CDh<dA2<T8aA4HcAD51ACI3A394=cM1
=CTg>44g=c4f3D<`ASM1@SPc@cT`=c=3>30a<S0i>38PCT@=;ePb<R0P=3DPDT@P
<SA5@d94<3DcAD8i@C0g=DA1=3Pc<THg=3=6=cHi<495A4@c>34e<d8h<cTc=4Ha
ACLhA3U1=D@b>4I23D=5=T4h=38a=D93@TDgASU1=3TgACL`<CQ1ACPaA21>A0d_
F38c820a<CPPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6>4=6>356=48i<SHg<S4b
>493>DDe@d55@S4c@DDbA30c@dA5ATI53CPb<dE4<SHa@CHd>CLbAT@e=dHf=cDb
<d<`@d8a>48a=DHb@cHg>48b=d<a>C55=SDe=D4f=4<g=DI3<Pe6<T4f=S@i@CA3
=THg=c0`>4I1=3La<3U5<dA2<d8e@C51<c0eA38fAC13=S<b=CA5=dE4<3Hi>D<g
>34=AT52<30h>4<i=T8`@SU2=TI5AS52=C11<SE4<CU2@c0bADE2<S@b<C92AD96
=D@g<C8i=THa@d4PCT@=;ePb=20P<SL`8594838dAD=2A30e<dE2>3Le<d=1=4@f
ASL`A48a<dDdAC8`=TE3>D8g<C=5=SE3=30c@c<i@STb@CL`ACTf>@de<CPh@D=3
>3<c<4<eAD4bAC8i@d8c@c8d@TDh=CU6A3TeAC@`<DH`<SDh=c<g=SLa=3<i@c<`
<d=1AC@=<34d=S@eA3PfACD`<SLc>3U1=S0eASM6<S=2@C8d=3Pe@T96ASA1<CHe
>393<3D`=dDa=3@dA452=C943C@e<d@f@cPe@S<f=cE4@dA6AC91<4De<S16A3@i
<S8dAC0b=d@e=CL`<D55@d8a<4E5@SE3<T54@CDc=0d`<3<h=T4e<cTe<D94@STb
=dE4<SLh=c93>C<a=48f<cLi<SA3ACTd=cE5@SDi@CM5=D<g>CM3=D95=c@=>4A3
<d4c=SDi=S0h=S16=c=5@C4a@d8gAD8f<cM4A3Tb=T=3>D91<3U2=c@a<DHe<3<`
@SLf=4I5@DA53CD`ASHi=TA6@CQ4>D8f>4Di>D8b=d55=SQ3A4DaAD4`>CU2>DI6
ASTcATHhAS4c=D8b>44aASU6<C8aA@dgA3@c<T<`<4<e>3<aAT=3>4Dh<d<b=C93
>C8`ASPf=cLh=S12>DI2@dE4<C<e@c16=3Le>393@DI4<DH=>DHh@DA6>30f<C@b
ATE4@C@h=CDg@d<d@D8g=CI6<S55=S@d<cA6<34dASU1A4<e@cTc=4@c<48e<S<h
84i43BmH<SDP838g<B1BA20b=4E3@T@`=C=5@T94>4@hADA2@CDdAT54=CTc<c0`
@CTcA456<CA1<S4eAT51=SM5ASDe<356=SP`ASL=@S<`=C95@D8g<THa=3<e<T<f
ASTc<C52AST`@S<h@SQ1=dHb@T@g=TE4=44d<S94A3Pe=3Q3=S=3=D@d3CE2<c56
=C52<C92<S@dAS@d=d@a<d8e>C<c=4<hAS<c<4<b>C@aA3Dh=D=2>4Hc<48e@S0c
<cLa<4@g<@e6<30g<cA6ACU5A3A3=c@`@c13AC8gA3Dg@S92AC8d@D@g<SU6<dE3
@c0b=S0g@T@`<CDa>456A4I2>CH=@C4f=3Q2=cHg@d=3AS14<3DhAS92<34f=4E4
=S8d=CDe=cM3>4Dd=S13AC@iAD=5=3@g=cLb=DI4=S563C4e<3@a@dE6A3He<c0h
AC96=T=2<T<g=c0i=d8g=d@f=cLcA48b<S56<T8g@cDb@CLa@S16@CI4=4I2=`di
ASE2<d4g>4Hf=T=3<4E5=4Db=S<h@dE2=cI4=SH`@THd@SLfA391<3Dh<CDg<CPd
<c0h=4=2>CPf=DD=<SM4<3=2=4@eA3E5=T4g>4E2=cA5A3Db@S91=3HaATE3@D<a
@SDe<S<g@SHg@D@hA44f<SDhAS0`=cQ23DI2<DA3ASTd>3Hd=44fATI5=SDh<T<a
=S8c@D=5ADE1@T@a>CDb@SU6>44g>3U5>D@`ASDe=CDh=CTh=Pdb=21>A0d_F38f
820c=3PPDT@P<SA5@d94<3DcAD8h<c4e<CTaADH`=3M4<C<gA3U5>DI3<4<h=T<g
=DHf<4Db@CD`<dHd>355@TH`>4I53C8g=3De<d=1<C52=dI2=S95=c55@cU3ASA3
=CM6AD4d@CA2<c51<3=4@cHe=cDi=CHa<T8i>DE3<D4c<0dcAC8e=C11@DH`<cI2
@d4iA3Lc@cHbA3@`=cE3@d8`<C<f<DHc=cPb>3Dc=C<i<34a<TDf<3Ta>3HgA4D=
=dA3@cQ6@d53<30d@dI6>3Ti<c@g@d8bASPf=D4iACHe=3Hf>DDgA34e@CP`ADI6
<TA4ACTg=SPiACPf3C4c=4H`=D8h<CQ6<cI1<SA6@cDc>34`<CPh<456=CI2>D@g
@cD`<TDbASHbAD@f@c0b@CU6@CQ4<d4g=@e1=d4aA34b=CA2@DDa@S94=DI2<D8a
=4@aAS@a>355@S94>CI4A312=SI5=dDa=3Hd>4E2=cDf=3Dh=S0=<cU5@D8c=c4f
=STi>496<313=cU2>3Df>3Hb@CH`>D=6=CLc>C0c<SDcADA4=48eASE1=cI5@c96
<C0a3DE6@S4e=DDe@SE4AD4c>3M4@dH`<SDi=S8dA3E3A3Tf@S<`=D<gASTd<S4e
<C0`=T<`ASE3<c0`@cA6APdc<T94=DA1<cA1<c=3>C55AS94<SHeA4Dg<TE1AT56
>C96AS0f@S0e<38gACLf=SE1ADE3@d93<CQ6@cD=>DI6=3E2=SM1>C8aAT@a=SE2
AC=6A3<f@T52<4HgA4@g@d@h=TDiASPe<c=2<T=2>4Dg>D4b<T4g@d8`3CTb=4@g
@CA2@T4b<cTf<cE1=C<a>3Q6@D8h=SE1=CDeAS<b=38`>C56=T8`>CLbACDg=D54
<cTe@T4eAPdi<cPc>C=6@cPi<cD`A4@d<cM2>44b<cI6<3@c<CT`@SU1@SPPCT@=
;ePb=b0P<c0PDT@P<SA5@d94<3DcAD8f=dDc<cI1@C@g<C@f>496ACPhAD=6=3Li
@CHfA3Lc<3La=S@d>44c<C4dASLi<TDe84i43BmH<SPP834`=B1BA20b=4E3@T@`
=C=5@STg@T56=4E1=SM2AT4e@S92=cHi=SA2AC<`<cTa>C<d@C=6>3Q1>DI6>C<d
=c@d=C8=<S8a=ST`=cU1=cE3=DHe>4DbAT<eATI2@D4`A391=3@d=4Hg=S56A4A4
AC<eAT96ACTbA4<f=SM4=S523CDdAT@e=S@c@T8g=456=c=2@SLhA48aAT8c<dHf
@S4f@D<h<4Hd<D4a=SPf<S0a<C14<DE4<d91=DDhA0de>3Pd<D4d=S@b<C0h=dE3
=4=6>C=1=C<a@c13=cHPCT@=;ePb>B0P<C0d8594838dAD=2A30e<dE2>CM2@DHd
AD4f=3Pc<c8c=313AD8dASTc=d8`<316ASLc=C4fAS4a=4H`>313>4=4=`e4A34h
<4Dh@C13@S8e<C0e<C0a=CTd=44eASTbA30f<THi=D8g=c@h<THdA455<492>D51
ACA1AC12>3T=<CTc>C=2=T8b<SM2@SQ3>CA2<4H`@D@`A3@hA3E3@d@i@c13<3<h
<3TaA354<TDf>4<aASQ4=DDa>4<b3CPg>3U4A44`=dDg@c0c<391@SA4@C8c=CPf
<T8PCT@=;ePb@B0P=c4PDT@P<SA5@d94<3DcAD8i@SQ4AT=6<cHe@dE4>CHhADA5
=C=4@S@c<DHb@CTc@c8a=S4iACHa=C8`@S<h=C533DA2<d8c=4<i=T8h>3<a<c95
=4<iA4I5A34d=392=cDb=dDa=3Q1<D56<cA4<cTa<D4e<dDg<4D`=3Pc=@e6@d8`
AS4d=T<gA3M6<3Df>CU2@CM284i43BmH<T8P83@i8594838dAD=2A30e<dE2>3Le
<d=1=4@fASM5A4A1>DA6<4<cAS94=T<e<cPa<4<a<D<f<SHg=C8a<T93=4@`<`df
@cHb<4Dc<c4`=STd@SU2=38aASQ2<dHhA34a>3M2@D8`@CI4=21>A0d_F393820g
<21BA20b=4E3@T@`=C=5@SHgAC<c=T51=3Hd=T8c>4<c>44c=S<e<4A3@dI6=dE6
=D@g>D@fAS4a<d52AS0d@cP=<D@g@d94ASM3=c13@T=6A3Pb<TI6@cDf>D<d<CQ6
@c@h<T8f=c15=T@g=SLc=c=5@c4bATA2AS0i>D<b3CE1>D<c<TDgAT<g<CDf<C8h
@SE384i43BmH<T@P838f8594838dAD=2A30e<dE2>C8gAD96=c94A48h@DA1@CTh
@c<c<S<c<C@dACE4A3I4<c<hAT@fASHPCT@=;ePbAB0P<SLPDT@P<SA5@d94<3Dc
AD8f=dDc<cI1@C@g<CHg<CTg>CM1=d52<dA4@cE4=DDe>C=1@CLg<T54ADI284i4
3BmH<THP83<`8594838dAD=2A30e<dE2>CPf>4=1=3U5ADHc@dDc>C4`@c@`=c<h
<T54@T4h<SHaASDb>44gATHd@CI4@d8h=b1>A0d_F3<`820a<cDPDT@P<SA5@d94
<3DcAD8h=cDc@d4dA3I6>316@S4h>394=cPg<S8i>3Pg<d8eADI3>34bATI3@SLe
=CLb=d<f3D4b<CQ3<3H`@S4c>CE5AC0h=d=5@C@a<3E6<d@g=34h@C0h>CM4<T8a
<CI3=T<h<c@dASE6=SE1ACLg<0e5<T=2<4@cA38h>DI6=D95@c4b<CHi<c8f>44i
<c56=DDhAT@h>DA4>CE4@CM4@CE4A30b=T4e@dI2<T4=@T@`=T=4=c=5=CM5=SQ6
=S96>3Ha>C8`=34i<48h>353<S8d=TE3ATA1>D<d@cD`=44f@S8a@dHd<cPa3CU1
=T8a<SLf=d<b@S15<c4a@cDb@c96>D4i@S<c>21>A0d_F3<a820c=B1BA20b=4E3
@T@`=C=5@SPg=C=3@CA4=THh<THh=CTf=3M3>34d>3<h@SQ5=3Tb=cD`=S54A4I6
<cLb=T8d=cT=<DE5<cLf@D@b=21>A0d_F3<b820a=CPPDT@P<SA5@d94<3DcAD8h
=cDc@d4dA3I5A34iACTc=S94>CDi=C0aAD4g=cI2AC15@D8a=3Pa>395<c51@dD`
3D51<S92=T4bATE2=c11>3A5<D56@S4dA3I4>4I2A3Q2=CPe<D94=S53A4Dc>30e
@c@cA38eA4@`=d8`>0dd<44h<SE1>3U3@CI5>DE2<c0i<30b<3PdASQ1A48i=3Pd
ADI4@TDg=494AT@c<CPe<d4gAT8c<T8a=4H=<SU5=STc=D4c<S=4<CTc@CI6<3E6
=cHe<48e<TI4>CQ2@T@e<cI2<CI2=DDc=c<d=c@i@c0d=SE5<T@g3DD`<cU3@cPc
AD8h=cI5>3Tc=cA3=d8f=CI5=c8`<DA2<4Ha=S<b=S<`=cDdAD96@CE6ACHdAT<h
<CPf=0da@SPg@S<bA3PiA3E3>C9584i43BmH<c<P838c<B1BA20b=4E3@T@`=C=5
@SPg=C=3@CA4=THh@T8hAC94=cA2=30b<44d>3E5@T8b@dDf@cLb>353AD@a<TE6
=C<=A4<b=SM5>3A1=cTi>CPa<ST`A391<D4cATHc<4<a=4<d@CPi<SDa=4@i=T@h
=3Lc>CHf<c8g<4E2ASM23CLcAS0h=4Hi@S0d@c<`<cLf@CM6@THfASE4AC0fA4E3
>C<d>3E5=CQ4@S14=cPfAD@h@S@c<C0i@d<`APd`ACD`@c14=S<aA312<D@a<4E2
=3M5=T4d=D4fADA6ACA6=TA2ACA5=SHd<CU3A4@`AT51<394ACL`@c0=>3TgA4@d
<SI3=c<b=DA1<d<e<492>D<d=d4h@cU5>DI5AS16=CDc<dE1ASTi<3Li<cThASPe
@CDe=DDe3CE3=cHeA3<f>D<g=cHh@C@b=4I3=S=2<THe@d93=c4h=cM1AC=3<34h
AD8i<4A4@c@`@CTa@S8`>C4e=`df>CPg@dE6ACHe=CM2@DA4@C0`=3<g<S=1<DE1
>CA2<C8c<DDd@SE6AC0g=S8b=STcAS0g@C=6@dHc=c0=A491>C=5=C<f<CTaA4<f
<T@f@D55=d53=SLf=S<c@TA5=314AS@e<SLc84i43BmH<c@P83H`8594838dAD=2
A30e<dE2>3Le<d=1=4@fASLhASLgAC15@dI4AS92A4<a<CHi=cI2=S12>4Hg@c8c
@SHd@DDc@@e4>3Lf<T=4=DA6=c51=c=3@cHc=D4e=38a<454<44c@cU4@d<b<S<d
@d4f<D56@S16<4I1<TA1<493=CHPCT@=;ePc=B0P<C<b8594838dAD=2A30e<dE2
>3Le<d=1=4@fASQ3=T54A4Dg@cT`@d=3=T55A3I6AS8a<d@a>4Hg<c@eA4Di@STb
=@df>3Pf=STbATDb=3A2AC@b=SPd>DI5@D<h=T8gA393=4Hb@C<d@C8b<S8g@CQ6
<3Tb=38fA34a>DHa@d4=@c8e<4Hc<D4h<4=4@C16<355@T=5=d<hAT55AD<i=CE5
=D@f=3U3>C@a=cDi=3@hASDa>4=2=D55=S4a3CHc<D@g=d<g>451<cPc=44f>3U2
<4@f=3Pc<d@dACL`>3I2=SPf@SI3=d4c<C93AT<d<d@e=cHdAT=5A@dg<cThAD=6
AT93@cPi>3Ha<T52>491A3<PCT@=;ePc=R0P<S<f8594838dAD=2A30e<dE2>3Le
<d=1=4@fASQ1=SL`@S51@SL`AS53<d@`@d@d<CTa>4@h=d53=cE2@D8h<4Hh=0df
<30`<CE6A3Pi@c0c>44h@T8c=30a=SM6>34a@c<d=D8f@DA1<3TfAD4c>C=5>C=4
=495<T<c@SPd=T4=AD96<C@`AT96=4Di=30c<3M2@cHd<D<aAD8f@CPh=DHd<CTf
AS4a>D54<cP`=D54=d92<3T`<CTd<CE53D4g>CQ4@SI3=d@a>392@CA3ASPdAS@b
<THf<T<d=C4h<CDcA4DeATHa@SQ6<cLb=STa@S0g=452<S<d>@dc=cH`=cI3ADHe
<S0hAT54@TA2@C8d>3A3=d94@cD`A3@f=cHh<D8h=356<T4g<4E5<4E4>C<i>DHd
ACT==c13<SU6=D55=3TeA3Le=SPi@C14AC4gAS<dASE3@S@b=C<b=3Li=SH`<dA5
AD96>DA1=3Hd@d@fA3933CU6<4Dg=dHf=CM6=dA1=4Da@T95>D=6<D=6<c4fASDi
>38a@dDa=dE3A3DcAD@h=c91>CA6<353=D@d@@deAS11<d@`@CI2ADHg=S0b=3=4
<TD`=T@d<3U4<C0e=d92A44iATA4>CI1@D<b>4@c@d<h84i43BmH<cLP83Pf8594
838dAD=2A30e<dE2>3Le<d=1=4@fASPd@CA5=cI4AC13@C51<S@b=396>CE4=C4a
=3A6=c0eAS0a=c4b@Pe2>D8hACA3=30d=D@eASTg>DDh<SQ4AT91<C<i=dE2=T4i
A4I5<c51>3Tf@SM6>38f<C4c@d4h<d@a<D<=A3@i>CTi=T=5<SA6<CLh@T<e>C4h
>D<c<C@cACE2<3DhA4=4@cE4@SU3ADHi=S13=cDa=B1>A0d_F3<h820c<3DPDT@P
<SA5@d94<3DcAD8h=cDc@d4dA3I6=cA5<4Hh>CQ2A34`<3P`=4Di=455=S<g<S8i
A30f<d92ACTi>CE53C8f=CQ5>C8e=4<fA3U2<3Pa>3A2=493<3@g<d<iA3D`@c0h
@c4cATD`=c54@T94<dI3<C4i=SQ1=395<0d`<3=6<4I2AT<aA4<g>4=5<c0iASE5
>C=6>CQ1>DDe=DHb<cE1@S8dA4=6=3Hc<TDf<SU1@cPe@dE5<c0==D8c<cI4>D93
>C<`A3Lb<c=4@SDdAS11@cHc<D8g>C15<d56@DI2<dI3=313ADH`<C@b=3=4>DE1
<DA53C55=34`<c8h=c4fASU1@cE3=c8h=CPb@STi=3Lh>D=1<SHa=cDaACU5<DHh
<4Hc@c0a@DDh@SI2=cLf=Pe2@cLc<cM3=TI3>48a<393>D8d=C<e=DA2@cM6<3<g
>4Hf@CLb<CTc=d<bAS53A491=cHb=C@e=SHe>DH=<SQ3<c93=c8a@D4h=D=6=CE6
>D55>493@c@a=S56@C@h=S0a<D<f<dD`=3Di>4Db>4=6<cPd<S4`<CM53CM3<3Li
@DA1<CH`@TE6<d<h=S95<d@a@c16<D@c>3PdA4<f=S4fAD8`<3Ph@d8b=3I5<CI3
<CDhACA2>@e5AC4e@D@e=DDd>3<i=CHh<c16<STd=dE4@dI6@STgAS0i>3Q6=C0e
<dA5>495A44c<3L`@T91>393=TD=<C14A4I3AC54AC8h<c@e@CU4<CM4=3Ta>3Db
@DE2<dA6=T@c=C16ACI5A3Q1=d@d=3LaADDe=4H`=c4i3C@f=c@i@d52=C@PCT@=
;ePc>B0P<S<f8594838dAD=2A30e<dE2>3Le<d=1=4@fASLf=3A4<T52=492>3Tg
=d95<T@f@cQ6>4D`=CA1>D=3>C=3=STaA0di=d8`=S4f=cE1=SPaA3E4<4@a=DDg
<CLi@d8h>3Dg@dE6@S@g@cHbADE5=CTf<cU2=3Tg<c=4@cQ1@c0==SM2=cPi=c<e
>D=6>C@f<c<iA3U5AT4e>4Hg=30g@CA6=48g<SHd@C<f=TI3@d<g>D=4=3U4@SDh
>3=33CE3=C94<cT`=3@c<4H`=DDc=c13@cDd<CM6@d55<d52>313<CLa<S4h=c@h
<D51=3Ha<cHh<ST`AD@f=0da<T=4@D@`>30f<cQ1>D@c=4<e@C56<T@f<3Lh>C4`
<cI3ACHh=DDcASA6@SHbATE4ACA2<4I6AT@e>4H=<CI2=4Hg>4@`@SDb<d8b@S4b
=C0d<T4i>DDf=d@f=cI5>D@g>4@`<CLc<S4i=dA1>D=5A3Da<THf<CQ63D@g<c0b
@c13A4I1<cU5<d8g@cPb@c0`@CPb<cHf>CI4>CM4A4A2<30h<d@`<SPa<S14=C<b
<cHd=c96>0dh@c55AT8i@S<c<dI5@S53=cHg>C8bA3A6=cHb<cDg=S8e<S56AS8h
@C4e=C51@D=3A4<d84i43BmH<d4P83@c8594838dAD=2A30e<dE2=SM5<c<f@D4d
=c4f=c4i=cTg@CM1@S=4A4<eA3E5=CTc@D4g=c91A4D`A34e=3=3<0e6<D<b@C14
>4De=3M2=CQ6<c4`<313AD@g=b1>A0d_F3=2820h>21BA20b=4E3@T@`=C=5@SHg
AC<c=T51=3Hd=T8c>4<c>44c=S<e<4A3@dI6=dE6=D@g>D@fAS4a<d52AS0d@cP=
<D@g@d94ASM3=c13@T=6A3Pb<TI6@cDf>D<d<CQ6@c@h<T8f=c15=T@g=SLc=c=5
@c4bATA2AS0i>D<b3CE1>D<c<TDgAT<g<CDf<C8h@T4e=D96=c@iA4Da<SDa>CHd
=48a>3E6=cDa>DI2A3I4AC@f<cA184i43BmH<d<P83@a8594838dAD=2A30e<dE2
>3Le<d=1=4@fASM5A4@eAT92>C4a<CLa<C4i=S0e<3=2>3TaASDf@DA4=cE6<C8i
<0dc<352@CHi=T@e=dE6<C0b<TDi@cE684i43BmH<d@P83@a8594838dAD=2A30e
<dE2>3Le<d=1=4@fASM5A4@e=C14ASTi<DHg=c<fA3Tf<SPc=DE1>CDb<S0f<3H`
<314=Pd`>3<g@T4i@D8c>3Pb@CTf@d8e<C5184i43BmH<dDP83<h8594838dAD=2
A30e<dE2>3Le<d=1=4@f@cLgA30h<CH`=C95=4Hh<38i@cDd=c0iAT=3@CM2>C0d
A4=5<cE4=@e3<DHg<THb>D4i<S94<C4f84i43BmH<dHP834g<b1BA20b=4E3@T@`
=C=5@SU5=3@`<C8e=cU4@dDiASI5=TE4ACLh@CDfAC56<c<b@c@f@C94AT8`=4A4
ASLf@D4=<D@bAT=4@T<a=3L`<STeASTb>30g<C51AT@`=d51AC11=495ACI5<CTc
>CHb>D4i=3E5@D8aADDc=cDi3C51@CLa<C<d=cPg=D=6=C95A316=D4`=dE2AD8e
ADA3=c52=CE2ASDh<DA6<CA4ASE6=3=2<3Pb@C8b=`e6=4=1=T<a=SM3@cTe=dA5
<TH`=S4`=THi<S93=492<cQ1=d8e@cDgACH`<3Le=4DhA311=3Ld<D=2AST=<C@`
A4I6=DDb@S8f=TE2A3I4>4@c<d51@dE3<T8g>DDg@DDc@CE4A30aATHi=TA2>C@b
<cU1<d=2A3Hi3D<c=34b<4A1<3@hACU4ADDb>D8g>4A1<3=4A394>C=6>CI4=4=2
>3@dASI5<30PCT@=;ePd<20P<c@i8594838dAD=2A30e<dE2>44a@C51<D8i=DHa
@S0e<3Th=T=4@C0a<4E3=c@d=C<i@CQ6@S@cAS<i@CPaA452@@db=4I6A4<d<4I1
=T@h=S<h=S@dAS95A3<b=SQ6=dE1<c8eAD@c<3Hc@SU2=TDd<30e>D8cAC12@cQ3
=3T==SI1>CPcA3U4A4Dh@C4b>34c=C<i@C12>D8`=D95>3LbAC<dADHf>4@hAC<b
<TI6<cE5<T8h<D4`=d963DHc=34dA3I1@SI3=cM5>44b<CPi=44gA3M4=34e@T<f
=D8d<315=S8iAC@i=dHbAC@b=TA5=DHgA3PdA@dhATDe<cQ6@C13<CDd=DI1=C4`
<S@g<TI1A496ACPg=T8h=cHe=SQ6AS0`>3@c@SD`>CDc<T8i=dHiA4@=A4Db<c<f
ACI6@cTg@c94=D4g<4<c=S<b<CU4=30c=cE1<CU4AD4i=3Dg=DE2<SHd<d54@S0c
@SE4@CH`3C92>4I4<c8cAS15@T<`>D91@C<d=cE4@d<c>30h=SPc=d4gADDe@cA2
>48dAS=2@CU2<dHc>CQ4<T52>@di@CI2=S4i@DE5AD4b=c8g@cM1@CM5@T=2@dHa
@dDg@cU3<S0gADA3ASL`>3LiA3E3ASU1A3D`<3PeAS@=AT<c=dI1@S@g@c8h>496
>455<DE5>C<gA3A1=c13=S0`=SM4AD=2=dE2=T4a<4A6=3Pe>C93@C93=30g3DHb
=S=4@C4i@SD`=SH`=T4`@CM1<SQ6=394A395AT4e@c15@T@c<d@c<3T`@D<dACA2
@cQ2=SM5@TA1>0e2@c8`<d8hAT4g=T4g=C8fAS<eAC0hASDd<SA2>CLi@C<g<C=5
ASTaADE2>C8g@S4i<SA5>D51A3A5AD8=@T@d=C11<TDh=SA5<cPd@cPd=3<e=dHe
<dI4=CHgAC@g>351<4<PCT@=;ePd<B0P=S0PDT@P<SA5@d94<3DcAD8h<c4e<CTa
ADH`>C4c=CE5=S<a>D@cASTa<C0e=S53ACA1<T96>3I6=cM4=c52<D4c3@00X@30
?oli<dHeAC4dAD@f@cM3<d<g@c8b>D4c=dI4AC<d=cQ2<d=2<T<a<3M6AS<g<T4e
@c@c=S<h<S4b<3<f=SDPCT@=;ePd<R0P<CTa8594838dAD=2A30e<dE2>3A1>3P`
<cPd=d56=T4a<CHf=S16=d4d>3He=dE2>392<S0e<D55=C4f=dA1<TI1<Pdc@dI4
@CQ4ACHe<CU2=T<a@CTh>CDa<D<e=dE3@C8fASLi=3M6@SM3<SM5@THe=cLhASTb
<T<e<4De>38=@cQ4>34g>3Pf>44a<S11<cU6<CPc@SHb<D<h=S@dAT8fACU1<D4`
>3Hi<DE1>C4b@cDc>DHc=D@i>48i3C0e@SHf<44f@T4c=3<d=cA1>CTg@T8i=d=3
@TDg=c=6<cTh>3Pb=SE1A4Dh<DE4>C@g=cH`=SI1=C4b<0daA316<S8fASHc>4A1
=CM4>4<hAT@e<CDi=T<fADDg@S<cA3A1=c54<D53=4E3<SHa<dE5<3ThATHdA3T=
>C15@CU3@d53@c8b=dDe@c8`>C@`>CU5<d8aA3Tg=d<a<48d=453=c<bAT56=dHb
=C<gAS92ATA3<d=43C8c<SDi=STi=3Dh=44hAT=6@C4c<cDPCT@=;ePd<b0P<CHd
8594838dAD=2A30e<dE2>3@e=c11<S0iASI5@SM5>3D`=cTdA494@SPc@T8c<S55
A4I4>3Q3=3E6<C0cAD55A0dbA44b<48c=CDh<S0f=STh@CDg@cE2<c15A3Q2<d<f
@CLi@S12@C<c=SA3=S=6<C<h<cE5=S4hAC8a>38==c16=D@i@S<`ADHg=4E6A3Lc
=D94<T=6@SHh<cDb@CE4A3Hh<T@`<456@CTdATE5=44a>3E6=4Di@T<b3D4eAS54
AS4i<D<`<D<aA3Df@dA6=dI4>44g<S@gAD4`<c<cASQ5@C@d=C=1>3A6<c15=SDe
=cQ1<SPfAPdfA3<e>CPeASPh<cA1>D8hAT92AC8iACTh=3<a=CQ2>D<bAS=1AC52
<3<h=TE2=cPgA48hA3PiA48gA38=AD@g<cU4<496>4<`>C4h<SQ5<dA6AT4c<C96
=R1>A0d_F3@d820a<S0PDT@P<SA5@d94<3DcAD8h<492=CE1AT8h=3Di=3E4A3Dg
>D92<C<d@c4bAS0a<TD`<DHg=S56@D4g>CHb=4I13CE1AS@h@CPaADE3<SQ5<S0a
AS<a@DE6=d8d=cM5@TE3>CLc@c<d<T@f=SHh<TH`>4De<c96>CE3A48i@Pe2=CM5
=c53A3Pg>CU2>3E4<d8a=S4i=dDeA4I6@C0b<THc=351@S4c>CPh<D<i@c8c@c96
>4I1=dA4AS8=<D95>4Df<3E5<cU5=T8f<SHg<CL`=3M2>3M2=C@c=SLg=c54=DA6
AC55AC54@C4f=SQ4<cPh<T54ADI284i43BmH=3DP83@g8594838dAD=2A30e<dE2
>DI3@D4`=c4e=4Hi@T8`<4@iAC52=4<`@d@bA3H`<CA4AS@cA3Tc@c16<c53AS@b
<Pe4@T8`>38a<S=1=c0`>3PgADI5AC56=SA5ASDb@T4iA31284i43BmH=3HP83@a
8594838dAD=2A30e<dE2>CTe>C@b=CTd<CI3=44g<4I6=3A5=44b<T4eADHc<4A1
=d8f@DA4@SHb>C=2<cD`A0dc=S16=C0h@dE4AC<g=S8i<D@d<48e84i43BmH=3LP
834f<R1BA20b=4E3@T@`=C=5@SPf@dDb<CLa@D4i<d4e=cDaA34f>C8g=SQ2=CM2
@S8`AS<`<T8`=SQ5A3Tg<CT`>CD=<d@a<CDbASQ6<T@i<3Tf<CLh=4E2@C8f=SI1
=S8bACDd<d@e<CM5@CLg<CI4@S=3=S8i=S4f<d<c=3E13CU4=SQ2<SI4@D@h@SL`
@cPdA3@f<3Q4@SE6@TDe@S@eAD=3<3Pa>3@i=S0a<cL`>3E1=3HbAS16>3@i@`dc
@D=1A3Hb=d51<C12=4E2=3Pc=C@i=3U6>DE1<d@f<S0g<SQ2AS=3<CLiA3Ld<SPc
=C<g>312=c<d<30=>D<g>4@h=SU2=D<hAS<cACM1>C=6>34i=4I4<3Td=c8c<C0b
>3Th<SHg=THd=T54>3Q4=3E4ATHf<cU23CTh=d@`<T8i=STi>4I2A3T`<3U2@cHf
A21>A0d_F3@h820d=b1BA20b=4E3@T@`=C=5@SPaAT@d=T8`=CLeA3Pd=cM4<cM4
<cE4<cQ4<3Dd<D8e>DI5<3La<THb<TE4=S4i@T4=<38b@C<a=cLd<c@a=352>C4`
@C@g=4=6=d8e=T@g=S=5=21>A0d_F3@i820b=B1BA20b=4E3@T@`=C=5@SHc@S<e
>DE5=3@`<c12>CQ1=c4`AS4`=d93=SQ1<cI5<S15@CDi<R1>A0d_F3A1820a<3LP
DT@P<SA5@d94<3DcAD8i@CQ5=T<hATE6<CHg<d8b@c0eACDc<cU2<cA4@c92<CLc
=3DcA4E1=c0g<TDh@DDi3C=5@c@`A455AS96=3=1=3M3>C8`@SPg>3Q6=S<g<312
A3<iA3Hc=cLg@STf<cP`<3Lf=C@g<cDd<T<d@Pdh@C@b=4<gAC=1@c0dA3<g>4Ha
@S93ATDd<cPg@TA5>C0gACU6ADHb=CE2AS@g=dDeAC8b@D<i@STc<c0==452@c11
@c0iA3@a<T@fACLb<dA6=d<gAC4h@c0hA38aA21>A0d_F3A2820e=21BA20b=4E3
@T@`=C=5@SPg<DHe=cU1<D8b<d52=D51<SDaASQ1>3Li@SPbACI5<SLa<SE2<3Te
=3A6AT54<cT==4Hg@d51A34`A48`>3Hb>D=2<c@i=44h@TI5=c0a<CP`=496<C=2
=4A1@TA2<T8c84i43BmH=4<P83<`8594838dAD=2A30e<dE2>DHc=SPfA3@g>3Hf
=CDf=SLdA3U5<C@gAT<a<D@f=CP`@cHiA3E6<3I1=dD`@CPa=21>A0d_F3A4820g
=b1BA20b=4E3@T@`=C=5@SQ6<THa<4<a=SLaAT4g<T55<T8dA3U2=d<c>C55<cPg
<d@h@C8`=T54>3Ld<CM1=TH=<352@cI6A4I1=3Lc@c4f@D56<cPg>CA4=cA2=SDc
AD=5@c=6=454AC8`=SHeAD<g@CLgAC4b>3=2=cE33C55AS=3=SDe@TDg<c8h=S0f
<C=2@CLi@S0`<3Ta<cTa>C0PCT@=;ePdAB0P=CLPDT@P<SA5@d94<3DcAD8h<38g
@S4e<d4b>48a@D=2@C55=4I2=3=6@CLaA3Te=c13>4=2@dDcAC95=SPb<3Q53C8f
=C4a@TE4<cE3=4I4<4@g>48b<4Dh@C=2=3=6=CI2<cM5=S0h<CLf=38c=30eA3A4
=cQ2=B1>A0d_F3A6820a<cDPDT@P<SA5@d94<3DcAD8h<SU5=3@d@S0e>DHi=D4a
A3@aATE3<3E5@C8b@D4a>D@c=48e@C12<d<gAC8`<34b3D@b<D<g<D4h>D92AS8i
<SLh>4<c>38g=dHg<T4dAS55ASQ6=C0`<CE6=cDa<355AS96>D4h>4A4<354>@e5
@D4i<DE1<T95@SL`AS8h@CHbA3A5>34a<C<h<D=1=cTg@cH`=SQ4=cQ2<3Lc@CTf
@C@eAD4d=CLa<d8=A3A2=30d@T93@dE1@S8f=3@i=3DfAC<c<SU3=S4h<T95AC@f
AC=2=c=6=3=5<3U2<3Dc<D55AC@c@D@g3CE5=c<`=3Q6@C8a@S96<SLb<44a<SPi
=3Hh=S<f<b1>A0d_F3D`820a<3<PDT@P<SA5@d94<3DcAD8iAS<f>3I4=3M1<S<i
<4E4<4Hh=D=4=SLf>4H`=38b@dE5A4@h@S53@CU6=D=4=C4c3C0a=T8d>44iACDf
@cU5>3M3@DD`ATA1<cI5@DA2>CQ6=dDc<3Th=CTg@SLd<cPa<S8g<D@d=CQ3<CI6
>0da>D4dA4De=SHd=C8e=4D`<3D`=CHeACHg<C<`@SHf=38e<3M1>D4`=D8i=3<b
>4<i>3Tg<cTfAT@d<DH==4=6AC@e@S53>CLg=D<b=d<c=c4e>34`@D8PCT@=;ePe
<B0P<CTa8594838dAD=2A30e<dE2>38iAC@d=48`=CU6AC@d=D8fA312<3Lg<dE1
>3Hc@cHdA3Pe=cPcAD@bASLb=S8`=@di<cDa@CM5@C<e=c4i<dH`=D8b@S55<d@h
@D8g<T94=C14<d<i=D@f<cLb@SPb<SHe@CTd@C<c=4@c<T@=@cTh>D8e@d<`=c91
=cPg@c4i>DA2>CPf=c8d=3<i<SPd>CDd<SLi@cDf<4@b@d4a=DE3AD4eAT@i=cLc
3CQ4>3Q4@S8f<c<c=c0h@CPd<4Hb=314A3I4ADI5@d<`<TDi@CDi>351@c@d<S51
@TI4=454A38hAS@c@Pe2=313ACU3AC=6@CDcACTbA312=c4c=D4c<4=3=3Tb@THb
<cA4AT55@DI2<3Lb<CH`=TA4@C<iACPc<TH=<cDhA4E5ADHf=T@e<3=3@SLb@cE4
>396@c4h<dA3<cDhA3Pi>CI4<34d<c<h>CThAT@gASE6@CHb@DI43D<b@D=1=T51
@D<f>DHb<cHb<d8g=cHPCT@=;ePe<R0P<CHc8594838dAD=2A30e<dE2>DA1<c0b
<C@b<c8fA3=4@dA1>D55<cDe=4Ha<3HaA30f@SPb<356@C<`=S@e@dHc>0d`=DI2
A4@g=dE1<D@bAT<fA3U1ATE2=D56=495<d=4>3H`<4I1=c52AT<dAS12AS8aAD<b
<dHe<CU3<C4=A4A6@d<i<cQ3ACHa<SLc=S4a=cI3@D4i@cU2=C8i@DA2=T4d@T<g
<CHi=353<CPg<c0`<c=1@CQ2@cH`3CQ1<STb=TA2>3Ti>CDiAC96@DDiA456>34`
=d8h@C8a<d@f<T54>3I2AS51@D4b@SE2AD8`=3A2=SP`<`dc<SM3AS4e<S<`@S8c
=SI1>48a@DHg@C0a<c16@C4h=c<a>D95@d@`=c8f<T4b@c8e=S8a<cM5@DI1>DD=
@dH`<c94=CPa<3Li@TA1<3DbASE5@c8cA4DPCT@=;ePe<b0P<S<g8594838dAD=2
A30e<dE2>DA1<c0b<C@b<3E6A351@dE4ASL`A44d@dDf=CPd>48c>CI3<cHi@dD`
=CTd<D=2=0e3@d4a=DI4<c@`ASHhASQ6ASQ5AS8i<34`=dD`<STe@T<h@D51<cI1
@d96>3I3>CHf=d8h>CHc<34e=44=<S56<SI6>C93<3Q5<DDh>C<g=S8bASDc=44`
@S95A3Le@C0gACT`@S0g=cQ2<D@f=CE4@SH`=d<f<D<b3DDd@STe@S=2@c<f<D4`
@c<b<dE3<S8a<D4dA3Hc=3HbAD=5AT=4<S<d<dHg@S0a<d8h<44i@T@d=c0h=0db
<S<d>4<a<D<a=STd=D@g<3M3<48`A4@i=C55=38g<S55=CE1>CHa>30d>315>C@g
=D8i@CPf<cU3A3P=@dA4=c56@c<f=c95>30bA3Te@cQ3ATDe<494<3Pb@C<b@T55
=c4c@TDiAD8aASE2>4=6<S@h@CTc=T923CQ3>3Q2>3E5@CHd@D4c=c@f@C<c>4@f
>456AS4d<CM6@C8h<d<`<CA5AT96A312@c8hADHg=3Q2A316<0e1@S8e<c4b>C8i
A4E1AT@i@T92=D<h<S12=d<i<3Tf<44e=3Lf=CHgAD4g=TA1>495ACM2=DHPCT@=
;ePe=20P<cHPDT@P<SA5@d94<3DcAD8h=4E2<S@d=C91<30b<c4h=CPe<34c>C=2
=C0g<396A3<c<cLg<SPg=T4gACTa>C@f3DHi>3@a@D<d<T4e=B1>A0d_F3De820a
<CHPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I3=cTb=C<b<cE5AS@c=c94<S4`@C55
<dD`>3HfA3Q3@T@i<S0e<4Hh3C96<48aACI4@C0g=CI5@cQ6<391<3Pb>C@h>454
<CA6@SM1=TI1>CLd=3M3=D8a<D=1AS@a@S0g=3Ha=0e2@SA6AC52@DI6>3He<d54
=3P`=D95<44b=T<aAD4`@TI3<4@a>3A1>DA6AD<h=DA4=cU4=dE4<S0`=CH=>D8b
=D=1<T@eA38g@d54ASHa=cH`AC<iA355=353@dA1>CLi<CQ1=D8e@DDd=cTe=D96
<b1>A0d_F3Df820d<b1BA20b=4E3@T@`=C=5@SPc<CDa>C55AS0e@d91<c@d@c94
>CL`=391<3<i<d<b<STg=34h<44i<3Pg=D4g<CP=>34e>34a>D@e@T@`>392=DA4
=dI1>3M1=TDPCT@=;ePe=b0P>3TPDT@P<SA5@d94<3DcAD92>38g<DHb<cTa=c0d
<3A5=d8i=SQ2@DI3@d@gATDi=44`AS4b=c55>3@`<30g=D=23D@d>D8`=3Td@SHb
ACHe@cDdAC0c<TDa@CA1AS13@T8`A456ADH`<CI2@dDc>34gA38i>48e<cP`>C=3
<@e1ASTb=D<c<CTbAS0h=d4`<T96<4Df=C<g=SU2=d8g<S8iAT=3<dA5<44b=T8h
<T=2@C=2=3Pc>D<b84i43BmH=CPP83Hd8594838dAD=2A30e<dE2>DA5=d8`=T4h
=cI1=C=3@SDi=C4e@TA6=4Db>4=4>CI2>DDa@SM5>3Hf=391@d=5=`e4=T8`A4<b
>D8i<C8i=3Le=c53<T<f@SM1@SE2>C@dA4Df<C@b>4<cASM2=3<i@C<aACI6=c4i
=D=1@DD=<495<C4h>C<PCT@=;ePe>B0P=3PPDT@P<SA5@d94<3DcAD8iA4Dg@S0f
@CPg=SDe@TD`@d92=34g>C4dA34`>DA5A4Dh>CI2@C16AD93@d<c@SDd3CPi<d96
<C=2<3Q6=SPf<48h>3@i<D92>3M1@cA1=T@eAT@e<R1>A0d_F3E1820d=R1BA20b
=4E3@T@`=C=5@SU6@d51<3La=CHdA44b=S96<C@a<4I3ATDh=391@DE3<cM4>C16
<SA3<cPa=T8b@SL=@CM4@S0a@STd>CDg>3PhA34h<cT`A3@c=315ADE4@d4PCT@=
;ePe@R0P<cPPDT@P<SA5@d94<3DcAD8i=d91ASA5@CHg=496ASLcA48h<C=1@d<i
>3<h@c0e<CLe<D56=d55<DDg<d93@C<b3C53ASE4@cQ1@dDh=c53<cTPCT@=;ePe
@b0P<c4PDT@P<SA5@d94<3DcAD8i>3Hh@d4d>DE5AS=3=TDhA3LiAT4a=T<h<cTg
=cTc<cA4A495@CE6<S8i=CM2@TDc3CHa84i43BmH=D@P83<h8594838dAD=2A30e
<dE2>CM2@DHdAD4f=S4`>491<30fACLc=3=5<c54>CQ5=S54<cE4>3Pc<3E1=SPd
AS4eA0d`<cHc@C0`=3E3ASDg=3U684i43BmH=DDP83@a8594838dAD=2A30e<dE2
>3Le<d=1=4@fASM5A4A1<dDeATI3ACP`AS8i@S15AD=2=d=1<CI6@THiAC4e@C0b
>0e3=SA1=d4c>316=S11<SHb<SM1=T4f84i43BmH=DHP838e8594838dAD=2A30e
<dE2>3Le<d=1=4@f@CI6<44h=3Q2<c<fAS<f>D@a@C<`>3@iA3Hi<S<h84i43BmH
=S0P83<a8594838dAD=2A30e<dE2>D=2<STg<T=2<3Hf>CQ5AT4b=C16@CH`<c0c
=cI6ADE6>3<i=DA5@DHd<d<f>C<i<Pdg=b1>A0d_F3Ha820b<c4PDT@P<SA5@d94
<3DcAD8i>CDi=38e>C@cA3Hi>C8g<SA4>CU2=3E3@cU4<D8c=cTg<3Pc=30c<C@`
<dE2=DDf3CLc>38aADH`ASQ5@THe@C=6=CTi@S8i=DDa>4<i>38`>CU4@S8b=cQ3
@S13ASQ2>391=S0e=DDf@cQ5<0db<3M1<S8a@T4h=4@i>4=6=D@bAC0d>4Hh>C15
@DA1>392<cDa@SLa<3Lg=d4c@D8d=T8c<4Hg=c=3<d4==D4bASHb=C4f@CLf<C=3
>3Q1=d<i@SI3<4A1<S94@c4gAT=5<S0`=4@h@STb<CQ2=C8i>3Q2AS8e<DDh3C@d
=SA5>D8g@cDa<D@d<4H`AC13=34a=38h<c8g=C92AT<h>CPh>D@bA3<f>4Hb=C0c
A3<a<SI6ASPiAPdi>C12@CTdAS@a@SA3<cPg@S4h<DDe>3Tf=C0b>CM3@D=4<S@d
<4E6>3Td>D@fASA2ACTdADH`<S96ASD==44f<T@fAC<d=d=4<d8e<4I6=3<b@TDd
>D95=3Pc@dHa=CQ1A3E6@dHf<c91=c=6A3<h@TI3@C13@dI43D8c<DA2=C4g<S52
A44h>DDg=TE3=cE1@d<b=4=6<SDg@d8i=dHf@DE2=R1>A0d_F3Hb820b<34PDT@P
<SA5@d94<3DcAD8iA4Dg@S0f@CPg=SQ4@cHfAT51AC@g<d4e@CLc@T8eA4@e>3Th
>3<aAT4b@c4b>3<e3D8a=dI1AC<h<C12AS0`<S@d<SHe=D4d=4I5=48aAS52<38c
=TDh<d@h<S0d<T53=4Hg@S52=SE4@C94<`di=S0g@C4d=44fAS8e<D=6<3E5=C11
A3=3AC<d=d@`AST`<4<g@S8b>4<aA3Hb<4I6=SHh@d91A3E1<4@=<S4d<S0a<3Tc
<3PiAC@`@D@a<3I4ASU1@c@i=cQ6=c<h<S8c@dHgA38f>CDc=CU2@T96<T4d<354
<dDe3D4e<T=6=cTe<SHg@c@`=dE2AC8e@TDb=CI1>C93<C13>C53<cHg=TDhAS0g
<D<i=3<e<3Pb<cU6=T<f@`e4AT8i<48e<STc>4@e<dHeASU5@CDc@D8e@d4hA3<e
@T4f@SA4=THa=C11=4@i<4HdA352=T4b>D<d<cH==c0e@T4i>4I6>D@`<T@e<3=4
=T4c<T<a@D<b=TI4<3LgAD4f<CHf<c1684i43BmH=S<P834e=B1BA20b=4E3@T@`
=C=5@STiA30`@C4c=SE3AS@gA3HfAC<iA48a=cTa>D=5@cDi<4E1>3De>C11<cDb
=cE2>CP==3Pe=C8e@D=2<d8d=3H`<CHbAS0e=S<`>D53@T=2AD@e>4@e=dI4AC8f
<3Pg<4E5AD<f<dI3@c55@SE53CHg<T95A3<f<4A1=4@eA3@g<3Db=cE4<311<CU6
AT<i>4DgAT<b@cLe>C4hASM4@TE2@c@cATHd<dDh<@dg=c0e=S@d=C14=cE4ADE2
=CU1>451@cTi>3U3<DDiAC=1A3A1>34h=3I1@CU1<S55>CA4@TI1<cHf=4H=>3=5
<C52<4I3AC<g=D93>3M4=S<`>4E5=cPg<dHi@SLd>C53ASE4@cTi<SQ2@S11<d<i
<C<c=3=6ADDd3C4g>4E1=SPc=SLPCT@=;ePf=20P<CLc8594838dAD=2A30e<dE2
>D<f<C4a<DE1@SLd=cM6A4I6@C@h<cLa<D@e@d4g@S4h=S@f=C54=38h<d4h=C=1
<@e5@c<b<cHbACU5<CE6>C<`AD8h=T4h>3Ha>C55=cU3<356A3A2<SU6<STcA4Hh
ATH`=44a=TA2=4I5@CP==48`@SU4@CQ1=D93A44a<S4d<T8e=c4f=T4c>CTcACTc
ACI1A3@a@cTf=C0`=C11=c8e<C=4<3Tg@DA53CM5<c52<T96>48h>DE1@cDi>CU1
=354<c8eA3U4@cDd<T<e<SHe=4HfAC<i<D@e<494ACE2<SU6<S11>0de=4I4<44c
ACU6<S15<4Di=3@i=d@i>3=2<S0b@cDiA3Hh<D<c=SE1@SPf@c4c>D@d=C8fA3Q6
A455>38=<CLfASI5>44`<311@C8f>D91<d8a@CU5AD<`=C56=CLd<d@g<30a<3@c
>D@h=R1>A0d_F3He820a=c8PDT@P<SA5@d94<3DcAD8iAT=1@C0g<CDf=3=3@DE2
>3<i>3@d=C@f=4@h=3A2<D4bADDd=CE4ASI4<dDb=3Lc3C<e<SHi<d8b=C0b=SU4
=SLe<SU5=3=3<30a<SE4>DDd<d8f=4=5AT@c=C=5ACPb@S95<CPh=SDg>4Hg@`e4
=c=3<dDe=CI6@CA3AC8f=C0aAC93<3Di=3@e@DH`A354ADDg@CTe<34hATE3>4A6
=d<c@TD`=CM6=c0==4=6A3A3<3@`<cDh=D8i=CPb<4=5<dE6>C0c>C91<3TiATI2
=TE4@CThASM4=TDa<4@b@S@e=30`A3Pa3CPf@S55>3Pi=CLf<C96<CPg=34g<d4`
A3Q5>C<a>3A2<d8f@d@e<CU5@DE6@cLg=3<dADDe>CE4=S=6@`dg>C51ACQ1>D<c
=394AD8c>C<i<30a@cTiAT8g=454@cHf=cM6=3U1@D@i@b1>A0d_F3Hf820h=B1B
A20b=4E3@T@`=C=5@STc<T<h=T@f<TDe=TDgAS16=S@g@DA3<44h=C8dAD@g@dDc
AS51=c8cAC@`>CA2=C8=@dHg<SE6@S<i@D92<3E5>DHa<dE3ACLc<D8f<S53>4A3
AC@e=D<i=T<a@T8`@TI1@CPc<3@fACE3=SQ23DA1=cDh<T=3=cE2=CPh@T@hA3Tf
<c95<CLf<cE6=CHa=d8d<d51@CHi@T4f@CM6AC@a84i43BmH=SLP838d<21BA20b
=4E3@T@`=C=5@SU4ACM2<3I1>3Li=DDdADI5ACLa<CDg=48b<c8h>CM3<SA4=cE2
A3Q2>D4d<D<`=d<=>C8iAC<`@D@a@S<h<C95<SLh>3A2>C<cADE1<395=cM2ACTe
@T8i=THi=DI6=T4g<cHf=C@i>CU6>3U13C=3=cPc<C4a=453=C4`<c0i<STiA4=1
@cDb>D51<SPg<DDc@c8h<3Q6<c56@D8g=S8e@C<b=3A1=CD`<0df<TA4>D4cA4H`
@cHd>4=5AS<a<D8a=d<i=S4a<DHd<S52=SQ4=C4c@c@a<S<a@CA3@d@g=T52=3A3
=4D=@C=4=CQ5@cI6<D4c=C@e<3HiAS0i@c@h@C92@cHg<SU5>DI1ADA3<S0f=STh
=cE4<3=1<3PaASPcA3A63CLaA313@T@c>356>3M2<d8i@c15AS4b@T<e<c8a<D@`
>CDi<C8e<D<a@D93=c8g@d8fASHfA4A6<SM1A@dbACTh=S4d@C=6=S<i<396=S52
<d4a=d=5A3TeAS8d=3<i=c@i>48cAC0a<3<c<3Hf<4E1=492>C0iAS<=@C4i<S@i
AT@b>3U3<dE2@CE5AS<a<d<c@TDi@CTb@C4f=T52=STi<cPaAT@i<S0fASE5=d4g
>4Hb>34d84i43BmH=SPP834b<21BA20b=4E3@T@`=C=5@SU6<cHh=T@d=d4b<c13
<38bAD@f>4A3@CU4>D52<cI5<44g<T8a=cHd=S15>3U6<3D==CHi=S11<3Hc=392
>CM6=CL`=3Pe=SI1<4@g@T@cA3Q1<cT`AC4h@C13A30a>3Q4A4Dh@STg<4<h<495
3CDh>C55AS8g<SU3@C55@c0gA44a=3M6>C12AC8gAS0e<CLi<3Tb@S4`=4=2ACDb
A3Pa@THe=DDi<dI3=Pe4@D<`<4Ha=DDe=D56=4Dg=CHc=c0d@SPa>3Lb>D94<394
<d51@D@h<D=2=cTf<cE5ACE4@dI2@d93=T@PCT@=;ePf>B0P<cPPDT@P<SA5@d94
<3DcAD8f@c8aACM4=T<d>D8a<3La>CI1ATE2>3A3<d8a>C=3>CLg<313<CE5@C=1
=3A2A4A33DA3=D4i=D<c>3Tg=3Tb@d8PCT@=;ePf@B0P>C4PDT@P<SA5@d94<3Dc
AD8f<CDi>C@g<4I1<3@g=S94=S=1@S4e=3HgA3Hb>DA5AC0g@S4c>D92>3Lc@STe
A3H`3CTgAT4i<3Ha=SDd<SU1@c8d@DA2@cDi<455<CPf=S91>4I4A4Dc@S=4<C94
AS@dACI6<S8cADE2=3L`=`e5AS8a@CDd=D51@CA3ACQ4=4<a=34d@DA5@DDd=D8b
AT8b>C@d<dA4<CA5ATA4=3=3@SA1=3U4A30gA3<=AC@PCT@=;ePf@R0P=C<PDT@P
<SA5@d94<3DcAD8i>3Hh@d4d>DE5AS0e<T94=T@c>CA6@D=1<3=4@SLf<S0i@STg
ATHe<dA4=C8c=DE23DE5A44g=C4g@c0a<d=5=SPg=TDb<dA2=3Ha>CTb=3Ti=CM6
=S<h@D@gA30i=TDPCT@=;ePf@b0P<SDPDT@P<SA5@d94<3DcAD8f@c8aACM4=T<f
A3Hg@CQ6=CHfASDh<c=2A4<g>CHa>C4bAT4e=D@PCT@=;ePfA20P<S4a8594838d
AD=2A30e<dE2@T@g<496=C92>C4g>CQ5@c15@DHc=c15A3U3ASI5>4@`@SE4<c4i
<D93ADHc<SE5<0de<S=3A4@e@c15@THbA494@DHe<T@d@S4i>3Dc<T<i<cQ6@CU2
A392<3<c=SPeASLg>3Le>C12ADD`AC4==SA5=3Q2<4Hi=D52<DHi=ST`=STgA3Db
ADHi=C15@dDh>3Da@SE3@CDe>3@gA455=SDb@TE1<455=cU13CDb@SU5=4Hf>D<e
@cPdA34cAS@hAC54>CLc<S52<S0i<TE5=T<d>4<a=C@b<3DgA48e>3I1@D8gACE4
=`db=cM6@CE5A3La<C<f=dHc@c@e<CE5=T@a@C=1>C52@CHb<3Pa>3Hg=SDc@c94
<3=2@D93ACM1@S0hA3L=<c@a@c0f@C0d<DE3AS8c<T=5ASHb<D93<dE4<S4g>DDc
>4Dg<3@`=DA4A4I2=C=3AT93=SDi>C@eATHa3D=2=SLe=30a=S0`AT<d<D4f@C14
=D<b<T8c@C0f>48d>C0`>C8b@C<`=cA6@SPa<SU2<d8c<3P`=3<eA0e2=R1>A0d_
F3I5820a<CTPDT@P<SA5@d94<3DcAD8iAS<f>3I4=3M1<S<`@c0b<TE4=SU6=c0i
<SLh@cPb=cI1<30g=3<b>4De=D@a<DA23C51=d<`>C0e@S@g@T<e=CI3AC92AS@e
>4<`=4E2=D8c<THb=CU4@CTi@cLi=SDb>D@h>4Hf>395=C8c=0dgA454AD4h=T56
=4=1=d4dAS@c<S93=cLd=C4cA38e<D8b<C=1=D4b=D8d>3A6<C<b=3LhAS=4=CPc
AD8=<SA3=CPa@d55=cA2A3@d=492ATI1=dA4AC4i@SU4A394AS<i=3Hf=d8c@T8g
<T@iA3Q1=CPdACI5=B1>A0d_F3I6820a<c4PDT@P<SA5@d94<3DcAD8iA44c<38a
=38c<ST`<CPc>C4g=d55=48`<4Dc<T@h>4I1<3D`AS@aADE3<S0`>3A43C4a@C@f
@C8b@c@bAC4g>C53<cDiACLbATHb=C8h>CPh=D53ASE4=c<b>CHc=T<i>CQ3<4<b
=CM1@c@a<0dd=c<e@S52=c@iAT=1@CPg>C8d<d<h@dHg>3E6@C8d<SA1=C8e<3Tf
<D8a=S53>D8bAT8c=c56<C<f@T@=>DDh>4E3<d@d<S11ACPe<S4c<S8c@D53=38b
AT4a<3P`@cDc@D8h=3U6@dE5=30f<cA3<CPi<3=6@SQ63CTh@T@c=396=cLh=4=6
AD@h<cA6=SLPCT@=;ePg<20P<CLc8594838dAD=2A30e<dE2>D<f<C4a<DE1@SQ3
A4@e>3Q6>3Lg<DHiAC<h@D8e=c4b<CDe<3Di@T4a@SLg@c0e@`dd@c@i@CLeASDg
=S=2<dDdACA6<DA4AC8f<48e=T<f>3LcAS=2AS@i=3E6@cDa<dHf>3E6ASQ6<392
=4H=>316>DDd=CE5=TI4=d4`A311=c<d=SDcASH`=d52ATE2@cPeA4HaACM1=3Lc
=THf<SQ3ACU4<495=d8g3C13<cPiA353@T4e>CI2>34c@cHd<SDe@T@h=cDh<D@h
@dHf@THh=c8g@D93=3I6>4@i<d93@DA6ACPe<Pe3=TD`=C<h@SDa<cDa<3Pi@c<e
<SU2=395=C8d=34b=3A6=T51=D56@C@i@THd<THdAT8i=c8cAS@`=TH==THf@S0f
AD91<CPf@CQ1=c0g>4<f=SI5<d<`=DE2=SPh=3Th=S95@CA3=T=4=b1>A0d_F3La
820a=c<PDT@P<SA5@d94<3DcAD8i@cHa<C4aAD52=c@g=dDa@c14=DDc>DHe@cP`
<D4g@SLh=CHe<c@`>3M5=3Th=THf3D53=4A5<3Pb<48b>CTh>D8e<CDb@d4`ACE1
=c56<S12=C=3AD4d<cTc@S8aAD=2ASM5>C@`ATA3=T8c@@dg<SHd=dHgA48a<c@d
=S8g@S92AS@h@CDc@S96<CHeADHfA494>311=DDc<S<c<D<c@C0g<SHg@cA3ATD=
=SPhASU6<T96<S8d=CDi<S@d@C<`>CQ6<STcAD4i>CU3=30`=TDg>CQ5<CU4A3@a
=dHg=d51=SU6AC113CQ1>CDa<c@`=T93>CHaAS93@D4f<C13<DD`A44hASHg@dI3
=S8b>3M3=S=3=S0a<3Hc<DDc>4E6@C55APe1>C@`=CDgA3Dd<30a<d93<38b>4Hg
>313@d4e@cPa<CDe@C13>38h>4Hc@S0`84i43BmH=c8P83Lh8594838dAD=2A30e
<dE2>C=5=dI3A492>C@g>3L`<d94>D<d<TI5=4Hi=dHb>C4a=CI6<DDe@TA3<48f
=cPb@Pdf<dA2ACU4=DA5@T@bA44cAT53<C0g<3T`@CE1@THa<c=1<30e>38h@TA2
>4<f<D<aA3Dd<4I6AT@d=cD=@DDdA3A2<dI2<cI3A353=T55>CT`<3A2@CHb>3M1
<T8h@d4a84i43BmH=c<P838a>21BA20b=4E3@T@`=C=5@SU2>D53<c@h>30bAC8a
>C0g<C52=4HaA3=3@dDh<THa@c55=D8c=3Ld@S=4>4=6<38=<CLd=c4cA3A1<SHe
ASM6<cHh>C4iAT8g<c93AT<b@c@e@SI1=48d@C4c@CPi<SDa<c8d<4@f=ST`=C0g
3C=1<4<hACLbAC0f@CL`@c@b@D54AC<i<S8c@S4`ASHiAS<a@CDe<CI6<3Pe<30f
AD@c<d=6<3Ha<CI5>@db<SPc=3La<dA2<SPf<SI5=TE5<c<a=SPi@SE1=cE1ASLb
<C4a<d@a@DI4AT4`AD51<44iA4@h=cM3>CP=>D=2=THi=dHdA3Tb=3P`@CU3>4<g
AS=5A3M5=cD`<DE3>4E5@cPhA4D`>C<i=cM5@dDd<TI4>4Dg=DHa3CHcAT<c<44`
@CTg<SPg=T8i<c=3>392<S94<T91@cPa@STb@SE1<3L`<D<c=C8`=316ASE1>3Tc
>38hAPe3<44b>3E5A3Q6@S=6>C0g<T<`<S54ASE2@SH`ASDi@CDdASPc=C4f=cTe
AT95<DH`@C13=44cAT96<S<==4Hi>C@f<d@cACE4=DA3A21>A0d_F3Ld820a<38P
DT@P<SA5@d94<3DcAD8i=SLhASI3@c<h<SPh<CA2=SM1>3<h=4A2>3I2<D4eA3Dd
=D<f<34bA30d<CDeASA33D4c@DDa=30`=4=4@C95<S91>D8e<DE2=S4iACPg>48h
=CTb=c4f@S<`A3Ta<C14ACLg@dDa@D55<3@gAPe4>CTg@C@f@TE1=c8a=c@c>3Pa
>3HdASA2AT94>312=cLd@cA5=dE2@c8`>DDa@S<g<SPa<4E3<4I2@DD==S4f=4A1
AC<b<C4i<CDd<c0e>4E2AD@g84i43BmH=cDP834`=b1BA20b=4E3@T@`=C=5@SU6
<cHh=T@d=d54A4@`<3P`=c54ADD`=CL`<c96ACDe=S96AD@`<T55@SLa=cTd<34=
A395@S8i>CU4=4HeAS14>CTd<TA3@C=4@TDe<cDa=CDdA3U6=3Q2@SI6=4@h=SH`
=3U4<D4f=D<aAC913DA6=c4c@S16<4A2=T=6@TA5@THc>4Hf@S=1=cE4=d8e=DI5
<T=5<D=3>3<`<c8iA354=cPc<d<fA3M6@@e1>3Hc<3E4A4=1AT@c=c52<d<g@S8c
<4Dg<CLa=TDg=CA584i43BmH=cHP83@a8594838dAD=2A30e<dE2>DD`<DDdAC<h
=cPe=TA3<TI6<3E6<c<f=3La=TI3@SPfAT4g=THh<c4d>CLi>CDd=Pe5ACPgA44h
@DDa<SM2<3Hc=cA3<30c84i43BmH=cLP83Pe8594838dAD=2A30e<dE2>4I1=d@e
@D<eA396>3Tb<c4e=T<g=cM2<S0b@S4b=SPe<3E6AD4eA3A6@CLg<48g=`dgAT4e
@CPf@DE3=DA3>DI4@dI6A3<g@CPi>3Da<c=5@TE5=D<eAS@d@SPbA3U6AC13>4@e
<cU3@CTiAC8==CM6<d4`=CTg>48b<CI4@D8e=c53=d4f@CHcA44`ACTg=T56ACDf
AC93>D=3ACM6=CTPCT@=;ePg>20P=S<PDT@P<SA5@d94<3DcAD8i>4E6>CI4@cE4
>3Pg<c0g=S@`@SLb<dDhADE4=D51=CT`<cM6<3=5=cLgA48h@dI33DE6<34bA34i
<THc@SLa<CLf=TDc=T94@d53=C<aATI1<T<b=34c@STa=34h<3Df@D<iAD91<d<i
=3I3<Pe6AD@i=d@PCT@=;ePg>B0P>C4PDT@P<SA5@d94<3DcAD8iASPf<4I3AD4f
@c8h=44g>CHb<3@f<D<h<CLa=SHb@DHh>3Ph=SHc>D4g<493@dDg3DDd@C0c=S@i
=3He@dI6>C52<3Q1=48i<d=5@SDaA34i@SDh>CDf>C53@c51A30g<cLg<3HdAC8d
<dA2<0di@CQ3@d=6=CLi=C8a<3Hi=c<b=4<h>DHb@SPc=3Q5@cPe@C8f<CPfA4=4
<C8b@d=4AS4hAC<`ASDh>4@=AT4PCT@=;ePg@B0P=3HPDT@P<SA5@d94<3DcAD8i
>CDi=38e>C@cA4=4AS53@STd<dHc=c=4>D4e<DD`ASPg>3Pd<3H`=DI5=3<h@SHb
3D8i=S95=cP`@SPc<30d=c92=c=5@cQ3@D91@cDd=S<i84i43BmH=d8P838b<21B
A20b=4E3@T@`=C=5@STgAT@a<C94=D8d<3U6=C@g<3=6AT=3>D4c=D4h<cLeA3@`
<d4eAT91@S4`=THg>C<=<3Hh<SE1ACI1=d4iACI2>3HfACLb@CLh=c0g=455@cDi
=CT`>3Hh=D52=DA5>3Tc=cE2A3A1<T4f<CQ13C93>C8f=c14=3=5<S<f@c=4>C<c
<cE6=D=3<4<b=T96<3@fACDa=4DcASLb@SLh=S96ASPf=d4h>4@f<`e4<4=5A4=6
ADE2<d8i>311@DDcAC51@dA6@SPe=C<i=TA3>38cAC4f<CHf=CLg<d@hAC4b<THc
=4A4=cT=>CU4=313<S<d<C<b>4Dh@cTg=DHeAD@a=3ThA38f>DDaASI6A4@iA3Hh
<D@i<SM2@DE1=CI2=DI5>30d3DDd=c15>D4cA3Hd<C8g=TE2<48`<C15>3E4<SU2
>DA3<CI3@C8bA3U5AC@`@S0c@T@h<4Hh=cDf<C8g@`e2=3=2<SPd<S0d<SE6<3La
<3LcADHd>38f@S=5<3Lb=DI6<SHc<D<a@cTa=3@f=CU1AC8h<c<h<3M2=S0=AD56
=SLf<CT`<T8i@D8h>4@bAC8PCT@=;ePg@b0P<SDPDT@P<SA5@d94<3DcAD8f<cM6
<cI2=THg<3<b=d92@SA6<3TbA4I4>3M5@THi=dA6@SPe=TDPCT@=;ePgA20P<S8a
8594838dAD=2A30e<dE2>CM6A34a<T@e@S8i<dDa=C0h=S@h=CLf>D<f<cL`=d54
=CA6@SHe=STe<SE1>CLh@`dbAC0a<DA3>3Ti>4Ha@cLaACQ4<S0g>CI4ASQ4<CU2
<3<c@cA1>4I5=C<h=cDc=d@d=DHf@cDh>3A5<T4=A4E2<T@d=DE2<44f<c0b=D@b
@SA6@cLc@d@e=T4b<CHh<cDb<cA4<cPa@cLcAD8f@d@a<cQ5>CHfA4933D<`<3@a
@d4i=TDg=d<f=d55ACTg@cDa=CI1=CPfACHe@SE6>44g=dA6=3L`>C11A3<c=SHa
=D54@CU1A0dg=4Db<DA5AD<`<T4`>DDi<T8h<4@cACM5<dE2=STe@SH`=dA3<dH`
@D@a<4E1<3Ti<3TaASPd>C8g=D4==TE4AD4h>4=6@dDf=TE2<S4h<3I6<c@g<3Dg
=TA5<cA4<3Ld=T=5A3<cASE2>3Te<c95ATI6@SA5<c0c3DHh=30g=dDg@d@dA4E4
<SPb=D@c=THb=T91A30g@dDg=CQ3@cQ2ACHcA3He@CE2>3M6AC0c<d91>3<b@`da
ADHi=c54=c0h=dHb>C8c@d54=CDa84i43BmH=dDP834c>B1BA20b=4E3@T@`=C=5
@SPg=C=3@CA4=T<g>D=2<395>C8h<493<S=6A30fAS12ASA5>3D`<4D`@S95@cTe
@T@=<cHd=34h<d@a=T56<D@`=d8c@C8a>4Da@CU5@C@b@c56<T=6<d4i=d8d=dE6
<cLhASPbA4@b=d8i<S@a3CQ6<c4aAT=1A3Ti@cE3=30fAD=1AT@d@T8d>D=3<SM1
<SHb<D94<TE4>C@`=T93ASTfA4<e<30c<S4i<`d`<4<`=4HcA355<CI6<D=6<3Q2
@c<`AC<`@cE2=3=5>3=4AC92<S<g<cLf@TDcA4HgAC4g<D92=C8d<S8==3M6<dDb
@DHe<CPaA3DaAS14=cPg@d=5=DDd@cA1=SHc=3E3A30PCT@=;ePgAR0P<C8PDT@P
<SA5@d94<3DcAD8i@C0g=DA1=3Q3@dE584i43BmH>30P83Pe8594838dAD=2A30e
<dE2>3<a=C4i<DE6<3Ta<cDeACHc<CU4<dHi<C4`=CHa@dDd@C92ASPfASLgA3La
@S51<`di<dHeAC4dAD@f@cM3<d<g@c8b>D4c=dI4AC<d=cQ2<d=2<T<a<3M6AS<g
<T4e@c@c=S<h<S4b<3<fAT4=<dI2<c0g=C53<3HiAS8b<d8i<d<f>CTb<c0`=3U1
<STf>4Hf<S8g@STb@cLd@c@g=4DPCT@=;ePh<B0P<CLg8594838dAD=2A30e<dE2
>3<a=C4i<DE6<48g@d93=SPb=3M4=4DaA3<a>3Pi=CTi@d<`=4HcACTc<d95=3@g
=0dc<T<e@dDf@dDfAT@a<SA6=SDdATI2<3E3@DD`<c4iASDdAT@`<4Hf=T4c@T@d
=3De>D56<4H`>3Tf@T@==cU4@S=2@SI1AT8i@TH`<T4`@SA5>3=3A38d@SDi=d4b
@SLd<TE3AT4b=SA4=c55<dDf=SPiAS4`=34e3C0i@DHa@c96@C=1=3A1@C0g=cL`
=dA1@cQ6ASQ3>DDb>48h@DDg=SD`=C0a=d<f<THh<c@b@T4a=SP`@Pe6@C0g<C@d
A3<eATE5@c0h<S4hA3<hATI1AC4c>38d<DDg@c13=D8b@TH`@CD`>DDd=495=4<h
<3Q2=S8==CA4=T51<3M2>C4b<S<a>3Q1=d92AC8gAS15=S=5A3HcATHg<SHf<cA5
<D4a=3Q1>D4fAS1284i43BmH>38P838d=R1BA20b=4E3@T@`=C=5@SPd=CL`@C8`
>DHi<496<d8aA30g@d8e=38g<c<`AS8h=392@DHg<316ACU6A48g<4H=<3M4@DDe
@C15>CPe<44b@STb<SPaAS@i=C<a>CI2>D4g<T53=d<f=TDd@S=1=S<gAD54=CM6
ACI6AC4e3C4d=SQ4@SPc<3Pe=D@g<3U6<cH`=SLg>3M3@d8a=3A1=d4a@c4h=TA4
<SA2=D<f=S0a@DHb<T<e@DHcA@e3>C0dASDe<CHaADE6=C0g>D4c<S55=d51AD@h
>DE2A3HaAS56@C<c<S0c<4He=c51@cT`@SDb=SI2>3T=>DA4A3M3AS@cADDa<4Di
>CHi>C4c@D94=c4i>34bA4Hh<cI6@cM2@D=2=C0`AC0b@S0e=D=1AS8aA3A23DDe
>3L`<d92=3Q2AC4a@T@f<38f<SA2ADA2AD<a=492>3D`=THe=CDdASI1<C<a<cDi
=4@a@cHc<T<g<@ddAST`<dA4@S=2<3E1A4@f>DDi=4Dc@S<b<3Hf@dA1>3<b>3@f
<THb<c4h=cA1=cH`>CA3>38a<S0e=3H=A3He=3I2>4E2>4DhAS<f=3TiAD@f=D<g
@T94<4E5ACA1AT=5<D8b>CQ4=d52<3@fAS@e=30c=C0e=D8b3DE1=4@d<cHaAS15
A21>A0d_F3Pc820f=b1BA20b=4E3@T@`=C=5@SU6@d51<3La=CA6>D92<314>DDa
@SA3<4=4<T@f<34dA4Hd<d@i<d<`AS<a@dHd<S8=A492<3Pb<C8c@CL`<3Ph=dE6
ADDaASHdADHe<T91>DA6<SE2=4Hh>3=1<4=3>34e=DI1ASD`<3E1@CM13D8`@CHf
=cM3A4E1<3@`84i43BmH>3@P834f=b1BA20b=4E3@T@`=C=5@SP`<SM2<CDc@C8h
@S51@d91<DDdAT8d<dI1=c54>CDg<4<h@d93AC=5<TDf>38`>4D=<SHe<C52AD@c
=D<dAT@`A3Lh@S8`ACQ1<d8d<dHe=T8c=dDf<3Pa=cHd<S<d<3E4=4@g>3A3=351
<3Th3CQ5<cM3>DDf=C<d@d4i>3Q2>492>4Db@cTbAS92=34c>C<g=cDb@D8d<D<i
<T4d=CDb@C53=CHd=d92>@de<CTg@T53AT4dAS55@C93=394@cPaAS=5<34b@SA3
>C0cASM3=3Lh@SPi<d@i=D4fADI5ASU1>3I1<CH=<cQ4A3U6A4E6>C4aAC<gADI5
>315<4I4@dE1ACLcA356@CPaA3@f>CU4<dHd@c16=3M1<dI2=C4cA4E43D53<T4`
>454ASDc>3Pa>D<a@cHh>3Pi=cE1A3@gA494@cHPCT@=;ePh=B0P<CHa8594838d
AD=2A30e<dE2>38iAC@d=48`=CU6>CE1<D@d<DI5@c0eAD4b<T51<CU4<cA2=D4`
@S=3=dDb<30a<Pe4<S53=c51>3U2@THb>C8g>3Q3<cPb=cM6=c91=4HaADHhASD`
<34eASLe<C0aADHbASU1>3Q4A30aA3T=AD51>C55@C92AD8g<4Hb>44f<T@dACPa
<C4c>353@CLi=d<f<3HhA3Lh@S0g<d4i=T4d=DE1=3Dg<C=23D@d@S@`=492@d=5
@D8b=S@d>C@e=TDc<c8i@cHa>392ADDd=TDc@SLcAS@cAC0i@S0e<c51ADDd<d54
=`deACLc<3@hAT4b<D8bAS8g<S11<C8h>C@f>3Hc>CH`=cQ6@CTa=3PfAC<`=S0g
<312>3Lc=4@cA3M5AT<=@cPe>C8h@C0d<C<c=S@e<392@DDg>21>A0d_F3Pf820a
=34PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I3=cTb=C<b<cE5AS@c=c94<S4`@C55
<dD`>3HfA3Q3@T@i<S0e<4Hh3C96<48aACI4@C0g=CI5@cQ6<391<3Pb>C@h>454
<CA6@SM1=TI1>CLd=3M3=D8a<D=1AS@a@S0g=3Ha=0e2@SA6AC52@DI6>3He<d54
=3P`=D95<44b=T<aAD4`@TI3<4@a>3A1>DA6AD<h=DA4=cU4=dE4<S0`=CH=>D8b
=D=1<T@eA38g@d54ASHa=cH`AC<iA355=353@dA1>CLi<CQ1=D8e@DDd=cTe=D8`
@DHa=S96AC8i3D@h<CQ6@S@b@S@`@dA4<4=6A4Hi<30gASHaAD4dAS4i>DI3<SLg
=dDfAB1>A0d_F3Pg820b=C400:40`3oo8594838dAD=2A30e<dE2>CTe>C@b=CTd
<d@f>CTb=c8dA3Ti@S@e@d<iA352<cLi=c0h<c@`<c4d<3=5@SE5=Pdg<cPb<DE6
<4HhAD96=D4cASDi>D8b>CE5<CQ3>CPb<3TiA48b<SLh@d8`@dHh@SPb@CH`=CE5
=T<hAC0=<S0g@C8b<D91>3A4>CQ3ASE4<TD`=3Q6>3T`AD54@CPb@S<e<D8g<C0g
=cM1<d52=3I2<c16=cLc@c=13CE1<THf<SDa=T4g=S4c@cPh@CM3>D8f@c14@C8b
A4<a=dI3AC8`<3A4>48i<S4h@SDb>CPh@THb=C55>0dd=3HdACU2=d<e<C54=316
<4D`@c@a<C@b>3<b=cDb@TI3>3Th>3U4<T@c=SQ6<SD`<d@c<C8fATHh>DH=>CT`
@T4i=4Hd<D8d@c<h=d8a>355=CPi=SD`<STg@d53A38d=315ASPi=3U4=THd@TDi
=4E6<38bATHe3CA1=S94=TDc=3M3A3=2=C16AS@c<T95=3U2AC@h<d=6<CDh@D@e
AT=6=S<b@CLcAT@c>496@d4`@d=6A0e2<c54@SDa=c8a@TA1>3U5=cI5@cLe@D=3
<SA3AS8e=d=2>CM6=T55=3<g<S0a>38bACM3=SDd@CHb@S8=>DI4>3I2<4Hb<4<b
=3LgADE6=D=3@B1>A0d_F3Ph820b=C0PDT@P<SA5@d94<3DcAD8i>CDi=38e>C@c
A3Hi>C8g<SA4>CU2=3E3@cU4<D8c=cTg<3Pc=30c<C@`<dE2=DDf3CLc>38aADH`
ASQ5@THe@C=6=CTi@S8i=DDa>4<i>38`>CU4@S8b=cQ3@S13ASQ2>391=S0e=DDf
@cQ5<0db<3M1<S8a@T4h=4@i>4=6=D@bAC0d>4Hh>C15@DA1>392<cDa@SLa<3Lg
=d4c@D8d=T8c<4Hg=c=3<d4==D4bASHb=C4f@CLf<C=3>3Q1=d<i@SI3<4A1<S94
@c4gAT=5<S0`=4@h@STb<CQ2=C8i>3Q2AS8e<DDh3C@d=SA5>D8g@cDa<D@d<4H`
AC13=34a=38h<c8g=C92AT<h>CPh>D@bA3<f>4Hb=C0cA3<a<SI6ASPiAPdi>C12
@CTdAS@a@SA3<cPg@S4h<DDe>3Tf=C0b>CM3@D=4<S@d<4E6>3Td>D@fASA2ACTd
ADH`<S96ASD==44f<T@fAC<d=d=4<d8e<4I6=3<b@TDd>D95=3Pc@dHa=CQ1A3E6
@dHf<c91=c=6A3<h@TI3@C13@dI43D8c<DA2=C4g<S52A44h>DDg=TE3=cE1@d<b
=4=6<SDg@d8i=dHf@DDc>C53=S13=C12@cI4ACDcA3U4@`df<C53ADI3=SQ6=C8c
@CTa=cTe>21>A0d_F3Pi820b=CTPDT@P<SA5@d94<3DcAD8i>CDi=38e>C@cA3Hi
>C8g<SA4>CU2=3E3@cU4<D8c=cTg<3Pc=30c<C@`<dE2=DDf3CLc>38aADH`ASQ5
@THe@C=6=CTi@S8i=DDa>4<i>38`>CU4@S8b=cQ3@S13ASQ2>391=S0e=DDf@cQ5
<0db<3M1<S8a@T4h=4@i>4=6=D@bAC0d>4Hh>C15@DA1>392<cDa@SLa<3Lg=d4c
@D8d=T8c<4Hg=c=3<d4==D4bASHb=C4f@CLf<C=3>3Q1=d<i@SI3<4A1<S94@c4g
AT=5<S0`=4@h@STb<CQ2=C8i>3Q2AS8e<DDh3C@d=SA5>D8g@cDa<D@d<4H`AC13
=34a=38h<c8g=C92AT<h>CPh>D@bA3<f>4Hb=C0cA3<a<SI6ASPiAPdi>C12@CTd
AS@a@SA3<cPg@S4h<DDe>3Tf=C0b>CM3@D=4<S@d<4E6>3Td>D@fASA2ACTdADH`
<S96ASD==44f<T@fAC<d=d=4<d8e<4I6=3<b@TDd>D95=3Pc@dHa=CQ1A3E6@dHf
<c91=c=6A3<h@TI3@C13@dI43D8c<DA2=C4g<S52A44h>DDg=TE3=cE1@d<b=4=6
<SDg@d8i=dHf@DDd<dI2>CLd<SPc=44i@C4h>3Pg>@dhAT8i>4E3=38c=SA5A3@h
A30b=C=1=C4g<3A6@CDb@dHiA3M6>21>A0d_F3Q1820b=CLPDT@P<SA5@d94<3Dc
AD8i>CDi=38e>C@cA3Hi>C8g<SA4>CU2=3E3@cU4<D8c=cTg<3Pc=30c<C@`<dE2
=DDf3CLc>38aADH`ASQ5@THe@C=6=CTi@S8i=DDa>4<i>38`>CU4@S8b=cQ3@S13
ASQ2>391=S0e=DDf@cQ5<0db<3M1<S8a@T4h=4@i>4=6=D@bAC0d>4Hh>C15@DA1
>392<cDa@SLa<3Lg=d4c@D8d=T8c<4Hg=c=3<d4==D4bASHb=C4f@CLf<C=3>3Q1
=d<i@SI3<4A1<S94@c4gAT=5<S0`=4@h@STb<CQ2=C8i>3Q2AS8e<DDh3C@d=SA5
>D8g@cDa<D@d<4H`AC13=34a=38h<c8g=C92AT<h>CPh>D@bA3<f>4Hb=C0cA3<a
<SI6ASPiAPdi>C12@CTdAS@a@SA3<cPg@S4h<DDe>3Tf=C0b>CM3@D=4<S@d<4E6
>3Td>D@fASA2ACTdADH`<S96ASD==44f<T@fAC<d=d=4<d8e<4I6=3<b@TDd>D95
=3Pc@dHa=CQ1A3E6@dHf<c91=c=6A3<h@TI3@C13@dI43D8c<DA2=C4g<S52A44h
>DDg=TE3=cE1@d<b=4=6<SDg@d8i=dHf@DDd<cHd=D8f<SLa=4Hh=C52@DHb@@d`
=SE3<cPb@THa=c8b<dI1A4Df=3LdAD8e@S<b>CTf=cTh84i43BmH>48P83<b<21B
A20b=4E3@T@`=C=5@STi=CTd<SDi=3=4=STi<SLb=4@i>D8d=D=3>D@a@S<g>CL`
>3<d<3<a=30cAD8eACH==c<h<S55AS16>4E2ASE1<dHe>CU2<STeAC4h@cTh<S0i
>DA2<S8g>4=2<4=6>48h<T4f<3DeACI3>4D`3C8`=d4b<S52@CPdA3Th@dHeA395
<3@hASPi<4E1A44h<T8c=C52=c4`=cLg@C=1@S@f@S<`ASLg<d<c@@de@C96=S8e
<CI1=cHa<d<h>44g@cU2=T<`A44b<TA3<CM6@dDb<30dA3Q2>C8a>48e<STh>496
<SDaACP==3@f=4Di@SM3=C4aA3@`AS15<4<d<C4d<SPc<SLe<T96@cPi>3PiA394
<cHhAS8e<3=4<c4b=TI6>3U63CTi<491>CA6=352=4<c>3M2<CPaACDh>CHe<38i
=d=1@d@b=3@`ADHh>C@iA3I6=495>CA5AS0b<TI6=@dd@CHbA3I5<c@g@d@c@SD`
ATHd<c92AC@i@TDd>3=3AS4e>454=DI3ASHc<T4g<dI4<cQ2AT=1<4=3AT@=@S<a
A48e<CLb<D94@CPiACLfAD<g=D53@c8d@dHb=CM3@STgASI1AC@c>C4`<D@a=D=5
<S=6ADHg>C563D4d@TH`=d91@SH`=C12@c=3<DI2<DI1ASI5=D93AS<c@TA5=THh
<4@fAT@b=3<`@c92<CPa=493>4I1=Pe2=c@eA4E4@T<f@D8gACA2<44f<C56@TI3
=D4h<4H`A3Df>C96=cDf@cTcA4@hAS8fACQ5<3Pb=C0h=CH=@d<`AC11=T8h@d8a
A3<c@C=2<STa=SU5=T8b@CI5<4A2=CPi<T<g<21>A0d_F3Q3820c=C8PDT@P<SA5
@d94<3DcAD8i>CDi=38e>C@cA3Hi>C8g<SA4>CU2=3E3@cU4<D8c=cTg<3Pc=30c
<C@`<dE2=DDf3CLc>38aADH`ASQ5@THe@C=6=CTi@S8i=DDa>4<i>38`>CU4@S8b
=cQ3@S13ASQ2>391=S0e=DDf@cQ5<0db<3M1<S8a@T4h=4@i>4=6=D@bAC0d>4Hh
>C15@DA1>392<cDa@SLa<3Lg=d4c@D8d=T8c<4Hg=c=3<d4==D4bASHb=C4f@CLf
<C=3>3Q1=d<i@SI3<4A1<S94@c4gAT=5<S0`=4@h@STb<CQ2=C8i>3Q2AS8e<DDh
3C@d=SA5>D8g@cDa<D@d<4H`AC13=34a=38h<c8g=C92AT<h>CPh>D@bA3<f>4Hb
=C0cA3<a<SI6ASPiAPdi>C12@CTdAS@a@SA3<cPg@S4h<DDe>3Tf=C0b>CM3@D=4
<S@d<4E6>3Td>D@fASA2ACTdADH`<S96ASD==44f<T@fAC<d=d=4<d8e<4I6=3<b
@TDd>D95=3Pc@dHa=CQ1A3E6@dHf<c91=c=6A3<h@TI3@C13@dI43D8c<DA2=C4g
<S52A44h>DDg=TE3=cE1@d<b=4=6<SDg@d8i=dHf@DDd<dHc<3=3<cHd=C<i@C8c
=3M4>0dbAC=2>455=cA3>4<d>CM1@C51<c8c<3=5=CTb<CDc>D51@SU5=cI1ACTf
A3Hi@SPbAC0d@SM1=c13@cD=<D=3=CI5A34g=3=1=C<i>C4f=d@cA4DeACP`A4=5
<3A6<D8a>CDd@C4`<SDc=cTb<cQ6@DHi<4I1<SM53C@d=SDi=SE2<SHgA3De<d8e
<D@`AS<`A3DgAS0b@THh>D4e>30g<SHh=c8f>3=1>C<f=d<a@T8c<dHaAPdh@C4i
>D@`A3De@cE6=3Q5ACA2>3Lb=c53>C0e<D<a<S94AS=4=316ADH`AR1>A0d_F3Q4
820b<SDPDT@P<SA5@d94<3DcAD8i>D@`<44a<cHe<c<`=D51=S93=S8h@D55@SA1
>DI2@SE6A314@SDa@D4b>C@d=TE23C96A3@c@T@c=C0cA4<f=T<gAC4e@CQ4<c@i
<4<aA4Hc@C@cAS0h=CU1>452<SPf<3Li@CI2<SE5AC0i>@e6@D92@SLa@SI4>3Dc
=D4d<T4b<SI4@c0g@c@a>30aA3I2=S<`=D=2<3Q5<SPa>C8i=44i=DI5@S@hAT@=
=3@`A3DiASHa=d8dADHd@C<c<d8d<cU6<T<`A4@i<SI2<SU3>4E1=3He@D56@D@e
@C55@c=6A4=1@CU13CDaAT4g=48b@CE5>D8h@T93=4Hc@CTi<34f=TA5=d4d@c0c
<dDb<44a=D@g=SI5<C@g<T53<4I4<CPe<`dd@DHd=C53=392<d8h>3TfA4Hi=D8a
@D4d>4HcA3Q2=S0b<S0f@S4d<495A3Tg<SA5@cM3@cM1AC@a=CL=@C=3>C95<D=3
=DDg@d@f@d4d<354AC56<CQ5A4A3<3Tg@cDe<CE6>C=4=S95ACE3=3@dACE4@C0f
=C<i3CHf=T=2ACHa<D56>4@f<3<c<SL`@C@i@S@f@T8c@B1>A0d_F3Q5820a>C4P
DT@P<SA5@d94<3DcAD8iAT=1@C0g<CDf=3<d<C4`@S0a=3Q5<d<b@SM4=34d<3Li
<dDh@c<g>D@`ACDd@c963D8a<d4e<cLi>CI5=CDfAD<b@d=4ATI4>3I6>CLd<c8d
<3Di=S0b=3Hf=38e<3=1>4De@dE1ADDh>C12<Pe3<CHg<dHaASPh@T=5=TDg<D4c
ASE4=SQ6ASPgAS=2@D<h@CA3=T8f>CP`>4Hf=D@d>3@a>C4i@C<h<C8=ACDf=SI3
@cA2=T8e<cA5ACPi<SPi>3DfAT<iAS4d=CLd=cI5<SA2>D52>3Pa<CE6@SLf@DDa
A3Df<cI43DDa@T91A3A6AC@`@dH`<S8iA3=5<SPh<cA3AT53=dE5=c<i@C8aASPh
<4I5@CHe=T@d>4Db=C8f=S@iAPdd=44iA3Hc=4I4=d4fAT@`<3<eA4A2AS0`<496
=CM6@C4h<CDgA3=3=DH`ATHf=c0cAT4i@TA3=T@`<T4=@TA4>38`=38dA4Hg@S0e
@S0a>C<g=R1>A0d_F3Q6820a>C8PDT@P<SA5@d94<3DcAD8iAT=1@C0g<CDf=3<d
<C4`@S0a=3Q5<d<b@SM4=34d<3Li<dDh@c<g>D@`ACDd@c963D8a<d4e<cLi>CI5
=CDfAD<b@d=4ATI4>3I6>CLd<c8d<3Di=S0b=3Hf=38e<3=1>4De@dE1ADDh>C12
<Pe3<CHg<dHaASPh@T=5=TDg<D4cASE4=SQ6ASPgAS=2@D<h@CA3=T8f>CP`>4Hf
=D@d>3@a>C4i@C<h<C8=ACDf=SI3@cA2=T8e<cA5ACPi<SPi>3DfAT<iAS4d=CLd
=cI5<SA2>D52>3Pa<CE6@SLf@DDaA3Df<cI43DDa@T91A3A6AC@`@dH`<S8iA3=5
<SPh<cA3AT53=dE5=c<i@C8aASPh<4I5@CHe=T@d>4Db=C8f=S@iAPdd=44iA3Hc
=4I4=d4fAT@`<3<eA4A2AS0`<496=CM6@C4h<CDgA3=3=DHf<SH`<D<a@c15<c@f
>D8f<C<=A3A2@cDa<S93=3@f=4=1<4E6A4<g<C@a84i43BmH>C0P838`<21BA20b
=4E3@T@`=C=5@SU6@d51<3La=CHd<c@a<C12<34d>4Dc@c92=d@d<C@`=cTcACQ3
<cLiA315=CA3<TH=@S4c@CDc=cTi=TDe=CI5@c93@dA6AT@h=THi=c@c<S@`=CTf
<38d=SHd<SD`<d4hACE3AD55ACPi<48b3D<a=SLcAS56>3Q2@dDfACLa@C=6=D@f
>4I6>3M6<d91@cQ1=4<f@SHi>30hASHeA3@h=34i<CU1<cPa<Pe5=CHf=T=3=48f
@SDc=4E5>3Tb>3Th=CI6@cU6<C@e=c@g=TDb=48i@D8h>34a=DI2=cI1AC54=CHc
=T@=AC52@T54=4I5=313AS0b<SU4<dDb>3Pc=4=6@D<gADDg<cU1<S56>3P`ATE1
=SDfA3@hAC8e<SHf=3U63C@d@CU4=S<dAT@g@CI6A30`<cE4A496<30`@THe=dI1
<CPa=CM4<d<eASHb@d4i@d@h<DDa=cPc=T95>0dg=44e=3H`>48eAT@`AC8`@cM5
AD@d=SQ1@dE3<cE4@SE6@D8hAS<a84i43BmH>C4P834i=b1BA20b=4E3@T@`=C=5
@SU6@d51<3La=CHd<c@a<C12<34d>4Dc@c92=d@d<C@`=cTcACQ3<cLiA315=CA3
<TH=@S4c@CDc=cTi=TDe=CI5@c93@dA6AT@h=THi=c@c<S@`=CTf<38d=SHd<SD`
<d4hACE3AD55ACPi<48b3D<a=SLcAS56>3Q2@dDfACLa@C=6=D@f>4I6>3M6<d91
@cQ1=4<f@SHi>30hASHeA3@h=34i<CU1<cPa<Pe5=CHf=T=3=48f@SDc=4E5>3Tb
>3Th=CI6@cU6<C@e=c@g=TDb=48i@D8h>34a=DI2=cI1AC54=CHc=T@=AC52@T54
=4I5=313AS0b<SU4<dDb>3Pc=4=6@D<gADDg<cU1<S56>3P`ATE1=SDfA3@hAC8e
<SHf=3U63C@d@CU4=S<dAT@g@CI6A30`<cE4A496<30`@THe=dI1<CPa=CM4<d<e
AS4f=C4d<c4a>D@a<c53=c4e@Pdi@C@b=3Da=C93>452@C=6@cU4@S55A4<b<T@d
=DDi<C0i84i43BmH>C8P83@d8594838dAD=2A30e<dE2=T<b<DDgA3I3=3U2<C0g
<CTf@DI5@SPd@c=2<CTc@cTg=c0`@c4e<cDi@CHiA48fAPe2<48a<4@fA3=5<495
A44i=dHgAC@d<C4dA3Hd84i43BmH>C<P83@e8594838dAD=2A30e<dE2=T<b<DDg
A3I3=3U2<C0g<CTf@DI5@SPd@c=2<CTc@cTg=c0`@c4eAD4a@d@aAC0c@Pd`>C4d
<S54ACI3@S0f=391=T91<C<e<C93<CA6A3@PCT@=;ePi=20P=C<PDT@P<SA5@d94
<3DcAD8f@c8aACM4=T<d>D8a<3La>CI1ATE2>3A3<d8a>C=3>CLg<313<CE1=CHc
>495AS=53C11<T4f<30c=SPi@C4a<D=6@S4hA3Lc=S<e@SPbAT@f>D4d<356<c=5
<c@b<dDPCT@=;ePi=B0P=C0PDT@P<SA5@d94<3DcAD8f@c8aACM4=T<d>D8a<3La
>CI1ATE2>3A3<d8a>C=3>CLg<313<CDc@c<gASA4<T@h3C<g<DH`@D<d<TE3<c<h
<c=2@SM4@d8e<CM1ASTgACPf<d8iACHe@TDPCT@=;ePi=R0P<S0g8594838dAD=2
A30e<dE2>DHc=SPfA3@g@C8c<4<`<S95A3HiASL`>C8g>4<h<SLf@C0`=c@c<SQ5
=CE4<C54@Pda@CM3<3T`=D8d=d93=CDf@dDb@THd=CQ3<3A5@SE2<c96<SDiA44i
>D<g>CHe<SU4>3Q6=SPbACDb<c@==dA1A4E1>3I1ASA3@CM1=4Hd<c8b@cLg=3Da
<d@b=C52<S4c@CE1<SE2=3PdAS4c<S@g>4HcA3Dh<dE23C8d@cDh<D=1ACLd@T@d
=3A2@TI6@CM4A4Da>D8iA4@bA4Hc>C@f=SM2<d92=c94>D@h@CDh=4Df=3Dd@Pdf
=SM2AD8g<CLhAD95=CHb<cQ4=d95=4A5@d4a=3TbAS<c<3Lg<c@e=3HeACHi@cP`
AS0i>C<g>DHg<48=<D8bACPi>CM6<cPc@S=5<cHdA4<i<3Pd>C<i<CU6=44d<3<f
<d<c>44i@C0h@d<dAC@aATHi=TI4=CTc3D4g=cM6=d4aASI4@DI4=34d=dHg=SPf
<455>C4c<CDf<4<`=3Tg<C4g@cM3<C4h=C8`>CQ5<21>A0d_F3Tg820a=C4PDT@P
<SA5@d94<3DcAD8iA44c<38a=38c<ST`<CPc>C4g=d55=48`<4Dc<T@h>4I1<3D`
AS@aADE3<S0`>3A43C4a@C@f@C8b@c@bAC4g>C53<cDiACLbATHb=C8h>CPh=D53
ASE4=c<b>CHc=T<i>CQ3<4<b=CM1@c@a<0dd=c<e@S52=c@iAT=1@CPg>C8d<d<h
@dHg>3E6@C8d<SA1=C8e<3Tf<D8a=S53>D8bAT8c=c56<C<f@T@=>DDh>4E3<d@d
<S11ACPe<S4c<S8c@D53=38bAT4a<3P`@cDc@D8h=3U6@dE5=30f<cA3<CPi<3=6
@SQ63CTh@T@c=396=cLh=4=6AD@h<cA6>C95@SE6=S<f<SL`ACPb@dI6A44f>C52
>4Hb<3Pe@d93A4I3<C0h=Pdf<R1>A0d_F3Th820a=C0PDT@P<SA5@d94<3DcAD8i
A44c<38a=38c<ST`<CPc>C4g=d55=48`<4Dc<T@h>4I1<3D`AS@aADE3<S0`>3A4
3C4a@C@f@C8b@c@bAC4g>C53<cDiACLbATHb=C8h>CPh=D53ASE4=c<b>CHc=T<i
>CQ3<4<b=CM1@c@a<0dd=c<e@S52=c@iAT=1@CPg>C8d<d<h@dHg>3E6@C8d<SA1
=C8e<3Tf<D8a=S53>D8bAT8c=c56<C<f@T@=>DDh>4E3<d@d<S11ACPe<S4c<S8c
@D53=38bAT4a<3P`@cDc@D8h=3U6@dE5=30f<cA3<CPi<3=6@SQ63CTh@T@c=396
=cLh=4=6AD@h<cA6>D@b=CI4<dA6ATA3>CDe<CHd@dHh@T@d<T4b=SE5=dDaACTd
=C=4<R1>A0d_F3Ti820a=CLPDT@P<SA5@d94<3DcAD8iA44c<38a=38c<ST`<CPc
>C4g=d55=48`<4Dc<T@h>4I1<3D`AS@aADE3<S0`>3A43C4a@C@f@C8b@c@bAC4g
>C53<cDiACLbATHb=C8h>CPh=D53ASE4=c<b>CHc=T<i>CQ3<4<b=CM1@c@a<0dd
=c<e@S52=c@iAT=1@CPg>C8d<d<h@dHg>3E6@C8d<SA1=C8e<3Tf<D8a=S53>D8b
AT8c=c56<C<f@T@=>DDh>4E3<d@d<S11ACPe<S4c<S8c@D53=38bAT4a<3P`@cDc
@D8h=3U6@dE5=30f<cA3<CPi<3=6@SQ63CTh@T@c=396=cLh=4=6AD@h<cA6>C0g
ASDh<T4i=c12<C<cAT<iASTb@SHh<cA1=D=5AT4i>3A2>4E6=0e5=3Tg@SQ5=4E6
=4=4@B1>A0d_F3U1820a=CLPDT@P<SA5@d94<3DcAD8iA44c<38a=38c<ST`<CPc
>C4g=d55=48`<4Dc<T@h>4I1<3D`AS@aADE3<S0`>3A43C4a@C@f@C8b@c@bAC4g
>C53<cDiACLbATHb=C8h>CPh=D53ASE4=c<b>CHc=T<i>CQ3<4<b=CM1@c@a<0dd
=c<e@S52=c@iAT=1@CPg>C8d<d<h@dHg>3E6@C8d<SA1=C8e<3Tf<D8a=S53>D8b
AT8c=c56<C<f@T@=>DDh>4E3<d@d<S11ACPe<S4c<S8c@D53=38bAT4a<3P`@cDc
@D8h=3U6@dE5=30f<cA3<CPi<3=6@SQ63CTh@T@c=396=cLh=4=6AD@h<cA6>C94
=C4b>CPiACDd>3U6@CU4<D=6>C0eAC96=3<bACM3@DHdACQ5@`e4=cA6@CHi@cQ3
=DHe=b1>A0d_F3U2820b<CTPDT@P<SA5@d94<3DcAD8iA44c<38a=38c<ST`<CPc
>C4g=d55=48`<4Dc<T@h>4I1<3D`AS@aADE3<S0`>3A43C4a@C@f@C8b@c@bAC4g
>C53<cDiACLbATHb=C8h>CPh=D53ASE4=c<b>CHc=T<i>CQ3<4<b=CM1@c@a<0dd
=c<e@S52=c@iAT=1@CPg>C8d<d<h@dHg>3E6@C8d<SA1=C8e<3Tf<D8a=S53>D8b
AT8c=c56<C<f@T@=>DDh>4E3<d@d<S11ACPe<S4c<S8c@D53=38bAT4a<3P`@cDc
@D8h=3U6@dE5=30f<cA3<CPi<3=6@SQ63CTh@T@c=396=cLh=4=6AD@h<cA6=30b
=dE1<4Hb@S12=4@d>3<iAD4i@d8e>DA6<CM3=394ACDh>C8eA@db<4E5=3Pd=C15
<SE3<SA5<44f<3U2A3A2<SM4@DE5@T=6=d92=dE2<SDc>4A3>C<h@d8bAC=3<492
=C0==c55=cDbACDf@c52>C<c=T8i<451=DA6=3Da>DA2=D@bADA3@cLg=S<e<dH`
@CLa=cU4>CDf<3Ph<c<`3D@`@C8f=3E1=d55A44g>C11=b1>A0d_F3U3820a<SHP
DT@P<SA5@d94<3DcAD8iAS<f>3I4=3M1A4A4<30h<3LaA4E5<3Dg<3<bATDe=CHb
ATE4<391AD8g<CLi=30a3D@bAD8b>CTiA3A6=DH`A3Ti=394@d4cA495=C<e<CDe
=4@iAS@h@T8fASA4>3Hf<3@iA351=SE3<DDb@@e4ASLa<d8`AS14@SI3AT94AD96
<cQ6=T8c@CLeA3M2=CE6AC93AC53@cPc<3<b>D@aA3Lh<c=3=T@gAT4=@CPf<c0e
A4A3@DI4<cLa@S=3=d8b<c15=c4g<CI5=cE2@S8`AC0g=SDg>312=d@`>4Hc@THb
=d8b=SHa3C0c=DA4@CD`@T<iAB1>A0d_F3U4820a<SDPDT@P<SA5@d94<3DcAD8i
AS<f>3I4=3M1A4A4<30h<3LaA4E5<3Dg<3<bATDe=CHbATE4<391AD8g<CLi=30a
3D@bAD8b>CTiA3A6=DH`A3Ti=394@d4cA495=C<e<CDe=4@iAS@h@T8fASA4>3Hf
<3@iA351=SE3<DDb@@e4ASLa<d8`AS14@SI3AT94AD96<cQ6=T8c@CLeA3M2=CE6
AC93AC53@cPc<3<b>D@aA3Lh<c=3=T@gAT4=@CPf<c0eA4A3@DI4<cLa@S=3=d8b
<c15=c4g<CI5=cDb<CDb@SU1@c4f<C0f=D4a<D=3@d4dASTg=3M43CQ5>CLa>C=5
=c@PCT@=;ePiAB0P<C<e8594838dAD=2A30e<dE2>DHc=SPfA3@g@DA4A30`>30g
<DA5AC0e=c0c<TI5=CDf<TI5A30b@DE2=c4g>C@`<@e4<TE2<STi>D@dASE6<4@i
>C@bA4=1<dA2ACDc=C4e=CA4>DHd>492=THdA3Pf=S0d>D@a@CHe@c55<T4=A4Hg
<C=2<4H`A48f@dI2A4E2AS<hASI2<d4g=D@g@SDeATDb@dDa@d<h<c0c<SU4<D@g
>3<c@cI4=dI13D4h=S<`=DA4@d56A3<g<D8c@cM2<S<`ACLa=c4fACLe@T91<c4g
=SU5@c0h@c=4>3@f@CHd=cPd<T4h<Pda@CD`>C@c=4<e<d8g=d@dADA3A4@d=SI3
=cI1=c8PCT@=;ePiAR0P<C<b8594838dAD=2A30e<dE2>DHc=SPfA3@g@DA4A30`
>30g<DA5AC0e=c0c<TI5=CDf<TI5A30b@DE2=c4g>C@`<@e4<TE2<STi>D@dASE6
<4@i>C@bA4=1<dA2ACDc=C4e=CA4>DHd>492=THdA3Pf=S0d>D@a@CHe@c55<T4=
A4Hg<C=2<4H`A48f@dI2A4E2AS<hASI2<d4g=D@g@SDeATDb@dDa@d<h<c0c<SU4
<D@g>3<c@cI4=dI13D4h=S<`=DA4@d56A3<g<D8c@cM2<S<`ACLa=c4fACLe@T8`
@CE6<4=3=T8c<CDd<S4d@c@b=DDb=4E1@Pdc@T51<S15@C4`AC@g=C<aASLa=THc
<T4PCT@=;eQ1<20P=CTPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=c0f<C96=S91
<CHbA3Hd@T91<44d>D92ADE2ACP`@T@`=3ThAT8i3D8a@dA3@SDcAD@g<TE2<TDe
@cPd@cI4<T51=3@a@THb@T53>4Hb<SQ2<cQ5<cU4>D8`@c=1<4A6ATDPCT@=;eQ1
<B0P<C<b8594838dAD=2A30e<dE2=SDd=TA4@C55<CQ3@S=2<D@c>CH`=C4g>34f
@C0e>451<T54<CL`>3Hg>4E2=S8a<`e3@T<f=SQ1A456=CA4=CHc=cHhATDaA3E3
AD8h>4Dc<4A1=c=1@SA6A44d<3Df>CA2A3Pg=TDf=30g@D4==3<a<T@`A3TcA3I3
>C53ADDeAD51<c95@SDf>4E4>44g<DI1@CPa>CE2@CM6@SPf=SU4@cU4>313>DE1
3D8`=SLg=cTb=c4b=495<c8`AS95<C4a<c52A34f=CA2>38gACI1AC4f=353<T8a
>D52>CP`@C14<CHb=@dh@CE6@d@g<cT`A48e=C8b<cDa<3Lb@dDPCT@=;eQ1<R0P
<CT`8594838dAD=2A30e<dE2>3Le<d=1=4@fASLa<SP`>C<i@CLg=c4a@T8b=TI3
<cDe<S92<3E5<T51@C=3@c95<@e6>D95=d<c<TI3<dHfAT@g@C@d=D54ATA6=cPh
<SPi@S=5@d8`=S0h<4H`<C<g=TE5<SHc=48a<30b@S<=<34b=TA6@c0`@d<fA30d
ASE6>456@cLe<cA6=D<b>DDa<cI2<dDd=T94@S93<S<fA44d>DI6ACTfA3923C<h
ADA6AS0gAS4f=CLc>CI5<dA1ACE1=C<f=SE1@c4f<S8e@d4i@C@e@CU5<c0c=CDe
<D4e@S4c<SLh<0d`=TI5@TI6>30dASDc=dA2@cHf@dE2A3M6=3E1<3=1<TE4@D8`
<d91ACU5<4Hh>C0e<C15@d94=S0hA3@==S93<S@d<THf=cE2AC0f<34g>D4d<T=4
AS4i@d52=dE3<3<`=355AT94AD8h@S8e=C<f@c4c=S0eA38`3C@b=TDg=S@i>C8a
=S0h@D<`A38b84i43BmH@C<P834e<R1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=T@d
AS11<T8f<SDi=48h<C8h>DE5<cLf@S@c=SA2ASHh=CDd<cLc=cL=<T4`ACA4@DDd
ACPb>C56<S53>CU5=D@h>454<3Lg=DHc<SDc<d4e@S<g=3<i=T=3>352=48c<3Dg
@c4e3DE1=3Di<cU3>3=4<S@dACLa<D@i<3Dc<3E3<3E1>C0`@cU3@C4a<48`>DHb
A44gAT92AD<f=3I5=c@a<@df<d4`<3E6>3@a<T@g<CU3@CQ3@c=1@cPc<S8bA3A6
<cI3A34`=C8g<d4e>3Tg<4@e<D8gACDfAS@f<CP=>3M1<CE3<S8a>3M3ADDe@d@g
=SE3>4<i@S54<c<hAS0e<cLg<CA6AT55AD@dA3@`@d53@T<e@d93A3L`3DE4ASDP
CT@=;eQ1=20P<c<e8594838dAD=2A30e<dE2>3Le<d=1=4@fASLiAT96>CP`<CQ4
A48e@T8d@CDb@CTi=CA4A3Db@cD`ASI3@D=3@`e5<S14<d8g>48h>453=DE4=CLe
<c51=CTg<DA6<3@hA48dA3M1@DDe>D56>4@c<4=1=3I1@C4fASLd=TH==4<`>4Dg
>4A6A3DiA30f=CTb>C12<SA4AT55=S<bASI5=d@dACQ4=T@b@C8a<S<d@DD`>C52
<4@e<3@e3C51>3DeAT<d<d8`<TDc<D8c>C@b=38`<C91AD8g>D8h>3A3<D94ATE4
<TD`@d@h<c<b>C54=T<iA3Tg<Pdd<C8fATH`>30a=D8d<cM5@STdASU6>38eASM6
AS16@d@a<4I2<48b=4E4=3Pb=cA4ACI5@CA6@DE4=d<=@D4fAT8c@c15<T8c<cE5
>315<cD`=394>DE2AD92=S<bACLe@SI2@DI1AD=1>DE2>3<a=3M1>D@d<4=63C<f
>394=SPdAS=6<D@b@S8h=C=2=4<h@dH`<C8c<SLe=cD`@SDaA3T`=SDiAS<b@dI1
=SPg@S@eAD4h=`e4=C4hACDeA3E6=c8`=TI3A4=3=34g=CDb=30d<S@i@TI1@c<e
=SHfA3E1A34c<C@d<3Q6AS0d=cPaAST=<C52=T4h<c@b>D94=d91>CM5A3L`>4E2
=393AD8fA3=4ACA6@STf=S=4ADDb@c0`=cLiAT@g=C@b>CDh3CPi=C16=S8h>CDc
<D<fASLf<CPe<CPcA453AT53AT8bACDh<d91=S8iA30d=3Hf>C=1=c@h<SDb=3Hg
@@dg=T4`=T92=cLe<T4a=T8cAS4i@D=2=cLg>CI5>CM1=S=2@cDiAT<iAD4b=4De
@D@h<d8`@CU6=d8b=3H=>CU1ATDb<C8f@b1>A0d_F44e820a<34PDT@P<SA5@d94
<3DcAD8h=cDc@d4dA3I6>4I6@S=6=d4`@S0g@D94<3=4<D4e<c0d>DE3@d@c=4=3
<CA3<C@h3CU6<C<aACA5>D53A38g=44c@SHf>4DaA48eACM1<D<`<48g@c91ACDh
=T@i<3U3>DA2>C0c<T<d<T@i<`dh<d8c@dHeA3D`=T8d>34i@c4a<cDi@c@i<d8d
>CA4@cA1ASDh=DI1A3LfASDcA30e=S<dA34eASU5=D<==T8a<d8d@S@dADE6A3=1
=C@e=34d<R1>A0d_F44f820g=b1BA20b=4E3@T@`=C=5@SPg=C=3@CA4=THgA3Lh
@S4d>D8a=SA5AD@d<3@g<D=5=TDhA3A2<3Dd=S<`=3Dh>CP=@D@a<CHgA48a>3Ld
<D=6ADDaAD8b=d92@D@f=3E2ACH`>4E6=c<b=S8g@d8b>C=3AT4f<dHb=DDc<3Hg
3CLh>C@c@CM5AC<cASE1<SHiAD=6A30a<dE6=CDe@D<h<T8PCT@=;eQ1=b0P<S@e
8594838dAD=2A30e<dE2>D=2<STg<T=2<TA6>48dA4A6>D4a@S=6=4=4=c8c<T4i
@T96=T<i@SI2>4I5A44`<`dc@CDf@SM4A4I5=3Le<CQ5=DHd@cDe@TA4>C0`<SH`
ADHa=3<`=TDb=3E1@S56AT8gAC92=3I2=4Db<ST=A4@c<d@b>CLb@CQ3=34g=DE2
ACU2=DHc@SHi@SA6@C92=T<f=3Lb=3M4<c@c@cE5=C8g=T8i@CU2=CDh3C8bA3E2
>4@g=453>3I5<4@`@dDc>3@g=494<d4f=c8g>4Dg<cE1=3Di>3Lh@T8eAT53<T8b
A3@`>C4c@`dh@DA3ASTf<cQ4<dDc>CTc=455>4De@CM5<DI2@d94@dI5@c<e@SHf
A396=d4c@CDc>CHh=T=5<dDh=CP=<SE5>395<c=2@CA2=T=4@S8a@D8h@CE6=3M4
>DE6=d4cAS54A38f<S95>DE4ATI2@c53=d@f<SU4@d<e3CI4A3<e<TA5=d@`=CTc
=34b=S4e<C<bA3U5=TI2=cE2ATDc=4I3ATI1ACHg@CPc<SU4@T8h<d=3@S<`APdi
=TE4>394AC<e@TDf=DHi@SLe<CQ6AS=1=d8eAC0b>DHi=DHfA354@d4g@cDh<S@e
<T51=cE5>311=S0=>4I5>C8i<CDhA21>A0d_F44h820c<C@PDT@P<SA5@d94<3Dc
AD92@cHe@c0e>D<gAC8c<4DiA3U3<355<C=3@dA1ADDa<S8g=T4f=D=2<S=1<30b
=4=33CHc<3U1@DA3<D@`=CE3=T92A3U5=c8g>4D`<d4a=D53<CA3AD51<D51ASPd
A313<T<g@D<`ACE2<3Pi<@e6@C@f=cI4AS<i<d4d=SQ5=DI4<CHf=CHc<cM6<S@e
<dHd<C4bAC0b=c4i<S92<c4a>C0gAD@`<3M4=TD=>DHc<T@aAS=4<3Db=SE3>C4`
@D@e@d8d<38`>3Q5<S8h@T8f<CLg=30b<SPdASDe=CI4ACHd>DH`>3Lc3C@f@CHg
@T<`=TA2@CQ6A48e=4Hc=4@h>3@f<THg=SL`@SPeA3Ta<S@a@cU2<3Ld=CA1A3@b
A4HaAT8i=Pe3=c4`<dA2>CI6=CPc>D52>3HdADDh>C8c@cQ4<CDg@c92=cQ5AS8g
@c8h<DDg>DA5@S<e=c<dAS0dA4H=@C0f<S13@d51=T4a<d4d=3U4AT8a@c53=3Lg
<TE2=SHd<d<fA316>DI1A44hACP`=4E5@S4f@cA3@c0`3CP`>495@c12A34i>3He
<T8`AS@f=3Ph=dA4@C4eAC4c=cPc=38bASM6AT<`=TD`A4E1@cM3<D<b>4E6<`e6
=34h@dHi<4<`@c93@TE3A34c>4@h=T@d@S56>4A3<C@e<T8a@S91>CTdACPa@TH`
@cA6=CQ6>3Pe<c4==c<h<3A3<S51<34bA4HhA34g@cLg>CHi<S8g<cI4@d53<4=6
<S<c=d=6@S4a=4I5@dA4=SPg@dDc>44f3D=6=SPb=DE3=c8h<T<b=dI1=S4f=3He
@SE3>D@PCT@=;eQ1>B0P<SPi8594838dAD=2A30e<dE2@T<f=D<`=CU3=dE3A4Hi
AT4h<3Td<c0a<cLd=3HdA4I2=CT`=DDe=d8i@d92>CM1A@d`ASLh>3Pa>3<c>C96
>38`ACPh@cU5<cLi<d8g@d@f<cPe@CQ1ACHcA3Q3>3<f>3@c=3TeASPgACE5@SD=
=THb>4I2>CLb=453AS<f<CA4@SU2<SLh<3M2=48fADI2AS@h<SHaASDf=cLi<c=1
@d=6<c0aA3H`@c8h3CTh<4Hh=C4a=TD`=CHg<cDeACLgA493=DDi@cD`AT@a=3A1
=T54<S8a=C8h>C8gA3Q5@C8eA491=3E6APe6=3<iADI3AT8h@cHc=T95<THh@C4c
=3I2>D@a<3PbA44c>356<d<iA3Hi=3U6>CTf>D4c<cHg<S8hAC<=@CPb=S@e@D54
=T8b@C4i<311<c8fACDcA3M5>38h@S12=CTe@S93=D8d<cU6@SQ2<T<b=SDh=D<h
A3Di3DDh>393>CTh>4I1A3Dh<T@h=SPe=T=4@CLf=38f=T8f@CHiA4@e=3@dASHg
=3I3@S54@T@`AD94=C@eA0db@c0`AC8`=S<a=T<gA4=4=d@a<SM3=SI5<c15>34e
@TE2=dE4>C0d<CU4>CA1@CU3=S@f@SE2AC<h<C<=>3E6<c8d@cHa@DE1=S8d=d<i
<3I1AC4d@S8d=48g>3U5@d@h<3DcA44a=30f<3Tb=CTc>D@b@d92<cHa3C8eASDf
=c@i<S4d@cHc@CLh=cLd>44dA4@iAD8h=34gA3Ti=3Hc84i43BmH@D4P83P`8594
838dAD=2A30e<dE2>4@`>DHfA44d@c4h@TA1>C4`<cTe=d4gAD4bAT<e>C4g<CHf
=S@b@C8`=4=4AC@h@`e3>C=3AS=5>DA2AT4c<CHb>CQ6@c@d=dHeAT@e<C@e>DDf
=c4g>4De=DHc=TA2AT<b<dDcAS12A34d@cH==4<e@SA2<4=3AC8a>DA5<4@b=4Dc
ADHh<391@CDe@D4g@S<e@T=4<b1>A0d_F452820c<B1BA20b=4E3@T@`=C=5@SU3
@S8i=c93@S0iATDi=C8d@STh=S0c@C4d<cDi=S<e=CQ1A3Lf>D93A3He=c14<TD=
<dHPCT@=;eQ1@b0P<cLPDT@P<SA5@d94<3DcAD8i@d8b>CLb@d8`>D<bAS=3<4I1
>C<h>4=2@T8b=SDfAT=5>3E4<38g=CI1@D<d=d<f3C56<c8c<TE5=3Li=SM584i4
3BmH@D@P83La8594838dAD=2A30e<dE2>3Le<d=1=4@fASM5A4A1<SI5=C4`@c<e
>353=dA3@cLgAT=6<T4g<d@d@c<bASQ6<0dd>CTe=D<e@cM6@SDi<S0e<4E5=d96
>3U6>3Hh@cM4<C8`<dDhA4Db<DI2=d4fASA1@cDd>C<i@CU3<4<=A4@e<395AD4`
=C92@c0`@THiAS0aAB1>A0d_F455820g>21BA20b=4E3@T@`=C=5@T92<CI6@TDb
=3Tf>34e=CM6<CE1=C<d@cQ2@d4d<4<i@c0b=SA3<CE1<SM2=34i<C<=>44h=CHf
>4E2@c=3@d96<T8h@TE4@c12>48c>38b=453=d4d@STf<S@g=CLf<c4f@C@h>D=2
=CA5>C8i3CTe=c=5>CTh=C@a>C@`=4Dg@SPb<dE6>C<f=d8g<DE4A3Ha=21>A0d_
F456820b<3<PDT@P<SA5@d94<3DcAD8h<SU5=3@d@S0e=STe@cTi=d95<T94ADHi
>34iASTf<STiASD`@d55@D94A4A5=3Df3CA1=S@e@cTg>C0a=D=3>D@e<3P`>DE3
=d54=3E1=cLg=d92<352=d<b>3M2A4H`>CTa=T@i>C<i=3@f=Pdf<4A1<c0eA3L`
A4HcASLb=dHi@C0c@S0e<453ACTc<C0b<4@b@D8eAC@d<38e=CQ4>3Li<T=1=T@e
A30==D=1AT8c@S4`=dI5>D8e=CH`>351=3U1<S91@C8f=dI6>C8`=cE4<3Hf>CTc
AC4c@D4i<SLbA3Q4AC133D92<DA5ASQ1<D<`>4E6AS<d<D=6=d92=4A6<CTg<C91
@c4h<4A2ASM4ASDhA3U4@ST`=3Q2=S8f<S=3<`dg=D4c@c0b>314<SHc@S0i=d=5
>352<3=3>3DdACHi@S55@d4cADE4A4@b<4<i>CE6ASTe@D8f=CHa>D8=@DDa<STc
@cI4=44b<C4i<30c=D@dAD94>DA4@TI1@SDiA3A5ACDd@D=6=4E1@B1>A0d_F48`
820b=3HPDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6>316<c8e>4@c@cDf@THb=C<a
<3Db=T8a@d8a@DI3ADHf=cM5A3<a3CM1A4=1<dHg@cM4=30e<TE6A4H`ATDe>CDb
<3Td<30a@S4aAS14=cA2>D@b=dA5<S@c=4E2=d4`<CDf<0df=3Ti@dDf=TD`@CPi
@T=5=D56<d<d=34g=4<b<cQ2@S<d>D95@CLc=TH`ASTb>34c@S4d@C8eA3U6<3P=
@T8hATHg@D=2=T4d=S<aATHi=SA2ASM5=TE5=SM2<3La>CL`=dI5<T52@S<i=d<b
>44b@CTe@cTaAD@g3D<d<CHi=CPc>CLb=c8i@cLe<SE1AD@g>DA6A356ACPh@TI2
<DDf@cI6@SPf<TI1<d95<38d=cI4=S=5A0e4=4E1=T4g@D<b>DHh<3LeAT8i@C=6
<CTc@cA6@cPi<D4g=3Tg<38cA3M2AC0d<491>CM1<3Hd@CE5AD@=<CPi=cDb=4<`
>494<S0c@C52=D=1<3Lf@c<d@CTc<D95@T8b=cLaA30gAC@a@CDfA391ASE5@C=2
=C133C53@SQ2>30e<4Da<D55AC0cAD4h=d=5>492@CE2ACHf@S<d>3I2@C<b=4I5
=dE1=3Q3=3Lc<315=TE5=Pde<cTbAC<b=CT`<T8PCT@=;eQ2<B0P=S<PDT@P<SA5
@d94<3DcAD8h=cDc@d4dA3I6=dE4A3Db@d@g=3<f=3L`>3Q4=cPh<S4`<38c=THi
=3Ti@d55<4923CLd>C4iACPa>DA4>3A1=C0hAD4i@d4d@T56=d4d=4Dh=C<f=cPa
<S4cACDfASE3AD54>CHh=T53ASHd@`db>495=T4PCT@=;eQ2<R0P=CDPDT@P<SA5
@d94<3DcAD8h=cDc@d4dA3I6=dE4A3A3A4E6>38eAT4i=CDi=3@b<3E1ASE1<4H`
=C4e<c=6=SI63C51@SDbADHe@S<a>3Dd<TDd<C<c<D4i@dE6>4<b<CDi<CI4@D@b
@SHh>4<fAD96=c8e84i43BmH@S<P83Dd8594838dAD=2A30e<dE2>3Le<d=1=4@f
@cLi<STd>44`@CLd=S51A3Ph>453@c8f=SPh=3@hASA5>494>3=5APdi=391@CP`
<dDa=CPeAT4`ASQ6=TDaASTb>314A3Dc@T4`AD55=c0c<S=1<d54AC8PCT@=;eQ2
=20P>3<PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6=c0i=38g<4A1<C<d<48e=356
=CDd=d@i=D92<D8d=3M2@cDc@CTe3CE4<TI3@dA6>34g<T92>D<d>3<i>D@e>4@e
=DI6ASTa>D=6ACTg@cA1<4<a>D@a@TDb@T54=DDd=STc<0e1ATHiASHc@cDd=S96
<CD`<c4hASHh>4Hi@c4f@T@h=351<S@i<3Pd@SLbAS<`84i43BmH@SDP834a<R1B
A20b=4E3@T@`=C=5@SU3@S8i=c93@S<c<dI6=3U3=d4iAS0b@C11=30c=TDg<STd
>48b>D4h>4<g<SU6>C0=@CA2=3@dA4<d=d96>CLe<dE3AD<`ASI1<3=2@TI4ACQ2
=DDb=THh@CI6@D=3A4Dg=c11>3U5<S@a@CPb3C95A48e=CU4ATA2<44g@TH`AS0c
>CPh=D4`A4De=356=cPe@d8`>4I2=4<`@D<g<C8g>C@h<S<`<3<h<`db=c4gA44g
@D92=3<g@d54AS8c>C16<cI1<d8dAS8f=DHg<T8e@DA2A3E2=21>A0d_F48f820b
<3@PDT@P<SA5@d94<3DcAD8h=3Dg<44b<3U6=S53=SI5=T53ADE5>4E5=C0b=4E1
<3@d<4@g@S95=dDe=cHg>D943CDg<34b<48cA4@b=4Hc<3TiA30h<TH`AC0d=CLb
<48hAS8g=cU5<dHi@cI6>DHa=3@c>DI5<CPd@S@f@`dd=4A4ACDhA4<d<SDbA34c
AS0g=4A1@S8gAS11<3HbA3P`<356<S4cAD<c=C4d@c<`<CLf=D54@d@b@T8==S96
@d<a<3@a<4<iACHa<CA5ADDe=3I5<THa=D53>3@a=SLi<CLgASA3<TDh@S94AC<e
=C4d<T4g@S963DHd<d4b>34dA34i=3He>D4iA4De@d54=3La@d@f=CHh>3@f=D4c
AD53@CM5<d8dADA4<C=6>3=3=4Dg=@d`@T@d@DHh@D4f@c91>3=6@cI2@S@g@CA1
ACTc=4D`AS@b<C<d=SPi>CPaA354A4DgA3Te@T8g<30aACD=ASTe<S8i<4HhACPc
<S94=c8e@c<g@T52>3Pa=c=5ASLiASA4<T8b<C=5@T@h@D9584i43BmH@SLP83Dg
8594838dAD=2A30e<dE2>DA1<c0b<C@b<dA5=T4d@c0fADI6=3@`002Q0<0ood@i
<T8d=dE6>D95A4<h=451>3Tb=D95@T<=@T=6=3Dg<D4e<SU4=C4c=S@c<3M1AC52
@cU4<T<f=314AD8`=D4h>3Pi>4Hb>3Q1@C0`@THf84i43BmH@SPP83@g8594838d
AD=2A30e<dE2>4E4ASTg@dDe>DHaAC15=TDi>3U1@SM4=D<f>C0`=cA3=T<h=dHe
=3A1<T53@dI2A@dc=S<a=d92>C4`A4I6<3Te@c4`=d4h>D@f<C0`<3Lc=C1384i4
3BmH@STP83Pi8594838dAD=2A30e<dE2>356A3@f@S0e=cDiA3@f>CI4=454=3Q6
A4A3<SI2=d55>4HiAS=3<dI1<S0d@cM1=`e2AC8hA34f<CLb@SPi>D52=C<aA3@`
<4A1>C<d<3Ph@dD`<4E2@cQ6<CPiASM1@S4e<T8bAT91=3U6ASL=@c11>CA5AT=4
=STc=T=2<4HcAC8f=311>312=D8c@CTb<4HcA3Hb<T8hAD@e@c=4=d4h=d<b<3@i
AR1>A0d_F491820b<CHPDT@P<SA5@d94<3DcAD8i@SL`>CT`<CA6=CM3=c91A44`
ACHh=4HdAT@hA3L`<S@c<CPbA3M5@cH`=d8a@S0d3D8`=d<g=S16<cQ6@SPa<THd
@T8e<DA1ASDe<3M4<cT`>3Hc=DHe@T8d@cA6@C@h>C0c<c0i=3D`<d<d=0di>3A3
=3A3<d@f@C4`>4D`<3Th>C8g@D@g@T53>4Hd=cHaACPh@cDe<452ACU5=SLe<S4a
=d<aATHf>D<==353=DA5A44`<30d<d@a=SHe>3M3A4<c<3I1<d92@T@g<393ACM6
>454=4<aACM4@DE2@D<i<cTa<cPe3CE6=dE6=3E2=T54<D91=dA3@dDc=D<d>CPd
=c8c<c=5<D55ASI2@c15>48`=T95ADE2@TA3AS92ADDfA0df@T54<CDd@d4iA4=5
<3<`<T4`@STg<SLbATHf=cM2@S<g<351<CDc<T<f<3@`>4E3=CA2>CLf=cA5AT8=
@T=3<cHa=dA4<d4i<SA2@S8i=c<b>3A3@S53@CP`=DI6<SDb=T8f>CDa<392<C0`
AT52=CI1=c<c<T8d3C4i=c8`<c8a@c4b=R1>A0d_F492820b<C4PDT@P<SA5@d94
<3DcAD8f=D=4>D8a<C@dAC4c>315<d4a=cDc=T@f<S56A3Lf@S0c=D53<S<h>C=2
<CHi<SDe3CLf<d8a<D4g<cH`=D<a=cHf>4HcASDg@CQ4=S=2=48iAS8fA3E6<dA4
=C4e=dE4>3A1=D@a>3A3@SPi<@e3<c16A313<DA3<CTc@CHi=C8h@SDa<CM6@dHg
A34f>D91=D8c>3ThA495<3Tc>C=5<d4d=cHh>DHc=cT==3A3>4E4@TA2=3U6<312
>CDcAC<f<30gA3LcA3=3<cLb@S0f<DDb=3Pc=c54@C@e@TI3AC@hACTb=cPg3CI1
=d4f=4@a<38c>C8c<S96<4A2AC56@CHe=3@i=dDg=T8h=T8d<S16@c4h=T@f>4<`
@SPh@T<g=4D`@PdcASHi>DHa<34d>4Hi=4A6<C@h@SHhAC12=3Tg=TI6>3<i<3Td
@SD`ATHi<cTd=D<d<d4e>44eA3@f>3@=>C@g=SPe=THcASLh=d4a<CDh<dA3<S93
=D<b<S=4A3Q4=SDcAC8b<44a=DHa@cHa>CQ1@S@d=cLh=CHh3D@g84i43BmH@T<P
834c<R1BA20b=4E3@T@`=C=5@STbASDg=c<g@C<eA4=3@cM1ATA3<cA4=3U4A4I2
>4<i=SLf=d95A356@CDgAT<cAS4=<34`<C4fAC8d@c54>4A4<30c@CP`@c@i=c@h
<T8fA396AD@h@CA3AC<cA3E4@TE6@C0b=cQ2>CTi@cHd3DHcADHf>34h=TE2AS4`
ATE1@dHg<d=3<SHh@CU2@T96<d<`AS0bAC<d<d8h=D<c<TDc<C8b<313<TE6<Pdi
<T<f>30g@SA5<CU6<C<a=cI1ACQ5A4Db@CA6@SDb=30`@d8f>C55<T52>44i=C4c
AS<c<3M5=3A3=T@=@d8i<S56<cE2=cLe<C@d@SU1@SI1@SHa84i43BmH@T@P834g
=B1BA20b=4E3@T@`=C=5@SQ5A4Hi=d=5=CU6@D@e<T<aATDa@CTgACI6@CTe=4H`
=CHhA393=C<hA3U2@dI6<CL=@TA3<cPdASU1>D@c=C@g<C4f@TDb@cHd<38gAS=1
<cU1>CTa@S4i<cLfA3Pc<C53=T8a<4I4>DA3@cA23DHf=c15<C@h=S55<c@b@dHf
<cI2@c8g@D<cAS52>C96@S52=3I5@d94<DHd<c0b=352@S0cAT8a<STh=@e3AD8b
=C=5=dA4=d4d=D<g=c<cA4<d<DA6AC0`ADA2=CI2@S8f<392=4<h@SI6<d4g=CPf
<d4f<CM1@S<=@STe@C0b@SLb=C4`=S0b>CA1@SI2<T4h>3DcATDi@d<aA4A6ACPc
@D8g<c4g=3HdAC4b=D<a=D8gAC123C54>355=cPa>C11<4I5=34i>CPg=3Da=DHi
=34a>C8iA4<d<TDa<DI4<3Di<c0d=38a84i43BmH@TDP83<f<R1BA20b=4E3@T@`
=C=5@T96<DH`=DHh=CA3<3Pc=CM6<D53=TI6@D4gA3=2<d4iA30e=cPd>DHiA3E1
AS8a@c<=@STi@SDg=SE6<3U6@CLa=cQ1=c@i<3Q6@CQ3ASTg=d=2=TE3@C8g<T=4
A394=T@h=T=1=TI2@CP`@TE53D<f=C4aA3T`=d4h=3=2=C@h<453=c0d>3Tc>DDd
A48e@C<i>CTh=dE1AC54@cHe@DDc<S4h@T51@C4`@@db=454A4<e=3I4>4<`>C<`
<cDg<4<d=456<SLcAS<fAS96ACA5@DA1@T4i<C4g>DHb=c=3AC<g<C53<c<=>C8f
<CQ2=C<d@d8f<S=3>48g@T@fAS@i<d<g@SHh<D8a@c95=CE4AC@e=CE1=4=4@S<e
@cA3=d@dASI13CE5ASDg=CTc<CPc=c0i<C0eA3Ph=d@`<4@h>CTf=SU2@S=5<C=5
AC12<S11=3<g@c8e<3=5@CE1AC0bA@df<DE2>CQ5ADDh<34`=C8b>D8f<CPg@d=4
=D91<cE3AS0b@DHg@T@i<DHi>CDdASA2<CPc=D<b@D96@c0=@S<g<STf<THe=4A5
@c92<c<fATDh<S54=dH`=c8g=cHi>C15=TA3<cU5=c0`=S@i@cLaAD=6=313>DA2
3C0i<3A6ADI5>4@cA48gAD54AC0`>3A3=c<f<D<d=SDg=4Dd<STh@SLf<D95>3U5
@T55<cA4=CE6A3LcAPde=CM2A3P`=cHc>3Da@CTb<T8`=3Pf=c14@T93=THg=d@`
=T8g@S55@DDb<cA4>C=5<dI3=3@h@c@i>4@=<D=2A4@`=C<g=c@`=CHf>394=S<h
<c=3<S0`<C<f@DA1=3A5@CPi@DHa=D@i<S55=3Ta<cH`A3Hg@C933C8e<dHf<TE4
ACDdAS8a<D4b<TDe<d8h@T55=T8a=cHf=c0`>DE2>4<bA4Hb=S4e<DHd<CL`<THb
@DHf<Pe4>48`84i43BmH@THP834g>B1BA20b=4E3@T@`=C=5@SU4@C<`<S4d<S<b
=492@dA5A44eACQ5=C<bASHb>34e@SHh@SM3AC@f=48a>30eA4H=@CPfAS4a@cLb
=C<gAS<g@c0e=CU3=T91=3<g<SDe@CD`AC0e<c0e<3A2=3Ti>3Q1=SM3<4@c<d95
=CA23C92@c55<d4`=CTi>DDa<CTa=D56@CM4=CLg=CU5A3Pf@cLfA3E5<cE1@D<e
>CI3<S91@THf@TDc<T4aA0deAS16@T@b<d8bA3U2@C@i<SPd=d8`@C=5@dDh=cLd
=S=6<DHh>38f@d4f<d@h=SM1<C4a<dHg@D@b@ST=ACD`=3T`=C<b=T4i<CLa>48f
=30a=DDc@c@`@D@`A3@b=3Q1ADDeAD@gAC<h@S8e=T4`<dDf@SH`>CU33D4e>4De
@SLd<CD`>4I2@c=3<d4h@SA2<T<e@S<e<d96>D@h>D<`=T4a@cM1@cPcAC<e=c@d
>CQ2@SPPCT@=;eQ3<20P<CLc8594838dAD=2A30e<dE2>DDd=30a<SDg>DA4=cE4
>3@iACE5@T=4@c<f<cL`<30b<STg@D@b@DE4<D<`@c8c>@dh@C@e<c8fAS11=d8h
ASE1<CDc=c0f<d<a<S0f>CQ2=cU6=c8`@T=1<dE1@S94ACA2=cQ3ATHd=d@b=4H=
<48g<S@c@SA6@SU4=SHa=c4h<4I5@C<d=c92A38h=C8b=3<eACE3<S<cA44i=D4e
A3I2=3<d<SA3=c0d3C4`=STi=d94>CLf>4@fA4E2@THb=c0i@S0h=DDi>CPi<d96
>4@`>DE5ASHd=3A5<3@a<dHd<T4hAS=2>@dc>3HaA44e<44d=CT`<4@f<S0c<C@g
>30`=S13@ST`=4<e@C4d=S0iA3@h>4<e<4@g@DI4>3H`=dA3>D4=A4E4@cE4@DHg
=3Q5=3Pb@C<e=C8aA4H`@D@e@d92@CU3>3<a<3HbAT4b<3Ld@R1>A0d_F4<a820d
<R1BA20b=4E3@T@`=C=5@SHgAC<c=T51=3Lb<S92<STe>3PgA38fAC4b<S@`<dDi
<dHe@C4h<3@cA3=4A3I2<d<=@c<h@S0e>DHdAS<c@cHe<THe<TA3@S4c84i43BmH
@c8P83<c8594838dAD=2A30e<dE2>3Le<d=1=4@fASM5A4A1>DA6<30g<S8`>452
=SDi=S11>CLb@D=6@S8b@S0aA3M3@Pe3=3<b>3<PCT@=;eQ3<b0P=C0PDT@P<SA5
@d94<3DcAD92A3=3<CE4>CI3AD<eAT<gA4E3=SQ6=T56<34b>3Lg=48fA3I5=DA6
=SM4>C0c>C0a3C8cA3U4<dDb@d94>4A3=cPd>CPi<44d@d95<38c@S54@D=6>CPb
@CLPCT@=;eQ3=20P>C4PDT@P<SA5@d94<3DcAD8h=cDc@d4dA3I6>3U2=C8c>CDb
<cI6=C@`<DA5>3Te>CE1A3Ld@DE4@d4d=3Pg<d@g3D<g=CHa<D<e<dE4@T@cASU4
=DHeA3=3<38c@DH`AT@a=D<f=C4eA3I2@c@c=cHeAT@fA3=5>CPd<3Q4@@dg=4Dd
<T8b=C4bACM1@D4cADHh@DI2>3Lf=c8i@DE3>C@h=34fA451ACE6<SPb<cDf<CPg
@CI5=CTh@SH==d@PCT@=;eQ3=B0P<SHe8594838dAD=2A30e<dE2>3Le<d=1=4@f
@cLi@CDi=48g<S4c>C16@C0i<T<`AC@bA3<bACDf>D<iA316>DDf@Pe2@cPe=c0a
=cThASM2>DDc<38a=dHh>3=4@cTe<4<`ADHc<3DiAT@fACI1ADHf@C8gA456AS8c
@C4aA30=@S0c@c4d=SHg<CTcAD52<cA1=S0a<SL`=CTe>D4a=3M4A3De<CA6=C4i
ADI6=SA6<D4g=S@cA3PeA3@i3D4c=3Q4=CI5=c<`=d56@SD`<T51@cDd<T4h<SPa
<CM3<CPi<CHf<4Hd>CHhAD8b<4Hb=3@f@CDc@dE6<`dh<C8g@S<b@TI1=S@e=D4a
ASE6@cPa@SM5<44b@THb>30b<T8e=SA2<dDa=c@h@T4i<C0i<C<e<C0f>CP=>CTf
ACDa=CP`A4@`<TA2A48c@TA4=3U1@c8a<d<aA3L`@cLd=3=5<S0c=SQ3=D92=391
<D=5<cLd@SI13DA2=DA2<cI3>396=DI6@d4i@SDe>DE1A3A2@c4f@SHd@TDf=S0e
@SDd>DA1=44i=CM6<dI5=3E6A3Pi=`d`=SDa<S11A453A453ADI4<cE2A493<T94
<3A3<3Pd=c4f<4=5<456=D4a>3T`<dI4<D96=4Hi@cA3@D8=>3Ph@DHe=T4dA4@c
@c0f<S8`AS0`@T52<SDb=cPb@CLd=4=2>CLf>3Q5=3E6<c14>D<PCT@=;eQ3=R0P
=C0PDT@P<SA5@d94<3DcAD8hA30iASI4@C@iASE5@S4eA34f<CE1>CHaAC<iACDa
@C56=SU6=3Lc>4DgA3Pe=SLe3D4e=C@c<T=2<d4fAS4d=SLc>315<CA1A48`@cDb
AD=3A312=4@gA30PCT@=;eQ3=b0P=c<PDT@P<SA5@d94<3DcAD8i>38d@C0f=3Tf
>CM5>C0g@d4d@d<d>3Dh@d<e<c93@T96=S<bAT<dA38fADE1>CLe3DI5@cDh<3A2
<STd<4A1@D52<44h>C8e<DI4@T@a@TA4@CPc@C=5<C8i=3@b=3Lg@DHi<34b<c4c
@C11@PddADHa=TE5AD94=3U3@T53A3La@DE6=D93AB1>A0d_F4<h820g<b1BA20b
=4E3@T@`=C=5@STh<SA1<3Hd>CHi@c4i>C93>CE2AD@hAD=2<CU1<3A4>4Dg@SQ3
=3@h=DD`@c4c<D8=<cHi>314A3@d<TA5@C16<D8c=C4f<3Lf=S@c@TA6@DD`=DI5
<C4e>4=3>34i=CE6<cLh@cHfA356ADI23CTb=4E5<DDb>4@e@C8e<S8g<TA5@cDb
=T4g84i43BmH@cTP83Di8594838dAD=2A30e<dE2@SE6=4E1AT@f>C@b>30f@CLd
@dA4AT@c>453@D=2<S0i>30d>4A3ACDe@cPg=S8a@`e5<T@`=T4i>C4f=d=3>34e
>C51ACHi<c0f=S0e>D95@TDh=dHfA3@e=C@gASI1=493<4He=d<a>4<c84i43BmH
@d4P834b8594838dAD=2A30e<dE2>3Le<d=1=4@f<3I3=B1>A0d_F4=2820h<21B
A20b=4E3@T@`=C=5@SPc<CDa>C55AS0i<C<e=DDf<c4iA3=6>C4a<3Df<D=5=44b
@THh=THg=d@g<D8a@C<=>C=6=DDa=4E4=T<g@c=3=d<b<SU1<cM6A4Dc=3Lh@S=3
@S93<C0gATHc=c91=D<d<cHc>38a<S0c=STc3D8i=44e<D<i@THi<D4i@T8i@c52
<3Pb@SQ2@d@g@SI2@T93=CLc=c0PCT@=;eQ3@b0P<CHi8594838dAD=2A30e<dE2
>3<a=C4i<DE6<3Ta<cDeACHc<CU4<dHi<C4`=CHa@dDd@C92ASPfASLgA3La@S51
<`di<dHeAC4dAD@f@cM3<d<g@c8b>D4c=dI4AC<d=cQ2<d=2<T<a<3M6AS<g<T4e
@c@c=S<h<S4b<3<f>34=@d@c=S95<T@gADA6@cM1<c0g=S0g=S<h=4<b<C4`=CQ3
<30f=cPaASE3<48h=C0b>30d>C0c>48d>4<d3CE6A452<CE1>4Dh<DDiAC8c<d8b
AT53=cA2A3Dg>4<cADHf<dHd<SLiAT@c=3LfA4Db<S15<C@a<C4g=0e1=4Hg=d51
>34b@dD`=3Pi>496=SLi=CQ2>355@C<cA30d=3A3@CTb<3M1=c<`A4Dc=355>3M3
=CDc<3L==c14=c0b<SLi@cQ6=D8dADDf<c@b<TE1@d95=T91@SQ4<c4a<4HPCT@=
;eQ3A20P<S@d8594838dAD=2A30e<dE2>38iAC@d=48`=CU6>CE1<D@d<DI5@c0e
AD4b<T51<CU4<cA2=D4`@S=3=dDb<30a<Pe4<S53=c51>3U2@THb>C8g>3Q3<cPb
=cM6=c91=4HaADHhASD`<34eASLe<C0aADHbASU1>3Q4A30aA3T=AD51>C55@C92
AD8g<4Hb>44f<T@dACPa<C4c>353@CLi=d<f<3HhA3Lh@S0g<d4i=T4d=DE1=3Dg
<C=23D@d@S@`=492@d=5@D8b=S@d>C@e=TDc<c8i@cHa>392ADDd=TDc@SLcAS@c
AC0i@S0e<c51ADDd<d54=`deACLc<3@hAT4b<D8bAS8g<S11<C8h>C@f>3Hc<c0a
>315<CQ5<S4a<THd=SM1<C4e@CT`ACE3<3HdACH=<c8c=S0d<d4`=48gA451=4@g
ASTe<STf<SHb<SE5@d53=44h<cDbASHh=S0e>CDiASDa<dHe<DE5=C513DHg<cE4
=3<d@C0fAC8`=cTf@CPfACQ5@STh<C=3=3@c<D<a@D@a<C0h@C=6=cHf>C@c=DHi
=S94@CTbAPda<SQ4@dHg<CU3AS<h<4=6>30i<c15=C@d>3TfASPf@d=4<TA2<S=1
@S@`@cDg<CI2>3Lh@TE3ASQ5=c<==3<d=c=2<4<PCT@=;eQ3AB0P<CHh8594838d
AD=2A30e<dE2@S4b<S55<SI6@d=4>4E2>CM4@S<f<34g@dE1=48d=S4fATHaAT<g
@cLf<c@f=T<d=Pdi=cE2<3Hd=ST`<SA5<4=2=D91>311>CDf=3E5<3PdACHg<C95
AS0c>44e=CHdA4Dh<T51<4Df=D=2<D4=>CDg@D4g=cTh@d8cAC4bA4@a@c=1@dE6
<T@d<C91@T@aAC=1=3<h>D4f=TA1<STbAS<e=4<i<4A1=S8b3C4a<SPa@dDdA3Dh
=C96ASI2>3Td=S@b@c8a@C<i=4E3>3A3=dD`<SPe>DDg<D4g<CPa>30gASM6=4I4
A0dfACHg=3E5>C4aA34i>CA5=CTi=T<f>DE1=44h=D4b<4E5=SU1@CE5<dI6A4=4
=S4i<48c=CPcA4HbAC<=@DHc=T8d<SA1=CTbAS0fATHh=D4b=30a<cHg=C8f=T4b
@cHa84i43BmH@dHP838h<b1BA20b=4E3@T@`=C=5@T92A30b<3D`>D@g<C0`=D<f
@cHd@cDe@c56A38f<3I4>C<aA30c=cDi=4=1=C<iA3L==T8b>D=6@d8a=cE4@cA4
<S55=d4d>D51=3Pe@CDhACPf<S<g=34e=D8f>C8h=38a>4=1<S92=30h=DHh3C95
A3DgAD8h=4Da=SLiACPf<CP`@d=1=3@f=d@`<DI2<THa=DDc=311<T@i=C4d@SDg
@CE4=T4d@d@h=@e5<48i<3=3@SHh=C4`ASDa@cLa>44`@S0f<S0`AD<c<C13=T91
=3Da@CQ5=C<c=3M6>CHb@SQ4@dI6@C0=<3<d=THd>DA5@DDc=cPe=C4`>DE6=SPf
ASM4>D54AC=6=CDf=3Hi=d@e<d4`AT<a@T<a>4Hg=D=6=3Q33CPg<cPa@cPc<cDc
AD54=4E6=CI5=cI3@d8`@SLh=c@a<cDh>311<TDc<3Pa<d@`A30d@STh@CTc=SDc
@@e3@c<g=30a<STb=DA6@S8a=cI1ACM1>456=d8f=T51<cE6A4@b=d<gADDa=D95
<CTiA4=5AT92=c0h>4<=>3Q5<CDg>CI1@S96@CHeACU1=THf@DA1=4<b<4@hASLi
<4Hd=d@a@cM2=S4g>C0b@c<f<d=3A4Hh=THd3D=5@SI4=CLg<cHf<C<`>3@eAT8f
@CDhAC0cA3<a=TE2<d51=3=4<DA3=C8dAT<b@D<f=3Q2>3=6=d92<Pd`@T8f<CU1
>4=2@d4`@C@d<S52A456<S<f>21>A0d_F4@`820b=R1BA20b=4E3@T@`=C=5@SU2
ASM1>3M4>CU1ACM4>D<b@c4e<S=6<c8f>3U2@DI6=d=5ADA2@d=684i43BmHA34P
838f8594838dAD=2A30e<dE2@SE6=4E1AT@f@d53<c0h=C0b<CE3@cLi=4@g<T<d
@S94AC0a=3@b=48PCT@=;eQ4<R0P<C8i8594838dAD=2A30e<dE2>D4hACI3>4I5
>CM4=d=3AS=1AT<c@D<`<SQ1@cPd<CPh=S95AD95@c51@CHg<d@d=`da=4@h<C<c
<cQ2=TDbACU6=c0i@C4d>48g>D@iA3@a<SA6ACA6@SPbAS95@dDd=c55>CHi<CHi
=CLdACL==SE4<DA4=T91>311>3A5<3U5=CQ2>DHc@SLd=CA4@DHf<T51A3Hi@T95
=CDd<dDgAT8c@S4i=d92AS@i3CLh@C0g<SHi=D8dAS95@d4c=C95ASQ1=SHh@SDf
A3@h@C4c=d=5@D@e<S0c@cU3ACI1AC8e=D<h<S@i<Pdd@cTiATHbAC8c@c=3<c0`
>4@PCT@=;eQ4<b0P<C8h8594838dAD=2A30e<dE2>D4hACI3>4I5>4@a=D=5>316
@C12>4I5@cLi>CP`@SLi<cLe@dD`@SA2@C4e<4@f<@e3@d@a<STi@cPi>DI3@D4g
=STa<DA2<CU3<cTf>396@dDf@TDe<C14@d4a@DHh=T56<T4e<C@i<T56>38=<S<`
=D4f=DI2AT=3@cM2=44a<d@b>3Lb@SLh>4Df>3@`<cM4>4@f@d@`<C<f>CTgADI5
A3U3=352AT8c3C<a=44hAS96AD8h<dA2=cA2<CLgAC<a<S=6AC8g<dDa<3Di<S=2
=cHg=CE6=4@a@C0i<315>3Tb@CTdAPdg<dHi>3L`<CDc>D53<THe84i43BmHA3@P
83La8594838dAD=2A30e<dE2=SM5<c<f@D4d=c4f=dHf<30cAS0f<S93AS0g>3Tb
=48i<D94=3@b=351@c0i<dDdA0d`<3Q5<4H`=DA5<cPc=cM6@S8c=3@d@D@g@CD`
ACHa>DE6AT55>3U3=S0a<THf@c16=cHf@SLhACU4>38==S8a@d<h<STaA38`@CTh
=C0eA4@h=b1>A0d_F4@e820g<21BA20b=4E3@T@`=C=5@SHgAC<c=T51=3Hd=SPh
=d55>48i=3I3@D<e<3Q5=C56>C<iAC95<CQ1<dI3<S16=D8=<CTc=c<f>4@b=C<g
A3@i<d@f@CLg<cLa<D92@c=1=d@f@d<i<CTa=S51=DA3ACE1<C<g@D4d<C54<S0g
3C0eAC91@d@e@DI3A3<f<d91>3=384i43BmHA3HP83Dc8594838dAD=2A30e<dE2
>3Le<d=1=4@fASM5A4A1>DA6<4<cAS94<C0g<3=2<T@i>D92<351<S51=STd@S0e
APda@SLg@cP`@T<cA34c>3Pg=T8aA3Df<cA6=d4`=cTd=SA5@cTa@D=5A454<S14
84i43BmHA3LP83H`8594838dAD=2A30e<dE2>3Le<d=1=4@fASM5A4@e=351=4I3
=T<a=3Ti<C0a>DDiA356@S<`<C=2=S4dAD<eAPe6=CM1=D93ASTc>3@b<CTgAT@g
<3<f>4E4<cU5AC<h>38gA3LeAT4`<cQ6>3DgAT95A30eAD8f=T<f@D8PCT@=;eQ4
>20P<C4f8594838dAD=2A30e<dE2>DHh=S16@dE1=T<b>3A1=cTf<S0d=S53>34g
<CHf<T56>3Ph>3Hf<cU1=c12@d=5=`e5=44`<cHd>C@f=D=6ASTa@S0h@CA2>C=3
AD8e<D@a>D8e>3Te=STa@d<a@D@`=c<g=c0f=4Db=3=4@S0=>D4h@d=3ASDg>CDb
<C0f>CLc<SA3>3U6<T8h<c@hAD<h=D4b=S4h=TA3A34b<T=3A4Ha>4Dc<4He>3Q4
3D@f<T8eA3Te<D<i=T@b<C4a>CP`A48hAD=6@THg>4=6=CTc=C4a=TE1=3<d<S<g
AT54A3TPCT@=;eQ4>B0P=c@PDT@P<SA5@d94<3DcAD8iA4Dg@S0f@CPg=SDe@TD`
@d92=34g>C4dA34`>DA5A4Dh>CI2@C16AD93@d<c@SDd3CPi<d96<C=2<3Q6=SPf
<48h>3@i<D92>3M1@cA1=T@eATA1=c13<TI5<d<aAC=2ACM4ASM1<CHa=TE3=0dc
ADHa<CTa<STaAC8e<4I1<4<d=SLb<355A3Lb84i43BmHA44P838i8594838dAD=2
A30e<dE2<4E2<4Hc@DA5>D91<c52<d8d=c<h@C4g>3Ha@D55<cHdA3T`AD8a<C8g
@C=5>C<PCT@=;eQ4@R0P<C<i8594838dAD=2A30e<dE2>38f=c<f>CPh>C13AD@b
=DI4ACHi@dHb>CPi@T8e>D92ASPb<D94=SQ1@CTbA4<`A0dcAD8c=dDf<44aA48b
@D55<44g@c8h>CD`<c0g=30h<C8`A38f<311@CTh@C@aAC4a>CI5@CTa<4<b@S@=
@SA4<dD`@C0`@SLd<T8`<SLa@c=4=44i>DHh=c4e@T<`=CE5<DHd=c<f=dI3@SA6
A38f=4A4A3H`<dDf3CE2<TA6=cHe=d8b=T95<CPa=C4a@C54<S=3=c93=C@b<dDf
=CQ6AT@c@cA5AC0c=c=2<SHb=S0h>C4bA@de<cI3@S12@SU6A396@CM2@DHi>CI6
<3E4ASHh<CQ4ACLa<D@e=21>A0d_F4A3820d<b1BA20b=4E3@T@`=C=5@SHf@TDa
<c4c>34c<3<i<T<i=4Dd@TH`=T@i=cM3@T=4>CA6A3Hh<3=1A34gA48e>48=<THh
<SM3@C52=cM3<30f=S=5=TDfACM1AT8PCT@=;eQ4A20P=3<PDT@P<SA5@d94<3Dc
AD8f=T95<C<a<cPa<c@hATE2>3<b<cP`=SM2<3Ld@SE1=dE6<3I6=dI2=CHi<c4f
<THb3D96AT55>CLc@d@d@SA6@dDf@SL`<C96>C0d84i43BmHA4DP83Ta8594838d
AD=2A30e<dE2>D<c@T<b=CU4@DHa=4Da@T95>D4i=T@e<D@a<D=6<c<e<C8e=C8e
>3@i<d92@cLbA0e6=cTb=C95@C14<cQ5>CD`=SDd@SPd>3@h<D91<3Q6@c@h=353
A392>392=D@d<T8b@c14@CM5ADH`=DD=@dE1AS51<4<d=C4`ATHa@C@b<CHe<C4c
<CHd<SE5<T@c=4<d@SH`AT=1=DHh<T8`<3Pe=C@a<38`@DI33CTf84i43BmHA4HP
834`<21BA20b=4E3@T@`=C=5@SU3<d93<SDiA456=c<f>D4`=3E4AC<g@d52<SLi
<D54=493<D<h<T8h<cI6=SPe@C8==cA1=d4i=CM4@C<i=cM2<D92@C<cACA1ATHi
@cA4<3P`<44i@cA2=3=5ASA4<T94<CA6@ST`>396@CH`3D4e<D<eA3De<c96<456
@dI1>C@`@d=5=4=3=c=4ACA2@D@c=T<dAT<aA3Lf@CPhATDf>4E5@CU4@T93=0dh
AS13ACTi@T<fA3Lc@T8d=SM5<B1>A0d_F4D`820h=b1BA20b=4E3@T@`=C=5@SPg
=C=3@CA4=THg<3Ha<THf<T4a=S95<cHc<T4iAC<d@CQ6=TDa<T54=3M5<SQ1=CP=
<3Hb=3@`=DI4<c16@S@d=CHhASDb<SPc=D8e>3I3A3Dh>D=4<CDi<C94=3<`=DDe
=d4gA34dAD<i>CE33CDf=c93>353<SPc=S8`<SH`=SPi<D<g<CU5<SA6A34d>D@a
ACDcAC0e@CI1=cLc=30e<C=5<R1>A0d_F4Da820b>B1BA20b=4E3@T@`=C=5@SPg
=C=3@CA4=THh=4Hi=c8dAC@c@T<i=3U5=c53>3Lh@STd=SQ2<d8e=T@cACA484i4
3BmHAC8P83L`8594838dAD=2A30e<dE2=SM5<c<f@D4d=S@f@S<h@c<h@C<f<cD`
A4=3ATHgADHeA3LiA3I6<C4c@D96<3A3>0daA3M3@TA6=d<g<4=2@dI4>38bATI3
=CHi@c@a>4I3=3Pb@SHg<4DfA3Lf=c<g<dE3<C96A496<3Ti@c8==D4i@c<bACM6
@cLa=CHa<SQ2=D<PCT@=;eQ5<b0P<C8h8594838dAD=2A30e<dE2>D4hACI3>4I5
>4@a=T<g>DE2=dHc@S4b=3Dh>DI6@DHd>CLc<d<b<SQ6<S@d=SDb@@e6<44b=4@f
AS0i>3@iA3E4<CA5=cQ6ADA5ASLeAD=2=cE6=cTh<38gA4Hd>4<a<SDa=3Pa<T8d
ASE1>CP=>DHi<3@cATI6@D@h=3LhA4@c<cI3<SU4=CPc@D56AS<f=3Lg>34h<CDd
>4A5@CLe<DE6<c0h>3@d@SLg3C0d=C0b=3Q3=TA1@S0dASU3ADA5AC4c=3A6@STg
@c92=SU6A492<S<`AC<f=S8h<c13=3@b=d8g=SM5<0e2<c0f<351=C8eA3Tc>396
84i43BmHAC@P83<i<b1BA20b=4E3@T@`=C=5@TDc<393<C=4=455=D56=C=4@SLe
<4HhA44e@D8g=DDe@cA3<S96<c8e=D54=d4c@d8=<SHh>DE3AT@gASPd=3@e<CM1
<3DgA3HbATHc=c@f@CPc@cPbA4@dACTc@d55=491@cPeA3Pa=38d@TE33D8b<DA2
AS@e=dI4@cHhAC8eA38`=cDg@c8g<CM4=S8h>C0iA3Dc@cLbAD8f<3<gAT51=3Di
>DI4=3E1A@e1<4@i@c16=CI4<C4g@S4e>4Hf<C14>353<c4b@c=1>DA6>3@eASA2
AS51<C@b>CTf>C0a>3Pi=S4f=CL=>391=S=6<4Dg@SI4@D96=D51@TI4AS53AC14
@C4c@dDe@C54>3A1<314AS4g=T@bA3<b=cTf=CM6=4943DI3<cLg<DDa@cM2<T<`
A393<SQ6<CT`<S0c=d<e=3TcAT4h@cTb=S4fAC8`=3=2>C=1@CM6A48e@CDh=0e6
<CTg=T@h=c8a@TDc<C93<SPg=T8cA44a<c@`A34d@THb@d4h>4E1=SDi>C@c=T<`
@T4f>3Hd>DE2AC<=@C56>48i=493@d@h=4A3A44a@d8f@CDd=cPhAS8f<4Hc=D4h
<TE5=THf>4@g=CHd<352>CE6@SDb=d@c3DA5AD@f<S<`>D4c@C8b=DA5@DE6<CA3
=SA5<CLc<T4d=48hA4A5<SPg@C52@d54ACQ5<CHiA4@aAS=1<Pdg@C<h>C4e=452
@c12=4E4=CI3>4@g<d<b<S<hA3Hh<4@d@TDe<3U4AC@a@SI5=3Lc=3=2>DDc=cM1
A48=<c<d=T<`A3Hg=dHd<4E2=S=6<3A1A44f=TI5=CM6=THc=SQ4AD8h@c52>CDe
@T54A3Hh@CLf<3<h=d8c3CDcACTcACHcA454>C0i@d51ACM3@SDaAT@eA4<hAT@f
=4Hh<3Da=T4d<S@f=SDh@T92@S<i@DI2=DDf<`e1>C=1=354<S<fA3I4<THg@SI6
=3A5=T8b>4E6AT4a@c94>4De<C4c<d52<cPi<CHe@DHf<S8i<d52=SH=ACDf<D8g
84i43BmHACDP83Pf8594838dAD=2A30e<dE2>3<a=C4i<DE6<3Ta<cDeACHc<CU4
<dHi<C4`=CHa@dDd@C92ASPfASLgA3La@S51<`di<dHeAC4dAD@f@cM3<d<g@c8b
>D4c=dI4AC<d=cQ2<d=2<T<a<3M6AS<g<T4e@c@c=S<h<S4b<3<f>D<=>C4b=cPf
=TA1>4DbAD<g<DDe<S<`AS@h<dA2=SPf<cQ6>496@D@c<C16ATHa@d52=34f<21>
A0d_F4Df820g<b1BA20b=4E3@T@`=C=5@SU6@d51<3La=CA6>D92<314>DDa@SA3
<4=4<T@f<34dA4Hd<d@i<d<`AS<a@dHd<S8=A492<3Pb<C8c@CL`<3Ph=dE6ADDa
ASHdADHe<T91>DA6<TA1ACLg@STeA4E1<T55@CLiA312=CTi=d=23D4aAD=3ASPf
<cU3>4<`<cU6ACE4=CE1=c<b84i43BmHACLP83P`8594838dAD=2A30e<dE2>3<a
=C4i<DE6<3Ta<cDeACHc<CU4<dHi<C4`=CHa@dDd@C92ASPfASLgA3La@S51<`di
<dHeAC4dAD@f@cM3<d<g@c8b>D4c=dI4AC<d=cQ2<d=2<T<a<3M6AS<g<T4e@c@c
=S<h<S4b<3<f>D<=AT@`A3@g>4=1>4=6>D@eASLc=cPiAT91=SP`AS@d=S0f>CA3
@cHi<b1>A0d_F4Dh820g<R1BA20b=4E3@T@`=C=5@SU6@d51<3La=CA6>D92<314
>DDa@SA3<4=4<T@f<34dA4Hd<d@i<d<`AS<a@dHd<S8=A492<3Pb<C8c@CL`<3Ph
=dE6ADDaASHdADHe<T91>DA4>D<e@cHe>C93>CPg=D8i@S13@d=6>3A1@dHd3C53
@S0`=STd@d@f>CHa<CQ5>4H`=dDc>21>A0d_F4Di820f=b1BA20b=4E3@T@`=C=5
@SU6@d51<3La=CA6>D92<314>DDa@SA3<4=4<T@f<34dA4Hd<d@i<d<`AS<a@dHd
<S8=A492<3Pb<C8c@CL`<3Ph=dE6ADDaASHdADHe<T91>DA6A34b>394=3LdASHi
@CHg>DI5=3@b<312@cLd3C4i<4@b<CDg<S@c@TI584i43BmHAD4P83@d8594838d
AD=2A30e<dE2=S=2<cDiADDd=30c<48i>44g<C16<C0g@T<f>44c=TDb<4E1=D93
<38gA3I3<S4g=@e6>3Pc=3LaAC@f=S8c<dA4<48fAS0h>3I1AT8b84i43BmHAD8P
83D`8594838dAD=2A30e<dE2=S=2<cDiADDd=30c<48i>44g<C16<C0g@T<f>44c
=TDb<4E1=C=4=T4a>CHf<3Pd>@db>C8aASLd=TE3=3Ha<D8h=4Hf<451A3Lh<THf
<CLc=SI3A3Dg<39684i43BmHAD<P83Da8594838dAD=2A30e<dE2=S=2<cDiADDd
=30c<48i>44g<C16<C0g@T<f>44c=TDb<4E1=CHg<STc=d8hAC0iAPe2A30dADDe
=S@d>C8f@c4c=48d>496>4DiASA1@SPbATDc=3@c=T=3@c<PCT@=;eQ5A20P=3DP
DT@P<SA5@d94<3DcAD8f<d8c=CU5AC@d<3<`@STh@CLa<4Ha<3M2@cHh@C<fAC8`
AD4e=T95>4<b=dH`>3913CD`>CI6<48b<S<g=3Da@CHhA3U5<dE2<D94@SQ6>21>
A0d_F4E5820a=C@PDT@P<SA5@d94<3DcAD8h<SU5=3@d@S0e>DHi=D4aA3@aATE3
<3E5@C8b@D4a>D@c=48e@C12<d<gAC8`<34b3D@b<D<g<D4h>D92AS8i<SLh>4<c
>38g=dHg<T4dAS55ASQ6=C0`<CE6=cDa<355AS96>D4h>4A4<354>@e5@D4i<DE1
<T95@SL`AS8h@CHbA3A5>34a<C<h<D=1=cTg@cH`=SQ4=cQ2<3Lc@CTf@C@eAD4d
=CLa<d8=A3A2=30d@T93@dE1@S8f=3@i=3DfAC<c<SU3=S4h<T95AC@fAC=2=c=6
=3=5<3U2<3Dc<D55AC@c@D@g3CE5=c<`=3Q6@C8a@S96<SLb<44a<SPi=3Hh=S<c
AS0`AS0d@S8h=SDc@CQ3>CU5AD8d>493=3Da@S12<@deADE5AD4`<R1>A0d_F4E6
820a=S0PDT@P<SA5@d94<3DcAD8h<SU5=3@d@S0e>DHi=D4aA3@aATE3<3E5@C8b
@D4a>D@c=48e@C12<d<gAC8`<34b3D@b<D<g<D4h>D92AS8i<SLh>4<c>38g=dHg
<T4dAS55ASQ6=C0`<CE6=cDa<355AS96>D4h>4A4<354>@e5@D4i<DE1<T95@SL`
AS8h@CHbA3A5>34a<C<h<D=1=cTg@cH`=SQ4=cQ2<3Lc@CTf@C@eAD4d=CLa<d8=
A3A2=30d@T93@dE1@S8f=3@i=3DfAC<c<SU3=S4h<T95AC@fAC=2=c=6=3=5<3U2
<3Dc<D55AC@c@D@g3CE5=c<`=3Q6@C8a@S96<SLb<44a<SPi=3Hh=S=2ACTh=3@f
@cTf>4H`<T55=CLc<SLa<C4b=C4b=3Pf=Pe4@dI5@S4a@cE4<c<`ADA6<T4f@B1>
A0d_F4H`820b<CTPDT@P<SA5@d94<3DcAD8hAS0fA3HiAS15@cE5=4Df@c96=S0d
<STcASE2@cLf<T4f<C@i=C8aATA3=c4`=T4f3DHg@C<aA3Ti<SU6>3I1<c4gAC16
A3<g=D@e@SPeA3@`<44d=CH`A353=30fAC0i>C=3=c4e<3Le<cHdAPe5@cA5=CU3
>C@c<CQ6@d55@cDf=S<i>48`=SPaADH`AT4e<T53>DDf@S93>CDi@c4d>C8d<CQ5
ATE1=34=AS12>44c=C12<4A4@c<cA3<g@c0a@SQ1@S8d@CDhAC11>C@i=cHg=S0g
ASHd>3PhAT8h@c52@D4h=dA23D@cA3Di>3PiAC=4=cU3=3<cA3D`ATDaAC91=S95
=CPcA44d=dI2ASPiASM6A4@`=cP`=C8b<cA2ACE1@@dd>3A6<3@a=dHbA3=3@d@i
ASLbA3<i<SM5A3@`>CI1=C0c=CU5ADA6@C95=4<g<CTb=dE5A3@hAS51=SP=@DH`
=c55ADI3<T4gAD@cAD4a>C11<SP`=c8g@dE6A3D`@SM1>48a=D=6AC4i@D8g<3Hg
A4@g=T<`=T=53C@f=S<g=cTh<48a=dA1<3M1>21>A0d_F4Ha820a=CDPDT@P<SA5
@d94<3DcAD8h<SU5=3@d@S0e>DHi=D4aA3@aATE3<3E5@C8b@D4a>D@c=48e@C12
<d<gAC8`<34b3D@b<D<g<D4h>D92AS8i<SLh>4<c>38g=dHg<T4dAS55ASQ6=C0`
<CE6=cDa<355AS96>D4h>4A4<354>@e5@D4i<DE1<T95@SL`AS8h@CHbA3A5>34a
<C<h<D=1=cTg@cH`=SQ4=cQ2<3Lc@CTf@C@eAD4d=CLa<d8=A3A2=30d@T93@dE1
@S8f=3@i=3DfAC<c<SU3=S4h<T95AC@fAC=2=c=6=3=5<3U2<3Dc<D55AC@c@D@g
3CE5=c<`=3Q6@C8a@S96<SLb<44a<SPi=3Hh=S<i@C8i@S=4=C92AT4i@S=5<4I3
=d8h=cTi>C0a=3A2<@dgA4I1<CPaAS4c84i43BmHAS8P834c=B1BA20b=4E3@T@`
=C=5@SPg=C=3@CA4=T<g>C8e<c8c=DE6=3<g<T@b<C11<DDcAC0h=SI4>4=2A3Tb
<3D`ASP=<TH`@S55=TA1<3Le=TE3>4H`<T4`>38i=3Ph@D@a=4I2=d4fAT4i=c@d
=d<e@S4a@d56=352<3Ld=S4d3D92=4I5<D91ATHh=SDc@D@d>30e@TD`@C8f@c55
@C12AT<`A34h=44iA4I5@cPeA4@g>D@gAD@b<30e=Pdi@S8e@d4bA3E4<SM3@DA6
=S4g=S15<cU4<DDd<D=3A44i=cTa>44e@SE1AC@g>CDe@S11@S8c<CM3>44=ACDf
<3Hf=cHa@d@h<TD`AS13@C8i<S91@SA4<T5584i43BmHAS<P834d<R1BA20b=4E3
@T@`=C=5@SPg=C=3@CA4=T<g>C8e<c8c=DE6=3<g<T@b<C11<DDcAC0h=SI4>4=2
A3Tb<3D`ASP=<TH`@S55=TA1<3Le=TE3>4H`<T4`>38i=3Ph@D@a=4I2=d4fAT4i
=c@d=d<e@S4a@d56=352<3Ld=S4d3D92=4I5<D91ATHh=SDc@D@d>30e@TD`@C8f
@c55@C12AT<`A34h=44iA4I5@cPeA4@g>D@gAD@b<30e=Pdi@S8e@d4bA3E4<SM3
@DA6=S4g=S15<cU4<DDd<D=3A44i=cTa>44e@SE1AC@g>CDe@S11<4Dd=SHiACL=
@C8b>CDd=S<d@dE5=T8cASE4@SU3>CU2A4I5@S8f<34h<DHh<48fASQ6A48PCT@=
;eQ6=20P<C<e8594838dAD=2A30e<dE2>3Le<d=1=4@f@cLi<SDc<S<eADHd<cLb
A38a<44aAC=5<3Pf=T@h@d94>C8`=C16>0dbAS12<DDfA44`=cDfAD<hAS0b@C0h
<STd>3Q1A34dAT8g@CI6@CTg=3@g@cE2<C53@DHd<D8`=c@f<C@=@T8dATDa@T56
ASPf=C=1A3@h<3E2AC11<SI3<DE1<496@c14<CPd@CU4ATE3>3E4A3LiA3M5A38`
<3Df3CU2<SE3@C94=D@b=d=1A4Hf<CLf<4Dc>D@aAC@a@d=4@CTg>C4h@CE2=D55
=3Li=CE2<3DeAS8`=S52=Pe4ADI6>4<b@S<fA452AS92@c0i<SM5=c0iATDe<c4P
CT@=;eQ6=B0P<SHPDT@P<SA5@d94<3DcAD8f@c8aACM4=T<d>D8a<3La>CI1ATE2
>3A3<d8a>C=3>CLg<313<CDa<b1>A0d_F4Hf820c>B1BA20b=4E3@T@`=C=5@SU3
@S8i=c93@S0i=D@f<315A4=1AC<f<cE5>30b=CQ2>4E1<S12<dHi<4E1=C8e<TD=
AS13<T8fACPg<48f=34h>4He84i43BmHASLP834`<21BA20b=4E3@T@`=C=5@SU3
@S8i=c93@S0i@THf=SA5=CE6=c@h=C0a@DDf@SQ6<c16<c4h>CU4A4He@C<`=3<=
=CE2ATHa@CA5=CA5A3Pi<D94<D94<cL`<3@d>C4d=DH`<T<`=CDa@c8aAS<b@STa
>3M2<D<h@dE2<CE63C=3@d96=SHf<S8g@SA6>48`A3Tg<4I2=CI5@C0i@SA4=dA1
=cTd=d94AS<`>4@b<C<b=D96=3U4>DE4=Pe4=CU6<S8f@dHi@d=6=3Ph<dHb@R1>
A0d_F4Hh820b=b1BA20b=4E3@T@`=C=5@SU3@S8i=c93@S0iA3E1=CD`<30h>3M2
=3@cA48i=S4c@T=3<C@i=4<e@T@PCT@=;eQ6>B0P>C4PDT@P<SA5@d94<3DcAD8i
@d8b>CLb@d8`>CQ3>3I6@C<b<494ASA3A451@T4b@dE4@T@h=T91AD8c=dHcAS0h
3C0f@T8bACPa<D<a=C14=T=6<cLd<C53=c52A4A6=C=6AD92=CPc<CT`<c<b=CE5
>3Tf=3Hb>3TcASHb@@dd@C8iA4De@SLc<392@SQ6@c8i=cM5A3Q1>4Hh<3TaA3A2
<3A3A4A5<DDiACPa<c8a=d4`ADHc<CTi=d4=@STPCT@=;eQ6@B0P<SDPDT@P<SA5
@d94<3DcAD8i@d8b>CLb@d8`>CHh>34i@C8eAS92=D54=THd=D@bASP`ASTd=c@P
CT@=;eQ6@R0P<C<b8594838dAD=2A30e<dE2>D=2<STg<T=2<3TeA3H`=S<d<D51
<48aASA2=S@h@S92<3Pi=c@e<cPa<cLb<C@a<0e5@cM6<CA4>3Dd=CPh>DHi=C4a
@cLb<C94A38dAD96A491<cA1ACM1=T<f=S56<DE6@T52=C0g>4@i>CP=<3<cA3Pf
<3@b=3U1>4@c@c93<d8h=c4eASPgAC8g<38h>CHg=CLg<cHd<S51<4A2>3Hb>C4i
@S<`=dHh3C4b<4@aATHc@cT`=S<d=T8d>D93=SPd<S@`<dH`A3H`AS<iA34`=d@g
@cU4@D=6>DI4>4Dc<T55@D@d@@db>C<d>CI6>C<i>CDg=C<c=DI2>CLgA34PCT@=
;eQ6@b0P>3PPDT@P<SA5@d94<3DcAD8i@d8b>CLb@d8`>C<hA38i=cLe<T<i<cA6
=SThAS<bAS4e>3I4@DA4=S53<4A4>C543C<`<SLgA30a<T=2AC13@cPe=STfAD94
<C0g<3Db=3=4<3E2=d95=c<i@T<h<T@hA4<d=S@f=C@e<cTi>@e1AC4i@S56A492
<SD`@cU4=3Tf=4=2AS95>30a@SI1<3I3@dHi@S8f=CI5ACTd@S<cASE3>C@dAR1>
A0d_F4I4820d=B1BA20b=4E3@T@`=C=5@SU3@S8i=c93@S0i=cLf>CA3=cDa>CA4
ATI4AT@h@CTa=T94ACM1AT=1<c@d<T95=dH=<dDh>3Q5@TI3<THi>C0d>38a=THe
AC<i=SLb=C=184i43BmHATDP83Pb8594838dAD=2A30e<dE2>D=2<STg<T=2<3Hg
=C<b=T<g=d4g@d52=cLeAT4f<DI6>CLf=dE1=C@d=cE6A451A0da<cHb=DE3=S4g
=dI4=SDi>3A3@D4b>@00X@300?]5=S<bAC55<S13<S0b@CQ4>34a>455<c12<3U6
<d8h>3=6<cE63C15@CA5<CPc<SDeAT@`>3Lb>DHiAS4h>3Tg=D4c=cTa<S=4<T4c
=ST`<CU384i43BmHATHP83<i8594838dAD=2A30e<dE2>D=2<STg<T=2<3TeA3H`
<3=6ACM5>D<a<c0a=TA2ACU3A4<c<S@f<S<`=c@h@DHd<`da>3<g@SDg<dHa>CHg
AT@h<CLPCT@=IFiT3FE^I0e`MG@=L7Ed3FAeL20_AVm^M4iQKFDPIfEd86EhHfPP
I6EVJFiUIVm^M21`Kg0=9BE5KVABIG=_MG9SIB0=3@00X@300I`_GemOATha82m7
IFiUMV4P;dMUKVEfHB1TMG0PIVU^I6I_KW@PI7E`82m3J65bDgAbJFiWLb1[KVmg
KR1kHVEWJFhP@fQQLU=dLVU^Ig<P;d5TJFEbIG=YLb1[KVmgKR1k;C4POG/]<GdP
JFIUK7=U86E^I7dPNg1_L20]<GdPJFIUK7=U879V3C0PJF@=<B1VI0d`83<`<R1d
LV5^LfaQM6D=<c0`82dc<30PLf=/J@dU9DE^I5=UM7E`80dU9D9UIfU^D65WIE=U
M7E`80e`K@dU9DE^I51QIfECIGAeL0d_A6EfJF=UDTM287=SL`d`830P<21V<`d`
;S4b=C0P<2ha<SD`87=`3B0`86aS3B0b86aZ3E@PLf4=9G1QIfDPLVESM3XP=STP
<c8P=3Pa83<c<b0=LgA]3C0P<20`86Hc3C4g;S<f<C0P<CL^<cHa<21cL0da<Bhe
86a]3B0`86aZ3Fi`3C4a=SH^=c8a<B0a=S@i;S8b=cDPKG@==C4`<bhg<3Pi834f
=3T^<S8g=B1/J@eTL`ebM6d=0:40`015LgA]3C0P<20`86Hc3Fi`3C4a=SH^=c8a
<B0b=CLe;S4d>3HPKG@==C4`<bhg<3Pi838e=cD^<C@h=R1/J@eTL`ebM6d=002Q
0<00AG=dK@d`830P<21V<`e^L0da<CHf;SLb<C4P<cD`<Bh`=STh86ed3CDa<3<^
=c0h>B0c=C0a;S0f>CPPK6T=I7<=LWA]3@00X@3004EcM6d=<20`830PIS<=KW0=
<C4f=Rhg<S4a83@d<SH^>CT`>B1]M0de<C0c;SL`>3TP=3@b=Rhi>C0i86aY3FAc
3G9dK@d00:40`00mLgA]3C0P<20`86Hc3Fi`3CHg;SPa=34P<CH`=Bhg<C<g86ed
3CHg;SPa=34P=34i<Rhe<3Ha86aY3FAc3@00X@3000=WL`d00:40`02^<20`830P
IS<=KW0=<C<e;SHb=CPP=30b>Bhb<cLb86ed3C4c=Bhf<SDh83@`<ST^<S<g<R0f
>2ha=cLf83<i>CP^<C0i>B0`;S0`<34P=30b>Bhi=cPb86=d3C4b;SH`=B0d<3Hi
;STi>B0f>2hi<c0e83@b<S<^=34a=b0f>2hi<c0e83@b<S<^=34a=b1SM0da<cD^
=S8e>20d<38i;S8c=c8PK6T=Hg0=I6D=0:40`003Ig8=002Q0<00179dK@d0X@30
02McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`01E
LgA]3C8`>2hc<c8c86IdL`d_GemOATha86=fLfH=<20`830PIS<=AR1cH@db=38^
=38d<b0d<CDg;SLh=34PKG@=:7@Y821cJ6mg3E@PLf4=LWA]3@00X@3000AbM6d=
0:40`09PLgA]3C4^834^834^86Hc3Fi`3C4f<c0^<c0f<R0a=S<c;S<a>38PKG@=
<CLb<bhf<S4g834f<c<^<c4h<R0a=cPf;S8h=34P<CDg>Bhb<30f834h<S4^<SLg
=20a=3Hh;S<h>3DPHg@=<CPe=Rhb=c0g834c=CL^=CLf<b0a>3T`;SP`=S<P<C<`
<bhg<CDb834i<SH^=C8h=R0a<c0d;S8d<38PHg@=<CTf<Rhb=C4P<C<`=2hg=SDc
834i>C<^=CPb<R0a<cDh;SPh<SPP<S0b<Rh`<C@c834d=ST^<CHi>B1SM0db<3D`
;S@d=S<P<CDg>Bhd=CLa838`>CP^=C4a<b0a=S<c;S<a>38P<S4f>2hd>CLi834f
<c<^<c4h<R1SM0eTI@d`830P<21V<`da=bhc=S4`834g;S<f<C0PLg0=KW0=<CHc
<2hc<3Hb834f<c<^<c4h<R1]M0da=c8c;SHb<CLP<CHc<bhc<CPb834g>3H^<SPd
<B0a=CLi;S8`<3HP<CPb<Bhb=cLd834d=SP^<cPh=B1SM0da>3Df;S8g<3LP<C<e
=bhe=cHc834h>C0^>30f<b0a<c0c;SLa=C8P<CTb=Rhe<SPf834c<3@^<S@`<R1S
M0da>CHb;S8e<B0a<c0d;SLf=C<P<CTi<bhe>38b834c=CP^>3Pb>20b<38b;S0a
=3<P<C@f>Bha=STi86=d3C8`=C0^=3@f<b0a=CLi;S@e=c4P<S0i>2he<C4c834f
<c<^<c4h<R0b<CHh;S@i=cTP<CHc<bhc<CPb86=d3FAc3G9dK@d0X@300TecM6d=
<BhP<BhP<BhPIS<=KW0=<SDe<2hd=30d838e=C<^=3Db=21]M0db=S@c;SLe=CTP
<SDe<bhd=C8d838g<3H^=34h<b0b=3Ti;S<c=3PP<SLd<Bhd<C4f838c>3P^=C8b
=b1SM0db=cLf;S@`=B0b<SLg;SLa<3DP<SPa<2hi=30e838b<S<^>3@i=20b>3@f
;SHf<SPP<S8b=2hc=c@d86=d3C8h>38^<cPe<R0b<S8d;SPi>CDP<STa<bhg<CHd
838b=cT^<34g<B0b>C@b;S4d>3DP<S<h>Bhc<3@b86=d3C8i=c0^=CP`=B0b=3Ti
;SDi<C<P<c0a>2hf=3De838e=C<^=3Db=20c<3Ph;SHc<S4P<SDe<bhd=C8d86=d
3FAU3C0P<20`86Hc3Fi`3C8e=C0^=3@`=20b=CDc;S@e<S@PKG@=<SHd<bhg=CDi
838e=C<^=3Db=20b=c0f;S@a>3<P<S@i>Bhc<c@h838g=34^=34a=R0b<cPh;SDb
<SLPHg@=<SLg=Rhd<3DP<S8g=bhg<C0e838h<C0^>C@`=B0b<S8c;SPd>C@P<SPd
=Rhf=S8h838b<S@^<cLd=21SM0db>3Pb;S<h=C8P<S8b=2hh>CTe838i<C<^=c4f
=20b<SLi;S0a=c4P<STd<Rha=3Pe838c>3T^<c0d<R1SM0db>CL`;SDh<3DP<S@i
>Bhe>C4c83<`<CP^=S@e=B0b=CDc;S@e<S@P<c0h>2hf<c8a838e=C<^=3Db=21S
M0eTL`ebM6d=002Q0<02Cg=dK@da;R0a;R0a;R1V<`e^L0dc=3L`;SDg=3HP<c@i
<2hi=3Lf86ed3C<e=S<^>3T`<B0c=3T`;STd=cHP<cHb=Rhe=C8f83<d<cH^>3<`
<B0c=SHa;SDd=CTP<c<b=Rh`<CLi86=d3C<f>CH^=C<i<R0c<S4e;S8`=CPP<cLc
<Bh`=c@g83<a=S4^<c@d=R0c=cHf;SLi=c4P<c4f<Bhh=STg86=d3C<h<38^=C4i
=20c<CHb;S<i=3LP<cPc<bhh=C0f83<b<CH^=C4b<b0c>3Hb;S8h<SLP<c<b=Rhg
>CTd86=d3C<h>C0^=c4d>20c=3<g;S0h=SDP<cTc>2hg=cTg83<d>C0^>C@g=R0d
<30h;SLf=S<P<c@i<2hi=3Lf86=d3FAU3C0P<20`86Hc3Fi`3C<d=c0^=CLd=R0c
=3T`;STd=cHPKG@=<cDf<bhh>C0a83<d>C0^>C@g=R0c=S8f;SDe<SHP<c@c=Rhh
<c0a83<f=S4^=C@e>B0c<c8f;S0a=cTPHg@=<cHi=Rhe<cTb83<b<CD^<S0e>20c
=c<a;S0g=3LP<c4f<Bhc=3@f83<g=SH^=cTg<B0c<CHa;SPf>CLPHg@=<cP`<Rhe
<CTd83<a=S8^<cTd=b0c>3<c;SPe<3HP<c8a=Rhe<C8c83<h=S8^<SPb=b0c<c8f
;SLi>C@PHg@=<cPi<2hg<C@h83<d<cL^<3Pf=B0c>C<h;SLg>CLP<c@i<2hi=3Lf
83@`<3P^=cHf<b0c=3T`;STd=cHPHg@=I7<=LWA]3@00X@300TUcM6d=<BhP<BhP
<BhPIS<=KW0==3<i<2hg<3Ph83@d<C4^<3Pa>B1]M0dd=3Pd;S0b=3<P=3@a<Bh`
>34i83@e=3H^=SPf>20d<cDf;STf=3<P=3Dh<Bhf>30a83@b=3H^<CDb<B1SM0dd
=S4f;SHg<c@P=34c=Bhc=20d=SDa;S8`>3TP=30h<Bhd=cPi83@f>3H^>C<a<b0d
<3Pb;S0`<cTPHg@==3Lb<Rhf=C<f83@`>38^=C8h>B0d=cDc;STh=3PP=34c=Rhf
=3He83@g>38^=34f>B0d<S@f;STc<cHPHg@==3Pa<2hh=3TP=3<e=bhb<S0g83@h
=CP^>C4c>B0d=34a;S0h<CTP=3Tb>2hi<30e83@d<C4^<3Pa>B1SM0eTI@d`830P
<21V<`e^L0dd<cT`;SL`>3PP=3@a<Bh`>34i86ed3C@d>3@^<38d<b0d=34a;S0h
<CTP=3Dd=Rhf>3Hh83@c=CH^>CHd<b0d=CPa;SHh<34P=38d=Rha=C8a86=d3C@f
<CH^=SLc=20d<C<e;S<d83@f=C4^<S0h>B0d<3Pa;S@g>3TP=3Hh=Rhi<c4c83@`
>38^<30c>B1SM0dd=c8b;SHe<cHP=30h<Rhe<SPi83@g=C<^>CPd>20d<C<f;SHd
=SDP=3Lh<Rhd<CHi83@b=3H^>C<c=R1SM0dd>34`;SPd>B0d<cDg;S8b<3LP=3Pe
>2hi<C<i83@d<C4^<3Pa>B0d>C8h;ST`<3DP=3@a<Bh`>34i86=d3FAc3G9dK@d0
0:40`011LgA]3C0P<20`86Hc3Fi`3C4i<SD^<S8P<CHc>Bhh=cLPKG@==C4`>Bhb
=c8P=3Pb<bhi<STa86aY3FAc3G9dK@d00:40`015LgA]3C0P<20`86Hc3Fi`3C4a
=CL^<SHa=B0b=38e;S<g=3HPKG@=<CTb=Rhc<3Df834f=CH^<c<`=B1/J@eTL`eb
M6d=002Q0<00@g=dK@d`830P<21V<`e^L0db>30b;S4h=38P<SDf>2he<C@PKG@=
=C4`=Bhh<cLb83@h=c8^<CHg86aY3FAc3G9dK@d00:40`014LgA]3C0P<20`86Hc
3Fi`3C4a=ST^<C@`>20d<S0h;S8f>CDPKG@=<SP`<Bha>3DP<SDg=Rhb<SDb86aY
3FAc3G9dK@d0X@3004EcM6d=<20`830PIS<=KW0=<cHh=bhe<C@c83<e<3H^<30i
<b1]M0de<C0c;SP`>3HP=3Tb<Rhc<3<e86aY3FAc3G9dK@d00:40`015LgA]3C0P
<20`86Hc3Fi`3C4i=cH^<S8c<b0e<S0f;SLh>38PKG@=<cHg=bhh=S@b83<e<3D^
<C@g<R1/J@eTL`ebM6d=002Q0<00@g=dK@d`830P<21V<`e^L0dd=CDe;SHb83@d
<SH^<SP`<R1]M0de<C0e;S@c=3<P=3Tg=Rh`>C@e86aY3FAc3G9dK@d00:40`015
LgA]3C0P<20`86Hc3Fi`3C<g>3L^=3Df=B0e<S4a;SPa>3PPKG@==3De=Rhe<30f
83@d=38^=cLd=b1/J@eTL`ebM6d=002Q0<00@G=dK@d`830P<21V<`e^L0da<CPd
;S0h<S4P>34e;SPi>3@PKG@==C4b<Bh`=b0h<CD^>3Th=21/J@eTL`ebM6d=002Q
0<02:G=dK@da;R0a;R0a;R1V<`e^L0da=S@g;SHf=c8P=cTi;STi=3@PKG@=<CLd
<2hi>38g83Li>Bhi>C@d834h<3<^=S@e<B0f=ST^>3Th>20a>3<h;SHc>3DP=30c
;SDa<SLPHg@=<CPg<bhf<c4h834c=bha<SHe834i<3P^<CHg<b0g;SHd=c4P<CTd
<bhh>3Tg83P^>C0h=R1SM0da>CLi;SHa<R0a<2ha=c0a838`<C0^>C@c<R0a=30^
<SHe=20b<3<i;S<g=C<P=30e;S<i<34PHg@=<S0f=bhh<3Lc83Hg<2he<C@i838a
<CD^>3Lb<b0g>CT^>CTd=20b<CPe;SPe>3TP=cTi;STi=3@PHg@=I6D=<20`830P
IS<=KW0=<CHd=bhf=SLb83Li>Bhi>C@d86ed3C4g=30^>CPb=b0g>CT^>CTd=20a
>30c;SHd=C4P=SHi;SPi>3PP<CPc>2hf<cPe83@`<bhe<C8g86=d3C4h=c<^=S<a
>20a<cL^<C8f=B0a>C0h;S4f=c<P=bhf=3La834i=3<^>3Pi=b0h;ST`>3HPHg@=
<CTg>Bhf<C8P<C0^<CL`<B0b<34`;STd<c8P<C@`;S8f=C@P<S0c>Bhc=cDc83@`
=Bhc>C0a86=d3C8`=SL^>30g<b0f=c0^=C4d>B0b<C4e;SPg<S<P=cTi;STi=3@P
<S4h=Bhh=CPi83Li>Bhi>C@d86=d3FAc3G9dK@d00:40`08YLgA]3C4^834^834^
86Hc3Fi`3C8e=C0^=3@`=20g>CT^>CTd=21]M0db=S@c;SLe=CTP=cTi;STi=3@P
<SL`=Rhd<CPc83Hf>Bhh>CPh838g=34^=34a=R0d<3<^=C4b=b1SM0db=cLf;S@`
=B0a<cL^<C8f=B0b>34`;STd<3DP=bhf=3La838h=3H^=SHb>20h;ST`>3HPHg@=
<SPh<Rhc>3Db834`;S4g<34P<STa<bhg<CHd834d<2hb=SDd838i=38^<C@h=B0d
<3D^<cT`<B1SM0db>CL`;SDh<3DP=SL`;SDa=3TP<c0a>2hf=3De83Li>Bhi>C@d
83<`>3P^=S<b<B0g>CT^>CTd=21SM0eTI@d`830P<21V<`e^L0db=CD`;S@d<3@P
=cTi;STi=3@PKG@=<SHd<bhg=CDi83Li>Bhi>C@d838g<3H^=34h<b0f=ST^>3Th
>20b=c@a;S@a<CHP=30c;SDa<SLPHg@=<SLg=Rhd<3DP<C<g;S4b=SDP<SPa<2hi
=30e83L^=S@g<B0b>3@f;SHf<SPP>2hi<3Pf86=d3C8h>38^<cPe<R0a<2ha=c0a
838i<C<^=c4f=20a=30^<SHe=20b>C@b;S4d>3DP=30e;S<i<34PHg@=<STg<2he
>30e83Hg<2he<C@i83<`<CP^=S@e=B0g>CT^>CTd=20c<3Ph;SHc<S4P=cTi;STi
=3@PHg@=I7<=LWA]3@00X@300R]cM6d=<BhP<BhP<BhPIS<=KW0=<c@g<2he=c@f
83Li>Bhi>C@d86ed3C<e=S<^>3T`<B0g>CT^>CTd=20c=S8f;SDe<SHP=SHi;SPi
>3PP<cHf<Bhe=3Di83@`<bhe<C8g86=d3C<f>CH^=C<i<R0a<cL^<C8f=B0c=c<a
;S0g=3LP=bhf=3La83<g=SH^=cTg<B0h;ST`>3HPHg@=<cP`<Rhe<CTd834`;S4g
<34P<cPc<bhh=C0f834d<2hb=SDd83<h=S8^<SPb=b0d<3D^<cT`<B1SM0dc>3T`
;SLa=3PP=SL`;SDa=3TP<cTc>2hg=cTg83Li>Bhi>C@d83@`<3P^=cHf<b0g>CT^
>CTd=21SM0eTI@d`830P<21V<`e^L0dc=3L`;SDg=3HP=cTi;STi=3@PKG@=<cDf
<bhh>C0a83Li>Bhi>C@d83<f<SH^=CDb=R0f=ST^>3Th>20c=SHa;SDd=CTP=30c
;SDa<SLPHg@=<cHi=Rhe<cTb834c=bha<SHe83<g<c4^<3Ld=b0g;SHd=c4P<cLf
=Rhg>CLa83P^>C0h=R1SM0dc>30b;SDa>C@P<C0^<CL`<B0c>3<c;SPe<3HP<C@`
;S8f=C@P<cPf<Rhb>38g83@`=Bhc>C0a86=d3C<h>C0^=c4d>20f=c0^=C4d>B0c
>C<h;SLg>CLP=cTi;STi=3@P=30`>2hg=SHc83Li>Bhi>C@d86=d3FAc3G9dK@d0
0:40`08YLgA]3C4^834^834^86Hc3Fi`3C@c>C0^=c0h>20g>CT^>CTd=21]M0dd
=3Pd;S0b=3<P=cTi;STi=3@P=3Dd=Rhf>3Hh83Hf>Bhh>CPh83@e>34^=SP`<B0d
<3<^=C4b=b1SM0dd=S4f;SHg<c@P<C<g;S4b=SDP=3He<Bhb<3Pi83L^=S@g<B0d
=SPf;STc<C<P>2hi<3Pf86=d3C@g<S8^=SDc=R0a<2ha=c0a83@g=C<^>CPd>20a
=30^<SHe=20d=cPb;S@a=STP=30e;S<i<34PHg@==3Pa<2hh=3TP=SL`;SDa=3TP
=3Pe>2hi<C<i83Li>Bhi>C@d83@i<SP^>C0`=B0g>CT^>CTd=21SM0eTI@d`830P
<21V<`e^L0dd<cT`;SL`>3PP=cTi;STi=3@PKG@==3@h=2h`<S@c83Li>Bhi>C@d
83@e=3H^=SPf>20f=ST^>3Th>20d=CPa;SHh<34P=30c;SDa<SLPHg@==3Ha=Rhf
=c<d834c=bha<SHe83@f=C4^<S0h>B0g;SHd=c4P=3Hh=Rhi<c4c83P^>C0h=R1S
M0dd=c8b;SHe<cHP<C0^<CL`<B0d=cDc;STh=3PP<C@`;S8f=C@P=3Lh<Rhd<CHi
83@`=Bhc>C0a86=d3C@h<C0^>3@i83Hg<2he<C@i83@h=CP^>C4c>B0g>CT^>CTd
=20d>C8h;ST`<3DP=cTi;STi=3@PHg@=I7<=LWA]3@00X@30041cM6d=<20`830P
IS<=KW0=<S4`=Rhe=S4P<CTe<Bhd=SDh86ed3C8d<CT^<3Di=20b<SPa;S<b=C8P
K6T=I7<=0:40`003Ig<=002Q0<00_S0P<20`86Hc3Fi`3C8c=CH^<3<c=20b<C4f
;S4g>C@PKG@=<S<e=Rh`<c<d838a<CH^<CLi=20b<SPe;SHf<CDP<S4c>Bhi=STg
838b=CP^<3Pe<B0b<S0i;STi<cDPHg@=<S8i=2hg=CTi838b<c0^<cLg>20b=3@a
;S4e>3TP<S<`<bh`<C0e838d=34^<CDh>B0b<c0c;S0a<3DPHg@=<S<e=Rh`<c<d
838a<CH^<CLi=21/J@eSL0eTI@d0X@3000=WLPd00:40`004LWA]3@2Q0<00@G=d
K@d`830P<21V<`e^L0da=c@a;STg>CDP<CTf>2hh<SHh86ed3C4d<ST^=3Pa<B0b
<STh;SHh=S8PK6T=I7<=002Q0<000fMc3@00X@300;h`830P<21V<`e^L0da=3Tb
;SD`=c8P<S4c<bhe=30d86ed3C4d>C8^=C0g<R0b<C<c;SDd<3@P<CDf<Rhh=cTa
838a=CL^<c<`=b0a=CT`;S@e=CDP<S8b=bhc=C@f86=d3C4e=C<^=cP`=b0b<S@g
;SLc>3TP<C@`=bhc>34g838c<S0^<cLa=B0a=30g;S<h<CLP<S<b<2hc=c4e86=d
3C4d>C8^=C0g<R0b<C<c;SDd<3@PK6T=Hg0=I6D=0:40`003Ig8=002Q0<00179d
K@d0X@30041cM6d=<20`830PIS<=KW0=<STg=2hf<C8b838i<3H^<c8b86ed3C<b
>3L^<C4`=R0c<S<f;S4h<CDPK6T=I7<=0:40`003Ig<=002Q0<00^30P<20`86Hc
3Fi`3C<b<S@^<3Pd=R0c<3La;S0c=CHPKG@=<c8b=2h`>3@f83<`=c4^<3<e=R0c
<CDc;SLa<SHP<c0i=2hh<SHP<c4b=Rha<cHc83<a=S@^>3@i>21SM0dc<CHb;SPa
<B0c<CPe;S8c=34P<c<`>Bhb<B0c<SDg;SPf=SPP<c<`>Bhb<B0c<SDg;SPf=SPP
Hg@=<c8b=2h`>3@f83<`=c4^<3<e=R1/J@eSL0eTI@d0X@3000=WLPd00:40`004
LWA]3@2Q0<00@7=dK@d`830P<21V<`e^L0db=S4`;S0c<3LP<STb<bhf>3<PKG@=
<S8i=bhe<c8c83<b=C<^=C@b=B1/J@eTL`d0X@3000=WL`d00:40`02m<20`830P
IS<=KW0=<S<f<2he=CPc83<`>3P^<cTf=R1]M0db<cH`;SDe>3<P<c0h>2hc>CHf
838d<c0^>C<`<b0c<C4b;S4h=b0b=3Dh;SD`=SHP<c4h<Rhb<C0h86=d3C8d<S4^
>3<a>B0c<S0b;SDi=C4P<S8g=Bhd<c8i83<b=cD^<S8g>20b<SLe;S@c<STP<c8g
=Bhb<SLh86=d3C8c=S0^=CDh<b0c<3Ph;S<i=SHPK6T=Hg0=I6D=002Q0<000fMb
3@00X@3000AbM6d=0:40`011LgA]3C0P<20`86Hc3Fi`3C<h=S0^<38d<b0c>3@c
;SPa=c<PKG@==34g<Rhe<S8h83@a=c<^=SLf=b1/J@eTL`d00:40`003Ig<=002Q
0<00^c0P<20`86Hc3Fi`3C@a<3T^=3Tf=b0d<30h;SDc<3TPKG@==34`>Bhd>CHg
83@`<3P^=C<`>B0d<3<i;S4b=3PP=30c<Rhc<S4b83@`<C4^=C@h=20d<C0b;S<d
=B1SM0dd<3@h;S8b<c8P=34b<Rhg<STc83@a>C@^=S8b<R0d<CTe;S<f<R0d<CTd
;SHb<S8P=34i=Bhc=S8PHg@==34`>Bhd>CHg83@`<3P^=C<`>B1/J@eSL0eTI@d0
0:40`003Ig8=002Q0<00179dK@d0X@30045cM6d=<20`830PIS<=KW0=<c@i=Bhd
=38i83<h=S4^<CLh<b1]M0dc<CPb;STd=3DP=34i<Bh`<cLg86aY3FAc3@00X@30
00=WL`d00:40`02i<20`830PIS<=KW0=<c8d=Bhi=c0e83@`<SD^>3Ta>B1]M0dc
<S@e;STg<3DP=30b=Bhh>C4i83<c<CH^<c@b=20d<3@i;SHh<S8P<c<d<bhi<CPh
83@a<CT^=c0f<B1SM0dc<c0g;S8d=20d<C@`;S0i<3@P<c4f<2hh=3DP=38a<Rhg
<S<P<c4f<2hh=3DP=38a<Rhg<S<PHg@=<c8d=Bhi=c0e83@`<SD^>3Ta>B1/J@eS
L0eTI@d00:40`003Ig8=002Q0<00179dK@d0X@30045cM6d=<20`830PIS<=KW0=
=3Lb>2h`=cDe83@g>34^<c4b=B1]M0de<3@`;SDg<cTP=C4a<Bha=c4i86aY3FAc
3@00X@3000=WL`d00:40`02n<20`830PIS<=KW0==3Tg=bhe=3Li83@i=3H^<38f
<B1]M0dd>CLg;SDd=cTP=3Td=Rh`<SHa83@i<3L^<CLe>B0d>CHi;SPa=SDP=3Pg
>Bhe>CTf83D`<cT^>3@`<b1SM0dd>C4f;S8g=3<P=C0f<2hb<S@f83D`=S8^=SLc
<b0e<C<b;SPe=c<P=C0f<Rhf=c<c83Da<c8^>3Dg<b1SM0dd>CLg;SDd=cTP=3Td
=Rh`<SHa86aY3F=`3FAU3@2Q0<000fMb3@00X@3000AbM6d=0:40`00oLgA]3C0P
<20`86Hc3Fi`3C@c=S<^=3Td83@g>CP^=SLc=B1]M0dd<3D`;STi=CHP=C4b>2he
<c<PK6T=I7<=002Q0<000fMc3@00X@300;h`830P<21V<`e^L0dd<C4d;S0b<CHP
=3Tf<bhc>3La86ed3C@a<C@^<38a=R0d>CHc;S<h=c4P=34h=2hc>C<f83@i>3L^
<CLg=B0d<S4a;STf>CTP=C0e=bhb<34c86=d3C@a=cD^<STe<R0e<3Lg;SDh=CHP
=30b>2hh>CHb83Da=C0^<S4h<b0d<38h;SPi=S8P=C4e<2hb<CPc86=d3C@a<C@^
<38a=R0d>CHc;S<h=c4PK6T=Hg0=I6D=0:40`003Ig8=002Q0<00179dK@d0X@30
02McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d00:40`00k
LgA]3C0P<20`86Hc3DHPLf4=<SP`<Rh`<38P<C4a>2ha<cHg86ed3BQd:B0PLfQ_
M`eD87=Q3G9dK@d00:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`;S4b=C0P
<2ha<SD`87=`3C0P<20`86Hc3@00X@3003acM6d=<20`830PIS<=AR1cH@db>C8c
;SDb>C4P<C8b<Rhc<38h86ed3BQY:B0PLfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=
0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830PIS<=002Q
0<00?7=dK@d`830P<21V<`e687=Q3C<f>3L^=34d<B0a<C4h;S4c=SLPKG@=:7@Y
821cJ6mg3E@PLf4=LWA]3@2Q0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha
<SD`830^<C8e<21cL0d`830P<21V<`d00:40`01@LgA]3C0P<20`86Hc3DHPLf4=
<cP`=bhi=34c834b<S8^<c0b>21]M0dXJB/a:B1K=3P^>C<P<C<h;SPe830PGB1h
LfQ_M`eD87=Q3G9dK@d0X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e
<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00>g=dK@d`830P<21V<`e687=Q3CLa
>2hf=cTb838f=3D^>C0f=b1]M0dXM2TP87=XKgL=E21cH@ebM6d=002Q0<00179d
K@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21cL0d`830P<21V<`d0
0:40`00kLgA]3C0P<20`86Hc3DHPLf4=>3@`;S8`=S@P<SLe<2h`=c8h86ed3BQY
:B0PLfQ_M`eD87=Q3G9dK@d00:40`004LWA]3@2Q0<009g=dK@d`830P<21V<`d`
;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@3003]cM6d=<20`830PIS<=AR1c
H@dg<cH^<3@`<R0c=C4c;STe=cPPKG@=:7@Y821cJ6mg3E@PLf4=LWA]3@00X@30
00AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=<20`830P
IS<=002Q0<00CW=dK@d`830P<21V<`e687=Q3CPe=Rhe=SLd83<f<CP^<C8d86ed
3BQY:c4Y85/d>2hi<b0a<cP^>3DP<21M87QcJ6mg3E@PLf4=LWA]3@2Q0<00179d
K@d0X@3000AcM6d=0:40`003Ig<=002Q0<04B6Qc3C8h=3@^=30d=B0a<S<i;SHf
<cPPKG@=<SPf<Bhg=SDe834b<cT^=SHc>21/J@db>3Ha;SLf=CDP<SD`=bh`<CPe
86aY3C8h=3@^=30d=B0b=C0g;S0a>3DPK6T=<SPd=2hd<3@e834b<cT^=SHc>21/
J@eSL0dP<B1XH`d`830P<21V<`da=bhc=S4`834g;S<f<C0PLg0=838PK6X=KW0=
<SPf<Bhg=SDe834`>C@^<c0c=b1]M0db>3@d;S@`=3DP<C0i=2hc<3<g86aY3FAc
3Fi`3C8h=S4^=cHe=B0a<CPa;S4`>3PPKG@=<SPd=2hd<3@e834a>34^<C0h>21/
J@eTL`e^L0db>3Ha;SLf=CDP<C8f=bhi<C<i86ed3C8h=3@^=30d=B0a<SHg;STa
<cTPK6T=I7<=KW0=<SPf<Bhg=SDe834c=C@^=c4i86ed3C8h=3@^=30d=B0a<cDd
;SLa>B1/J@eTL`e^L0db>3Ha;SLf=CDP<C@d<Bhe<S@a86ed3C8h=3@^=30d=B0a
=3@a;SDb=34PK6T=I7<=KW0=<SPf<Bhg=SDe834e<SP^<c8i<R1]M0db>3@d;S@`
=3DP<CDb>2hc<STb86aY3FAc3Fi`3C8h=S4^=cHe=B0a=S4e;S4c=3@PKG@=<SPd
=2hd<3@e834f<CD^<C<d=21/J@eTL`e^L0db>3Ha;SLf=CDP<CL`<Bhi<cTe86ed
3C8h=3@^=30d=B0a=c0a;STc>CDPK6T=I7<=KW0=<SPf<Bhg=SDe834g>3P^=c@d
=R1]M0db>3@d;S@`=3DP<CLh>2hg=3@f86aY3FAc3Fi`3C8h=S4^=cHe=B0a>3Le
;SDd>CLPKG@=<SPd=2hd<3@e834h=cD^=C@i=b1/J@eTL`e^L0db>3Ha;SLf=CDP
<CTf<Rhc=C@h86ed3C8h=3@^=30d=B0a>CHb;S<e=3PPK6T=I7<=KW0=<SPf<Bhg
=SDe838`=3T^<CDi>B1]M0db>3@d;S@`=3DP<S0d>Bha=CTi86aY3FAc3Fi`3C8h
=S4^=cHe=B0b<C<e;STf=B1]M0db>3@d;S@`=3DP<S4c=Bhi=SDPK6T=I7<=KW0=
<SPf<Bhg=SDe838b<S8^=cL`<R1]M0db>3@d;S@`=3DP<S8b<Rhg=c0b86aY3FAc
3Fi`3C8h=S4^=cHe=B0b<c0i;SDg=C<PKG@=<SPd=2hd<3@e838c<3T^=CLe<b1/
J@eTL`e^L0db>3Ha;SLf=CDP<S<i=Rhc>30d86ed3C8h=3@^=30d=B0b<cTf;S<h
<3@PK6T=I7<=KW0=<SPf<Bhg=SDe838d>3<^<CPe=B1]M0db>3@d;S@`=3DP<S@h
<bha>3De86aY3FAc3Fi`3C8h=S4^=cHe=B0b=CHi;STi<3HPKG@=<SPd=2hd<3@e
838e=ST^>CT`=R1/J@eTL`eXI@d0X@3000=WLPd00:40`004LWA]3@2Q0<0017=d
K@d0X@3000=WL`d00:40`0J2J7<=<cLf=2he<cPg834b=CL^<38d>21]M0dc=cPa
;SPi>CLP<C8e=bh`<S@h86aY3C<g>34^>3Ti=b0c=3@d;SDa<cLPK6T=<cLf=2he
<cPg83<d=3@^=C4c=b1/J@dc=cHd;SDc>3LP<C8e=bh`<S@h86aY3F=`3B0a86QS
3C0P<20`86Hc3C4g;S<f<C0P<CL^<cHa<21cL0dP<R1/JPe^L0dc=cPa;SPi>CLP
<C0i=2hc<3<g86ed3C<g=S@^=C<h=b0a<3Td;S<`<cLPK6T=I7<=KW0=<cLh<Bhh
>CTg834a>34^<C0h>21]M0dc=cHd;SDc>3LP<C4h<Bha<3Ph86aY3FAc3Fi`3C<g
>34^>3Ti=b0a<SHg;STa<cTPKG@=<cLf=2he<cPg834b=SL^>C4c>B1/J@eTL`e^
L0dc=cPa;SPi>CLP<C<e=2hg<CTPKG@=<cLf=2he<cPg834c=C@^=c4i86aY3FAc
3Fi`3C<g>34^>3Ti=b0a=3@a;SDb=34PKG@=<cLf=2he<cPg834d=34^=C8d<B1/
J@eTL`e^L0dc=cPa;SPi>CLP<CDb>2hc<STb86ed3C<g=S@^=C<h=b0a=C8h;S<b
>C8PK6T=I7<=KW0=<cLh<Bhh>CTg834f<CD^<C<d=21]M0dc=cHd;SDc>3LP<CHa
=Bha<c@d86aY3FAc3Fi`3C<g>34^>3Ti=b0a=c0a;STc>CDPKG@=<cLf=2he<cPg
834g<34^>C<i=B1/J@eTL`e^L0dc=cPa;SPi>CLP<CLh>2hg=3@f86ed3C<g=S@^
=C<h=b0a=cPh;SLd=3HPK6T=I7<=KW0=<cLh<Bhh>CTg834h=cD^=C@i=b1]M0dc
=cHd;SDc>3LP<CPg=Bhe=3Tg86aY3FAc3Fi`3C<g>34^>3Ti=b0a>CHb;S<e=3PP
KG@=<cLf=2he<cPg834i=S8^<cDd>21/J@eTL`e^L0dc=cPa;SPi>CLP<S0d>Bha
=CTi86ed3C<g=S@^=C<h=b0b<3@i;S4e>CTPK6T=I7<=KW0=<cLh<Bhh>CTg838a
<cD^>CHe86ed3C<g=S@^=C<h=b0b<C<e;STf=B1/J@eTL`e^L0dc=cPa;SPi>CLP
<S8b<Rhg=c0b86ed3C<g=S@^=C<h=b0b<S8b;SLg<38PK6T=I7<=KW0=<cLh<Bhh
>CTg838c<3T^=CLe<b1]M0dc=cHd;SDc>3LP<S<`>Bhe=cDc86aY3FAc3Fi`3C<g
>34^>3Ti=b0b<cTf;S<h<3@PKG@=<cLf=2he<cPg838c>CH^<cP`=21/J@eTL`e^
L0dc=cPa;SPi>CLP<S@h<bha>3De86ed3C<g=S@^=C<h=b0b=3Pc;S4h=CDPK6T=
I7<=KW0=<cLh<Bhh>CTg838e=ST^>CT`=R1]M0dc=cHd;SDc>3LP<SDf>Bhi>C0f
86aY3FAc3Fi`3C<g>34^>3Ti=b0b=SDf;SLi=CLPKG@=<cLf=2he<cPg838f=CH^
=cTe=b1/J@eTL`e^L0dc=cPa;SPi>CLP<SLd<bhf<30h86ed3C<g=S@^=C<h=b0b
=c@c;SH`<3PPK6T=I7<=KW0=<cLh<Bhh>CTg838h<c0^=30f86ed3C<g=S@^=C<h
=b0b>3<`;S@`=R1/J@eTL`e^L0dc=cPa;SPi>CLP<STa=bhb<C4a86ed3C<g=S@^
=C<h=b0b>C4g;S8a<C4PK6T=I7<=KW0=<cLh<Bhh>CTg83<`<3@^<34f<R1]M0dc
=cHd;SDc>3LP<c0`=2h`<CHb86aY3FAc3Fi`3C<g>34^>3Ti=b0c<3T`;SPb<C<P
KG@=<cLf=2he<cPg83<`>C0^>38a<b1/J@eTL`e^L0dc=cPa;SPi>CLP<c4g=bhf
<SHd86ed3C<g=S@^=C<h=b0c<CLg;SHb=S@PK6T=I7<=KW0=<cLh<Bhh>CTg83<b
=S@^=3<a=B1]M0dc=cHd;SDc>3LP<c8f=2hd<c4e86aY3FAc3Fi`3C<g>34^>3Ti
=b0c<cDa;S8c=SLPKG@=<cLf=2he<cPg83<c=C4^<S<f=b1/J@eTL`e^L0dc=cPa
;SPi>CLP<c@c>2h`=34h86ed3C<g=S@^=C<h=b0c=3<h;S0d<CPPK6T=I7<=KW0=
<cLh<Bhh>CTg83<e<S@^>3@f>B1]M0dc=cHd;SDc>3LP<cDb=2hh=3Hi86aY3FAc
3FQU3@2Q0<000fMb3@00X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e
<20`;S4b=C0PLg0=<20`830PIS<=002Q0<00MW=dK@d`830P<21V<`e687=Q3C4b
<Rhd=S4e83D`<c@^=cLf=21]M0dXKVEQLR1UKV@Y85/a<S4^=CHP<C4i;STc834a
=Bhb=B0h<2hd=R0f>Bhd>20a<CT^>C<P<C8a;SDf830PGB1hLfQ_M`eD87=Q3G9d
K@d0X@3000AbM6d=0:40`00WLgA]3C0P<20`86Hc3C0^<C8e<20`;S4b=C0PLg0=
<20`830PIS<=002Q0<00KW=dK@d`830P<21V<`e687=Q3CDc<C<^=30g<b0e<3<d
;SLg=S@PKG@=:6IQLR1UKV@Y85/h<Bhb>20a<CD^<SDP>30^=3HP=ST^=3PP<C4i
;STc834b<Bhe=R0`85dPN7=XKgL=E21cH@ebM6d=0:40`004LWA]3@2Q0<009g=d
K@d`830P<21V<`d`;S4b=C0P<2ha<SD`87=`3C0P<20`86Hc3@00X@300<QcM6d=
<20`830PIS<=AR1cH@de<SHa;S<b=3<P>3Hh;S4c<3TPKG@=:71eK7=U86=QLW9i
JFiW87MYLVDY85/a<SD^=3<P<C8a;SDf83@h;STc834`=Rha<20a<CT^>C<P=ST^
=3PP<C4c;SHc834a=Bhb=B0h<2hd=R0h<2hd=R0a<CT^<C8P=3P^>C<P<C8a;SDf
834b=bh`=B0f>Bhd>20a=S8^=CHP=3P^>C<P>30^=3HP<21M87QcJ6mg3E@PLf4=
LWA]3@2Q0<00179dK@d0X@3002McM6d=<20`830PIS<=<2ha<SD`830^<C8e<21c
L0d`830P<21V<`d00:40`02LLgA]3C0P<20`86Hc3DHPLf4==C8f<Bhc<S@c83<`
=c8^>CP`>21]M0dXHFAZHF=UKW@PMfUbIBTPFc4a=Bhb=B0a<SD^=3<P=CL^=CPP
<C4e;S8e834a<bhf<b0a<CT^>C<P<C8a;SDf83Tb;S<g83Hi;S@h834f<Rhe=R0d
>2hi<b0h<2hd=R0`85dPN7=XKgL=E21cH@ebM6d=0:40`004LWA]3@2Q0<0017=d
K@d0X@3000=WL`d00:40`092J7<=<CTb=2hb=c0c834b<3@^>C@a>21]M0da>C@a
;SHc<C<P<C8`=2hi=34h86aY3C4i=34^=S<a<b0a=S@i;S<g=STPK6T=<CTb=2hb
=c0c834f=3T^<cLf>B1/J@da>C8d;S8g<3<P<C8`=2hi=34h86aY3F=`3B0a86QS
3C0P<20`86Hc3C4g;S<f<C0P<CL^<cHa<21cL0dP<R1/JPe^L0da>C@a;SHc<C<P
<C0i=2hc<3<g86ed3C4i<S@^<SL`<b0a<3Td;S<`<cLPK6T=I7<=KW0=<CTd<Bhf
<c4c834a>34^<C0h>21]M0da>C8d;S8g<3<P<C4h<Bha<3Ph86aY3FAc3Fi`3C4i
=34^=S<a<b0a<SHg;STa<cTPKG@=<CTb=2hb=c0c834b=SL^>C4c>B1/J@eTL`e^
L0da>C@a;SHc<C<P<C<e=2hg<CTPKG@=<CTb=2hb=c0c834c=C@^=c4i86aY3FAc
3Fi`3C4i=34^=S<a<b0a=3@a;SDb=34PKG@=<CTb=2hb=c0c834d=34^=C8d<B1/
J@eTL`e^L0da>C@a;SHc<C<P<CDb>2hc<STb86ed3C4i<S@^<SL`<b0a=C8h;S<b
>C8PK6T=I7<=KW0=<CTd<Bhf<c4c834f<CD^<C<d=21]M0da>C8d;S8g<3<P<CHa
=Bha<c@d86aY3FAc3Fi`3C4i=34^=S<a<b0a=c0a;STc>CDPKG@=<CTb=2hb=c0c
834g<34^>C<i=B1/J@eTL`eXI@d0X@3000=WLPd00:40`004LWA]3@2Q0<0017=d
K@d0X@3000=WL`d00:40`0QMJ7<==3Hh=2hf=c8i834b<S8^<c0b>21]M0dd=c0b
;S0c=20a<S8b;S<`<SPPK6T==3L`<Rh`<c@P=3<i<Rhd<CPe86aY3C@f>3@^=SLb
>B0d<cTb;S@a>3DPK6T==3Hh=2hf=c8i834b<S8^<c0b>21/J@eSL0dP<B1XH`d`
830P<21V<`da=bhc=S4`834g;S<f<C0PLg0=838PK6X=KW0==3L`<Rh`<c@P<C0i
=2hc<3<g86ed3C@f>3@^=SLb>B0a<3Td;S<`<cLPK6T=I7<=KW0==3L`<Rh`<c@P
<C4h<Bha<3Ph86ed3C@f>3@^=SLb>B0a<CPa;S4`>3PPK6T=I7<=KW0==3L`<Rh`
<c@P<C8f=bhi<C<i86ed3C@f>3@^=SLb>B0a<SHg;STa<cTPK6T=I7<=KW0==3L`
<Rh`<c@P<C<e=2hg<CTPKG@==3Hh=2hf=c8i834c=C@^=c4i86aY3FAc3Fi`3C@g
<38^<3<d834d=34^=C8d<B1]M0dd=SPd;SHg<STP<C@d<Bhe<S@a86aY3FAc3Fi`
3C@g<38^<3<d834e<SP^<c8i<R1]M0dd=SPd;SHg<STP<CDb>2hc<STb86aY3FAc
3Fi`3C@g<38^<3<d834f<CD^<C<d=21]M0dd=SPd;SHg<STP<CHa=Bha<c@d86aY
3FAc3Fi`3C@g<38^<3<d834g<34^>C<i=B1]M0dd=SPd;SHg<STP<CL`<Bhi<cTe
86aY3FAc3Fi`3C@g<38^<3<d834g>3P^=c@d=R1]M0dd=SPd;SHg<STP<CLh>2hg
=3@f86aY3FAc3Fi`3C@g<38^<3<d834h=cD^=C@i=b1]M0dd=SPd;SHg<STP<CPg
=Bhe=3Tg86aY3FAc3Fi`3C@g<38^<3<d834i=S8^<cDd>21]M0dd=SPd;SHg<STP
<CTf<Rhc=C@h86aY3FAc3Fi`3C@g<38^<3<d838`=3T^<CDi>B1]M0dd=SPd;SHg
<STP<S0d>Bha=CTi86aY3FAc3Fi`3C@g<38^<3<d838a<cD^>CHe86ed3C@f>3@^
=SLb>B0b<C<e;STf=B1/J@eTL`e^L0dd=c0b;S0c=20b<S8b;SLg<38PKG@==3Hh
=2hf=c8i838b<S8^=cL`<R1/J@eTL`e^L0dd=c0b;S0c=20b<c0i;SDg=C<PKG@=
=3Hh=2hf=c8i838c<3T^=CLe<b1/J@eTL`e^L0dd=c0b;S0c=20b<cTf;S<h<3@P
KG@==3Hh=2hf=c8i838c>CH^<cP`=21/J@eTL`e^L0dd=c0b;S0c=20b=3Pc;S4h
=CDPKG@==3Hh=2hf=c8i838d>3<^<CPe=B1/J@eTL`e^L0dd=c0b;S0c=20b=CHi
;STi<3HPKG@==3Hh=2hf=c8i838e=ST^>CT`=R1/J@eTL`e^L0dd=c0b;S0c=20b
=SDf;SLi=CLPKG@==3Hh=2hf=c8i838f=CH^=cTe=b1/J@eTL`e^L0dd=c0b;S0c
=20b=c@c;SH`<3PPKG@==3Hh=2hf=c8i838g=3<^=S0`>21/J@eTL`e^L0dd=c0b
;S0c=20b>3<`;S@`=R1]M0dd=SPd;SHg<STP<SPc<2hd<3HPK6T=I7<=KW0==3L`
<Rh`<c@P<STa=bhb<C4a86ed3C@f>3@^=SLb>B0b>C4g;S8a<C4PK6T=I7<=KW0=
=3L`<Rh`<c@P<c0`=2h`<CHb86ed3C@f>3@^=SLb>B0c<30d;S0a=S8PK6T=I7<=
KW0==3L`<Rh`<c@P<c0i<2hh<S4c86ed3C@f>3@^=SLb>B0c<3T`;SPb<C<PK6T=
I7<=KW0==3L`<Rh`<c@P<c4g=bhf<SHd86ed3C@f>3@^=SLb>B0c<CLg;SHb=S@P
K6T=I7<=KW0==3L`<Rh`<c@P<c8f=2hd<c4e86ed3C@f>3@^=SLb>B0c<SHd;S@c
<CDPK6T=I7<=KW0==3L`<Rh`<c@P<c<e<Bhb<cHg86ed3C@f>3@^=SLb>B0c<cDa
;S8c=SLPK6T=I7<=KW0==3L`<Rh`<c@P<c@c>2h`=34h86ed3C@f>3@^=SLb>B0c
=3<h;S0d<CPPK6T=I7<=KW0==3L`<Rh`<c@P<cDb=2hh=3Hi86ed3C@f>3@^=SLb
>B0c=C8d;SPd=STPK6T=I7<=KW0==3L`<Rh`<c@P<cHa<Bhf=C8PKG@==3Hh=2hf
=c8i83<f<C4^=SDb86aY3FAc3Fi`3C@g<38^<3<d83<f>CP^=3Dg<B1]M0dd=SPd
;SHg<STP<cHi>2hd=CLa86aY3FAc3Fi`3C@g<38^<3<d83<g>3D^<SHb<R1]M0dd
=SPd;SHg<STP<cLh=Bhb=S8b86aY3FAc3Fi`3C@g<38^<3<d83<h=c8^<3Hg<b1]
M0dd=SPd;SHg<STP<cPg<Rh`=SLc86aY3FAc3Fi`3C@g<38^<3<d83<i=CP^>3Lb
=B1]M0dd=SPd;SHg<STP<cTe>2hh=c8e86aY3FAc3Fi`3C@g<38^<3<d83@`=3D^
=SLg=R1]M0dd=SPd;SHg<STP=30d=Bhf=cLf86aY3FAc3Fi`3C@g<38^<3<d83@a
<c8^=3Pb=b1]M0dd=SPd;SHg<STP=34c<Rhd>38g86aY3FAc3Fi`3C@g<38^<3<d
83@b<CT^<SPg>21]M0dd=SPd;SHg<STP=38a>Bhb>3Lh86aY3FAc3Fi`3C@g<38^
<3<d83@c<3H^<3Tb>B1]M0dd=SPd;SHg<STP=3<`=Rh`>C8i86aY3FAc3Fi`3C@g
<38^<3<d83@c>C8^>3Th86ed3C@f>3@^=SLb>B0d<cTb;SPi>21/J@eTL`eXI@d0
0:40`003Ig8=002Q0<00179dK@d0X@3000YdIG9]JFiQM6D=0:00_`2P0;h0VP00
0?n?X0000003j0?X000010000000B00004P0000@02000`08000000000002KGK/
000000?X0nP000000nT3j`000321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`1>POn1oh7oZol10021oj[o0021
ojKo0@00POn1oh7oPOo@o`40087oZ_l0087oY_l10021oh7oPOn1om3o0@00POnZ
o`00POnVo`400:Ko04R1oh7oPOn_ooP0POnaooP0POn]ooP0POn1oh7oPOoHooP0
POnaooP0POn]ooP0POn1oh7oPOoHooP0POnaooP0POn]ooP0Z_l0B87oPOn1ojoo
m`21ok?om`21ojkom`21oh7oPOn1omSom`21ok?om`21ojkom`21oh7oPOn1omSo
m`21ok?om`21ojkom`2Zo`18POn1oh7o/?oe087o]Ooe087o/?oe087oPOn1oh7o
f_oe087o]Ooe087o/?oe087oPOn1oh7of_oe087o]Ooe087o/?oe0:_o06n1oh7o
POn`oo`00Ooon`21okKon`00oo/0POnaoo/00?ok087oPOn1oh7ofool007ooo/0
POnfoo/00?ok087o/Ook003on`21oh7oPOn1om_oo001oook087o]_ok003on`21
ok7on`00oo/0[?l0K87oPOn1ok7oo@3loo`0POngoo`0o?om087o/_ol0?coo@21
oh7oPOn1omcoo@3loo`0POngoo`0o?om087o/_ol0?coo@21oh7oPOn1omcoo@3l
oo`0POngoo`0o?om087o/_ol0?coo@2/o`1/POn1oh7o/ook0?con`21okWon`3l
oo`0POndoo/0o?ol087oPOn1oh7ogook0?con`21okWon`3loo`0POndoo/0o?ol
087oPOn1oh7ogook0?con`21okWon`3loo`0POndoo/0o?ol0:go06b1oh7oPOnc
oo`0n_ol087o^Ool0?[oo021okGoo03jood0POn1oh7oPOoOoo`0n_ol087o^Ool
0?[oo021okGoo03jood0POn1oh7oPOoOoo`0n_ol087o^Ool0?[oo021okGoo03j
ood0[Ol0K87oPOn1okCoo03hoo`0POnkoo`0n?ol087o]ool0?Woo021oh7oPOn1
on7oo03hoo`0POnkoo`0n?ol087o]ool0?Woo021oh7oPOn1on7oo03hoo`0POnk
oo`0n?ol087o]ool0?Woo02^o`1/POn1oh7o]?ol0?Soo021ok_oo03hoo`0POng
oo`0nOol087oPOn1oh7ohOol0?Soo021ok_oo03hoo`0POngoo`0nOol087oPOn1
oh7ohOol0?Soo021ok_oo03hoo`0POngoo`0nOol0:ko06b1oh7oPOndood0m_om
087o^oom0?Koo@21okOoo@3good0POn1oh7oPOoQood0m_om087o^oom0?Koo@21
okOoo@3good0POn1oh7oPOoQood0m_om087o^oom0?Koo@21okOoo@3good0[_l0
K87oPOn1okGoo03foo`0POnmoo`0m_ol087o^Ool0?Ooo021oh7oPOn1on?oo03f
oo`0POnmoo`0m_ol087o^Ool0?Ooo021oh7oPOn1on?oo03foo`0POnmoo`0m_ol
087o^Ool0?Ooo02_o`1/POn1oh7o]Oom0?Coo@21okgoo@3dood0POniood0mOom
087oPOn1oh7ohoom0?Coo@21okgoo@3dood0POniood0mOom087oPOn1oh7ohoom
0?Coo@21okgoo@3dood0POniood0mOom0:oo06b1oh7oPOnfoo`0m?ol087o_ool
0?Coo021ok_oo03eoo`0POn1oh7oPOoUoo`0m?ol087o_ool0?Coo021ok_oo03e
oo`0POn1oh7oPOoUoo`0m?ol087o_ool0?Coo021ok_oo03eoo`0/?l0K87oPOn1
okKoo@3coo`0POnoood0lool087o^oom0?Coo021oh7oPOn1onGoo@3coo`0POno
ood0lool087o^oom0?Coo021oh7oPOn1onGoo@3coo`0POnoood0lool087o^oom
0?Coo02`o`1/POn1oh7o]_om0?;oo@21okooo@3bood0POnkood0loom087oPOn1
oh7oiOom0?;oo@21okooo@3bood0POnkood0loom087oPOn1oh7oiOom0?;oo@21
okooo@3bood0POnkood0loom0;3o06b1oh7oPOngoo`0l_ol087o`Ool0?;oo@21
okcoo03coo`0POn1oh7oPOoWoo`0l_ol087o`Ool0?;oo@21okcoo03coo`0POn1
oh7oPOoWoo`0l_ol087o`Ool0?;oo@21okcoo03coo`0/Ol0K87oPOn1okOoo@3a
oo`0POo1ood0lOol087o_Oom0?;oo021oh7oPOn1onOoo@3aoo`0POo1ood0lOol
087o_Oom0?;oo021oh7oPOn1onOoo@3aoo`0POo1ood0lOol087o_Oom0?;oo02a
o`1/POn1oh7o]oom0?3oo@21ol7oo@3aoo`0POnmood0lOom087oPOn1oh7oioom
0?3oo@21ol7oo@3aoo`0POnmood0lOom087oPOn1oh7oioom0?3oo@21ol7oo@3a
oo`0POnmood0lOom0;7o06b1oh7oPOngood0l?om087o`Oom0?3oo@21okgoo@3a
ood0POn1oh7oPOoWood0l?om087o`Oom0?3oo@21okgoo@3aood0POn1oh7oPOoW
ood0l?om087o`Oom0?3oo@21okgoo@3aood0/Ol0K87oPOn1okSoo03`oo`0POo3
oo`0l?om087o__om0?3oo021oh7oPOn1onWoo03`oo`0POo3oo`0l?om087o__om
0?3oo021oh7oPOn1onWoo03`oo`0POo3oo`0l?om087o__om0?3oo02bo`1/POn1
oh7o^?om0>koo@21ol?oo@3_ood0POnnood0koom087oPOn1oh7ojOom0>koo@21
ol?oo@3_ood0POnnood0koom087oPOn1oh7ojOom0>koo@21ol?oo@3_ood0POnn
ood0koom0;;o06b1oh7oPOnhood0k_om087o`oom0>ooo021okoooP3^ood0POn1
oh7oPOoYood0k_om087o`oom0>ooo021okoooP3^ood0POn1oh7oPOoYood0k_om
087o`oom0>ooo021okoooP3^ood0/_l0K87oPOn1okWoo03^oo`0POo5oo`0kool
087o`?om0>koo021oh7oPOn1on_oo03^oo`0POo5oo`0kool087o`?om0>koo021
oh7oPOn1on_oo03^oo`0POo5oo`0kool087o`?om0>koo02co`1/POn1oh7o^Ool
0>koo021olGoo03^ood0POo1oo`0k_ol087oPOn1oh7ojool0>koo021olGoo03^
ood0POo1oo`0k_ol087oPOn1oh7ojool0>koo021olGoo03^ood0POo1oo`0k_ol
0;?o06b1oh7oPOniood0k?om087oaOom0>goo021ol;oo03]ood0POn1oh7oPOo[
ood0k?om087oaOom0>goo021ol;oo03]ood0POn1oh7oPOo[ood0k?om087oaOom
0>goo021ol;oo03]ood0/ol0K87oPOn1okWoo@3/ood0POo6oo`0kOol087o`_ol
0>goo@21oh7oPOn1on_oo@3/ood0POo6oo`0kOol087o`_ol0>goo@21oh7oPOn1
on_oo@3/ood0POo6oo`0kOol087o`_ol0>goo@2co`1/POn1oh7o^_ol0>coo021
olOoo03]oo`0POo3oo`0k?ol087oPOn1oh7okOol0>coo021olOoo03]oo`0POo3
oo`0k?ol087oPOn1oh7okOol0>coo021olOoo03]oo`0POo3oo`0k?ol0;Co06b1
oh7oPOnjood0j_om087oaoom0>_oo021olCoo03[ood0POn1oh7oPOo]ood0j_om
087oaoom0>_oo021olCoo03[ood0POn1oh7oPOo]ood0j_om087oaoom0>_oo021
olCoo03[ood0]?l0K87oPOn1ok[oo@3Zood0POo7ood0jool087oa?ol0>_oo@21
oh7oPOn1ongoo@3Zood0POo7ood0jool087oa?ol0>_oo@21oh7oPOn1ongoo@3Z
ood0POo7ood0jool087oa?ol0>_oo@2do`1/POn1oh7o^_om0>[oo@21olSoo03[
oo`0POo4oo`0joom087oPOn1oh7okOom0>[oo@21olSoo03[oo`0POo4oo`0joom
087oPOn1oh7okOom0>[oo@21olSoo03[oo`0POo4oo`0joom0;Co06b1oh7oPOnj
ood0j_om087ob?ol0>_oo021olCoo@3Zood0POn1oh7oPOo]ood0j_om087ob?ol
0>_oo021olCoo@3Zood0POn1oh7oPOo]ood0j_om087ob?ol0>_oo021olCoo@3Z
ood0]?l0K87oPOn1ok_oo03Zoo`0POo9oo`0jool087oaOol0>[oo021oh7oPOn1
onooo03Zoo`0POo9oo`0jool087oaOol0>[oo021oh7oPOn1onooo03Zoo`0POo9
oo`0jool087oaOol0>[oo02eo`1/POn1oh7o^oom0>Soo@21ol[oo03Yood0POo5
oo`0jOom087oPOn1oh7okoom0>Soo@21ol[oo03Yood0POo5oo`0jOom087oPOn1
oh7okoom0>Soo@21ol[oo03Yood0POo5oo`0jOom0;Go06b1oh7oPOnkood0j?om
087ob_ol0>Woo@21olGoo@3Xood0POn1oh7oPOo_ood0j?om087ob_ol0>Woo@21
olGoo@3Xood0POn1oh7oPOo_ood0j?om087ob_ol0>Woo@21olGoo@3Xood0]Ol0
K87oPOn1ok_oo@3Xood0POo:oo`0jOol087oa_om0>Soo@21oh7oPOn1onooo@3X
ood0POo:oo`0jOol087oa_om0>Soo@21oh7oPOn1onooo@3Xood0POo:oo`0jOol
087oa_om0>Soo@2eo`1/POn1oh7o_?ol0>Soo021ol_oo03Yoo`0POo7oo`0j?ol
087oPOn1oh7olOol0>Soo021ol_oo03Yoo`0POo7oo`0j?ol087oPOn1oh7olOol
0>Soo021ol_oo03Yoo`0POo7oo`0j?ol0;Ko06b1oh7oPOnlood0i_om087oc?ol
0>Ooo@21olOoo03Wood0POn1oh7oPOoaood0i_om087oc?ol0>Ooo@21olOoo03W
ood0POn1oh7oPOoaood0i_om087oc?ol0>Ooo@21olOoo03Wood0]_l0K87oPOn1
okcoo@3Vood0POo<oo`0ioom087oaoom0>Koo@21oh7oPOn1oo7oo@3Vood0POo<
oo`0ioom087oaoom0>Koo@21oh7oPOn1oo7oo@3Vood0POo<oo`0ioom087oaoom
0>Koo@2fo`1/POn1oh7o_?om0>Koo@21olcoo03Wood0POo7ood0i_om087oPOn1
oh7olOom0>Koo@21olcoo03Wood0POo7ood0i_om087oPOn1oh7olOom0>Koo@21
olcoo03Wood0POo7ood0i_om0;Ko06b1oh7oPOnlood0i_om087oc?ol0>Ooo@21
olOoo@3Vood0POn1oh7oPOoaood0i_om087oc?ol0>Ooo@21olOoo@3Vood0POn1
oh7oPOoaood0i_om087oc?ol0>Ooo@21olOoo@3Vood0]_l0K87oPOn1okgoo03V
ood0POo=oo/0ioom087ob?ol0>Koo@21oh7oPOn1oo;oo03Vood0POo=oo/0ioom
087ob?ol0>Koo@21oh7oPOn1oo;oo03Vood0POo=oo/0ioom087ob?ol0>Koo@2f
o`1/POn1oh7o_Oom0>Goo@21olgoo03Uood0POo9ood0i?om087oPOn1oh7oloom
0>Goo@21olgoo03Uood0POo9ood0i?om087oPOn1oh7oloom0>Goo@21olgoo03U
ood0POo9ood0i?om0;Oo06b1oh7oPOnmood0i?om087oc_ol0>Goo@21olWoo@3T
ood0POn1oh7oPOocood0i?om087oc_ol0>Goo@21olWoo@3Tood0POn1oh7oPOoc
ood0i?om087oc_ol0>Goo@21olWoo@3Tood0]ol0K87oPOn1okgoo@3Tood0POo>
oo`0iOom087obOom0>Coo@21oh7oPOn1oo?oo@3Tood0POo>oo`0iOom087obOom
0>Coo@21oh7oPOn1oo?oo@3Tood0POo>oo`0iOom087obOom0>Coo@2go`1/POn1
oh7o_Oom0>Coo@21olkoo03Uood0POo9ood0i?om087oPOn1oh7oloom0>Coo@21
olkoo03Uood0POo9ood0i?om087oPOn1oh7oloom0>Coo@21olkoo03Uood0POo9
ood0i?om0;Oo06b1oh7oPOnmood0i?om087oc_om0>Coo@21olWoo@3Tood0POn1
oh7oPOocood0i?om087oc_om0>Coo@21olWoo@3Tood0POn1oh7oPOocood0i?om
087oc_om0>Coo@21olWoo@3Tood0]ol0K87oPOn1okkoo03Tood0POo?oo`0i?ol
087obool0>Coo021oh7oPOn1ooGoo03Tood0POo?oo`0i?ol087obool0>Coo021
oh7oPOn1ooGoo03Tood0POo?oo`0i?ol087obool0>Coo02ho`1/POn1oh7o__om
0>?oo@21olooo03Sood0POo;ood0h_om087oPOn1oh7omOom0>?oo@21olooo03S
ood0POo;ood0h_om087oPOn1oh7omOom0>?oo@21olooo03Sood0POo;ood0h_om
0;So06b1oh7oPOnnood0hoom087ocool0>?oo@21ol_oo@3Rood0POn1oh7oPOoe
ood0hoom087ocool0>?oo@21ol_oo@3Rood0POn1oh7oPOoeood0hoom087ocool
0>?oo@21ol_oo@3Rood0^?l0K87oPOn1okkoo@3Sood0POo?ood0h_om087oboom
0>;oo@21oh7oPOn1ooGoo@3Sood0POo?ood0h_om087oboom0>;oo@21oh7oPOn1
ooGoo@3Sood0POo?ood0h_om087oboom0>;oo@2ho`1/POn1oh7o__om0>?oo021
om3oo@3Rood0POo;ood0h_om087oPOn1oh7omOom0>?oo021om3oo@3Rood0POo;
ood0h_om087oPOn1oh7omOom0>?oo021om3oo@3Rood0POo;ood0h_om0;So06b1
oh7oPOnooo`0h_om087odOol0>;oo@21olcoo03Rood0POn1oh7oPOofoo`0h_om
087odOol0>;oo@21olcoo03Rood0POn1oh7oPOofoo`0h_om087odOol0>;oo@21
olcoo03Rood0^?l0K87oPOn1okooo@3Qood0POoAoo`0hOom087ocOom0>3oo@21
oh7oPOn1ooOoo@3Qood0POoAoo`0hOom087ocOom0>3oo@21oh7oPOn1ooOoo@3Q
ood0POoAoo`0hOom087ocOom0>3oo@2io`1/POn1oh7o_oom0>7oo@21om7oo@3P
ood0POo=ood0h?om087oPOn1oh7omoom0>7oo@21om7oo@3Pood0POo=ood0h?om
087oPOn1oh7omoom0>7oo@21om7oo@3Pood0POo=ood0h?om0;Wo06b1oh7oPOno
ood0hOom087odOom0>3oo@21olgoo@3Pood0POn1oh7oPOogood0hOom087odOom
0>3oo@21olgoo@3Pood0POn1oh7oPOogood0hOom087odOom0>3oo@21olgoo@3P
ood0^Ol0K87oPOn1okooo@3Qood0POoAood0h?om087ocOom0>3oo@21oh7oPOn1
ooOoo@3Qood0POoAood0h?om087ocOom0>3oo@21oh7oPOn1ooOoo@3Qood0POoA
ood0h?om087ocOom0>3oo@2io`1/POn1oh7o_oom0>7oo@21om7oo@3Pood0POo=
ood0h?om087oPOn1oh7omoom0>7oo@21om7oo@3Pood0POo=ood0h?om087oPOn1
oh7omoom0>7oo@21om7oo@3Pood0POo=ood0h?om0;Wo06b1oh7oPOo0oo`0hOol
087odool0>3oo021olooo03Poo`0POn1oh7oPOoioo`0hOol087odool0>3oo021
olooo03Poo`0POn1oh7oPOoioo`0hOol087odool0>3oo021olooo03Poo`0^_l0
K87oPOn1ol3oo@3Oood0POoCood0g_om087ocoom0=ooo021oh7oPOn1ooWoo@3O
ood0POoCood0g_om087ocoom0=ooo021oh7oPOn1ooWoo@3Oood0POoCood0g_om
087ocoom0=ooo02jo`1/POn1oh7o`?om0=ooo@21om?oo@3Nood0POo?ood0g_om
087oPOn1oh7onOom0=ooo@21om?oo@3Nood0POo?ood0g_om087oPOn1oh7onOom
0=ooo@21om?oo@3Nood0POo?ood0g_om0;[o06b1oh7oPOo0ood0goom087odoom
0=koo@21olooo@3Nood0POn1oh7oPOoiood0goom087odoom0=koo@21olooo@3N
ood0POn1oh7oPOoiood0goom087odoom0=koo@21olooo@3Nood0^_l0K87oPOn1
ol3oo@3Oood0POoCood0g_om087ocoom0=koo@21oh7oPOn1ooWoo@3Oood0POoC
ood0g_om087ocoom0=koo@21oh7oPOn1ooWoo@3Oood0POoCood0g_om087ocoom
0=koo@2jo`1/POn1oh7o`?om0=ooo@21om?oo@3Nood0POo?ood0g_om087oPOn1
oh7onOom0=ooo@21om?oo@3Nood0POo?ood0g_om087oPOn1oh7onOom0=ooo@21
om?oo@3Nood0POo?ood0g_om0;[o06b1oh7oPOo0ood0goom087odoom0=koo@21
olooo@3Nood0POn1oh7oPOoiood0goom087odoom0=koo@21olooo@3Nood0POn1
oh7oPOoiood0goom087odoom0=koo@21olooo@3Nood0^_l0K87oPOn1ol7oo@3M
ood0POoEood0g?om087odOom0=goo021oh7oPOn1oo_oo@3Mood0POoEood0g?om
087odOom0=goo021oh7oPOn1oo_oo@3Mood0POoEood0g?om087odOom0=goo02k
o`1/POn1oh7o`Oom0=goo@21omGoo@3Lood0POoAood0gOol087oPOn1oh7onoom
0=goo@21omGoo@3Lood0POoAood0gOol087oPOn1oh7onoom0=goo@21omGoo@3L
ood0POoAood0gOol0;_o06b1oh7oPOo1ood0gOom087oeOom0=coo@21om7oo@3M
oo`0POn1oh7oPOokood0gOom087oeOom0=coo@21om7oo@3Moo`0POn1oh7oPOok
ood0gOom087oeOom0=coo@21om7oo@3Moo`0^ol0K87oPOn1ol7oo@3Mood0POoE
ood0g?om087odOom0=goo021oh7oPOn1oo_oo@3Mood0POoEood0g?om087odOom
0=goo021oh7oPOn1oo_oo@3Mood0POoEood0g?om087odOom0=goo02ko`1/POn1
oh7o`Oom0=goo@21omGoo@3Lood0POoAood0gOol087oPOn1oh7onoom0=goo@21
omGoo@3Lood0POoAood0gOol087oPOn1oh7onoom0=goo@21omGoo@3Lood0POoA
ood0gOol0;_o06b1oh7oPOo1ood0gOom087oeOom0=coo@21om7oo@3Lood0POn1
oh7oPOokood0gOom087oeOom0=coo@21om7oo@3Lood0POn1oh7oPOokood0gOom
087oeOom0=coo@21om7oo@3Lood0^ol0K87oPOn1ol;oo@3Loo`0POoGood0fool
087odoom0=_oo021oh7oPOn1oogoo@3Loo`0POoGood0fool087odoom0=_oo021
oh7oPOn1oogoo@3Loo`0POoGood0fool087odoom0=_oo02lo`1/POn1oh7o`_om
0=_oo@21omOoo@3Jood0POoCood0fool087oPOn1oh7ooOom0=_oo@21omOoo@3J
ood0POoCood0fool087oPOn1oh7ooOom0=_oo@21omOoo@3Jood0POoCood0fool
0;co06b1oh7oPOo2ood0foom087oeoom0=[oo@21om?oo@3Koo`0POn1oh7oPOom
ood0foom087oeoom0=[oo@21om?oo@3Koo`0POn1oh7oPOomood0foom087oeoom
0=[oo@21om?oo@3Koo`0_?l0K87oPOn1ol;oo@3Kood0POoGood0f_om087odoom
0=_oo021oh7oPOn1oogoo@3Kood0POoGood0f_om087odoom0=_oo021oh7oPOn1
oogoo@3Kood0POoGood0f_om087odoom0=_oo02lo`1/POn1oh7o`_om0=_oo@21
omOoo@3Jood0POoCood0fool087oPOn1oh7ooOom0=_oo@21omOoo@3Jood0POoC
ood0fool087oPOn1oh7ooOom0=_oo@21omOoo@3Jood0POoCood0fool0;co06b1
oh7oPOo2ood0foom087oeoom0=[oo@21om?oo@3Koo`0POn1oh7oPOomood0foom
087oeoom0=[oo@21om?oo@3Koo`0POn1oh7oPOomood0foom087oeoom0=[oo@21
om?oo@3Koo`0_?l0K87oPOn1ol?oo03Kood0POoGood0f_om087odoom0=_oo021
oh7oPOn1ookoo03Kood0POoGood0f_om087odoom0=_oo021oh7oPOn1ookoo03K
ood0POoGood0f_om087odoom0=_oo02lo`1/POn1oh7o`oom0=[oo021omWoo@3I
ood0POoDood0f_ol087oPOn1oh7oo_om0=[oo021omWoo@3Iood0POoDood0f_ol
087oPOn1oh7oo_om0=[oo021omWoo@3Iood0POoDood0f_ol0;co06b1oh7oPOo3
ood0fOom087ofOom0=Woo@21omCoo@3Iood0POn1oh7oPOonood0fOom087ofOom
0=Woo@21omCoo@3Iood0POn1oh7oPOonood0fOom087ofOom0=Woo@21omCoo@3I
ood0_?l0KX7oPOn1ol?oo@3Iood0POoIood0fOol087oeOom0=Woo021oh7oPOn1
o`7oood0fOom087ofOom0=Woo021omGoo@3Ioo`0POn1oh7oPOl1ooom0=Woo@21
omWoo@3Ioo`0POoEood0fOol0;go06j1oh7oPOo3ood0fOom087ofOom0=Soo@21
omGoo@3Ioo`0POn1oh7oPOl1ooom0=Woo@21omWoo@3Hood0POoEood0fOol087o
POn1oh7o0Oooo@3Iood0POoIood0f?om087oeOom0=Woo02mo`1^POn1oh7o`oom
0=Woo@21omWoo@3Hood0POoEood0fOol087oPOn1oh7o0Oooo@3Iood0POoIood0
f?om087oeOom0=Woo021oh7oPOn1o`7oood0fOom087ofOom0=Soo@21omGoo@3I
oo`0_Ol0K87oPOn1olCoo03Iood0POoIood0f?om087oeOom0=Woo021oh7oPOn1
o`3oo03Iood0POoIood0f?om087oeOom0=Woo021oh7oPOn1o`3oo03Iood0POoI
ood0f?om087oeOom0=Woo02mo`1/POn1oh7oa?ol0=Woo@21omWoo@3Hood0POoE
ood0fOol087oPOn1oh7o0?ol0=Woo@21omWoo@3Hood0POoEood0fOol087oPOn1
oh7o0?ol0=Woo@21omWoo@3Hood0POoEood0fOol0;go06b1oh7oPOo4oo`0fOol
087of_om0=Soo@21omGoo@3Ioo`0POn1oh7oPOl0oo`0fOol087of_om0=Soo@21
omGoo@3Ioo`0POn1oh7oPOl0oo`0fOol087of_om0=Soo@21omGoo@3Ioo`0_Ol0
K87oPOn1olCoo@3Good0POoKood0eoom087oe_om0=Ooo@21oh7oPOn1o`3oo@3G
ood0POoKood0eoom087oe_om0=Ooo@21oh7oPOn1o`3oo@3Good0POoKood0eoom
087oe_om0=Ooo@2mo`1/POn1oh7oa?om0=Ooo@21om_oo@3Good0POoFood0eoom
087oPOn1oh7o0?om0=Ooo@21om_oo@3Good0POoFood0eoom087oPOn1oh7o0?om
0=Ooo@21om_oo@3Good0POoFood0eoom0;go06R1oh7oPOo5oo`0eoom087ofoom
0=Ooo@21omKoo@3Good0POn1oh7oPOol0=Ooo@21om_oo@3Good0POoFood0eoom
087oPOn1oh7oo03Good0POoKood0eoom087oe_om0=Ooo@2mo`1XPOn1oh7oaOol
0=Ooo@21om_oo@3Good0POoFood0eoom087oPOn1oh7oo03Good0POoKood0eoom
087oe_om0=Ooo@21oh7oPOn1oo`0eoom087ofoom0=Ooo@21omKoo@3Good0_Ol0
J87oPOn1olGoo03Good0POoKood0eoom087oe_om0=Ooo@21oh7oPOn1oo`0eoom
087ofoom0=Ooo@21omKoo@3Good0POn1oh7oPOol0=Ooo@21om_oo@3Good0POoF
ood0eoom0;go06R1oh7oPOo5oo`0eoom087ofoom0=Ooo021omOoo@3Goo`0POn1
oh7oP_ol0=Ooo@21om_oo@3Goo`0POoGood0eool087oPOn1oh;oo03Good0POoK
ood0eool087oeoom0=Ooo02no`1XPOn1oh7oaOol0=Ooo@21om_oo@3Food0POoG
ood0eool087oPOn1oh;oo03Good0POoKood0e_om087oeoom0=Ooo021oh7oPOn2
oo`0eoom087ofoom0=Koo@21omOoo@3Goo`0__l0J87oPOn1olGoo@3Foo`0POoM
ood0eOom087of?om0=Koo021oh7oPOn2ood0e_ol087ogOom0=Goo@21omSoo@3F
oo`0POn1oh7oP_om0=Koo021omgoo@3Eood0POoHood0e_ol0;ko06R1oh7oPOo6
oo`0eOom087ogOom0=Goo@21omSoo@3Eood0POn1oh7oPool0=Goo@21omgoo@3E
ood0POoHood0eOom087oPOn1oh?oo03Eood0POoMood0eOom087of?om0=Goo@2n
o`1XPOn1oh7oa_ol0=Goo@21omgoo@3Eood0POoHood0eOom087oPOn1oh?oo03E
ood0POoMood0eOom087of?om0=Goo@21oh7oPOn3oo`0eOom087ogOom0=Goo@21
omSoo@3Eood0__l0J87oPOn1olKoo@3Dood0POoMood0eOom087of?om0=Goo@21
oh7oPOn3ood0e?om087ogOom0=Goo@21omSoo@3Eood0POn1oh7oPoom0=Coo@21
omgoo@3Eood0POoHood0eOom0;ko06R1oh7oPOo6ood0e?om087ogOom0=Goo@21
omSoo@3Eood0POn1oh7oPoom0=Coo@21omgoo@3Eood0POoHood0eOom087oPOn1
oh?oo@3Dood0POoMood0eOom087of?om0=Goo@2no`1XPOn1oh7oa_om0=Coo@21
omgoo@3Eood0POoHood0eOom087oPOn1oh?oo@3Dood0POoMood0eOom087of?om
0=Goo@21oh7oPOn3ood0e?om087ogOom0=Goo@21omSoo@3Eood0__l0J87oPOn1
olKoo@3Dood0POoMood0eOom087ofOol0=Goo@21oh7oPOn3ood0e?om087ogOom
0=Goo@21omWoo03Eood0POn1oh7oPoom0=Coo@21omgoo@3Eood0POoIoo`0eOom
0;ko06R1oh7oPOo7ood0doom087og_om0=Coo021om[oo@3Doo`0POn1oh7oQOom
0=?oo@21omkoo@3Doo`0POoJood0e?ol087oPOn1ohGoo@3Cood0POoNood0e?ol
087of_om0=Coo02oo`1XPOn1oh7oaoom0=?oo@21omkoo@3Cood0POoJood0doom
087oPOn1ohGoo@3Cood0POoNood0doom087of_om0=?oo@21oh7oPOn5ood0doom
087og_om0=?oo@21om[oo@3Cood0_ol0J87oPOn1olOoo@3Coo`0POoOood0doom
087of_om0=?oo@21oh7oPOn5ood0dool087ogoom0=?oo@21om[oo@3Cood0POn1
oh7oQOom0=?oo021omooo@3Cood0POoJood0doom0;oo06R1oh7oPOo7ood0d_om
087ogoom0=?oo@21om[oo@3Cood0POn1oh7oQOom0=;oo@21omooo@3Cood0POoJ
ood0doom087oPOn1ohGoo@3Bood0POoOood0doom087of_om0=?oo@2oo`1XPOn1
oh7oaoom0=;oo@21omooo@3Cood0POoJood0doom087oPOn1ohGoo@3Bood0POoO
ood0doom087of_om0=?oo@21oh7oPOn5ood0d_om087ogoom0=?oo@21om[oo@3C
ood0_ol0J87oPOn1olOoo@3Bood0POoOood0doom087ofool0=?oo@21oh7oPOn5
ood0d_om087ogoom0=?oo@21om_oo03Cood0POn1oh7oQOom0=;oo@21omooo@3C
ood0POoKoo`0doom0;oo06R1oh7oPOo7ood0d_om087ogoom0=?oo@21om_oo03C
ood0POn1oh7oQOom0=;oo@21omooo@3Cood0POoKoo`0doom087oPOn1ohGoo@3B
ood0POoOood0doom087ofool0=?oo@2oo`1XPOn1oh7oaoom0=;oo@21omooo@3C
ood0POoKoo`0doom087oPOn1ohGoo@3Bood0POoOood0doom087ofool0=?oo@21
oh7oPOn5ood0d_om087ogoom0=?oo@21om_oo03Cood0_ol0J87oPOn1olSoo@3A
ood0POoPood0dOom087og?om0=7oo@21oh7oPOn7ood0dOom087oh?om0=7oo@21
omcoo@3Aood0POn1oh7oQoom0=7oo@21on3oo@3Aood0POoLood0dOom0<3o06R1
oh7oPOo8ood0dOom087oh?om0=7oo@21omcoo@3Aood0POn1oh7oQoom0=7oo@21
on3oo@3Aood0POoLood0dOom087oPOn1ohOoo@3Aood0POoPood0dOom087og?om
0=7oo@30o`1XPOn1oh7ob?om0=7oo@21on3oo@3Aood0POoMoo`0dOom087oPOn1
ohOoo@3Aood0POoPood0dOom087ogOol0=7oo@21oh7oPOn7ood0dOom087oh?om
0=7oo@21omgoo03Aood0`?l0J87oPOn1olSoo@3Aood0POoPood0dOom087ogOol
0=7oo@21oh7oPOn7ood0dOom087oh?om0=7oo@21omgoo03Aood0POn1oh7oQoom
0=7oo@21on3oo@3Aood0POoMoo`0dOom0<3o06R1oh7oPOo8ood0dOom087oh?om
0=7oo@21omgoo03Aood0POn1oh7oQoom0=7oo@21on3oo@3Aood0POoMoo`0dOom
087oPOn1ohOoo@3Aood0POoPood0dOom087ogOol0=7oo@30o`1XPOn1oh7ob?om
0=7oo021on7oo@3Aood0POoMoo`0dOom087oPOn1ohOoo@3Aoo`0POoQood0dOom
087ogOol0=7oo@21oh7oPOn7ood0dOol087ohOom0=7oo@21omgoo03Aood0`?l0
J87oPOn1olSoo@3@ood0POoQood0dOom087ogOol0=7oo@21oh7oPOn7ood0d?om
087ohOom0=7oo@21omgoo03Aood0POn1oh7oQoom0=3oo@21on7oo@3Aood0POoM
oo`0dOom0<3o06R1oh7oPOo9oo`0d?om087oh_ol0=7oo021omkoo03Aoo`0POn1
oh7oROol0=3oo@21on;oo03Aoo`0POoNoo`0dOol087oPOn1ohWoo03@ood0POoR
oo`0dOol087og_ol0=7oo031o`1XPOn1oh7obOom0<ooo@21on;oo@3?ood0POoO
oo`0coom087oPOn1ohWoo@3?ood0POoRood0coom087ogool0<ooo@21oh7oPOn9
ood0coom087oh_om0<ooo@21omooo03?ood0`Ol0J87oPOn1olWoo@3?ood0POoR
ood0coom087ogool0<ooo@21oh7oPOn9ood0coom087oh_om0<ooo@21omooo03?
ood0POn1oh7oROom0<ooo@21on;oo@3?ood0POoOoo`0coom0<7o06R1oh7oPOo9
ood0coom087oh_om0<ooo@21omooo03?ood0POn1oh7oROom0<ooo@21on;oo@3?
ood0POoOoo`0coom087oPOn1ohWoo@3?ood0POoRood0coom087ogool0<ooo@31
o`1XPOn1oh7obOom0<ooo@21on;oo@3?ood0POoOoo`0coom087oPOn1ohWoo@3?
ood0POoRood0coom087ogool0<ooo@21oh7oPOn9ood0coom087oh_om0<ooo@21
omooo03?ood0`Ol0J87oPOn1olWoo@3?ood0POoRood0coom087ogool0<ooo@21
oh7oPOn9ood0coom087oh_om0<ooo@21omooo03?ood0POn1oh7oROom0<ooo@21
on;oo@3?ood0POoOoo`0coom0<7o06R1oh7oPOo:oo`0cool087oi?ol0<ooo@21
on3oo03>ood0POn1oh7oR_ol0<ooo021onCoo03?ood0POoPoo`0c_om087oPOn1
oh[oo03?oo`0POoToo`0coom087oh?ol0<koo@31o`1XPOn1oh7ob_om0<goo@21
onCoo@3=ood0POoQoo`0cOom087oPOn1oh_oo@3=ood0POoTood0cOom087ohOol
0<goo@21oh7oPOn;ood0cOom087oi?om0<goo@21on7oo03=ood0`_l0J87oPOn1
ol[oo@3=ood0POoTood0cOom087ohOol0<goo@21oh7oPOn;ood0cOom087oi?om
0<goo@21on7oo03=ood0POn1oh7oRoom0<goo@21onCoo@3=ood0POoQoo`0cOom
0<;o06R1oh7oPOo:ood0cOom087oi?om0<goo@21on7oo03=ood0POn1oh7oRoom
0<goo@21onCoo@3=ood0POoQoo`0cOom087oPOn1oh_oo@3=ood0POoTood0cOom
087ohOol0<goo@32o`1XPOn1oh7ob_om0<goo@21onCoo@3=ood0POoQood0c?om
087oPOn1oh_oo@3=ood0POoTood0cOom087ohOom0<coo@21oh7oPOn;ood0cOom
087oi?om0<goo@21on7oo@3<ood0`_l0J87oPOn1ol_oo03<ood0POoVoo`0cOom
087oh_ol0<coo@21oh7oPOn<oo`0c?om087oi_ol0<goo@21on;oo03<ood0POn1
oh7oS?ol0<coo@21onKoo03=ood0POoRoo`0c?om0<;o06R1oh7oPOo;ood0boom
087oi_om0<coo@21on;oo03<ood0POn1oh7oS?om0<_oo@21onKoo@3<ood0POoR
oo`0c?om087oPOn1ohcoo@3;ood0POoVood0c?om087oh_ol0<coo@32o`1XPOn1
oh7oboom0<_oo@21onKoo@3<oo`0POoSoo`0c?ol087oPOn1ohgoo@3;ood0POoV
ood0c?ol087ohool0<coo021oh7oPOn=ood0boom087oi_om0<coo021on?oo03<
oo`0`ol0J87oPOn1ol_oo@3;ood0POoVood0boom087ohoom0<[oo@21oh7oPOn=
ood0boom087oi_om0<_oo@21on?oo@3:ood0POn1oh7oSOom0<_oo@21onKoo@3;
ood0POoSood0b_om0<?o06R1oh7oPOo<oo`0boom087oiool0<_oo@21onCoo03:
ood0POn1oh7oS_ol0<_oo@21onOoo03;ood0POoToo`0b_om087oPOn1ohkoo03;
ood0POoWoo`0boom087oi?ol0<[oo@33o`1XPOn1oh7oc?om0<Woo@21onSoo@3:
ood0POoToo`0b_om087oPOn1ohkoo@39ood0POoXood0b_om087oi?ol0<[oo@21
oh7oPOn>ood0bOom087oj?om0<[oo@21onCoo03:ood0`ol0J87oPOn1olcoo@39
ood0POoXood0b_om087oi?ol0<[oo@21oh7oPOn>ood0bOom087oj?om0<[oo@21
onCoo03:ood0POn1oh7oS_om0<Woo@21onSoo@3:ood0POoToo`0b_om0<?o06R1
oh7oPOo<ood0bOom087oj?om0<[oo@21onCoo@39ood0POn1oh7oS_om0<Woo@21
onSoo@3:ood0POoTood0bOom087oPOn1ohkoo@39ood0POoXood0b_om087oi?om
0<Woo@33o`1XPOn1oh7oc?om0<Woo@21onSoo@3:ood0POoTood0bOom087oPOn1
ohkoo@39ood0POoXood0b_om087oi?om0<Woo@21oh7oPOn>ood0bOom087oj?om
0<[oo@21onCoo@39ood0`ol0J87oPOn1olgoo039ood0POoYoo`0bOom087oi_ol
0<Soo@21oh7oPOn@oo`0bOom087ojOol0<Woo@21onKoo038ood0POn1oh7oT?ol
0<Woo@21onWoo039ood0POoVoo`0b?om0<Co06R1oh7oPOo=ood0aoom087oj_om
0<Soo@21onKoo038ood0POn1oh7oT?om0<Ooo@21on[oo@38ood0POoVoo`0b?om
087oPOn1oi3oo@37ood0POoZood0b?om087oi_ol0<Soo@34o`1XPOn1oh7ocOom
0<Ooo@21on[oo@38ood0POoVood0aoom087oPOn1oi3oo@37ood0POoZood0b?om
087oi_om0<Ooo@21oh7oPOn@ood0aoom087oj_om0<Soo@21onKoo@37ood0a?l0
J87oPOn1olgoo@37ood0POoZood0b?om087oi_om0<Ooo@21oh7oPOn@ood0aoom
087oj_om0<Soo@21onKoo@37ood0POn1oh7oT?om0<Ooo@21on[oo@38ood0POoV
ood0aoom0<Co06R1oh7oPOo>oo`0aoom087ojool0<Soo@21onKoo@37ood0POn1
oh7oTOol0<Ooo@21on_oo038ood0POoVood0aoom087oPOn1oi7oo037ood0POo[
oo`0b?om087oi_om0<Ooo@34o`1XPOn1oh7oc_om0<Koo@21on_oo@37oo`0POoX
oo`0aool087oPOn1oi;oo@36ood0POo[ood0aool087oj?ol0<Ooo021oh7oPOnB
ood0a_om087ojoom0<Ooo021onSoo037oo`0aOl0J87oPOn1olkoo@36oo`0POo/
ood0a_om087oj?om0<Goo@21oh7oPOnBood0a_ol087ok?om0<Koo@21onSoo@35
ood0POn1oh7oT_om0<Koo021oncoo@36ood0POoXood0aOom0<Go06R1oh7oPOo>
ood0aOom087ok?om0<Koo@21onSoo@35ood0POn1oh7oT_om0<Goo@21oncoo@36
ood0POoXood0aOom087oPOn1oi;oo@35ood0POo/ood0a_om087oj?om0<Goo@35
o`1XPOn1oh7ocool0<Goo@21ongoo036ood0POoXood0aOom087oPOn1oi?oo035
ood0POo]oo`0a_om087oj?om0<Goo@21oh7oPOnCoo`0aOom087okOol0<Koo@21
onSoo@35ood0aOl0J87oPOn1olooo@34ood0POo]ood0aOol087oj_ol0<Goo021
oh7oPOnDood0a?om087okOom0<Goo021on[oo035oo`0POn1oh7oU?om0<Coo@21
ongoo@35oo`0POoZoo`0aOol0<Ko06R1oh7oPOo?ood0a?om087okOom0<Coo@21
on[oo@33ood0POn1oh7oU?om0<Coo@21ongoo@34ood0POoZood0`oom087oPOn1
oiCoo@34ood0POo]ood0a?om087oj_om0<?oo@36o`1XPOn1oh7od?ol0<Coo021
onooo034ood0POoZood0`oom087oPOn1oiGoo034oo`0POo_oo`0a?om087oj_om
0<?oo@21oh7oPOnEoo`0a?ol087okool0<Coo@21on[oo@33ood0a_l0J87oPOn1
om3oo@32ood0POo_ood0`oom087oj_om0<?oo@21oh7oPOnEood0`_om087okoom
0<?oo@21on[oo@33ood0POn1oh7oUOom0<;oo@21onooo@33ood0POoZood0`oom
0<Ko06R1oh7oPOo@ood0`_om087okoom0<?oo021oncoo033oo`0POn1oh7oU_om
0<;oo@21onooo@33oo`0POo/oo`0`ool087oPOn1oiKoo@32ood0POo_ood0`ool
087ok?ol0<?oo037o`1XPOn1oh7odOol0<;oo@21oo3oo032ood0POo/ood0`Oom
087oPOn1oiOoo032ood0POo`oo`0`_om087ok?om0<7oo@21oh7oPOnGoo`0`_om
087ol?ol0<;oo@21oncoo@31ood0aol0J87oPOn1om7oo@31ood0POo`ood0`Oom
087ok?om0<7oo@21oh7oPOnGood0`Oom087ol?om0<7oo@21oncoo@31ood0POn1
oh7oUoom0<7oo@21oo3oo@31ood0POo/ood0`Oom0<Oo06R1oh7oPOoAood0`Oom
087ol?om0<7oo@21oncoo@31ood0POn1oh7oUoom0<7oo@21oo3oo@31ood0POo/
ood0`Oom087oPOn1oiOoo@31ood0POo`ood0`Oom087ok?om0<7oo@37o`1XPOn1
oh7odOom0<7oo021oo7oo@31oo`0POo^oo`0`Ool087oPOn1oiSoo@31oo`0POoa
ood0`Ool087ok_ol0<7oo021oh7oPOnHood0`Ool087olOom0<7oo021onkoo031
oo`0b?l0J87oPOn1om;oo030ood0POoboo`0`?om087ok_om0;ooo@21oh7oPOnI
oo`0`?om087ol_ol0<3oo@21onkoo@2oood0POn1oh7oVOol0<3oo@21oo;oo030
ood0POo^ood0_oom0<So06R1oh7oPOoBood0_oom087ol_om0;ooo@21onkoo@2o
ood0POn1oh7oVOom0;ooo@21oo;oo@2oood0POo^ood0_oom087oPOn1oiWoo@2o
ood0POobood0_oom087ok_om0;ooo@38o`1XPOn1oh7odool0;ooo@21oo?oo02o
ood0POo_oo`0_oom087oPOn1oi[oo02oood0POocoo`0_oom087okool0;ooo@21
oh7oPOnJoo`0_oom087olool0;ooo@21onooo02oood0b?l0J87oPOn1om?oo02o
oo`0POodoo`0_ool087ol?ol0;ooo021oh7oPOnKoo`0_ool087om?ol0;ooo021
oo3oo02ooo`0POn1oh7oVool0;ooo021ooCoo02ooo`0POo`oo`0_ool0<Wo06R1
oh7oPOoCood0_Oom087omOol0;goo@21oo7oo02mood0POn1oh7oVoom0;goo@21
ooGoo02mood0POoaoo`0_Oom087oPOn1oi_oo@2mood0POoeoo`0_Oom087olOol
0;goo@39o`1XPOn1oh7oe?ol0;goo@21ooGoo02mood0POoaoo`0_Oom087oPOn1
oicoo02mood0POoeoo`0_Oom087olOol0;goo@21oh7oPOnLoo`0_Oom087omOol
0;goo@21oo7oo02mood0bOl0J87oPOn1omCoo@2loo`0POogoo`0_?ol087olool
0;coo021oh7oPOnMood0_?ol087omool0;coo021oo?oo02loo`0POn1oh7oWOom
0;coo021ooOoo02loo`0POocoo`0_?ol0<[o06R1oh7oPOoDood0^oom087omool
0;_oo@21oo?oo02kood0POn1oh7oWOom0;_oo@21ooOoo02kood0POocoo`0^oom
087oPOn1oigoo@2kood0POogoo`0^oom087olool0;_oo@3:o`1XPOn1oh7oeOol
0;_oo@21ooOoo@2jood0POocood0^_om087oPOn1oikoo02kood0POogood0^_om
087oloom0;[oo@21oh7oPOnNoo`0^oom087omoom0;[oo@21oo?oo@2jood0b_l0
J87oPOn1omGoo@2joo`0POoioo`0^_ol087omOol0;[oo021oh7oPOnOood0^_ol
087onOol0;[oo021ooGoo02joo`0POn1oh7oWoom0;[oo021ooWoo02joo`0POoe
oo`0^_ol0<_o06R1oh7oPOoFoo`0^Oom087onOom0;Soo@21ooGoo@2hood0POn1
oh7oX?ol0;Woo@21ooWoo@2hood0POoeood0^?om087oPOn1oj3oo02iood0POoi
ood0^?om087omOom0;Soo@3;o`1XPOn1oh7oe_ol0;Woo@21oo[oo02hood0POof
oo`0^?om087oPOn1oj3oo02iood0POojoo`0^?om087om_ol0;Soo@21oh7oPOnP
oo`0^Oom087on_ol0;Soo@21ooKoo02hood0bol0J87oPOn1omKoo@2hood0POoj
ood0]oom087om_om0;Ooo@21oh7oPOnPood0^?om087on_om0;Ooo@21ooKoo@2g
ood0POn1oh7oX?om0;Soo@21oo[oo@2good0POofood0]oom0<_o06R1oh7oPOoG
oo`0^?ol087oo?ol0;Ooo021ooSoo02goo`0POn1oh7oX_ol0;Soo021oocoo02g
oo`0POohoo`0]ool087oPOn1oj;oo02hoo`0POoloo`0]ool087on?ol0;Ooo03<
o`1XPOn1oh7of?ol0;Koo@21oocoo@2eood0POoioo`0]Oom087oPOn1oj?oo02f
ood0POolood0]Oom087onOol0;Goo@21oh7oPOnSoo`0]_om087oo?om0;Goo@21
ooWoo02eood0c?l0J87oPOn1omSoo02eood0POomood0]Ool087on_ol0;Goo021
oh7oPOnToo`0]Oom087ooOom0;Goo021oo[oo02eoo`0POn1oh7oY?ol0;Goo@21
oogoo@2eoo`0POojoo`0]Ool0<go06R1oh7oPOoIoo/0]Oom087oo_ol0;Goo021
oo_on`2eoo`0POn1oh7oYOok0;Goo@21ookoo02eoo`0POokoo/0]Ool087oPOn1
ojGon`2eood0POonoo`0]Ool087onook0;Goo03=o`1[POn1oh7ofOol0;Coo021
o`7oood0/ool087oo?ol0;?oo021oh7oPOnVoo`0]?ol087o0Oooo@2coo`0POol
oo`0/ool087oPOn1ojKoo02doo`0POl1ooom0;?oo021oocoo02coo`0c_l0J87o
POn1om[on`2cood0POl0oo`0/ool087ooOok0;?oo021oh7oPOnWoo/0/oom087o
0?ol0;?oo021oogon`2coo`0POn1oh7oYook0;?oo@21o`3oo02coo`0POomoo/0
/ool0<ko06:1oh7oPOoJoo`0/_ol087oo@2aoo`0POonoo`0/Ool087oPOn1ojSo
o02boo`0POom0;7oo021ookoo02aoo`0POn1oh7oZ?ol0;;oo021ood0/Ool087o
o_ol0;7oo03?o`1UPOn1oh7ofool0;3oo@22oo`0/Ool087o0Ooon`2aoo`0POn1
oh7oZOol0;3oo@22oo`0/Ool087o0Ooon`2aoo`0POn1oh7oZOol0;3oo@22oo`0
/Ool087o0Ooon`2aoo`0col0HX7oPOn1om_oo02`oo`0Poom0:ooo021o`3oo02_
oo`0POn1oh7oZ_ol0;3oo023ood0[ool087o0?ol0:ooo021oh7oPOnZoo`0/?ol
08?oo@2_oo`0POl0oo`0[ool0=3o05b1oh7oPOoLoo`0[ool08Coo@2^oo`0POol
0:koo021oh7oPOn[oo`0[ool08Coo@2^oo`0POol0:koo021oh7oPOn[oo`0[ool
08Coo@2^oo`0POol0:koo03@o`1LPOn1oh7og?om0:goo025ood0[Ool08;oo02]
oo`0POn1oh7o[?om0:goo025ood0[Ool08;oo02]oo`0POn1oh7o[?om0:goo025
ood0[Ool08;oo02]oo`0dOl0G87oPOn1omgoo@2/oo`0Q_om0:coo023oo`0[?ol
087oPOn1ojgoo@2/oo`0Q_om0:coo023oo`0[?ol087oPOn1ojgoo@2/oo`0Q_om
0:coo023oo`0[?ol0=7o05b1oh7oPOoNoo`0Zool08Soo02[ood0Pool0:_oo@21
oh7oPOn^oo`0Zool08Soo02[ood0Pool0:_oo@21oh7oPOn^oo`0Zool08Soo02[
ood0Pool0:_oo@3Ao`1LPOn1oh7ogool0:[on`2:oo`0Z_ol08Goo02Zoo`0POn1
oh7o/?ol0:[on`2:oo`0Z_ol08Goo02Zoo`0POn1oh7o/?ol0:[on`2:oo`0Z_ol
08Goo02Zoo`0d_l0G87oPOn1on3oo02Xoo`0Rool0:Soo027oo`0Z?om087oPOn1
ok7oo02Xoo`0Rool0:Soo027oo`0Z?om087oPOn1ok7oo02Xoo`0Rool0:Soo027
oo`0Z?om0=;o05b1oh7oPOoQoo/0Z?ok08goo02Woo/0ROol0:Ooo021oh7oPOnc
oo/0Z?ok08goo02Woo/0ROol0:Ooo021oh7oPOncoo/0Z?ok08goo02Woo/0ROol
0:Ooo03Co`1LPOn1oh7oh_ok0:Kon`2?oo`0YOol08[oo02Uoo`0POn1oh7o]Ook
0:Kon`2?oo`0YOol08[oo02Uoo`0POn1oh7o]Ook0:Kon`2?oo`0YOol08[oo02U
oo`0e?l0G87oPOn1on?on`2Too`0T?ok0:Coo02<oo/0Y?om087oPOn1okKon`2T
oo`0T?ok0:Coo02<oo/0Y?om087oPOn1okKon`2Too`0T?ok0:Coo02<oo/0Y?om
0=Co05b1oh7oPOoToo/0Xook09;on`2Soo/0S_ok0:?oo021oh7oPOnhoo/0Xook
09;on`2Soo/0S_ok0:?oo021oh7oPOnhoo/0Xook09;on`2Soo/0S_ok0:?oo03E
o`1LPOn1oh7oiOoj0:;on`2Doo/0XOok097onP2Qoo/0POn1oh7o^ooj0:;on`2D
oo/0XOok097onP2Qoo/0POn1oh7o^ooj0:;on`2Doo/0XOok097onP2Qoo/0eol0
G87oPOn1onKonP2QooT0V?oj0:3onP2CooX0X?oj087oPOn1okgonP2QooT0V?oj
0:3onP2CooX0X?oj087oPOn1okgonP2QooT0V?oj0:3onP2CooX0X?oj0=So05b1
oh7oPOoXooX0WOoj09_on@2MooX0Uooi09kon@21oh7oPOo1ooX0WOoj09_on@2M
ooX0Uooi09kon@21oh7oPOo1ooX0WOoj09_on@2MooX0Uooi09kon@3Jo`1LPOn1
oh7oj_oi09_onP2NooT0V_oj09[on@2JooX0POn1oh7oa?oi09_onP2NooT0V_oj
09[on@2JooX0POn1oh7oa?oi09_onP2NooT0V_oj09[on@2JooX0fol0G87oPOn1
oo;ol`2GooL0Z_oc09Oom`2Voo<0V?of087oPOn1om7ol`2GooL0Z_oc09Oom`2V
oo<0V?of087oPOn1om7ol`2GooL0Z_oc09Oom`2Voo<0V?of0>3o05b1oh7oPOob
oo@0UOoh0:[om@2DooP0Y_oe09Con021oh7oPOoAoo@0UOoh0:[om@2DooP0Y_oe
09Con021oh7oPOoAoo@0UOoh0:[om@2DooP0Y_oe09Con03Po`1LPOn1oh7olOog
09;on@2YooL0T_oi0:KomP2BooT0POn1oh7od?og09;on@2YooL0T_oi0:KomP2B
ooT0POn1oh7od?og09;on@2YooL0T_oi0:KomP2BooT0h?l0G87oPOn1oo7on@2?
oo/0Z?oi08oon`2UooT0S_ok087oPOn1oloon@2?oo/0Z?oi08oon`2UooT0S_ok
087oPOn1oloon@2?oo/0Z?oi08oon`2UooT0S_ok0=oo03J1oh7ohOn10840P@21
0840^@21oh7ohOn10840P@210840^@21oh7ohOn10840P@210840^@00=X7oPOoQ
oh40P@210840P@2i087oPOoQoh40P@210840P@2i087oPOoQoh40P@210840P@2i
000fPOn1on7oP@210840P@210;T0POn1on7oP@210840P@210;T0POn1on7oP@21
0840P@210;T003J1oh7ohOn10840P@210840^@21oh7ohOn10840P@210840^@21
oh7ohOn10840P@210840^@00<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0
<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9
o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`12POn1
oh7oPOn1omKoo021ok7oo021oh7oPOn1oh7oPOocoo`0POnaoo`0POn1oh7oPOn1
oh7olool087o/Ool09ko04:1oh7oPOn1oh7oe_ol087o/Ool087oPOn1oh7oPOn1
oo?oo021ok7oo021oh7oPOn1oh7oPOocoo`0POnaoo`0W_l0@X7oPOn1oh7oPOoF
oo`0POnaoo`0POn1oh7oPOn1oh7olool087o/Ool087oPOn1oh7oPOn1oo?oo021
ok7oo02No`12POn1oh7oPOn1omKoo021ok7oo021oh7oPOn1oh7oPOocoo`0POna
oo`0POn1oh7oPOn1oh7olool087o/Ool09ko04:1oh7oPOn1oh7oe_ol087o/Ool
087oPOn1oh7oPOn1oo?oo021ok7oo021oh7oPOn1oh7oPOocoo`0POnaoo`0W_l0
@X7oPOn1oh7oPOoFoo`0POnaoo`0POn1oh7oPOn1oh7olool087o/Ool087oPOn1
oh7oPOn1oo?oo021ok7oo02No`12POn1oh7oPOn1om_ok`21okkok`21oh7oPOn1
oh7oPOl0onl0POnnonl0POn1oh7oPOn1oh7o0?o_087o__o_0:Ko04:1oh7oPOn1
oh7ofoo_087o__o_087oPOn1oh7oPOn1o`3ok`21okkok`21oh7oPOn1oh7oPOl0
onl0POnnonl0Y_l0@X7oPOn1oh7oPOoKonl0POnnonl0POn1oh7oPOn1oh7o0?o_
087o__o_087oPOn1oh7oPOn1o`3ok`21okkok`2Vo`12POn1oh7oPOn1om_ok`21
okkok`21oh7oPOn1oh7oPOl0onl0POnnonl0POn1oh7oPOn1oh7o0?o_087o__o_
0:Ko04:1oh7oPOn1oh7oe_ol087o/Ool087oPOn1oh7oPOn1oo?oo021ok7oo021
oh7oPOn1oh7oPOocoo`0POnaoo`0W_l0@X7oPOn1oh7oPOoFoo`0POnaoo`0POn1
oh7oPOn1oh7olool087o/Ool087oPOn1oh7oPOn1oo?oo021ok7oo02No`12POn1
oh7oPOn1omKoo021ok7oo021oh7oPOn1oh7oPOocoo`0POnaoo`0POn1oh7oPOn1
oh7olool087o/Ool09ko04:1oh7oPOn1oh7oe_ol087o/Ool087oPOn1oh7oPOn1
oo?oo021ok7oo021oh7oPOn1oh7oPOocoo`0POnaoo`0W_l0@X7oPOn1oh7oPOoF
oo`0POnaoo`0POn1oh7oPOn1oh7olool087o/Ool087oPOn1oh7oPOn1oo?oo021
ok7oo02No`12POn1oh7oPOn1omKoo021ok7oo021oh7oPOn1oh7oPOocoo`0POna
oo`0POn1oh7oPOn1oh7olool087o/Ool09ko04:1oh7oPOn1oh7oe_ol087o/Ool
087oPOn1oh7oPOn1oo?oo021ok7oo021oh7oPOn1oh7oPOocoo`0POnaoo`0W_l0
@X7oPOn1oh7oPOoFoo`0POnaoo`0POn1oh7oPOn1oh7olool087o/Ool087oPOn1
oh7oPOn1oo?oo021ok7oo02No`12POn1oh7oPOn1omKoo021ok7oo021oh7oPOn1
oh7oPOocoo`0POnaoo`0POn1oh7oPOn1oh7olool087o/Ool09ko04:1oh7oPOn1
oh7oe_ol087o/Ool087oPOn1oh7oPOn1oo?oo021ok7oo021oh7oPOn1oh7oPOoc
oo`0POnaoo`0W_l0EX7oPOn1oh7oPOoFoo`0jool087oc?ol0>coo021oh7oPOn1
oh7oSOol0>_oo021olcoo03/oo`0POn1oh7oPOn1ohgoo03[oo`0POo<oo`0k?ol
0;So06:1oh7oPOn1oh7oe_ol0>_oo021olcoo03/oo`0cook087oPOn1oh7oPOo5
oo`0jool087oc?ol0>coo03?oo/0POn1oh7oPOn1olGoo03[oo`0POo<oo`0k?ol
0<oon`3`o`1RPOn1oh7oPOn1omKoo03[oo`0POo<oo`0k?ol0=;on021oh7oPOn1
oh7oaOol0>_oo021olcoo03/oo`0d_oh087oPOn1oh7oPOo5oo`0jool087oc?ol
0>coo03BooP0l?l0HX7oPOn1oh7oPOoFoo`0jool087oc?ol0>coo03EooD0POn1
oh7oPOn1olGoo03[oo`0POo<oo`0k?ol0=Gom@21oh7oPOn1oh7oaOol0>_oo021
olcoo03/oo`0eOoe0?3o06:1oh7oPOn1oh7oe_ol0>_oo021olcoo03/oo`0e_od
087oPOn1oh7oPOo5oo`0jool087oc?ol0>coo03Foo@0POn1oh7oPOn1olGoo03[
oo`0POo<oo`0k?ol0=Kom03`o`1:POn1oh7oPOn1omKoo021ok7oo02loo@0POn1
oh7oPOn1olGoo021ok7oo02loo@0POn1oh7oPOn1olGoo021ok7oo02loo@0l?l0
BX7oPOn1oh7oPOoFoo`0POnaoo`0_?od087oPOn1oh7oPOo5oo`0POnaoo`0_?od
087oPOn1oh7oPOo5oo`0POnaoo`0_?od0?3o05J1oh7oPOn1oh7oe_ol087o/Ool
0;coo03noo`0POn1oh7oPOn1olGoo021ok7oo02loo`0o_ol087oPOn1oh7oPOo5
oo`0POnaoo`0_?ol0?koo03`o`1IPOn1oh7oPOn1omKon`21ok;on`2mo`400?_o
o021oh7oPOn1oh7oaOok087o/_ok0;go0@00nool087oPOn1oh7oPOo5oo/0POnb
oo/0_Ol1003koo`0l?l0BX7oPOn1oh7oPOoEoo`0POnaoo`0]Ool087oPOn1oh7o
POo4oo`0POnaoo`0]Ool087oPOn1oh7oPOo4oo`0POnaoo`0]Ool0?3o06:1oh7o
POn1oh7oeOoj0?co0021okWonP3lo`00_Ool087oPOn1oh7oPOo4ooX0o?l0087o
^Ooj0?co002moo`0POn1oh7oPOn1olConP3lo`00POniooX0o?l00;goo03`o`1^
POn1oh7oPOn1omGom03doo`0POo;oo@0mOol0>ooo@3Too`0POn1oh7oPOn1olCo
m03doo`0POo;oo@0mOol0>ooo@3Too`0POn1oh7oPOn1olCom03doo`0POo;oo@0
mOol0>ooo@3Too`0l?l0KX7oPOn1oh7oPOoDooD0m?ol087ob_oe0?Goo03_ood0
i?ol087oPOn1oh7oPOo3ooD0m?ol087ob_oe0?Goo03_ood0i?ol087oPOn1oh7o
POo3ooD0m?ol087ob_oe0?Goo03_ood0i?ol0?3o06j1oh7oPOn1oh7odoof0?Co
o021olWomP3eoo`0koom0>Coo021oh7oPOn1oh7o`_of0?Coo021olWomP3eoo`0
koom0>Coo021oh7oPOn1oh7o`_of0?Coo021olWomP3eoo`0koom0>Coo03`o`1^
POn1oh7oPOn1om3on`3boo`0POo6oo/0lool0>ooo@3Too`0POn1oh7oPOn1okoo
n`3boo`0POo6oo/0lool0>ooo@3Too`0POn1oh7oPOn1okoon`3boo`0POo6oo/0
lool0>ooo@3Too`0l?l0EX7oPOn1oh7oPOnkoo`0POnboo`0koom0>Coo021oh7o
POn1oh7oZ_ol087o/_ol0>ooo@3Too`0POn1oh7oPOn1oj[oo021ok;oo03_ood0
i?ol0?3o05J1oh7oPOn1oh7o^ool087o/_ol0>ooo@3Too`0POn1oh7oPOn1oj[o
o021ok;oo03_ood0i?ol087oPOn1oh7oPOnZoo`0POnboo`0koom0>Coo03`o`1F
POn1oh7oPOn1ok_oo021ok;oo03_ood0i?ol087oPOn1oh7oPOnZoo`0POnboo`0
koom0>Coo021oh7oPOn1oh7oZ_ol087o/_ol0>ooo@3Too`0l?l0EX7oPOn1oh7o
POnkoo`0POnboo`0koom0>Coo021oh7oPOn1oh7oZ_ol087o/_ol0>ooo@3Too`0
POn1oh7oPOn1oj[oo021ok;oo03_ood0i?ol0?3o05J1oh7oPOn1oh7o^ool087o
/_ol0>ooo@3Too`0POn1oh7oPOn1oj[oo021ok;oo03_ood0i?ol087oPOn1oh7o
POnZoo`0POnboo`0koom0>Coo03`o`1FPOn1oh7oPOn1ok_oo021ok;oo03_ood0
i?ol087oPOn1oh7oPOnZoo`0POnboo`0koom0>Coo021oh7oPOn1oh7oZ_ol087o
/_ol0>ooo@3Too`0l?l0EX7oPOn1oh7oPOnkoo`0POnboo`0koom0>Coo021oh7o
POn1oh7oZ_ol087o/_ol0>ooo@3Too`0POn1oh7oPOn1oj[oo021ok;oo03_ood0
i?ol0?3o05J1oh7oPOn1oh7o^ool087o/_ol0>ooo@3Too`0POn1oh7oPOn1oj[o
o021ok;oo03_ood0i?ol087oPOn1oh7oPOnZoo`0POnboo`0koom0>Coo03`o`1F
POn1oh7oPOn1ok_oo021ok;oo03konD0l?ol087oPOn1oh7oPOnZoo`0POnboo`0
nooU0?3oo021oh7oPOn1oh7oZ_ol087o/_ol0?_oi@3`oo`0l?l0EX7oPOn1oh7o
POnkoo`0POnboo`0nooU0?3oo021oh7oPOn1oh7oZ_ol087o/_ol0?_oi@3`oo`0
POn1oh7oPOn1oj[oo021ok;oo03konD0l?ol0?3o05J1oh7oPOn1oh7o^ool087o
/_ol0?_oi@3`oo`0POn1oh7oPOn1oj[oo021ok;oo03konD0l?ol087oPOn1oh7o
POnZoo`0POnboo`0nooU0?3oo03`o`1FPOn1oh7oPOn1ok_oo021ok;oo03konD0
l?ol087oPOn1oh7oPOnZoo`0POnboo`0nooU0?3oo021oh7oPOn1oh7oZ_ol087o
/_ol0?_oi@3`oo`0l?l0EX7oPOn1oh7oPOnkoo`0POnboo`0koom0>Coo021oh7o
POn1oh7oZ_ol087o/_ol0>ooo@3Too`0POn1oh7oPOn1oj[oo021ok;oo03_ood0
i?ol0?3o05J1oh7oPOn1oh7o^ool087o/_ol0>ooo@3Too`0POn1oh7oPOn1oj[o
o021ok;oo03_ood0i?ol087oPOn1oh7oPOnZoo`0POnboo`0koom0>Coo03`o`1F
POn1oh7oPOn1ok_oo021ok;oo03_ood0i?ol087oPOn1oh7oPOnZoo`0POnboo`0
koom0>Coo021oh7oPOn1oh7oZ_ol087o/_ol0>ooo@3Too`0l?l0EX7oPOn1oh7o
POnkoo`0POnboo`0koom0>Coo021oh7oPOn1oh7oZ_ol087o/_ol0>ooo@3Too`0
POn1oh7oPOn1oj[oo021ok;oo03_ood0i?ol0?3o05J1oh7oPOn1oh7o^ool087o
/_ol0>ooo@3Too`0POn1oh7oPOn1oj[oo021ok;oo03_ood0i?ol087oPOn1oh7o
POnZoo`0POnboo`0koom0>Coo03`o`1FPOn1oh7oPOn1ok_oo021ok;oo03_ood0
i?ol087oPOn1oh7oPOnZoo`0POnboo`0koom0>Coo021oh7oPOn1oh7oZ_ol087o
/_ol0>ooo@3Too`0l?l0EX7oPOn1oh7oPOnkoo`0POnboo`0koom0>Coo021oh7o
POn1oh7oZ_ol087o/_ol0>ooo@3Too`0POn1oh7oPOn1oj[oo021ok;oo03_ood0
i?ol0?3o05J1oh7oPOn1oh7o^ool087o/_ol0>ooo@3Too`0POn1oh7oPOn1oj[o
o021ok;oo03_ood0i?ol087oPOn1oh7oPOnZoo`0POnboo`0koom0>Coo03`o`1F
POn1oh7oPOn1ok_oo021ok;oo03_ood0i?ol087oPOn1oh7oPOnZoo`0POnboo`0
koom0>Coo021oh7oPOn1oh7oZ_ol087o/_ol0>ooo@3Too`0l?l0EX7oPOn1oh7o
POnkoo`0POnboo`0koom0>Coo021oh7oPOn1oh7oZ_ol087o/_ol0>ooo@3Too`0
POn1oh7oPOn1oj[oo021ok;oo03_ood0i?ol0?3o05J1oh7oPOn1oh7o^ool087o
/_ol0>ooo@3Too`0POn1oh7oPOn1oj[oo021ok;oo03_ood0i?ol087oPOn1oh7o
POnZoo`0POnboo`0koom0>Coo03`o`1FPOn1oh7oPOn1ok_oo021ok;oo03_ood0
i?ol087oPOn1oh7oPOnZoo`0POnboo`0koom0>Coo021oh7oPOn1oh7oZ_ol087o
/_ol0>ooo@3Too`0l?l0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0B87oPOn1ojooo@21ojSo
o@21ojSoo@21oh7oPOn1omOoo@21ojSoo@21ojSoo@21oh7oPOn1omOoo@21ojSo
o@21ojSoo@2Yo`18POn1oh7o[oom087oZ?om087oZ?om087oPOn1oh7oeoom087o
Z?om087oZ?om087oPOn1oh7oeoom087oZ?om087oZ?om0:Wo04R1oh7oPOn_ood0
POnXood0POnXood0POn1oh7oPOoGood0POnXood0POnXood0POn1oh7oPOoGood0
POnXood0POnXood0ZOl0B87oPOn1ojooo@21ojSoo@21ojSoo@21oh7oPOn1omOo
o@21ojSoo@21ojSoo@21oh7oPOn1omOoo@21ojSoo@21ojSoo@2Yo`0`POn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo0321oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7obOl0<87o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo
03R1oh7oPOn_o`00POn1oh7oPOn1oh7oPOnJo`00POn1oh7oPOn1oh7oPOnJo`00
POn1oh7oPOo/o`0hPOn1oh7o/Ook087oPOn1oh7oPOn1oh7oWook087oPOn1oh7o
POn1oh7oWook087oPOn1oh7okol0>87oPOn1okComP21oh7oPOn1oh7oPOn1ojCo
mP21oh7oPOn1oh7oPOn1ojComP21oh7oPOn1oo7o03R1oh7oPOnfoo80POn1oh7o
POn1oh7oPOnXoo80POn1oh7oPOn1oh7oPOnXoo80POn1oh7oPOoco`0hPOn1oh7o
]ooa087oPOn1oh7oPOn1oh7oZOoa087oPOn1oh7oPOn1oh7oZOoa087oPOn1oh7o
lol0A87oPOn1okSon@3nooX0POn1oh7oPOn1oh7oPOn[ooT0o_oj087oPOn1oh7o
POn1oh7oZooi0?konP21oh7oPOn1ooCo04B1oh7oPOniooX0n_ok087oPOn1oh7o
POn1oh7o[Ooj0?[on`21oh7oPOn1oh7oPOn1ojgonP3joo/0POn1oh7oPOoeo`14
POn1oh7o^Ool0?Koo021oh7oPOn1oh7oPOn1ojkoo03foo`0POn1oh7oPOn1oh7o
POn^oo`0m_ol087oPOn1oh7om_l0A87oPOn1ok[oo03doo`0POn1oh7oPOn1oh7o
POn`oo`0m?ol087oPOn1oh7oPOn1oh7o/?ol0?Coo021oh7oPOn1ooOo04B1oh7o
POnkoo`0lool087oPOn1oh7oPOn1oh7o/Ool0??oo021oh7oPOn1oh7oPOn1ok7o
o03coo`0POn1oh7oPOogo`14POn1oh7o_?ol0?7oo021oh7oPOn1oh7oPOn1ok?o
o03aoo`0POn1oh7oPOn1oh7oPOncoo`0lOol087oPOn1oh7on?l0A87oPOn1okgo
o03_oo/0POn1oh7oPOn1oh7oPOnfoo`0kook087oPOn1oh7oPOn1oh7o]_ol0>oo
n`21oh7oPOn1oo[o0621oh7oPOnmood0moom0?_oo021ok?oo@21ojSoo@21oh7o
POn1onGoo@3good0nool087o/oom087oZ?om087oPOn1oh7oiOom0?Ooo@3koo`0
POncood0POnXood0ZOl0H87oPOn1okkoo03good0nook087o]?om087oZ?om087o
POn1oh7oi_ol0?Ooo@3koo/0POndood0POnXood0POn1oh7oPOoVoo`0moom0?_o
n`21okCoo@21ojSoo@2Yo`1PPOn1oh7o__om0?Koo@3joo`0POndood0POnXood0
POn1oh7oPOoVood0m_om0?[oo021okCoo@21ojSoo@21oh7oPOn1onKoo@3food0
n_ol087o]?om087oZ?om0:Wo0621oh7oPOnooo`0m_om0?Woo021okGoo@21ojSo
o@21oh7oPOn1onOoo03food0nOol087o]Oom087oZ?om087oPOn1oh7oiool0?Ko
o@3ioo`0POneood0POnXood0ZOl0H87oPOn1okooo@3eood0nOol087o]Oom087o
Z?om087oPOn1oh7oioom0?Goo@3ioo`0POneood0POnXood0POn1oh7oPOoWood0
mOom0?Woo021okGoo@21ojSoo@2Yo`14POn1oh7o`?ol0>Soo@21oh7oPOn1oh7o
POn1ok_oo03Xood0POn1oh7oPOn1oh7oPOnkoo`0j?om087oPOn1oh7oo?l0A87o
POn1ol3oo@3Woo`0POn1oh7oPOn1oh7oPOnlood0iool087oPOn1oh7oPOn1oh7o
_?om0>Ooo021oh7oPOn1oogo04B1oh7oPOo1oo`0iool087oPOn1oh7oPOn1oh7o
_Ool0>Ooo021oh7oPOn1oh7oPOn1okgoo03Woo`0POn1oh7oPOomo`14POn1oh7o
`Oom0>Goo021oh7oPOn1oh7oPOn1okkoo@3Uoo`0POn1oh7oPOn1oh7oPOnnood0
iOol087oPOn1oh7oo_l0A87oPOn1ol;oo@3Too`0POn1oh7oPOn1oh7oPOnoood0
i?ol087oPOn1oh7oPOn1oh7o_oom0>Coo021oh7oPOn1ooko04B1oh7oPOo2ood0
hoom087oPOn1oh7oPOn1oh7o_oom0>?oo@21oh7oPOn1oh7oPOn1okooo@3Sood0
POn1oh7oPOono`15POn1oh7o`oom0>;oo021oh7oPOn1oh7oPOn1ol7oo@3Roo`0
POn1oh7oPOn1oh7oPOo1ood0h_ol087oPOn1oh7o0Ooo04F1oh7oPOo3ood0h_ol
087oPOn1oh7oPOn1oh7o`Oom0>;oo021oh7oPOn1oh7oPOn1ol7oo@3Roo`0POn1
oh7oPOl1ool0AH7oPOn1ol?ooP3Pood0POn1oh7oPOn1oh7oPOo1ooh0h?om087o
POn1oh7oPOn1oh7o`Oon0>3oo@21oh7oPOn1o`7oo`14POn1oh7oa?om0>3oo021
oh7oPOn1oh7oPOn1ol?oo@3Poo`0POn1oh7oPOn1oh7oPOo3ood0h?ol087oPOn1
oh7o0?l0A87oPOn1olCooP3Nood0POn1oh7oPOn1oh7oPOo3ooh0g_om087oPOn1
oh7oPOn1oh7o`oon0=koo@21oh7oPOn1o`3o04B1oh7oPOo5ood0g_om087oPOn1
oh7oPOn1oh7oa?om0=koo@21oh7oPOn1oh7oPOn1olCoo@3Nood0POn1oh7oPOl0
o`12POn1oh7oaOom0=koo021oh7oPOn1oh7oPOn1olGoo@3Noo`0POn1oh7oPOn1
oh7oPOo5ood0g_ol087oPOn1oh7o04:1oh7oPOo5ooh0gOol087oPOn1oh7oPOn1
oh7oaOon0=goo021oh7oPOn1oh7oPOn1olGooP3Moo`0POn1oh7oPOl0@X7oPOn1
olKoo@3Lood0POn1oh7oPOn1oh7oPOo6ood0g?om087oPOn1oh7oPOn1oh7oa_om
0=coo@21oh7oPOn1o`12POn1oh7oa_om0=coo@21oh7oPOn1oh7oPOn1olKoo@3L
ood0POn1oh7oPOn1oh7oPOo6ood0g?om087oPOn1oh7o0621oh7oPOo7ood0kOom
0??oo021ok_oo@21ojSoo@21oh7oPOn1onooo@3]ood0lool087o^oom087oZ?om
087oPOn1oh7okoom0>goo@3coo`0POnkood0POnXood0ZOl0H87oPOn1olOoo@3]
ood0l_om087o^oom087oZ?om087oPOn1oh7okoom0>goo@3bood0POnkood0POnX
ood0POn1oh7oPOo_ood0kOom0?;oo@21ok_oo@21ojSoo@2Yo`1PPOn1oh7ob?om
0>coo@3bood0POnkood0POnXood0POn1oh7oPOo`ood0k?om0?;oo@21ok_oo@21
ojSoo@21oh7oPOn1oo3oo@3/ood0l_om087o^oom087oZ?om0:Wo0621oh7oPOo8
ood0k?om0?;oo021okcoo@21ojSoo@21oh7oPOn1oo3oo@3/ood0l_ol087o_?om
087oZ?om087oPOn1oh7ol?om0>coo@3boo`0POnlood0POnXood0ZOl0@X7oPOn1
olSoo@3Ioo`0POn1oh7oPOn1oh7oPOo:ood0fOol087oPOn1oh7oPOn1oh7ob_om
0=Woo021oh7oPOn3o`12POn1oh7obOom0=Ooo@21oh7oPOn1oh7oPOn1ol_oo@3G
ood0POn1oh7oPOn1oh7oPOo;ood0eoom087oPOn1oh?o04:1oh7oPOo9ood0eoom
087oPOn1oh7oPOn1oh7oboom0=Ooo@21oh7oPOn1oh7oPOn1ol_oo@3Good0POn1
oh7oPol0@X7oPOn1ol[oo03Goo`0POn1oh7oPOn1oh7oPOo=oo`0eool087oPOn1
oh7oPOn1oh7ocOol0=Ooo021oh7oPOn4o`12POn1oh7ob_om0=Koo021oh7oPOn1
oh7oPOn1olgoo@3Foo`0POn1oh7oPOn1oh7oPOo=ood0e_ol087oPOn1ohCo04:1
oh7oPOo:ood0eOom087oPOn1oh7oPOn1oh7ocOom0=Goo@21oh7oPOn1oh7oPOn1
olgoo@3Eood0POn1oh7oQ?l0@X7oPOn1ol_oo03Eoo`0POn1oh7oPOn1oh7oPOo?
oo`0eOol087oPOn1oh7oPOn1oh7ocool0=Goo021oh7oPOn5o`12POn1oh7obool
0=Goo021oh7oPOn1oh7oPOn1olooo03Eoo`0POn1oh7oPOn1oh7oPOo?oo`0eOol
087oPOn1ohGo04:1oh7oPOo<oo`0doom087oPOn1oh7oPOn1oh7od?ol0=?oo@21
oh7oPOn1oh7oPOn1om3oo03Cood0POn1oh7oQOl0@X7oPOn1olcoo03Coo`0POn1
oh7oPOn1oh7oPOoAoo`0dool087oPOn1oh7oPOn1oh7odOol0=?oo021oh7oPOn6
o`12POn1oh7oc?om0=;oo021oh7oPOn1oh7oPOn1om7oo@3Boo`0POn1oh7oPOn1
oh7oPOoAood0d_ol087oPOn1ohKo04:1oh7oPOo=oo`0dOol087oPOn1oh7oPOn1
oh7odool0=7oo021oh7oPOn1oh7oPOn1om?oo03Aoo`0POn1oh7oQol0@X7oPOn1
olgoo03Aoo`0POn1oh7oPOn1oh7oPOoCoo`0dOol087oPOn1oh7oPOn1oh7odool
0=7oo021oh7oPOn7o`12POn1oh7oc_ol0<ooo@21oh7oPOn1oh7oPOn1omCoo03?
ood0POn1oh7oPOn1oh7oPOoDoo`0coom087oPOn1ohOo04:1oh7oPOo>oo`0cool
087oPOn1oh7oPOn1oh7oeOol0<ooo021oh7oPOn1oh7oPOn1omGoo03?oo`0POn1
oh7oR?l0@X7oPOn1olooo03>oo`0POn1oh7oPOn1oh7oPOoFoo`0c_ol087oPOn1
oh7oPOn1oh7oe_ol0<koo021oh7oPOn8o`12POn1oh7ocool0<goo@21oh7oPOn1
oh7oPOn1omKoo03=ood0POn1oh7oPOn1oh7oPOoFoo`0cOom087oPOn1ohSo0621
oh7oPOo?ood0iOom0>coo021ol;oo@21ojSoo@21oh7oPOn1ooOoo@3Uood0k?ol
087o`_om087oZ?om087oPOn1oh7omoom0>Goo@3/oo`0POo2ood0POnXood0ZOl0
H87oPOn1om3oo03Uood0k?ol087o`_om087oZ?om087oPOn1oh7on?ol0>Goo@3/
oo`0POo2ood0POnXood0POn1oh7oPOohoo`0iOom0>coo021ol;oo@21ojSoo@2Y
o`1PPOn1oh7od?ol0>Goo@3[ood0POo2ood0POnXood0POn1oh7oPOohoo`0iOom
0>_oo@21ol;oo@21ojSoo@21oh7oPOn1ooSoo03Uood0joom087o`_om087oZ?om
0:Wo0621oh7oPOoAoo`0i?om0>_oo021ol?oo@21ojSoo@21oh7oPOn1ooWoo03T
ood0jool087o`oom087oZ?om087oPOn1oh7onOol0>Coo@3[oo`0POo3ood0POnX
ood0ZOl0@X7oPOn1om7oo03:oo`0POn1oh7oPOn1oh7oPOoJoo`0b_ol087oPOn1
oh7oPOn1oh7of_ol0<[oo021oh7oPOn:o`12POn1oh7od_ol0<Soo021oh7oPOn1
oh7oPOn1omcoo038oo`0POn1oh7oPOn1oh7oPOoLoo`0b?ol087oPOn1oh_o04:1
oh7oPOoCoo`0a_om087oPOn1oh7oPOn1oh7ogOol0<Koo@21oh7oPOn1oh7oPOn1
omgoo036ood0POn1oh7oRol0@X7oPOn1om?oo@34ood0POn1oh7oPOn1oh7oPOoN
ood0a?om087oPOn1oh7oPOn1oh7og_om0<Coo@21oh7oPOn<o`12POn1oh7oe?om
0<?oo021oh7oPOn1oh7oPOn1on3oo@33oo`0POn1oh7oPOn1oh7oPOoPood0`ool
087oPOn1ohgo04:1oh7oPOoEoo`0`_om087oPOn1oh7oPOn1oh7ohOol0<;oo@21
oh7oPOn1oh7oPOn1on7oo032ood0POn1oh7oSOl0@X7oPOn1omKoo030ood0POn1
oh7oPOn1oh7oPOoSoo`0`?om087oPOn1oh7oPOn1oh7ohool0<3oo@21oh7oPOn>
o`12POn1oh7oeool0;ooo021oh7oPOn1oh7oPOn1onGoo02ooo`0POn1oh7oPOn1
oh7oPOoUoo`0_ool087oPOn1ohoo04:1oh7oPOoHoo`0_Oom087oPOn1oh7oPOn1
oh7oi_ol0;goo@21oh7oPOn1oh7oPOn1onKoo02mood0POn1oh7oSol0@X7oPOn1
omSoo02moo`0POn1oh7oPOn1oh7oPOoWoo`0_Ool087oPOn1oh7oPOn1oh7oiool
0;goo021oh7oPOn@o`12POn1oh7ofOol0;_oo021oh7oPOn1oh7oPOn1onWoo02k
oo`0POn1oh7oPOn1oh7oPOoYoo`0^ool087oPOn1oi7o04:1oh7oPOoJoo`0^Oom
087oPOn1oh7oPOn1oh7oj_ol0;Woo@21oh7oPOn1oh7oPOn1on[oo02iood0POn1
oh7oTOl0@X7oPOn1om_oo02hoo`0POn1oh7oPOn1oh7oPOo/oo`0^?ol087oPOn1
oh7oPOn1oh7ok?ol0;Soo021oh7oPOnBo`12POn1oh7og?ok0;Ooo021oh7oPOn1
oh7oPOn1onkon`2goo`0POn1oh7oPOn1oh7oPOo^oo/0]ool087oPOn1oi?o04:1
oh7oPOoNooX0]_oj087oPOn1oh7oPOn1oh7ol_oj0;KonP21oh7oPOn1oh7oPOn1
oo;onP2fooX0POn1oh7oUOl0@X7oPOn1on3on@2dooX0POn1oh7oPOn1oh7oPOoe
ooT0]?oj087oPOn1oh7oPOn1oh7omOoi0;ConP21oh7oPOnFo`12POn1oh7ohOoj
0;7onP21oh7oPOn1oh7oPOn1ooOonP2aooX0POn1oh7oPOn1oh7oPOogooX0/Ooj
087oPOn1oiOo06S_oo`0POn1oh7on_oi0=Goo@3NooX0POoBood0POnXood0Uool
087oPOn1oo[on@3Eood0g_oj087od_om087oZ?om09Ooo021oh7oPOojooT0eOom
0=konP21om;oo@21ojSoo@2Yo`1Xkool087oPOn1oocon@3Cood0gOoj087odoom
087oZ?om09Ooo021oh7oPOolooT0doom0=gonP21om?oo@21ojSoo@2Goo`0POn1
oh7oo?oi0=?oo@3MooX0POoCood0POnXood0ZOl0J>ooo021oh7oPOonooP0d_om
0=conP21omCoo@21ojSoo@2Goo`0POn1oh7oo_oh0=;oo@3LooX0POoDood0POnX
ood0Uool087oPOn1ookon03Bood0g?oj087oe?om087oZ?om0:Wo06;_oo`0POn1
ohGol`3@ood0foof087ofOom087oZ?om09Ooo021oh7oQOoc0=3oo@3KooH0POoI
ood0POnXood0Uool087oPOn5oo<0d?om0=_omP21omWoo@21ojSoo@2Yo`14kool
087oPOn=ond0X_ob087oPOn1oiCoo021oh7oSOo]0:;olP21oh7oPOnDoo`0POn1
ohgok@2Roo80POn1oh7oY_l0A>ooo021oh7oSOo^0:3ol`21oh7oPOnDoo`0POn1
ohgokP2Poo<0POn1oh7oU?ol087oPOn=onh0X?oc087oPOn1ojKo04C_oo`0POn1
ohcolP2KooD0POn1oh7oU?ol087oPOn<oo80Vooe087oPOn1oiCoo021oh7oS?ob
09_om@21oh7oPOnVo`1Ckool087oPOn<ooT0`_l1003?oo`0POn1oh7oTool087o
POn<ooT0`_l1003?oo`0POn1oh7oTool087oPOn<ooT0`_l1003?oo`0POn1oh7o
YOl0@^ooo021oh7oo?n10840P@210840]@3_oo`0POn1oocoP@210840P@210;D0
kool087oPOoloh40P@210840P@2e0012kool087oPOoloh40P@210840P@2e0>oo
o021oh7oo?n10840P@210840]@3_oo`0POn1oocoP@210840P@210;D004;_oo`0
POn1oocoP@210840P@210;D0kool087oPOoloh40P@210840P@2e0>ooo021oh7o
o?n10840P@210840]@00@^ooo021oh7oo?n10840P@210840]@3_oo`0POn1ooco
P@210840P@210;D0kool087oPOoloh40P@210840P@2e001@kool087oPOn1olWo
o@00oo/0POn1oh7oPOoQoo`0POn1oh7obOom003on`21oh7oPOn1on7oo021oh7o
POo9ood00?ok087oPOn1oh7olol0D>ooo021oh7oPOo:oo/00?ok087oPOn1oh7o
h_ol087oPOn1ol[on`00oo/0POn1oh7oPOoRoo`0POn1oh7ob_ok003on`21oh7o
POn1ooCo053_oo`0POn1oh7obook0?kon`21oh7oPOn1on?oo021oh7oPOo;oo/0
o_ok087oPOn1oh7ohool087oPOn1ol_on`3noo/0POn1oh7oPOoeo`1@kool087o
POn1olcon`3loo/0POn1oh7oPOoToo`0POn1oh7oc?ok0?con`21oh7oPOn1onCo
o021oh7oPOo<oo/0o?ok087oPOn1oh7om_l0D>ooo021oh7oPOo=oo/0n_ok087o
POn1oh7oiOol087oPOn1olgon`3joo/0POn1oh7oPOoUoo`0POn1oh7ocOok0?[o
n`21oh7oPOn1ooOo053_oo`0POn1oh7oc_ok0?Son`21oh7oPOn1onKoo021oh7o
POo>oo/0n?ok087oPOn1oh7oi_ol087oPOn1olkon`3hoo/0POn1oh7oPOoho`1@
kool087oPOn1oloon`3foo/0POn1oh7oPOoWoo`0POn1oh7ocook0?Kon`21oh7o
POn1onOoo021oh7oPOo?oo/0m_ok087oPOn1oh7onOl0D>ooo021oh7oPOo@oo/0
m?ok087oPOn1oh7oj?ol087oPOn1om3on`3doo/0POn1oh7oPOoXoo`0POn1oh7o
d?ok0?Con`21oh7oPOn1oo[o053_oo`0POn1oh7odOok0?;on`21oh7oPOn1onWo
o021oh7oPOoAoo/0l_ok087oPOn1oh7ojOol087oPOn1om7on`3boo/0POn1oh7o
POoko`1Lkool087oPOn1om;on`3`oo/0POneood0POnXood0Uool087oPOn1om;o
n`3`oo/0POneood0POnXood0Uool087oPOn1om;on`3`oo/0POneood0POnXood0
ZOl0G>ooo021oh7oPOoCoo/0k_ok087o]_om087oZ?om09Ooo021oh7oPOoCoo/0
k_ok087o]_om087oZ?om09Ooo021oh7oPOoCoo/0k_ok087o]_om087oZ?om0:Wo
05c_oo`0POn1oh7oe?ok0>con`21okOoo@21ojSoo@2Goo`0POn1oh7oe?ok0>co
n`21okOoo@21ojSoo@2Goo`0POn1oh7oe?ok0>con`21okOoo@21ojSoo@2Yo`1L
kool087oPOn1omGon`3Zoo/0POnhood0POnXood0Uool087oPOn1omGon`3Zoo/0
POnhood0POnXood0Uool087oPOn1omGon`3Zoo/0POnhood0POnXood0ZOl0D>oo
o021oh7oPOoFoo/0j?ok087oPOn1oh7ok_ol087oPOn1omKon`3Xoo/0POn1oh7o
POo^oo`0POn1oh7oe_ok0>Son`21oh7oPOn1o`3o04k_oo`0POn1oh7oeook0>Ko
n`21oh7oPOn1onooo021oh7oPOoGoo/0i_ok087oPOn1oh7okool087oPOn1omOo
n`3Voo/0POn1oh7oPOl0C^ooo021oh7oPOoHoo/0i?ok087oPOn1oh7ol?ol087o
POn1omSon`3Too/0POn1oh7oPOo`oo`0POn1oh7of?ok0>Con`21oh7oPOn2o`1>
kool087oPOn1omWon`3Roo/0POn1oh7oPOoaoo`0POn1oh7ofOok0>;on`21oh7o
POn1oo7oo021oh7oPOoIoo/0h_ok087oPOn1oh?o04k_oo`0POn1oh7of_ok0>3o
n`21oh7oPOn1oo;oo021oh7oPOoJoo/0h?ok087oPOn1oh7ol_ol087oPOn1om[o
n`3Poo/0POn1oh7oQ?l0C^ooo021oh7oPOoKoo/0g_ok087oPOn1oh7olool087o
POn1om_on`3Noo/0POn1oh7oPOocoo`0POn1oh7ofook0=kon`21oh7oPOn5o`1>
kool087oPOn1omcon`3Loo/0POn1oh7oPOodoo`0POn1oh7og?ok0=con`21oh7o
POn1ooCoo021oh7oPOoLoo/0g?ok087oPOn1ohKo04k_oo`0POn1oh7ogOok0=[o
n`21oh7oPOn1ooGoo021oh7oPOoMoo/0f_ok087oPOn1oh7omOol087oPOn1omgo
n`3Joo/0POn1oh7oQol0C^ooo021oh7oPOoNoo/0f?ok087oPOn1oh7om_ol087o
POn1omkon`3Hoo/0POn1oh7oPOofoo`0POn1oh7og_ok0=Son`21oh7oPOn8o`1>
kool087oPOn1omoon`3Foo/0POn1oh7oPOogoo`0POn1oh7ogook0=Kon`21oh7o
POn1ooOoo021oh7oPOoOoo/0e_ok087oPOn1ohWo04k_oo`0POn1oh7oh?ok0=Co
n`21oh7oPOn1ooSoo021oh7oPOoPoo/0e?ok087oPOn1oh7on?ol087oPOn1on3o
n`3Doo/0POn1oh7oR_l0C^ooo021oh7oPOoQoo/0d_ok087oPOn1oh7onOol087o
POn1on7on`3Boo/0POn1oh7oPOoioo`0POn1oh7ohOok0=;on`21oh7oPOn;o`1>
kool087oPOn1on;on`3@oo/0POn1oh7oPOojoo`0POn1oh7oh_ok0=3on`21oh7o
POn1oo[oo021oh7oPOoRoo/0d?ok087oPOn1ohco04k_oo`0POn1oh7ohook0<ko
n`21oh7oPOn1oo_oo021oh7oPOoSoo/0c_ok087oPOn1oh7onool087oPOn1on?o
n`3>oo/0POn1oh7oSOl0C^ooo021oh7oPOoToo/0c?ok087oPOn1oh7oo?ol087o
POn1onCon`3<oo/0POn1oh7oPOoloo`0POn1oh7oi?ok0<con`21oh7oPOn>o`1>
kool087oPOn1onGon`3:oo/0POn1oh7oPOomoo`0POn1oh7oiOok0<[on`21oh7o
POn1oogoo021oh7oPOoUoo/0b_ok087oPOn1ohoo04k_oo`0POn1oh7oi_ok0<So
n`21oh7oPOn1ookoo021oh7oPOoVoo/0b?ok087oPOn1oh7oo_ol087oPOn1onKo
n`38oo/0POn1oh7oT?l0G>ooo021oh7oPOoWoo/0a_ok087ob_om087oZ?om09Oo
o021oh7oPOoWoo/0a_ok087ob_om087oZ?om09Ooo021oh7oPOoWoo/0a_ok087o
b_om087oZ?om0:Wo05c_oo`0POn1oh7oj?ok0<Con`21ol_oo@21ojSoo@2Goo`0
POn1oh7oj?ok0<Con`21ol_oo@21ojSoo@2Goo`0POn1oh7oj?ok0<Con`21ol_o
o@21ojSoo@2Yo`1Lkool087oPOn1onWon`32oo/0POo<ood0POnXood0Uool087o
POn1onWon`32oo/0POo<ood0POnXood0Uool087oPOn1onWon`32oo/0POo<ood0
POnXood0ZOl0G>ooo021oh7oPOoZoo/0`?ok087ocOom087oZ?om09Ooo021oh7o
POoZoo/0`?ok087ocOom087oZ?om09Ooo021oh7oPOoZoo/0`?ok087ocOom087o
Z?om0:Wo04[_oo`0POn1oh7ojook0;kon`21oh7oPOn3oo`0POn1oh7ojook0;ko
n`21oh7oPOn3oo`0POn1oh7ojook0;kon`21oh7oPOnEo`1:kool087oPOn1onco
n`2loo/0POn1oh7oQ?ol087oPOn1oncon`2loo/0POn1oh7oQ?ol087oPOn1onco
n`2loo/0POn1oh7oU_l0B^ooo021oh7oPOo]oo/0^_ok087oPOn1ohGoo021oh7o
POo]oo/0^_ok087oPOn1ohGoo021oh7oPOo]oo/0^_ok087oPOn1oiOo04[_oo`0
POn1oh7ok_ok0;Son`21oh7oPOn6oo`0POn1oh7ok_ok0;Son`21oh7oPOn6oo`0
POn1oh7ok_ok0;Son`21oh7oPOnHo`1:kool087oPOn1onoon`2foo/0POn1oh7o
Qool087oPOn1onoon`2foo/0POn1oh7oQool087oPOn1onoon`2foo/0POn1oh7o
VOl0B^ooo021oh7oPOo`oo/0]?ok087oPOn1ohSoo021oh7oPOo`oo/0]?ok087o
POn1ohSoo021oh7oPOo`oo/0]?ok087oPOn1oi[o04[_oo`0POn1oh7olOok0;;o
n`21oh7oPOn9oo`0POn1oh7olOok0;;on`21oh7oPOn9oo`0POn1oh7olOok0;;o
n`21oh7oPOnKo`1:kool087oPOn1oo;on`2`oo/0POn1oh7oR_ol087oPOn1oo;o
n`2`oo/0POn1oh7oR_ol087oPOn1oo;on`2`oo/0POn1oh7oW?l0B^ooo021oh7o
POocoo/0[_ok087oPOn1oh_oo021oh7oPOocoo/0[_ok087oPOn1oh_oo021oh7o
POocoo/0[_ok087oPOn1oigo04[_oo`0POn1oh7om?ok0:con`21oh7oPOn<oo`0
POn1oh7om?ok0:con`21oh7oPOn<oo`0POn1oh7om?ok0:con`21oh7oPOnNo`1:
kool087oPOn1ooGon`2Zoo/0POn1oh7oSOol087oPOn1ooGon`2Zoo/0POn1oh7o
SOol087oPOn1ooGon`2Zoo/0POn1oh7oWol0B^ooo021oh7oPOofoo/0Z?ok087o
POn1ohkoo021oh7oPOofoo/0Z?ok087oPOn1ohkoo021oh7oPOofoo/0Z?ok087o
POn1oj3o04[_oo`0POn1oh7omook0:Kon`21oh7oPOn?oo`0POn1oh7omook0:Ko
n`21oh7oPOn?oo`0POn1oh7omook0:Kon`21oh7oPOnQo`1:kool087oPOn1ooSo
n`2Too/0POn1oh7oT?ol087oPOn1ooSon`2Too/0POn1oh7oT?ol087oPOn1ooSo
n`2Too/0POn1oh7oX_l0B^ooo021oh7oPOoioo/0X_ok087oPOn1oi7oo021oh7o
POoioo/0X_ok087oPOn1oi7oo021oh7oPOoioo/0X_ok087oPOn1oj?o04[_oo`0
POn1oh7on_ok0:3on`21oh7oPOnBoo`0POn1oh7on_ok0:3on`21oh7oPOnBoo`0
POn1oh7on_ok0:3on`21oh7oPOnTo`1Lkool087oPOn1oo_on`2Noo/0POoNood0
POnXood0Uool087oPOn1oo_on`2Noo/0POoNood0POnXood0Uool087oPOn1oo_o
n`2Noo/0POoNood0POnXood0ZOl0G>ooo021oh7oPOoloo/0W?ok087ogoom087o
Z?om09Ooo021oh7oPOoloo/0W?ok087ogoom087oZ?om09Ooo021oh7oPOoloo/0
W?ok087ogoom087oZ?om0:Wo05c_oo`0POn1oh7ooOok09[on`21on3oo@21ojSo
o@2Goo`0POn1oh7ooOok09[on`21on3oo@21ojSoo@2Goo`0POn1oh7ooOok09[o
n`21on3oo@21ojSoo@2Yo`1Lkool087oPOn1ookon`2Hoo/0POoQood0POnXood0
Uool087oPOn1ookon`2Hoo/0POoQood0POnXood0Uool087oPOn1ookon`2Hoo/0
POoQood0POnXood0ZOl0Gnooo021oh7oPOl1oook09Kon`21on;oo@21ojSoo@2G
oo`0POn1oh7o0Ooon`2Foo/0POoRood0POnXood0Uool087oPOn1o`7ooo/0U_ok
087oh_om087oZ?om0:Wo04[_oo`0POn1oh7o0?ok09Con`21oh7oPOnHoo`0POn1
oh7o0?ok09Con`21oh7oPOnHoo`0POn1oh7o0?ok09Con`21oh7oPOnZo`14kool
087oPOn1oo/0T_ok087oPOn1oiWoo021oh7oPOok09;on`21oh7oPOnIoo`0POn1
oh7on`2Boo/0POn1oh7oZol0A>ooo021oh7oP_ok093on`21oh7oPOnJoo`0POn1
oh;on`2@oo/0POn1oh7oV_ol087oPOn2oo/0T?ok087oPOn1ojco04C_oo`0POn1
oh?on`2>oo/0POn1oh7oVool087oPOn3oo/0S_ok087oPOn1oi_oo021oh7oPook
08kon`21oh7oPOn]o`14kool087oPOn4oo/0S?ok087oPOn1oicoo021oh7oQ?ok
08con`21oh7oPOnLoo`0POn1ohCon`2<oo/0POn1oh7o[_l0A>ooo021oh7oQOok
08[on`21oh7oPOnMoo`0POn1ohGon`2:oo/0POn1oh7oWOol087oPOn5oo/0R_ok
087oPOn1ojoo04C_oo`0POn1ohKon`28oo/0POn1oh7oW_ol087oPOn6oo/0R?ok
087oPOn1oikoo021oh7oQ_ok08Son`21oh7oPOn`o`14kool087oPOn7oo/0Q_ok
087oPOn1oiooo021oh7oQook08Kon`21oh7oPOnOoo`0POn1ohOon`26oo/0POn1
oh7o/Ol0A>ooo021oh7oR?ok08Con`21oh7oPOnPoo`0POn1ohSon`24oo/0POn1
oh7oX?ol087oPOn8oo/0Q?ok087oPOn1ok;o04C_oo`0POn1ohWon`22oo/0POn1
oh7oXOol087oPOn9oo/0P_ok087oPOn1oj7oo021oh7oROok08;on`21oh7oPOnc
o`1:kool087oPOn:oo/0POl0oo/0POn1oh7oX_ol087oPOn:oo/0POl0oo/0POn1
oh7oX_ol087oPOn:oo/0POl0oo/0POn1oh7o]?l0B^ooo021oh7oRook087oo_ok
087oPOn1oj?oo021oh7oRook087oo_ok087oPOn1oj?oo021oh7oRook087oo_ok
087oPOn1okGo04[_oo`0POn1ohcon`21oocon`21oh7oPOnToo`0POn1ohcon`21
oocon`21oh7oPOnToo`0POn1ohcon`21oocon`21oh7oPOnfo`1:kool087oPOn=
oo/0POojoo/0POn1oh7oYOol087oPOn=oo/0POojoo/0POn1oh7oYOol087oPOn=
oo/0POojoo/0POn1oh7o]ol0B^ooo021oh7oS_ok087on?ok087oPOn1ojKoo021
oh7oS_ok087on?ok087oPOn1ojKoo021oh7oS_ok087on?ok087oPOn1okSo05?_
oo`0POn1ohoon`2Bo`400>Oon`21oh7oPOnWoo`0POn1ohoon`2Bo`400>Oon`21
oh7oPOnWoo`0POn1ohoon`2Bo`400>Oon`21oh7oPOnio`1Rkool087oPOn@oo/0
T_om0>Oon`21oo?oo@21ojSoo@2Goo`0POn1oi3on`2Bood0iook087oloom087o
Z?om09Ooo021oh7oT?ok09;oo@3Woo/0POocood0POnXood0ZOl0H^ooo021oh7o
TOok09;on`3Woo/0POodood0POnXood0Uool087oPOnAoo/0T_ok0>Oon`21ooCo
o@21ojSoo@2Goo`0POn1oi7on`2Boo/0iook087om?om087oZ?om0:Wo06;_oo`0
POn1oi;on`2@oo/0iook087omOom087oZ?om09Ooo021oh7oT_ok093on`3Woo/0
POoeood0POnXood0Uool087oPOnBoo/0T?ok0>Oon`21ooGoo@21ojSoo@2Yo`1a
kool087oPOnCoo/0j?l1002Yoo/0iook087om_om087oZ?om09Ooo021oh7oTook
0>So0@00ZOok0>Oon`21ooKoo@21ojSoo@2Goo`0POn1oi?on`3Xo`400:Won`3W
oo/0POofood0POnXood0ZOl0G>ooo021oh7oU?ok0>Soo@2Yoo/0iook087oPOn1
ojcoo021oh7oU?ok0>Soo@2Yoo/0iook087oPOn1ojcoo021oh7oU?ok0>Soo@2Y
oo/0iook087oPOn1okko05c_oo`0POn1oiGon`3Xoo/0ZOok0>Oon`21oh7oPOn]
oo`0POn1oiGon`3Xoo/0ZOok0>Oon`21oh7oPOn]oo`0POn1oiGon`3Xoo/0ZOok
0>Oon`21oh7oPOnoo`1Lkool087oPOnFoo/0j?ok0:Oon`3Woo/0POn1oh7o[_ol
087oPOnFoo/0j?ok0:Oon`3Woo/0POn1oh7o[_ol087oPOnFoo/0j?ok0:Oon`3W
oo/0POn1oh7o`?l0G>ooo021oh7oUook0>Son`2Uoo/0iook087oPOn1ojooo021
oh7oUook0>Son`2Uoo/0iook087oPOn1ojooo021oh7oUook0>Son`2Uoo/0iook
087oPOn1ol7o05c_oo`0POn1oiSon`3Xoo/0Xook0>Oon`21oh7oPOn`oo`0POn1
oiSon`3Xoo/0Xook0>Oon`21oh7oPOn`oo`0POn1oiSon`3Xoo/0Xook0>Oon`21
oh7oPOo2o`1Lkool087oPOnIoo/0j?ok0:7oo03Voo/0POn1oh7o/Ool087oPOnI
oo/0j?ok0:7oo03Voo/0POn1oh7o/Ool087oPOnIoo/0j?ok0:7oo03Voo/0POn1
oh7o`ol0G>ooo021oh7oV_ok0>Ooo02Ooo`0i_ok087oPOn1ok;oo021oh7oV_ok
0>Ooo02Ooo`0i_ok087oPOn1ok;oo021oh7oV_ok0>Ooo02Ooo`0i_ok087oPOn1
olCo05c_oo`0POn1oi_on`3Woo`0WOol0>Kon`21oh7oPOncoo`0POn1oi_on`3W
oo`0WOol0>Kon`21oh7oPOncoo`0POn1oi_on`3Woo`0WOol0>Kon`21oh7oPOo5
o`1Lkool087oPOnLoo/0iool09con`3Voo/0POn1oh7o]?ol087oPOnLoo/0iool
09con`3Voo/0POn1oh7o]?ol087oPOnLoo/0iool09con`3Voo/0POn1oh7oa_l0
G>ooo021oh7oWOok0>Ooo02Joo/0i_ok087oPOn1okGoo021oh7oWOok0>Ooo02J
oo/0i_ok087oPOn1okGoo021oh7oWOok0>Ooo02Joo/0i_ok087oPOn1olOo05c_
oo`0POn1oikon`3Woo`0V?ok0>Kon`21oh7oPOnfoo`0POn1oikon`3Woo`0V?ok
0>Kon`21oh7oPOnfoo`0POn1oikon`3Woo`0V?ok0>Kon`21oh7oPOo8o`1Lkool
087oPOnOoo/0iook09Oon`3Voo/0POn1oh7o]ool087oPOnOoo/0iook09Oon`3V
oo/0POn1oh7o]ool087oPOnOoo/0iook09Oon`3Voo/0POn1oh7obOl0G>ooo021
oh7oX?ok0>Oon`2Eoo/0i_ok087oPOn1okSoo021oh7oX?ok0>Oon`2Eoo/0i_ok
087oPOn1okSoo021oh7oX?ok0>Oon`2Eoo/0i_ok087oPOn1ol[o05c_oo`0POn1
oj7on`3Woo/0Took0>Kon`21oh7oPOnioo`0POn1oj7on`3Woo/0Took0>Kon`21
oh7oPOnioo`0POn1oj7on`3Woo/0Took0>Kon`21oh7oPOo;o`1Lkool087oPOnR
oo/0iook097on`3Voo/0POn1oh7o^_ol087oPOnRoo/0iook097on`3Voo/0POn1
oh7o^_ol087oPOnRoo/0iook097on`3Voo/0POn1oh7oc?l0G>ooo021oh7oXook
0>Oon`2?oo/0i_ok087oPOn1ok_oo021oh7oXook0>Oon`2?oo/0i_ok087oPOn1
ok_oo021oh7oXook0>Oon`2?oo/0i_ok087oPOn1olgo05c_oo`0POn1ojCon`3W
oo/0SOok0>Kon`21oh7oPOnloo`0POn1ojCon`3Woo/0SOok0>Kon`21oh7oPOnl
oo`0POn1ojCon`3Woo/0SOok0>Kon`21oh7oPOo>o`1Xkool087oPOnUoo/0iook
08_on`3Voo/0R?om087oZ?om09Ooo021oh7oYOok0>Oon`2;oo/0i_ok08Soo@21
ojSoo@2Goo`0POn1ojGon`3Woo/0Rook0>Kon`28ood0POnXood0ZOl0J>ooo021
oh7oY_ok0>Oon`29oo/0i_ok08Woo@21ojSoo@2Goo`0POn1ojKon`3Woo/0ROok
0>Kon`29ood0POnXood0Uool087oPOnVoo/0iook08Won`3Voo/0ROom087oZ?om
0:Wo06S_oo`0POn1ojOon`3Woo/0Qook0>Kon`2:ood0POnXood0Uool087oPOnW
oo/0iook08Oon`3Voo/0R_om087oZ?om09Ooo021oh7oYook0>Oon`27oo/0i_ok
08[oo@21ojSoo@2Yo`1Xkool087oPOnXoo/0iook08Gon`3Voo/0Room087oZ?om
09Ooo021oh7oZ?ok0>Oon`25oo/0i_ok08_oo@21ojSoo@2Goo`0POn1ojSon`3W
oo/0QOok0>Kon`2;ood0POnXood0ZOl0G>ooo021oh7oZOok0>Oon`23oo/0i_ok
087oPOn1ol7oo021oh7oZOok0>Oon`23oo/0i_ok087oPOn1ol7oo021oh7oZOok
0>Oon`23oo/0i_ok087oPOn1om?o05c_oo`0POn1oj[on`3Voo`0POok0>Kon`21
oh7oPOo2oo`0POn1oj[on`3Voo`0POok0>Kon`21oh7oPOo2oo`0POn1oj[on`3V
oo`0POok0>Kon`21oh7oPOoDo`1Ukool087oPOn[oo/0i_ol087o0Ooon`3Voo/0
POn1oh7o`ool087oPOn[oo/0i_ol087o0Ooon`3Voo/0POn1oh7o`ool087oPOn[
oo/0i_ol087o0Ooon`3Voo/0POn1oh7oeOl0H^ooo021oh7o[?ok0>Koo021oogo
o03Uoo/0POn1oh7oa?ol087oPOn/oo/0i_ol087ooOol0>Gon`21oh7oPOo4oo`0
POn1ojcon`3Voo`0POomoo`0iOok087oPOn1omKo06;_oo`0POn1ojgon`3Voo`0
POokoo`0iOok087oPOn1olGoo021oh7o[Ook0>Koo021oo_oo03Uoo/0POn1oh7o
aOol087oPOn]oo/0i_ol087onool0>Gon`21oh7oPOoGo`1Rkool087oPOn^oo/0
i_ol087onOol0>Gon`21oh7oPOo6oo`0POn1ojkon`3Voo`0POoioo`0iOok087o
POn1olKoo021oh7o[_ok0>Koo021ooWoo03Uoo/0POn1oh7of?l0H^ooo021oh7o
[ook0>Koo021ooSon`3Uoo/0POn1oh7oaool087oPOn_oo/0i_ol087on?ok0>Go
n`21oh7oPOo7oo`0POn1ojoon`3Voo`0POohoo/0iOok087oPOn1omWo06;_oo`0
POn1ok3on`3Voo`0POofoo/0iOok087oPOn1olSoo021oh7o/?ok0>Koo021ooKo
n`3Uoo/0POn1oh7ob?ol087oPOn`oo/0i_ol087om_ok0>Gon`21oh7oPOoJo`1R
kool087oPOnaoo/0i_ol087om?ok0>Gon`21oh7oPOo9oo`0POn1ok7on`3Voo`0
POodoo/0iOok087oPOn1olWoo021oh7o/Ook0>Koo021ooCon`3Uoo/0POn1oh7o
fol0H^ooo021oh7o/_ok0>Koo021oo;on`3Uoo/0POn1oh7ob_ol087oPOnboo/0
i_ol087ol_ok0>Gon`21oh7oPOo:oo`0POn1ok;on`3Voo`0POoboo/0iOok087o
POn1omco06;_oo`0POn1ok?on`3Voo/0POoaoo/0iOok087oPOn1ol_oo021oh7o
/ook0>Kon`21oo7on`3Uoo/0POn1oh7obool087oPOncoo/0i_ok087olOok0>Go
n`21oh7oPOoMo`1Rkool087oPOndoo/0i_ok087okook0>Gon`21oh7oPOo<oo`0
POn1okCon`3Voo/0POo_oo/0iOok087oPOn1olcoo021oh7o]?ok0>Kon`21onoo
n`3Uoo/0POn1oh7og_l0H^ooo021oh7o]Ook0>Kon`21ongon`3Uoo/0POn1oh7o
cOol087oPOneoo/0i_ok087okOok0>Gon`21oh7oPOo=oo`0POn1okGon`3Voo/0
POo]oo/0iOok087oPOn1omoo06;_oo`0POn1okKon`3Voo/0POo[oo/0iOok087o
POn1olkoo021oh7o]_ok0>Kon`21on_on`3Uoo/0POn1oh7oc_ol087oPOnfoo/0
i_ok087ojook0>Gon`21oh7oPOoPo`1^kool087oPOngoo/0i_ok087ojOok0>ko
003ioo/0POn1oh7ocool087oPOngoo/0i_ok087ojOok0>ko003ioo/0POn1oh7o
cool087oPOngoo/0i_ok087ojOok0>ko003ioo/0POn1oh7ohOl0K^ooo021oh7o
^?ok0>Kon`21onOon`3aooh0n?ok087oPOn1om3oo021oh7o^?ok0>Kon`21onOo
n`3aooh0n?ok087oPOn1om3oo021oh7o^?ok0>Kon`21onOon`3aooh0n?ok087o
POn1on;o06k_oo`0POn1okWon`3Voo/0POoUoo/0lool0?Son`21oh7oPOoAoo`0
POn1okWon`3Voo/0POoUoo/0lool0?Son`21oh7oPOoAoo`0POn1okWon`3Voo/0
POoUoo/0lool0?Son`21oh7oPOoSo`1jkool087oPOnjoo/0iOol087ohook0?Ko
nP3goo/0WOom087oZ?om09Ooo021oh7o^_ok0>Goo021on?on`3fooX0mook09go
o@21ojSoo@2Goo`0POn1ok[on`3Uoo`0POoSoo/0m_oj0?Oon`2Mood0POnXood0
ZOl0N^ooo021oh7o^ook0>Goo021on7on`3iooL0mook09koo@21ojSoo@2Goo`0
POn1ok_on`3Uoo`0POoQoo/0nOog0?Oon`2Nood0POnXood0Uool087oPOnkoo/0
iOol087ohOok0?Wom`3goo/0W_om087oZ?om0:Wo08K_oo`0POn1okcon`3io`00
k_ol087ogook0?com@3foo/0Woom087oZ?om09Ooo021oh7o_?ok0?Wo003^oo`0
POoOoo/0o?oe0?Kon`2Oood0POnXood0Uool087oPOnloo/0nOl00>koo021omoo
n`3looD0m_ok09ooo@21ojSoo@2Yo`26kool087oPOnmoo/0nOom0?7oo021omgo
n`3noo<0m_ok0:3oo@21ojSoo@2Goo`0POn1okgon`3iood0lOol087ogOok0?ko
l`3foo/0X?om087oZ?om09Ooo021oh7o_Ook0?Woo@3aoo`0POoMoo/0o_oc0?Ko
n`2Pood0POnXood0ZOl0K^ooo021oh7o__ok0?SonP3eoo`0POoKon/0mOok087o
POn1omKoo021oh7o__ok0?SonP3eoo`0POoKon/0mOok087oPOn1omKoo021oh7o
__ok0?SonP3eoo`0POoKon/0mOok087oPOn1onSo06k_oo`0POn1okoon`3hooL0
n?ol087ofOo[0?Gon`21oh7oPOoGoo`0POn1okoon`3hooL0n?ol087ofOo[0?Go
n`21oh7oPOoGoo`0POn1okoon`3hooL0n?ol087ofOo[0?Gon`21oh7oPOoYo`1^
kool087oPOo0oo/0mooe0?_oo021omOok03doo/0POn1oh7of?ol087oPOo0oo/0
mooe0?_oo021omOok03doo/0POn1oh7of?ol087oPOo0oo/0mooe0?_oo021omOo
k03doo/0POn1oh7oj_l0K^ooo021oh7o`Ook0?OolP3noo`0POoEond0look087o
POn1omWoo021oh7o`Ook0?OolP3noo`0POoEond0look087oPOn1omWoo021oh7o
`Ook0?OolP3noo`0POoEond0look087oPOn1on_o06k_oo`0POn1ol;on`3foo40
0?ol087oe?o/0??on`21oh7oPOoJoo`0POn1ol;on`3foo400?ol087oe?o/0??o
n`21oh7oPOoJoo`0POn1ol;on`3foo400?ol087oe?o/0??on`21oh7oPOo/o`1R
kool087oPOo3oo/0m_o[087oe?o[0?;on`21oh7oPOoKoo`0POn1ol?on`3fon/0
POoDon/0l_ok087oPOn1om_oo021oh7o`ook0?Koj`21omCoj`3boo/0POn1oh7o
kOl0H^ooo021oh7oa?ok0?Gok021omCoj@3boo/0POn1oh7og?ol087oPOo4oo/0
mOo/087oe?oY0?;on`21oh7oPOoLoo`0POn1olCon`3eon`0POoDonT0l_ok087o
POn1onko06;_oo`0POn1olGon`3dond0POoDonP0lOok087oPOn1omgoo021oh7o
aOok0?Cok@21omCoj03aoo/0POn1oh7ogOol087oPOo5oo/0m?o]087oe?oX0?7o
n`21oh7oPOo_o`1Rkool087oPOo6oo/0m?o/087oe?oW0?7on`21oh7oPOoNoo`0
POn1olKon`3don`0POoDonL0lOok087oPOn1omkoo021oh7oa_ok0?Cok021omCo
i`3aoo/0POn1oh7ol?l0H^ooo021oh7oaook0??oj`21omKoiP3`oo/0POn1oh7o
gool087oPOo7oo/0loo[087oe_oV0?3on`21oh7oPOoOoo`0POn1olOon`3con/0
POoFonH0l?ok087oPOn1oo7o06;_oo`0POn1olSon`3conT0POoHon@0l?ok087o
POn1on3oo021oh7ob?ok0??oj@21omSoi03`oo/0POn1oh7oh?ol087oPOo8oo/0
looY087of?oT0?3on`21oh7oPOobo`1Rkool087oPOo9oo/0l_oX087ofOoT0>oo
n`21oh7oPOoQoo`0POn1olWon`3bonP0POoIon@0kook087oPOn1on7oo021oh7o
bOok0?;oj021omWoi03_oo/0POn1oh7olol0H^ooo021oh7ob_ok0?;oiP21om_o
h`3^oo/0POn1oh7oh_ol087oPOo:oo/0l_oV087ofooS0>kon`21oh7oPOoRoo`0
POn1ol[on`3bonH0POoKon<0k_ok087oPOn1ooCo06;_oo`0POn1ol_on`3aonH0
POoKon80k_ok087oPOn1on?oo021oh7obook0?7oiP21om_ohP3^oo/0POn1oh7o
hool087oPOo;oo/0lOoV087ofooR0>kon`21oh7oPOoeo`1Rkool087oPOo<oo/0
lOoT087ogOoQ0>gon`21oh7oPOoToo`0POn1olcon`3aon@0POoMon40kOok087o
POn1onCoo021oh7oc?ok0?7oi021omgoh@3]oo/0POn1oh7om_l0H^ooo021oh7o
cOok0?3oh`21omkoh03]oo/0POn1oh7oiOol087oPOo=oo/0l?oS087og_oP0>go
n`21oh7oPOoUoo`0POn1olgon`3`on<0POoNon00kOok087oPOn1ooOo06;_oo`0
POn1olkon`3_on<0POoOoml0k?ok087oPOn1onKoo021oh7oc_ok0>ooh`21omoo
g`3/oo/0POn1oh7oi_ol087oPOo>oo/0kooS087ogooO0>con`21oh7oPOoho`1^
kool087oPOo?oo/0kooQ087ogOoQ0>con`2bood0POnXood0Uool087oPOo?oo/0
kooQ087ogOoQ0>con`2bood0POnXood0Uool087oPOo?oo/0kooQ087ogOoQ0>co
n`2bood0POnXood0ZOl0K^ooo021oh7od?ok0>koh@21om_oh`3[oo/0]Ook087o
Z?om09Ooo021oh7od?ok0>koh@21om_oh`3[oo/0]Ook087oZ?om09Ooo021oh7o
d?ok0>koh@21om_oh`3[oo/0]Ook087oZ?om0:Wo06k_oo`0POn1om7on`3^oml0
POoJon@0jook0;Wom`21ojWoo@2Goo`0POn1om7on`3^oml0POoJon@0jook0;Wo
m`21ojWoo@2Goo`0POn1om7on`3^oml0POoJon@0jook0;Wom`21ojWoo@2Yo`1^
kool087oPOoBoo/0kOoO087of?oV0>[on`2moo40POn/ood0Uool087oPOoBoo/0
kOoO087of?oV0>[on`2moo40POn/ood0Uool087oPOoBoo/0kOoO087of?oV0>[o
n`2moo40POn/ood0ZOl0J>ooo021oh7odook0>goh021omCoj03Yoo/0_oo_087o
POnooo`0POn1om?on`3]on00POoDonP0jOok0;ook`21oh7o_ool087oPOoCoo/0
kOoP087oe?oX0>Won`2oonl0POn1om7o07C_oo`0POn1omCon`3/on<0POo?onT0
jOok0<3on@3nooT0POn1ol3oo021oh7oe?ok0>coh`21olooj@3Yoo/0`?oi0?ko
n@21oh7o`?ol087oPOoDoo/0k?oS087ocooY0>Won`30ooT0o_oi087oPOoBo`1d
kool087oPOoEoo/0k?oT087oboo[0>Son`32ooX0n_ok087oPOo0oo`0POn1omGo
n`3/on@0POo;on/0j?ok0<;onP3joo/0POn1ol3oo021oh7oeOok0>coi021ol_o
j`3Xoo/0`_oj0?[on`21oh7od_l0M>ooo021oh7oe_ok0>_oiP21olSoj`3Xoo/0
a?ok0?Koo021oh7o`Ool087oPOoFoo/0jooV087ob?o[0>Son`34oo/0m_ol087o
POo1oo`0POn1omKon`3[onH0POo8on/0j?ok0<Con`3foo`0POn1om?o07C_oo`0
POn1omOon`3ZonP0POo4ond0iook0<Kon`3doo`0POn1ol;oo021oh7oeook0>[o
j021olCok@3Woo/0a_ok0?Coo021oh7o`_ol087oPOoGoo/0j_oX087oa?o]0>Oo
n`36oo/0m?ol087oPOoDo`1dkool087oPOoHoo/0j_oY087o`?o^0>Oon`37oo`0
l_ol087oPOo3oo`0POn1omSon`3ZonT0POo0onh0iook0<Ooo03boo`0POn1ol?o
o021oh7of?ok0>[oj@21ol3okP3Woo/0aool0?;oo021oh7oeOl0M>ooo021oh7o
fOok0>WojP21okgol03Voo/0bOol0?3oo@21oh7o`ool087oPOoIoo/0jOoZ087o
_Oo`0>Kon`39oo`0l?om087oPOo3oo`0POn1omWon`3YonX0POnmoo00i_ok0<Wo
o03`ood0POn1omGo07C_oo`0POn1om[on`3Yon/0POnjoo00i_ok0<_oo03_oo`0
POn1olCoo021oh7of_ok0>Woj`21ok[ol03Voo/0bool0>ooo021oh7oa?ol087o
POoJoo/0jOo[087o^_o`0>Kon`3;oo`0kool087oPOoFo`1dkool087oPOoKoo/0
j?o]087o]_ob0>Gon`3<ood0kOol087oPOo5oo`0POn1om_on`3Xond0POnfoo80
iOok0<coo@3]oo`0POn1olGoo021oh7ofook0>Sok@21okKolP3Uoo/0c?om0>go
o021oh7oeol0M>ooo021oh7og?ok0>SokP21ok7om@3Too/0c_ol0>coo@21oh7o
aOol087oPOoLoo/0j?o^087o/Ooe0>Con`3>oo`0k?om087oPOo5oo`0POn1omco
n`3Xonh0POnaooD0i?ok0<koo03/ood0POn1omOo07C_oo`0POn1omgon`3Wonl0
POn^ooH0i?ok0<ooo@3[ood0POn1olGoo021oh7ogOok0>Ook`21ojkomP3Too/0
coom0>_oo@21oh7oaOol087oPOoMoo/0ioo_087o[_of0>Con`3?ood0joom087o
POoGo`1dkool087oPOoNoo/0ioo`087oZ_oh0>?on`3Aoo`0j_om087oPOo6oo`0
POn1omkon`3Woo00POnZooP0hook0=7oo03Zood0POn1olKoo021oh7og_ok0>Oo
l021oj[on03Soo/0dOol0>[oo@21oh7of?l0M>ooo021oh7ogook0>KolP21ojKo
n@3Soo/0d_om0>Woo@21oh7oa_ol087oPOoOoo/0i_ob087oY_oi0>?on`3Bood0
jOom087oPOo6oo`0POn1omoon`3Voo80POnVooT0hook0=;oo@3Yood0POn1omSo
07C_oo`0POn1on3on`3Uoo@0POnRoo/0h_ok0=Coo03Xood0POn1olOoo021oh7o
h?ok0>Gom021oj;on`3Roo/0e?ol0>Soo@21oh7oaool087oPOoPoo/0iOod087o
X_ok0>;on`3Doo`0j?om087oPOoIo`1dkool087oPOoQoo/0iOof087oWOol0>;o
n`3Eood0ioom087oPOo7oo`0POn1on7on`3UooH0POnMoo`0h_ok0=Goo@3Wood0
POn1olOoo021oh7ohOok0>GomP21oigoo03Roo/0eOom0>Ooo@21oh7ofOl0Mnoo
o021oh7oh_ok0>Con021oiSo0@00hOok0=Ooo03Vood0POn1olSoo021oh7oh_ok
0>Con021oiSo0@00hOok0=Ooo03Vood0POn1olSoo021oh7oh_ok0>Con021oiSo
0@00hOok0=Ooo03Vood0POn1om[o07C_oo`0POn1on?on`3TooT0POnDo`00hOok
0=Soo@3Uood0POn1olSoo021oh7ohook0>Con@21oiCo003Qoo/0f?om0>Goo@21
oh7ob?ol087oPOoSoo/0i?oi087oU?l00>7on`3Hood0iOom087oPOoJo`20kool
087oPOoToo/0hook087oPOo`oo/0f_om0?;oo@3goo`0POngood0Uool087oPOoT
oo/0hook087oPOo`oo/0f_om0?;oo@3goo`0POngood0Uool087oPOoToo/0hook
087oPOo`oo/0f_om0?;oo@3goo`0POngood0ZOl0P>ooo021oh7oiOok0>?oo021
oh7okOok0=_oo@3bood0m_om087o]oom09Ooo021oh7oiOok0>?oo021oh7okOok
0=_oo@3bood0m_om087o]oom09Ooo021oh7oiOok0>?oo021oh7okOok0=_oo@3b
ood0m_om087o]oom0:Wo083_oo`0POn1onKon`3Rooh0POn1on[on`3Noo`0lOom
0?Koo021okSoo@2Goo`0POn1onKon`3Rooh0POn1on[on`3Noo`0lOom0?Koo021
okSoo@2Goo`0POn1onKon`3Rooh0POn1on[on`3Noo`0lOom0?Koo021okSoo@2Y
o`20kool087oPOoWoo/0h_l0087oPOoVoo/0gool0?7oo@3eood0POnhood0Uool
087oPOoWoo/0h_l0087oPOoVoo/0gool0?7oo@3eood0POnhood0Uool087oPOoW
oo/0h_l0087oPOoVoo/0gool0?7oo@3eood0POnhood0ZOl0H^ooo021oh7oj?ok
087oPOo4oo/0h?om0>3oo@21oh7ob_ol087oPOoXoo/0POn1olCon`3Pood0h?om
087oPOo:oo`0POn1onSon`21oh7oa?ok0>3oo@3Pood0POn1omco06;_oo`0POn1
onWon`21oh7o`_ok0>;oo03Poo`0POn1ol_oo021oh7ojOok087oPOo2oo/0h_ol
0>3oo021oh7obool087oPOoYoo/0POn1ol;on`3Roo`0h?ol087oPOoMo`1Rkool
087oPOoZoo/0POn1ol3on`3Sood0g_om087oPOo;oo`0POn1on[on`21oh7o`?ok
0>?oo@3Nood0POn1ol_oo021oh7oj_ok087oPOo0oo/0hoom0=koo@21oh7ogOl0
H^ooo021oh7ojook087oPOnnoo/0i?om0=koo@21oh7obool087oPOo[oo/0POn1
okkon`3Tood0g_om087oPOo;oo`0POn1on_on`21oh7o__ok0>Coo@3Nood0POn1
omgo06;_oo`0POn1oncon`21oh7o_?ok0>Koo03Noo`0POn1olcoo021oh7ok?ok
087oPOnloo/0i_ol0=koo021oh7oc?ol087oPOo/oo/0POn1okcon`3Voo`0g_ol
087oPOoNo`1Rkool087oPOo]oo/0POn1ok[on`3Wood0g?om087oPOo<oo`0POn1
ongon`21oh7o^_ok0>Ooo@3Lood0POn1olcoo021oh7okOok087oPOnjoo/0ioom
0=coo@21oh7og_l0H^ooo021oh7ok_ok087oPOnhoo/0j?om0=coo@21oh7oc?ol
087oPOo^oo/0POn1okSon`3Xood0g?om087oPOo<oo`0POn1onkon`21oh7o^?ok
0>Soo@3Lood0POn1omko06;_oo`0POn1onoon`21oh7o]_ok0>[oo03Lood0POn1
olcoo021oh7okook087oPOnfoo/0j_ol0=coo@21oh7oc?ol087oPOo_oo/0POn1
okKon`3Zoo`0g?om087oPOoNo`1Rkool087oPOo`oo/0POn1okCon`3[ood0fool
087oPOo=oo`0POn1oo3on`21oh7o]?ok0>_oo@3Koo`0POn1olgoo021oh7ol?ok
087oPOndoo/0joom0=_oo021oh7ogol0H^ooo021oh7olOok087oPOnboo/0kOol
0=[oo@21oh7ocOol087oPOoaoo/0POn1ok;on`3]oo`0f_om087oPOo=oo`0POn1
oo7on`21oh7o/_ok0>goo03Jood0POn1omoo06;_oo`0POn1oo;on`21oh7o/?ok
0>koo@3Iood0POn1olgoo021oh7ol_ok087oPOn`oo/0k_om0=Woo@21oh7ocOol
087oPOoboo/0POn1ok3on`3^ood0fOom087oPOoOo`1Rkool087oPOocoo/0POn1
ojkon`3_ood0fOol087oPOo>oo`0POn1oo?on`21oh7o[_ok0>ooo@3Ioo`0POn1
olkoo021oh7olook087oPOn^oo/0koom0=Woo021oh7oh?l0H^ooo021oh7om?ok
087oPOn/oo/0lOol0=Soo@21oh7oc_ol087oPOodoo/0POn1ojcon`3aoo`0f?om
087oPOo>oo`0POn1ooCon`21oh7o[?ok0?7oo03Hood0POn1on3o06;_oo`0POn1
ooGon`21oh7oZ_ok0?;oo@3Good0POn1olkoo021oh7omOok087oPOnZoo/0l_om
0=Ooo@21oh7oc_ol087oPOoeoo/0POn1oj[on`3bood0eoom087oPOoPo`1Rkool
087oPOofoo/0POn1ojSon`3cood0eoom087oPOo>oo`0POn1ooKon`21oh7oZ?ok
0??oo@3Good0POn1olkoo021oh7om_ok087oPOnXoo/0loom0=Ooo@21oh7oh?l0
H^ooo021oh7omook087oPOnVoo/0mOol0=Ooo021oh7ocool087oPOogoo/0POn1
ojKon`3eoo`0eool087oPOo?oo`0POn1ooOon`21oh7oY_ok0?Goo03Goo`0POn1
on7o07C_oo`0POn1ooSon`21oh7oY?ok0?Koo@3Zood0l?om087o_Oom09Ooo021
oh7on?ok087oPOnToo/0m_om0>[oo@3`ood0POnmood0Uool087oPOohoo/0POn1
ojCon`3food0j_om0?3oo@21okgoo@2Yo`1dkool087oPOoioo/0POn1oj;on`3g
ood0j_om0?3oo@21okgoo@2Goo`0POn1ooWon`21oh7oX_ok0?Ooo@3Zood0l?om
087o_Oom09Ooo021oh7onOok087oPOnRoo/0moom0>[oo@3`ood0POnmood0ZOl0
M>ooo021oh7on_ok087oPOnPoo/0nOol0>[oo@3`oo`0POnnood0Uool087oPOoj
oo/0POn1oj3on`3ioo`0j_om0?3oo021okkoo@2Goo`0POn1oo[on`21oh7oX?ok
0?Woo03Zood0l?ol087o__om0:Wo07C_oo`0POn1oo_on`21oh7oW_ok0?[oo@3Y
ood0koom087o__om09Ooo021oh7onook087oPOnNoo/0n_om0>Woo@3_ood0POnn
ood0Uool087oPOokoo/0POn1oikon`3jood0jOom0>ooo@21okkoo@2Yo`1dkool
087oPOoloo/0POn1oicon`3loo`0jOom0>ooo@21okkoo@2Goo`0POn1oocon`21
oh7oW?ok0?coo03Yood0koom087o__om09Ooo021oh7oo?ok087oPOnLoo/0o?ol
0>Woo@3_ood0POnnood0ZOl0H^ooo021oh7ooOok087oPOnJoo/0oOom0=;oo021
oh7odOol087oPOomoo/0POn1oi[on`3mood0d_ol087oPOoAoo`0POn1oogon`21
oh7oV_ok0?goo@3Boo`0POn1on?o06;_oo`0POn1ookon`21oh7oV?ok0?koo@3A
ood0POn1om7oo021oh7oo_ok087oPOnHoo/0o_om0=7oo@21oh7odOol087oPOon
oo/0POn1oiSon`3nood0dOom087oPOoSo`1Ukool087oPOl1oook087oPOnFoo/0
0?om0=3oo021oh7od_ol087oPOl1oook087oPOnFoo/00?om0=3oo021oh7od_ol
087oPOl1oook087oPOnFoo/00?om0=3oo021oh7oi?l0E^ooo021oh7o0?ok087o
POnDooL0d?ol087oPOoBoo`0POn1o`3on`21oh7oU?og0=3oo021oh7od_ol087o
POl0oo/0POn1oiCom`3@oo`0POn1onCo05W_oo`0POn1o`7oood0POn1oi;on@3>
ood0POn1om;oo021oh7o0Oooo@21oh7oT_oi0<koo@21oh7od_ol087oPOl1ooom
087oPOnBooT0c_om087oPOoTo`1Ikool087oPOono`40087oPOn@ooX0c_ol087o
POoCoo`0POn1ooko0@00POn1oi3onP3>oo`0POn1om?oo021oh7oo_l10021oh7o
T?oj0<koo021oh7oiOl0B^ooo021oh7oPOn1oh[on`3>oo`0POn1om?oo021oh7o
POn1oh[on`3>oo`0POn1om?oo021oh7oPOn1oh[on`3>oo`0POn1onGo04[_oo`0
POn1oh7oPOn9oo/0c_om087oPOoCoo`0POn1oh7oPOn9oo/0c_om087oPOoCoo`0
POn1oh7oPOn9oo/0c_om087oPOoUo`1:kool087oPOn1oh7oROoj0<ooo021oh7o
e?ol087oPOn1oh7oROoj0<ooo021oh7oe?ol087oPOn1oh7oROoj0<ooo021oh7o
i_l0B^ooo021oh7oPOn1oh[on03@oo`0POn1omCoo021oh7oPOn1oh[on03@oo`0
POn1omCoo021oh7oPOn1oh[on03@oo`0POn1onKo04[_oo`0POn1oh7oPOn:ooL0
d?om087oPOoDoo`0POn1oh7oPOn:ooL0d?om087oPOoDoo`0POn1oh7oPOn:ooL0
d?om087oPOoVo`1Ikool087oPOn1oh7oRoom007ooo/0dOol087oPOoEoo`0POn1
oh7oPOn;ood00Ooon`3Aoo`0POn1omGoo021oh7oPOn1oh_oo@01oook0=7oo021
oh7oiol0E^ooo021oh7oPOn1oh_oo@3noo/0d_ol087oPOoEoo`0POn1oh7oPOn;
ood0o_ok0=;oo021oh7oeOol087oPOn1oh7oRoom0?kon`3Boo`0POn1onOo05K_
oo`0POn1oh7oPOn<ood0o?ok0=;oo021oh7oe_ol087oPOn1oh7oS?om0?con`3B
oo`0POn1omKoo021oh7oPOn1ohcoo@3loo/0d_ol087oPOoXo`1Fkool087oPOn1
oh7oSOol0?_on`3Bood0POn1omKoo021oh7oPOn1ohgoo03koo/0d_om087oPOoF
oo`0POn1oh7oPOn=oo`0nook0=;oo@21oh7oj?l0E^ooo021oh7oPOn1ohgoo@3i
oo/0d_om087oPOoGoo`0POn1oh7oPOn=ood0nOok0=;oo@21oh7oeool087oPOn1
oh7oSOom0?Won`3Bood0POn1onWo06S_oo`0POn1oh7oPOn>ood0mook0?3oo@3X
oo`0POo6ood0Uool087oPOn1oh7oS_om0?Oon`3`ood0j?ol087oa_om09Ooo021
oh7oPOn1ohkoo@3goo/0l?om0>Soo021olKoo@2Yo`1Xkool087oPOn1oh7oSool
0?Kon`3aood0ioom087oa_om09Ooo021oh7oPOn1ohooo03foo/0lOom0>Ooo@21
olKoo@2Goo`0POn1oh7oPOn?oo`0m_ok0?7oo@3Wood0POo6ood0ZOl0J>ooo021
oh7oPOn1oi3oo03doo/0l_om0>Ooo021olOoo@2Goo`0POn1oh7oPOn@oo`0m?ok
0?;oo@3Woo`0POo7ood0Uool087oPOn1oh7oT?ol0?Con`3bood0iool087oaoom
0:Wo06S_oo`0POn1oh7oPOnAoo`0l_ok0??oo@3Voo`0POo8ood0Uool087oPOn1
oh7oTOol0?;on`3cood0i_ol087ob?om09Ooo021oh7oPOn1oi7oo03boo/0loom
0>Koo021olSoo@2Yo`1Fkool087oPOn1oh7oT_ol0?3on`3Dood0POn1om[oo021
oh7oPOn1oi;oo03`oo/0e?om087oPOoJoo`0POn1oh7oPOnBoo`0l?ok0=Coo@21
oh7ok?l0E^ooo021oh7oPOn1oi;oo03_oo/0eOol087oPOoKoo`0POn1oh7oPOnB
oo`0kook0=Goo021oh7ofool087oPOn1oh7oT_ol0>oon`3Eoo`0POn1ongo05K_
oo`0POn1oh7oPOnCoo`0kOok0=Goo021oh7og?ol087oPOn1oh7oTool0>gon`3E
oo`0POn1omcoo021oh7oPOn1oi?oo03]oo/0eOol087oPOo^o`1Rkool087ohOol
087oPOn1okWoo03[oo/0e_ol087oPOoLoo`0POoQoo`0POn1oh7o^Ool0>_on`3F
oo`0POn1omcoo021on7oo021oh7oPOnioo`0jook0=Koo021oh7ok_l0H^ooo021
on7oo021oh7oPOnkoo/0jOok0=Koo021oh7ogOol087ohOol087oPOn1ok_on`3Y
oo/0e_ol087oPOoMoo`0POoQoo`0POn1oh7o^ook0>Won`3Foo`0POn1onoo06;_
oo`0POoQoo`0POn1oh7o_Ooi0>Son`3Goo/0POn1omkoo021on7oo021oh7oPOnm
ooT0j?ok0=Oon`21oh7og_ol087ohOol087oPOn1okgon@3Xoo/0eook087oPOo`
o`1Rkool087ohOol087oPOn1okkon@3Voo/0eook087oPOoOoo`0POoQoo`0POn1
oh7o__oi0>Kon`3Goo/0POn1omooo021on7oo021oh7oPOnnooT0i_ok0=Oon`21
oh7olOl0H^ooo021on7oo021oh7oPOo0ooT0hook0=Oon`21oh7oh?ol087ohOol
087oPOn1ol3on@3Soo/0eook087oPOoPoo`0POoQoo`0POn1oh7o`?oi0>?on`3G
oo/0POn1oo;o06;_oo`0POoQoo`0POn1oh7o`Ooj0>3on`3Foo/0POn1on;oo021
on7oo021oh7oPOo1ooX0h?ok0=Kon`21oh7oh_ol087ohOol087oPOn1ol7onP3P
oo/0e_ok087oPOodo`1Rkool087oi_o_087oPOn1ol_on@3Noo/0e_ok087oPOoS
oo`0POoVonl0POn1oh7obooi0=kon`3Foo/0POn1on?oo021onKok`21oh7oPOo;
ooT0g_ok0=Kon`21oh7omOl0H^ooo021onKok`21oh7oPOo<ooX0fook0=KonP21
oh7oiOol087oi_o_087oPOn1olconP3Koo/0e_oj087oPOoUoo`0POoVonl0POn1
oh7oc?oj0=_on`3FooX0POn1ooOo06;_oo`0POoVonl0POn1oh7oc_oj0=Son`3E
oo/0POn1onKoo021onKok`21oh7oPOo>ooX0f?ok0=Gon`21oh7oi_ol087oi_o_
087oPOn1olkonP3Hoo/0eOok087oPOoho`1Rkool087oi_o_087oPOn1omGom@3E
oo/0eOog087oPOo[oo`0POoVonl0POn1oh7oeOoe0=Gon`3EooL0POn1on_oo021
onKok`21oh7oPOoEooD0eOok0=Gom`21oh7ooOl0H>ooo021on7oo021oh7oPOoE
onh0dook0=Col`21oh7olOol087ohOol087oPOn1omGokP3Coo/0e?oc087oPOoa
oo`0POoQoo`0POn1oh7oeOo^0=?on`3Doo<0POn3o`1Pkool087ohOol087oPOn1
omGol03@oo/0e?od087oPOoaoo`0POoQoo`0POn1oh7oeOo`0=3on`3Doo@0POn1
oo7oo021on7oo021oh7oPOoEoo00d?ok0=Com021oh?o063_oo`0POoQoo`0POn1
oh7oe?ob0<kon`3Eoo@0POn1oo7oo021on7oo021oh7oPOoDoo80c_ok0=Gom021
oh7olOol087ohOol087oPOn1omColP3>oo/0eOod087oPol0H>ooo021on7oo021
oh7oPOoDooT0a_ok0=3on`21oh7ol?ol087ohOol087oPOn1omCon@36oo/0d?ok
087oPOo`oo`0POoQoo`0POn1oh7oe?oi0<Kon`3@oo/0POn2o`1@kool087ohOol
087oPOn1oi3on`21ojSoo@2Goo`0POoQoo`0POn1oh7oT?ok087oZ?om09Ooo021
on7oo021oh7oPOn@oo/0POnXood0ZOl0B>ooo021on7oo02Qoh40P@210840P@2e
0>ooo021on7oo02Qoh40P@210840P@2e0>ooo021on7oo02Qoh40P@210840P@2e
0018kool087ohOol0:7oP@210840P@210;D0kool087ohOol0:7oP@210840P@21
0;D0kool087ohOol0:7oP@210840P@210;D004S_oo`0POoQoo`0XOn10840P@21
0840]@3_oo`0POoQoo`0XOn10840P@210840]@3_oo`0POoQoo`0XOn10840P@21
0840]@00B>ooo021on7oo02Qoh40P@210840P@2e0>ooo021on7oo02Qoh40P@21
0840P@2e0>ooo021on7oo02Qoh40P@210840P@2e001Fkool087ohOol087oPOn1
oigomP3joo/0POn1okooo021on7oo021oh7oPOnMooH0n_ok087oPOnooo`0POoQ
oo`0POn1oh7oWOof0?[on`21oh7odOl0K^ooo021on7oo03[oo`0POn1oh7o^Ook
003on`3joo/0POn1ol3oo021on7oo03[oo`0POn1oh7o^Ook003on`3joo/0POn1
ol3oo021on7oo03[oo`0POn1oh7o^Ook003on`3joo/0POn1om;o06k_oo`0POoQ
oo`0jool087oPOn1ok[on`3noo/0n_ok087oPOo1oo`0POoQoo`0jool087oPOn1
ok[on`3noo/0n_ok087oPOo1oo`0POoQoo`0jool087oPOn1ok[on`3noo/0n_ok
087oPOoCo`1^kool087ohOol0>_oo021oh7oPOnkoo/0o?ok0?[on`21oh7o`_ol
087ohOol0>_oo021oh7oPOnkoo/0o?ok0?[on`21oh7o`_ol087ohOol0>_oo021
oh7oPOnkoo/0o?ok0?[on`21oh7oe?l0K^ooo021on7oo03[oo`0POn1oh7o_?ok
0?[on`3joo/0POn1ol?oo021on7oo03[oo`0POn1oh7o_?ok0?[on`3joo/0POn1
ol?oo021on7oo03[oo`0POn1oh7o_?ok0?[on`3joo/0POn1omGo06k_oo`0POoQ
oo`0jool087oPOn1okgon`3hoo/0n_ok087oPOo4oo`0POoQoo`0jool087oPOn1
okgon`3hoo/0n_ok087oPOo4oo`0POoQoo`0jool087oPOn1okgon`3hoo/0n_ok
087oPOoFo`1Rkool087ohOol087oPOn1oj?on`3foo/0n_ok087oPOo5oo`0POoQ
oo`0POn1oh7oXook0?Kon`3joo/0POn1olGoo021on7oo021oh7oPOnSoo/0m_ok
0?[on`21oh7oeol0H^ooo021on7oo021oh7oPOnToo/0m?ok0?[on`21oh7oa_ol
087ohOol087oPOn1ojCon`3doo/0n_ok087oPOo6oo`0POoQoo`0POn1oh7oY?ok
0?Con`3joo/0POn1omSo06;_oo`0POoQoo`0POn1oh7oYOok0?;on`3joo/0POn1
olOoo021on7oo021oh7oPOnUoo/0l_ok0?[on`21oh7oaool087ohOol087oPOn1
ojGon`3boo/0n_ok087oPOoIo`1Rkool087ohOok087oPOn1ojOon`3`oo/0n_ok
087oPOo8oo`0POoQoo/0POn1oh7oYook0?3on`3joo/0POn1olSoo021on7on`21
oh7oPOnWoo/0l?ok0?[on`21oh7of_l0H^ooo021on3oo021oh7oPOnXoo/0k_ok
0?[on`21oh7obOol087oh?ol087oPOn1ojSon`3^oo/0n_ok087oPOo9oo`0POoP
oo`0POn1oh7oZ?ok0>kon`3joo/0POn1om_o06k_oo`0POoPooX0o?l0087oPOn1
ok7on`3/oo/0n_ok087oPOo:oo`0POoPooX0o?l0087oPOn1ok7on`3/oo/0n_ok
087oPOo:oo`0POoPooX0o?l0087oPOn1ok7on`3/oo/0n_ok087oPOoLo`1^kool
087oh?od0?Coo021oh7oPOo4oo/0j_ok0?[on`21oh7obool087oh?od0?Coo021
oh7oPOo4oo/0j_ok0?[on`21oh7obool087oh?od0?Coo021oh7oPOo4oo/0j_ok
0?[on`21oh7ogOl0K^ooo021omoom@3doo`0POn1oh7oaOok0>Son`3joo/0POn1
olcoo021omoom@3doo`0POn1oh7oaOok0>Son`3joo/0POn1olcoo021omoom@3d
oo`0POn1oh7oaOok0>Son`3joo/0POn1omko06k_oo`0POoNooH0m?ol087oPOn1
olKon`3Voo/0n_ok087oPOo=oo`0POoNooH0m?ol087oPOn1olKon`3Voo/0n_ok
087oPOo=oo`0POoNooH0m?ol087oPOn1olKon`3Voo/0n_ok087oPOoOo`1^kool
087ofook0?;oo021oh7oPOo7oo/0i?ok0?[on`21oh7oc_ol087ofook0?;oo021
oh7oPOo7oo/0i?ok0?[on`21oh7oc_ol087ofook0?;oo021oh7oPOo7oo/0i?ok
0?[on`21oh7oh?l0J>ooo021olKoo021oh7oPOo8oo/0h_ok0?[on`21okgoo@2G
oo`0POo6oo`0POn1oh7ob?ok0>;on`3joo/0POnmood0Uool087oa_ol087oPOn1
olSon`3Roo/0n_ok087o_Oom0:Wo06S_oo`0POo6oo`0POn1oh7obOok0>3on`3j
oo/0POnnood0Uool087oa_ol087oPOn1olWon`3Poo/0n_ok087o__om09Ooo021
olKoo021oh7oPOo9oo/0h?ok0?[on`21okkoo@2Yo`1Xkool087oa_ol087oPOn1
ol[on`3Noo/0n_ok087o_oom09Ooo021olKoo021oh7oPOo:oo/0g_ok0?[on`21
okooo@2Goo`0POo6oo`0POn1oh7ob_ok0=kon`3joo/0POnoood0ZOl0J>ooo021
olKoo021oh7oPOo;oo/0g?ok0?[on`21ol3oo@2Goo`0POo6oo`0POn1oh7obook
0=con`3joo/0POo0ood0Uool087oa_ol087oPOn1ol_on`3Loo/0n_ok087o`?om
0:Wo06;_oo`0POo6oo`0POn1oh7oc?ok0=[on`3joo/0POn1om?oo021olKoo021
oh7oPOo<oo/0f_ok0?[on`21oh7odool087oa_ol087oPOn1olcon`3Joo/0n_ok
087oPOoUo`1Rkool087oa_ol087oPOn1olgon`3Hoo/0n_ok087oPOoDoo`0POo6
oo`0POn1oh7ocOok0=Son`3joo/0POn1omCoo021olKoo021oh7oPOo=oo/0f?ok
0?[on`21oh7oi_l0H^ooo021olKoo021oh7oPOo>oo/0e_ok0?[on`21oh7oeOol
087oa_ol087oPOn1olkon`3Foo/0n_ok087oPOoEoo`0POo6oo`0POn1oh7oc_ok
0=Kon`3joo/0POn1onOo06;_oo`0POo6oo`0POn1oh7ocook0=Con`3joo/0POn1
omKoo021olKoo021oh7oPOo?oo/0e?ok0?[on`21oh7oe_ol087oa_ol087oPOn1
oloon`3Doo/0n_ok087oPOoXo`1Rkool087oa_ol087oPOn1om3on`3Boo/0n_ok
087oPOoGoo`0POo6oo`0POn1oh7od?ok0=;on`3joo/0POn1omOoo021olKoo021
oh7oPOo@oo/0d_ok0?[on`21oh7ojOl0H^ooo021olKoo021oh7oPOoAoo/0d?ok
0?[on`21oh7of?ol087oa_ol087oPOn1om7on`3@oo/0n_ok087oPOoHoo`0POo6
oo`0POn1oh7odOok0=3on`3joo/0POn1on[o06;_oo`0POo6oo`0POn1oh7od_ok
0<kon`3joo/0POn1omWoo021olKoo021oh7oPOoBoo/0c_ok0?[on`21oh7ofOol
087oa_ol087oPOn1om;on`3>oo/0n_ok087oPOo[o`1Rkool087oa_ol087oPOn1
om?on`3<oo/0n_ok087oPOoJoo`0POo6oo`0POn1oh7odook0<con`3joo/0POn1
om[oo021olKoo021oh7oPOoCoo/0c?ok0?[on`21oh7ok?l0H^ooo021olKoo021
oh7oPOoDoo/0b_ok0?[on`21oh7ofool087oa_ol087oPOn1omCon`3:oo/0n_ok
087oPOoKoo`0POo6oo`0POn1oh7oe?ok0<[on`3joo/0POn1ongo06;_oo`0POo6
oo`0POn1oh7oeOok0<Son`3joo/0POn1omcoo021olKoo021oh7oPOoEoo/0b?ok
0?[on`21oh7og?ol087oa_ol087oPOn1omGon`38oo/0n_ok087oPOo^o`1Rkool
087oa_ol087oPOn1omKon`36oo/0n_ok087oPOoMoo`0POo6oo`0POn1oh7oe_ok
0<Kon`3joo/0POn1omgoo021olKoo021oh7oPOoFoo/0a_ok0?[on`21oh7okol0
H^ooo021olKoo021oh7oPOoGoo/0a?ok0?[on`21oh7og_ol087oa_ol087oPOn1
omOon`34oo/0n_ok087oPOoNoo`0POo6oo`0POn1oh7oeook0<Con`3joo/0POn1
oo3o06;_oo`0POo6oo`0POn1oh7of?ok0<;on`3joo/0POn1omooo021olKoo021
oh7oPOoHoo/0`_ok0?[on`21oh7ogool087oa_ol087oPOn1omSon`32oo/0n_ok
087oPOoao`1Rkool087oa_ol087oPOn1omWon`30oo/0n_ok087oPOoPoo`0POo6
oo`0POn1oh7ofOok0<3on`3joo/0POn1on3oo021olKoo021oh7oPOoIoo/0`?ok
0?[on`21oh7ol_l0H^ooo021olKoo021oh7oPOoJoo/0__ok0?[on`21oh7ohOol
087oa_ol087oPOn1om[on`2noo/0n_ok087oPOoQoo`0POo6oo`0POn1oh7of_ok
0;kon`3joo/0POn1oo?o06;_oo`0POo6oo`0POn1oh7ofook0;con`3joo/0POn1
on;oo021olKoo021oh7oPOoKoo/0_?ok0?[on`21oh7oh_ol087oa_ol087oPOn1
om_on`2loo/0n_ok087oPOodo`1Rkool087oa_ol087oPOn1omcon`2joo/0n_ok
087oPOoSoo`0POo6oo`0POn1oh7og?ok0;[on`3joo/0POn1on?oo021olKoo021
oh7oPOoLoo/0^_ok0?[on`21oh7omOl0J>ooo021olKoo021oh7oPOoMoo/0^?ok
0?[on`21om;oo@2Goo`0POo6oo`0POn1oh7ogOok0;Son`3joo/0POoBood0Uool
087oa_ol087oPOn1omgon`2hoo/0n_ok087od_om0:Wo06S_oo`0POo6oo`0POn1
oh7og_ok0;Kon`3joo/0POoCood0Uool087oa_ol087oPOn1omkon`2foo/0n_ok
087odoom09Ooo021olKoo021oh7oPOoNoo/0]_ok0?[on`21om?oo@2Yo`1Xkool
087oa_ol087oPOn1omoon`2doo/0n_ok087oe?om09Ooo021olKoo021oh7oPOoO
oo/0]?ok0?[on`21omCoo@2Goo`0POo6oo`0POn1oh7ogook0;Con`3joo/0POoD
ood0ZOl0G>ooo021oh7oPOn1oj3on`2boo/0n_ok087oeOom09Ooo021oh7oPOn1
oj3on`2boo/0n_ok087oeOom09Ooo021oh7oPOn1oj3on`2boo/0n_ok087oeOom
0:Wo05K_oo`0POn1oh7oPOnQoo/0/?ok0?[on`21oh7oj?ol087oPOn1oh7oXOok
0;3on`3joo/0POn1onSoo021oh7oPOn1oj7on`2`oo/0n_ok087oPOojo`1Fkool
087oPOn1oh7oX_ok0:kon`3joo/0POn1onWoo021oh7oPOn1oj;on`2^oo/0n_ok
087oPOoYoo`0POn1oh7oPOnRoo/0[_ok0?[on`21oh7onol0E^ooo021oh7oPOn1
oj?on`2/oo/0n_ok087oPOoZoo`0POn1oh7oPOnSoo/0[?ok0?[on`21oh7oj_ol
087oPOn1oh7oXook0:con`3joo/0POn1ooco05K_oo`0POn1oh7oPOnToo/0Z_ok
0?[on`21oh7ojool087oPOn1oh7oY?ok0:[on`3joo/0POn1on_oo021oh7oPOn1
ojCon`2Zoo/0n_ok087oPOomo`1Fkool087oPOn1oh7oYOok0:Son`3joo/0POn1
oncoo021oh7oPOn1ojGon`2Xoo/0n_ok087oPOo/oo`0POn1oh7oPOnUoo/0Z?ok
0?[on`21oh7oo_l0Enooo021oh7oPOn1ojKon`2Voo/0n_ok087oPOo]oo`0POn1
oh7oPOnVoo/0Y_ok0?[on`21oh7okOol087oPOn1oh7oY_ok0:Kon`3joo/0POn1
o`7oo`1Fkool087oPOn1oh7oYook0:Con`3joo/0POn1onkoo021oh7oPOn1ojOo
n`2Too/0n_ok087oPOo^oo`0POn1oh7oPOnWoo/0Y?ok0?[on`21oh7o0?l0E>oo
o021oh7oPOn1ojSon`2Roo/0n_ok087oPOo_oo`0POn1oh7oPOnXoo/0X_ok0?[o
n`21oh7okool087oPOn1oh7oZ?ok0:;on`3joo/0POn1o`1Dkool087oPOn1oh7o
ZOok0:3on`3joo/0POn1oo3oo021oh7oPOn1ojWon`2Poo/0n_ok087oPOo`oo`0
POn1oh7oPOnYoo/0X?ok0?[on`21oh;o05C_oo`0POn1oh7oPOnZoo/0W_ok0?[o
n`21oh7olOol087oPOn1oh7oZ_ok09kon`3joo/0POn1oo7oo021oh7oPOn1oj[o
n`2Noo/0n_ok087oPol0E>ooo021oh7oPOn1oj_on`2Loo/0n_ok087oPOoboo`0
POn1oh7oPOn[oo/0W?ok0?[on`21oh7ol_ol087oPOn1oh7oZook09con`3joo/0
POn4o`1Dkool087oPOn1oh7o[?ok09[on`3joo/0POn1oo?oo021oh7oPOn1ojco
n`2Joo/0n_ok087oPOocoo`0POn1oh7oPOn/oo/0V_ok0?[on`21ohGo05C_oo`0
POn1oh7oPOn]oo/0V?ok0?[on`21oh7om?ol087oPOn1oh7o[Ook09Son`3joo/0
POn1ooCoo021oh7oPOn1ojgon`2Hoo/0n_ok087oQ_l0E>ooo021oh7oPOn1ojko
n`2Foo/0n_ok087oPOoeoo`0POn1oh7oPOn^oo/0U_ok0?[on`21oh7omOol087o
POn1oh7o[_ok09Kon`3joo/0POn7o`1Dkool087oPOn1oh7o[ook09Con`3joo/0
POn1ooKoo021oh7oPOn1ojoon`2Doo/0n_ok087oPOofoo`0POn1oh7oPOn_oo/0
U?ok0?[on`21ohSo05C_oo`0POn1oh7oPOn`oo/0T_ok0?[on`21oh7omool087o
POn1oh7o/?ok09;on`3joo/0POn1ooOoo021oh7oPOn1ok3on`2Boo/0n_ok087o
ROl0E>ooo021oh7oPOn1ok7on`2@oo/0n_ok087oPOohoo`0POn1oh7oPOnaoo/0
T?ok0?[on`21oh7on?ol087oPOn1oh7o/Ook093on`3joo/0POn:o`1Lkool087o
POn1oh7o/_ok08kon`3joo/0POoWood0Uool087oPOn1oh7o/_ok08kon`3joo/0
POoWood0Uool087oPOn1oh7o/_ok08kon`3joo/0POoWood0ZOl0G>ooo021oh7o
POn1ok?on`2<oo/0n_ok087oj?om09Ooo021oh7oPOn1ok?on`2<oo/0n_ok087o
j?om09Ooo021oh7oPOn1ok?on`2<oo/0n_ok087oj?om0:Wo05c_oo`0POn1oh7o
POndoo/0R_ok0?[on`21onWoo@2Goo`0POn1oh7oPOndoo/0R_ok0?[on`21onWo
o@2Goo`0POn1oh7oPOndoo/0R_ok0?[on`21onWoo@2Yo`1Lkool087oPOn1oh7o
]Ook08Son`3joo/0POoZood0Uool087oPOn1oh7o]Ook08Son`3joo/0POoZood0
Uool087oPOn1oh7o]Ook08Son`3joo/0POoZood0ZOl0E>ooo021oh7oPOn1okKo
n`26oo/0n_ok087oPOomoo`0POn1oh7oPOnfoo/0Q_ok0?[on`21oh7ooOol087o
POn1oh7o]_ok08Kon`3joo/0POn?o`1Dkool087oPOn1oh7o]ook08Con`3joo/0
POn1ookoo021oh7oPOn1okOon`24oo/0n_ok087oPOonoo`0POn1oh7oPOngoo/0
Q?ok0?[on`21oi3o05K_oo`0POn1oh7oPOnhoo/0P_ok0?[on`21oh7o0Oooo021
oh7oPOn1okSon`22oo/0n_ok087oPOl1oool087oPOn1oh7o^?ok08;on`3joo/0
POnAo`1Jkool087oPOn1oh7o^Ook087o0?ok0?[on`21oh7o0?ol087oPOn1oh7o
^Ook087o0?ok0?[on`21oh7o0?ol087oPOn1oh7o^Ook087o0?ok0?[on`21oi;o
05K_oo`0POn1oh7oPOnjoo/0POonoo/0n_ok087oPOol087oPOn1oh7o^_ok087o
o_ok0?[on`21oh7oo021oh7oPOn1ok[on`21ookon`3joo/0POnCo`1Fkool087o
POn1oh7o^ook087oo?ok0?[on`21oh;oo021oh7oPOn1ok_on`21oocon`3joo/0
POn2oo`0POn1oh7oPOnkoo/0POoloo/0n_ok087oU?l0E^ooo021oh7oPOn1okco
n`21oo[on`3joo/0POn3oo`0POn1oh7oPOnloo/0POojoo/0n_ok087oPool087o
POn1oh7o_?ok087on_ok0?[on`21oiGo05K_oo`0POn1oh7oPOnmoo/0POohoo/0
n_ok087oQ?ol087oPOn1oh7o_Ook087on?ok0?[on`21ohCoo021oh7oPOn1okgo
n`21ooSon`3joo/0POnFo`1Fkool087oPOn1oh7o__ok087om_ok0?[on`21ohGo
o021oh7oPOn1okkon`21ooKon`3joo/0POn5oo`0POn1oh7oPOnnoo/0POofoo/0
n_ok087oUol0E^ooo021oh7oPOn1okoon`21ooCon`3joo/0POn6oo`0POn1oh7o
POnooo/0POodoo/0n_ok087oQ_ol087oPOn1oh7o_ook087om?ok0?[on`21oiSo
05K_oo`0POn1oh7oPOo0oo/0POoboo/0n_ok087oQool087oPOn1oh7o`?ok087o
l_ok0?[on`21ohOoo021oh7oPOn1ol3on`21oo;on`3joo/0POnIo`1Fkool087o
POn1oh7o`Ook087ol?ok0?[on`21ohSoo021oh7oPOn1ol7on`21oo3on`3joo/0
POn8oo`0POn1oh7oPOo1oo/0POo`oo/0n_ok087oV_l0E^ooo021oh7oPOn1ol;o
n`21onkon`3joo/0POn9oo`0POn1oh7oPOo2oo/0POo^oo/0n_ok087oROol087o
POn1oh7o`_ok087ok_ok0?[on`21oi_o05K_oo`0POn1oh7oPOo3oo/0POo/oo/0
n_ok087oR_ol087oPOn1oh7o`ook087ok?ok0?[on`21oh[oo021oh7oPOn1ol?o
n`21oncon`3joo/0POnLo`1Fkool087oPOn1oh7oa?ok087oj_ok0?[on`21oh_o
o021oh7oPOn1olCon`21on[on`3joo/0POn;oo`0POn1oh7oPOo4oo/0POoZoo/0
n_ok087oWOl0Gnooo021oh7oPOn1olGon`2;o`400>3on`3joo/0POn<oo`0POn1
oh7oPOo5oo/0Rol1003Poo/0n_ok087oS?ol087oPOn1oh7oaOok08_o0@00h?ok
0?[on`21oiko06S_oo`0POn1oh7oPOo6oo/0Room0>3on`3joo/0POokood0Uool
087oPOn1oh7oa_ok08_oo@3Poo/0n_ok087onoom09Ooo021oh7oPOn1olKon`2;
ood0h?ok0?[on`21oo_oo@2Yo`1Xkool087oPOn1oh7oaook08_on`3Poo/0n_ok
087oo?om09Ooo021oh7oPOn1olOon`2;oo/0h?ok0?[on`21oocoo@2Goo`0POn1
oh7oPOo7oo/0Rook0>3on`3joo/0POolood0ZOl0J>ooo021oh7oPOn1olSon`29
oo/0h?ok0?[on`21oogoo@2Goo`0POn1oh7oPOo8oo/0ROok0>3on`3joo/0POom
ood0Uool087oPOn1oh7ob?ok08Won`3Poo/0n_ok087ooOom0:Wo06S_oo`0POn1
oh7oPOo9oo/0Qook0>3on`3joo/0POonood0Uool087oPOn1oh7obOok08Oon`3P
oo/0n_ok087oo_om09Ooo021oh7oPOn1olWon`27oo/0h?ok0?[on`21ookoo@2Y
o`1gkool087oPOn1oh7ob_ok0>7ooP2Xoo/0h?ok0?[on`21o`7oood0Uool087o
POn1oh7ob_ok0>7ooP2Xoo/0h?ok0?[on`21o`7oood0Uool087oPOn1oh7ob_ok
0>7ooP2Xoo/0h?ok0?[on`21o`7oood0ZOl0J>ooo021oh7oPOn1ol_on`3Qoo`0
Z?ok0>3on`3joo/0POnBoo`0POn1oh7oPOo;oo/0hOol0:Son`3Poo/0n_ok087o
T_ol087oPOn1oh7obook0>7oo02Xoo/0h?ok0?[on`21ojCo06S_oo`0POn1oh7o
POo<oo/0hOol0:Kon`3Poo/0n_ok087oTool087oPOn1oh7oc?ok0>7oo02Voo/0
h?ok0?[on`21oi?oo021oh7oPOn1olcon`3Qoo`0Y_ok0>3on`3joo/0POnUo`1X
kool087oPOn1oh7ocOok0>7oo02Too`0gook0?[on`21oiCoo021oh7oPOn1olgo
n`3Qoo`0Y?ol0=oon`3joo/0POnDoo`0POn1oh7oPOo=oo/0hOol0:Coo03Ooo/0
n_ok087oY_l0J>ooo021oh7oPOn1olkon`3Qoo`0X_ol0=oon`3joo/0POnEoo`0
POn1oh7oPOo>oo/0hOol0:;oo03Ooo/0n_ok087oUOol087oPOn1oh7oc_ok0>7o
o02Roo`0gook0?[on`21ojOo06S_oo`0POn1oh7oPOo?oo/0hOol0:3oo03Ooo/0
n_ok087oU_ol087oPOn1oh7ocook0>7oo02Poo`0gook0?[on`21oiKoo021oh7o
POn1oloon`3Qoo`0X?ol0=oon`3joo/0POnXo`1Xkool087oPOn1oh7od?ok0>7o
o02Noo`0gook0?[on`21oiOoo021oh7oPOn1om3on`3Qoo`0W_ol0=oon`3joo/0
POnGoo`0POn1oh7oPOo@oo/0hOol09koo03Ooo/0n_ok087oZOl0J>ooo021oh7o
POn1om7on`3Qoo`0W?ol0=oon`3joo/0POnHoo`0POn1oh7oPOoAoo/0hOol09co
o03Ooo/0n_ok087oV?ol087oPOn1oh7odOok0>7oo02Loo`0gook0?[on`21oj[o
06S_oo`0POn1oh7oPOoBoo/0hOol09_on`3Ooo/0n_ok087oVOol087oPOn1oh7o
d_ok0>7oo02Koo/0gook0?[on`21oiWoo021oh7oPOn1om;on`3Qoo`0Vook0=oo
n`3joo/0POn[o`1Xkool087oPOn1oh7odook0>3oo02Joo/0gook0?[on`21oi[o
o021oh7oPOn1om?on`3Poo`0V_ok0=oon`3joo/0POnJoo`0POn1oh7oPOoCoo/0
h?ol09[on`3Ooo/0n_ok087o[?l0J>ooo021oh7oPOn1omCon`3Poo`0V?ok0=oo
n`3joo/0POnKoo`0POn1oh7oPOoDoo/0h?ol09Son`3Ooo/0n_ok087oVool087o
POn1oh7oe?ok0>3oo02Hoo/0gook0?[on`21ojgo06S_oo`0POn1oh7oPOoEoo/0
h?ol09Kon`3Ooo/0n_ok087oW?ol087oPOn1oh7oeOok0>3oo02Foo/0gook0?[o
n`21oicoo021oh7oPOn1omGon`3Poo`0U_ok0=oon`3joo/0POn^o`1Xkool087o
POn1oh7oe_ok0>3oo02Doo/0gook0?[on`21oigoo021oh7oPOn1omKon`3Poo`0
U?ok0=oon`3joo/0POnMoo`0POn1oh7oPOoFoo/0h?ol09Con`3Ooo/0n_ok087o
[ol0J>ooo021oh7oPOn1omOon`3Poo`0T_ok0=oon`3joo/0POnNoo`0POn1oh7o
POoGoo/0h?ol09;on`3Ooo/0n_ok087oW_ol087oPOn1oh7oeook0>3oo02Boo/0
gook0?[on`21ok3o06S_oo`0POn1oh7oPOoHoo/0h?ol093on`3Ooo/0n_ok087o
Wool087oPOn1oh7of?ok0>3oo02@oo/0gook0?[on`21oiooo021oh7oPOn1omSo
n`3Poo`0T?ok0=oon`3joo/0POnao`1Xkool087oPOn1oh7ofOok0>3oo02>oo/0
gook0?[on`21oj3oo021oh7oPOn1omWon`3Poo`0S_ok0=oon`3joo/0POnPoo`0
POn1oh7oPOoIoo/0h?ol08kon`3Ooo/0n_ok087o/_l0J>ooo021oh7oPOn1om[o
n`3Poo`0S?ok0=oon`3joo/0POnQoo`0POn1oh7oPOoJoo/0h?ol08con`3Ooo/0
n_ok087oXOol087oPOn1oh7of_ok0>3oo02<oo/0gook0?[on`21ok?o06k_oo`0
POn1oh7oPOoKoo/0h?ol08[on`3Ooo/0n_ok093oo@2Goo`0POn1oh7oPOoKoo/0
h?ol08[on`3Ooo/0n_ok093oo@2Goo`0POn1oh7oPOoKoo/0h?ol08[on`3Ooo/0
n_ok093oo@2Yo`1^kool087oPOn1oh7og?ok0>3oo028oo/0gook0?[on`2Aood0
Uool087oPOn1oh7og?ok0>3oo028oo/0gook0?[on`2Aood0Uool087oPOn1oh7o
g?ok0>3oo028oo/0gook0?[on`2Aood0ZOl0K^ooo021oh7oPOn1omgon`3Poo`0
Q_ol0=kon`3joo/0T_om09Ooo021oh7oPOn1omgon`3Poo`0Q_ol0=kon`3joo/0
T_om09Ooo021oh7oPOn1omgon`3Poo`0Q_ol0=kon`3joo/0T_om0:Wo06k_oo`0
POn1oh7oPOoNoo/0h?ol08Coo03Noo/0n_ok09?oo@2Goo`0POn1oh7oPOoNoo/0
h?ol08Coo03Noo/0n_ok09?oo@2Goo`0POn1oh7oPOoNoo/0h?ol08Coo03Noo/0
n_ok09?oo@2Yo`1Xkool087oPOn1oh7ogook0>3oo022oo`0g_ok0?[on`21ojKo
o021oh7oPOn1omoon`3Poo`0P_ol0=kon`3joo/0POnVoo`0POn1oh7oPOoOoo/0
h?ol08;oo03Noo/0n_ok087o^?l0K^ooo021oh7oPOn1on3on`3Poo`0POl0oo`0
g_ok0?[on`21ojOoo021oh7oPOn1on3on`3Poo`0POl0oo`0g_ok0?[on`21ojOo
o021oh7oPOn1on3on`3Poo`0POl0oo`0g_ok0?[on`21okWo06k_oo`0POn1oh7o
POoQoo/0h?ol087oo_ol0=kon`3joo/0POnXoo`0POn1oh7oPOoQoo/0h?ol087o
o_ol0=kon`3joo/0POnXoo`0POn1oh7oPOoQoo/0h?ol087oo_ol0=kon`3joo/0
POnjo`1^kool087oPOn1oh7oh_ok0>3oo021oocoo03Noo/0n_ok087oZOol087o
POn1oh7oh_ok0>3oo021oocoo03Noo/0n_ok087oZOol087oPOn1oh7oh_ok0>3o
o021oocoo03Noo/0n_ok087o^ol0K^ooo021oh7oPOn1on?on`3Poo/0POokoo`0
g_ok0?[on`21oj[oo021oh7oPOn1on?on`3Poo/0POokoo`0g_ok0?[on`21oj[o
o021oh7oPOn1on?on`3Poo/0POokoo`0g_ok0?[on`21okco06k_oo`0POn1oh7o
POoToo/0h?ok087onOol0=kon`3joo/0POn[oo`0POn1oh7oPOoToo/0h?ok087o
nOol0=kon`3joo/0POn[oo`0POn1oh7oPOoToo/0h?ok087onOol0=kon`3joo/0
POnmo`1^kool087oPOn1oh7oiOok0>3on`21ooSon`3Noo/0n_ok087o[?ol087o
POn1oh7oiOok0>3on`21ooSon`3Noo/0n_ok087o[?ol087oPOn1oh7oiOok0>3o
n`21ooSon`3Noo/0n_ok087o__l0K^ooo021oh7oPOn1onKon`3Poo/0POofoo/0
g_ok0?[on`21ojgoo021oh7oPOn1onKon`3Poo/0POofoo/0g_ok0?[on`21ojgo
o021oh7oPOn1onKon`3Poo/0POofoo/0g_ok0?[on`21okoo06k_oo`0POn1oh7o
POoWoo/0gool087om?ok0=kon`3joo/0POn^oo`0POn1oh7oPOoWoo/0gool087o
m?ok0=kon`3joo/0POn^oo`0POn1oh7oPOoWoo/0gool087om?ok0=kon`3joo/0
POo0o`1^kool087oPOn1oh7oj?ok0=ooo021oo;on`3Noo/0n_ok087o[ool087o
POn1oh7oj?ok0=ooo021oo;on`3Noo/0n_ok087o[ool087oPOn1oh7oj?ok0=oo
o021oo;on`3Noo/0n_ok087o`Ol0K^ooo021oh7oPOn1onWon`3Ooo`0POo`oo/0
g_ok0?[on`21ok3oo021oh7oPOn1onWon`3Ooo`0POo`oo/0g_ok0?[on`21ok3o
o021oh7oPOn1onWon`3Ooo`0POo`oo/0g_ok0?[on`21ol;o06k_oo`0POn1oh7o
POoZoo/0gool087ok_ok0=kon`3joo/0POnaoo`0POn1oh7oPOoZoo/0gool087o
k_ok0=kon`3joo/0POnaoo`0POn1oh7oPOoZoo/0gool087ok_ok0=kon`3joo/0
POo3o`1^kool087oPOn1oh7ojook0=ooo021oncon`3Noo/0n_ok087o/_ol087o
POn1oh7ojook0=ooo021oncon`3Noo/0n_ok087o/_ol087oPOn1oh7ojook0=oo
o021oncon`3Noo/0n_ok087oa?l0K^ooo021oh7oPOn1oncon`3Ooo`0POoZoo/0
g_ok0?[on`21ok?oo021oh7oPOn1oncon`3Ooo`0POoZoo/0g_ok0?[on`21ok?o
o021oh7oPOn1oncon`3Ooo`0POoZoo/0g_ok0?[on`21olGo06k_oo`0POn1oh7o
POo]oo/0gool087oj?ol0=gon`3joo/0POndoo`0POn1oh7oPOo]oo/0gool087o
j?ol0=gon`3joo/0POndoo`0POn1oh7oPOo]oo/0gool087oj?ol0=gon`3joo/0
POo6o`1jkool087oPOn1oh7ok_ok0=ooo021onKoo03_o`00l?ok0?[on`21okGo
o021oh7oPOn1onkon`3Ooo`0POoVoo`0kol00?3on`3joo/0POneoo`0POn1oh7o
POo^oo/0gool087oi_ol0>oo003`oo/0n_ok087oaol0N^ooo021oh7oPOn1onoo
n`3Ooo`0POoToo`0l_om0?3on`3joo/0POnfoo`0POn1oh7oPOo_oo/0gool087o
i?ol0?;oo@3`oo/0n_ok087o]_ol087oPOn1oh7okook0=ooo021onCoo03bood0
l?ok0?[on`21olSo083_oo`0POn1oh7oPOo`oo/0gool087oh_ol0?KonP3_oo/0
n_ok0:Goo@2Goo`0POn1oh7oPOo`oo/0gool087oh_ol0?KonP3_oo/0n_ok0:Go
o@2Goo`0POn1oh7oPOo`oo/0gool087oh_ol0?KonP3_oo/0n_ok0:Goo@2Yo`20
kool087oPOn1oh7olOok0=ooo021on3oo03hooP0kook0?[on`2Vood0Uool087o
POn1oh7olOok0=ooo021on3oo03hooP0kook0?[on`2Vood0Uool087oPOn1oh7o
lOok0=ooo021on3oo03hooP0kook0?[on`2Vood0ZOl0P>ooo021oh7oPOn1oo;o
n`3Ooo`0POoNoo`0noof0>kon`3joo/0Yoom09Ooo021oh7oPOn1oo;on`3Ooo`0
POoNoo`0noof0>kon`3joo/0Yoom09Ooo021oh7oPOn1oo;on`3Ooo`0POoNoo`0
noof0>kon`3joo/0Yoom0:Wo08o_oo`0POn1oh7oPOocoo/0lOl1003aoo/0POoM
oo`0oOod0>kon`3joo/0Z?om09Ooo021oh7oPOn1oo?on`3ao`400?7on`21omgo
o03moo@0k_ok0?[on`2Xood0Uool087oPOn1oh7olook0?7o0@00lOok087ogOol
0?gom03^oo/0n_ok0:Soo@2Yo`26kool087oPOn1oh7om?ok0?7on`3eoo/0POoK
oo`00?ob0>gon`3joo/0POnkoo`0POn1oh7oPOodoo/0lOok0?Gon`21om_oo000
oo80kOok0?[on`21ok_oo021oh7oPOn1ooCon`3aoo/0mOok087ofool003olP3]
oo/0n_ok087ocOl0N^ooo021oh7oPOn1ooGon`3`ooT0n?ok087ofOo/0>gon`3j
oo/0POnloo`0POn1oh7oPOoeoo/0l?oi0?Son`21omWok03]oo/0n_ok087o_?ol
087oPOn1oh7omOok0?3on@3hoo/0POoIon`0kOok0?[on`21olko07[_oo`0POn1
oh7oPOofoo/0l?og0?[on`21omOok@3/oo/0n_ok087o_Ool087oPOn1oh7om_ok
0?3om`3joo/0POoGond0k?ok0?[on`21okgoo021oh7oPOn1ooKon`3`ooL0n_ok
087oeoo]0>con`3joo/0POo?o`1jkool087oPOn1oh7omook0>oomP3loo/0POoE
onh0jook0?[on`21okkoo021oh7oPOn1ooOon`3_ooH0o?ok087oeOo^0>_on`3j
oo/0POnnoo`0POn1oh7oPOogoo/0koof0?con`21omGokP3[oo/0n_ok087od?l0
ONooo021oh7oPOn1ooSon`3_oo<00Ooon`21omGok03[oo/0n_ok087o_ool087o
POn1oh7on?ok0>ool`01oook087oeOo/0>_on`3joo/0POnooo`0POn1oh7oPOoh
oo/0kooc007ooo/0POoEon`0jook0?[on`21om7o06k_oo`0POn1oh7oPOoioo/0
k_o/087oeOo[0>[on`3joo/0POo0oo`0POn1oh7oPOoioo/0k_o/087oeOo[0>[o
n`3joo/0POo0oo`0POn1oh7oPOoioo/0k_o/087oeOo[0>[on`3joo/0POoBo`1^
kool087oPOn1oh7on_ok0>kok021omGoj@3Zoo/0n_ok087o`Ool087oPOn1oh7o
n_ok0>kok021omGoj@3Zoo/0n_ok087o`Ool087oPOn1oh7on_ok0>kok021omGo
j@3Zoo/0n_ok087odol0K^ooo021oh7oPOn1oo_on`3]ond0POoEonP0jOok0?[o
n`21ol;oo021oh7oPOn1oo_on`3]ond0POoEonP0jOok0?[on`21ol;oo021oh7o
POn1oo_on`3]ond0POoEonP0jOok0?[on`21omCo06k_oo`0POn1oh7oPOoloo/0
kOo/087oeOoW0>Won`3joo/0POo3oo`0POn1oh7oPOoloo/0kOo/087oeOoW0>Wo
n`3joo/0POo3oo`0POn1oh7oPOoloo/0kOo/087oeOoW0>Won`3joo/0POoEo`1^
kool087oPOn1oh7ooOok0>coj`21omOoiP3Xoo/0n_ok087oa?ol087oPOn1oh7o
oOok0>coj`21omOoiP3Xoo/0n_ok087oa?ol087oPOn1oh7ooOok0>coj`21omOo
iP3Xoo/0n_ok087oe_l0K^ooo021oh7oPOn1ookon`3/onT0POoIon@0j?ok0?[o
n`21olGoo021oh7oPOn1ookon`3/onT0POoIon@0j?ok0?[on`21olGoo021oh7o
POn1ookon`3/onT0POoIon@0j?ok0?[on`21omOo077_oo`0POn1oh7oPOl1oook
0>_oj@21omWoi03Woo/0n_ok087oa_ol087oPOn1oh7o0Ooon`3[onT0POoIon@0
iook0?[on`21olKoo021oh7oPOn1o`7ooo/0jooY087ofOoT0>Oon`3joo/0POoH
o`1^kool087oPOn1oh7o0?ok0>_oi`21om_oh`3Voo/0n_ok087oaool087oPOn1
oh7o0?ok0>_oi`21om_oh`3Voo/0n_ok087oaool087oPOn1oh7o0?ok0>_oi`21
om_oh`3Voo/0n_ok087ofOl0LNooo021oh7oPOn1oo/0j_oV087og?oR0>Kon`3j
oo/0]ol1002Doo`0POn1oh7oPOok0>[oiP21omcohP3Voo/0n_ok0;Oo0@00U?ol
087oPOn1oh7on`3ZonH0POoLon80i_ok0?[on`2go`400:Ko06k_oo`0POn1oh7o
P_ok0>[oi@21omgoh@3Uoo/0n_ok0;[on`2Foo`0POn1oh7oP_ok0>[oi@21omgo
h@3Uoo/0n_ok0;[on`2Foo`0POn1oh7oP_ok0>[oi@21omgoh@3Uoo/0n_ok0;[o
n`2Xo`1^kool087oPOn1oh?on`3Yon@0POoNon00iOok0?[on`2mooL0V?ol087o
POn1oh?on`3Yon@0POoNon00iOok0?[on`2mooL0V?ol087oPOn1oh?on`3Yon@0
POoNon00iOok0?[on`2mooL0Z_l0K^ooo021oh7oPOn4oo/0jOoS087ogooO0>Co
n`3joo/0`Ooa09_oo021oh7oPOn4oo/0jOoS087ogooO0>Con`3joo/0`Ooa09_o
o021oh7oPOn4oo/0jOoS087ogooO0>Con`3joo/0`Ooa0:go06k_oo`0POn1oh7o
QOok0>SohP21omgoh@3Too/0n_ok0<?ok`2Loo`0POn1oh7oQOok0>SohP21omgo
h@3Too/0n_ok0<?ok`2Loo`0POn1oh7oQOok0>SohP21omgoh@3Too/0n_ok0<?o
k`2^o`1jkool087oPOn1ohKon`3Xon40POoKon<0hook0?[on`34ooT00?og09go
o021oh7oPOn6oo/0j?oQ087ofooS0>?on`3joo/0a?oi003om`2Moo`0POn1oh7o
Q_ok0>Soh@21om_oh`3Soo/0n_ok0<Con@00ooL0[ol0N^ooo021oh7oPOn7oo/0
iooP087of_oT0>?on`3joo/0a_oj0?kom`2Moo`0POn1oh7oQook0>Ooh021om[o
i03Soo/0n_ok0<KonP3nooL0WOol087oPOn1ohOon`3Won00POoJon@0hook0?[o
n`36ooX0o_og0:oo08W_oo`0POn1oh7oR?ok0>Koh021omSoiP3Roo/0n_ok0<So
o03kood00Oooo02Noo`0POn1oh7oR?ok0>Koh021omSoiP3Roo/0n_ok0<Soo03k
ood00Oooo02Noo`0POn1oh7oR?ok0>Koh021omSoiP3Roo/0n_ok0<Soo03kood0
0Oooo02`o`1jkool087oPOn1ohWon`3Von40POoDonP0hOok0?[on`3:oo`0lool
09ooo021oh7oPOn9oo/0i_oQ087oe?oX0>7on`3joo/0b_ol0??oo02Ooo`0POn1
oh7oROok0>Koh@21omCoj03Qoo/0n_ok0<[oo03coo`0/Ol0N^ooo021oh7oPOn:
oo/0iOoS087od?oY0>7on`3joo/0boom0?7oo02Poo`0POn1oh7oR_ok0>Goh`21
om3oj@3Qoo/0n_ok0<_oo@3aoo`0X?ol087oPOn1oh[on`3Uon<0POo@onT0hOok
0?[on`3;ood0lOol0;;o07[_oo`0POn1oh7oRook0>Goh`21olgoj`3Poo/0n_ok
0<goo03`ood0X?ol087oPOn1oh_on`3Uon<0POo=on/0h?ok0?[on`3=oo`0l?om
0:3oo021oh7oPOn;oo/0iOoS087ocOo[0>3on`3joo/0cOol0?3oo@2bo`1jkool
087oPOn1ohcon`3TonD0POo:on/0h?ok0?[on`3?oo`0kool0:7oo021oh7oPOn<
oo/0i?oU087ob_o[0>3on`3joo/0cool0>ooo02Qoo`0POn1oh7oS?ok0>Coi@21
ol[oj`3Poo/0n_ok0<ooo03_oo`0/ol0N^ooo021oh7oPOn=oo/0i?oU087oaoo]
0=oon`3joo/0dOol0>goo02Roo`0POn1oh7oSOok0>Coi@21olOok@3Ooo/0n_ok
0=7oo03]oo`0X_ol087oPOn1ohgon`3TonD0POo7ond0gook0?[on`3Aoo`0kOol
0;Co07[_oo`0POn1oh7oS_ok0>?oi`21ol?okP3Ooo/0n_ok0=;oo@3/oo`0X_ol
087oPOn1ohkon`3SonL0POo3onh0gook0?[on`3Bood0k?ol0:;oo021oh7oPOn>
oo/0hooW087o`oo^0=oon`3joo/0d_om0>coo02do`1jkool087oPOn1ohoon`3S
onT0POnnoo00g_ok0?[on`3Doo`0joom0:;oo021oh7oPOn?oo/0hooY087o__o`
0=kon`3joo/0e?ol0>_oo@2Roo`0POn1oh7oSook0>?oj@21okkol03Noo/0n_ok
0=Coo03[ood0]?l0N^ooo021oh7oPOn@oo/0h_o[087o^_oa0=kon`3joo/0eOom
0>[oo02Soo`0POn1oh7oT?ok0>;oj`21ok[ol@3Noo/0n_ok0=Goo@3Zoo`0Xool
087oPOn1oi3on`3Ron/0POnjoo40g_ok0?[on`3Eood0j_ol0;Go07[_oo`0POn1
oh7oTOok0>;ok@21okGol`3Moo/0n_ok0=Ooo03Yood0Xool087oPOn1oi7on`3R
ond0POneoo<0gOok0?[on`3Goo`0jOom0:?oo021oh7oPOnAoo/0h_o]087o]Ooc
0=gon`3joo/0eool0>Woo@2eo`1jkool087oPOn1oi;on`3Qonl0POn`ooH0g?ok
0?[on`3Hood0j?ol0:Coo021oh7oPOnBoo/0hOo_087o/?of0=con`3joo/0f?om
0>Soo02Too`0POn1oh7oT_ok0>7ok`21ok3omP3Loo/0n_ok0=Soo@3Xoo`0]_l0
N^ooo021oh7oPOnCoo/0hOo_087o[Oog0=con`3joo/0f_ol0>Ooo@2Too`0POn1
oh7oTook0>7ok`21ojgom`3Loo/0n_ok0=[oo03Wood0Y?ol087oPOn1oi?on`3Q
onl0POn]ooL0g?ok0?[on`3Joo`0ioom0;Ko07[_oo`0POn1oh7oU?ok0>3ol@21
ojWon@3Koo/0n_ol0=_oo03Voo`0YOol087oPOn1oiCon`3Poo40POnYooT0fook
0?[oo03Koo`0i_ol0:Goo021oh7oPOnDoo/0h?oa087oZOoi0=_on`3joo`0fool
0>Koo02go`1jkool087oPOn1oiGon`3Poo80POnUooX0fook0?[oo03Loo`0iOom
0:Goo021oh7oPOnEoo/0h?ob087oYOoj0=_on`3joo`0g?ol0>Goo@2Uoo`0POn1
oh7oUOok0>3olP21ojGonP3Koo/0n_ol0=coo03Uood0]ol0N^ooo021oh7oPOnF
oo/0good087oXOol0=[on`3joo`0g_ol0>Coo02Voo`0POn1oh7oU_ok0=oom021
oj7oo03Joo/0n_ol0=koo03Too`0Y_ol087oPOn1oiKon`3Ooo@0POnQoo`0f_ok
0?[oo03Noo`0i?ol0;So07[_oo`0POn1oh7oUook0=oom021oikoo@3Joo/0nook
0=ooo03Sood0Y_ol087oPOn1oiOon`3Ooo@0POnNood0f_ok0?_on`3Ooo`0hoom
0:Koo021oh7oPOnGoo/0good087oW_om0=[on`3koo/0gool0>?oo@2ho`1mkool
087oPOn1oiSon`3NooH0POnJo`400=Won`3koo/0hOol0>;oo02Woo`0POn1oh7o
V?ok0=komP21oi[o0@00fOok0?_on`3Qoo`0h_ol0:Ooo021oh7oPOnHoo/0g_of
087oV_l1003Ioo/0nook0>7oo03Roo`0^Ol0N^ooo021oh7oPOnIoo/0g_og087o
U_l00=Won`3koo/0h_ol0>7oo@2Woo`0POn1oh7oVOok0=kom`21oiKo003Ioo/0
nook0>;oo03Qood0Yool087oPOn1oiWon`3NooL0POnFo`00fOok0?_on`3Roo`0
hOom0;Wo083_oo`0POn1oh7oV_ok0=gon@21oh7oj_ok0?_on`3Sood0l?om0?Go
o@2Woo`0POn1oh7oV_ok0=gon@21oh7oj_ok0?_on`3Sood0l?om0?Goo@2Woo`0
POn1oh7oV_ok0=gon@21oh7oj_ok0?_on`3Sood0l?om0?Goo@2io`20kool087o
POn1oi_on`3MooX0POn1onOon`3koo/0iOol0?3oo@3eoo`0Z?ol087oPOn1oi_o
n`3MooX0POn1onOon`3koo/0iOol0?3oo@3eoo`0Z?ol087oPOn1oi_on`3MooX0
POn1onOon`3koo/0iOol0?3oo@3eoo`0^_l0P>ooo021oh7oPOnLoo/0g?ol087o
POoToo/0nook0>Koo@3_ood0m?om0:Soo021oh7oPOnLoo/0g?ol087oPOoToo/0
nook0>Koo@3_ood0m?om0:Soo021oh7oPOnLoo/0g?ol087oPOoToo/0nook0>Ko
o@3_ood0m?om0;[o083_oo`0POn1oh7oWOok0=coo@21oh7ohOok0?_on`3Wood0
koom0?Coo@2Xoo`0POn1oh7oWOok0=coo@21oh7ohOok0?_on`3Wood0koom0?Co
o@2Xoo`0POn1oh7oWOok0=coo@21oh7ohOok0?_on`3Wood0koom0?Coo@2jo`1X
kool087oPOn1oikon`21oh7o]_ok0?_on`3Yoo`0g_ol0:Woo021oh7oPOnNoo/0
POn1okKon`3koo/0jOol0=koo02Yoo`0POn1oh7oW_ok087oPOnfoo/0nook0>Wo
o03Noo`0^ol0J>ooo021oh7oPOnOoo/0POn1okCon`3koo/0j_om0=coo@2Yoo`0
POn1oh7oWook087oPOndoo/0nook0>[oo@3Lood0ZOol087oPOn1oioon`21oh7o
]?ok0?_on`3Zood0g?om0;_o06S_oo`0POn1oh7oX?ok087oPOnboo/0nook0>_o
o@3Lood0ZOol087oPOn1oj3on`21oh7o/_ok0?_on`3[ood0g?om0:Woo021oh7o
POnPoo/0POn1ok;on`3koo/0joom0=coo@2ko`1Xkool087oPOn1oj7on`21oh7o
/?ok0?_on`3]oo`0g?om0:Woo021oh7oPOnQoo/0POn1ok3on`3koo/0kOol0=co
o@2Yoo`0POn1oh7oXOok087oPOn`oo/0nook0>goo03Lood0^ol0J>ooo021oh7o
POnRoo/0POn1ojkon`3koo/0k_om0=_oo02Zoo`0POn1oh7oX_ok087oPOn^oo/0
nook0>koo@3Koo`0Z_ol087oPOn1oj;on`21oh7o[_ok0?_on`3^ood0fool0;co
06S_oo`0POn1oh7oXook087oPOn/oo/0nook0?3oo03Jood0Z_ol087oPOn1oj?o
n`21oh7o[?ok0?_on`3`oo`0f_om0:[oo021oh7oPOnSoo/0POn1ojcon`3koo/0
l?ol0=[oo@2lo`1Xkool087oPOn1ojCon`21oh7oZ_ok0?_on`3aood0fOom0:[o
o021oh7oPOnToo/0POn1oj[on`3koo/0lOom0=Woo@2Zoo`0POn1oh7oY?ok087o
POnZoo/0nook0?7oo@3Iood0_?l0J>ooo021oh7oPOnUoo/0POn1ojSon`3koo/0
l_om0=Woo02[oo`0POn1oh7oYOok087oPOnXoo/0nook0?;oo@3Ioo`0Zool087o
POn1ojGon`21oh7oZ?ok0?_on`3bood0fOol0;go06S_oo`0POn1oh7oY_ok087o
POnVoo/0nook0?Coo03Hood0Zool087oPOn1ojKon`21oh7oY_ok0?_on`3doo`0
f?om0:_oo021oh7oPOnVoo/0POn1ojKon`3koo/0m?ol0=Soo@2mo`1Xkool087o
POn1ojOon`21oh7oY?ok0?_on`3eood0eoom0:_oo021oh7oPOnWoo/0POn1ojCo
n`3koo/0mOom0=Ooo@2[oo`0POn1oh7oYook087oPOnToo/0nook0?Goo@3Good0
_Ol0J>ooo021oh7oPOnXoo/0POn1oj;on`3koo/0m_om0=Ooo@2[oo`0POn1oh7o
Z?ok087oPOnRoo/0nook0?Koo@3Good0Zool087oPOn1ojSon`21oh7oX_ok0?_o
n`3food0eoom0;go06S_oo`0POn1oh7oZOok087oPOnPoo/0nook0?Soo03Goo`0
[?ol087oPOn1ojWon`21oh7oX?ok0?_on`3hoo`0eool0:coo021oh7oPOnYoo/0
POn1oj3on`3koo/0n?ol0=Ooo02no`1Xkool087oPOn1oj[on`21oh7oW_ok0?_o
n`3iood0eOom0:coo021oh7oPOnZoo/0POn1oikon`3koo/0nOom0=Goo@2/oo`0
POn1oh7oZ_ok087oPOnNoo/0nook0?Woo@3Eood0__l0J>ooo021oh7oPOn[oo/0
POn1oicon`3koo/0n_om0=Goo@2/oo`0POn1oh7oZook087oPOnLoo/0nook0?[o
o@3Eood0[?ol087oPOn1oj_on`21oh7oW?ok0?_on`3jood0eOom0;ko06S_oo`0
POn1oh7o[?ok087oPOnJoo/0nook0?coo03Eoo`0[Ool087oPOn1ojcon`21oh7o
V_ok0?_on`3loo`0eOol0:goo021oh7oPOn/oo/0POn1oi[on`3koo/0o?ol0=Go
o02oo`1Xkool087oPOn1ojgon`21oh7oV?ok0?_on`3mood0doom0:goo021oh7o
POn]oo/0POn1oiSon`3koo/0oOom0=?oo@2]oo`0POn1oh7o[Ook087oPOnHoo/0
nook0?goo@3Cood0_ol0Jnooo021oh7oPOn^oo/0POn1oiKon`3koo/00Oooo03C
ood0[Ool087oPOn1ojkon`21oh7oU_ok0?_on`01oool0=?oo@2]oo`0POn1oh7o
[_ok087oPOnFoo/0nook007ooo`0doom0;oo07C_oo`0POn1oh7o[ook087oPOnD
oo/0nook003oo@3Xood0kool0:koo021oh7oPOn_oo/0POn1oiCon`3koo/00?om
0>Soo@3_oo`0[_ol087oPOn1ojoon`21oh7oU?ok0?_on`00ood0j?om0>ooo030
o`1Xkool087oPOn1ok3on`21oh7oT_ok0?_om`3Xood0k_om0:koo021oh7oPOn`
oo/0POn1oi;on`3kooL0j?om0>koo@2^oo`0POn1oh7o/?ok087oPOnBoo/0noog
0>Soo@3^ood0`?l0J>ooo021oh7oPOnaoo/0POn1oi3on`3kooT0ioom0>koo02_
oo`0POn1oh7o/Ook087oPOn@oo/0nooi0>Ooo@3^oo`0[ool087oPOn1ok7on`21
oh7oT?ok0?_on@3Wood0k_ol0<7o06S_oo`0POn1oh7o/_ok087oPOn>oo/0nooj
0>Ooo@3^oo`0[ool087oPOn1ok;on`21oh7oS_ok0?_onP3Wood0k_ol0:ooo021
oh7oPOnboo/0POn1ohkon`3kooX0ioom0>koo031o`1Lkool087oPOn1ok?on`21
oh7oS?ok0?_on`3?ood0[ool087oPOn1ok?on`21oh7oS?ok0?_on`3?ood0[ool
087oPOn1ok?on`21oh7oS?ok0?_on`3?ood0`Ol0G>ooo021oh7oPOndoo/0POn1
oh[on`3looX0d?ol0;3oo021oh7oPOndoo/0POn1oh[on`3looX0d?ol0;3oo021
oh7oPOndoo/0POn1oh[on`3looX0d?ol0<;o05c_oo`0POn1oh7o]Ook087oPOn8
oo/0oOoi0=7oo02`oo`0POn1oh7o]Ook087oPOn8oo/0oOoi0=7oo02`oo`0POn1
oh7o]Ook087oPOn8oo/0oOoi0=7oo032o`1[kool087og?ol087oPOoPoo/0POn1
ohKon`01ooog0=7oo@2`oo`0POoLoo`0POn1on3on`21oh7oQ_ok007oooL0dOom
0;3oo021omcoo021oh7oh?ok087oPOn6oo/00Ooom`3Aood0`_l0J>ooo021omco
o021oh7ohOok087oPOn4oo/00?of0=;oo02aoo`0POoLoo`0POn1on7on`21oh7o
Q?ok003omP3Boo`0/Ool087og?ol087oPOoQoo/0POn1ohCon`00ooH0d_ol0<?o
06__oo`0POoLoo`0POn1on;on`21oh7oP_og007ooo/0dool0;7oo021omcoo021
oh7oh_ok087oPOn2ooL00Ooon`3Coo`0/Ool087og?ol087oPOoRoo/0POn1oh;o
m`01oook0=?oo033o`1^kool087og?ol087oPOoSoo/0POn1oh7o0?oh0?kon`3C
ood0/Ool087og?ol087oPOoSoo/0POn1oh7o0?oh0?kon`3Cood0/Ool087og?ol
087oPOoSoo/0POn1oh7o0?oh0?kon`3Cood0`ol0K^ooo021omcoo021oh7oi?ok
087oPOn1ookonP3loo/0e?ol0;;oo021omcoo021oh7oi?ok087oPOn1ookonP3l
oo/0e?ol0;;oo021omcoo021oh7oi?ok087oPOn1ookonP3loo/0e?ol0<Co06k_
oo`0POoLoo`0POn1onGon`21oh7oPOoloo/0nook0=Goo02boo`0POoLoo`0POn1
onGon`21oh7oPOoloo/0nook0=Goo02boo`0POoLoo`0POn1onGon`21oh7oPOol
oo/0nook0=Goo034o`1^kool087ohOo_087oPOo^oo/0POn1oh7on_ok0?_on`3E
oo`0/ool087ohOo_087oPOo^oo/0POn1oh7on_ok0?_on`3Eoo`0/ool087ohOo_
087oPOo^oo/0POn1oh7on_ok0?_on`3Eoo`0aOl0K^ooo021on7ok`21oh7okook
087oPOn1oo[on@3koo/0e_ol0;?oo021on7ok`21oh7okook087oPOn1oo[on@3k
oo/0e_ol0;?oo021on7ok`21oh7okook087oPOn1oo[on@3koo/0e_ol0<Go06k_
oo`0POoQonl0POn1oo3on`21oh7oPOoiooP0nook0=Koo02doo`0POoQonl0POn1
oo3on`21oh7oPOoiooP0nook0=Koo02doo`0POoQonl0POn1oo3on`21oh7oPOoi
ooP0nook0=Koo036o`1jkool087ohOo_087oPOoaoo/0POn1oh7onOom003on`3k
oo/0eook0;Goo021on7ok`21oh7olOok087oPOn1ooWoo@00oo/0nook0=Oon`2e
oo`0POoQonl0POn1oo7on`21oh7oPOoiood00?ok0?_on`3Goo/0aol0ONooo021
omcoo021oh7oj_ok087oPOn1ooWoo001oook0?_on`3Goo`0]Ool087og?ol087o
POoZoo/0POn1oh7onOol007ooo/0nook0=Ooo02eoo`0POoLoo`0POn1on[on`21
oh7oPOoioo`00Ooon`3koo/0eool0<Oo07[_oo`0POoLoo`0POn1on_on`21oh7o
POoioo`0oOok0?_on`3Goo`0]_ol087og?ol087oPOo[oo/0POn1oh7onOol0?go
n`3koo/0eool0;Koo021omcoo021oh7ojook087oPOn1ooWoo03moo/0nook0=Oo
o038o`1jkool087og?ol087oPOo/oo/0POn1oh7onOol0?_on`3koo/0f?ok0;Oo
o021omcoo021oh7ok?ok087oPOn1ooWoo03koo/0nook0=Son`2goo`0POoLoo`0
POn1oncon`21oh7oPOoioo`0nook0?_on`3Hoo/0bOl0Q^ooo021omcoo021oh7o
kOok087oPOn1ooWoo03ioo/0nook0?Ooo@3Voo`0]ool087og?ol087oPOo]oo/0
POn1oh7onOol0?Won`3koo/0moom0>Koo02goo`0POoLoo`0POn1ongon`21oh7o
POoioo`0nOok0?_on`3good0i_ol0<Wo08K_oo`0POoLoo`0POn1onkon`21oh7o
POohoo`0n?ok0?_on`3hood0iOol0;Soo021omcoo021oh7ok_ok087oPOn1ooSo
o03hoo/0nook0?Soo@3Uoo`0^?ol087og?ol087oPOo^oo/0POn1oh7on?ol0?So
n`3koo/0n?om0>Goo03:o`26kool087og?ol087oPOo_oo/0POn1oh7on?ol0?Ko
n`3koo/0nOom0>Gon`2ioo`0POoLoo`0POn1onoon`21oh7oPOohoo`0m_ok0?_o
n`3iood0iOok0;Woo021omcoo021oh7okook087oPOn1ooSoo03foo/0nook0?Wo
o@3Uoo/0bol0Q^ooo021omcoo021oh7ol?ok087oPOn1ooSoo03doo/0nook0?[o
o@3Too`0^Ool087og?ol087oPOo`oo/0POn1oh7on?ol0?Con`3koo/0n_om0>Co
o02ioo`0POoLoo`0POn1oo3on`21oh7oPOohoo`0m?ok0?_on`3jood0i?ol0<_o
07[_oo`0POoLoo`0POn1oo7on`21oh7oPOojooX0l_ok0?_on`3Ioo`0^_ol087o
g?ol087oPOoaoo/0POn1oh7on_oj0?;on`3koo/0fOol0;[oo021omcoo021oh7o
lOok087oPOn1oo[onP3boo/0nook0=Woo03<o`1jkool087og?ol087oPOoboo/0
POn1oh7on_oi0?7on`3koo/0f_ok0;_oo021omcoo021oh7ol_ok087oPOn1oo[o
n@3aoo/0nook0=[on`2koo`0POoLoo`0POn1oo;on`21oh7oPOojooT0lOok0?_o
n`3Joo/0cOl0N^ooo021omcoo021oh7olook087oPOn1oo_on03_oo/0nook0=[o
n`2loo`0POoLoo`0POn1oo?on`21oh7oPOokooP0kook0?_on`3Joo/0_?ol087o
g?ol087oPOocoo/0POn1oh7onooh0>oon`3koo/0f_ok0<ko083_oo`0POoLoo`0
k?ol087oS_ok087oPOn1oo_on@3/oo/0nook0=[on`2moo`0POoLoo`0k?ol087o
S_ok087oPOn1oo_on@3/oo/0nook0=[on`2moo`0POoLoo`0k?ol087oS_ok087o
POn1oo_on@3/oo/0nook0=[on`3?o`2<kool087og?ol0>coo03?oo/0POo7oo/0
POn1oh7oo?oi0>Won`3koo/0f_oj0;ooo021omcoo03/oo`0cook087oaook087o
POn1oocon@3Yoo/0nook0=[onP2ooo`0POoLoo`0k?ol0<oon`21olOon`21oh7o
POolooT0jOok0?_on`3JooX0dOl0S>ooo021omcoo03/oo`0d_oh087ob?ok087o
POn1oogon03Woo/0nook0=Won`30oo`0POoLoo`0k?ol0=;on021olSon`21oh7o
POomooP0iook0?_on`3Ioo/0`?ol087og?ol0>coo03BooP0POo8oo/0POn1oh7o
oOoh0>Oon`3koo/0fOok0=;o08c_oo`0POoLoo`0k?ol0=Gom@21olWon`21oh7o
POomooT0i?ok0?_on`3IooX0`_ol087og?ol0>coo03EooD0POo9oo/0POn1oh7o
oOoi0>Con`3koo/0fOoj0<;oo021omcoo03/oo`0eOoe087obOok087oPOn1oogo
n@3Too/0nook0=WonP3Do`2<kool087og?ol0>coo03Foo@0POo:oo/0POn1oh7o
o_oi0>7on`3koo/0fOoj0<?oo021omcoo03/oo`0e_od087ob_ok087oPOn1ooko
n@3Qoo/0nook0=WonP33oo`0POoLoo`0k?ol0=Kom021ol[on`21oh7oPOonooT0
hOok0?_on`3IooX0eOl0N^ooo021omcoo02loo@0POo;oo/0POn1oh?om@3Noo/0
nook0=Som`38oo`0POoLoo`0_?od087obook087oPOn3ooD0g_ok0?_on`3HooL0
b?ol087og?ol0;com021ol_on`21oh7oPooe0=kon`3koo/0f?og0=[o07[_oo`0
POoLoo`0_?od087oc?ok087oPOn:onh0g?ok0?_on`3Hoo80c_ol087og?ol0;co
m021olcon`21oh7oR_o^0=con`3koo/0f?ob0<koo021omcoo02loo@0POo<oo/0
POn1oh[okP3Loo/0nook0=SolP3Po`26kool087og?ol0;coo03noo`0POo=oo/0
POn1ohWol03Ioo/0nook0=Sol`3>oo`0POoLoo`0_?ol0?koo021olgon`21oh7o
ROo`0=Won`3koo/0f?oc0<koo021omcoo02loo`0o_ol087ocOok087oPOn9oo00
fOok0?_on`3Hoo<0h?l0RNooo021omcon`2mo`400?_oo021olkon`21oh7oR?oa
0=Oon`3koo/0f?od0<koo021omcon`2mo`400?_oo021olkon`21oh7oR?oa0=Oo
n`3koo/0f?od0<koo021omcon`2mo`400?_oo021olkon`21oh7oR?oa0=Oon`3k
oo/0f?od0>3o05C_oo`0POoKoo`0]Ool0?SoP@210840P@210;D0kool087ofool
0;Goo03hoh40P@210840P@2e0>ooo021om_oo02eoo`0n?n10840P@210840]@00
H>ooo021om_onP3lo`00_Ool0?SoP@210840P@210;D0kool087ofooj0?co002m
oo`0n?n10840P@210840]@3_oo`0POoKooX0o?l00;goo03hoh40P@210840P@2e
001/kool087ofood0?Goo03`ood0hool0?SoP@210840P@210;D0kool087ofood
0?Goo03`ood0hool0?SoP@210840P@210;D0kool087ofood0?Goo03`ood0hool
0?SoP@210840P@210;D006c_oo`0POoJooD0mOol0?3oo@3Soo`0n?n10840P@21
0840]@3_oo`0POoJooD0mOol0?3oo@3Soo`0n?n10840P@210840]@3_oo`0POoJ
ooD0mOol0?3oo@3Soo`0n?n10840P@210840]@00S>ooo021omWomP3eoo`0l?om
0>?oo021om?on`21oh7oPOoFooD0nook0?_on`2Moo`0POoIooH0mOol0?3oo@3S
oo`0POoCoo/0POn1oh7oe_oe0?_on`3koo/0WOol087ofOof0?Goo03`ood0hool
087odook087oPOn1omKom@3koo/0nook0:oo09__oo`0POoFoo/0lool0?3oo@3S
oo`0POoDoo/0POn1oh7oe_ok007ooo/0nook0?_on`2Noo`0POoFoo/0lool0?3o
o@3Soo`0POoDoo/0POn1oh7oe_ok007ooo/0nook0?_on`2Noo`0POoFoo/0lool
0?3oo@3Soo`0POoDoo/0POn1oh7oe_ok007ooo/0nook0?_on`2`o`2<kool087o
`_ol0?3oo@3Soo`0POoEoo/0POn1oh7oe_ok0?gon`3koo/0nook09ooo021ol;o
o03`ood0hool087oeOok087oPOn1omKon`3moo/0nook0?_on`2Ooo`0POo2oo`0
l?om0>?oo021omGon`21oh7oPOoFoo/0oOok0?_on`3koo/0/Ol0S>ooo021ol;o
o03`ood0hool087oe_ok087oPOn1omKon`3koo/0nook0?_on`2Poo`0POo2oo`0
l?om0>?oo021omKon`21oh7oPOoFoo/0nook0?_on`3koo/0X?ol087o`_ol0?3o
o@3Soo`0POoFoo/0POn1oh7oe_ok0?_on`3koo/0nook0;;o08c_oo`0POo2oo`0
l?om0>?oo021omOon`21oh7oPOoFoo/0nOok0?_on`3koo/0XOol087o`_ol0?3o
o@3Soo`0POoGoo/0POn1oh7oe_ok0?Won`3koo/0nook0:7oo021ol;oo03`ood0
hool087oeook087oPOn1omKon`3ioo/0nook0?_on`2co`2<kool087o`_ol0?3o
o@3Soo`0POoHoo/0POn1oh7oe_ok0?Oon`3koo/0nook0:;oo021ol;oo03`ood0
hool087of?ok087oPOn1omKon`3goo/0nook0?_on`2Roo`0POo2oo`0l?om0>?o
o021omSon`21oh7oPOoFoo/0mook0?_on`3koo/0]?l0S>ooo021ol;oo03`ood0
hool087ofOok087oPOn1omKon`3eoo/0nook0?_on`2Soo`0POo2oo`0l?om0>?o
o021omWon`21oh7oPOoFoo/0mOok0?_on`3koo/0Xool087o`_ol0?3oo@3Soo`0
POoIoo/0POn1oh7oe_ok0?Gon`3koo/0nook0;Go08c_oo`0POo2oo`0l?om0>?o
o021om[on`21oh7oPOoFoo/0look0?_on`3koo/0Y?ol087o`_ol0?3oo@3Soo`0
POoJoo/0POn1oh7oe_ok0??on`3koo/0nook0:Coo021ol;oo03`ood0hool087o
f_ok087oPOn1omKon`3coo/0nook0?_on`2fo`2<kool087o`_ol0?3oo@3Soo`0
POoKoo/0POn1oh7oe_ok0?7on`3koo/0nook0:Goo021ol;oo03`ood0hool087o
fook087oPOn1omKon`3aoo/0nook0?_on`2Uoo`0POo2oo`0l?om0>?oo021om_o
n`21oh7oPOoFoo/0lOok0?_on`3koo/0]ol0S>ooo021ol;oo03`ood0hool087o
g?ok087oPOn1omKon`3_oo/0nook0?_on`2Voo`0POo2oo`0l?om0>?oo021omco
n`21oh7oPOoFoo/0kook0?_on`3koo/0Y_ol087o`_ol0?3oo@3Soo`0POoLoo/0
POn1oh7oe_ok0>oon`3koo/0nook0;So08c_oo`0POo2oo`0o?oU0>ooo021omgo
n`21oh7oPOoFoo/0kOok0?_on`3koo/0Yool087o`_ol0?coi@3_oo`0POoMoo/0
POn1oh7oe_ok0>gon`3koo/0nook0:Ooo021ol;oo03lonD0kool087ogOok087o
POn1omKon`3]oo/0nook0?_on`2io`2<kool087o`_ol0?coi@3_oo`0POoNoo/0
POn1oh7oe_ok0>_on`3koo/0nook0:Soo021ol;oo03lonD0kool087og_ok087o
POn1omKon`3[oo/0nook0?_on`2Xoo`0POo2oo`0o?oU0>ooo021omkon`21oh7o
POoFoo/0jook0?_on`3koo/0^_l0S>ooo021ol;oo03lonD0kool087ogook087o
POn1omKon`3Yoo/0nook0?_on`2Yoo`0POo2oo`0o?oU0>ooo021omoon`21oh7o
POoFoo/0jOok0?_on`3koo/0ZOol087o`_ol0?coi@3_oo`0POoOoo/0POn1oh7o
e_ok0>Won`3koo/0nook0;_o08c_oo`0POo2oo`0o?oU0>ooo021on3on`21oh7o
POoFoo/0iook0?_on`3koo/0Z_ol087o`_ol0?coi@3_oo`0POoPoo/0POn1oh7o
e_ok0>Oon`3koo/0nook0:[oo021ol;oo03lonD0kool087oh?ok087oPOn1omKo
n`3Woo/0nook0?_on`2lo`2<kool087o`_ol0?3oo@3Soo`0POoQoo/0POn1oh7o
e_ok0>Gon`3koo/0nook0:_oo021ol;oo03`ood0hool087ohOok087oPOn1omKo
n`3Uoo/0nook0?_on`2[oo`0POo2oo`0l?om0>?oo021on7on`21oh7oPOoFoo/0
iOok0?_on`3koo/0_Ol0S>ooo021ol;oo03`ood0hool087oh_ok087oPOn1omKo
n`3Soo/0nook0?_on`2/oo`0POo2oo`0l?om0>?oo021on;on`21oh7oPOoFoo/0
hook0?_on`3koo/0[?ol087o`_ol0?3oo@3Soo`0POoRoo/0POn1oh7oe_ok0>?o
n`3koo/0nook0;ko08c_oo`0POo2oo`0l?om0>?oo021on?on`21oh7oPOoFoo/0
hOok0?_on`3koo/0[Ool087o`_ol0?3oo@3Soo`0POoSoo/0POn1oh7oe_ok0>7o
n`3koo/0nook0:goo021ol;oo03`ood0hool087ohook087oPOn1omKon`3Qoo/0
nook0?_on`2oo`2<kool087o`_ol0?3oo@3Soo`0POoToo/0POn1oh7oe_ok0=oo
n`3koo/0nook0:koo021ol;oo03`ood0hool087oi?ok087oPOn1omKon`3Ooo/0
nook0?_on`2^oo`0POo2oo`0l?om0>?oo021onCon`21oh7oPOoFoo/0gook0?_o
n`3koo/0`?l0S>ooo021ol;oo03`ood0hool087oiOok087oPOn1omKon`3Moo/0
nook0?_on`2_oo`0POo2oo`0l?om0>?oo021onGon`21oh7oPOoFoo/0gOok0?_o
n`3koo/0[ool087o`_ol0?3oo@3Soo`0POoUoo/0POn1oh7oe_ok0=gon`3koo/0
nook0<7o08c_oo`0POo2oo`0l?om0>?oo021onKon`21oh7oPOoFoo/0fook0?_o
n`3koo/0/?ol087o`_ol0?3oo@3Soo`0POoVoo/0POn1oh7oe_ok0=_on`3koo/0
nook0;3oo021ol;oo03`ood0hool087oi_ok087oPOn1omKon`3Koo/0nook0?_o
n`32o`2<kool087o`_ol0?3oo@3Soo`0POoWoo/0POn1oh7oe_ok0=Won`3koo/0
nook0;7oo021ol;oo03`ood0hool087oiook087oPOn1omKon`3Ioo/0nook0?_o
n`2aoo`0POo2oo`0l?om0>?oo021onOon`21oh7oPOoFoo/0fOok0?_on`3koo/0
`ol0S>ooo021ol;oo03`ood0hool087oj?ok087oPOn1omKon`3Goo/0nook0?_o
n`2boo`0POo2oo`0l?om0>?oo021onSon`21oh7oPOoFoo/0eook0?_on`3koo/0
/_ol087o`_ol0?3oo@3Soo`0POoXoo/0POn1oh7oe_ok0=Oon`3koo/0nook0<Co
08c_oo`0POo2oo`0l?om0>?oo021onWon`21oh7oPOoFoo/0eOok0?_on`3koo/0
/ool087o`_ol0?3oo@3Soo`0POoYoo/0POn1oh7oe_ok0=Gon`3koo/0nook0;?o
o021ol;oo03`ood0hool087ojOok087oPOn1omKon`3Eoo/0nook0?_on`35o`2<
kool087o`_ol0?3oo@3Soo`0POoZoo/0POn1oh7oe_ok0=?on`3koo/0nook0;Co
o021ol;oo03`ood0hool087oj_ok087oPOn1omKon`3Coo/0nook0?_on`2doo`0
POo2oo`0l?om0>?oo021on[on`21oh7oPOoFoo/0dook0?_on`3koo/0a_l0S>oo
o021ol;oo03`ood0hool087ojook087oPOn1omKon`3Aoo/0nook0?_on`2eoo`0
POo2oo`0l?om0>?oo021on_on`21oh7oPOoFoo/0dOok0?_on`3koo/0]Ool087o
`_ol0?3oo@3Soo`0POo[oo/0POn1oh7oe_ok0=7on`3koo/0nook0<Oo08c_oo`0
POo2oo`0l?om0>?oo021oncon`21oh7oPOoFoo/0cook0?_on`3koo/0]_ol087o
`_ol0?3oo@3Soo`0POo/oo/0POn1oh7oe_ok0<oon`3koo/0nook0;Koo021ol;o
o03`ood0hool087ok?ok087oPOn1omKon`3?oo/0nook0?_on`38o`1^kool087o
POn1oo7on`21oh7oPOoFoo/0cOok0?_on`3koo/0]ool087oPOn1oo7on`21oh7o
POoFoo/0cOok0?_on`3koo/0]ool087oPOn1oo7on`21oh7oPOoFoo/0cOok0?_o
n`3koo/0bOl0K^ooo021oh7oPOoboo/0POn1oh7oe_ok0<_on`3koo/0nook0;So
o021oh7oPOoboo/0POn1oh7oe_ok0<_on`3koo/0nook0;Soo021oh7oPOoboo/0
POn1oh7oe_ok0<_on`3koo/0nook0<[o06k_oo`0POn1oh7olook087oPOn1omKo
n`39oo/0nook0?_on`2ioo`0POn1oh7olook087oPOn1omKon`39oo/0nook0?_o
n`2ioo`0POn1oh7olook087oPOn1omKon`39oo/0nook0?_on`3;o`1^kool087o
POn1ooCon`21oh7oPOoFoo/0aook0?_on`3koo/0^_ol087oPOn1ooCon`21oh7o
POoFoo/0aook0?_on`3koo/0^_ol087oPOn1ooCon`21oh7oPOoFoo/0aook0?_o
n`3koo/0c?l0K^ooo021oh7oPOoeoo/0POn1oh7oe_ok0<Gon`3koo/0nook0;_o
o021oh7oPOoeoo/0POn1oh7oe_ok0<Gon`3koo/0nook0;_oo021oh7oPOoeoo/0
POn1oh7oe_ok0<Gon`3koo/0nook0<go06k_oo`0POn1oh7om_ok087oPOn1omKo
n`33oo/0nook0?_on`2loo`0POn1oh7om_ok087oPOn1omKon`33oo/0nook0?_o
n`2loo`0POn1oh7om_ok087oPOn1omKon`33oo/0nook0?_on`3>o`1^kool087o
POn1ooOon`21oh7oPOoFoo/0`Ook0?_on`3koo/0_Ool087oPOn1ooOon`21oh7o
POoFoo/0`Ook0?_on`3koo/0_Ool087oPOn1ooOon`21oh7oPOoFoo/0`Ook0?_o
n`3koo/0col0K^ooo021oh7oPOohoo/0POn1oh7oe_ok0;oon`3koo/0nook0;ko
o021oh7oPOohoo/0POn1oh7oe_ok0;oon`3koo/0nook0;koo021oh7oPOohoo/0
POn1oh7oe_ok0;oon`3koo/0nook0=3o06k_oo`0POn1oh7onOok087oPOn1omKo
n`2moo/0nook0?_on`2ooo`0POn1oh7onOok087oPOn1omKon`2moo/0nook0?_o
n`2ooo`0POn1oh7onOok087oPOn1omKon`2moo/0nook0?_on`3Ao`1^kool087o
POn1oo[on`21oh7oPOoFoo/0^ook0?_on`3koo/0`?ol087oPOn1oo[on`21oh7o
POoFoo/0^ook0?_on`3koo/0`?ol087oPOn1oo[on`21oh7oPOoFoo/0^ook0?_o
n`3koo/0d_l0K^ooo021oh7oPOokoo/0POn1oh7oe_ok0;Won`3koo/0nook0<7o
o021oh7oPOokoo/0POn1oh7oe_ok0;Won`3koo/0nook0<7oo021oh7oPOokoo/0
POn1oh7oe_ok0;Won`3koo/0nook0=?o06k_oo`0POn1oh7oo?ok087oPOn1omKo
n`2goo/0nook0?_on`32oo`0POn1oh7oo?ok087oPOn1omKon`2goo/0nook0?_o
n`32oo`0POn1oh7oo?ok087oPOn1omKon`2goo/0nook0?_on`3Do`1^kool087o
POn1oogon`21oh7oPOoFoo/0]Ook0?_on`3koo/0`ool087oPOn1oogon`21oh7o
POoFoo/0]Ook0?_on`3koo/0`ool087oPOn1oogon`21oh7oPOoFoo/0]Ook0?_o
n`3koo/0eOl0K^ooo021oh7oPOonoo/0POn1oh7oe_ok0;?on`3koo/0nook0<Co
o021oh7oPOonoo/0POn1oh7oe_ok0;?on`3koo/0nook0<Coo021oh7oPOonoo/0
POn1oh7oe_ok0;?on`3koo/0nook0=Ko077_oo`0POn1oh7o0Ooon`21oh7oPOoF
oo/0/Ook0?_on`3koo/0aOol087oPOn1o`7ooo/0POn1oh7oe_ok0;7on`3koo/0
nook0<Goo021oh7oPOl1oook087oPOn1omKon`2aoo/0nook0?_on`3Go`1^kool
087oPOn1o`3on`21oh7oPOoFoo/0[ook0?_on`3koo/0a_ol087oPOn1o`3on`21
oh7oPOoFoo/0[ook0?_on`3koo/0a_ol087oPOn1o`3on`21oh7oPOoFoo/0[ook
0?_on`3koo/0f?l0J>ooo021oh7oPOok087oPOn1omKon`2]oo/0nook0?_on`37
oo`0POn1oh7on`21oh7oPOoFoo/0[Ook0?_on`3koo/0aool087oPOn1oo/0POn1
oh7oe_ok0:gon`3koo/0nook0=Wo06S_oo`0POn1oh;on`21oh7oPOoFoo/0Zook
0?_on`3koo/0b?ol087oPOn2oo/0POn1oh7oe_ok0:_on`3koo/0nook0<Soo021
oh7oP_ok087oPOn1omKon`2[oo/0nook0?_on`3Jo`1Xkool087oPOn3oo/0POn1
oh7oe_ok0:Won`3koo/0nook0<Woo021oh7oPook087oPOn1omKon`2Yoo/0nook
0?_on`39oo`0POn1oh?on`21oh7oPOoFoo/0ZOok0?_on`3koo/0fol0J>ooo021
oh7oQ?ok087oPOn1omKon`2Woo/0nook0?_on`3:oo`0POn1ohCon`21oh7oPOoF
oo/0Yook0?_on`3koo/0b_ol087oPOn4oo/0POn1oh7oe_ok0:Oon`3koo/0nook
0=co06S_oo`0POn1ohGon`21oh7oPOoFoo/0YOok0?_on`3koo/0bool087oPOn5
oo/0POn1oh7oe_ok0:Gon`3koo/0nook0<_oo021oh7oQOok087oPOn1omKon`2U
oo/0nook0?_on`3Mo`1Xkool087oPOn6oo/0POn1oh7oe_ok0:?on`3koo/0nook
0<coo021oh7oQ_ok087oPOn1omKon`2Soo/0nook0?_on`3<oo`0POn1ohKon`21
oh7oPOoFoo/0Xook0?_on`3koo/0g_l0J>ooo021oh7oQook087oPOn1omKon`2Q
oo/0nook0?_on`3=oo`0POn1ohOon`21oh7oPOoFoo/0XOok0?_on`3koo/0cOol
087oPOn7oo/0POn1oh7oe_ok0:7on`3koo/0nook0=oo06S_oo`0POn1ohSon`21
oh7oPOoFoo/0Wook0?_on`3koo/0c_ol087oPOn8oo/0POn1oh7oe_ok09oon`3k
oo/0nook0<koo021oh7oR?ok087oPOn1omKon`2Ooo/0nook0?_on`3Po`1Xkool
087oPOn9oo/0POn1oh7oe_ok09gon`3koo/0nook0<ooo021oh7oROok087oPOn1
omKon`2Moo/0nook0?_on`3?oo`0POn1ohWon`21oh7oPOoFoo/0WOok0?_on`3k
oo/0hOl0J>ooo021oh7oR_ok087oPOn1omKon`2Koo/0nook0?_on`3@oo`0POn1
oh[on`21oh7oPOoFoo/0Vook0?_on`3koo/0d?ol087oPOn:oo/0POn1oh7oe_ok
09_on`3koo/0nook0>;o06S_oo`0POn1oh_on`21oh7oPOoFoo/0VOok0?_on`3k
oo/0dOol087oPOn;oo/0POn1oh7oe_ok09Won`3koo/0nook0=7oo021oh7oRook
087oPOn1omKon`2Ioo/0nook0?_on`3So`1Xkool087oPOn<oo/0POn1oh7oe_ok
09Oon`3koo/0nook0=;oo021oh7oS?ok087oPOn1omKon`2Goo/0nook0?_on`3B
oo`0POn1ohcon`21oh7oPOoFoo/0Uook0?_on`3koo/0i?l0J>ooo021oh7oSOok
087oPOn1omKon`2Eoo/0nook0?_on`3Coo`0POn1ohgon`21oh7oPOoFoo/0UOok
0?_on`3koo/0dool087oPOn=oo/0POn1oh7oe_ok09Gon`3koo/0nook0>Go06S_
oo`0POn1ohkon`21oh7oPOoFoo/0Took0?_on`3koo/0e?ol087oPOn>oo/0POn1
oh7oe_ok09?on`3koo/0nook0=Coo021oh7oS_ok087oPOn1omKon`2Coo/0nook
0?_on`3Vo`1Xkool087oPOn?oo/0POn1oh7oe_ok097on`3koo/0nook0=Goo021
oh7oSook087oPOn1omKon`2Aoo/0nook0?_on`3Eoo`0POn1ohoon`21oh7oPOoF
oo/0TOok0?_on`3koo/0iol0J>ooo021oh7oT?ok087oPOn1omKon`2?oo/0nook
0?_on`3Foo`0POn1oi3on`21oh7oPOoFoo/0Sook0?_on`3koo/0e_ol087oPOn@
oo/0POn1oh7oe_ok08oon`3koo/0nook0>So06S_oo`0POn1oi7on`21oh7oPOoF
oo/0SOok0?_on`3koo/0eool087oPOnAoo/0POn1oh7oe_ok08gon`3koo/0nook
0=Ooo021oh7oTOok087oPOn1omKon`2=oo/0nook0?_on`3Yo`1Xkool087oPOnB
oo/0POn1oh7oe_ok08_on`3koo/0nook0=Soo021oh7oT_ok087oPOn1omKon`2;
oo/0nook0?_on`3Hoo`0POn1oi;on`21oh7oPOoFoo/0Rook0?_on`3koo/0j_l0
J>ooo021oh7oTook087oPOn1omKon`29oo/0nook0?_on`3Ioo`0POn1oi?on`21
oh7oPOoFoo/0ROok0?_on`3koo/0fOol087oPOnCoo/0POn1oh7oe_ok08Won`3k
oo/0nook0>_o06S_oo`0POn1oiCon`21oh7oPOoFoo/0Qook0?_on`3koo/0f_ol
087oPOnDoo/0POn1oh7oe_ok08Oon`3koo/0nook0=[oo021oh7oU?ok087oPOn1
omKon`27oo/0nook0?_on`3/o`1Xkool087oPOnEoo/0POn1oh7oe_ok08Gon`3k
oo/0nook0=_oo021oh7oUOok087oPOn1omKon`25oo/0nook0?_on`3Koo`0POn1
oiGon`21oh7oPOoFoo/0QOok0?_on`3koo/0kOl0J>ooo021oh7oU_ok087oPOn1
omKon`23oo/0nook0?_on`3Loo`0POn1oiKon`21oh7oPOoFoo/0Pook0?_on`3k
oo/0g?ol087oPOnFoo/0POn1oh7oe_ok08?on`3koo/0nook0>ko06S_oo`0POn1
oiOon`21oh7oPOoFoo/0POok0?_on`3koo/0gOol087oPOnGoo/0POn1oh7oe_ok
087on`3koo/0nook0=goo021oh7oUook087oPOn1omKon`21oo/0nook0?_on`3_
o`1akool087oPOnHoo/0POn1oh7oe_ok087o0Ooon`3koo/0nook0=koo021oh7o
V?ok087oPOn1omKon`21o`7ooo/0nook0?_on`3Noo`0POn1oiSon`21oh7oPOoF
oo/0POl1oook0?_on`3koo/0l?l0K^ooo021oh7oVOok087oPOn1omKon`21oogo
n`3koo/0nook0=ooo021oh7oVOok087oPOn1omKon`21oogon`3koo/0nook0=oo
o021oh7oVOok087oPOn1omKon`21oogon`3koo/0nook0?7o06k_oo`0POn1oi[o
n`21oh7oPOoFoo/0POokoo/0nook0?_on`3Poo`0POn1oi[on`21oh7oPOoFoo/0
POokoo/0nook0?_on`3Poo`0POn1oi[on`21oh7oPOoFoo/0POokoo/0nook0?_o
n`3bo`1^kool087oPOnKoo/0POn1oh7oe_ok087onOok0?_on`3koo/0hOol087o
POnKoo/0POn1oh7oe_ok087onOok0?_on`3koo/0hOol087oPOnKoo/0POn1oh7o
e_ok087onOok0?_on`3koo/0lol0K^ooo021oh7oW?ok087oPOn1omKon`21ooOo
n`3koo/0nook0>;oo021oh7oW?ok087oPOn1omKon`21ooOon`3koo/0nook0>;o
o021oh7oW?ok087oPOn1omKon`21ooOon`3koo/0nook0?Co06k_oo`0POn1oigo
n`21oh7oPOoFoo/0POoeoo/0nook0?_on`3Soo`0POn1oigon`21oh7oPOoFoo/0
POoeoo/0nook0?_on`3Soo`0POn1oigon`21oh7oPOoFoo/0POoeoo/0nook0?_o
n`3eo`1^kool087oPOnNoo/0POn1oh7oe_ok087olook0?_on`3koo/0i?ol087o
POnNoo/0POn1oh7oe_ok087olook0?_on`3koo/0i?ol087oPOnNoo/0POn1oh7o
e_ok087olook0?_on`3koo/0m_l0K^ooo021oh7oWook087oPOn1omKon`21oo7o
n`3koo/0nook0>Goo021oh7oWook087oPOn1omKon`21oo7on`3koo/0nook0>Go
o021oh7oWook087oPOn1omKon`21oo7on`3koo/0nook0?Oo06k_oo`0POn1oj3o
n`21oh7oPOoFoo/0POo_oo/0nook0?_on`3Voo`0POn1oj3on`21oh7oPOoFoo/0
POo_oo/0nook0?_on`3Voo`0POn1oj3on`21oh7oPOoFoo/0POo_oo/0nook0?_o
n`3ho`1^kool087oPOnQoo/0POn1oh7oe_ok087okOok0?_on`3koo/0iool087o
POnQoo/0POn1oh7oe_ok087okOok0?_on`3koo/0iool087oPOnQoo/0POn1oh7o
e_ok087okOok0?_on`3koo/0nOl0K^ooo021oh7oX_ok087oPOn1omKon`21on_o
n`3koo/0nook0>Soo021oh7oX_ok087oPOn1omKon`21on_on`3koo/0nook0>So
o021oh7oX_ok087oPOn1omKon`21on_on`3koo/0nook0?[o06k_oo`0POn1oj?o
n`21oh7oPOoFoo/0POoYoo/0nook0?_on`3Yoo`0POn1oj?on`21oh7oPOoFoo/0
POoYoo/0nook0?_on`3Yoo`0POn1oj?on`21oh7oPOoFoo/0POoYoo/0nook0?_o
n`3ko`1^kool087oPOnToo/0POn1oh7oe_ok087oiook0?_on`3koo/0j_ol087o
POnToo/0POn1oh7oe_ok087oiook0?_on`3koo/0j_ol087oPOnToo/0POn1oh7o
e_ok087oiook0?_on`3koo/0o?l0K^ooo021oh7oYOok087oPOn1omKon`21onGo
n`3koo/0nook0>_oo021oh7oYOok087oPOn1omKon`21onGon`3koo/0nook0>_o
o021oh7oYOok087oPOn1omKon`21onGon`3koo/0nook0?go07O_oo`0POn1ojKo
n`21oh7oPOoFoo/0Qol1003Ooo/0nook0?_on`3/oo`0POn1ojKon`21oh7oPOoF
oo/0Qol1003Ooo/0nook0?_on`3/oo`0POn1ojKon`21oh7oPOoFoo/0Qol1003O
oo/0nook0?_on`3no`1ekool087oPOnWoo/0POn1oh7oe_ok08Ooo@3Ooo/0nook
0?_on`3]oo`0POn1ojOon`21oh7oPOoFoo/0Qoom0=oon`3koo/0nook0>goo021
oh7oYook087oPOn1omKon`27ood0gook0?_on`3koo/00Ooo07C_oo`0POn1ojSo
n`21oh7oPOoFoo/0Qook0=oon`3koo/0nook0>koo021oh7oZ?ok087oPOn1omKo
n`27oo/0gook0?_on`3koo/0k_ol087oPOnXoo/0POn1oh7oe_ok08Oon`3Ooo/0
nook0?_on`00o`1bkool087oPOnYoo/0POn1oh7oe_ok08Gon`3Ooo/0nook0?_o
n`3_oo`0POn1ojWon`21oh7oPOoFoo/0QOok0=oon`3koo/0nook0>ooo021oh7o
ZOok087oPOn1omKon`25oo/0gook0?_on`3koo/007;_oo`0POn1oj[on`21oh7o
POoFoo/0Pook0=oon`3koo/0nool0>ooo021oh7oZ_ok087oPOn1omKon`23oo/0
gook0?_on`3koo`0kool087oPOnZoo/0POn1oh7oe_ok08?on`3Ooo/0nook0?_o
o000O^ooo021oh7oZook087oPOn1omKon`3Looh0ZOok0=oon`3koo/0noom0>oo
o021oh7oZook087oPOn1omKon`3Looh0ZOok0=oon`3koo/0noom0>ooo021oh7o
Zook087oPOn1omKon`3Looh0ZOok0=oon`3koo/0noom001nkool087oPOn/oo/0
POn1oh7oe_ok0=coo02Yoo/0gook0?_on`3kooh0kool087oPOn/oo/0POn1oh7o
e_ok0=coo02Yoo/0gook0?_on`3kooh0kool087oPOn/oo/0POn1oh7oe_ok0=co
o02Yoo/0gook0?_on`3kooh0087_oo`0POn1ojgon`21oh7oPOoFoo/0g?ol0:Oo
n`3Ooo/0nook0?_o0@00kool087oPOn]oo/0POn1oh7oe_ok0=coo02Woo/0gook
0?_on`3ko`400>ooo021oh7o[Ook087oPOn1omKon`3Loo`0Yook0=oon`3koo/0
nol10000O^ooo021oh7o[_ok087oPOn1omKon`3Loo`0YOol0=kon`3koo/0nol0
0>ooo021oh7o[_ok087oPOn1omKon`3Loo`0YOol0=kon`3koo/0nol00>ooo021
oh7o[_ok087oPOn1omKon`3Loo`0YOol0=kon`3koo/0nol0001dkool087oPOn_
oo/0POn1oh7oe_ok0=coo02Soo`0g_ok0?_on`3Yoo`0POn1ojoon`21oh7oPOoF
oo/0g?ol0:?oo03Noo/0nook0>Woo021oh7o[ook087oPOn1omKon`3Loo`0Xool
0=kon`3koo/0nol0M>ooo021oh7o/?ok087oPOn1omKon`3Loo`0XOol0=kon`3k
oo/0j_ol087oPOn`oo/0POn1oh7oe_ok0=coo02Qoo`0g_ok0?_on`3Zoo`0POn1
ok3on`21oh7oPOoFoo/0g?ol0:7oo03Noo/0nook0?co07C_oo`0POn1ok7on`21
oh7oPOoFoo/0g?ol09ooo03Noo/0nook0>_oo021oh7o/Ook087oPOn1omKon`3L
oo`0Wool0=kon`3koo/0jool087oPOnaoo/0POn1oh7oe_ok0=coo02Ooo`0g_ok
0?_on`3mo`1dkool087oPOnboo/0POn1oh7oe_ok0=coo02Moo`0g_ok0?_on`3/
oo`0POn1ok;on`21oh7oPOoFoo/0g?ol09goo03Noo/0nook0>coo021oh7o/_ok
087oPOn1omKon`3Loo`0WOol0=kon`3koo/0o_l0MNooo021oh7o/ook087oPOn1
omKon`3Loo`0W?ok0=kon`3koo/0kOol087oPOncoo/0POn1oh7oe_ok0=coo02L
oo/0g_ok0?_on`3]oo`0POn1ok?on`21oh7oPOoFoo/0g?ol09con`3Noo/0nook
007oo`1dkool087oPOndoo/0POn1oh7oe_ok0=_oo02Koo/0g_ok0?_on`3^oo`0
POn1okCon`21oh7oPOoFoo/0fool09_on`3Noo/0nook0>koo021oh7o]?ok087o
POn1omKon`3Koo`0Vook0=kon`3koo/00?l0L^ooo021oh7o]Ook087oPOn1omKo
n`3Koo`0VOok0=kon`3koo/0kool087oPOneoo/0POn1oh7oe_ok0=_oo02Ioo/0
g_ok0?_on`3_oo`0POn1okGon`21oh7oPOoFoo/0fool09Won`3Noo/0nook001b
kool087oPOnfoo/0POn1oh7oe_ok0=_oo02Goo/0g_ok0?_oo03_oo`0POn1okKo
n`21oh7oPOoFoo/0fool09Oon`3Noo/0nool0>ooo021oh7o]_ok087oPOn1omKo
n`3Koo`0Uook0=kon`3koo`007;_oo`0POn1okOon`21oh7oPOoFoo/0fool09Go
n`3Noo/0noom0>ooo021oh7o]ook087oPOn1omKon`3Koo`0UOok0=kon`3kood0
kool087oPOngoo/0POn1oh7oe_ok0=_oo02Eoo/0g_ok0?_oo@00L^ooo021oh7o
^?ok087oPOn1omKon`3Koo`0Took0=kon`3kooh0kool087oPOnhoo/0POn1oh7o
e_ok0=_oo02Coo/0g_ok0?_ooP3_oo`0POn1okSon`21oh7oPOoFoo/0fool09?o
n`3Noo/0noon001ekool087oPOnioo/0POn1oh7oe_ok0=_oo02Aoo/0g_ok0?_o
0@00kool087oPOnioo/0POn1oh7oe_ok0=_oo02Aoo/0g_ok0?_o0@00kool087o
POnioo/0POn1oh7oe_ok0=_oo02Aoo/0g_ok0?_o0@0007;_oo`0POn1ok[on`21
oh7oPOoFoo/0fool08oon`3Noo/0nol00>ooo021oh7o^_ok087oPOn1omKon`3K
oo`0Sook0=kon`3ko`00kool087oPOnjoo/0POn1oh7oe_ok0=_oo02?oo/0g_ok
0?_o0000J>ooo021oh7o^ook087oPOn1omKon`3Koo`0SOok0=kon`3Yoo`0POn1
ok_on`21oh7oPOoFoo/0fool08gon`3Noo/0jOol087oPOnkoo/0POn1oh7oe_ok
0=_oo02=oo/0g_ok0?_o06S_oo`0POn1okcon`21oh7oPOoFoo/0fool08_on`3N
oo/0j_ol087oPOnloo/0POn1oh7oe_ok0=_oo02;oo/0g_ok0>[oo021oh7o_?ok
087oPOn1omKon`3Koo`0Rook0=kon`3lo`1Xkool087oPOnmoo/0POn1oh7oe_ok
0=_oo029oo/0g_ok0>_oo021oh7o_Ook087oPOn1omKon`3Koo`0ROok0=kon`3[
oo`0POn1okgon`21oh7oPOoFoo/0fool08Won`3Noo/0oOl0J>ooo021oh7o__ok
087oPOn1omKon`3Koo`0Qool0=gon`3/oo`0POn1okkon`21oh7oPOoFoo/0fool
08Ooo03Moo/0k?ol087oPOnnoo/0POn1oh7oe_ok0=_oo027oo`0gOok0?ko06W_
oo`0POn1okoon`21oh7oPOoFoo/0fool08Goo03Moo/0kOol087oPOnooo/0POn1
oh7oe_ok0=_oo025oo`0gOok0>goo021oh7o_ook087oPOn1omKon`3Koo`0QOol
0=gon`01ool0J>ooo021oh7o`?ok087oPOn1omKon`3Koo`0Pool0=gon`3^oo`0
POn1ol3on`21oh7oPOoFoo/0fool08?oo03Moo/0k_ol087oPOo0oo/0POn1oh7o
e_ok0=_oo023oo`0gOok003o06K_oo`0POn1ol7on`21oh7oPOoFoo/0fool087o
o03Moo/0kool087oPOo1oo/0POn1oh7oe_ok0=_oo021oo`0gOok0>ooo021oh7o
`Ook087oPOn1omKon`3Koo`0POol0=gon`00Knooo021oh7o`_ok087oPOn1omKo
n`3Koo`0POl1oool0=goo03_oo`0POn1ol;on`21oh7oPOoFoo/0fool087o0Ooo
o03Moo`0kool087oPOo2oo/0POn1oh7oe_ok0=_oo021o`7ooo`0gOol001/kool
087oPOo3oo/0POn1oh7oe_ok0=_oo021oogoo03Mood0kool087oPOo3oo/0POn1
oh7oe_ok0=_oo021oogoo03Mood0kool087oPOo3oo/0POn1oh7oe_ok0=_oo021
oogoo03Mood006c_oo`0POn1olCon`21oh7oPOoFoo/0fook087oo?ol0=gooP3_
oo`0POn1olCon`21oh7oPOoFoo/0fook087oo?ol0=gooP3_oo`0POn1olCon`21
oh7oPOoFoo/0fook087oo?ol0=gooP00Knooo021oh7oaOok087oPOn1omKon`3K
oo/0POojoo`0gOl1003_oo`0POn1olGon`21oh7oPOoFoo/0fook087on_ol0=go
0@00kool087oPOo5oo/0POn1oh7oe_ok0=_on`21oo[oo03Mo`40001/kool087o
POo6oo/0POn1oh7oe_ok0=_on`21ooWon`3Mo`00kool087oPOo6oo/0POn1oh7o
e_ok0=_on`21ooWon`3Mo`00kool087oPOo6oo/0POn1oh7oe_ok0=_on`21ooWo
n`3Mo`0006;_oo`0POn1olOon`21oh7oPOoFoo/0fook087omook0<_oo021oh7o
aook087oPOn1omKon`3Koo/0POogoo/0bool087oPOo7oo/0POn1oh7oe_ok0=_o
n`21ooOon`3Mo`1Rkool087oPOo8oo/0POn1oh7oe_ok0=[oo021ooGon`3<oo`0
POn1olSon`21oh7oPOoFoo/0f_ol087omOok0<coo021oh7ob?ok087oPOn1omKo
n`3Joo`0POoeoo/0g_l0H^ooo021oh7obOok087oPOn1omKon`3Joo`0POocoo/0
cOol087oPOo9oo/0POn1oh7oe_ok0=[oo021oo?on`3=oo`0POn1olWon`21oh7o
POoFoo/0f_ol087olook0=oo06;_oo`0POn1ol[on`21oh7oPOoFoo/0f_ol087o
lOok0<koo021oh7ob_ok087oPOn1omKon`3Joo`0POoaoo/0c_ol087oPOo:oo/0
POn1oh7oe_ok0=[oo021oo7on`3Po`1Rkool087oPOo;oo/0POn1oh7oe_ok0=[o
o021onoon`3?oo`0POn1ol_on`21oh7oPOoFoo/0f_ol087okook0<ooo021oh7o
book087oPOn1omKon`3Joo`0POo_oo/0hOl0H^ooo021oh7oc?ok087oPOn1omKo
n`3Joo`0POo]oo/0d?ol087oPOo<oo/0POn1oh7oe_ok0=[oo021ongon`3@oo`0
POn1olcon`21oh7oPOoFoo/0f_ol087okOok0>;o06;_oo`0POn1olgon`21oh7o
POoFoo/0f_ol087ojook0=7oo021oh7ocOok087oPOn1omKon`3Joo`0POo[oo/0
dOol087oPOo=oo/0POn1oh7oe_ok0=[oo021on_on`3So`1Rkool087oPOo>oo/0
POn1oh7oe_ok0=[oo021onWoo03Aoo`0POn1olkon`21oh7oPOoFoo/0f_ol087o
jOol0=7oo021oh7oc_ok087oPOn1omKon`3Joo`0POoYoo`0hol0H^ooo021oh7o
cook087oPOn1omKon`3Joo`0POoWoo`0d_ol087oPOo?oo/0POn1oh7oe_ok0=[o
o021onOoo03Boo`0POn1oloon`21oh7oPOoFoo/0f_ol087oiool0>Co07CaooX0
dool087oPook087oPOn1omKon`3Joo`0POoUoo`0lOon0>SonP3Coo`0POn3oo/0
POn1oh7oe_ok0=[oo021onGoo03aooh0j?oj0=?oo021oh?on`21oh7oPOoFoo/0
f_ol087oiOol0?7ooP3ho`1dmoo/0=_oo021ohCon`21oh7oPOoFoo/0f_ol087o
hool0?Gon`3^on`0fool087oQ?ok087oPOn1omKon`3Joo`0POoSoo`0mOok0>ko
k03Koo`0POn4oo/0POn1oh7oe_ok0=[oo021on?oo03eoo/0n?l0M?Woi`3Noo`0
POn5oo/0POn1oh7oe_ok0=[oo021on7oo03hooP0lOoW0=koo021ohGon`21oh7o
POoFoo/0f_ol087ohOol0?Son03aonL0g_ol087oQOok087oPOn1omKon`3Joo`0
POoQoo`0n?oh0?Wo083kon80hOol087oQ_ok087oPOn1omKon`3^o`00k_ol087o
gool0?_omP3con80hOol087oQ_ok087oPOn1omKon`3^o`00k_ol087ogool0?_o
mP3con80hOol087oQ_ok087oPOn1omKon`3^o`00k_ol087ogool0?_omP3io`20
oOoP0>7oo021ohOon`21oh7oPOoFoo/0kOon0?7on`21omkoo03moo@0m_oP0>7o
o021ohOon`21oh7oPOoFoo/0kOon0?7on`21omkoo03moo@0m_oP0>7oo021ohOo
n`21oh7oPOoFoo/0kOon0?7on`21omkoo03moo@0n_l0P?cohP3Poo`0POn8oo/0
POn1oh7oe_ok0>gonP3eoo/0POoLoo`00?ob0?GohP3Poo`0POn8oo/0POn1oh7o
e_ok0>gonP3eoo/0POoLoo`00?ob0?GohP3Poo`0POn8oo/0POn1oh7oe_ok0>go
nP3eoo/0POoLoo`00?ob0?[o07Clon80iOo_087oTOok087oPOn1omKon`3/ooP0
n?ok087of_o/0?KohP3Uonl0POnAoo/0POn1oh7oe_ok0>con03hoo/0POoJon`0
m_oR0>Gok`21oi7on`21oh7oPOoFoo/0k?oh0?Son`21om[ok03ko`1dnooS0>Go
k`21oi;on`21oh7oPOoFoo/0k?of0?[on`21omSok@3eon<0iOo_087oT_ok087o
POn1omKon`3/ooH0n_ok087of?o]0?Goh`3Uonl0POnBoo/0POn1oh7oe_ok0>co
mP3joo/0POoHond0nol0M?_oi03Tonl0POnCoo/0POn1oh7oe_ok0>_om@3loo/0
POoFond0m_oT0>Cok`21oi?on`21oh7oPOoFoo/0jooe0?con`21omKok@3fon@0
i?o_087oTook087oPOn1omKon`3[ooD0o?ok087oe_o]0?co07Ckon@0i?o_087o
U?ok087oPOn1omKon`3[oo<0o_ok087oe_o/0?Koi03Tonl0POnDoo/0POn1oh7o
e_ok0>_ol`3noo/0POoFon`0m_oT0>Cok`21oiCon`21oh7oPOoFoo/0jooc0?ko
n`21omKok03lo`1dn_oU0=ooo021ohgon`21oh7oPOoFoo/0j_ob003on`21omKo
jP3fonD0gool087oSOok087oPOn1omKon`3Zoo800?ok087oe_oZ0?Koi@3Ooo`0
POn=oo/0POn1oh7oe_ok0>[olP00oo/0POoFonX0oOl0J?[oiP3Noo`0POn>oo/0
POn1oh7oe_ok0>[oj`21omKoj@3fonH0g_ol087oS_ok087oPOn1omKon`3Zon/0
POoFonT0m_oV0=koo021ohkon`21oh7oPOoFoo/0j_o[087oe_oY0?go06SjonH0
g_ol087oSook087oPOn1omKon`3Yon`0POoEonP0mooV0=koo021ohoon`21oh7o
POoFoo/0jOo/087oeOoX0?OoiP3Noo`0POn?oo/0POn1oh7oe_ok0>Wok021omGo
j03no`1XnOoW0=koo021oi3on`21oh7oPOoFoo/0jOo/087oeOoW0?Koi`3Noo`0
POn@oo/0POn1oh7oe_ok0>Wok021omGoi`3fonL0g_ol087oT?ok087oPOn1omKo
n`3Yon`0POoEonL0o_l0J?Woj03Moo`0POnAoo/0POn1oh7oe_ok0>Soj`21omKo
i`3fonP0gOol087oTOok087oPOn1omKon`3Xon/0POoFonL0m_oX0=goo021oi7o
n`21oh7oPOoFoo/0j?o[087oe_oW0?ko06WionP0gOol087oT_ok087oPOn1omKo
n`3WonX0POoHonD0mooX0=goo021oi;on`21oh7oPOoFoo/0iooZ087of?oU0?Oo
j03Moo`0POnBoo/0POn1oh7oe_ok0>OojP21omSoi@01ool0JOSoj@3Moo`0POnC
oo/0POn1oh7oe_ok0>Ooj021omWoi@3fonT0gOol087oTook087oPOn1omKon`3W
onP0POoIonD0m_oY0=goo021oi?on`21oh7oPOoFoo/0iooX087ofOoU007oo`1X
n?oZ0=coo021oiCon`21oh7oPOoFoo/0i_oW087ofooS0?OojP3Loo`0POnDoo/0
POn1oh7oe_ok0>Koi`21om_oh`3gonX0g?ol087oU?ok087oPOn1omKon`3VonL0
POoKon<00?l0J?SojP3Loo`0POnEoo/0POn1oh7oe_ok0>KoiP21om_oh`3gonX0
g?ol087oUOok087oPOn1omKon`3VonH0POoKon<0mooZ0=coo021oiGon`21oh7o
POoFoo/0i_oV087ofooS003o06Kgon/0g?ol087oU_ok087oPOn1omKon`3UonD0
POoMon40moo[0=coo021oiKon`21oh7oPOoFoo/0iOoU087ogOoQ0?Ooj`3Loo`0
POnFoo/0POn1oh7oe_ok0>Goi@21omgoh@00I_Ook03Koo`0POnGoo/0POn1oh7o
e_ok0>Goh`21omkoh@3gon`0fool087oUook087oPOn1omKon`3Uon<0POoNon40
moo/0=_oo021oiOon`21oh7oPOoFoo/0iOoS087og_oQ001Vm_o]0=_oo021oiSo
n`21oh7oPOoFoo/0i?oS087ogooP0?Kok@3Koo`0POnHoo/0POn1oh7oe_ok0>Co
h`21omooh03fond0fool087oV?ok087oPOn1omKon`3Ton<0POoOon0006Kfond0
fool087oVOok087oPOn1omKon`3Ton40POoNon80m_o]0=_oo021oiWon`21oh7o
POoFoo/0i?oQ087og_oR0?Kok@3Koo`0POnIoo/0POn1oh7oe_ok0>Coh@21omko
hP00I_KokP3Joo`0POnJoo/0POn1oh7oe_ok0>?oh@21omcoi03fonh0f_ol087o
V_ok087oPOn1omKon`3Son40POoLon@0m_o^0=[oo021oi[on`21oh7oPOoFoo/0
hooQ087og?oT001VmOo_0=[oo021oi_on`21oh7oPOoFoo/0hooO087of_oW0?Go
k`3Joo`0POnKoo/0POn1oh7oe_ok0>?og`21om[oi`3eonl0f_ol087oVook087o
POn1omKon`3Soml0POoJonL006Keonl0f_ol087oW?ok087oPOn1omKon`3Roml0
POoHonT0mOo_0=[oo021oicon`21oh7oPOoFoo/0h_oO087of?oY0?Gok`3Joo`0
POnLoo/0POn1oh7oe_ok0>;og`21omSoj@00I_Col@3Ioo`0POnMoo/0POn1oh7o
e_ok0>7oh@21omCoj`3doo40fOol087oWOok087oPOn1omKon`3Qon40POoDon/0
m?oa0=Woo021oigon`21oh7oPOoFoo/0hOoQ087oe?o[001Vm?oa0=Woo021oiko
n`21oh7oPOoFoo/0hOoS087ocoo]0?Col@3Ioo`0POnNoo/0POn1oh7oe_ok0>7o
h`21olook@3doo40fOol087oW_ok087oPOn1omKon`3Qon<0POo?ond006Kdoo80
f?ok087oX?ok087oPOn1omKon`3Pon@0POo<onl0m?ob0=Son`21oj3on`21oh7o
POoFoo/0h?oT087oc?o_0?ColP3Hoo/0POnPoo/0POn1oh7oe_ok0>3oi021olco
k`00I_?ol`3Goo`0POnQoo/0POn1oh7oe_ok0>3oi@21olWol03coo<0eool087o
XOok087oPOn1omKon`3PonD0POo9oo00looc0=Ooo021oj7on`21oh7oPOoFoo/0
h?oU087obOo`001blooc0=OonP3lo`00POnZoo/0POn1oh7oe_ok0=ooiP21olKo
lP3coo<0eooj0?co0021oj[on`21oh7oPOoFoo/0gooV087oa_ob0??ol`3GooX0
o?l0087oZ_ok087oPOn1omKon`3OonH0POo6oo8006Kcoo@0e_od087oZook087o
POn1omKon`3OonL0POo2oo@0lood0=Kom021oj_on`21oh7oPOoFoo/0gooW087o
`_od0??om03Foo@0POn[oo/0POn1oh7oe_ok0=ooi`21ol;om000VP000?n;c000
0003j0;c000010000000B00004P0000@02000`08000000000002KGK/000000?X
0^`000?[0nT6e00002B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
Z?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOnXo`0]POl10021oh7oPOn1oh7oT?l10021oh7oPOn1oh7oT?l10021
oh7oPOn1oi3o02Z5ooL0POn1oh7oPOn1oiSom`21oh7oPOn1oh7oV?og087oPOn1
oh7oU?l0:XGom`21oh7oPOn1oh7oV?og087oPOn1oh7oPOnHooL0POn1oh7oPOnD
o`0ZQ_oe087oPOn1oh7oPOnJooD0POn1oh7oPOn1oi[om@21oh7oPOn1oiGo03J6
oo/00?ok087oPOn1oh7oPOnKoo/00?ok087oPOn1oh7oPOnKoo/00?ok087oPOn1
oh7oU_l0=XOoo03moo`0POn1oh7oPOn1oicoo03moo`0POn1oh7oPOn1oicoo03m
oo`0POn1oh7oPOnFo`0fR?ol0?_oo021oh7oPOn1oh7oW_ol0?_oo021oh7oPOn1
oh7oW_ol0?_oo021oh7oPOn1oiOo03J8ood0nOom087oPOn1oh7oPOnNood0nOom
087oPOn1oh7oPOnNood0nOom087oPOn1oh7oUol0=XWoo03ioo`0POn1oh7oPOn1
oj3oo03ioo`0POn1oh7oPOn1oj3oo03ioo`0POn1oh7oPOnHo`0fROom0?Soo021
oh7oPOn1oh7oX?om0?Soo021oh7oPOn1oh7oX?om0?Soo021oh7oPOn1oiSo03J9
ood0moom087oPOn1oh7oPOnPood0moom087oPOn1oh7oPOnPood0moom087oPOn1
oh7oV?l0=X[oo@3foo`0POn1oh7oPOn1oj;oo@3foo`0POn1oh7oPOn1oj;oo@3f
oo`0POn1oh7oPOnIo`0fR_om0?Goo@21oh7oPOn1oh7oX_om0?Goo@21oh7oPOn1
oh7oX_om0?Goo@21oh7oPOn1oiWo03J;ood0m?ol087oPOn1oh7oPOnTood0m?ol
087oPOn1oh7oPOnTood0m?ol087oPOn1oh7oV_l0=X_oo@3doo`0POn1oh7oPOn1
ojCoo@3doo`0POn1oh7oPOn1ojCoo@3doo`0POn1oh7oPOnJo`0fRoon0?;oo@21
oh7oPOn1oh7oY?on0?;oo@21oh7oPOn1oh7oY?on0?;oo@21oh7oPOn1oi[o03J<
ood0l_ol087oPOn1oh7oPOnVood0l_ol087oPOn1oh7oPOnVood0l_ol087oPOn1
oh7oVol0=XcooP3aoo`0POn1oh7oPOn1ojKooP3aoo`0POn1oh7oPOn1ojKooP3a
oo`0POn1oh7oPOnKo`0fSOom0?3oo@21oh7oPOn1oh7oYoom0?3oo@21oh7oPOn1
oh7oYoom0?3oo@21oh7oPOn1oi_o03J=ood0l?om087oPOn1oh7oPOnWood0l?om
087oPOn1oh7oPOnWood0l?om087oPOn1oh7oVol0=Xgoo@3`oo`0POn1oh7oPOn1
ojSoo@3`oo`0POn1oh7oPOn1ojSoo@3`oo`0POn1oh7oPOnLo`0fS_om0>koo@21
oh7oPOn1oh7oZOom0>koo@21oh7oPOn1oh7oZOom0>koo@21oh7oPOn1oico03J>
ood0k_om087oPOn1oh7oPOnYood0k_om087oPOn1oh7oPOnYood0k_om087oPOn1
oh7oW?l0=Xooo03^oo`0POn1oh7oPOn1oj_oo03^oo`0POn1oh7oPOn1oj_oo03^
oo`0POn1oh7oPOnMo`0fSool0>koo021oh7oPOn1oh7oZool0>koo021oh7oPOn1
oh7oZool0>koo021oh7oPOn1oigo03J?ood0k?om087oPOn1oh7oPOn[ood0k?om
087oPOn1oh7oPOn[ood0k?om087oPOn1oh7oWOl0=Xooo@3/ood0POn1oh7oPOn1
oj_oo@3/ood0POn1oh7oPOn1oj_oo@3/ood0POn1oh7oPOnMo`0fT?ol0>coo021
oh7oPOn1oh7o[Ool0>coo021oh7oPOn1oh7o[Ool0>coo021oh7oPOn1oiko03J@
ood0j_om087oPOn1oh7oPOn]ood0j_om087oPOn1oh7oPOn]ood0j_om087oPOn1
oh7oW_l0=Y3oo@3Zood0POn1oh7oPOn1ojgoo@3Zood0POn1oh7oPOn1ojgoo@3Z
ood0POn1oh7oPOnNo`0fT?om0>[oo@21oh7oPOn1oh7o[Oom0>[oo@21oh7oPOn1
oh7o[Oom0>[oo@21oh7oPOn1oiko03J@ood0j_om087oPOn1oh7oPOn]ood0j_om
087oPOn1oh7oPOn]ood0j_om087oPOn1oh7oW_l0=Y7oo03Zoo`0POn1oh7oPOn1
ojooo03Zoo`0POn1oh7oPOn1ojooo03Zoo`0POn1oh7oPOnOo`0fTOom0>Soo@21
oh7oPOn1oh7o[oom0>Soo@21oh7oPOn1oh7o[oom0>Soo@21oh7oPOn1oioo03JA
ood0j?om087oPOn1oh7oPOn_ood0j?om087oPOn1oh7oPOn_ood0j?om087oPOn1
oh7oWol0=Y7oo@3Xood0POn1oh7oPOn1ojooo@3Xood0POn1oh7oPOn1ojooo@3X
ood0POn1oh7oPOnOo`0fT_ol0>Soo021oh7oPOn1oh7o/Ool0>Soo021oh7oPOn1
oh7o/Ool0>Soo021oh7oPOn1oj3o03JBood0i_om087oPOn1oh7oPOnaood0i_om
087oPOn1oh7oPOnaood0i_om087oPOn1oh7oX?l0=Y;oo@3Vood0POn1oh7oPOn1
ok7oo@3Vood0POn1oh7oPOn1ok7oo@3Vood0POn1oh7oPOnPo`0fT_om0>Koo@21
oh7oPOn1oh7o/Oom0>Koo@21oh7oPOn1oh7o/Oom0>Koo@21oh7oPOn1oj3o03JB
ood0i_om087oPOn1oh7oPOnaood0i_om087oPOn1oh7oPOnaood0i_om087oPOn1
oh7oX?l0=Y?oo03Vood0POn1oh7oPOn1ok;oo03Vood0POn1oh7oPOn1ok;oo03V
ood0POn1oh7oPOnPo`0fToom0>Coo@21oh7oPOn1oh7o/oom0>Coo@21oh7oPOn1
oh7o/oom0>Coo@21oh7oPOn1oj7o03JCood0i?om087oPOn1oh7oPOncood0i?om
087oPOn1oh7oPOncood0i?om087oPOn1oh7oXOl0=Y?oo@3Tood0POn1oh7oPOn1
ok?oo@3Tood0POn1oh7oPOn1ok?oo@3Tood0POn1oh7oPOnQo`0fToom0>Coo@21
oh7oPOn1oh7o/oom0>Coo@21oh7oPOn1oh7o/oom0>Coo@21oh7oPOn1oj7o03JC
ood0i?om087oPOn1oh7oPOncood0i?om087oPOn1oh7oPOncood0i?om087oPOn1
oh7oXOl0=YCoo03Too`0POn1oh7oPOn1okGoo03Too`0POn1oh7oPOn1okGoo03T
oo`0POn1oh7oPOnRo`0fU?om0>;oo@21oh7oPOn1oh7o]Oom0>;oo@21oh7oPOn1
oh7o]Oom0>;oo@21oh7oPOn1oj;o03JDood0h_om087oPOn1oh7oPOneood0h_om
087oPOn1oh7oPOneood0h_om087oPOn1oh7oX_l0=YCoo@3Rood0POn1oh7oPOn1
okGoo@3Rood0POn1oh7oPOn1okGoo@3Rood0POn1oh7oPOnRo`0fU?om0>;oo@21
oh7oPOn1oh7o]Oom0>;oo@21oh7oPOn1oh7o]Oom0>;oo@21oh7oPOn1oj;o03JE
oo`0h_om087oPOn1oh7oPOnfoo`0h_om087oPOn1oh7oPOnfoo`0h_om087oPOn1
oh7oX_l0=YGoo@3Pood0POn1oh7oPOn1okOoo@3Pood0POn1oh7oPOn1okOoo@3P
ood0POn1oh7oPOnSo`0fUOom0>3oo@21oh7oPOn1oh7o]oom0>3oo@21oh7oPOn1
oh7o]oom0>3oo@21oh7oPOn1oj?o03JEood0h?om087oPOn1oh7oPOngood0h?om
087oPOn1oh7oPOngood0h?om087oPOn1oh7oXol0=YGoo@3Pood0POn1oh7oPOn1
okOoo@3Pood0POn1oh7oPOn1okOoo@3Pood0POn1oh7oPOnSo`0fUOom0>3oo@21
oh7oPOn1oh7o]oom0>3oo@21oh7oPOn1oh7o]oom0>3oo@21oh7oPOn1oj?o03JF
oo`0h?om087oPOn1oh7oPOnhoo`0h?om087oPOn1oh7oPOnhoo`0h?om087oPOn1
oh7oXol0=YKoo@3Oood0POn1oh7oPOn1okSoo@3Oood0POn1oh7oPOn1okSoo@3O
ood0POn1oh7oPOnSo`0fU_om0=koo@21oh7oPOn1oh7o^Oom0=koo@21oh7oPOn1
oh7o^Oom0=koo@21oh7oPOn1ojCo03JFood0g_om087oPOn1oh7oPOniood0g_om
087oPOn1oh7oPOniood0g_om087oPOn1oh7oY?l0=YKoo@3Nood0POn1oh7oPOn1
okWoo@3Nood0POn1oh7oPOn1okWoo@3Nood0POn1oh7oPOnTo`0fU_om0=koo@21
oh7oPOn1oh7o^Oom0=koo@21oh7oPOn1oh7o^Oom0=koo@21oh7oPOn1ojCo03JF
ood0g_om087oPOn1oh7oPOniood0g_om087oPOn1oh7oPOniood0g_om087oPOn1
oh7oY?l0=YOoo@3Mood0POn1oh7oPOn1ok[oo@3Mood0POn1oh7oPOn1ok[oo@3M
ood0POn1oh7oPOnTo`0fUoom0=goo@21oh7oPOn1oh7o^_om0=goo@21oh7oPOn1
oh7o^_om0=goo@21oh7oPOn1ojCo03JGood0gOom087oPOn1oh7oPOnjood0gOom
087oPOn1oh7oPOnjood0gOom087oPOn1oh7oY?l0=YOoo@3Mood0POn1oh7oPOn1
ok[oo@3Mood0POn1oh7oPOn1ok[oo@3Mood0POn1oh7oPOnTo`0fUoom0=goo021
oh7oPOn1oh7o^oom0=goo021oh7oPOn1oh7o^oom0=goo021oh7oPOn1ojGo03JG
ood0g?om087oPOn1oh7oPOnkood0g?om087oPOn1oh7oPOnkood0g?om087oPOn1
oh7oYOl0=YSoo@3Kood0POn1oh7oPOn1okcoo@3Kood0POn1oh7oPOn1okcoo@3K
ood0POn1oh7oPOnUo`0fV?om0=_oo@21oh7oPOn1oh7o_?om0=_oo@21oh7oPOn1
oh7o_?om0=_oo@21oh7oPOn1ojGo03JHood0foom087oPOn1oh7oPOnlood0foom
087oPOn1oh7oPOnlood0foom087oPOn1oh7oYOl0=YSoo@3Kood0POn1oh7oPOn1
okcoo@3Kood0POn1oh7oPOn1okcoo@3Kood0POn1oh7oPOnUo`0fV?om0=_oo@21
oh7oPOn1oh7o_?om0=_oo@21oh7oPOn1oh7o_?om0=_oo@21oh7oPOn1ojGo03JH
ood0foom087oPOn1oh7oPOnlood0foom087oPOn1oh7oPOnlood0foom087oPOn1
oh7oYOl0=YSoo@3Kood0POn1oh7oPOn1okcoo@3Kood0POn1oh7oPOn1okcoo@3K
ood0POn1oh7oPOnUo`0fVOom0=[oo021oh7oPOn1oh7o__om0=[oo021oh7oPOn1
oh7o__om0=[oo021oh7oPOn1ojKo03JIood0fOom087oPOn1oh7oPOnnood0fOom
087oPOn1oh7oPOnnood0fOom087oPOn1oh7oY_l0=YWoo@3Iood0POn1oh7oPOn1
okkoo@3Iood0POn1oh7oPOn1okkoo@3Iood0POn1oh7oPOnVo`0fVOom0=Woo@21
oh7oPOn1oh7o__om0=Woo@21oh7oPOn1oh7o__om0=Woo@21oh7oPOn1ojKo03JI
ood0fOom087oPOn1oh7oPOnnood0fOom087oPOn1oh7oPOnnood0fOom087oPOn1
oh7oY_l0=YWoo@3Iood0POn1oh7oPOn1okkoo@3Iood0POn1oh7oPOn1okkoo@3I
ood0POn1oh7oPOnVo`0fVOom0=Woo@21oh7oPOn1oh7o__om0=Woo@21oh7oPOn1
oh7o__om0=Woo@21oh7oPOn1ojKo03JIood0fOol087oPOn1oh7oPOnoood0fOol
087oPOn1oh7oPOnoood0fOol087oPOn1oh7oYol0=Y[oo@3Good0POn1oh7oPOn1
ol3oo@3Good0POn1oh7oPOn1ol3oo@3Good0POn1oh7oPOnWo`0fV_om0=Ooo@21
oh7oPOn1oh7o`?om0=Ooo@21oh7oPOn1oh7o`?om0=Ooo@21oh7oPOn1ojOo03JJ
ood0eoom087oPOn1oh7oPOo0ood0eoom087oPOn1oh7oPOo0ood0eoom087oPOn1
oh7oYol0=Y[oo@3Good0POn1oh7oPOn1ol3oo@3Good0POn1oh7oPOn1ol3oo@3G
ood0POn1oh7oPOnWo`0fV_om0=Ooo@21oh7oPOn1oh7o`?om0=Ooo@21oh7oPOn1
oh7o`?om0=Ooo@21oh7oPOn1ojOo03JJood0eoom087oPOn1oh7oPOo0ood0eoom
087oPOn1oh7oPOo0ood0eoom087oPOn1oh7oYol0=Y[oo@3Good0POn1oh7oPOn1
ol3oo@3Good0POn1oh7oPOn1ol3oo@3Good0POn1oh7oPOnWo`0fVoom0=Koo021
oh7oPOn1oh7o`_om0=Koo021oh7oPOn1oh7o`_om0=Koo021oh7oPOn1ojSo03JK
ood0eOom087oPOn1oh7oPOo2ood0eOom087oPOn1oh7oPOo2ood0eOom087oPOn1
oh7oZ?l0=Y_oo@3Eood0POn1oh7oPOn1ol;oo@3Eood0POn1oh7oPOn1ol;oo@3E
ood0POn1oh7oPOnXo`0fVoom0=Goo@21oh7oPOn1oh7o`_om0=Goo@21oh7oPOn1
oh7o`_om0=Goo@21oh7oPOn1ojSo03JKood0eOom087oPOn1oh7oPOo2ood0eOom
087oPOn1oh7oPOo2ood0eOom087oPOn1oh7oZ?l0=Y_oo@3Eood0POn1oh7oPOn1
ol;oo@3Eood0POn1oh7oPOn1ol;oo@3Eood0POn1oh7oPOnXo`0fW?om0=Coo@21
oh7oPOn1oh7o`oom0=Coo@21oh7oPOn1oh7o`oom0=Coo@21oh7oPOn1ojSo03JL
ood0e?ol087oPOn1oh7oPOo4ood0e?ol087oPOn1oh7oPOo4ood0e?ol087oPOn1
oh7oZOl0=Ycoo@3Cood0POn1oh7oPOn1olCoo@3Cood0POn1oh7oPOn1olCoo@3C
ood0POn1oh7oPOnYo`0fW?om0=?oo@21oh7oPOn1oh7oa?om0=?oo@21oh7oPOn1
oh7oa?om0=?oo@21oh7oPOn1ojWo03JLood0doom087oPOn1oh7oPOo4ood0doom
087oPOn1oh7oPOo4ood0doom087oPOn1oh7oZOl0=Ycoo@3Cood0POn1oh7oPOn1
olCoo@3Cood0POn1oh7oPOn1olCoo@3Cood0POn1oh7oPOnYo`0fWOom0=;oo@21
oh7oPOn1oh7oaOom0=;oo@21oh7oPOn1oh7oaOom0=;oo@21oh7oPOn1ojWo03JM
ood0d_om087oPOn1oh7oPOo5ood0d_om087oPOn1oh7oPOo5ood0d_om087oPOn1
oh7oZOl0=Ygoo@3Bood0POn1oh7oPOn1olGoo@3Bood0POn1oh7oPOn1olGoo@3B
ood0POn1oh7oPOnYo`0fWOom0=7oo@21oh7oPOn1oh7oa_om0=7oo@21oh7oPOn1
oh7oa_om0=7oo@21oh7oPOn1oj[o03JMood0dOom087oPOn1oh7oPOo6ood0dOom
087oPOn1oh7oPOo6ood0dOom087oPOn1oh7oZ_l0=Ykoo03Aood0POn1oh7oPOn1
olOoo03Aood0POn1oh7oPOn1olOoo03Aood0POn1oh7oPOnZo`0fW_om0=3oo@21
oh7oPOn1oh7oaoom0=3oo@21oh7oPOn1oh7oaoom0=3oo@21oh7oPOn1oj[o03JN
ood0d?om087oPOn1oh7oPOo7ood0d?om087oPOn1oh7oPOo7ood0d?om087oPOn1
oh7oZ_l0=Ykoo@3@ood0POn1oh7oPOn1olOoo@3@ood0POn1oh7oPOn1olOoo@3@
ood0POn1oh7oPOnZo`0fW_om0=3oo@21oh7oPOn1oh7oaoom0=3oo@21oh7oPOn1
oh7oaoom0=3oo@21oh7oPOn1oj[o03JNood0d?ol087oPOn1oh7oPOo8ood0d?ol
087oPOn1oh7oPOo8ood0d?ol087oPOn1oh7oZol0=Yooo03?ood0POn1oh7oPOn1
olWoo03?ood0POn1oh7oPOn1olWoo03?ood0POn1oh7oPOn[o`0fWoom0<koo@21
oh7oPOn1oh7obOom0<koo@21oh7oPOn1oh7obOom0<koo@21oh7oPOn1oj_o03JO
ood0c_om087oPOn1oh7oPOo9ood0c_om087oPOn1oh7oPOo9ood0c_om087oPOn1
oh7oZol0=Yooo@3>ood0POn1oh7oPOn1olWoo@3>ood0POn1oh7oPOn1olWoo@3>
ood0POn1oh7oPOn[o`0fWoom0<koo@21oh7oPOn1oh7obOom0<koo@21oh7oPOn1
oh7obOom0<koo@21oh7oPOn1oj_o03JPoo`0c_om087oPOn1oh7oPOo:oo`0c_om
087oPOn1oh7oPOo:oo`0c_om087oPOn1oh7oZol0=Z3oo@3<ood0POn1oh7oPOn1
ol_oo@3<ood0POn1oh7oPOn1ol_oo@3<ood0POn1oh7oPOn/o`0fX?om0<coo@21
oh7oPOn1oh7oboom0<coo@21oh7oPOn1oh7oboom0<coo@21oh7oPOn1ojco03JP
ood0c?om087oPOn1oh7oPOo;ood0c?om087oPOn1oh7oPOo;ood0c?om087oPOn1
oh7o[?l0=Z3oo@3<ood0POn1oh7oPOn1ol_oo@3<ood0POn1oh7oPOn1ol_oo@3<
ood0POn1oh7oPOn/o`0fXOol0<coo@21oh7oPOn1oh7oc?ol0<coo@21oh7oPOn1
oh7oc?ol0<coo@21oh7oPOn1ojco03JQood0boom087oPOn1oh7oPOo<ood0boom
087oPOn1oh7oPOo<ood0boom087oPOn1oh7o[?l0=Z7oo@3;oo`0POn1oh7oPOn1
olgoo@3;oo`0POn1oh7oPOn1olgoo@3;oo`0POn1oh7oPOn]o`0fXOom0<[oo@21
oh7oPOn1oh7ocOom0<[oo@21oh7oPOn1oh7ocOom0<[oo@21oh7oPOn1ojgo03JR
oo`0b_om087oPOn1oh7oPOo>oo`0b_om087oPOn1oh7oPOo>oo`0b_om087oPOn1
oh7o[Ol0=Z;oo@39ood0POn1oh7oPOn1olkoo@39ood0POn1oh7oPOn1olkoo@39
ood0POn1oh7oPOn]o`0fX_om0<Woo@21oh7oPOn1oh7oc_om0<Woo@21oh7oPOn1
oh7oc_om0<Woo@21oh7oPOn1ojgo03JRood0bOom087oPOn1oh7oPOo>ood0bOom
087oPOn1oh7oPOo>ood0bOom087oPOn1oh7o[Ol0=Z;oo@39ood0POn1oh7oPOn1
olkoo@39ood0POn1oh7oPOn1olkoo@39ood0POn1oh7oPOn]o`0fXool0<Soo@21
oh7oPOn1oh7od?ol0<Soo@21oh7oPOn1oh7od?ol0<Soo@21oh7oPOn1ojko03JS
ood0aoom087oPOn1oh7oPOo@ood0aoom087oPOn1oh7oPOo@ood0aoom087oPOn1
oh7o[_l0=Z?oo@37ood0POn1oh7oPOn1om3oo@37ood0POn1oh7oPOn1om3oo@37
ood0POn1oh7oPOn^o`0fXoom0<Ooo@21oh7oPOn1oh7od?om0<Ooo@21oh7oPOn1
oh7od?om0<Ooo@21oh7oPOn1ojko03JToo`0aoom087oPOn1oh7oPOoAoo`0aoom
087oPOn1oh7oPOoAoo`0aoom087oPOn1oh7o[_l0=ZCoo@36oo`0POn1oh7oPOn1
om;oo@36oo`0POn1oh7oPOn1om;oo@36oo`0POn1oh7oPOn_o`0fY?om0<Goo@21
oh7oPOn1oh7od_om0<Goo@21oh7oPOn1oh7od_om0<Goo@21oh7oPOn1ojoo03JT
ood0aOom087oPOn1oh7oPOoBood0aOom087oPOn1oh7oPOoBood0aOom087oPOn1
oh7o[ol0=ZGoo035ood0POn1oh7oPOn1om?oo035ood0POn1oh7oPOn1om?oo035
ood0POn1oh7oPOn_o`0fYOom0<Coo021oh7oPOn1oh7oe?om0<Coo021oh7oPOn1
oh7oe?om0<Coo021oh7oPOn1ok3o03JUood0`oom087oPOn1oh7oPOoDood0`oom
087oPOn1oh7oPOoDood0`oom087oPOn1oh7o/?l0=ZKoo033ood0POn1oh7oPOn1
omGoo033ood0POn1oh7oPOn1omGoo033ood0POn1oh7oPOn`o`0fY_om0<;oo@21
oh7oPOn1oh7oeOom0<;oo@21oh7oPOn1oh7oeOom0<;oo@21oh7oPOn1ok3o03JV
ood0`_ol087oPOn1oh7oPOoFood0`_ol087oPOn1oh7oPOoFood0`_ol087oPOn1
oh7o/Ol0=ZOoo031ood0POn1oh7oPOn1omOoo031ood0POn1oh7oPOn1omOoo031
ood0POn1oh7oPOnao`0fYoom0<3oo@21oh7oPOn1oh7oeoom0<3oo@21oh7oPOn1
oh7oeoom0<3oo@21oh7oPOn1ok7o03JWood0`?om087oPOn1oh7oPOoGood0`?om
087oPOn1oh7oPOoGood0`?om087oPOn1oh7o/Ol0=ZOoo@30oo`0POn1oh7oPOn1
omSoo@30oo`0POn1oh7oPOn1omSoo@30oo`0POn1oh7oPOnbo`0fZ?ol0;ooo@21
oh7oPOn1oh7ofOol0;ooo@21oh7oPOn1oh7ofOol0;ooo@21oh7oPOn1ok;o03JX
ood0__om087oPOn1oh7oPOoIood0__om087oPOn1oh7oPOoIood0__om087oPOn1
oh7o/_l0=ZSoo@2nood0POn1oh7oPOn1omWoo@2nood0POn1oh7oPOn1omWoo@2n
ood0POn1oh7oPOnbo`0fZ?om0;koo021oh7oPOn1oh7of_om0;koo021oh7oPOn1
oh7of_om0;koo021oh7oPOn1ok?o03JYood0_?om087oPOn1oh7oPOoKood0_?om
087oPOn1oh7oPOoKood0_?om087oPOn1oh7o/ol0=ZWoo@2lood0POn1oh7oPOn1
om_oo@2lood0POn1oh7oPOn1om_oo@2lood0POn1oh7oPOnco`0fZ_om0;_oo021
oh7oPOn1oh7ogOom0;_oo021oh7oPOn1oh7ogOom0;_oo021oh7oPOn1okCo03JZ
ood0^_om087oPOn1oh7oPOoMood0^_om087oPOn1oh7oPOoMood0^_om087oPOn1
oh7o]?l0=Z[oo@2jood0POn1oh7oPOn1omgoo@2jood0POn1oh7oPOn1omgoo@2j
ood0POn1oh7oPOndo`0fZoom0;Woo021oh7oPOn1oh7ogoom0;Woo021oh7oPOn1
oh7ogoom0;Woo021oh7oPOn1okGo03J[ood0^?om087oPOn1oh7oPOoOood0^?om
087oPOn1oh7oPOoOood0^?om087oPOn1oh7o]Ol0=Zcoo02hood0POn1oh7oPOn1
on3oo02hood0POn1oh7oPOn1on3oo02hood0POn1oh7oPOneo`0f[?om0;Ooo@21
oh7oPOn1oh7oh?om0;Ooo@21oh7oPOn1oh7oh?om0;Ooo@21oh7oPOn1okGo03J]
oo`0]ool087oPOn1oh7oPOoRoo`0]ool087oPOn1oh7oPOoRoo`0]ool087oPOn1
oh7o]_l0=Zkoo02eood0POn1oh7oPOn1on?oo02eood0POn1oh7oPOn1on?oo02e
ood0POn1oh7oPOnfo`0n[_ol0;Goo@21omooo021oh7oPOn:oo`0]Oom087ogool
087oPOn1oh[oo02eood0POoOoo`0POn1oh7ogOl0CZoon`2eoo`0POoPoo`0POni
oo`0Qool087oeook0;Goo021on3oo021okWoo027oo`0POoGoo/0]Ool087oh?ol
087o^Ool08Ooo02Yo`1>[ool0;?oo@21on3oo021okWoo027oo`0POoGoo`0/oom
087oh?ol087o^Ool08Ooo021omOoo02cood0POoPoo`0POnioo`0Qool0:Wo04j`
oo/0/ool087ohOol087o^Ool08Ooo021omSon`2coo`0POoQoo`0POnioo`0Qool
087of?ok0;?oo021on7oo021okWoo027oo`0ZOl0C[3oo02aood0POoQoo`0POni
oo`0Qool087of?ol0;7oo@21on7oo021okWoo027oo`0POoHoo`0/Oom087ohOol
087o^Ool08Ooo02Yo`1>/Ook0;7oo@21on7oo021okWoo027oo`0POoIoo/0/Oom
087ohOol087o^Ool08Ooo021omWon`2aood0POoQoo`0POnioo`0Qool0:Wo03ja
oo`0[oom087oh_ol087oPOn1ohgoo02_ood0POoRoo`0POn1oh7oSOol0:ooo@21
on;oo021oh7oPOoMo`0n/_ol0:koo@21on;oo021oh7oPOn>oo`0[_om087oh_ol
087oPOn1ohkoo02^ood0POoRoo`0POn1oh7ogOl0?[;oo02]ood0POoSoo`0POn1
oh7oS_ol0:goo@21on?oo021oh7oPOn>oo`0[Oom087ohool087oPOn1omgo03jc
oo`0[?om087ohool087oPOn1ohooo02/ood0POoSoo`0POn1oh7oSool0:coo@21
on?oo021oh7oPOoMo`0n]?ok0:_oo@21onCoo021oh7oPOn@oo/0Zoom087oi?ol
087oPOn1oi3on`2[ood0POoToo`0POn1oh7ogOl0Z[Gon`2Zoo`0UOok0=Ooo03e
ooP0kooj0=[on@3_ooT0jOol0??oo03:ooX0kooj0:;oo03fooX0QOok0:[oo02E
oo/0eool0?Gon03_ooX0f_oi0>oon@3Yoo`0lool0<[onP3_ooX0X_ol0?KonP25
oo/0Z_ol09Gon`3Goo`0mOoh0>oonP3JooT0kooi0>Woo03coo`0b_oj0>oonP2R
oo`0m_oj0=7o0Ejfoo/0Z?om0:3oo03mooL0m_ol0?Goo03joo`0n?oc0??om@3P
oo@0m?oc0?Koo03nooX0oOol0?konP00oo`0l?ol0?coo03joo`0oOog0??omP3n
oo`0k?ol0?Koo03eood0o?ol0?[oo03nooX0n?oe08Won`2Xood0X?ol0?gom`3f
oo`0mOol0?[oo03hoo<0looe0>3om03doo<0m_ol0?konP3moo`0o_oj003oo03`
oo`0o?ol0?[oo03mooL0loof0?koo03/oo`0m_ol0?Goo@3loo`0n_ol0?konP3h
ooD0ROok0:Soo@2Poo`0oOog0?Koo03eoo`0n_ol0?Sol`3cooD0h?od0?Col`3f
oo`0o_oj0?goo03nooX00?ol0?3oo03loo`0n_ol0?gom`3cooH0o_ol0>coo03f
oo`0mOom0?coo03joo`0o_oj0?Som@3Do`5c]_ol0:Ooo02Qoo`00Ooom03goo`0
mOol0?[oo03ioo40m_ob0>;olP3foo40mool007oooT0oOol007oooT00Oooo03a
ood0nool0?[oo001oood0?Kol`01oool0>con`3goo`0m_ol0?coo03joo`00Ooo
n@3joo80R_ol0:Ooo02Qoo`00Ooom03goo`0mOol0?[oo03ioo40m_ob0>;olP3f
oo40mool007oooT0oOol007oooT00Oooo03aood0nool0?[oo001oood0?Kol`01
oool0>con`3goo`0m_ol0?coo03joo`00Ooon@3joo80R_ol0:Ooo02Qoo`00Ooo
m03goo`0mOol0?[oo03ioo40m_ob0>;olP3foo40mool007oooT0oOol007oooT0
0Oooo03aood0nool0?[oo001oood0?Kol`01oool0>con`3goo`0m_ol0?coo03j
oo`00Ooon@3joo80eOl1HKOoo02Uoo`0X_ol003olP3hoo`0mOol0?[oo03jonl0
n?o`0>Col03honl0n?ol003on03moo`00?oh007ooo`0lOom0?_oo03joo`00?oc
0?Ool@00oo`0jool0?SonP3good0nool0?[oo000ooP0noo`08coo02Uoo`0X_ol
003olP3hoo`0mOol0?[oo03jonl0n?o`0>Col03honl0n?ol003on03moo`00?oh
007ooo`0lOom0?_oo03joo`00?oc0?Ool@00oo`0jool0?SonP3good0nool0?[o
o000ooP0noo`08coo02Uoo`0X_ol003olP3hoo`0mOol0?[oo03jonl0n?o`0>Co
l03honl0n?ol003on03moo`00?oh007ooo`0lOom0?_oo03joo`00?oc0?Ool@00
oo`0jool0?SonP3good0nool0?[oo000ooP0noo`0=Ko0Kjhoo/0Y?om0:;oo000
ood0o?oj0?Woo03eoo`0n_ol0?_onP3koo/0nOoj0?conP3VooX0nook0?[onP3l
ooX0n?og0?go003mooL0oOl20?oon`3coo`0nool0?[oo000ood0oOoj0?SonP3l
ood00?ol0>_oo03hooX0moom0?_oo03jooL0oOl00?conP3looX0S_ok0:Coo@2R
oo`00?om0?conP3ioo`0mOol0?[oo03kooX0nook0?WonP3looX0i_oj0?_on`3j
ooX0o?oj0?Som`3mo`00oOog0?go0P3ooo/0lool0?_oo03joo`00?om0?gonP3h
ooX0o?om003oo03[oo`0n?oj0?Ooo@3koo`0n_og0?go003looX0o?oj08kon`2T
ood0X_ol003oo@3looX0nOol0?Goo03joo`0nooj0?_on`3iooX0o?oj0>KonP3k
oo/0n_oj0?conP3hooL0oOl00?gom`3mo`80oook0??oo03koo`0n_ol003oo@3m
ooX0n?oj0?coo@00oo`0jool0?SonP3good0nool0?[om`3mo`00o?oj0?conP3G
o`5f^Ook0:?oo02SooT0n?ok0?[oo03eoo`0n_ol0?_oo03hoo/0n_ok0?Woo03W
oo/0n?ok0?_oo03hoo/0nOoi0?Kon@3goo`0loom0?[oo03jooT0nOol0?Won`3h
ooT0jool0?SonP3good0nool0?[on@3eoo/0nOol08oon`2Soo`0Xooi0?Son`3j
oo`0mOol0?[oo03koo`0n?ok0?[on`3ioo`0iook0?Son`3koo`0n?ok0?Won@3f
ooT0mool0??oo@3joo`0n_oi0?Woo03ioo/0n?oi0>_oo03hooX0moom0?_oo03j
ooT0mOok0?Woo02?oo/0Xool0:?on@3hoo/0n_ol0?Goo03joo`0nool0?Son`3j
oo/0nOol0>Oon`3hoo/0nool0?Son`3iooT0m_oi0?Ooo03cood0n_ol0?[on@3i
oo`0nOok0?Son@3[oo`0n?oj0?Ooo@3koo`0n_oi0?Gon`3ioo`0eol1M[_onP2Q
oo`0Y?oj0?Koo03joo`0mOol0?[oo03loo`0m_ol0?_on`3hoo/0j?ol0?Koo03l
oo`0m_ol0?WonP3eooX0m_ok0?Goo03joo`0n_oj0?Son`3joo`0m_oj0>[oo03i
ooT0nOom0?[oo03jooX0mOok0?Son`2BooX0XOol0:ConP3foo`0n_ol0?Goo03j
oo`0o?ol0?Koo03koo/0n?ok0>Soo03foo`0o?ol0?Koo03iooX0mOoj0?Kon`3e
oo`0n_ol0?[onP3hoo/0n_ol0?KonP3Zoo`0nOoi0?Woo@3joo`0n_oj0?Gon`3h
oo/0T_oj0:7oo02TooX0m_ol0?[oo03eoo`0n_ol0?coo03foo`0nook0?Son`3X
oo`0m_ol0?coo03foo`0nOoj0?GonP3foo/0mOol0?[oo03jooX0n?ok0?[oo03f
ooX0j_ol0?Won@3iood0n_ol0?[onP3eoo/0n?ok0=So0GJlooX0X?oj0:KonP3f
oo/0nool0?Goo03joo`0o?ol0>_oo03foo`0jOok0?Koo03loo`0m_ol0?Won`3d
oo/0m?ol0?Goo@3ioo`0n_oj0?Ooo03koo/0m_oj0>[oo03jood00?om0?Woo@3j
oo`0n_ok0?Coo03foo`0Tooj0:3onP2VooX0m_ok0?_oo03eoo`0n_ol0?coo03[
oo`0m_ol0>Won`3foo`0o?ol0?Koo03ioo/0m?ok0?Coo03eood0nOol0?[onP3g
oo`0nook0?KonP3Zoo`0n_om003oo@3iood0n_ol0?[on`3doo`0m_ol09?onP2P
ooX0Y_oj0?Kon`3koo`0mOol0?[oo03loo`0jool0?Koo03Yoo/0m_ol0?coo03f
oo`0nOok0?Con`3doo`0mOom0?Woo03jooX0mool0?_on`3fooX0j_ol0?[oo@00
ood0nOom0?[oo03joo/0m?ol0?Koo03Ho`5N__oj09gonP2Woo/0m?ol0?_oo03e
oo`0n_ol0?coo03/oo`0mOol0>Woo03Koo`0nOok0?Con`3doo`0mOom0?Woo03j
oo/0m_ol0?_oo03doo/0j_ol0?[oo@00ood0nOom0?[oo03joo/0mOol0?Goo02E
ooX0WOoj0:Oon`3doo`0nool0?Goo03joo`0o?ol0>coo03eoo`0jOol0=_oo03i
oo/0m?ok0?Coo03eood0nOol0?[on`3foo`0nool0?Con`3Zoo`0n_om003oo@3i
ood0n_ol0?[on`3eoo`0mOol09GonP2MooX0Yook0?Coo03koo`0mOol0?[oo03l
oo`0k?ol0?Goo03Yoo`0fool0?Won`3doo/0m?ol0?Goo@3ioo`0n_ok0?Koo03k
oo`0m?ok0>[oo03jood00?om0?Woo@3joo`0n_ok0?Goo03eoo`0f?l1G/3on@2J
oo/0Z?ok0?Coo03koo`0mOol0?[oo03loo`0k?ol0?Coo03Zoo`0fool0?Won`3d
oo/0lool0?Ooo@3hoo`0n_ok0?Koo03koo`0m?ok0>[oo03jood00?om0?[oo03j
oo`0n_ok0?Goo03doo`0V?oi09[on`2Xoo/0m?ol0?_oo03eoo`0n_ol0?coo03/
oo`0m?ol0>[oo03Koo`0nOok0?Con`3coo`0moom0?Soo03joo/0m_ol0?_oo03d
oo/0j_ol0?[oo@00ood0n_ol0?[oo03joo/0mOol0?Coo02HooT0V_ok0:Son`3d
oo`0nool0?Goo03joo`0o?ol0>coo03doo`0j_ol0=_oo03ioo/0m?ok0??oo03g
ood0n?ol0?[on`3foo`0nool0?Con`3Zoo`0n_om003oo@3joo`0n_ol0?[on`3e
oo`0m?ol0=Wo0Ek7oo@0Uoof0:kon`3coo`0o?ol0?Goo03joo`0o?ok0>goo03d
oo`0jool0=[oo03ioo`0lool0?;oo03good0n?ol0?[oo03eoo`0o?ol0?;oo03Y
oo`0noom003oo03kood0nOol0?[oo03doo`0m?ol09oom02GooH0[_ok0??oo03l
oo`0mOol0?[oo03loo/0kOol0?Coo03[oo`0f_ol0?Woo03coo`0l_ol0?Ooo@3h
oo`0n_ol0?Goo03loo`0l_ol0>Woo03kood00?ol0?_oo@3ioo`0n_ol0?Coo03d
oo`0Wood09OomP2^oo/0lool0?coo03eoo`0n_ol0?con`3]oo`0m?ol0>_oo03J
oo`0nOol0??oo03boo`0moom0?Soo03joo`0mOol0?coo03boo`0jOol0?_oo@00
oo`0noom0?Woo03joo`0m?ol0?Coo03Io`5Naooe09Con02^oo`0l_ol0?coo03e
oo`0n_ol0?_on@3aoo`0lool0>_oo03Joo`0nOol0??oo03boo/0nOol0?Soo03j
oo`0mOol0?coo03boo`0jOol0?coo@3nood0noom0?Woo03joo`0mOol0??oo02O
ooD0U?oh0:koo03boo`0o?ol0?Goo03joo`0nooi0?7oo03coo`0jool0=[oo03i
oo`0lool0?;on`3ioo`0n?ol0?[oo03eoo`0o?ol0?;oo03Yoo`0o?om0?koo@3k
ood0nOol0?[oo03eoo`0lool09oom@2DooP0[_ol0?;oo03loo`0mOol0?[oo03k
ooT0lOol0??oo03[oo`0f_ol0?Woo03coo`0l_ok0?Woo03hoo`0n_ol0?Goo03l
oo`0l_ol0>Woo03lood0o_om0?_oo@3ioo`0n_ol0?Goo03coo`0fOl1A/Oom`2A
ooT0[_ol0?;oo03loo`0mOol0?[oo03kooH0m?oY0>_oo03LooX0nOol0??oo03a
oo`0nOom0?Ooo03joo`0mOol0?coo03boo`0jOol0?coo@3nood0noom0?Woo03j
oo`0mOoY09oom`2AooT0[_ol0?;oo03loo`0mOol0?[oo03kooH0m?oY0>_oo03L
ooX0nOol0??oo03aoo`0nOom0?Ooo03joo`0mOol0?coo03boo`0jOol0?coo@3n
ood0noom0?Woo03joo`0mOoY09oom`2AooT0[_ol0?;oo03loo`0mOol0?[oo03k
ooH0m?oY0>_oo03LooX0nOol0??oo03aoo`0nOom0?Ooo03joo`0mOol0?coo03b
oo`0jOol0?coo@3nood0noom0?Woo03joo`0mOoY0=Wo0DK7ooT0S_ok0:goo03b
oo`0o?ol0?Goo03joo`0n_od0?Ooj@3[oo`0h?of0?Woo03coo`0lOol0?[oo03g
oo`0n_ol0?Goo03loo`0l_ol0>Soo@3lood0o_om0?coo@3hoo`0n_ol0?Goj@2O
ooT0S_ok0:goo03boo`0o?ol0?Goo03joo`0n_od0?Ooj@3[oo`0h?of0?Woo03c
oo`0lOol0?[oo03goo`0n_ol0?Goo03loo`0l_ol0>Soo@3lood0o_om0?coo@3h
oo`0n_ol0?Goj@2OooT0S_ok0:goo03boo`0o?ol0?Goo03joo`0n_od0?Ooj@3[
oo`0h?of0?Woo03coo`0lOol0?[oo03goo`0n_ol0?Goo03loo`0l_ol0>Soo@3l
ood0o_om0?coo@3hoo`0n_ol0?Goj@3Io`4nP@2H0=_oo03boo`0o?ol0?Goo03j
oo`0n?oc0?[oj@3[oo`0hooc0?Woo03coo`0l?ol0?_oo@3foo`0n_ol0?Goo03l
oo`0l_ol0>Soo03mood0o_ol0?goo@3hoo`0n_ol0?Goj@3Ioh40V03Koo`0l_ol
0?coo03eoo`0n_ol0?Sol`3jonT0jool0>?ol`3ioo`0lool0?3oo03kood0m_ol
0?[oo03eoo`0o?ol0?;oo03Xoo`0oOom0?koo03mood0n?ol0?[oo03eonT0fOn1
09P0fool0?;oo03loo`0mOol0?[oo03hoo<0n_oY0>_oo03Soo<0nOol0??oo03`
oo`0noom0?Koo03joo`0mOol0?coo03boo`0j?ol0?goo@3noo`0oOom0?Soo03j
oo`0mOoY0=Wo0Cj109P0fool0?;oo03loo`0mOol0?[oo03foo@0nooY0>_oo03V
oo00nOol0??oo03`oo`0noom0?Koo03joo`0mOol0?coo03boo`0j?ol0?koo@3l
ood0oOom0?Soo03joo`0mOoY0=WoP@2H0=_oo03boo`0o?ol0?Goo03joo`0m_od
0?_oj@3[oo`0i_o`0?Woo03coo`0l?ol0?_oo@3foo`0n_ol0?Goo03loo`0l_ol
0>Soo03nood0o?om0?goo@3hoo`0n_ol0?Goj@3Ioh40V03Koo`0l_ol0?coo03e
oo`0n_ol0?Kom03konT0jool0>Kol03ioo`0lool0?3oo03kood0m_ol0?[oo03e
oo`0o?ol0?;oo03Xoo`0o_om0?coo@3mood0n?ol0?[oo03eonT0fOl1CH40V03K
oo`0l_ol0?coo03eoo`0n_ol0??omP3loo`0f?ol0>OomP01oool0?Woo03coo`0
l?ok0?goo03foo`0n_ol0?Goo03loo`0l_ol0>Soo03nood0o?om0?koo03hoo`0
n_ol0?Goo036oh40V03Koo`0l_ol0?coo03eoo`0n_ol0??omP3loo`0f?ol0>Oo
mP01oool0?Woo03coo`0l?ok0?goo03foo`0n_ol0?Goo03loo`0l_ol0>Soo03n
ood0o?om0?koo03hoo`0n_ol0?Goo036oh40V03Koo`0l_ol0?coo03eoo`0n_ol
0??omP3loo`0f?ol0>OomP01oool0?Woo03coo`0l?ok0?goo03foo`0n_ol0?Go
o03loo`0l_ol0>Soo03nood0o?om0?koo03hoo`0n_ol0?Goo036o`5@P@2H0=_o
o03boo`0o?ol0?Goo03joo`0l?oi0?coo03Hoo`0j?oi0?_oo03ioo`0lool0>oo
o03mood0mOol0?[oo03eoo`0o?ol0?;oo03Woo`00Oooo@3loo`00Oooo@3goo`0
n_ol0?Goo036oh40V03Koo`0l_ol0?coo03eoo`0n_ol0?3on@3loo`0f?ol0>So
n@3koo`0nOol0??oo03_oo`0oOom0?Goo03joo`0mOol0?coo03boo`0iool007o
ood0o?ol007oood0mool0?[oo03eoo`0a_n109P0fool0?;oo03loo`0mOol0?[o
o03`ooT0o?ol0=Soo03XooT0nool0?Woo03coo`0kool0?goo@3eoo`0n_ol0?Go
o03loo`0l_ol0>Ooo001ooom0?coo001ooom0?Ooo03joo`0mOol0<Ko0Dn1oh7o
l_ol0?;oo03loo`0mOol0?[oo03]oo/0oOol0=Soo03YooX0nOol0?Woo03coo`0
kook007ooo`0mOol0?[oo03eoo`0o?ol0??on`3Woo`00Oooo@3loo`00Oooo@3g
oo`0n_ol0?Goo021oh7o]ool0?;oo03loo`0mOol0?[oo03]oo/0oOol0=Soo03Y
ooX0nOol0?Woo03coo`0kook007ooo`0mOol0?[oo03eoo`0o?ol0??on`3Woo`0
0Oooo@3loo`00Oooo@3goo`0n_ol0?Goo021oh7o]ool0?;oo03loo`0mOol0?[o
o03]oo/0oOol0=Soo03YooX0nOol0?Woo03coo`0kook007ooo`0mOol0?[oo03e
oo`0o?ol0??on`3Woo`00Oooo@3loo`00Oooo@3goo`0n_ol0?Goo036o`5?POn1
oo;oo03boo`0o?ol0?Goo03joo`0k?ol0?goo03Hoo`0jOol0?Ooo03ioo`0lool
0>koo001ooom0?Coo03joo`0mOol0?_oo03doo/0iool007oooh0n_om007oood0
mool0?[oo03eoo`0POn1okOoo03boo`0o?ol0?Goo03joo`0k?ol0?goo03Hoo`0
jOol0?Ooo03ioo`0lool0>koo001ooom0?Coo03joo`0mOol0?_oo03doo/0iool
007oooh0n_om007oood0mool0?[oo03eoo`0POn1okOoo03boo`0o?ol0?Goo03j
oo`0k?ol0?goo03Hoo`0jOol0?Ooo03ioo`0lool0>koo001ooom0?Coo03joo`0
mOol0?_oo03doo/0iool007oooh0n_om007oood0mool0?[oo03eoo`0a_l1C87o
POoboo/0m?ol0?_oo03foo/0n_ol0>coo03loo`0f?ol0>_on`3goo`0nOol0??o
o03^oo`00Oooo@3doo`0n_ol0?Goo03koo`0m?ok0>Koo@00ood0n_om007oooh0
m_ol0?[oo03doo`0POn1okSon`3doo`0nool0?Kon`3joo`0k?ol0?coo03Hoo`0
jook0?Ooo03ioo`0lool0>koo001ooom0?Coo03joo`0mOol0?_oo03doo/0i_om
003oo@3jood00OoooP3foo`0n_ol0?Coo021oh7o^?ok0?Coo03koo`0m_ok0?[o
o03/oo`0o?ol0=Soo03[oo/0mool0?Woo03coo`0k_ol007oood0m?ol0?[oo03e
oo`0nool0?Con`3Vood00?om0?[oo@01ooon0?Koo03joo`0m?ol0<Oo0Bj1oh7o
l_ok0?Coo03koo`0m_ok0?[oo03/oo`0o?ol0=Soo03[oo`0mook0?Woo03coo`0
kOoh0??oo03joo`0mOol0?_oo03eooX0i_om003oo@3jooP0m_ol0?[oo03doo`0
POn1okSon`3doo`0nool0?Kon`3joo`0k?ol0?coo03Hoo`0jool0?Oon`3ioo`0
lool0>gon03coo`0n_ol0?Goo03koo`0mOoj0>Koo@00ood0n_oh0?Koo03joo`0
m?ol087oPOnhoo/0m?ol0?_oo03foo/0n_ol0>coo03loo`0f?ol0>_oo03goo/0
nOol0??oo03]ooP0lool0?[oo03eoo`0nool0?GonP3Vood00?om0?[on03foo`0
n_ol0?Coo037o`56POn1oo;onP3foo/0nool0?OonP3joo`0k?ol0?con`3eoo`0
j_ok0?Koo03loo`0mook0?Woo03coo`0kOoh0??oo03joo`0mOol0?[oo03gooT0
i_oh0?[on03foo`0n_ol0?Con`3eoo`0POn1ol[onP3foo/0nool0?OonP3joo`0
k?ol0?con`3eoo`0j_ok0?Koo03loo`0mook0?Woo03coo`0kOoh0??oo03joo`0
mOol0?[oo03gooT0i_oh0?[on03foo`0n_ol0?Con`3eoo`0POn1ol[onP3foo/0
nool0?OonP3joo`0k?ol0?con`3eoo`0j_ok0?Koo03loo`0mook0?Woo03coo`0
kOoh0??oo03joo`0mOol0?[oo03gooT0i_oh0?[on03foo`0n_ol0?Con`3eoo`0
fOl1DX7oPOobooX0m_ol0?[on`3hooX0n_ol0?coo03goo/0nook0?Koo03Yoo`0
m_ol0?coo03hooX0nOol0??oo03]ooP0lool0?[oo03eoo`0n_ok0?Won03VooT0
n?oi0?Koo03joo`0look0?Koo021oh7ob_oj0?Koo03joo/0n?oj0?[oo03loo`0
mook0?_on`3foo`0jOol0?Koo03loo`0n?oj0?Woo03coo`0kOoh0??oo03joo`0
mOol0?[on`3iooP0i_oi0?Son@3foo`0n_ol0??on`3foo`0POn1ol[onP3foo`0
n_ok0?SonP3joo`0o?ol0?Oon`3koo/0m_ol0>Woo03foo`0o?ol0?SonP3ioo`0
lool0>gon03coo`0n_ol0?Goo03joo/0nOoh0>Kon@3hooT0m_ol0?[oo03coo/0
m_ol0=Wo0Ej1oh7ol_oi0?Son`3ioo`0nOoi0?[oo03loo/0nOok0?[onP3hoo`0
j?ok0?Soo03koo/0n_oi0?Woo03coo`0k?oj0?;oo03joo`0mOol0?WonP3lood0
0?ol0>GonP3hooX0mOol0?[oo03cooX0n?ol087oPOo9ooT0n?ok0?Woo03iooT0
n_ol0?con`3ioo/0n_oj0?Soo03Xoo/0n?ol0?_on`3jooT0nOol0??oo03/ooX0
l_ol0?[oo03eoo`0nOoj0?coo@00oo`0iOoj0?SonP3eoo`0n_ol0??onP3hoo`0
POn1olWon@3hoo/0nOol0?Won@3joo`0o?ok0?Won`3jooX0n?ol0>Son`3hoo`0
nook0?[on@3ioo`0lool0>conP3boo`0n_ol0?Goo03iooX0o?om003oo03UooX0
n?oj0?Goo03joo`0looj0?Soo03Ho`5ZPOn1oo;oo000ood0o?oj0?SonP3mood0
0?ol0?[oo03koo/0nooj0?Won@3koo/0iooj0?_on`3joo/0oOog0?Woo03coo`0
k?oj0?;oo03joo`0mOol0?SolP00oo`0iOoj0?SonP3eoo`0n_ol0?;on@3koo/0
POn1olWoo000ood0o?oj0?SonP3mood00?ol0?[oo03koo/0nooj0?Won@3koo/0
iooj0?_on`3joo/0oOog0?Woo03coo`0k?oj0?;oo03joo`0mOol0?SolP00oo`0
iOoj0?SonP3eoo`0n_ol0?;on@3koo/0POn1olWoo000ood0o?oj0?SonP3mood0
0?ol0?[oo03koo/0nooj0?Won@3koo/0iooj0?_on`3joo/0oOog0?Woo03coo`0
k?oj0?;oo03joo`0mOol0?SolP00oo`0iOoj0?SonP3eoo`0n_ol0?;on@3koo/0
f?l19H7oPOoboo`00?ob0?OolP00oo`0n_ol0?_ok`3gonl0iOo`0?Wol`00oo`0
nOol0??oo03[oo`0lOol0?[oo03eoo`0mood007ooo`0iOoj0?Oon`3eoo`0n_ol
0?7ok`21oh7ob?ol003olP3goo800?ol0?[oo03konl0moo_0>Gol03ioo<00?ol
0?Woo03coo`0jool0?7oo03joo`0mOol0?Oom001oool0>GonP3goo/0mOol0?[o
o03aonl0POn1olSoo000oo80moob003oo03joo`0noo_0?Ook`3Uoo00nOoc003o
o03ioo`0lool0>_oo03aoo`0n_ol0?Goo03goo@00Oooo03UooX0mook0?Goo03j
oo`0lOo_0=Oo0B^1oh7ol_ol007ooo@0mOod007ooo`0n_ol0?[ol@3eoo40hoob
0?Oom@01oook0?[oo03coo`0jool0?7oo03joo`0mOol0?Kom`3moo`0i?ol0?Ko
o03doo`0n_ol0?3ol@21oh7oaool007ooo@0mOod007ooo`0n_ol0?[ol@3eoo40
hoob0?Oom@01oook0?[oo03coo`0jool0?7oo03joo`0mOol0?Kom`3moo`0i?ol
0?Koo03doo`0n_ol0?3ol@21oh7oaool007ooo@0mOod007ooo`0n_ol0?[ol@3e
oo40hoob0?Oom@01oook0?[oo03coo`0jool0?7oo03joo`0mOol0?Kom`3moo`0
i?ol0?Koo03doo`0n_ol0?3ol@3Fo`4RPOn1oo;oo03nooH0l_oh0?goo03joo`0
n?od0?;om03Qoo@0mOoh0?coo03joo`0lool0>_oo03aoo`0n_ol0?Goo03doo/0
nool0>Coo03foo`0m?ol0?[oo03^oo@0POn1olKoo03nooH0l_oh0?goo03joo`0
n?od0?;om03Qoo@0mOoh0?coo03joo`0lool0>_oo03aoo`0n_ol0?Goo03doo/0
nool0>Coo03foo`0m?ol0?[oo03^oo@0POn1olKoo03nooH0l_oh0?goo03joo`0
n?od0?;om03Qoo@0mOoh0?coo03joo`0lool0>_oo03aoo`0n_ol0?Goo03doo/0
nool0>Coo03foo`0m?ol0?[oo03^oo@0eOl0QX7oPOoboo`0nook0>koo03OooT0
kOoi0=_on@3aoo`0`?om0;Goo02LooT0POn1ol?oo03koo/0k_ol0=oon@3]ooT0
fooi0?7oo030ood0]Ool09con@21oh7o`ool0?_on`3^oo`0gooi0>gon@3KooT0
lOol0<3oo@2eoo`0W?oi0=;o03j1oh7ol_ol087oU?ol0;Goo021oh7oPOoFoo`0
POnDoo`0]Ool087oPOn1omKoo021oiCoo02eoo`0POoUo`0nPOn1oo;oo021oiCo
o@2doo`0POn1oh7oe_ol087oU?om0;Coo021oh7oPOoFoo`0POnDood0]?ol087o
iOl0BX7oPOoboo`0POnEoo`0b?ol0??oo021oh7oPOoEoo`0POnEoo`0b?ol0??o
o021oh7oPOoEoo`0POnEoo`0b?ol0??oo021onCo04Z1oh7ol_ol087oUOom0<Oo
o03coo`0POn1oh7oeOol087oUOom0<Ooo03coo`0POn1oh7oeOol087oUOom0<Oo
o03coo`0POoTo`1:POn1oo;oo021oiKoo037oo/0mOok087oPOn1omGoo021oiKo
o037oo/0mOok087oPOn1omGoo021oiKoo037oo/0mOok087oi?l0BX7oPOoboo`0
POnHoo/0aOok0?Oon`21oh7oPOoDoo`0POnHoo/0aOok0?Oon`21oh7oPOoDoo`0
POnHoo/0aOok0?Oon`21on?o04Z1oh7ol_ol087oW_oe0<Gon@3kooX0POn1oh7o
dool087oW_oe0<Gon@3kooX0POn1oh7odool087oW_oe0<Gon@3kooX0POoRo`0n
POn1oo;oo021oikomP33ond0POn1oh7odool087oW_of0<?ok@21oh7oPOoCoo`0
POnNooH0`oo]087oh_l0?X7oPOoboo`0POnNooL0`Oo`087oPOn1om7oo021oiko
m`31oo00POn1oh7odOol087oW_og0<7ol021on3o03j1oh7ol_ol087oW_oi0;go
l`21oh7oPOo@oo`0POnNooT0_Ooc087oPOn1om3oo021oikon@2moo<0POoOo`0/
POn1oh7oPOnkooT0POn1oh7oPOn1oiKon@21oh7oPOn1oh7oU_oi087og?l0987o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
Z?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo
02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0T
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
Z?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo
02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0T
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
Z?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo
02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0T
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
Z?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0ZPOol087o
POn1oh7oPOnCoo`0POn1oh7oPOn1oi?oo021oh7oPOn1oi?o02Z1oo`0POn1oh7o
POn1oi?oo021oh7oPOn1oh7oTool087oPOn1oh7oTol0:X7oo021oh7oPOn1oh7o
Tool087oPOn1oh7oPOnCoo`0POn1oh7oPOnCo`0ZPOol087oPOn1oh7oPOnCoo`0
POn1oh7oPOn1oi?oo021oh7oPOn1oi?o02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
Z?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo
02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oZ?l0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7oPOnCoo`0POn1oh7o
POnCo`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7oPOn1oi?oo021oh7oPOn1oi?o
02Z1oo`0POn1oh7oPOn1oi?oo021oh7oPOn1oh7oTool087oPOn1oh7oTol0:X7o
o021oh7oPOn1oh7oTool087oPOn1oh7oPOnCoo`0POn1oh7oPOnCo`0ZPOol087o
POn1oh7oPOnCoo`0POn1oh7oPOn1oi?oo021oh7oPOn1oi?o02B1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
Z?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oZ?l0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7o
POnCoo`0POn1oh7oPOnCo`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7oPOn1oi?o
o021oh7oPOn1oi?o02Z1oo`0POn1oh7oPOn1oi?oo021oh7oPOn1oh7oTool087o
POn1oh7oTol0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7oPOnCoo`0POn1oh7o
POnCo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
Z?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo
02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0T
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0:X7oo021oh7oPOn1oh7oTool087o
POn1oh7oPOnCoo`0POn1oh7oPOnCo`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7o
POn1oi?oo021oh7oPOn1oi?o02Z1oo`0POn1oh7oPOn1oi?oo021oh7oPOn1oh7o
Tool087oPOn1oh7oTol0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7oPOnCoo`0
POn1oh7oPOnCo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo
02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0T
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0:X7oo021oh7oPOn1oh7o
Tool087oPOn1oh7oPOnCoo`0POn1oh7oPOnCo`0ZPOol087oPOn1oh7oPOnCoo`0
POn1oh7oPOn1oi?oo021oh7oPOn1oi?o02Z1oo`0POn1oh7oPOn1oi?oo021oh7o
POn1oh7oTool087oPOn1oh7oTol0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7o
POnCoo`0POn1oh7oPOnCo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02Z109`0POn1oh7oPOocoh40W021oh7o
POn1oo?oP@2L087oPOn1oh7olol0:X40W021oh7oPOn1oo?oP@2L087oPOn1oh7o
lon109`0POn1oh7oPOoco`0ZP@2L087oPOn1oh7olon109`0POn1oh7oPOocoh40
W021oh7oPOn1oo?o02Z109`0POn1oh7oPOocoh40W021oh7oPOn1oo?oP@2L087o
POn1oh7olol0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0T
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oZ?l0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7oPOnCoo`0
POn1oh7oPOnCo`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7oPOn1oi?oo021oh7o
POn1oi?o02Z1oo`0POn1oh7oPOn1oi?oo021oh7oPOn1oh7oTool087oPOn1oh7o
Tol0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7oPOnCoo`0POn1oh7oPOnCo`0T
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
Z?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oZ?l0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7o
POnCoo`0POn1oh7oPOnCo`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7oPOn1oi?o
o021oh7oPOn1oi?o02Z1oo`0POn1oh7oPOn1oi?oo021oh7oPOn1oh7oTool087o
POn1oh7oTol0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7oPOnCoo`0POn1oh7o
POnCo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
Z?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo
02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0T
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02Z1oo`0POn1oh7o
POn1oi?oo021oh7oPOn1oh7oTool087oPOn1oh7oTol0:X7oo021oh7oPOn1oh7o
Tool087oPOn1oh7oPOnCoo`0POn1oh7oPOnCo`0ZPOol087oPOn1oh7oPOnCoo`0
POn1oh7oPOn1oi?oo021oh7oPOn1oi?o02Z1oo`0POn1oh7oPOn1oi?oo021oh7o
POn1oh7oTool087oPOn1oh7oTol0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7o
POnCoo`0POn1oh7oPOnCo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
Z?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo
02Z1oo`0POn1oh7oPOn1oi?oo021oh7oPOn1oh7oTool087oPOn1oh7oTol0:X7o
o021oh7oPOn1oh7oTool087oPOn1oh7oPOnCoo`0POn1oh7oPOnCo`0ZPOol087o
POn1oh7oPOnCoo`0POn1oh7oPOn1oi?oo021oh7oPOn1oi?o02Z1oo`0POn1oh7o
POn1oi?oo021oh7oPOn1oh7oTool087oPOn1oh7oTol0987oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
Z?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo
02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0T
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ojSo02Z1oo`0POn1oh7oPOn1oi?oo021oh7oPOn1oh7oTool087oPOn1oh7o
Tol0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7oPOnCoo`0POn1oh7oPOnCo`0Z
POol087oPOn1oh7oPOnCoo`0POn1oh7oPOn1oi?oo021oh7oPOn1oi?o02Z1oo`0
POn1oh7oPOn1oi?oo021oh7oPOn1oh7oTool087oPOn1oh7oTol0987oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0T
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ojSo02Z1oo`0POn1oh7oPOn1oi?oo021oh7oPOn1oh7oTool087o
POn1oh7oTol0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7oPOnCoo`0POn1oh7o
POnCo`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7oPOn1oi?oo021oh7oPOn1oi?o
02Z1oo`0POn1oh7oPOn1oi?oo021oh7oPOn1oh7oTool087oPOn1oh7oTol0987o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
Z?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo
02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ojSo02Z1oo`0POn1oh7oPOn1oi?oo021oh7oPOn1oh7o
Tool087oPOn1oh7oTol0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7oPOnCoo`0
POn1oh7oPOnCo`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7oPOn1oi?oo021oh7o
POn1oi?o02Z1oo`0POn1oh7oPOn1oi?oo021oh7oPOn1oh7oTool087oPOn1oh7o
Tol0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo
02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0T
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02Z1oo`0POn1oh7oPOn1oi?oo021oh7o
POn1oh7oTool087oPOn1oh7oTol0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7o
POnCoo`0POn1oh7oPOnCo`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7oPOn1oi?o
o021oh7oPOn1oi?o02Z1oo`0POn1oh7oPOn1oi?oo021oh7oPOn1oh7oTool087o
POn1oh7oTol0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0T
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
Z?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0ZPOol087o
POn1oh7oPOnCoo`0POn1oh7oPOn1oi?oo021oh7oPOn1oi?o02Z1oo`0POn1oh7o
POn1oi?oo021oh7oPOn1oh7oTool087oPOn1oh7oTol0:X7oo021oh7oPOn1oh7o
Tool087oPOn1oh7oPOnCoo`0POn1oh7oPOnCo`0ZPOol087oPOn1oh7oPOnCoo`0
POn1oh7oPOn1oi?oo021oh7oPOn1oi?o02Z1oo`0POn1oh7oPOn1oi?oo021oh7o
POn1oh7oTool087oPOn1oh7oTol0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo
02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0T
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POnXo`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7oPOn1oi?oo021oh7oPOn1oi?o
02Z1oo`0POn1oh7oPOn1oi?oo021oh7oPOn1oh7oTool087oPOn1oh7oTol0:X7o
o021oh7oPOn1oh7oTool087oPOn1oh7oPOnCoo`0POn1oh7oPOnCo`0ZPOol087o
POn1oh7oPOnCoo`0POn1oh7oPOn1oi?oo021oh7oPOn1oi?o02B1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
Z?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOnXo`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7oPOn1oi?oo021oh7o
POn1oi?o02Z109`0POn1oh7oPOocoh40W021oh7oPOn1oo?oP@2L087oPOn1oh7o
lol0:X40W021oh7oPOn1oo?oP@2L087oPOn1oh7olon109`0POn1oh7oPOoco`0Z
P@2L087oPOn1oh7olon109`0POn1oh7oPOocoh40W021oh7oPOn1oo?o02Z109`0
POn1oh7oPOocoh40W021oh7oPOn1oo?oP@2L087oPOn1oh7olol0987oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0T
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOnXo`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7o
POn1oi?oo021oh7oPOn1oi?o02Z1oo`0POn1oh7oPOn1oi?oo021oh7oPOn1oh7o
Tool087oPOn1oh7oTol0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7oPOnCoo`0
POn1oh7oPOnCo`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7oPOn1oi?oo021oh7o
POn1oi?o02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
Z?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo
02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0ZPOol087oPOn1oh7oPOnCoo`0
POn1oh7oPOn1oi?oo021oh7oPOn1oi?o02Z1oo`0POn1oh7oPOn1oi?oo021oh7o
POn1oh7oTool087oPOn1oh7oTol0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7o
POnCoo`0POn1oh7oPOnCo`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7oPOn1oi?o
o021oh7oPOn1oi?o02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
Z?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo
02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0T
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0ZPOol087oPOn1oh7o
POnCoo`0POn1oh7oPOn1oi?oo021oh7oPOn1oi?o02Z1oo`0POn1oh7oPOn1oi?o
o021oh7oPOn1oh7oTool087oPOn1oh7oTol0:X7oo021oh7oPOn1oh7oTool087o
POn1oh7oPOnCoo`0POn1oh7oPOnCo`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7o
POn1oi?oo021oh7oPOn1oi?o02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0T
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7o
POn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
POn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7o
Z?l0=X7oo021olWoo021oh7oPOn1om3oo021olWoo021oh7oPOn1om3oo021olWo
o021oh7oPOo@o`18POol087obOol0?Woo021ok_oo021oh7oZ?ol087obOol0?Wo
o021ok_oo021oh7oZ?ol087obOol0?Woo021ok_oo021ojSo04R1oo`0POo9oo`0
nOol087o^ool087oPOnXoo`0POo9oo`0nOol087o^ool087oPOnXoo`0POo9oo`0
nOol087o^ool087oZ?l0B87oo021olWoo03ioo`0POnkoo`0POn1ojSoo021olWo
o03ioo`0POnkoo`0POn1ojSoo021olWoo03ioo`0POnkoo`0POnXo`18POol087o
bOol0?Woo021ok_oo021oh7oZ?ol087obOol0?Woo021ok_oo021oh7oZ?ol087o
bOol0?Woo021ok_oo021ojSo04:1oh7oa?ol0?Woo021ok_oo021oh7oPOn1on_o
o03ioo`0POnkoo`0POn1oh7oPOo[oo`0nOol087o^ool087oZ?l0>87oPOo4oo`0
POoioo`0POn1oh7oPOnPoo`0POoioo`0POn1oh7oPOnPoo`0POoioo`0POn1omgo
03R1oh7oa?ol087onOol087oPOn1oh7oX?ol087onOol087oPOn1oh7oX?ol087o
nOol087oPOoMo`0hPOn1olCoo021ooWoo021oh7oPOn1oj3oo021ooWoo021oh7o
POn1oj3oo021ooWoo021oh7ogOl0>87oPOo4oo`0POoioo`0POn1oh7oPOnPoo`0
POoioo`0POn1oh7oPOnPoo`0POoioo`0POn1omgo03R1oh7oa?ol087onOol087o
POn1oh7oX?ol087onOol087oPOn1oh7oX?ol087onOol087oPOoMo`2<POn1onco
n@3]ooX0o?ol0>Oon@3/ooT0k_oj0>SonP3boo`0YOol0?KonP21oh7oPOnkooT0
kOoj0?coo03WooT0k?oi0>konP3XooX0l_ol0:Goo03fooX0POn1oh7o^ooi0>go
nP3loo`0iooi0>con@3^ooX0j?oj0?;oo02Uoo`0m_oj087od?l0h87oPOo_oo<0
l_of0?koo03ioo`0mooc0?;om03booD0mOol0?gom`3ionl0kOol0?Koo03eood0
o?ol0?[oo03nooX0n?oe087oPOn1ol7ol`3booH0o_ol0?Woo03goo<0l_od0?;o
m@3eoo`0oOog0?Wok`3]oo`0m_ol0?Goo@3loo`0n_ol0?konP3hooD0POn1oh7o
`Ooc0?;omP3noo`0nOol0?Ool`3boo@0l_oe0?Goo03mooL0nOo_0>goo03foo`0
mOom0?coo03joo`0o_oj0?Som@21om?o0>V1oh7ol?oa0?Com001oool0?Woo03h
oo40m?ob0?GolP3foo`00Ooom03jonl0kOok0?Ooo03foo`0o?ol0?[oo001oooi
0?[olP21oh7oPOo3oo40m?od007ooo`0nOol0?Sol@3doo80mOob0?Koo001oood
0?[ok`3]oo/0mool0?Koo03loo`0n_ol007oooT0n_ob087oPOn1ol?ol@3doo@0
0Oooo03ioo`0n?oa0?ColP3eoo80m_ol007ooo@0n_o_0>gon`3goo`0m_ol0?co
o03joo`00Ooon@3joo80POoDo`3PPOn1oo7ok`3foo800?ol0?Woo03ionl0m_o`
0?Ool03goo`00?oc0?[ok`3/oo`0n?oj0?Ooo@3koo`0n_ol003on03koo00POn1
oh7oaOo_0?KolP00oo`0nOol0?Wok`3foo00moo`0?Ooo000oo<0n_o_0>coo03h
ooX0moom0?_oo03joo`00?oh0?_ol021oh7oPOo5onl0m_ob003oo03ioo`0nOo_
0?Kol03goo00mool003ol`3jonl0k?ol0?SonP3good0nool0?[oo000ooP0noo`
087oeOl1=87oPOobooX0o?oj0?OonP3lood00?ol0?Woo03jooX0o?oj0?OonP3k
oo/0nOoj0?conP3hoo`00?om0?gonP3konl0k?ol0?SonP3good0nool0?[om`3m
o`00o?oj0?conP21oh7oPOo7ooX0o?oj0?OonP3lood00?ol0?Woo03jooX0o?oj
0?OonP3koo/0nOoj0?conP3hoo`00?om0?gonP3konl0k?ol0?SonP3good0nool
0?[om`3mo`00o?oj0?conP21oh7oPOo7ooX0o?oj0?OonP3lood00?ol0?Woo03j
ooX0o?oj0?OonP3koo/0nOoj0?conP3hoo`00?om0?gonP3konl0k?ol0?SonP3g
ood0nool0?[om`3mo`00o?oj0?conP21omKo0A21oh7ol_ol0?Son`3ioo/0n?oi
0?Woo03joo`0n?ok0?Won`3hoo/0n_ok0?Woo03hooT0nOol0?Koo03Too`0n?oj
0?Ooo@3koo`0n_oi0?Gon`3ioo`0POn1oh7oaool0?Son`3ioo/0n?oi0?Woo03j
oo`0n?ok0?Won`3hoo/0n_ok0?Woo03hooT0nOol0?Koo03Too`0n?oj0?Ooo@3k
oo`0n_oi0?Gon`3ioo`0POn1oh7oaool0?Son`3ioo/0n?oi0?Woo03joo`0n?ok
0?Won`3hoo/0n_ok0?Woo03hooT0nOol0?Koo03Too`0n?oj0?Ooo@3koo`0n_oi
0?Gon`3ioo`0POoFo`4@POn1oo?oo03foo`0nOol0?KonP3ioo`0nool0?Koo03i
oo`0m_ol0?_on`3hoo/0nOoj0?Son`3goo`0hool0?Won@3iood0n_ol0?[onP3e
oo/0n?ok087oPOn1olWoo03foo`0nOol0?KonP3ioo`0nool0?Koo03ioo`0m_ol
0?_on`3hoo/0nOoj0?Son`3goo`0hool0?Won@3iood0n_ol0?[onP3eoo/0n?ok
087oPOn1olWoo03foo`0nOol0?KonP3ioo`0nool0?Koo03ioo`0m_ol0?_on`3h
oo/0nOoj0?Son`3goo`0hool0?Won@3iood0n_ol0?[onP3eoo/0n?ok087oeol1
787oPOocoo`0m_ol0?[on`3fooX0nOol0?_oo03foo`0n_ok0?Koo03koo`0m_ol
0?WonP3goo`0mool0>?oo03jood00?om0?Woo@3joo`0n_ok0?Coo03foo`0POn1
oh7obOol0?Koo03joo/0m_oj0?Woo03koo`0m_ol0?[on`3foo`0nool0?Koo03i
ooX0mool0?Ooo03Soo`0n_om003oo@3iood0n_ol0?[on`3doo`0m_ol087oPOn1
olWoo03foo`0n_ok0?KonP3ioo`0nool0?Koo03joo/0m_ol0?_oo03foo`0nOoj
0?Ooo03goo`0hool0?[oo@00ood0nOom0?[oo03joo/0m?ol0?Koo021omOo0?R1
oh7ohool0?[oo03doo/0nOol0>_oo03joo`0jool0?Goo03ioo/0m_ol0?Ooo03S
oo`0n_om003oo@3iood0n_ol0?[on`3eoo`0mOol087oPOn1okWoo03joo`0m?ok
0?Woo03[oo`0n_ol0>_oo03eoo`0nOok0?Koo03goo`0hool0?[oo@00ood0nOom
0?[oo03joo/0mOol0?Goo021oh7oPOnioo`0n_ol0?Con`3ioo`0jool0?[oo03[
oo`0mOol0?Won`3foo`0mool0>?oo03jood00?om0?Woo@3joo`0n_ok0?Goo03e
oo`0POoGo`3hPOn1on?oo03joo`0m?ok0?Woo03[oo`0n_ol0>_oo03doo`0n_ok
0?Koo03goo`0hool0?[oo@00ood0n_ol0?[oo03joo/0mOol0?Coo021oh7oPOnj
oo`0n_ol0?Con`3ioo`0jool0?[oo03[oo`0m?ol0?[on`3foo`0mool0>?oo03j
ood00?om0?[oo03joo`0n_ok0?Goo03doo`0POn1oh7o^_ol0?[oo03doo/0nOol
0>_oo03joo`0jool0?Coo03joo/0m_ol0?Ooo03Soo`0n_om003oo@3joo`0n_ol
0?[on`3eoo`0m?ol087of?l10X7oo021onSoo03koo`0l_ol0?Woo03[oo`0nool
0>[oo03doo`0n_ol0?Goo03goo`0h_ol0?_oo@00oo`0noom0?Woo03joo`0m?ol
0?Coo021oh7of?ol087oj?ol0?_oo03boo`0nOol0>_oo03koo`0j_ol0?Coo03j
oo`0mOol0?Ooo03Roo`0noom003oo03kood0nOol0?[oo03doo`0m?ol087oPOoH
oo`0POoXoo`0nool0?;oo03ioo`0jool0?_oo03Zoo`0m?ol0?[oo03eoo`0mool
0>;oo03kood00?ol0?_oo@3ioo`0n_ol0?Coo03doo`0POoHo`42POol087oj?ol
0?_oo03boo`0nOol0>_oo03koo`0jool0??oo03joo`0mOol0?Ooo03Roo`0o?om
0?koo@3kood0nOol0?[oo03eoo`0lool087oPOoHoo`0POoXoo`0nool0?;oo03i
oo`0jool0?_oo03[oo`0lool0?[oo03eoo`0mool0>;oo03lood0o_om0?_oo@3i
oo`0n_ol0?Goo03coo`0POn1omSoo021onSoo03koo`0l_ol0?Woo03[oo`0nool
0>_oo03coo`0n_ol0?Goo03goo`0h_ol0?coo@3nood0noom0?Woo03joo`0mOol
0??oo021omSo0>Z1oo`0POoZooX0nool0?;oo03ioo`0kOoj0?_oo03[onT0n_ol
0?Goo03goo`0h_ol0?coo@3nood0noom0?Woo03joo`0mOoY087oPOoHoo`0POoZ
ooX0nool0?;oo03ioo`0kOoj0?_oo03[onT0n_ol0?Goo03goo`0h_ol0?coo@3n
ood0noom0?Woo03joo`0mOoY087oPOoHoo`0POoZooX0nool0?;oo03ioo`0kOoj
0?_oo03[onT0n_ol0?Goo03goo`0h_ol0?coo@3nood0noom0?Woo03joo`0mOoY
087of?l0jX7oo021onkomP3koo`0l_ol0?Woo03aooH0nool0>_oj@3joo`0mOol
0?Ooo03Qood0o?om0?koo@3lood0n?ol0?[oo03eonT0POn1omSoo021onkomP3k
oo`0l_ol0?Woo03aooH0nool0>_oj@3joo`0mOol0?Ooo03Qood0o?om0?koo@3l
ood0n?ol0?[oo03eonT0POn1omSoo021onkomP3koo`0l_ol0?Woo03aooH0nool
0>_oj@3joo`0mOol0?Ooo03Qood0o?om0?koo@3lood0n?ol0?[oo03eonT0POoH
o`3PPOn1oncol`3koo`0l_ol0?Woo03doo<0nool0>_oj@3joo`0mOol0?Ooo03Q
oo`0oOom0?koo03mood0n?ol0?[oo03eonT0POn1oh7o`ooc0?_oo03boo`0nOol
0?Col`3koo`0jooY0?[oo03eoo`0mool0>7oo03mood0o_ol0?goo@3hoo`0n_ol
0?Goj@21oh7oPOo3oo<0nool0?;oo03ioo`0m?oc0?_oo03[onT0n_ol0?Goo03g
oo`0hOol0?goo@3noo`0oOom0?Soo03joo`0mOoY087of?l0h87oPOo_oo00nool
0?;oo03ioo`0moo`0?_oo03[onT0n_ol0?Goo03goo`0hOol0?koo@3lood0oOom
0?Soo03joo`0mOoY087oPOn1olKol03koo`0l_ol0?Woo03goo00nool0>_oj@3j
oo`0mOol0?Ooo03Qoo`0o_om0?coo@3mood0n?ol0?[oo03eonT0POn1oh7oa_o`
0?_oo03boo`0nOol0?Ool03koo`0jooY0?[oo03eoo`0mool0>7oo03nood0o?om
0?goo@3hoo`0n_ol0?Goj@21omSo0?j1oh7ol?of007ooo`0nool0?;oo03ioo`0
n?of007ooo`0nool0>_oo03Woo`0mOol0?Ooo03Qoo`0o_om0?coo@3noo`0n?ol
0?[oo03eoo`0POn1oh7o]?of007ooo`0nool0?;oo03ioo`0n?of007ooo`0nool
0>_oo03Woo`0mOol0?Ooo03Qoo`0o_om0?coo@3noo`0n?ol0?[oo03eoo`0POn1
oh7o]?of007ooo`0nool0?;oo03ioo`0n?of007ooo`0nool0>_oo03Woo`0mOol
0?Ooo03Qoo`0o_om0?coo@3noo`0n?ol0?[oo03eoo`0POo5o`3nPOn1oo7on@3k
oo`0nool0?;oo03ioo`0nOoi0?_oo03koo`0jool0>Ooo03eoo`0mool0>3oo001
ooom0?coo001ooom0?Ooo03joo`0mOol087oPOn1okGon@3koo`0nool0?;oo03i
oo`0nOoi0?_oo03koo`0jool0>Ooo03eoo`0mool0>3oo001ooom0?coo001ooom
0?Ooo03joo`0mOol087oPOn1okGon@3koo`0nool0?;oo03ioo`0nOoi0?_oo03k
oo`0jool0>Ooo03eoo`0mool0>3oo001ooom0?coo001ooom0?Ooo03joo`0mOol
087oaOl0oX7oPOobooX0nOol0?_oo03boo`0nOol0?[onP3ioo`0nool0>_oo03W
oo`0mOol0?Ooo03Poo`00Oooo@3loo`00Oooo@3goo`0n_ol0?Goo021oh7oPOnf
ooX0nOol0?_oo03boo`0nOol0?[onP3ioo`0nool0>_oo03Woo`0mOol0?Ooo03P
oo`00Oooo@3loo`00Oooo@3goo`0n_ol0?Goo021oh7oPOnfooX0nOol0?_oo03b
oo`0nOol0?[onP3ioo`0nool0>_oo03Woo`0mOol0?Ooo03Poo`00Oooo@3loo`0
0Oooo@3goo`0n_ol0?Goo021olGo0?j1oh7ol_ol0?Ooo03koo`0look0?Woo03j
oo`0mool0?_oo03[oo`0iool0?Goo03goo`0h?ol007oooh0n_om007oood0mool
0?[oo03eoo`0POn1oh7o]_ol0?Ooo03koo`0look0?Woo03joo`0mool0?_oo03[
oo`0iool0?Goo03goo`0h?ol007oooh0n_om007oood0mool0?[oo03eoo`0POn1
oh7o]_ol0?Ooo03koo`0look0?Woo03joo`0mool0?_oo03[oo`0iool0?Goo03g
oo`0h?ol007oooh0n_om007oood0mool0?[oo03eoo`0POo5o`3kPOn1oo?on`3g
oo`0n_ol0?Con`3ioo`0nook0?Ooo03joo`0jool0>Soo03eoo`0mool0=ooo@00
ood0n_om007oooh0m_ol0?[oo03doo`0POn1oh7o^?ok0?Ooo03joo`0m?ok0?Wo
o03koo/0mool0?[oo03[oo`0j?ol0?Goo03goo`0goom003oo@3jood00OoooP3f
oo`0n_ol0?Coo021oh7oPOnhoo/0mool0?[oo03doo/0nOol0?_on`3goo`0n_ol
0>_oo03Xoo`0mOol0?Ooo03Oood00?om0?[oo@01ooon0?Koo03joo`0m?ol087o
a_l0k87oPOocoo`0mook0?[oo03doo/0nOol0?_oo03goo/0n_ol0>_oo03Xoo`0
mOol0?Ooo03Oood00?om0?[on03foo`0n_ol0?Coo021oh7oPOnhoo`0mook0?[o
o03doo/0nOol0?_oo03goo/0n_ol0>_oo03Xoo`0mOol0?Ooo03Oood00?om0?[o
n03foo`0n_ol0?Coo021oh7oPOnhoo`0mook0?[oo03doo/0nOol0?_oo03goo/0
n_ol0>_oo03Xoo`0mOol0?Ooo03Oood00?om0?[on03foo`0n_ol0?Coo021olKo
0@B1oh7olool0?Oon`3joo`0mOoj0?Woo03koo`0mook0?[on`3foo`0o?ok0?Go
o03joo`0mOol0?Ooo03OooP0n_oh0?Koo03joo`0m?ok0?Goo021oh7oPOo:oo`0
mook0?[oo03eooX0nOol0?_oo03goo/0n_ok0?Koo03loo/0mOol0?[oo03eoo`0
mool0=oon03jooP0m_ol0?[oo03doo/0mOol087oPOn1ol[oo03goo/0n_ol0?Go
nP3ioo`0nool0?Oon`3joo/0m_ol0?con`3eoo`0n_ol0?Goo03goo`0gooh0?[o
n03foo`0n_ol0?Con`3eoo`0POoHo`44POn1oo?oo03hooX0nOol0?KonP3ioo`0
nool0?SonP3ioo`0m_ol0?_on`3foo`0n_ol0?Goo03goo/0h?oi0?Son@3foo`0
n_ol0??on`3foo`0POn1oh7ob_ol0?SonP3ioo`0m_oj0?Woo03koo`0n?oj0?Wo
o03foo`0nook0?Koo03joo`0mOol0?Oon`3PooT0n?oi0?Koo03joo`0look0?Ko
o021oh7oPOo:oo`0n?oj0?Woo03fooX0nOol0?_oo03hooX0nOol0?Koo03koo/0
m_ol0?[oo03eoo`0mook0>3on@3hooT0m_ol0?[oo03coo/0m_ol087of?l1187o
POocoo/0n_oi0?Won`3hooT0nOol0?_on`3jooT0nOok0?Soo03jooX0n?ol0?Wo
o03eoo`0m_ol0=oonP3hooX0mOol0?[oo03cooX0n?ol087oPOn1olWon`3jooT0
nOok0?Son@3ioo`0nook0?[on@3ioo/0n?ol0?[onP3hoo`0nOol0?Goo03foo`0
gooj0?SonP3eoo`0n_ol0??onP3hoo`0POn1oh7obOok0?[on@3ioo/0n?oi0?Wo
o03koo/0n_oi0?Won`3hoo`0n_oj0?Soo03ioo`0mOol0?Koo03OooX0n?oj0?Go
o03joo`0looj0?Soo021omOo0Ab1oh7ol_ok0?gom`3hooX0o?om003oo03ioo`0
n_ok0?gom`3hooX0nook0?Won@3koo/0nOol0?Goo03fooX0o?l00>OonP3hooX0
mOol0?[oo03booT0nook087oPOn1olSon`3mooL0n?oj0?coo@00oo`0nOol0?[o
n`3mooL0n?oj0?_on`3iooT0nook0?Woo03eoo`0m_oj0?co003WooX0n?oj0?Go
o03joo`0l_oi0?_on`21oh7oPOo8oo/0oOog0?SonP3lood00?ol0?Woo03joo/0
oOog0?SonP3koo/0nOoi0?_on`3ioo`0mOol0?KonP3lo`00iooj0?SonP3eoo`0
n_ol0?;on@3koo/0POoGo`3PPOn1oo;ol`00oo`0moob003oo03ioo`0n_oc003o
o03goo00moo_0?Soo03eoo`0m_od0>OonP3goo/0mOol0?[oo03aonl0POn1oh7o
aooc003oo03goo800?ol0?Woo03joo<00?ol0?Ool03gonl0n?ol0?Goo03foo@0
iooj0?Oon`3eoo`0n_ol0?7ok`21oh7oPOo7oo<00?ol0?OolP00oo`0nOol0?[o
l`00oo`0moo`0?Ook`3hoo`0mOol0?Kom03WooX0mook0?Goo03joo`0lOo_087o
e_l0jH7oPOoaooD00Ooon`3goo@00Oooo03ioo`0nOoe007ooo/0moob0?Gol@3g
oo`0mOol0?Gom@3Voo`0m_ol0?Coo03joo`0l?oa087oPOn1olGom@01oook0?Oo
m001oool0?Woo03iooD00Ooon`3goo80mOoa0?Ooo03eoo`0mOoe0>Koo03foo`0
m?ol0?[oo03`oo40POn1oh7oaOoe007ooo/0mood007ooo`0nOol0?Wom@01oook
0?OolP3eoo40mool0?Goo03eooD0i_ol0?Koo03doo`0n_ol0?3ol@21omGo0>21
oh7ol?oh0?coo03fooH0o_ol0?Woo03hooP0o?ol0?Kom03boo@0m_ol0?Goo03d
ooH0i_ol0?Koo03doo`0n_ol0>kom021oh7oPOo3ooP0o?ol0?KomP3noo`0nOol
0?Son03loo`0m_od0?;om03foo`0mOol0?ComP3Voo`0m_ol0?Coo03joo`0k_od
087oPOn1ol?on03loo`0m_of0?koo03ioo`0n?oh0?coo03foo@0l_od0?Koo03e
oo`0m?of0>Koo03foo`0m?ol0?[oo03^oo@0POoDo`1dPOn1onkoo03XooX0kool
0?Koo03WooT0k_oi0<gon`2LooT0POn1oh7o__ol0>SonP3_oo`0m_ol0>Oon@3^
ooT0cOok09con@21oh7oPOnnoo`0j?oj0>ooo03foo`0iooi0>kon@3=oo/0W?oi
087odOl0;87oPOngoo`0POn1oh7oPOn1oi?oo021oh7oPOn1oh7oTool087oPOn1
omgo03J1oo`0POnloo`0POn1oh7oPOoMoo`0POnloo`0POn1oh7oPOoMoo`0POnl
oo`0POn1oh7ogOl0=X7oo021okcoo021oh7oPOn1omgoo021okcoo021oh7oPOn1
omgoo021okcoo021oh7oPOoMo`0fPOol087o_Ook087oPOn1oh7ogOol087o_Ook
087oPOn1oh7ogOol087o_Ook087oPOn1omgo03J1oo`0POnmoo`0POn1oh7oPOoL
oo`0POnmoo`0POn1oh7oPOoLoo`0POnmoo`0POn1oh7og?l0;87oPOnjooX0POn1
oh7oPOn1oiGonP21oh7oPOn1oh7oUOoj087oPOn1omco02b1oh7o_Ooh087oPOn1
oh7oPOnGooP0POn1oh7oPOn1oiOon021oh7oPOoKo`0/POn1okgon@21oh7oPOn1
oh7oU_oi087oPOn1oh7oPOnFooT0POn1oh7of_l0;87oPOnmooX0POn1oh7oPOn1
oiGonP21oh7oPOn1oh7oUOoj087oPOn1omWo02b1oh7o_Ool087oPOn1oh7oPOnC
oo`0POn1oh7oPOn1oi?oo021oh7oPOoGo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnX
o`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7oPOn1oi?oo021oh7oPOn1oi?o02Z1
oo`0POn1oh7oPOn1oi?oo021oh7oPOn1oh7oTool087oPOn1oh7oTol0:X7oo021
oh7oPOn1oh7oTool087oPOn1oh7oPOnCoo`0POn1oh7oPOnCo`0ZPOol087oPOn1
oh7oPOnCoo`0POn1oh7oPOn1oi?oo021oh7oPOn1oi?o02B1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnX
o`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0
987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOnXo`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7oPOn1oi?oo021oh7oPOn1
oi?o02Z1oo`0POn1oh7oPOn1oi?oo021oh7oPOn1oh7oTool087oPOn1oh7oTol0
:X7oo021oh7oPOn1oh7oTool087oPOn1oh7oPOnCoo`0POn1oh7oPOnCo`0ZPOol
087oPOn1oh7oPOnCoo`0POn1oh7oPOn1oi?oo021oh7oPOn1oi?o02B1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0
987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOnXo`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7oPOn1oi?oo021
oh7oPOn1oi?o02Z1oo`0POn1oh7oPOn1oi?oo021oh7oPOn1oh7oTool087oPOn1
oh7oTol0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7oPOnCoo`0POn1oh7oPOnC
o`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7oPOn1oi?oo021oh7oPOn1oi?o02B1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnX
o`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0:X7oo021oh7oPOn1oh7oTool
087oPOn1oh7oPOnCoo`0POn1oh7oPOnCo`0ZPOol087oPOn1oh7oPOnCoo`0POn1
oh7oPOn1oi?oo021oh7oPOn1oi?o02Z1oo`0POn1oh7oPOn1oi?oo021oh7oPOn1
oh7oTool087oPOn1oh7oTol0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7oPOnC
oo`0POn1oh7oPOnCo`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7oPOn1oi?oo021
oh7oPOn1oi?o02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0
987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0ZP@2L
087oPOn1oh7olon109`0POn1oh7oPOocoh40W021oh7oPOn1oo?o02Z109`0POn1
oh7oPOocoh40W021oh7oPOn1oo?oP@2L087oPOn1oh7olol0:X40W021oh7oPOn1
oo?oP@2L087oPOn1oh7olon109`0POn1oh7oPOoco`0ZP@2L087oPOn1oh7olon1
09`0POn1oh7oPOocoh40W021oh7oPOn1oo?o02B1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oZ?l0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7oPOnC
oo`0POn1oh7oPOnCo`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7oPOn1oi?oo021
oh7oPOn1oi?o02Z1oo`0POn1oh7oPOn1oi?oo021oh7oPOn1oh7oTool087oPOn1
oh7oTol0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7oPOnCoo`0POn1oh7oPOnC
o`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0
987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0:X7oo021oh7oPOn1oh7oTool087oPOn1
oh7oPOnCoo`0POn1oh7oPOnCo`0ZPOol087oPOn1oh7oPOnCoo`0POn1oh7oPOn1
oi?oo021oh7oPOn1oi?o02Z1oo`0POn1oh7oPOn1oi?oo021oh7oPOn1oh7oTool
087oPOn1oh7oTol0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7oPOnCoo`0POn1
oh7oPOnCo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnX
o`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0:X7oo021oh7oPOn1oh7oTool
087oPOn1oh7oPOnCoo`0POn1oh7oPOnCo`0ZPOol087oPOn1oh7oPOnCoo`0POn1
oh7oPOn1oi?oo021oh7oPOn1oi?o02Z1oo`0POn1oh7oPOn1oi?oo021oh7oPOn1
oh7oTool087oPOn1oh7oTol0:X7oo021oh7oPOn1oh7oTool087oPOn1oh7oPOnC
oo`0POn1oh7oPOnCo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnX
o`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0
987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0:X7oo021oh7oPOn1
oh7oTool087oPOn1oh7oPOnCoo`0POn1oh7oPOnCo`0ZPOol087oPOn1oh7oPOnC
oo`0POn1oh7oPOn1oi?oo021oh7oPOn1oi?o02Z1oo`0POn1oh7oPOn1oi?oo021
oh7oPOn1oh7oTool087oPOn1oh7oTol0:X7oo021oh7oPOn1oh7oTool087oPOn1
oh7oPOnCoo`0POn1oh7oPOnCo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0
987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOnXo`0Z0021oh7oPOn1oh7oSol0087oPOn1oh7oPOn?o`00POn1
oh7oPOn1ohoo02d10021oh7oPOn1oh7oT?l10021oh7oPOn1oh7oT?l10021oh7o
POn1oh7oT?l0<?h0Q?ol087oPOn1oh7oToon08Coo021oh7oPOn1oi?ooP24oo`0
POn1oh7oPOnCo`0`o@25oo`0POn1oh7oPOnCood0QOol087oPOn1oh7oToom08Go
o021oh7oPOn1oi?o033l08Koo021oh7oPOn1oi?oo026oo`0POn1oh7oPOnCoo`0
Q_ol087oPOn1oh7oTol0<?/0Qool087oPOn1oh7oTook08Ooo021oh7oPOn1oi?o
n`27oo`0POn1oh7oPOnCo`0/0?ok087oPOn1oh7oPOnDoo/0POn1oh7oPOn1oiCo
n`21oh7oPOn1oh7oUOl0;@7ooo/0POn1oh7oPOn1oiCon`21oh7oPOn1oh7oU?ok
087oPOn1oh7oPOnFo`0/o_ok087oPOn1oh7oPOnDoo/0POn1oh7oPOn1oiCon`21
oh7oPOn1oh7oUol0;?gon`21oh7oPOn1oh7oU?ok087oPOn1oh7oPOnDoo/0POn1
oh7oPOn1oiSo02cloo/0POn1oh7oPOn1oiCon`21oh7oPOn1oh7oU?ok087oPOn1
oh7oPOnIo`0/nook087oPOn1oh7oPOnDoo/0POn1oh7oPOn1oiCon`21oh7oPOn1
oh7oV_l0=P00nook087oPOn1oh7oPOnKo`00nook087oPOn1oh7oPOnKo`00nook
087oPOn1oh7oPOnKo`0i0@00nook087oPOn1oh7oPOnLo`400?_on`21oh7oPOn1
oh7oW?l1003koo/0POn1oh7oPOn1oico03Kn0?_on`21oh7oPOn1oh7oWOon0?_o
n`21oh7oPOn1oh7oWOon0?_on`21oh7oPOn1oh7oWOl0=_d0nook087oPOn1oh7o
POnNood0nook087oPOn1oh7oPOnNood0nook087oPOn1oh7oPOnNo`0fo03koo/0
POn1oh7oPOn1oiooo03koo/0POn1oh7oPOn1oiooo03koo/0POn1oh7oPOn1oioo
03Kk0?_on`21oh7oPOn1oh7oX?ok0?_on`21oh7oPOn1oh7oX?ok0?_on`21oh7o
POn1oh7oX?l0>03on`3koo/0POn1oh7oPOn1oj3on`3koo/0POn1oh7oPOn1oj3o
n`3koo/0POn1oh7oPOn1oj7o03T1oook0?_on`21oh7oPOn1oh7oX?ok0?_on`21
oh7oPOn1oh7oX?ok0?_on`21oh7oPOn1oh7oX_l0>?kon`3koo/0POn1oh7oPOn1
oj3on`3koo/0POn1oh7oPOn1oj3on`3koo/0POn1oh7oPOn1oj?o03Smoo/0nook
087oPOn1oh7oPOnPoo/0nook087oPOn1oh7oPOnPoo/0nook087oPOn1oh7oPOnT
o`0no?ok0?_on`2Hoo`0POn1oh7oPOn>oo/0nook09Soo021oh7oPOn1ohkon`3k
oo/0V?ol087oPOn1oh7oTol0?__on`3koo/0VOol087oPOn1oh7oSOok0?_on`2I
oo`0POn1oh7oPOn=oo/0nook09Woo021oh7oPOn1oi?o04P00?_on`3koo/0V_ol
087oPOn1oh7oTol00?_on`3koo/0V_ol087oPOn1oh7oTol00?_on`3koo/0V_ol
087oPOn1oh7oTol0B`400?_on`3koo/0Vool087oPOn1oh7oTol1003koo/0nook
09_oo021oh7oPOn1oi?o0@00nook0?_on`2Koo`0POn1oh7oPOnCo`18oP3koo/0
nook09coo021oh7oPOn1oi?ooP3koo/0nook09coo021oh7oPOn1oi?ooP3koo/0
nook09coo021oh7oPOn1oi?o04;m0?_on`3koo/0POn1oh7oPOn1oj[oo@3koo/0
nook087oPOn1oh7oPOnZood0nook0?_on`21oh7oPOn1oh7oZ_l0@_`0nook0?_o
n`21oh7oPOn1oh7oZool0?_on`3koo/0POn1oh7oPOn1oj_oo03koo/0nook087o
POn1oh7oPOn[o`12n`3koo/0nook087oPOn1oh7oPOn/oo/0nook0?_on`21oh7o
POn1oh7o[?ok0?_on`3koo/0POn1oh7oPOn1ojco04@0oo/0nook0?_on`21oh7o
POn1oh7o[?ok0?_on`3koo/0POn1oh7oPOn1ojcon`3koo/0nook087oPOn1oh7o
POn]o`150Ooon`3koo/0nook087oPOn1oh7oPOn/oo/0nook0?_on`21oh7oPOn1
oh7o[?ok0?_on`3koo/0POn1oh7oPOn1ojko04Cnoo/0nook0?_on`21oh7oPOn1
oh7o[?ok0?_on`3koo/0POn1oh7oPOn1ojcon`3koo/0nook087oPOn1oh7oPOn_
o`14oOok0?_on`3koo/0POn1oh7oPOn1ojcon`3koo/0nook087oPOn1oh7oPOn/
oo/0nook0?_on`21oh7oPOn1oh7o/?l0A?con`3koo/0nook087oPOn1oh7oPOn/
oo/0nook0?_on`21oh7oPOn1oh7o[?ok0?_on`3koo/0POn1oh7oPOn1ok7o04Ck
oo/0nook0?_on`21oh7oPOn1oh7o[?ok0?_on`3koo/0POn1oh7oPOn1ojcon`3k
oo/0nook087oPOn1oh7oPOnbo`14n_ok0?_on`3koo/0POn1oh7oPOn1ojcon`3k
oo/0nook087oPOn1oh7oPOn/oo/0nook0?_on`21oh7oPOn1oh7o/ol0A?Won`3k
oo/0nook087oPOn1oh7oPOn/oo/0nook0?_on`21oh7oPOn1oh7o[?ok0?_on`3k
oo/0POn1oh7oPOn1okCo04Choo/0nook0?_on`21oh7oPOn1oh7o[?ok0?_on`3k
oo/0POn1oh7oPOn1ojcon`3koo/0nook087oPOn1oh7oPOneo`14mook0?_on`3k
oo/0POn1oh7oPOn1ojcon`3koo/0nook087oPOn1oh7oPOn/oo/0nook0?_on`21
oh7oPOn1oh7o]_l0A?Kon`3koo/0nook087oPOn1oh7oPOn/oo/0nook0?_on`21
oh7oPOn1oh7o[?ok0?_on`3koo/0POn1oh7oPOn1okOo04Ceoo/0nook0?_on`21
oh7oPOn1oh7o[?ok0?_on`3koo/0POn1oh7oPOn1ojcon`3koo/0nook087oPOn1
oh7oPOnho`14m?ok0?_on`3koo/0POn1oh7oPOn1ojcon`3koo/0nook087oPOn1
oh7oPOn/oo/0nook0?_on`21oh7oPOn1oh7o^Ol0B_?on`3koo/0nook0:goo021
oh7oPOn1ohGon`3koo/0nook0:goo021oh7oPOn1ohGon`3koo/0nook0:goo021
oh7oPOn1oi?o04[boo/0nook0?_on`2^oo`0POn1oh7oPOn4oo/0nook0?_on`2^
oo`0POn1oh7oPOn4oo/0nook0?_on`2^oo`0POn1oh7oPOnCo`1:lOok0?_on`3k
oo/0[ool087oPOn1oh7oPook0?_on`3koo/0[ool087oPOn1oh7oPook0?_on`3k
oo/0[ool087oPOn1oh7oTol0B_3on`3koo/0nook0;3oo021oh7oPOn1oh;on`3k
oo/0nook0;3oo021oh7oPOn1oh;on`3koo/0nook0;3oo021oh7oPOn1oi?o04C_
oo/0nook0?_on`21oh7oPOn1oh7o[?ok0?_on`3koo/0POn1oh7oPOn1ojcon`3k
oo/0nook087oPOn1oh7oPOnno`14k_ok0?_on`3koo/0POn1oh7oPOn1ojcon`3k
oo/0nook087oPOn1oh7oPOn/oo/0nook0?_on`21oh7oPOn1oh7o_ol0A>gon`3k
oo/0nook087oPOn1oh7oPOn/oo/0nook0?_on`21oh7oPOn1oh7o[?ok0?_on`3k
oo/0POn1oh7oPOn1ol3o04C/oo/0nook0?_on`21oh7oPOn1oh7o[?ok0?_on`3k
oo/0POn1oh7oPOn1ojcon`3koo/0nook087oPOn1oh7oPOo1o`14jook0?_on`3k
oo/0POn1oh7oPOn1ojcon`3koo/0nook087oPOn1oh7oPOn/oo/0nook0?_on`21
oh7oPOn1oh7o`_l0DN[on`3koo/0nook0;Ko0@00POn1oh7oPOn1ooWon`3koo/0
nook0;Ko0@00POn1oh7oPOn1ooWon`3koo/0nook0;Ko0@00POn1oh7oPOn@o`1>
jOok0?_on`3koo/0^_oj087oPOn1oh7oPOojoo/0nook0?_on`2jooX0POn1oh7o
POn1oo[on`3koo/0nook0;[onP21oh7oPOn1oi;o04kXoo/0nook0?_on`2nooD0
POn1oh7oPOn1oo_on`3koo/0nook0;kom@21oh7oPOn1oh7onook0?_on`3koo/0
__oe087oPOn1oh7oU?l0C^Oon`3koo/0nook0<3ol@21oh7oPOn1oh7ooOok0?_o
n`3koo/0`?oa087oPOn1oh7oPOomoo/0nook0?_on`30oo40POn1oh7oPOnGo`1>
i_ok0?_on`3koo/0`_o_087oPOn1oh7oPOomoo/0nook0?_on`32onl0POn1oh7o
POn1oogon`3koo/0nook0<;ok`21oh7oPOn1oiSo05[Uoo/0nook0?_on`34ooT0
oOoi087oPOn1oh7oPOomoo/0nook0?_on`34ooT0oOoi087oPOn1oh7oPOomoo/0
nook0?_on`34ooT0oOoi087oPOn1oh7oVOl0F^Con`3koo/0nook0<Kon`3goo`0
POn1oh7oPOn1oocon`3koo/0nook0<Kon`3goo`0POn1oh7oPOn1oocon`3koo/0
nook0<Kon`3goo`0POn1oh7oPOnIo`1P003Too/0nook0?_on`37oo`0mOol087o
POn1oh7oV_l00>Con`3koo/0nook0<Ooo03eoo`0POn1oh7oPOnJo`00i?ok0?_o
n`3koo/0aool0?Goo021oh7oPOn1oi[o06000>?on`3koo/0nook0<Woo03coo`0
POn1oh7oPOnKo`00hook0?_on`3koo/0bOol0??oo021oh7oPOn1oi_o003Soo/0
nook0?_on`39oo`0lool087oPOn1oh7oVol0H`400>?on`3koo/0nook0<_oo03a
oo`0POn1oh7oPOnLo`400>?on`3koo/0nook0<_oo03aoo`0POn1oh7oPOnLo`40
0>?on`3koo/0nook0<_oo03aoo`0POn1oh7oPOnLo`1S0@00h_ok0?_on`3koo/0
cOok0?3oo@21oh7oPOn1oico0@00h_ok0?_on`3koo/0cOok0?3oo@21oh7oPOn1
oico0@00h_ok0?_on`3koo/0cOok0?3oo@21oh7oPOn1oico063n0>;on`3koo/0
nook0<oon`3_oo`0POn1oh7oPOnMooh0h_ok0?_on`3koo/0cook0>ooo021oh7o
POn1oigooP3Roo/0nook0?_on`3?oo/0kool087oPOn1oh7oWOl0K?h0hOok0?_o
n`3koo/0d?ol0?Soo03koo`0POn1oh7oPOnNooh0hOok0?_on`3koo/0d?ol0?So
o03koo`0POn1oh7oPOnNooh0hOok0?_on`3koo/0d?ol0?Soo03koo`0POn1oh7o
POnNo`1/o@3Qoo/0nook0?_on`3Boo`0mool0?_oo021oh7oPOn1oikoo@3Qoo/0
nook0?_on`3Boo`0mool0?_oo021oh7oPOn1oikoo@3Qoo/0nook0?_on`3Boo`0
mool0?_oo021oh7oPOn1oiko06cm0>3on`3koo/0nook0=?oo03goo`0n_ol087o
POn1oh7oWoom0>3on`3koo/0nook0=?oo03goo`0n_ol087oPOn1oh7oWoom0>3o
n`3koo/0nook0=?oo03goo`0n_ol087oPOn1oh7oWol0K?d0gook0?_on`3koo/0
eOol0?Koo03joo`0POn1oh7oPOnOood0gook0?_on`3koo/0eOol0?Koo03joo`0
POn1oh7oPOnOood0gook0?_on`3koo/0eOol0?Koo03joo`0POn1oh7oPOnOo`1P
o03Ooo/0nook0?_on`3Foo`0jOol087oPOn1oh7oX?ol0=oon`3koo/0nook0=Ko
o03Yoo`0POn1oh7oPOnPoo`0gook0?_on`3koo/0e_ol0>Woo021oh7oPOn1oj3o
063l0=kon`3koo/0nook0=Soo03Xoo`0POn1oh7oPOnPoo`0g_ok0?_on`3koo/0
f?ol0>Soo021oh7oPOn1oj3oo03Noo/0nook0?_on`3Hoo`0j?ol087oPOn1oh7o
X?l0VP000?n?X00000010`?X000010000000B00004P0000@02000`0800000000
0002KGK/000000430nP3j@001>/3j`0006KbooD0eOoe087o[?ok087oPOn1omKo
n`3NonT0POnnooH0l_oe0=Gom@21ojcon`21oh7oPOoFoo/0g_oY087o__of0?;o
m@3EooD0POn/oo/0POn1oh7oe_ok0=koj@21okkomP00I_;om@3DooH0POn]oo/0
POn1oh7oe_ok0=koj`21ok[om`3booD0e?of087o[Ook087oPOn1omKon`3Non/0
POnjooL0l_oe0=ComP21ojgon`21oh7oPOoFoo/0g_o[087o^_og001Vl_of0=3o
n`21ojcon`21oh7oPOoFoo/0gOo]087o]_oi0?;omP3@oo/0POn/oo/0POn1oh7o
e_ok0=gok@21okKon@3booH0d?ok087o[?ok087oPOn1omKon`3Mond0POnfooT0
063booH0POn1ooKon`21oh7oPOoFoo/0gOo^087o/Ool0?;omP21oh7om_ok087o
POn1omKon`3Monh0POnaoo`0l_of087oPOofoo/0POn1oh7oe_ok0=gokP21ok7o
o000H?7om`21oh7omook087oPOn1omKon`3Loo00POn]ooh0lOog087oPOogoo/0
POn1oh7oe_ok0=col021ojgooP3aooL0POn1ooOon`21oh7oPOoFoo/0g?o`087o
[Oon001PlOoh087oPOogoo/0POn1oh7oe_ok0=_olP21ojWo003aooP0POn1ooOo
n`21oh7oPOoFoo/0foob087oZOl00?7on021oh7omook087oPOn1omKon`3Koo80
POnYo`0005KaooP0POn1ooSon`21oh7oPOoFoo/0fooc087oU_oh087oPOohoo/0
POn1oh7oe_ok0=_ol`21oiKon021oh7on?ok087oPOn1omKon`3Koo<0POnVo`1F
l?oi087oPOoioo/0POn1oh7oe_ok0=[om@21oi?on@21oh7onOok087oPOn1omKo
n`3JooD0POnCooT0POn1ooWon`21oh7oPOoFoo/0f_oe087oY?l0E_3onP21oh7o
nOok087oPOn1omKon`3JooD0POnBooX0POn1ooWon`21oh7oPOoFoo/0f_oe087o
T_oj087oPOoioo/0POn1oh7oe_ok0=[om@21oj?o05K_oo/0POn1oo[on`21oh7o
POoFoo/0fOog087oSook087oPOojoo/0POn1oh7oe_ok0=Wom`21ohoon`21oh7o
n_ok087oPOn1omKon`3IooL0POnQo`1Fkook087oPOokoo/0POn1oh7oe_ok0=Wo
n021ohgon`21oh7onook087oPOn1omKon`3IooP0POn=oo/0POn1oo_on`21oh7o
POoFoo/0fOoh087oWol0E^koo@21oh7onook087oPOn1omKon`3HooX0POn:ood0
POn1oo_on`21oh7oPOoFoo/0f?oj087oR_om087oPOokoo/0POn1oh7oe_ok0=So
nP21oigo05K^ood0POn1oocon`21oh7oPOoFoo/0f?ok087oR?om087oPOoloo/0
POn1oh7oe_ok0=Son`21ohSoo@21oh7oo?ok087oPOn1omKon`3Hoo/0POnKo`1F
k_om087oPOomoo/0POn1oh7oe_ok0=Ooo@21ohKoo@21oh7ooOok087oPOn1omKo
n`3Good0POn6ood0POn1oogon`21oh7oPOoFoo/0eoom087oVOl0FNgo0@00POn1
oo_oo@21oh7oPOoFoo/0eoon087oPol10021oh7onoom087oPOn1omKon`3Gooh0
POn3o`40087oPOokood0POn1oh7oe_ok0=OooP21oiOo05K]o`40087oPOojo`40
087oPOn1omKon`21oh7oeOl10021oh7on_l10021oh7oPOoFoo/0POn1omGo0@00
POn1oo[o0@00POn1oh7oe_ok087oPOoYo`17kOl10021oh7oPOn1oh7oc_ok087o
POoDo`40087oPOn1oh7oPOo>oo/0POn1omCo0@00POn1oh7oPOn1olkon`21oh7o
j?l0>87oPOn1oh7oPOnioo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7o
POnOoo/0POn1onOo03R1oh7oPOn1oh7o^_ok087oPOn1oh7oPOn1oh7oWook087o
POn1oh7oPOn1oh7oWook087oPOoVo`0hPOn1oh7oPOn1ok_on`21oh7oPOn1oh7o
POn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7oiOl0>87oPOn1oh7oPOnloo/0
POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1onCo03R1oh7o
POn1oh7o_Ook087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087o
POoSo`0hPOn1oh7oPOn1okkon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7o
POn1oioon`21oh7oh_l0>87oPOn1oh7oPOnooo/0POn1oh7oPOn1oh7oPOnOoo/0
POn1oh7oPOn1oh7oPOnOoo/0POn1on7o03R1oh7oPOn1oh7o`?ok087oPOn1oh7o
POn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOoPo`0hPOn1oh7oPOn1ol7o
n`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7ogol0>87o
POn1oh7oPOo2oo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0
POn1omko03R1oh7oPOn1oh7o`ook087oPOn1oh7oPOn1oh7oWook087oPOn1oh7o
POn1oh7oWook087oPOoMo`0hPOn1oh7oPOn1olCon`21oh7oPOn1oh7oPOn1oioo
n`21oh7oPOn1oh7oPOn1oioon`21oh7og?l0>87oPOn1oh7oPOo5oo/0POn1oh7o
POn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1om_o03R1oh7oPOn1oh7o
a_ok087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOoJo`0h
POn1oh7oPOn1olOon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioo
n`21oh7ofOl0>87oPOn1oh7oPOo8oo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7o
POn1oh7oPOnOoo/0POn1omSo03R1oh7oPOn1oh7obOok087oPOn1oh7oPOn1oh7o
Wook087oPOn1oh7oPOn1oh7oWook087oPOoGo`0hPOn1oh7oPOn1ol[on`21oh7o
POn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7oe_l0>87oPOn1oh7o
POo;oo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1omGo
03R1oh7oPOn1oh7oc?ok087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7o
Wook087oPOoDo`0hPOn1oh7oPOn1olgon`21oh7oPOn1oh7oPOn1oioon`21oh7o
POn1oh7oPOn1oioon`21oh7odol0>87oPOn1oh7oPOo>oo/0POn1oh7oPOn1oh7o
POnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1om;o03R1oh7oPOn1oh7ocook087o
POn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOoAo`0hPOn1oh7o
POn1om3on`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7o
d?l0>87oPOn1oh7oPOoAoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7o
POnOoo/0POn1oloo03R1oh7oPOn1oh7od_ok087oPOn1oh7oPOn1oh7oWook087o
POn1oh7oPOn1oh7oWook087oPOo>o`0hPOn1oh7oPOn1om?on`21oh7oPOn1oh7o
POn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7ocOl0>87oPOn1oh7oPOoDoo/0
POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1olco03R1oh7o
POn1oh7oeOok087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087o
POo;o`0hPOn1oh7oPOn1omKon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7o
POn1oioon`21oh7ob_l0>87oPOn1oh7oPOoGoo/0POn1oh7oPOn1oh7oPOnOoo/0
POn1oh7oPOn1oh7oPOnOoo/0POn1olWo03R1oh7oPOn1oh7of?ok087oPOn1oh7o
POn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOo8o`0hPOn1oh7oPOn1omWo
n`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7oaol0>87o
POn1oh7oPOoJoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0
POn1olKo03R1oh7oPOn1oh7ofook087oPOn1oh7oPOn1oh7oWook087oPOn1oh7o
POn1oh7oWook087oPOo5o`0hPOn1oh7oPOn1omcon`21oh7oPOn1oh7oPOn1oioo
n`21oh7oPOn1oh7oPOn1oioon`21oh7oa?l0>87oPOn1oh7oPOoMoo/0POn1oh7o
POn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1ol?o03R1oh7oPOn1oh7o
g_ok087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOo2o`0h
POn1oh7oPOn1omoon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioo
n`21oh7o`Ol0>87oPOn1oh7oPOoPoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7o
POn1oh7oPOnOoo/0POn1ol3o03R1oh7oPOn1oh7ohOok087oPOn1oh7oPOn1oh7o
Wook087oPOn1oh7oPOn1oh7oWook087oPOnoo`0hPOn1oh7oPOn1on;on`21oh7o
POn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7o__l0>87oPOn1oh7o
POoSoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1okgo
03R1oh7oPOn1oh7oi?ok087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7o
Wook087oPOnlo`0hPOn1oh7oPOn1onGon`21oh7oPOn1oh7oPOn1oioon`21oh7o
POn1oh7oPOn1oioon`21oh7o^ol0>87oPOn1oh7oPOoVoo/0POn1oh7oPOn1oh7o
POnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1ok[o03R1oh7oPOn1oh7oiook087o
POn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOnio`0hPOn1oh7o
POn1onSon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7o
^?l0=X7oPOoUoh40P@210840P@2e087oPOoUoh40P@210840P@2e087oPOoUoh40
P@210840P@2e000fPOn1onGoP@210840P@210;D0POn1onGoP@210840P@210;D0
POn1onGoP@210840P@210;D003J1oh7oiOn10840P@210840]@21oh7oiOn10840
P@210840]@21oh7oiOn10840P@210840]@00=X7oPOoUoh40P@210840P@2e087o
POoUoh40P@210840P@2e087oPOoUoh40P@210840P@2e000hPOn1oh7oPOn1ongo
n`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7o/ol0>87o
POn1oh7oPOo^oo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0
POn1ok;o03R1oh7oPOn1oh7okook087oPOn1oh7oPOn1oh7oWook087oPOn1oh7o
POn1oh7oWook087oPOnao`0hPOn1oh7oPOn1oo3on`21oh7oPOn1oh7oPOn1oioo
n`21oh7oPOn1oh7oPOn1oioon`21oh7o/?l0>87oPOn1oh7oPOoaoo/0POn1oh7o
POn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1ojoo03R1oh7oPOn1oh7o
l_ok087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOn^o`0h
POn1oh7oPOn1oo?on`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioo
n`21oh7o[Ol0>87oPOn1oh7oPOodoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7o
POn1oh7oPOnOoo/0POn1ojco03R1oh7oPOn1oh7omOok087oPOn1oh7oPOn1oh7o
Wook087oPOn1oh7oPOn1oh7oWook087oPOn[o`0hPOn1oh7oPOn1ooKon`21oh7o
POn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7oZ_l0>87oPOn1oh7o
POogoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1ojWo
03R1oh7oPOn1oh7on?ok087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7o
Wook087oPOnXo`0hPOn1oh7oPOn1ooWon`21oh7oPOn1oh7oPOn1oioon`21oh7o
POn1oh7oPOn1oioon`21oh7oYol0>87oPOn1oh7oPOojoo/0POn1oh7oPOn1oh7o
POnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1ojKo03R1oh7oPOn1oh7onook087o
POn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOnUo`0hPOn1oh7o
POn1oocon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7o
Y?l0>87oPOn1oh7oPOomoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7o
POnOoo/0POn1oj?o03R1oh7oPOn1oh7oo_ok087oPOn1oh7oPOn1oh7oWook087o
POn1oh7oPOn1oh7oWook087oPOnRo`0iPOn1oh7oPOn1o`7ooo/0POn1oh7oPOn1
oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oj7o03R1oh7oPOn1oh7o0?ok
087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOnPo`0fPOn1
oh7oPOn1oo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1
oioo03J1oh7oPOn1oh;on`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1
oioon`21oh7oW_l0=X7oPOn1oh7oPook087oPOn1oh7oPOn1oh7oWook087oPOn1
oh7oPOn1oh7oWook087oPOnMo`0fPOn1oh7oPOn4oo/0POn1oh7oPOn1oh7oPOnO
oo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oico03J1oh7oPOn1ohGon`21oh7oPOn1
oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7oVol0=X7oPOn1oh7oQ_ok
087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOnJo`0fPOn1
oh7oPOn7oo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1
oiWo03J1oh7oPOn1ohSon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1
oioon`21oh7oV?l0=X7oPOn1oh7oROok087oPOn1oh7oPOn1oh7oWook087oPOn1
oh7oPOn1oh7oWook087oPOnGo`0fPOn1oh7oPOn:oo/0POn1oh7oPOn1oh7oPOnO
oo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oiKo03J1oh7oPOn1oh_on`21oh7oPOn1
oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7oUOl0=X7oPOn1oh7oS?ok
087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOnDo`0fPOn1
oh7oPOn=oo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1
oi?o03J1oh7oPOn1ohkon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1
oioon`21oh7oT_l0=X7oPOn1oh7oSook087oPOn1oh7oPOn1oh7oWook087oPOn1
oh7oPOn1oh7oWook087oPOnAo`0fPOn1oh7oPOn@oo/0POn1oh7oPOn1oh7oPOnO
oo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oi3o03J1oh7oPOn1oi7on`21oh7oPOn1
oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7oSol0=X7oPOn1oh7oT_ok
087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOn>o`0fPOn1
oh7oPOnCoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1
ohgo03J1oh7oPOn1oiCon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1
oioon`21oh7oS?l0=X7oPOn1oh7oUOok087oPOn1oh7oPOn1oh7oWook087oPOn1
oh7oPOn1oh7oWook087oPOn;o`0fPOn1oh7oPOnFoo/0POn1oh7oPOn1oh7oPOnO
oo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh[o03J1oh7oPOn1oiOon`21oh7oPOn1
oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7oROl0=X7oPOn1oh7oV?ok
087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOn8o`0fPOn1
oh7oPOnIoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1
ohOo03J1oh7oPOn1oi[on`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1
oioon`21oh7oQ_l0=X7oPOn1oh7oVook087oPOn1oh7oPOn1oh7oWook087oPOn1
oh7oPOn1oh7oWook087oPOn5o`0fPOn1oh7oPOnLoo/0POn1oh7oPOn1oh7oPOnO
oo/0POn1oh7oPOn1oh7oPOnOoo/0POn1ohCo03J1oh7oPOn1oigon`21oh7oPOn1
oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7oPol0=X7oPOn1oh7oW_ok
087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOn2o`0fPOn1
oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1
oh7o03R1oh7oPOn1oj3on`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1
oioon`21oh7oPOl0o`0iPOn1oh7oPOnQoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1
oh7oPOn1oh7oPOnOoo/0POn1oh7o0Ooo03R1oh7oPOn1oj;on`21oh7oPOn1oh7o
POn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOono`0hPOn1oh7oPOnSoo/0
POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7ooOl0>87o
POn1oh7oY?ok087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087o
POn1ooco03R1oh7oPOn1ojGon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7o
POn1oioon`21oh7oPOoko`0hPOn1oh7oPOnVoo/0POn1oh7oPOn1oh7oPOnOoo/0
POn1oh7oPOn1oh7oPOnOoo/0POn1oh7on_l0>87oPOn1oh7oYook087oPOn1oh7o
POn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOn1ooWo03R1oh7oPOn1ojSo
n`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOoho`0h
POn1oh7oPOnYoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0
POn1oh7omol0>87oPOn1oh7oZ_ok087oPOn1oh7oPOn1oh7oWook087oPOn1oh7o
POn1oh7oWook087oPOn1ooKo03R1oh7oPOn1oj_on`21oh7oPOn1oh7oPOn1oioo
n`21oh7oPOn1oh7oPOn1oioon`21oh7oPOoeo`0hPOn1oh7oPOn/oo/0POn1oh7o
POn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7om?l0>87oPOn1oh7o
[Ook087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOn1oo?o
03R1oh7oPOn1ojkon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioo
n`21oh7oPOobo`0hPOn1oh7oPOn_oo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7o
POn1oh7oPOnOoo/0POn1oh7olOl0>87oPOn1oh7o/?ok087oPOn1oh7oPOn1oh7o
Wook087oPOn1oh7oPOn1oh7oWook087oPOn1oo3o03R1oh7oPOn1ok7on`21oh7o
POn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOo_o`0hPOn1oh7o
POnboo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7o
k_l0>87oPOn1oh7o/ook087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7o
Wook087oPOn1ongo03R1oh7oPOn1okCon`21oh7oPOn1oh7oPOn1oioon`21oh7o
POn1oh7oPOn1oioon`21oh7oPOo/o`0hPOn1oh7oPOneoo/0POn1oh7oPOn1oh7o
POnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7ojol0>87oPOn1oh7o]_ok087o
POn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOn1on[o03R1oh7o
POn1okOon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7o
POoYo`0hPOn1oh7oPOnhoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7o
POnOoo/0POn1oh7oj?l0>87oPOn1oh7o^Ook087oPOn1oh7oPOn1oh7oWook087o
POn1oh7oPOn1oh7oWook087oPOn1onOo03R1oh7oPOn1ok[on`21oh7oPOn1oh7o
POn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOoVo`0hPOn1oh7oPOnkoo/0
POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oiOl0>87o
POn1oh7o_?ok087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087o
POn1onCo03R1oh7oPOn1okgon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7o
POn1oioon`21oh7oPOoSo`0hPOn1oh7oPOnnoo/0POn1oh7oPOn1oh7oPOnOoo/0
POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oh_l0>87oPOn1oh7o_ook087oPOn1oh7o
POn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOn1on7o03R1oh7oPOn1ol3o
n`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOoPo`0h
POn1oh7oPOo1oo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0
POn1oh7ogol0>87oPOn1oh7o`_ok087oPOn1oh7oPOn1oh7oWook087oPOn1oh7o
POn1oh7oWook087oPOn1omko03R1oh7oPOn1ol?on`21oh7oPOn1oh7oPOn1oioo
n`21oh7oPOn1oh7oPOn1oioon`21oh7oPOoMo`0hPOn1oh7oPOo4oo/0POn1oh7o
POn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7og?l0>87oPOn1oh7o
aOok087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOn1om_o
03R1oh7oPOn1olKon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioo
n`21oh7oPOoJo`0hPOn1oh7oPOo7oo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7o
POn1oh7oPOnOoo/0POn1oh7ofOl0>87oPOn1oh7ob?ok087oPOn1oh7oPOn1oh7o
Wook087oPOn1oh7oPOn1oh7oWook087oPOn1omSo03R1oh7oPOn1olWon`21oh7o
POn1oh7oPOn1oioon`21oh7oPOn1oh7oPOn1oioon`21oh7oPOoGo`0hPOn1oh7o
POo:oo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7o
e_l0>87oPOn1oh7obook087oPOn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7o
Wook087oPOn1omGo03R1oh7oPOn1olcon`21oh7oPOn1oh7oPOn1oioon`21oh7o
POn1oh7oPOn1oioon`21oh7oPOoDo`0hPOn1oh7oPOo=oo/0POn1oh7oPOn1oh7o
POnOoo/0POn1oh7oPOn1oh7oPOnOoo/0POn1oh7odol0>87oPOn1oh7oc_ok087o
POn1oh7oPOn1oh7oWook087oPOn1oh7oPOn1oh7oWook087oPOn1om;o04:1oh7o
POn1oloon`21oh7oPOoBo`00POn1oh7oPOo?oo/0POn1oh7od_l0087oPOn1oh7o
cook087oPOn1om;o0000AH7oPOn1oh7od?ok087oPOn1om;o0@00POn1oh7oPOo@
oo/0POn1oh7od_l10021oh7oPOn1om3on`21oh7oPOoBo`400012POn1oh7oPOoA
oo/0POn1oh7od_on087oPOn1oh7odOok087oPOn1om;ooP21oh7oPOn1om7on`21
oh7oPOoBooh004:1oh7oPOn1om;on`21oh7oPOoBood0POn1oh7oPOoBoo/0POn1
oh7od_om087oPOn1oh7od_ok087oPOn1om;oo@00@X7oPOn1oh7odook087oPOn1
om;oo021oh7oPOn1om?on`21oh7oPOoBoo`0POn1oh7oPOoCoo/0POn1oh7od_ol
0012POn1oh7oPOoDoo/0POn1oh7od_ok087oPOn1oh7oe?ok087oPOn1om;on`21
oh7oPOn1omCon`21oh7oPOoBoo/004Z1oiKoo021oh7oaOok087oPOn1om;on`21
oiGoo021oh7oaOok087oPOn1om;on`21oiGoo021oh7oaOok087oPOn1om;on`00
o`1;POnFoo`0POn1olKon`21oh7oPOoBoo/0POnDoo`0POn1olKon`21oh7oPOoB
oo/0POnDoo`0POn1olKon`21oh7oPOoBoo/00Ooo04Z1oiKoo021oh7oaook087o
POn1om;on`21oi?oo021oh7oaook087oPOn1om;on`21oi?oo021oh7oaook087o
POn1om;on`3no`1:POnFoo`0POn1olSon`21oh7oPOoBoo/0POnBoo`0POn1olSo
n`21oh7oPOoBoo/0POnBoo`0POn1olSon`21oh7oPOoBoo/0oOl0BX7oU_ol087o
POo9oo/0POn1oh7od_ok087oTOol087oPOo9oo/0POn1oh7od_ok087oTOol087o
POo9oo/0POn1oh7od_ok0?co04Z1oiKoo021oh7ob_ok087oPOn1om;on`21oi3o
o021oh7ob_ok087oPOn1om;on`21oi3oo021oh7ob_ok087oPOn1om;on`3ko`1:
POnFoo`0POn1ol_on`21oh7oPOoBoo/0POn?oo`0POn1ol_on`21oh7oPOoBoo/0
POn?oo`0POn1ol_on`21oh7oPOoBoo/0n_l0BX7oU_ol087oPOo<oo/0POn1oh7o
d_ok087oS_ol087oPOo<oo/0POn1oh7od_ok087oS_ol087oPOo<oo/0POn1oh7o
d_ok0?Wo04Z1oiKoo021oh7ocOok087oPOn1om;on`21ohgoo021oh7ocOok087o
POn1om;on`21ohgoo021oh7ocOok087oPOn1om;on`3ho`1:POnFoo`0POn1olko
n`21oh7oPOoBoo/0POn<oo`0POn1olkon`21oh7oPOoBoo/0POn<oo`0POn1olko
n`21oh7oPOoBoo/0mol0BX7oU_ol087oPOo?oo/0POn1oh7od_ok087oRool087o
POo?oo/0POn1oh7od_ok087oRool087oPOo?oo/0POn1oh7od_ok0?Ko09SAooX0
k_oj0>con@3Zoo`0iOoj0>SonP3_ooX0o?ol087oPOo@oo/0POn1oh7od_ok0<Go
nP3^ooX0k?oi0>[oo03UooX0j?oj0>oonP3loo`0POn1om3on`21oh7oPOoBoo/0
aOoj0>konP3/ooT0j_ol0>GonP3XooX0kooj0?coo021oh7od?ok087oPOn1om;o
n`3eo`2lfool0?gom`3booD0l_oc0?Ooo03nooX0iooe0?Goo03mooL0loof0?ko
o021oh7odOok087oPOn1om;on`3>oo`0oOog0?;om@3boo<0mool0?konP3WooD0
mOol0?gom`3cooH0o_ol087oPOoAoo/0POn1oh7od_ok0<koo03mooL0l_oe0?;o
l`3goo`0o_oj0>Oom@3eoo`0oOog0??omP3noo`0POn1om7on`21oh7oPOoBoo/0
m?l0b=_oo001oood0?GolP3doo40n?ol007oooT0jOob0?Koo001oood0?Gom001
oool087oPOoBoo/0POn1oh7od_ok0<goo001oood0?GolP3doo40n?ol007oooT0
jOob0?Koo001oood0?Gom001oool087oPOoBoo/0POn1oh7od_ok0<goo001oood
0?GolP3doo40n?ol007oooT0jOob0?Koo001oood0?Gom001oool087oPOoBoo/0
POn1oh7od_ok0??o0;cKoo`00?oc0?Kol03fonl0nOol003on03Zoo00mool003o
l`3foo800?ol087oPOoCoo/0POn1oh7od_ok0<coo000oo<0m_o`0?Kok`3ioo`0
0?oh0>[ol03goo`00?oc0?KolP00oo`0POn1om?on`21oh7oPOoBoo/0c?ol003o
l`3foo00m_o_0?Woo000ooP0j_o`0?Ooo000oo<0m_ob003oo021oh7odook087o
POn1om;on`3bo`44fool003oo@3mooX0n?oj0?conP3hooX0o?oj0?Wom`3mo`00
jooj0?conP3hoo`00?om0?gonP3hooX0o?om003oo021oh7oe?ok087oPOn1om;o
n`3;oo`00?om0?gonP3hooX0o?oj0?SonP3looX0nOog0?go003[ooX0o?oj0?So
o000ood0oOoj0?SonP3lood00?ol087oPOoDoo/0POn1oh7od_ok0<_oo000ood0
oOoj0?SonP3looX0n?oj0?conP3iooL0oOl00>_onP3looX0n?ol003oo@3mooX0
n?oj0?coo@00oo`0POn1omCon`21oh7oPOoBoo/0lOl0e=_on@3ioo`0n?ok0?Wo
o03hoo`0n?ok0?[on@3Too/0nOol0?Son@3ioo`0nOok0?Son@21oh7oeOok087o
POn1om;on`3:ooT0nOol0?Son`3ioo`0n?ol0?Son`3jooT0i?ok0?Woo03hooT0
nOol0?Won`3hooT0POn1omGon`21oh7oPOoBoo/0b_oi0?Woo03hoo/0nOol0?So
o03hoo/0n_oi0>Con`3ioo`0n?oi0?Woo03ioo/0n?oi087oPOoEoo/0POn1oh7o
d_ok0?3o0=CKooX0n?ok0?[on`3hoo/0n_ol0?Koo03jooX0i?ok0?Son`3iooX0
n?ok0?[oo03fooX0POn1omKon`21oh7oPOoBoo/0bOoj0?Son`3joo/0n?ok0?[o
o03foo`0n_oj0>Con`3hoo/0nOoj0?Son`3joo`0m_oj087oPOoFoo/0POn1oh7o
d_ok0<WonP3hoo/0n_ok0?Son`3joo`0m_ol0?[onP3Too/0n?ok0?WonP3hoo/0
n_ol0?KonP21oh7oe_ok087oPOn1om;on`3_o`3Dfooj0?Ooo03joo`0m_ol0?[o
o03foo`0n_ok0>?oo03foo`0nOoj0?Ooo03koo/0m_oj087oPOoGoo/0POn1oh7o
d_ok0<SonP3goo`0n_ol0?Koo03joo`0m_ol0?[on`3Soo`0m_ol0?WonP3goo`0
nook0?KonP21oh7oeook087oPOn1om;on`38ooX0mool0?[oo03foo`0n_ol0?Ko
o03joo/0hool0?Koo03iooX0mool0?_on`3fooX0POn1omOon`21oh7oPOoBoo/0
k_l0b=_on`3foo`0nool0?Goo03Zoo`0n_ok0>Coo03eoo`0nOok0?Koo03koo`0
m?ok087oPOoHoo/0POn1oh7od_ok0<Oon`3foo`0nool0?Goo03Zoo`0n_ok0>Co
o03eoo`0nOok0?Koo03koo`0m?ok087oPOoHoo/0POn1oh7od_ok0<Oon`3foo`0
nool0?Goo03Zoo`0n_ok0>Coo03eoo`0nOok0?Koo03koo`0m?ok087oPOoHoo/0
POn1oh7od_ok0>go0<SKoo/0m_ol0?_oo03doo`0jool0?[on`3Too`0m?ol0?[o
n`3foo`0nool0?Con`21oh7ofOok087oPOn1om;on`36oo/0m_ol0?_oo03doo`0
jool0?[on`3Too`0m?ol0?[on`3foo`0nool0?Con`21oh7ofOok087oPOn1om;o
n`36oo/0m_ol0?_oo03doo`0jool0?[on`3Too`0m?ol0?[on`3foo`0nool0?Co
n`21oh7ofOok087oPOn1om;on`3/o`38fool0?Goo03koo`0m?ol0>_oo03joo`0
hool0?Coo03joo`0mOol0?coo03boo`0POn1om[on`21oh7oPOoBoo/0aOol0?Go
o03koo`0m?ol0>_oo03joo`0hool0?Coo03joo`0mOol0?coo03boo`0POn1om[o
n`21oh7oPOoBoo/0aOol0?Goo03koo`0m?ol0>_oo03joo`0hool0?Coo03joo`0
mOol0?coo03boo`0POn1om[on`21oh7oPOoBoo/0jol0b=_oo03eoo`0o?ol0??o
o03[oo`0n_ol0>Coo03coo`0n_ol0?Goo03loo`0l_ol087oPOoKoo/0POn1oh7o
d_ok0<Coo03eoo`0o?ol0??oo03[oo`0n_ol0>Coo03coo`0n_ol0?Goo03loo`0
l_ol087oPOoKoo/0POn1oh7od_ok0<Coo03eoo`0o?ol0??oo03[oo`0n_ol0>Co
o03coo`0n_ol0?Goo03loo`0l_ol087oPOoKoo/0POn1oh7od_ok0>[o0;3Koo`0
mOol0?coj@3]ooX0n_ol0>Coj@3joo`0mOol0?coo03boo`0POn1omcon`21oh7o
POoBoo/0`ool0?Goo03lonT0kOoj0?[oo03TonT0n_ol0?Goo03loo`0l_ol087o
POoLoo/0POn1oh7od_ok0<?oo03eoo`0o?oY0>gonP3joo`0i?oY0?[oo03eoo`0
o?ol0?;oo021oh7og?ok087oPOn1om;on`3Yo`2ofool0?Goo03lonT0lOof0?[o
o03TonT0n_ol0?Goo03loo`0l_ol087oPOoMoo/0POn1oh7od_ok0?3o0@00eOol
0?Goo03lonT0lOof0?[oo03TonT0n_ol0?Goo03loo`0l_ol087oPOoMoo/0POn1
oh7od_ok0?3o0@00eOol0?Goo03lonT0lOof0?[oo03TonT0n_ol0?Goo03loo`0
l_ol087oPOoMoo/0POn1oh7od_ok0?3o0@00nol0_=_oo03eoo`0o?oY0?Col`3j
oo`0i?oY0?[oo03eoo`0o?ol0?;oo021oh7og_ok087oPOn1om;on`3`oo/0f?ol
0?Goo03lonT0m?oc0?[oo03TonT0n_ol0?Goo03loo`0l_ol087oPOoNoo/0POn1
oh7od_ok0?3on`3Hoo`0mOol0?coj@3doo<0n_ol0>Coj@3joo`0mOol0?coo03b
oo`0POn1omkon`21oh7oPOoBoo/0l?ok0?ko0;cKoo`0mOol0?coj@3goo00n_ol
0>Coj@3joo`0mOol0?coo03boo`0POn1omoon`21oh7oPOoBoo/0kooi0=[oo03e
oo`0o?oY0?Ool03joo`0i?oY0?[oo03eoo`0o?ol0?;oo021oh7ogook087oPOn1
om;on`3_ooT0f_ol0?Goo03lonT0moo`0?[oo03TonT0n_ol0?Goo03loo`0l_ol
087oPOoOoo/0POn1oh7od_ok0>oon@00o`39fool0?Goo03loo`0iOof007ooo`0
n_ol0>Coo03Woo`0mOol0?coo03boo`0POn1on3on`21oh7oPOoBoo/0koog0=_o
o03eoo`0o?ol0>GomP01oool0?[oo03Too`0iool0?Goo03loo`0l_ol087oPOoP
oo/0POn1oh7od_ok0>oom`3Koo`0mOol0?coo03UooH00Oooo03joo`0i?ol0>Oo
o03eoo`0o?ol0?;oo021oh7oh?ok087oPOn1om;on`3_ooL00<KKoo`0mOol0?co
o03VooT0nool0?[oo03Too`0iool0?Goo03loo`0l_ol087oPOoQoo/0POn1oh7o
d_ok0>kom`3Koo`0mOol0?coo03VooT0nool0?[oo03Too`0iool0?Goo03loo`0
l_ol087oPOoQoo/0POn1oh7od_ok0>kom`3Koo`0mOol0?coo03VooT0nool0?[o
o03Too`0iool0?Goo03loo`0l_ol087oPOoQoo/0POn1oh7od_ok0>kom`00a]_o
o03eoo`0o?ol0>OonP3ioo`0n_ol0>Coo03Woo`0mOol0?coo03boo`0POn1on;o
n`21oh7oPOoBoo/0k_of0=_oo03eoo`0o?ol0>OonP3ioo`0n_ol0>Coo03Woo`0
mOol0?coo03boo`0POn1on;on`21oh7oPOoBoo/0k_of0=_oo03eoo`0o?ol0>Oo
nP3ioo`0n_ol0>Coo03Woo`0mOol0?coo03boo`0POn1on;on`21oh7oPOoBoo/0
k_of0036fool0?Goo03loo`0iool0?Ooo03joo`0i?ol0>Ooo03eoo`0o?ol0??o
n`21oh7ohook087oPOn1om;on`3]ooH0fool0?Goo03loo`0iool0?Ooo03joo`0
i?ol0>Ooo03eoo`0o?ol0??on`21oh7ohook087oPOn1om;on`3]ooH0fool0?Go
o03loo`0iool0?Ooo03joo`0i?ol0>Ooo03eoo`0o?ol0??on`21oh7ohook087o
POn1om;on`3]ooH00<KKoo`0mOol0?_oo03Yoo/0mool0?[oo03Soo`0j?ol0?Go
o03koo`0m?ok087oPOoToo/0POn1oh7od_ok0>gom@3Koo`0mOol0?_oo03Yoo/0
mool0?[oo03Soo`0j?ol0?Goo03koo`0m?ok087oPOoToo/0POn1oh7od_ok0>go
m@3Koo`0mOol0?_oo03Yoo/0mool0?[oo03Soo`0j?ol0?Goo03koo`0m?ok087o
POoToo/0POn1oh7od_ok0>gom@00a]_oo03eoo`0nool0>Woo03goo/0n_ol0>?o
o03Xoo`0mOol0?_oo03doo/0POn1onGon`21oh7oPOoBoo/0k?oe0=_oo03eoo`0
nool0>Woo03goo/0n_ol0>?oo03Xoo`0mOol0?_oo03doo/0POn1onGon`21oh7o
POoBoo/0k?oe0=_oo03eoo`0nool0>Woo03goo/0n_ol0>?oo03Xoo`0mOol0?_o
o03doo/0POn1onGon`21oh7oPOoBoo/0k?oe003Nfool0?Goo03koo/0mOol0?_o
o03goo/0n_ol0>?on`3eoo`0n_ol0?Goo03koo`0mOoj087oPOoVoo/0POn1oh7o
d_ok0>com03Koo`0mOol0?_on`3eoo`0nool0?Oon`3joo`0hook0?Goo03joo`0
mOol0?_oo03eooX0POn1onKon`21oh7oPOoBoo/0k?od0=_oo03eoo`0nook0?Go
o03koo`0mook0?[oo03Soo/0mOol0?[oo03eoo`0nool0?GonP21oh7oi_ok087o
POn1om;on`3/oo@00=kKoo`0mOol0?[on`3foo`0nool0?SonP3joo`0h_ok0?Ko
o03joo`0mOol0?[oo03fooX0POn1onOon`21oh7oPOoBoo/0jood0=_oo03eoo`0
n_ok0?Koo03koo`0n?oj0?[oo03Roo/0m_ol0?[oo03eoo`0n_ol0?KonP21oh7o
iook087oPOn1om;on`3[oo@0fool0?Goo03joo/0m_ol0?_oo03hooX0n_ol0>;o
n`3foo`0n_ol0?Goo03joo`0m_oj087oPOoWoo/0POn1oh7od_ok0>_om000g]_o
o03eoo`0n_oj0?Soo03joo/0n_oi0?[oo03RooX0n?ol0?Woo03eoo`0n_ok0?So
n@21oh7oj?ok087oPOn1om;on`3[oo<0fool0?Goo03jooX0n?ol0?[on`3jooT0
n_ol0>;onP3hoo`0nOol0?Goo03joo/0n?oi087oPOoXoo/0POn1oh7od_ok0>_o
l`3Koo`0mOol0?[onP3hoo`0n_ok0?[on@3joo`0h_oj0?Soo03ioo`0mOol0?[o
n`3hooT0POn1onSon`21oh7oPOoBoo/0jooc003Zfool0?Goo03iooT0nook0?Wo
n`3mooL0n_ol0>7on@3koo/0nOol0?Goo03iooX0o?om003oo021oh7ojOok087o
POn1om;on`3Zoo<0fool0?Goo03iooT0nook0?Won`3mooL0n_ol0>7on@3koo/0
nOol0?Goo03iooX0o?om003oo021oh7ojOok087oPOn1om;on`3Zoo<0fool0?Go
o03iooT0nook0?Won`3mooL0n_ol0>7on@3koo/0nOol0?Goo03iooX0o?om003o
o021oh7ojOok087oPOn1om;on`3Zoo<00<KKoo`0mOol0?Sok`3hoo<00?ol0?[o
o03Ponl0n?ol0?Goo03hoo800?ol087oPOoZoo/0POn1oh7od_ok0>[olP3Koo`0
mOol0?Sok`3hoo<00?ol0?[oo03Ponl0n?ol0?Goo03hoo800?ol087oPOoZoo/0
POn1oh7od_ok0>[olP3Koo`0mOol0?Sok`3hoo<00?ol0?[oo03Ponl0n?ol0?Go
o03hoo800?ol087oPOoZoo/0POn1oh7od_ok0>[olP00c=_oo03eoo`0mooa0?Ko
m@01oook0?_oo03Ooo40mool0?Goo03goo@00Oooo021oh7ojook087oPOn1om;o
n`3Yoo80fool0?Goo03goo40m_oe007ooo/0nool0=ool@3goo`0mOol0?Oom001
oool087oPOo[oo/0POn1oh7od_ok0>WolP3Koo`0mOol0?Ool@3fooD00Ooon`3k
oo`0gooa0?Ooo03eoo`0mood007ooo`0POn1on_on`21oh7oPOoBoo/0jOob0036
fool0?Goo03eoo@0m?oh0?coo03koo`0gOod0?Koo03eoo`0m_of0?koo021oh7o
k?ok087oPOn1om;on`3Yoo40fool0?Goo03eoo@0m?oh0?coo03koo`0gOod0?Ko
o03eoo`0m_of0?koo021oh7ok?ok087oPOn1om;on`3Yoo40fool0?Goo03eoo@0
m?oh0?coo03koo`0gOod0?Koo03eoo`0m_of0?koo021oh7ok?ok087oPOn1om;o
n`3Yoo4007:gooT0kool0<Con@3@ooX0POn1on?on`21oh7oPOoBoo/0j?oa0;Oo
n@3_oo`0a?oi0=3onP21oh7ohook087oPOn1om;on`3Xoo40]ooi0>ooo034ooT0
d?oj087oPOoSoo/0POn1oh7od_ok0>Sol@00CX7oPOn1oh7oo_ok087oPOn1om;o
n`3Xoo00POn1oh7oPOonoo/0POn1oh7od_ok0>Sol021oh7oPOn1ookon`21oh7o
POoBoo/0j?o`001APOn1oh7oPOl1oook087oPOn1om;on`3Woo00POn1oh7oPOl1
oook087oPOn1om;on`3Woo00POn1oh7oPOl1oook087oPOn1om;on`3Woo0004j1
oh7oPOn1o`3on`21oh7oPOoBoo/0ioo_087oPOn1oh7o0?ok087oPOn1om;on`3W
onl0POn1oh7oPOl0oo/0POn1oh7od_ok0>Ook`00B87oPOn1oh7on`21oh7oPOoB
oo/0i_o_087oPOn1oh7on`21oh7oPOoBoo/0i_o_087oPOn1oh7on`21oh7oPOoB
oo/0i_o_0018POn1oh7oP_ok087oPOn1om;on`3Uonl0POn1oh7oP_ok087oPOn1
om;on`3Uonl0POn1oh7oP_ok087oPOn1om;on`3Uonl004R1oh7oPOn3oo/0POn1
oh7od_ok0>GokP21oh7oPOn3oo/0POn1oh7od_ok0>GokP21oh7oPOn3oo/0POn1
oh7od_ok0>GokP00B87oPOn1ohCon`21oh7oPOoBoo/0i?o^087oPOn1ohCon`21
oh7oPOoBoo/0i?o^087oPOn1ohCon`21oh7oPOoBoo/0i?o^0018POn1oh7oQOok
087oPOn1om;on`3Tond0POn1oh7oQOok087oPOn1om;on`3Tond0POn1oh7oQOok
087oPOn1om;on`3Tond004R1oh7oPOn6oo/0POn1oh7od_ok0>?ok@21oh7oPOn6
oo/0POn1oh7od_ok0>?ok@21oh7oPOn6oo/0POn1oh7od_ok0>?ok@00B87oPOn1
ohOon`21oh7oPOoBoo/0hoo/087oPOn1ohOon`21oh7oPOoBoo/0hoo/087oPOn1
ohOon`21oh7oPOoBoo/0hoo/0018POn1oh7oR?ok087oPOn1om;on`3Ron`0POn1
oh7oR?ok087oPOn1om;on`3Ron`0POn1oh7oR?ok087oPOn1om;on`3Ron`004R1
oh7oPOn9oo/0POn1oh7od_ok0>;oj`21oh7oPOn9oo/0POn1oh7od_ok0>;oj`21
oh7oPOn9oo/0POn1oh7od_ok0>;oj`00BX7oPOn1oh[on`21oh7oPOoBoo/0hOo/
087oPOn1ohWon`21oh7oPOoBoo/0hOo/087oPOn1ohWon`21oh7oPOoBoo/0hOo/
003o04Z1oh7oPOn;oo/0POn1oh7od_ok0>7ok@21oh7oPOn8oo/0POn1oh7od_ok
0>7ok@21oh7oPOn8oo/0POn1oh7od_ok0>7ok@3no`1:POn1oh7oS?ok087oPOn1
om;on`3Ponl0POn1oh7oQook087oPOn1om;on`3Ponl0POn1oh7oQook087oPOn1
om;on`3Ponl0o?l0BX7oPOn1ohgon`21oh7oPOoBoo/0h?o_087oPOn1ohOon`21
oh7oPOoBoo/0h?o_087oPOn1ohOon`21oh7oPOoBoo/0h?o_0?_o04Z1oh7oPOn>
oo/0POn1oh7od_ok0=ool@21oh7oPOn6oo/0POn1oh7od_ok0=ool@21oh7oPOn6
oo/0POn1oh7od_ok0=ool@3io`1:POn1oh7oSook087oPOn1om;on`3Ooo80POn1
oh7oQOok087oPOn1om;on`3Ooo80POn1oh7oQOok087oPOn1om;on`3Ooo80mol0
BX7oPOn1oi3on`21oh7oPOoBoo/0g_od087oPOn1ohCon`21oh7oPOoBoo/0g_od
087oPOn1ohCon`21oh7oPOoBoo/0g_od0?Go04Z1oh7oPOnAoo/0POn1oh7od_ok
0=kom021oh7oPOn4oo/0POn1oh7od_ok0=kom021oh7oPOn4oo/0POn1oh7od_ok
0=kom03do`1:POn1oh7oT_ok087oPOn1om;on`3MooH0POn1oh7oPook087oPOn1
om;on`3MooH0POn1oh7oPook087oPOn1om;on`3MooH0l_l0BX7oPOn1oi?on`21
oh7oPOoBoo/0gOog087oPOn1oh;on`21oh7oPOoBoo/0gOog087oPOn1oh;on`21
oh7oPOoBoo/0gOog0?3o04Z1oh7oPOnDoo/0POn1oh7od_ok0=con@21oh7oPOn1
oo/0POn1oh7od_ok0=con@21oh7oPOn1oo/0POn1oh7od_ok0=con@3^o`1>POn1
oh7oUOok087oPOn1om;on`3LooX0POn1oh7oPOl0oo/0POn1oh7od_ok0=conP21
oh7oPOn1o`3on`21oh7oPOoBoo/0g?oj0>co0521oh7oPOnFoo/0POn1oh7od_ok
0=_oo021oh7oPOn1o`7ooo/0POn1oh7od_ok0=_oo021oh7oPOn1o`7ooo/0POn1
oh7od_ok0=_oo03Zo`1>POn1oh7oUook087oPOn1om;on`3Kood0POn1oh7oPOon
oo/0POn1oh7od_ok0=_oo@21oh7oPOn1ookon`21oh7oPOoBoo/0foom0>So04:1
oh7oPOnHoo/0POn1oh7od_ok087oPOn1oh7oe?ok087oPOn1om;on`21oh7oPOn1
omCon`21oh7oPOoBoo/0_Ol0@X7oPOn1oiWon`21oh7oPOoBoo/0POn1oh7oPOoD
oo/0POn1oh7od_ok087oPOn1oh7oe?ok087oPOn1om;on`2lo`12POn1oh7oV_ok
087oPOn1om;on`21oh7oPOn1omCon`21oh7oPOoBoo/0POn1oh7oPOoDoo/0POn1
oh7od_ok0;_o04:1oh7oPOnKoo/0POn1oh7od_ok087oPOn1oh7oe?ok087oPOn1
om;on`21oh7oPOn1omCon`21oh7oPOoBoo/0^_l0@X7oPOn1oicon`21oh7oPOoB
oo/0POn1oh7oPOoDoo/0POn1oh7od_ok087oPOn1oh7oe?ok087oPOn1om;on`2i
o`12POn1oh7oWOok087oPOn1om;on`21oh7oPOn1omCon`21oh7oPOoBoo/0POn1
oh7oPOoDoo/0POn1oh7od_ok0;So04:1oh7oPOnNoo/0POn1oh7od_ok087oPOn1
oh7oe?ok087oPOn1om;on`21oh7oPOn1omCon`21oh7oPOoBoo/0]ol0@X7oPOn1
oioon`21oh7oPOoBoo/0POn1oh7oPOoDoo/0POn1oh7od_ok087oPOn1oh7oe?ok
087oPOn1om;on`2fo`12POn1oh7oX?ok087oPOn1om;on`21oh7oPOn1omCon`21
oh7oPOoBoo/0POn1oh7oPOoDoo/0POn1oh7od_ok0;Go04:1oh7oPOnQoo/0POn1
oh7od_ok087oPOn1oh7oe?ok087oPOn1om;on`21oh7oPOn1omCon`21oh7oPOoB
oo/0]?l0@X7oPOn1oj;on`21oh7oPOoBoo/0POn1oh7oPOoDoo/0POn1oh7od_ok
087oPOn1oh7oe?ok087oPOn1om;on`2co`12POn1oh7oXook087oPOn1om;on`21
oh7oPOn1omCon`21oh7oPOoBoo/0POn1oh7oPOoDoo/0POn1oh7od_ok0;;o04:1
oh7oPOnToo/0POn1oh7od_ok087oPOn1oh7oe?ok087oPOn1om;on`21oh7oPOn1
omCon`21oh7oPOoBoo/0/Ol0@X7oPOn1oj?oo@21oh7oPOoBoo/0POn1oh7oPOoB
ood0POn1oh7od_ok087oPOn1oh7od_om087oPOn1om;on`2`o`15POn1oh7oX_l1
0021oh7oPOoBoo/0POn1oh7oPOo@o`40087oPOn1om;on`21oh7oPOn1om3o0@00
POn1oh7od_ok0:oo03R1oh7oPOn1oh7oPOn1oo3oo@21oh7oPOn1oh7oPOn1oigo
o@21oh7oPOn1oh7oPOn1oigoo@2^o`0kPOn1oh7oPOn1oh7oPOo_o`40087oPOn1
oh7oPOn1oh7oVol10021oh7oPOn1oh7oPOn1oi_o0@00[Ol0<87oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOo9o`0`POn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1olWo002J0000oh_<
000000430_<00004000000180000B0000100800300P000000000009]M^`00000
0@<2k0?Y0n/4j`KD0000H?/0g_ok0?_on`3koo/0fOol0>Ooo021oh7oPOn1oj7o
n`3Noo/0nook0?_on`3Ioo`0iool087oPOn1oh7oXOok0=kon`3koo/0nook0=Wo
o03Woo`0POn1oh7oPOnQo`1Pn`3Moo/0nook0?_on`3Koo`0i_ol087oPOn1oh7o
XOok0=gon`3koo/0nook0=_oo03Voo`0POn1oh7oPOnQoo/0gOok0?_on`3koo/0
fool0>Koo021oh7oPOn1oj7o063j0=gon`3koo/0nook0=coo03Uoo`0POn1oh7o
POnRooX0gOok0?_on`3koo/0g?ol0>Goo021oh7oPOn1oj;onP3Moo/0nook0?_o
n`3Loo`0iOol087oPOn1oh7oX_l0H?X0g?ok0?_on`3koo/0g_ol0>Coo021oh7o
POn1oj;onP3Loo/0nook0?_on`3Noo`0i?ol087oPOn1oh7oX_oj0=con`3koo/0
nook0=koo03Too`0POn1oh7oPOnRo`1Pn@3Loo/0nook0?_on`3Ooo`0hool087o
POn1oh7oXooi0=con`3koo/0nook0=ooo03Soo`0POn1oh7oPOnSooT0g?ok0?_o
n`3koo/0gool0>?oo021oh7oPOn1oj?o063i0=_on`3koo/0nook0>7oo03Roo`0
POn1oh7oPOnSooT0fook0?_on`3koo/0hOol0>;oo021oh7oPOn1oj?on@3Koo/0
nook0?_on`3Qoo`0h_ol087oPOn1oh7oXol0HP3on@3Koo/0nook0?_on`3Roo`0
hOom087oPOn1oh7oX_oi0=_on`3koo/0nook0>;oo03Qood0POn1oh7oPOnRooT0
fook0?_on`3koo/0h_ol0>7oo@21oh7oPOn1oj?o06;noo/0f_ok0?_on`3koo/0
i?ol0>3oo@21oh7oPOn1oj3on`3Joo/0nook0?_on`3Too`0h?om087oPOn1oh7o
X?ok0=[on`3koo/0nook0>Coo03Pood0POn1oh7oPOnSo`1Ro?ol0=[on`3koo/0
nook0>Goo03Poo`0POn1oh7oPOnOoo`0f_ok0?_on`3koo/0iOol0>3oo021oh7o
POn1oiooo03Joo/0nook0?_on`3Uoo`0h?ol087oPOn1oh7oY?l0H_[ooP3Ioo/0
nook0?_on`3Vood0g_om087oPOn1oh7oWOon0=Won`3koo/0nook0>Koo@3Nood0
POn1oh7oPOnMooh0fOok0?_on`3koo/0i_om0=koo@21oh7oPOn1ojCo06Gho`40
0=Won`3koo/0nook0>Soo03Nood0POn1oh7oPOnKo`400=Won`3koo/0nook0>So
o03Nood0POn1oh7oPOnKo`400=Won`3koo/0nook0>Soo03Nood0POn1oh7oPOnT
o`1JcOok0?_on`3koo/0jOol0=koo021oh7oPOn1oh7olOok0?_on`3koo/0jOol
0=koo021oh7oPOn1oh7olOok0?_on`3koo/0jOol0=koo021oh7oPOn1ojGo05[<
oo/0nook0?_on`3Zood0g?om087oPOn1oh7oPOo`oo/0nook0?_on`3Zood0g?om
087oPOn1oh7oPOo`oo/0nook0?_on`3Zood0g?om087oPOn1oh7oYOl0F/_on`3k
oo/0nook0>coo03Lood0POn1oh7oPOn1onoon`3koo/0nook0>coo03Lood0POn1
oh7oPOn1onoon`3koo/0nook0>coo03Lood0POn1oh7oPOnUo`1Jb_ok0?_on`3k
oo/0kOol0=coo@21oh7oPOn1oh7ok_ok0?_on`3koo/0kOol0=coo@21oh7oPOn1
oh7ok_ok0?_on`3koo/0kOol0=coo@21oh7oPOn1ojGo06K9oo/0nook0?_on`3^
ood0k_ol0??oo021oh7oPOn1oh7ok_ok0?_on`3koo/0k_om0>koo03coo`0POn1
oh7oPOn1onkon`3koo/0nook0>koo@3^oo`0lool087oPOn1oh7oY_l0I/Son`3k
oo/0nook0?3oo03^oo`0l_om087oPOn1oh7oPOo]oo/0nook0?_on`3`oo`0k_ol
0?;oo@21oh7oPOn1oh7okOok0?_on`3koo/0l?ol0>koo03bood0POn1oh7oPOnV
o`1Vaook0?_on`3koo/0lOom0>goo03bood0POn1oh7oPOn1oncon`3koo/0nook
0?7oo@3]oo`0l_om087oPOn1oh7oPOo/oo/0nook0?_on`3aood0kOol0?;oo@21
oh7oPOn1ojKo06K6oo/0nook0?_on`3bood0kOol0?;oo021oh7oPOn1oh7ok?ok
0?_on`3koo/0l_om0>goo03boo`0POn1oh7oPOn1oncon`3koo/0nook0?;oo@3]
oo`0l_ol087oPOn1oh7oYol0F/Gon`3koo/0nook0?Coo03Hood0POn1oh7oPOn1
on_on`3koo/0nook0?Coo03Hood0POn1oh7oPOn1on_on`3koo/0nook0?Coo03H
ood0POn1oh7oPOnWo`1Ja?ok0?_on`3koo/0mOom0=Ooo@21oh7oPOn1oh7oj_ok
0?_on`3koo/0mOom0=Ooo@21oh7oPOn1oh7oj_ok0?_on`3koo/0mOom0=Ooo@21
oh7oPOn1ojOo05[3oo/0nook0?_on`3food0eoom087oPOn1oh7oPOoYoo/0nook
0?_on`3food0eoom087oPOn1oh7oPOoYoo/0nook0?_on`3food0eoom087oPOn1
oh7oYol0F/;on`3koo/0nook0?Soo03Goo`0POn1oh7oPOn1onWon`3koo/0nook
0?Soo03Goo`0POn1oh7oPOn1onWon`3koo/0nook0?Soo03Goo`0POn1oh7oPOnX
o`1J`Ook0?_on`3koo/0nOom0=Goo@21oh7oPOn1oh7oj?ok0?_on`3koo/0nOom
0=Goo@21oh7oPOn1oh7oj?ok0?_on`3koo/0nOom0=Goo@21oh7oPOn1ojSo05[0
oo/0nook0?_on`3jood0eOom087oPOn1oh7oPOoWoo/0nook0?_on`3jood0eOom
087oPOn1oh7oPOoWoo/0nook0?_on`3jood0eOom087oPOn1oh7oZ?l0F[oon`3k
oo/0nook0?coo03Eoo`0POn1oh7oPOn1onOon`3koo/0nook0?coo03Eoo`0POn1
oh7oPOn1onOon`3koo/0nook0?coo03Eoo`0POn1oh7oPOnYo`1J__ok0?_on`3k
oo/0oOom0=?oo@21oh7oPOn1oh7oi_ok0?_on`3koo/0oOom0=?oo@21oh7oPOn1
oh7oi_ok0?_on`3koo/0oOom0=?oo@21oh7oPOn1ojWo05fmoo/0nook0?_on`01
oool0=?oo@21oh7oPOn1oh7oiOok0?_on`3koo/00Oooo03Cood0POn1oh7oPOn1
onGon`3koo/0nook007ooo`0doom087oPOn1oh7oZOl0F[con`3koo/0nook003o
o@3Boo`0POn1oh7oPOn1onGon`3koo/0nook003oo@3Boo`0POn1oh7oPOn1onGo
n`3koo/0nook003oo@3Boo`0POn1oh7oPOnZo`1>^ook0?_on`3kooL0dOom087o
POn1oh7oPOoToo/0nook0?_om`3Aood0POn1oh7oPOn1onCon`3koo/0noog0=7o
o@21oh7oPOn1oj[o04jjoo/0nook0?_on@3@oo`0POn1oh7oPOn1onCon`3koo/0
nooi0=3oo021oh7oPOn1oh7oi?ok0?_on`3kooT0d?ol087oPOn1oh7oZol0C[Wo
n`3koo/0nooj0=3oo021oh7oPOn1oh7ohook0?_on`3kooX0d?ol087oPOn1oh7o
POoSoo/0nook0?_onP3@oo`0POn1oh7oPOn[o`1>^?ok0?_on`3koo/0coom087o
POn1oh7oPOoRoo/0nook0?_on`3?ood0POn1oh7oPOn1on;on`3koo/0nook0<oo
o@21oh7oPOn1oj_o04jgoo/0nook0?conP3@oo`0POn1oh7oPOn1on;on`3koo/0
o?oj0=3oo021oh7oPOn1oh7oh_ok0?_on`3looX0d?ol087oPOn1oh7o[?l0C[Ko
n`3koo/0oOoi0=7oo021oh7oPOn1oh7ohOok0?_on`3mooT0dOol087oPOn1oh7o
POoQoo/0nook0?gon@3Aoo`0POn1oh7oPOn/o`1A]Ook0?_on`01ooog0=7oo@21
oh7oPOn1oh7oh?ok0?_on`01ooog0=7oo@21oh7oPOn1oh7oh?ok0?_on`01ooog
0=7oo@21oh7oPOn1ojco05Zdoo/0nook003omP3/oo`0k?ol087oPOn1oh7oPOoP
oo/0nook003omP3/oo`0k?ol087oPOn1oh7oPOoPoo/0nook003omP3/oo`0k?ol
087oPOn1oh7o[Ol0GK?on`3kooL00Ooon`3]oo`0k?ol087oPOn1oh7oPOoOoo/0
noog007ooo/0kOol0>coo021oh7oPOn1oh7ogook0?_om`01oook0>goo03/oo`0
POn1oh7oPOn]o`1J/_ok0?_on03noo/0k_ol0>_oo@21oh7oPOn1oh7og_ok0?_o
n03noo/0k_ol0>_oo@21oh7oPOn1oh7og_ok0?_on03noo/0k_ol0>_oo@21oh7o
POn1ojgo05Zaoo/0nooj0?con`3_oo`0jool087oPOn1oh7oPOoNoo/0nooj0?co
n`3_oo`0jool087oPOn1oh7oPOoNoo/0nooj0?con`3_oo`0jool087oPOn1oh7o
[_l0C[3on`3koo/0nook0=Goo021oh7oPOn1oh7ogOok0?_on`3koo/0eOol087o
POn1oh7oPOoMoo/0nook0?_on`3Eoo`0POn1oh7oPOn^o`1>[ook0?conP3koo/0
eOol087oPOn1oh7oPOoMoo/0o?oj0?_on`3Eoo`0POn1oh7oPOn1omgon`3looX0
nook0=Goo021oh7oPOn1ojoo04j^oo/0o_oh0?_on`3Foo`0POn1oh7oPOn1omco
n`3nooP0nook0=Koo021oh7oPOn1oh7og?ok0?kon03koo/0e_ol087oPOn1oh7o
[ol0DJgon`01ooog0?_on`3Foo`0POn1oh7oPOn1omcon`01ooog0?_on`3Foo`0
POn1oh7oPOn1omcon`01ooog0?_on`3Foo`0POn1oh7oPOn`o`1>[?of003on`3k
oo/0eook087oPOn1oh7oPOoLooH00?ok0?_on`3Goo/0POn1oh7oPOn1omcomP00
oo/0nook0=Oon`21oh7oPOn1ok7o056[ooL00Ooon`3koo/0eool087oPOn1oh7o
POoKooL00Ooon`3koo/0eool087oPOn1oh7oPOoKooL00Ooon`3koo/0eool087o
POn1oh7o/Ol0CZ[on@3moo/0nook0=Ooo021oh7oPOn1oh7ofooi0?gon`3koo/0
eool087oPOn1oh7oPOoKooT0oOok0?_on`3Goo`0POn1oh7oPOnbo`1>ZOok0?_o
n`3koo/0f?ok087oPOn1oh7oPOoKoo/0nook0?_on`3Hoo/0POn1oh7oPOn1om_o
n`3koo/0nook0=Son`21oh7oPOn1ok?o04jZooT0nook0?_on`3Hoo`0POn1oh7o
POn1omcon@3koo/0nook0=Soo021oh7oPOn1oh7og?oi0?_on`3koo/0f?ol087o
POn1oh7o/ol0CZ[on03koo/0nook0=Soo021oh7oPOn1oh7ogOoh0?_on`3koo/0
f?ol087oPOn1oh7oPOoMooP0nook0?_on`3Hoo`0POn1oh7oPOndo`1>Zoof0?_o
n`3koo/0fOok087oPOn1oh7oPOoOooH0nook0?_on`3Ioo/0POn1oh7oPOn1omoo
mP3koo/0nook0=Won`21oh7oPOn1okGo05Z/oo/00?ok0?_on`3koo/0fOol087o
POn1oh7oPOoPoo/00?ok0?_on`3koo/0fOol087oPOn1oh7oPOoPoo/00?ok0?_o
n`3koo/0fOol087oPOn1oh7o]Ol0FZkonP3noo/0nook0?_on`3Ioo`0POn1oh7o
POn1on?onP3noo/0nook0?_on`3Ioo`0POn1oh7oPOn1on?onP3noo/0nook0?_o
n`3Ioo`0POn1oh7oPOnfo`1J[ooj0?con`3koo/0nook0=[onP21oh7oPOn1oh7o
i_oj0?con`3koo/0nook0=[onP21oh7oPOn1oh7oi_oj0?con`3koo/0nook0=[o
nP21oh7oPOn1okSo05ZaooT0n_ok0?_on`3koo/0f_oj087oPOn1oh7oPOoYooT0
n_ok0?_on`3koo/0f_oj087oPOn1oh7oPOoYooT0n_ok0?_on`3koo/0f_oj087o
POn1oh7o^Ol0F[;on@3hoo/0nook0?_on`3JooX0POn1oh7oPOn1on_on@3hoo/0
nook0?_on`3JooX0POn1oh7oPOn1on_on@3hoo/0nook0?_on`3JooX0POn1oh7o
POnjo`1J]?oi0?Gon`3koo/0nook0=[onP21oh7oPOn1oh7ok_oi0?Gon`3koo/0
nook0=[onP21oh7oPOn1oh7ok_oi0?Gon`3koo/0nook0=[onP21oh7oPOn1ok_o
05ZfooT0l_ok0?_on`3kooH0g_oj087oPOn1oh7oPOobooT0l_ok0?_on`3kooH0
g_oj087oPOn1oh7oPOobooT0l_ok0?_on`3kooH0g_oj087oPOn1oh7o_Ol0F[Oo
nP3_oo/0nook0?_om`3MooX0POn1oh7oPOn1ooConP3_oo/0nook0?_om`3MooX0
POn1oh7oPOn1ooConP3_oo/0nook0?_om`3MooX0POn1oh7oPOnno`1J_Ooe0>go
n`3koo/0nook0=Wom`21oh7oPOn1oh7oo_oe0>gon`3koo/0nook0=Wom`21oh7o
POn1oh7oo_oe0>gon`3koo/0nook0=Wom`21oh7oPOn1ol;o05K2oo80j_ok0?_o
n`3koo/0f?oe087oPOn1oh7oQoob0>[on`3koo/0nook0=Som@21oh7oPOn1ohOo
lP3Zoo/0nook0?_on`3HooD0POn1oh7oPOo6o`1Faoo_0>Oon`3koo/0nook0=So
lP21oh7oPOn1oi3ok`3Woo/0nook0?_on`3Hoo80POn1oh7oPOn@onl0iook0?_o
n`3koo/0f?ob087oPOn1oh7ob_l0E/Ool@3Too/0nook0?_on`3Goo@0POn1oh7o
POn@oo40i?ok0?_on`3koo/0eood087oPOn1oh7oT?oa0>Con`3koo/0nook0=Oo
m021oh7oPOn1ol[o05K7oo40hook0?_on`3koo/0f?od087oPOn1oh7oT?oa0>?o
n`3koo/0nook0=Som021oh7oPOn1oi3ol@3Soo/0nook0?_on`3Hoo@0POn1oh7o
POo:o`1Faooi0=[on`3koo/0nook0=?on`21oh7oPOn1ohoon@3Joo/0nook0?_o
n`3Coo/0POn1oh7oPOn?ooT0f_ok0?_on`3koo/0dook087oPOn1oh7obOl0:X40
W021oh7oPOn1oo?oP@2L087oPOn1oh7olon109`0POn1oh7oPOoco`0ZP@2L087o
POn1oh7olon109`0POn1oh7oPOocoh40W021oh7oPOn1oo?o02Z109`0POn1oh7o
POocoh40W021oh7oPOn1oo?oP@2L087oPOn1oh7olol0:X40W021oh7oPOn1oo?o
P@2L087oPOn1oh7olon109`0POn1oh7oPOoco`1>X?ok0?[on`3koo/0nook087o
POn1oh7oPOnioo/0n_ok0?_on`3koo/0POn1oh7oPOn1okWon`3joo/0nook0?_o
n`21oh7oPOn1oi[o05ZRo`800?ok0?[on`3koo/0nook087oPOn1oh7oPOnlo`80
0?ok0?[on`3koo/0nook087oPOn1oh7oPOnlo`800?ok0?[on`3koo/0nook087o
POn1oh7oVol0FZ?oo@00oo/0n_ok0?_on`3koo/0POn1oh7oPOn1okkoo@00oo/0
n_ok0?_on`3koo/0POn1oh7oPOn1okkoo@00oo/0n_ok0?_on`3koo/0POn1oh7o
POnLo`1JY?ok003on`3joo/0nook0?_on`21oh7oPOn1oh7o`?ok003on`3joo/0
nook0?_on`21oh7oPOn1oh7o`?ok003on`3joo/0nook0?_on`21oh7oPOn1oigo
05ZUoo/0o_ok0?[on`3koo/0nook087oPOn1oh7oPOo2oo/0o_ok0?[on`3koo/0
nook087oPOn1oh7oPOo2oo/0o_ok0?[on`3koo/0nook087oPOn1oh7oW_l0FZKo
n`3loo/0n_ok0?_on`3koo/0POn1oh7oPOn1olCon`3loo/0n_ok0?_on`3koo/0
POn1oh7oPOn1olCon`3loo/0n_ok0?_on`3koo/0POn1oh7oPOnOo`1JYook0?[o
n`3joo/0nook0?_on`21oh7oPOn1oh7oa_ok0?[on`3joo/0nook0?_on`21oh7o
POn1oh7oa_ok0?[on`3joo/0nook0?_on`21oh7oPOn1oj3o05ZXoo/0n?ok0?[o
n`3koo/0nook087oPOn1oh7oPOo8oo/0n?ok0?[on`3koo/0nook087oPOn1oh7o
POo8oo/0n?ok0?[on`3koo/0nook087oPOn1oh7oXOl0FZWon`3foo/0n_ok0?_o
n`3koo/0POn1oh7oPOn1ol[on`3foo/0n_ok0?_on`3koo/0POn1oh7oPOn1ol[o
n`3foo/0n_ok0?_on`3koo/0POn1oh7oPOnRo`1JZ_ok0?Con`3joo/0nook0?_o
n`21oh7oPOn1oh7oc?ok0?Con`3joo/0nook0?_on`21oh7oPOn1oh7oc?ok0?Co
n`3joo/0nook0?_on`21oh7oPOn1oj?o05Z[oo/0l_ok0?[on`3koo/0nook087o
POn1oh7oPOo>oo/0l_ok0?[on`3koo/0nook087oPOn1oh7oPOo>oo/0l_ok0?[o
n`3koo/0nook087oPOn1oh7oY?l0FZcon`3`oo/0n_ok0?_on`3koo/0POn1oh7o
POn1om3on`3`oo/0n_ok0?_on`3koo/0POn1oh7oPOn1om3on`3`oo/0n_ok0?_o
n`3koo/0POn1oh7oPOnUo`1J[Ook0>kon`3joo/0nook0?_on`21oh7oPOn1oh7o
d_ok0>kon`3joo/0nook0?_on`21oh7oPOn1oh7od_ok0>kon`3joo/0nook0?_o
n`21oh7oPOn1ojKo05Z^oo/0k?ok0?[on`3koo/0nook087oPOn1oh7oPOoDoo/0
k?ok0?[on`3koo/0nook087oPOn1oh7oPOoDoo/0k?ok0?[on`3koo/0nook087o
POn1oh7oYol0FZoon`3Zoo/0n_ok0?_on`3koo/0POn1oh7oPOn1omKon`3Zoo/0
n_ok0?_on`3koo/0POn1oh7oPOn1omKon`3Zoo/0n_ok0?_on`3koo/0POn1oh7o
POnXo`1J/?ok0>Son`3joo/0nook0?_on`21oh7oPOn1oh7of?ok0>Son`3joo/0
nook0?_on`21oh7oPOn1oh7of?ok0>Son`3joo/0nook0?_on`21oh7oPOn1ojWo
05Zaoo/0i_ok0?[on`3koo/0nook087oPOn1oh7oPOoJoo/0i_ok0?[on`3koo/0
nook087oPOn1oh7oPOoJoo/0i_ok0?[on`3koo/0nook087oPOn1oh7oZ_l0F[;o
n`3Too/0n_ok0?_on`3koo/0POn1oh7oPOn1omcon`3Too/0n_ok0?_on`3koo/0
POn1oh7oPOn1omcon`3Too/0n_ok0?_on`3koo/0POn1oh7oPOn[o`1J/ook0>;o
n`3joo/0nook0?_on`21oh7oPOn1oh7og_ok0>;on`3joo/0nook0?_on`21oh7o
POn1oh7og_ok0>;on`3joo/0nook0?_on`21oh7oPOn1ojco05Zdoo/0h?ok0?[o
n`3koo/0nook087oPOn1oh7oPOoPoo/0h?ok0?[on`3koo/0nook087oPOn1oh7o
POoPoo/0h?ok0?[on`3koo/0nook087oPOn1oh7o[Ol0F[Gon`3Noo/0n_ok0?_o
n`3koo/0POn1oh7oPOn1on;on`3Noo/0n_ok0?_on`3koo/0POn1oh7oPOn1on;o
n`3Noo/0n_ok0?_on`3koo/0POn1oh7oPOn^o`1J]_ok0=con`3joo/0nook0?_o
n`21oh7oPOn1oh7oi?ok0=con`3joo/0nook0?_on`21oh7oPOn1oh7oi?ok0=co
n`3joo/0nook0?_on`21oh7oPOn1ojoo05Zgoo/0f_ok0?[on`3koo/0nook087o
POn1oh7oPOoVoo/0f_ok0?[on`3koo/0nook087oPOn1oh7oPOoVoo/0f_ok0?[o
n`3koo/0nook087oPOn1oh7o/?l0F[Son`3Hoo/0n_ok0?_on`3koo/0POn1oh7o
POn1onSon`3Hoo/0n_ok0?_on`3koo/0POn1oh7oPOn1onSon`3Hoo/0n_ok0?_o
n`3koo/0POn1oh7oPOnao`1J^Ook0=Kon`3joo/0nook0?_on`21oh7oPOn1oh7o
j_ok0=Kon`3joo/0nook0?_on`21oh7oPOn1oh7oj_ok0=Kon`3joo/0nook0?_o
n`21oh7oPOn1ok;o05Zjoo/0e?ok0?[on`3koo/0nook087oPOn1oh7oPOo/oo/0
e?ok0?[on`3koo/0nook087oPOn1oh7oPOo/oo/0e?ok0?[on`3koo/0nook087o
POn1oh7o/ol0F[_on`3Boo/0n_ok0?_on`3koo/0POn1oh7oPOn1onkon`3Boo/0
n_ok0?_on`3koo/0POn1oh7oPOn1onkon`3Boo/0n_ok0?_on`3koo/0POn1oh7o
POndo`1J_?ok0=3on`3joo/0nook0?_on`21oh7oPOn1oh7ol?ok0=3on`3joo/0
nook0?_on`21oh7oPOn1oh7ol?ok0=3on`3joo/0nook0?_on`21oh7oPOn1okGo
05Zmoo/0c_ok0?[on`3koo/0nook087oPOn1oh7oPOoboo/0c_ok0?[on`3koo/0
nook087oPOn1oh7oPOoboo/0c_ok0?[on`3koo/0nook087oPOn1oh7o]_l0F[ko
n`3<oo/0n_ok0?_on`3koo/0POn1oh7oPOn1ooCon`3<oo/0n_ok0?_on`3koo/0
POn1oh7oPOn1ooCon`3<oo/0n_ok0?_on`3koo/0POn1oh7oPOngo`1J_ook0<[o
n`3joo/0nook0?_on`21oh7oPOn1oh7om_ok0<[on`3joo/0nook0?_on`21oh7o
POn1oh7om_ok0<[on`3joo/0nook0?_on`21oh7oPOn1okSo05[0oo/0b?ok0?[o
n`3koo/0nook087oPOn1oh7oPOohoo/0b?ok0?[on`3koo/0nook087oPOn1oh7o
POohoo/0b?ok0?[on`3koo/0nook087oPOn1oh7o^Ol0F/7on`36oo/0n_ok0?_o
n`3koo/0POn1oh7oPOn1oo[on`36oo/0n_ok0?_on`3koo/0POn1oh7oPOn1oo[o
n`36oo/0n_ok0?_on`3koo/0POn1oh7oPOnjo`1J`_ok0<Con`3joo/0nook0?_o
n`21oh7oPOn1oh7oo?ok0<Con`3joo/0nook0?_on`21oh7oPOn1oh7oo?ok0<Co
n`3joo/0nook0?_on`21oh7oPOn1ok_o05[3oo/0`_ok0?[on`3koo/0nook087o
POn1oh7oPOonoo/0`_ok0?[on`3koo/0nook087oPOn1oh7oPOonoo/0`_ok0?[o
n`3koo/0nook087oPOn1oh7o_?l0F/Con`30oo/0n_ok0?_on`3koo/0POn1oh7o
POn1o`3on`30oo/0n_ok0?_on`3koo/0POn1oh7oPOn1o`3on`30oo/0n_ok0?_o
n`3koo/0POn1oh7oPOnmo`1FaOok0;kon`3joo/0nook0?_on`21oh7oPOn1oh;o
n`2noo/0n_ok0?_on`3koo/0POn1oh7oPOn2oo/0__ok0?[on`3koo/0nook087o
POn1oh7o__l0E/Kon`2loo/0n_ok0?_on`3koo/0POn1oh7oPOn4oo/0_?ok0?[o
n`3koo/0nook087oPOn1oh7oQ?ok0;con`3joo/0nook0?_on`21oh7oPOn1okoo
05K7oo/0^_ok0?[on`3koo/0nook087oPOn1oh7oQ_ok0;[on`3joo/0nook0?_o
n`21oh7oPOn1ohKon`2joo/0n_ok0?_on`3koo/0POn1oh7oPOo0o`1Fb?ok0;So
n`3joo/0nook0?_on`21oh7oPOn1ohSon`2hoo/0n_ok0?_on`3koo/0POn1oh7o
POn8oo/0^?ok0?[on`3koo/0nook087oPOn1oh7o`Ol0E/Won`2foo/0n_ok0?_o
n`3koo/0POn1oh7oPOn:oo/0]_ok0?[on`3koo/0nook087oPOn1oh7oR_ok0;Ko
n`3joo/0nook0?_on`21oh7oPOn1ol;o05K:oo/0]?ok0?[on`3koo/0nook087o
POn1oh7oS?ok0;Con`3joo/0nook0?_on`21oh7oPOn1ohcon`2doo/0n_ok0?_o
n`3koo/0POn1oh7oPOo3o`1Fbook0;;on`3joo/0nook0?_on`21oh7oPOn1ohko
n`2boo/0n_ok0?_on`3koo/0POn1oh7oPOn>oo/0/_ok0?[on`3koo/0nook087o
POn1oh7oa?l0E/con`2`oo/0n_ok0?_on`3koo/0POn1oh7oPOn@oo/0/?ok0?[o
n`3koo/0nook087oPOn1oh7oT?ok0;3on`3joo/0nook0?_on`21oh7oPOn1olGo
05K=oo/0[_ok0?[on`3koo/0nook087oPOn1oh7oT_ok0:kon`3joo/0nook0?_o
n`21oh7oPOn1oi;on`2^oo/0n_ok0?_on`3koo/0POn1oh7oPOo6o`1Fc_ok0:co
n`3joo/0nook0?_on`21oh7oPOn1oiCon`2/oo/0n_ok0?_on`3koo/0POn1oh7o
POnDoo/0[?ok0?[on`3koo/0nook087oPOn1oh7oaol0E/oon`2Zoo/0n_ok0?_o
n`3koo/0POn1oh7oPOnFoo/0Z_ok0?[on`3koo/0nook087oPOn1oh7oU_ok0:[o
n`3joo/0nook0?_on`21oh7oPOn1olSo05K@oo/0Z?ok0?[on`3koo/0nook087o
POn1oh7oV?ok0:Son`3joo/0nook0?_on`21oh7oPOn1oiSon`2Xoo/0n_ok0?_o
n`3koo/0POn1oh7oPOo9o`1FdOok0:Kon`3joo/0nook0?_on`21oh7oPOn1oi[o
n`2Voo/0n_ok0?_on`3koo/0POn1oh7oPOnJoo/0Y_ok0?[on`3koo/0nook087o
POn1oh7ob_l0E];on`2Too/0n_ok0?_on`3koo/0POn1oh7oPOnLoo/0Y?ok0?[o
n`3koo/0nook087oPOn1oh7oW?ok0:Con`3joo/0nook0?_on`21oh7oPOn1ol_o
05KCoo/0X_ok0?[on`3koo/0nook087oPOn1oh7oW_ok0:;on`3joo/0nook0?_o
n`21oh7oPOn1oikon`2Roo/0n_ok0?_on`3koo/0POn1oh7oPOo<o`1Fe?ok0:3o
n`3joo/0nook0?_on`21oh7oPOn1oj3on`2Poo/0n_ok0?_on`3koo/0POn1oh7o
POnPoo/0X?ok0?[on`3koo/0nook087oPOn1oh7ocOl0E]Gon`2Noo/0n_ok0?_o
n`3koo/0POn1oh7oPOnRoo/0W_ok0?[on`3koo/0nook087oPOn1oh7oX_ok09ko
n`3joo/0nook0?_on`21oh7oPOn1olko05KFoo/0W?ok0?[on`3koo/0nook087o
POn1oh7oY?ok09con`3joo/0nook0?_on`21oh7oPOn1ojCon`2Loo/0n_ok0?_o
n`3koo/0POn1oh7oPOo?o`1Feook09[on`3joo/0nook0?_on`21oh7oPOn1ojKo
n`2Joo/0n_ok0?_on`3koo/0POn1oh7oPOnVoo/0V_ok0?[on`3koo/0nook087o
POn1oh7od?l0E]Son`2Hoo/0n_ok0?_on`3koo/0POn1oh7oPOnXoo/0V?ok0?[o
n`3koo/0nook087oPOn1oh7oZ?ok09Son`3joo/0nook0?_on`21oh7oPOn1om7o
05KIoo/0U_ok0?[on`3koo/0nook087oPOn1oh7oZ_ok09Kon`3joo/0nook0?_o
n`21oh7oPOn1oj[on`2Foo/0n_ok0?_on`3koo/0POn1oh7oPOoBo`1Ff_ok09Co
n`3joo/0nook0?_on`21oh7oPOn1ojcon`2Doo/0n_ok0?_on`3koo/0POn1oh7o
POn/oo/0U?ok0?[on`3koo/0nook087oPOn1oh7odol0E]_on`2Boo/0n_ok0?_o
n`3koo/0POn1oh7oPOn^oo/0T_ok0?[on`3koo/0nook087oPOn1oh7o[_ok09;o
n`3joo/0nook0?_on`21oh7oPOn1omCo05KLoo/0T?ok0?[on`3koo/0nook087o
POn1oh7o/?ok093on`3joo/0nook0?_on`21oh7oPOn1ok3on`2@oo/0n_ok0?_o
n`3koo/0POn1oh7oPOoEo`1FgOok08kon`3joo/0nook0?_on`21oh7oPOn1ok;o
n`2>oo/0n_ok0?_on`3koo/0POn1oh7oPOnboo/0S_ok0?[on`3koo/0nook087o
POn1oh7oe_l0E]kon`2<oo/0n_ok0?_on`3koo/0POn1oh7oPOndoo/0S?ok0?[o
n`3koo/0nook087oPOn1oh7o]?ok08con`3joo/0nook0?_on`21oh7oPOn1omOo
05KOoo/0R_ok0?[on`3koo/0nook087oPOn1oh7o]_ok08[on`3joo/0nook0?_o
n`21oh7oPOn1okKon`2:oo/0n_ok0?_on`3koo/0POn1oh7oPOoHo`1Fh?ok08So
n`3joo/0nook0?_on`21oh7oPOn1okSon`28oo/0n_ok0?_on`3koo/0POn1oh7o
POnhoo/0R?ok0?[on`3koo/0nook087oPOn1oh7ofOl0E^7on`26oo/0n_ok0?_o
n`3koo/0POn1oh7oPOnjoo/0Q_ok0?[on`3koo/0nook087oPOn1oh7o^_ok08Ko
n`3joo/0nook0?_on`21oh7oPOn1om[o05KRoo/0Q?ok0?[on`3koo/0nook087o
POn1oh7o_?ok08Con`3joo/0nook0?_on`21oh7oPOn1okcon`24oo/0n_ok0?_o
n`3koo/0POn1oh7oPOoKo`1Fhook08;on`3joo/0nook0?_on`21oh7oPOn1okko
n`22oo/0n_ok0?_on`3koo/0POn1oh7oPOnnoo/0P_ok0?[on`3koo/0nook087o
POn1oh7og?l0G>Con`21o`3on`3joo/0nook0?_on`21oh7oPOn1ol3on`21o`3o
n`3joo/0nook0?_on`21oh7oPOn1ol3on`21o`3on`3joo/0nook0?_on`21oh7o
POn1omgo05cUoo/0POonoo/0n_ok0?_on`3koo/0POn1oh7oPOo2oo/0POonoo/0
n_ok0?_on`3koo/0POn1oh7oPOo2oo/0POonoo/0n_ok0?_on`3koo/0POn1oh7o
POoNo`1Li_ok087oo?ok0?[on`3koo/0nook087oPOn1oh7oa?ok087oo?ok0?[o
n`3koo/0nook087oPOn1oh7oa?ok087oo?ok0?[on`3koo/0nook087oPOn1oh7o
gol0G>Oon`21oo[on`3joo/0nook0?_on`21oh7oPOn1olKon`21oo[on`3joo/0
nook0?_on`21oh7oPOn1olKon`21oo[on`3joo/0nook0?_on`21oh7oPOn1on3o
05cXoo/0POohoo/0n_ok0?_on`3koo/0POn1oh7oPOo8oo/0POohoo/0n_ok0?_o
n`3koo/0POn1oh7oPOo8oo/0POohoo/0n_ok0?_on`3koo/0POn1oh7oPOoQo`1L
jOok087om_ok0?[on`3koo/0nook087oPOn1oh7ob_ok087om_ok0?[on`3koo/0
nook087oPOn1oh7ob_ok087om_ok0?[on`3koo/0nook087oPOn1oh7oh_l0G>[o
n`21ooCon`3joo/0nook0?_on`21oh7oPOn1olcon`21ooCon`3joo/0nook0?_o
n`21oh7oPOn1olcon`21ooCon`3joo/0nook0?_on`21oh7oPOn1on?o05c[oo/0
POoboo/0n_ok0?_on`3koo/0POn1oh7oPOo>oo/0POoboo/0n_ok0?_on`3koo/0
POn1oh7oPOo>oo/0POoboo/0n_ok0?_on`3koo/0POn1oh7oPOoTo`1Lk?ok087o
l?ok0?[on`3koo/0nook087oPOn1oh7od?ok087ol?ok0?[on`3koo/0nook087o
POn1oh7od?ok087ol?ok0?[on`3koo/0nook087oPOn1oh7oiOl0G>gon`21onko
n`3joo/0nook0?_on`21oh7oPOn1om;on`21onkon`3joo/0nook0?_on`21oh7o
POn1om;on`21onkon`3joo/0nook0?_on`21oh7oPOn1onKo05c^oo/0POo/oo/0
n_ok0?_on`3koo/0POn1oh7oPOoDoo/0POo/oo/0n_ok0?_on`3koo/0POn1oh7o
POoDoo/0POo/oo/0n_ok0?_on`3koo/0POn1oh7oPOoWo`1Lkook087oj_ok0?[o
n`3koo/0nook087oPOn1oh7oe_ok087oj_ok0?[on`3koo/0nook087oPOn1oh7o
e_ok087oj_ok0?[on`3koo/0nook087oPOn1oh7oj?l0G?3on`21onSon`3joo/0
nook0?_on`21oh7oPOn1omSon`21onSon`3joo/0nook0?_on`21oh7oPOn1omSo
n`21onSon`3joo/0nook0?_on`21oh7oPOn1onWo05caoo/0POoVoo/0n_ok0?_o
n`3koo/0POn1oh7oPOoJoo/0POoVoo/0n_ok0?_on`3koo/0POn1oh7oPOoJoo/0
POoVoo/0n_ok0?_on`3koo/0POn1oh7oPOoZo`1Ll_ok087oi?ok0?[on`3koo/0
nook087oPOn1oh7og?ok087oi?ok0?[on`3koo/0nook087oPOn1oh7og?ok087o
i?ok0?[on`3koo/0nook087oPOn1oh7ojol0IO?on`2:o`400=_on`3joo/0nook
0?_on`21oh7oPOn1omkon`2:o`400=_on`3joo/0nook0?_on`21oh7oPOn1omko
n`2:o`400=_on`3joo/0nook0?_on`21oh7oPOn1onco06;doo/0R_om0=_on`3j
oo/0nook0?_on`21oh7oPOn1on3on`2:ood0fook0?[on`3koo/0nook087oPOn1
oh7oh?ok08[oo@3Koo/0n_ok0?_on`3koo/0POn1oh7oPOo]o`1RmOok08[on`3K
oo/0n_ok0?_on`3koo/0POn1oh7oPOoRoo/0R_ok0=_on`3joo/0nook0?_on`21
oh7oPOn1on;on`2:oo/0fook0?[on`3koo/0nook087oPOn1oh7ok_l0H_Kon`28
oo/0fook0?[on`3koo/0nook087oPOn1oh7oi?ok08Son`3Koo/0n_ok0?_on`3k
oo/0POn1oh7oPOoToo/0R?ok0=_on`3joo/0nook0?_on`21oh7oPOn1onoo06;g
oo/0Q_ok0=_on`3joo/0nook0?_on`21oh7oPOn1onKon`26oo/0fook0?[on`3k
oo/0nook087oPOn1oh7oi_ok08Kon`3Koo/0n_ok0?_on`3koo/0POn1oh7oPOo`
o`1^n?ok0=oooP2Yoo/0fook0?[on`3koo/0nook087oPOn1oh7oj?ok0=oooP2Y
oo/0fook0?[on`3koo/0nook087oPOn1oh7oj?ok0=oooP2Yoo/0fook0?[on`3k
oo/0nook087oPOn1oh7olOl0K_Won`3Ooo`0ZOok0=_on`3joo/0nook0?_on`21
oh7oPOn1on[on`3Ooo`0ZOok0=_on`3joo/0nook0?_on`21oh7oPOn1on[on`3O
oo`0ZOok0=_on`3joo/0nook0?_on`21oh7oPOn1oo;o06kjoo/0gool0:Oon`3K
oo/0n_ok0?_on`3koo/0POn1oh7oPOo/oo/0gool0:Oon`3Koo/0n_ok0?_on`3k
oo/0POn1oh7oPOo/oo/0gool0:Oon`3Koo/0n_ok0?_on`3koo/0POn1oh7oPOoc
o`1^nook0=ooo02Uoo`0f_ok0?[on`3koo/0nook087oPOn1oh7ok_ok0=ooo02U
oo`0f_ok0?[on`3koo/0nook087oPOn1oh7ok_ok0=ooo02Uoo`0f_ok0?[on`3k
oo/0nook087oPOn1oh7om?l0K_con`3Ooo`0Xool0=[on`3joo/0nook0?_on`21
oh7oPOn1oo3on`3Ooo`0Xool0=[on`3joo/0nook0?_on`21oh7oPOn1oo3on`3O
oo`0Xool0=[on`3joo/0nook0?_on`21oh7oPOn1ooGo06kmoo/0gool0:7oo03J
oo/0n_ok0?_on`3koo/0POn1oh7oPOoboo/0gool0:7oo03Joo/0n_ok0?_on`3k
oo/0POn1oh7oPOoboo/0gool0:7oo03Joo/0n_ok0?_on`3koo/0POn1oh7oPOof
o`1^oOol0=ooo02Ooo`0f_ok0?[on`3koo/0noom087oPOn1oh7olOol0=ooo02O
oo`0f_ok0?[on`3koo/0noom087oPOn1oh7olOol0=ooo02Ooo`0f_ok0?[on`3k
oo/0noom087oPOn1oh7omOl0LOkoo03Ooo`0WOol0=[on`3joo/0nook0?_o0@00
POn1oh7oPOoaoo`0gool09goo03Joo/0n_ok0?_on`3ko`40087oPOn1oh7olOol
0=ooo02Moo`0f_ok0?[on`3koo/0nol10021oh7oPOn1ooCo06<1oool0=ooo02L
oo/0f_ok0?[on`3koo/0POn1oh7oPOo[oo`0gool09con`3Joo/0n_ok0?_on`21
oh7oPOn1on_oo03Ooo`0W?ok0=[on`3joo/0nook087oPOn1oh7okOl0HP3on`3O
oo`0Vook0=[on`3joo/0nook087oPOn1oh7okOok0=ooo02Koo/0f_ok0?[on`3k
oo/0POn1oh7oPOo]oo/0gool09_on`3Joo/0n_ok0?_on`21oh7oPOn1onko063k
0=ooo02Ioo/0f_ok0?[on`3koo/0POn1oh7oPOo_oo/0gool09Won`3Joo/0n_ok
0?_on`21oh7oPOn1onoon`3Ooo`0VOok0=[on`3joo/0nook087oPOn1oh7okol0
H?`0gool09Oon`3Joo/0n_ok0?_on`21oh7oPOn1oo3oo03Ooo`0Uook0=[on`3j
oo/0nook087oPOn1oh7ol?ol0=ooo02Goo/0f_ok0?[on`3koo/0POn1oh7oPOo`
o`1Po@3Ooo`0UOok0=[on`3joo/0nook087oPOn1oh7olOom0=ooo02Eoo/0f_ok
0?[on`3koo/0POn1oh7oPOoaood0gool09Gon`3Joo/0n_ok0?_on`21oh7oPOn1
oo7o063n0=ooo02Coo/0f_ok0?[on`3koo/0POn1oh7oPOobooh0gool09?on`3J
oo/0n_ok0?_on`21oh7oPOn1oo;ooP3Ooo`0Took0=[on`3joo/0nook087oPOn1
oh7ol_l0H`400=ooo02Aoo/0f_ok0?[on`3koo/0POn1oh7oPOoco`400=ooo02A
oo/0f_ok0?[on`3koo/0POn1oh7oPOoco`400=ooo02Aoo/0f_ok0?[on`3koo/0
POn1oh7oPOoco`1P003Ooo`0Sook0=[on`3joo/0nook087oPOn1oh7om?l00=oo
o02?oo/0f_ok0?[on`3koo/0POn1oh7oPOodo`00gool08oon`3Joo/0n_ok0?_o
n`21oh7oPOn1ooCo05KOoo`0SOok0=[on`3joo/0nook087oPOn1oh7odool08go
n`3Joo/0n_ok0?_on`21oh7oPOn1om?oo02=oo/0f_ok0?[on`3koo/0POn1oh7o
POoeo`1Xh?ol08_on`3Joo/0n_ok0?_oo@34ooX0POo`oo`0POn1ojgoo02;oo/0
f_ok0?[on`3kood0a?oj087ol?ol087oPOn]oo`0Rook0=[on`3joo/0noom0<Co
nP21oo3oo021oh7oc_l0Jn7oo029oo/0f_ok0?[on`3ko`400<Gon021oo3oo021
oh7o[_ol08Won`3Joo/0n_ok0?_o0@00aOoh087ol?ol087oPOn^oo`0ROok0=[o
n`3joo/0nol10035ooP0POo`oo`0POn1olko05cRoo`0Qool0=Won`3joo/0`?of
087ol?ol087oPOn_oo`0Qool0=Won`3joo/0`?of087ol?ol087oPOn_oo`0Qool
0=Won`3joo/0`?of087ol?ol087oPOo>o`1Lhool08Goo03Ioo/0n_ok0<7omP21
oo3oo021oh7o/?ol08Goo03Ioo/0n_ok0<7omP21oo3oo021oh7o/?ol08Goo03I
oo/0n_ok0<7omP21oo3oo021oh7oc_l0G>Coo023oo`0fOok0?[on`33oo/0POoZ
oo`0POn1ok7oo023oo`0fOok0?[on`33oo/0POoZoo`0POn1ok7oo023oo`0fOok
0?[on`33oo/0POoZoo`0POn1olko05cUoo`0POol0=Won`3joo/0a?ol087ojOol
087oPOnboo`0POol0=Won`3joo/0a?ol087ojOol087oPOnboo`0POol0=Won`3j
oo/0a?ol087ojOol087oPOo>o`1Ui_ol087o0Oooo03Ioo/0n_ok0<Koo021onSo
o021oh7o/ool087o0Oooo03Ioo/0n_ok0<Koo021onSoo021oh7o/ool087o0Ooo
o03Ioo/0n_ok0<Koo021onSoo021oh7oc_l0H^Ooo021oogoo03Ioo/0n_ok0<Oo
o021onSoo021oh7o]?ol087ooOol0=Won`3joo/0aool087oj?ol087oPOndoo`0
POomoo`0fOok0?[on`37oo`0POoXoo`0POn1olko06;Xoo/0POoloo`0fOok0?[o
n`38oo`0POoXoo`0POn1okGon`21oocoo03Ioo/0n_ok0<Soo021onSoo021oh7o
]Ook087oo?ol0=Won`3joo/0b?ol087oj?ol087oPOo>o`1RjOok087on_ol0=Wo
n`3joo/0bOol087oj?ol087oPOnfoo/0POojoo`0fOok0?[on`39oo`0POoXoo`0
POn1okKon`21oo[oo03Ioo/0n_ok0<Woo021onSoo021oh7oc_l0H^[on`21ooWo
n`3Ioo/0n_ok0<[oo021onSoo021oh7o]ook087onOok0=Won`3joo/0b_ol087o
j?ol087oPOngoo/0POoioo/0fOok0?[on`3:oo`0POoXoo`0POn1olko09S[oo/0
POogoo/0fOok0?[on`3;oo`0k_oi0>Woo03UooX0jOoj0>konP3loo`0POn1okSo
n`21ooOon`3Ioo/0n_ok0<_oo03^ooT0jOol0>GonP3YooX0k_oj0?coo021oh7o
^?ok087omook0=Won`3joo/0bool0>kon@3Yoo`0iOoj0>WonP3^ooX0o?ol087o
POo>o`2`jool087omOok0=Won`3jood0c_o`0?Wol`3foo`0o_oj0>Oom@3foo`0
oOog0?;omP3noo`0POn1okSoo021ooGon`3Ioo/0n_om0<kol03ioo<0m_ol0?ko
nP3WooD0m_ol0?gom`3booH0o_ol087oPOnhoo`0POoeoo/0fOok0?[oo@3>oo00
nOoc0?Koo03nooX0iooe0?Koo03mooL0l_of0?koo021oh7oc_l0_>coo021oo?o
n`3Ioo/0n_l1003=oo00n_oa0?Ooo001oooi0>WolP3goo`00Ooom03doo@00Ooo
o021oh7o^Ool087olook0=Won`3jo`400<gol03joo40mool007oooT0jOob0?Oo
o001oood0?Com001oool087oPOnioo`0POocoo/0fOok0?[o0@00cOo`0?[ol@3g
oo`00Ooon@3Yoo80mool007ooo@0m?od007ooo`0POn1olko0:C]oo`0POoaoo/0
fOok0<Gol03konl0n?ol003on03Zoo00n?ol003ol`3eoo800?ol087oPOnjoo`0
POoaoo/0fOok0<Gol03konl0n?ol003on03Zoo00n?ol003ol`3eoo800?ol087o
POnjoo`0POoaoo/0fOok0<Gol03konl0n?ol003on03Zoo00n?ol003ol`3eoo80
0?ol087oPOo>o`3Dk_ol087okook0=Won`36oo00o?oj0?conP3hooL0oOl00>_o
nP3looX0nOol003oo@3mooX0mooj0?coo@00oo`0POn1ok_oo021onoon`3Ioo/0
a_o`0?conP3looX0n?og0?go003[ooX0o?oj0?Woo000ood0oOoj0?OonP3lood0
0?ol087oPOnkoo`0POo_oo/0fOok0<Kol03looX0o?oj0?Som`3mo`00jooj0?co
nP3ioo`00?om0?gonP3gooX0o?om003oo021oh7oc_l0/>ooo021ongon`3Ioo/0
`ool0?Coo03hoo/0nOoi0>Con`3ioo`0nOoi0?Woo03hoo/0n?oi087oPOnloo`0
POo]oo/0fOok0<?oo03doo`0n?ok0?Won@3Too/0nOol0?Won@3ioo`0n?ok0?So
n@21oh7o_?ol087okOok0=Won`33oo`0m?ol0?Son`3iooT0i?ok0?Woo03iooT0
nOol0?Son`3hooT0POn1olko0;3`oo`0POo[oo/0fOok0<Coo03eoo`0m_ol0?Wo
nP3Too/0n?ok0?[onP3hoo/0nOol0?KonP21oh7o_Ool087ojook0=Won`34oo`0
mOol0?Koo03iooX0i?ok0?Son`3jooX0n?ok0?Woo03fooX0POn1okgoo021on_o
n`3Ioo/0a?ol0?Goo03foo`0nOoj0>Con`3hoo/0n_oj0?Son`3ioo`0m_oj087o
POo>o`2`lOol087ojOol0=Son`35oo`0mOol0?Koo03ioo/0hool0?Koo03jooX0
mool0?[on`3fooX0POn1okkoo021onWoo03Hoo/0aOol0?Goo03foo`0nOok0>?o
o03foo`0n_oj0?Ooo03joo/0m_oj087oPOnnoo`0POoYoo`0f?ok0<Goo03eoo`0
m_ol0?Won`3Soo`0m_ol0?[onP3goo`0n_ok0?KonP21oh7oc_l0/?;oo021onOo
o03^o`00k?ok0<Koo03Uoo`0nOok0>Coo03eoo`0n_ok0?Koo03joo`0m?ok087o
POnooo`0POoWoo`0k_l00>con`36oo`0iOol0?Won`3Too`0mOol0?[on`3foo`0
n_ol0?Con`21oh7o_ool087oiool0>ko003/oo/0a_ol0>Goo03ioo/0i?ol0?Go
o03joo/0m_ol0?[oo03doo/0POn1olko0;3coo`0POoUoo`0lOom0>con`37oo`0
iOol0?Won`3Too`0m?ol0?_on`3foo`0n_ol0?Con`21oh7o`?ol087oiOol0?7o
o@3/oo/0aool0>Goo03ioo/0i?ol0?Coo03koo/0m_ol0?[oo03doo/0POn1ol3o
o021onGoo03aood0k?ok0<Ooo03Uoo`0nOok0>Coo03doo`0nook0?Koo03joo`0
m?ok087oPOo>o`2`m?ol087ohool0?GonP3[oo/0b?ol0>Goo03ioo`0hool0?Co
o03koo`0mOol0?_oo03boo`0POn1ol7oo021on?oo03eooX0jook0<Soo03Uoo`0
nOol0>?oo03doo`0nool0?Goo03koo`0l_ol087oPOo1oo`0POoSoo`0mOoj0>_o
n`38oo`0iOol0?Woo03Soo`0m?ol0?_oo03eoo`0nool0?;oo021oh7oc_l0/?Go
o021on7oo03gooP0jook0<Woo03Uoo`0nOol0>Coo03coo`0nool0?Goo03koo`0
l_ol087oPOo2oo`0POoQoo`0mooh0>_on`39oo`0iOol0?Woo03Too`0lool0?_o
o03eoo`0nool0?;oo021oh7o`_ol087ohOol0?Oon03[oo/0bOol0>Goo03ioo`0
i?ol0??oo03koo`0mOol0?_oo03boo`0POn1olko0:Cfoo`0POoOoo`0n_of0>[o
n`3:oo`0iooj0?Woo03TonT0nool0?Goo03koo`0l_ol087oPOo3oo`0POoOoo`0
n_of0>[on`3:oo`0iooj0?Woo03TonT0nool0?Goo03koo`0l_ol087oPOo3oo`0
POoOoo`0n_of0>[on`3:oo`0iooj0?Woo03TonT0nool0?Goo03koo`0l_ol087o
POo>o`2Tmook087og_ol0?com03Zoo/0bool0>_omP3ioo`0i?oY0?_oo03eoo`0
nool0?;oo021oh7oa?ok087og_ol0?com03Zoo/0bool0>_omP3ioo`0i?oY0?_o
o03eoo`0nool0?;oo021oh7oa?ok087og_ol0?com03Zoo/0bool0>_omP3ioo`0
i?oY0?_oo03eoo`0nool0?;oo021oh7oc_l0YoSon`21omcoo001ooob0>Woo@3:
oo`0k_oc0?Woo03TonT0nool0?Goo03koo`0l_ol087oPOo5oo/0POoLoo`00Ooo
lP3Yood0b_ol0>kol`3ioo`0i?oY0?_oo03eoo`0nool0?;oo021oh7oaOok087o
g?ol007ooo80jOom0<[oo03^oo<0nOol0>Coj@3koo`0mOol0?_oo03boo`0POn1
olko09_ioo/0POoJon/0jOl10039oo`0lOo`0?Woo03TonT0nool0?Goo03koo`0
l_ol087oPOo6oo/0POoJon/0jOl10039oo`0lOo`0?Woo03TonT0nool0?Goo03k
oo`0l_ol087oPOo6oo/0POoJon/0jOl10039oo`0lOo`0?Woo03TonT0nool0?Go
o03koo`0l_ol087oPOo>o`2U003koo/0POoHon`0[ool0?;omP01oool0?Woo03T
oo`0j?ol0?Goo03koo`0l_ol087oPOo>o`00nook087of?o/0:ooo03booH00Ooo
o03ioo`0i?ol0>Soo03eoo`0nool0?;oo021oh7oc_l00?_on`21omSok02_oo`0
l_of007ooo`0nOol0>Coo03Xoo`0mOol0?_oo03boo`0POn1olko0:D1003moo/0
POoFond0[ool0??on@3koo`0nOol0>Coo03Xoo`0mOol0?_oo03boo`0POn1olko
0@00oOok087oe_o]0:ooo03cooT0nool0?Woo03Too`0j?ol0?Goo03koo`0l_ol
087oPOo>o`400?gon`21omKok@2_oo`0looi0?_oo03ioo`0i?ol0>Soo03eoo`0
nool0?;oo021oh7oc_l0YOh00Ooon`21omGok02`oo`0m?oj0?Woo03ioo`0i?ol
0>Soo03eoo`0nool0?;oo021oh7oc_on007ooo/0POoEon`0/?ol0?ConP3ioo`0
nOol0>Coo03Xoo`0mOol0?_oo03boo`0POn1olkooP01oook087oeOo/0;3oo03d
ooX0nOol0?Woo03Too`0j?ol0?Goo03koo`0l_ol087oPOo>o`2Fm`21omGoj`2`
oo`0m?ol0?Ooo03ioo`0i?ol0>Soo03eoo`0nool0??on`21oh7oc_og087oeOo[
0;3oo03doo`0mool0?Woo03Too`0j?ol0?Goo03koo`0look087oPOo>ooL0POoE
on/0/?ol0?Coo03goo`0nOol0>Coo03Xoo`0mOol0?_oo03coo/0POn1olko09Kh
087oeOoY0;7oo03eoo/0mool0?Woo03Soo`0jOol0?Goo03joo`0m?ok087oPOo>
ooP0POoEonT0/Ool0?Gon`3goo`0nOol0>?oo03Yoo`0mOol0?[oo03doo/0POn1
olkon021omGoj@2aoo`0mOok0?Ooo03ioo`0hool0>Woo03eoo`0n_ol0?Con`21
oh7oc_l0U_T0POoEonP0/Ool0?Goo03goo/0nOol0>?oo03Yoo`0mOol0?[oo03d
oo/0POn1olkon@21omGoj02aoo`0mOol0?Oon`3ioo`0hool0>Woo03eoo`0n_ol
0?Con`21oh7oc_oi087oeOoX0;7oo03eoo`0mook0?Woo03Soo`0jOol0?Goo03j
oo`0m?ok087oPOo>o`2Rn@21omGoi`2boo`0mOol0?Oon`3ioo`0hook0?Goo03k
oo`0mOol0?[oo03eooX0POn1olkon@21omGoi`2boo`0mOol0?Oon`3ioo`0hook
0?Goo03koo`0mOol0?[oo03eooX0POn1olkon@21omGoi`2boo`0mOol0?Oon`3i
oo`0hook0?Goo03koo`0mOol0?[oo03eooX0POn1olko0:;h087oeooV0;;oo03e
oo`0n?oj0?Woo03Roo/0m_ol0?_oo03eoo`0nOol0?KonP21oh7oc_oh087oeooV
0;;oo03eoo`0n?oj0?Woo03Roo/0m_ol0?_oo03eoo`0nOol0?KonP21oh7oc_oh
087oeooV0;;oo03eoo`0n?oj0?Woo03Roo/0m_ol0?_oo03eoo`0nOol0?KonP21
oh7oc_l0X_L0POoIon@0/ool0?Gon`3jooT0nOol0>;onP3hoo`0n_ol0?Goo03i
oo/0n?oi087oPOo>ooL0POoIon@0/ool0?Gon`3jooT0nOol0>;onP3hoo`0n_ol
0?Goo03ioo/0n?oi087oPOo>ooL0POoIon@0/ool0?Gon`3jooT0nOol0>;onP3h
oo`0n_ol0?Goo03ioo/0n?oi087oPOo>o`2^m`21omWoi02coo`0m?ok0?gom`3i
oo`0hOoi0?_on`3joo`0mOol0?SonP3lood00?ol087oPOo>ooL0POoIon@0/ool
0?Con`3mooL0nOol0>7on@3koo/0n_ol0?Goo03hooX0o?om003oo021oh7oc_og
087ofOoT0;?oo03doo/0oOog0?Woo03QooT0nook0?[oo03eoo`0n?oj0?coo@00
oo`0POn1olko09Kf087ofooS0;?oo03doo<00?ol0?Woo03Ponl0nOol0?Goo03g
oo800?ol087oPOo>ooH0POoKon<0/ool0?Col`00oo`0nOol0>3ok`3ioo`0mOol
0?OolP00oo`0POn1olkomP21om_oh`2coo`0m?oc003oo03ioo`0h?o_0?Woo03e
oo`0moob003oo021oh7oc_l0W?D0POoLon80]?ol0??om@01oook0?[oo03Ooo40
n?ol0?Goo03foo@00Oooo021oh7oc_oe087og?oR0;Coo03cooD00Ooon`3joo`0
gooa0?Soo03eoo`0m_od007ooo`0POn1olkom@21omcohP2doo`0looe007ooo/0
n_ol0=ool@3hoo`0mOol0?Kom001oool087oPOo>o`2Fm@21omgoh@2doo`0l_oh
0?coo03joo`0gOod0?Ooo03eoo`0mOof0?koo021oh7oc_oe087ogOoQ0;Coo03b
ooP0o?ol0?[oo03Moo@0mool0?Goo03eooH0o_ol087oPOo>ooD0POoMon40]?ol
0?;on03loo`0n_ol0=gom03goo`0mOol0?GomP3noo`0POn1olko04kd087og_oP
09ooo033ooT0d?oj087oPOo4oo@0POoNon00Wool0<?on@3@ooX0POn1olCom021
omkoh02Ooo`0`ooi0=3onP21oh7oa?l0=_@0POoOoml0POn1oh7oPOoOoo@0POoO
oml0POn1oh7oPOoOoo@0POoOoml0POn1oh7oPOoOo`0fl`21omgoh@21oh7oPOn1
on3ol`21omgoh@21oh7oPOn1on3ol`21omgoh@21oh7oPOn1on3o03Kc087ofooS
087oPOn1oh7oh?oc087ofooS087oPOn1oh7oh?oc087ofooS087oPOn1oh7oh?l0
=_80POoJon@0POn1oh7oPOoQoo80POoJon@0POn1oh7oPOoQoo80POoJon@0POn1
oh7oPOoQo`0flP21omSoiP21oh7oPOn1on7olP21omSoiP21oh7oPOn1on7olP21
omSoiP21oh7oPOn1on7o03Kd087oe?oX087oPOn1oh7ohOod087oe?oX087oPOn1
oh7ohOod087oe?oX087oPOn1oh7ohOl0=_H0POo@onT0POn1oh7oPOoRooH0POo@
onT0POn1oh7oPOoRooH0POo@onT0POn1oh7oPOoRo`0fn021olcoj`21oh7oPOn1
on;on021olcoj`21oh7oPOn1on;on021olcoj`21oh7oPOn1on;o03Ki087ob_o[
087oPOn1oh7ohooi087ob_o[087oPOn1oh7ohooi087ob_o[087oPOn1oh7ohol0
=_/0POo6ond0POn1oh7oPOoSoo/0POo6ond0POn1oh7oPOoSoo/0POo6ond0POn1
oh7oPOoSo`0fo@21ol;okP21oh7oPOn1onCoo@21ol;okP21oh7oPOn1onCoo@21
ol;okP21oh7oPOn1onCo03T10021okkol021oh7oPOn1onCo0@00POnnoo00POn1
oh7oPOoTo`40087o__o`087oPOn1oh7oi?l0;87o^_oa087oPOn1oh7oPOnNoo40
POn1oh7oPOn1oikol@21oh7oPOn1onGo02b1okSol`21oh7oPOn1oh7oW?oc087o
POn1oh7oPOnLoo<0POn1oh7oPOoUo`0/POneooH0POn1oh7oPOn1oiWomP21oh7o
POn1oh7oVOof087oPOn1oh7oiOl0;87o/oog087oPOn1oh7oPOnHooL0POn1oh7o
POn1oiSom`21oh7oPOn1onKo02b1ok7on@21oh7oPOn1oh7oU_oi087oPOn1oh7o
POnFooT0POn1oh7oPOoVo`0/POn_ooX0POn1oh7oPOn1oiGonP21oh7oPOn1oh7o
UOoj087oPOn1oh7oiol0;87o[Ool087oPOn1oh7oPOnCoo`0POn1oh7oPOn1oi?o
o021oh7oPOn1onOo02b1oj_oo@21oh7oPOn1oh7oT_om087oPOn1oh7oPOnBood0
POn1oh7oPOoXo`0_POnYo`40087oPOn1oh7oPOn@o`40087oPOn1oh7oPOn@o`40
087oPOn1oh7oj?l0;87oYol0087oPOn1oh7oPOn?o`00POn1oh7oPOn1ohoo0021
oh7oPOn1onWo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0
987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnXo`0TPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOnX
o`0TPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1ojSo02B1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOn1oh7oPOn1oh7oZ?l0987oPOn1oh7oPOn1oh7oPOn1
oh7oPOn1oh7oPOn1oh7oPOnXo`00X02o0?l\>"], "NumberedFigure",
  ImageSize->{419, 302},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Figure 9.  Accumulation of far end crosstalk", "Caption"],

Cell["\<\
At each instant in time some portion of the main pulse is coupled \
to the adjacent wire, where it starts propagating to both ends. As the main \
pulse has one direction (here: to the right) and travels with the same speed \
as the crosstalk portions, everything that goes to the far end arrives at the \
same time, while the parts going to the left are distributed in time and see \
the near end only one after the other. This process continues until a \
likewise growing part of the crosstalk starts flowing back to the main wire \
and an equilibrium is reached.\
\>", "Text"],

Cell["\<\
\tNext shown  is the shape of the pulse after having travelled on \
line 1 for about 12m 
(horizontal unit is 4mm, leading edge is to the right):\
\>", "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P00025A000`40O003h00OogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00;Ioo``000aoo`L000Yo
o`@000ioo`@005Uoo``000]oo`D000eoo`@000ioo`@005Yoo``000Yoo`H000eoo`@000ioo`@005io
o`D000ioo`@000ioo`@000ioo`@005eoo`D000Uoo``000]oo`@000ioo`@000Uoo`00]Woo300037oo
1`0027oo20002Woo2000Egoo30002Goo20002Woo20002Woo2000F7oo30002Goo20002Woo20002Woo
2000FWoo2@002Woo20002Woo20002Woo2000FGoo2@001goo30002Goo20002Woo20001goo002gOol3
0006Ool2000?Ool2000:Ool20004Ool2000:Ool20004Ool2001HOol30006Ool20009Ool20004Ool3
0009Ool20004Ool2000:Ool20004Ool2001IOol30006Ool20008Ool30004Ool30009Ool20004Ool2
000:Ool20004Ool2001IOol40004Ool30009Ool20004Ool2000:Ool20004Ool2000:Ool20004Ool2
001HOol40004Ool30007Ool30006Ool20009Ool20004Ool2000:Ool20004Ool20007Ool00;Qoo`<0
01Ioo`8000Uoo`8000Ioo`8000Qoo`8000Ioo`8005Qoo`<000moo`8000Ioo`<000Moo`8000Ioo`80
00Qoo`8000Ioo`8005Uoo`<000ioo`<000Ioo`<000Moo`8000Ioo`8000Qoo`8000Ioo`8005Qoo`80
00Moo`<000Moo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8005Moo`8000Moo`<000Moo`<0
00moo`8000Ioo`8000Qoo`8000Ioo`8000Ioo`00^Goo0`005Goo0P002Goo0P001Woo0P0027oo0P00
1Woo0P00FGoo0`003Goo0P0027oo0P001goo0P001Woo0P0027oo0P001Woo0P00FWoo0`003Goo0P00
27oo0P001goo0P001Woo0P0027oo0P001Woo0P00HWoo0P001goo0P001Woo0P0027oo0P001Woo0P00
27oo0P001Woo0P00HGoo0P0027oo0`003Woo0P001Woo0P0027oo0P001Woo0P001Woo002jOol3000<
Ool<0006Ool20008Ool20006Ool20008Ool2001IOol3000<Ool20008Ool20006Ool20008Ool20006
Ool20008Ool2001JOol3000<Ool20008Ool20006Ool20008Ool20006Ool20008Ool2001QOol20006
Ool20008Ool20006Ool20008Ool20006Ool20008Ool2001POol20009Ool3000<Ool20008Ool20006
Ool20008Ool20005Ool00;]oo`<000]oo``000Ioo`8000Qoo`8000Ioo`8000Qoo`8005Yoo`<000]o
o`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8005]oo`<000]oo`8000Qoo`8000Ioo`8000Qo
o`8000Ioo`8000Qoo`80065oo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`80061o
o`8000Yoo`<000]oo`8000Qoo`8000Ioo`8000Qoo`8000Eoo`00_7oo0`002Woo0P001Woo0P0000=o
o`00Ool01Goo0P0027oo0P001Woo0P0027oo0P00Fgoo0`002Woo0P0027oo0P001Woo0P0027oo0P00
1Woo0P0027oo0P00G7oo0`002Woo0`001Woo0`001Woo0P0027oo0P001Woo0P0027oo0P00H7oo0`00
1Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P00Ggoo0`002goo0`002Woo0P0027oo0P00
1Woo0P0027oo0P001Goo002mOol3000:Ool20005Ool20008Ool20008Ool20006Ool20008Ool2001L
Ool30009Ool30006Ool30006Ool20008Ool20006Ool20008Ool2001MOol3000:Ool30004Ool30007
Ool20008Ool20006Ool20008Ool2001OOol30007Ool20008Ool20006Ool20008Ool20006Ool20008
Ool2001NOol3000=Ool30009Ool20008Ool20006Ool20008Ool20005Ool00;ioo`<000Uoo`<000Ao
o`8000Qoo`8000Qoo`8000Ioo`8000Qoo`8005eoo`<000Qoo`@000Aoo`<000Moo`8000Qoo`8000Io
o`8000Qoo`8005ioo`<000Yoo`P000Qoo`8000Qoo`8000Ioo`8000Qoo`8005aoo`D000Qoo`8000Qo
o`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8005]oo`D000moo`<000Qoo`8000Qoo`8000Ioo`8000Qo
o`8000Eoo`00_goo0P002Woo0P0017oo0P0027oo0P0027oo0P001Woo0P0027oo0P00GWoo0P0027oo
0P0000=oo`0000001@0027oo0P0027oo0P001Woo0P0027oo0P00Ggoo0P002Woo200027oo0P0027oo
0P001Woo0P0027oo0P00G7oo10002Goo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P00Fgoo
10004Goo0P0027oo0P0027oo0P001Woo0P0027oo0P001Goo0030Ool2000:Ool20003Ool20008Ool2
0008Ool20006Ool20008Ool2001OOol20008Ool00`00Oomoo`050009Ool20008Ool20006Ool20008
Ool2001POol20008Ool30004Ool30007Ool20008Ool20006Ool20008Ool2001OOol20008Ool20008
Ool20006Ool20008Ool20006Ool20008Ool2001NOol2000AOol20007Ool20008Ool20006Ool20008
Ool20005Ool00<1oo`8000Yoo`<0009oo`8000Qoo`8000Qoo`8000Ioo`8000Qoo`8005moo`8000Qo
o`8000moo`8000Qoo`8000Ioo`8000Qoo`80061oo`8000Moo`8000Qoo`8000Ioo`8000Qoo`8000Io
o`8000Qoo`80061oo`8000Moo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8005moo`80011o
o`8000Moo`8000Qoo`8000Ioo`8000Qoo`8000Eoo`00]goo0P001goo0P002goo0P000Woo0P002Goo
0P001Woo0P0027oo0P001Woo0P00Egoo0P001goo0P0027oo0`003goo0P001Woo0P0027oo0P001Woo
0P00F7oo0P001goo0P001goo0P0027oo0P001goo0P001Woo0P0027oo0P001Woo0P00HGoo0P0027oo
0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P00H7oo0P001goo0P001goo0P0027oo0P001Woo
0P0027oo0P001Woo0P001Woo002gOol30006Ool2000<Ool200000goo00000009Ool20006Ool20008
Ool20006Ool2001GOol30006Ool20009Ool3000>Ool20006Ool20008Ool20006Ool2001HOol30006
Ool20007Ool20008Ool20007Ool20006Ool20008Ool20006Ool2001IOol20006Ool20008Ool20006
Ool20008Ool20006Ool20008Ool20006Ool2001HOol20006Ool20007Ool30006Ool20008Ool20006
Ool20008Ool20006Ool20006Ool00;Moo`@000Aoo`8000ioo`@000Yoo`8000Aoo`8000Yoo`8000Ao
o`8005Qoo`@000Aoo`8000]oo`<000ioo`8000Aoo`8000Yoo`8000Aoo`8005Uoo`@000Aoo`8000Uo
o`<000Aoo`@000Qoo`8000Aoo`8000Yoo`8000Aoo`8005Yoo`<000Aoo`<000Uoo`8000Aoo`8000Yo
o`8000Aoo`8000Yoo`8000Aoo`8005Uoo`<000Aoo`<000Moo`@000Aoo`8000Yoo`8000Aoo`8000Yo
o`8000Aoo`8000Moo`00^7oo20003goo10002Woo20002Woo2000FGoo20003Goo200027oo20002Woo
2000FWoo20002Woo2P002Goo20002Woo2000Fgoo20002Woo20002Woo20002Woo2000FWoo20002Goo
20002goo20002Woo20001goo002jOol5000AOol3000<Ool4000>Ool4001MOol5000@Ool6000:Ool4
000>Ool4001NOol5000=Ool6000=Ool4000>Ool4001NOol5000>Ool4000>Ool4000>Ool4001MOol5
000=Ool5000>Ool4000>Ool40009Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOooo
OomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=o
o`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003o
OoooOoooOomSOol00?mooomooomoof=oo`00?gooo`00o`00oP009Goo000oOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0DOol200000goo001oo`0:Ool00`00Oomoo`0AOol20004Ool00`00
Oomoo`0:Ool00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00
Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00
Oomoo`0SOol00`00Oomoo`0GOol=000UOol003moo`03001oogoo02=oo`03001oogoo02=oo`03001o
ogoo02Aoo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001o
ogoo01=oo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo00Yoo`03001o
ogoo00Aoo`03001oogoo00Uoo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001o
ogoo02=oo`03001oogoo02=oo`03001oogoo02Aoo`03001oogoo02=oo`03001oogoo02=oo`03001o
ogoo02=oo`03001oogoo02=oo`03001oogoo01=oo`@000aoo`03001oogoo02=oo`00?goo00<007oo
Ool08goo00<007ooOol08goo00<007ooOol097oo00<007ooOol08goo00<007ooOol08goo00<007oo
Ool08goo00<007ooOol08goo00<007ooOol04goo00<007ooOol00goo00<007ooOol01goo00<007oo
Ool00goo1@0027oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol08goo00<007ooOol08goo
00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol097oo00<007ooOol08goo
00<007ooOol08goo00<007ooOol08goo00<007ooOol08goo00<007ooOol04Goo0`003goo00<007oo
Ool08goo000oOol00`00Oomoo`2FOol00`00Oomoo`1dOol4000=Ool00`00Oomoo`03Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool20006Ool00`00Oomoo`07Ool00`00Oomoo`1jOol0
0`00Oomoo`2FOol00`00Oomoo`22Ool00`00Oomoo`0@Ool00`00Oomoo`0SOol003moo`03001oogoo
09Ioo`03001oogoo02Uoo`8000Uoo`@000Uoo`@000]oo`80025oo`03001oogoo009oo`03001oogoo
00Uoo`03001oogoo00Eoo`03001oogoo00Ioo`05001oogooOol00007Ool6000;Ool00`00Oomoo`1i
Ool00`00Oomoo`2FOol00`00Oomoo`20Ool2000COol00`00Oomoo`0SOol003moo`8000=oo`@000Ao
o`D000=oo`@000Eoo`@000Eoo`<000Eoo`<000Moo`03001oogoo06Eoo`<000Qoo`@000Moo`D000Mo
o`80009oo`03001oogoo00Ioo`05001oogooOol00008Ool01@00Oomoogoo000027oo0P000Woo0P00
2goo1P003Goo00<007ooOol00goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<0
07ooOol05goo00<007ooOol0ogooUGoo00<007ooOol0>Goo000oOol00`00Ool000020004Ool40005
Ool40003Ool50004Ool50003Ool60002Ool700000goo0000001U0002Ool40003Ool20004Ool00`00
Oomoo`03Ool20004Ool20004Ool20004Ool00`00Oomoo`03Ool20004Ool20005Ool20005Ool00`00
Oomoo`04Ool20005Ool20006Ool30006Ool30009Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00
Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0GOol00`00Oomoo`3oOonEOol00`00Oomoo`0iOol0
03moo`03001oogoo09Yoo`03001oogoo00Ioo`@000Moo`D000Moo`800003Ool0000000Moo`80009o
o`03001oogoo00Ioo`05001oogooOol00008Ool00`00Oomoo`02Ool00`00Oomoo`06Ool20004Ool0
0`00Oomoo`0:Ool20006Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`0GOol00`00Oomoo`3oOonDOol00`00Oomoo`0jOol003moo`03001oogoo0;ao
o`8000Uoo`@000Uoo`04001oo`000009Ool01000Oomoo`002goo10003goo1P002goo00<007ooOol0
17oo00<007ooOol027oo00<007ooOol01goo00<007ooOol067oo00<007ooOol0ogooTgoo00<007oo
Ool0>goo000oOol00`00Oomoo`3EOol00`00Oomoo`0:Ool2000`Ool00`00Oomoo`04Ool00`00Oomo
o`09Ool00`00Oomoo`05Ool00`00Oomoo`0JOol00`00Oomoo`3oOonAOol00`00Oomoo`0lOol003mo
o`03001oogoo0?mooaEoo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo
01Yoo`03001oogoo0?mooi5oo`03001oogoo03aoo`00?goo00<007ooOol0ogoo5Woo0P000Woo00<0
07ooOol037oo00<007ooOol00goo00<007ooOol06goo00<007ooOol0ogooT7oo00<007ooOol0?Goo
000oOol00`00Oomoo`3oOolHOol2000?Ool00`00Oomoo`03Ool00`00Oomoo`0KOol00`00Oomoo`3o
Oon@Ool00`00Oomoo`0mOol003moo`@00?moobUoo`05001oogooOol0000OOol00`00Oomoo`3oOon>
Ool00`00Oomoo`0nOol003moo`03001oogoo0?moob]oo`<0021oo`03001oogoo0?mooheoo`03001o
ogoo03moo`00?goo00<007ooOol0ogooCWoo00<007ooOol0ogooSGoo00<007ooOol0?goo000oOol0
0`00Oomoo`3oOom>Ool00`00Oomoo`3oOon<Ool00`00Oomoo`10Ool003moo`03001oogoo0?moodmo
o`03001oogoo0?mooh]oo`03001oogoo041oo`00?goo00<007ooOol0ogooCgoo00<007ooOol0ogoo
Rgoo00<007ooOol0@7oo000oOol00`00Oomoo`3oOom?Ool00`00Oomoo`3oOon;Ool00`00Oomoo`10
Ool003moo`03001oogoo0?moodmoo`03001oogoo0?moohYoo`03001oogoo045oo`00?goo00<007oo
Ool0ogooCgoo00<007ooOol0ogooRWoo00<007ooOol0@Goo000oOol00`00Oomoo`3oOom?Ool00`00
Oomoo`3oOon9Ool00`00Oomoo`12Ool003moo`03001oogoo0?moodmoo`03001oogoo0?moohUoo`03
001oogoo049oo`00?goo00<007ooOol0ogooCgoo00<007ooOol0ogooR7oo00<007ooOol0@goo000o
Ool00`00Oomoo`3oOom@Ool00`00Oomoo`3oOon7Ool00`00Oomoo`13Ool003moo`@00?moodmoo`03
001oogoo0?moohMoo`03001oogoo04=oo`00?goo00<007ooOol0ogooD7oo00<007ooOol0ogooQgoo
00<007ooOol0@goo000oOol00`00Oomoo`3oOom@Ool00`00Oomoo`3oOon7Ool00`00Oomoo`13Ool0
03moo`03001oogoo0?mooe1oo`03001oogoo0?moohIoo`03001oogoo04Aoo`00?goo00<007ooOol0
ogooD7oo00<007ooOol0ogooQWoo00<007ooOol0A7oo000oOol00`00Oomoo`3oOomAOol00`00Oomo
o`3oOon5Ool00`00Oomoo`14Ool003moo`03001oogoo0?mooe5oo`03001oogoo0?moohEoo`03001o
ogoo04Aoo`00?goo00<007ooOol0ogooDGoo00<007ooOol0ogooQ7oo00<007ooOol0AGoo000oOol0
0`00Oomoo`3oOomAOol00`00Oomoo`3oOon4Ool00`00Oomoo`15Ool003moo`03001oogoo0?mooe5o
o`03001oogoo0?moohAoo`03001oogoo04Eoo`00?goo00<007ooOol0ogooDGoo00<007ooOol0ogoo
Pgoo00<007ooOol0AWoo000oOol00`00Oomoo`3oOomBOol00`00Oomoo`3oOon2Ool00`00Oomoo`16
Ool003moo`03001oogoo0?mooe9oo`03001oogoo0?mooh9oo`03001oogoo04Ioo`00?goo00<007oo
Ool0ogooDWoo00<007ooOol0ogooPWoo00<007ooOol0AWoo000oOol4003oOomAOol00`00Oomoo`3o
Oon2Ool00`00Oomoo`16Ool003moo`03001oogoo0?mooe9oo`03001oogoo0?mooh9oo`03001oogoo
04Ioo`00?goo00<007ooOol0ogooDWoo00<007ooOol0ogooPWoo00<007ooOol0AWoo000oOol00`00
Oomoo`3oOomCOol00`00Oomoo`3oOon1Ool00`00Oomoo`16Ool003moo`03001oogoo0?mooe=oo`03
001oogoo0?mooh1oo`03001oogoo04Moo`00?goo00<007ooOol0ogooDgoo00<007ooOol0ogooP7oo
00<007ooOol0Agoo000oOol00`00Oomoo`3oOomCOol00`00Oomoo`3oOon0Ool00`00Oomoo`17Ool0
03moo`03001oogoo0?mooe=oo`03001oogoo0?mooh1oo`03001oogoo04Moo`00?goo00<007ooOol0
ogooDgoo00<007ooOol0ogooOgoo00<007ooOol0B7oo000oOol00`00Oomoo`3oOomCOol00`00Oomo
o`3oOomoOol00`00Oomoo`18Ool003moo`03001oogoo0?mooe=oo`03001oogoo0?moogmoo`03001o
ogoo04Qoo`00?goo00<007ooOol0ogooDgoo00<007ooOol0ogooOgoo00<007ooOol0B7oo000oOol0
0`00Oomoo`3oOomCOol00`00Oomoo`3oOomnOol00`00Oomoo`19Ool003moo`@00?mooe9oo`03001o
ogoo0?moogioo`03001oogoo04Uoo`00?goo00<007ooOol0ogooDgoo00<007ooOol0ogooOWoo00<0
07ooOol0BGoo000oOol00`00Oomoo`3oOomDOol00`00Oomoo`3oOommOol00`00Oomoo`19Ool003mo
o`03001oogoo0?mooeAoo`03001oogoo0?moogeoo`03001oogoo04Uoo`00?goo00<007ooOol0ogoo
E7oo00<007ooOol0ogooOGoo00<007ooOol0BGoo000oOol00`00Oomoo`3oOomDOol00`00Oomoo`3o
OommOol00`00Oomoo`19Ool003moo`03001oogoo0?mooeAoo`03001oogoo0?moogeoo`03001oogoo
04Uoo`001goo10003Woo0`0037oo2P003Goo00<007ooOol0ogooE7oo00<007ooOol0ogooOGoo00<0
07ooOol0BGoo0005Ool8000;Ool5000;Ool:000=Ool00`00Oomoo`3oOomDOol00`00Oomoo`3oOoml
Ool00`00Oomoo`1:Ool000Eoo`8000Aoo`8000]oo`D000moo`80015oo`03001oogoo0?mooeEoo`03
001oogoo0?moog]oo`03001oogoo04Yoo`0017oo0P001Woo0P002Woo1@003goo0P004Goo00<007oo
Ool0ogooEGoo00<007ooOol0ogooNgoo00<007ooOol0BWoo0004Ool20006Ool2000;Ool3000@Ool2
000AOol00`00Oomoo`3oOomEOol00`00Oomoo`3oOomkOol00`00Oomoo`1:Ool000=oo`8000Qoo`80
01eoo`80015oo`03001oogoo0?mooeEoo`03001oogoo0?moog]oo`03001oogoo04Yoo`000goo0P00
27oo0P007Goo0P004Goo00<007ooOol0ogooEGoo00<007ooOol0ogooNgoo00<007ooOol0BWoo0003
Ool20008Ool2000MOol2000AOol6003oOomBOol00`00Oomoo`3oOomjOol00`00Oomoo`1;Ool000=o
o`8000Qoo`8001eoo`80015oo`03001oogoo0?mooeEoo`03001oogoo0?moogYoo`03001oogoo04]o
o`000goo0P0027oo0P007Goo0P004Goo00<007ooOol0ogooEWoo00<007ooOol0ogooNGoo00<007oo
Ool0Bgoo0003Ool20008Ool2000MOol2000AOol00`00Oomoo`3oOomFOol00`00Oomoo`3oOomiOol0
0`00Oomoo`1;Ool000=oo`8000Qoo`8001eoo`80015oo`03001oogoo0?mooeIoo`03001oogoo0?mo
ogUoo`03001oogoo04]oo`000goo0P0027oo0P007Goo0P004Goo00<007ooOol0ogooEWoo00<007oo
Ool0ogooN7oo00<007ooOol0C7oo0004Ool20006Ool2000NOol2000AOol00`00Oomoo`3oOomFOol0
0`00Oomoo`3oOomhOol00`00Oomoo`1<Ool000Aoo`8000Ioo`8001ioo`80015oo`03001oogoo0?mo
oeIoo`03001oogoo0?moogQoo`03001oogoo04aoo`001Goo0P0017oo0P006goo0`0000=oo`000000
4Goo00<007ooOol0ogooEWoo00<007ooOol0ogooN7oo00<007ooOol0C7oo0005Ool8000KOol6000A
Ool00`00Oomoo`3oOomFOol00`00Oomoo`3oOomhOol00`00Oomoo`1<Ool000Moo`@0021oo`<0015o
o`03001oogoo0?mooeIoo`03001oogoo0?moogQoo`03001oogoo04aoo`00?goo00<007ooOol0ogoo
EWoo00<007ooOol0ogooN7oo00<007ooOol0C7oo000oOol00`00Oomoo`3oOomFOol00`00Oomoo`3o
OomhOol00`00Oomoo`1<Ool003moo`@00?mooeEoo`03001oogoo0?moogQoo`03001oogoo04aoo`00
?goo00<007ooOol0ogooEWoo00<007ooOol0ogooN7oo00<007ooOol0C7oo000oOol00`00Oomoo`3o
OomFOol00`00Oomoo`3oOomhOol00`00Oomoo`1<Ool003moo`03001oogoo0?mooeIoo`03001oogoo
0?moogQoo`03001oogoo04aoo`00?goo00<007ooOol0ogooEgoo00<007ooOol0ogooMWoo00<007oo
Ool0CGoo000oOol00`00Oomoo`3oOomGOol00`00Oomoo`3oOomfOol00`00Oomoo`1=Ool003moo`03
001oogoo0?mooeMoo`03001oogoo0?moogIoo`03001oogoo04eoo`00?goo00<007ooOol0ogooEgoo
00<007ooOol0ogooMWoo00<007ooOol0CGoo000oOol00`00Oomoo`3oOomGOol00`00Oomoo`3oOomf
Ool00`00Oomoo`1=Ool003moo`03001oogoo0?mooeMoo`03001oogoo0?moogIoo`03001oogoo04eo
o`00?goo00<007ooOol0ogooEgoo00<007ooOol0ogooMGoo00<007ooOol0CWoo000oOol00`00Oomo
o`3oOomGOol00`00Oomoo`3oOomeOol00`00Oomoo`1>Ool003moo`03001oogoo0?mooeQoo`03001o
ogoo0?moogAoo`03001oogoo04ioo`00?goo00<007ooOol0ogooF7oo00<007ooOol0ogooM7oo00<0
07ooOol0CWoo000oOol4003oOomGOol00`00Oomoo`3oOomdOol00`00Oomoo`1>Ool003moo`03001o
ogoo0?mooeQoo`03001oogoo0?moogAoo`03001oogoo04ioo`00?goo00<007ooOol0ogooF7oo00<0
07ooOol0ogooM7oo00<007ooOol0CWoo000oOol00`00Oomoo`3oOomHOol00`00Oomoo`3oOomcOol0
0`00Oomoo`1?Ool003moo`03001oogoo0?mooeQoo`03001oogoo0?moog=oo`03001oogoo04moo`00
?goo00<007ooOol0ogooF7oo00<007ooOol0ogooLgoo00<007ooOol0Cgoo000oOol00`00Oomoo`3o
OomIOol00`00Oomoo`3oOombOol00`00Oomoo`1?Ool003moo`03001oogoo0?mooeUoo`03001oogoo
0?moog9oo`03001oogoo04moo`00?goo00<007ooOol0ogooFGoo00<007ooOol0ogooLWoo00<007oo
Ool0Cgoo000oOol00`00Oomoo`3oOomIOol00`00Oomoo`3oOomaOol00`00Oomoo`1@Ool003moo`03
001oogoo0?mooeUoo`03001oogoo0?moog5oo`03001oogoo051oo`00?goo00<007ooOol0ogooFGoo
00<007ooOol0ogooLGoo00<007ooOol0D7oo000oOol00`00Oomoo`3oOomIOol00`00Oomoo`3oOoma
Ool00`00Oomoo`1@Ool003moo`@00?mooeQoo`03001oogoo0?moog5oo`03001oogoo051oo`00?goo
00<007ooOol0ogooFGoo00<007ooOol0ogooLGoo00<007ooOol0D7oo000oOol00`00Oomoo`3oOomI
Ool00`00Oomoo`3oOomaOol00`00Oomoo`1@Ool003moo`03001oogoo0?mooeUoo`03001oogoo0?mo
og5oo`03001oogoo051oo`00?goo00<007ooOol0ogooFGoo00<007ooOol0ogooLGoo00<007ooOol0
D7oo000oOol00`00Oomoo`3oOomIOol00`00Oomoo`3oOomaOol00`00Oomoo`1@Ool003moo`03001o
ogoo0?mooeUoo`03001oogoo0?moog5oo`03001oogoo051oo`00?goo00<007ooOol0ogooFGoo00<0
07ooOol0ogooLGoo00<007ooOol0D7oo000oOol00`00Oomoo`3oOomIOol00`00Oomoo`3oOomaOol0
0`00Oomoo`1@Ool003moo`03001oogoo0?mooeUoo`03001oogoo0?moog5oo`03001oogoo051oo`00
?goo00<007ooOol0ogooFWoo00<007ooOol0ogooL7oo00<007ooOol0D7oo000oOol00`00Oomoo`3o
OomJOol00`00Oomoo`3oOom_Ool00`00Oomoo`1AOol003moo`03001oogoo0?mooeYoo`03001oogoo
0?moofmoo`03001oogoo055oo`00?goo00<007ooOol0ogooFWoo00<007ooOol0ogooKgoo00<007oo
Ool0DGoo000oOol4003oOomIOol00`00Oomoo`3oOom_Ool00`00Oomoo`1AOol003moo`03001oogoo
0?mooeYoo`03001oogoo0?moofmoo`03001oogoo055oo`00?goo00<007ooOol0ogooFWoo00<007oo
Ool0ogooKgoo00<007ooOol0DGoo000oOol00`00Oomoo`3oOomJOol00`00Oomoo`3oOom_Ool00`00
Oomoo`1AOol003moo`03001oogoo0?mooeYoo`03001oogoo0?moofmoo`03001oogoo055oo`00?goo
00<007ooOol0ogooFgoo00<007ooOol0ogooKGoo00<007ooOol0DWoo0007Ool4000>Ool3000:Ool<
000=Ool00`00Oomoo`3oOomKOol00`00Oomoo`3oOom]Ool00`00Oomoo`1BOol000Eoo`P000]oo`D0
00Uoo``000eoo`03001oogoo0?mooe]oo`03001oogoo0?moofeoo`03001oogoo059oo`001Goo0P00
17oo0P002goo1@002Woo0`001Woo0P003Goo00<007ooOol0ogooFgoo00<007ooOol0ogooKGoo00<0
07ooOol0DWoo0004Ool20006Ool2000:Ool5000;Ool3000DOol00`00Oomoo`3oOomKOol00`00Oomo
o`3oOom]Ool00`00Oomoo`1BOol000Aoo`8000Ioo`8000]oo`<000eoo`<001=oo`03001oogoo0?mo
oe]oo`03001oogoo0?moofeoo`03001oogoo059oo`000goo0P0027oo0P006goo0`004Woo00<007oo
Ool0ogooFgoo00<007ooOol0ogooKGoo00<007ooOol0DWoo0003Ool20008Ool2000LOol3000AOol0
0`00Oomoo`3oOomKOol00`00Oomoo`3oOom]Ool00`00Oomoo`1BOol000=oo`8000Qoo`8001eoo`<0
011oo`H00?mooeQoo`03001oogoo0?moofaoo`03001oogoo05=oo`000goo0P0027oo0P007Woo0`00
3goo00<007ooOol0ogooG7oo00<007ooOol0ogooJgoo00<007ooOol0Dgoo0003Ool20008Ool2000O
Ool3000>Ool00`00Oomoo`3oOomLOol00`00Oomoo`3oOom[Ool00`00Oomoo`1COol000=oo`8000Qo
o`80021oo`8000ioo`03001oogoo0?mooeaoo`03001oogoo0?moof]oo`03001oogoo05=oo`000goo
0P0027oo0P008Goo0P003Goo00<007ooOol0ogooG7oo00<007ooOol0ogooJgoo00<007ooOol0Dgoo
0003Ool20008Ool2000QOol2000=Ool00`00Oomoo`3oOomLOol00`00Oomoo`3oOom[Ool00`00Oomo
o`1COol000Aoo`8000Ioo`8001Uoo`8000Moo`8000eoo`03001oogoo0?mooeaoo`03001oogoo0?mo
of]oo`03001oogoo05=oo`0017oo0P001Woo0P006Goo0`001Woo0P003Goo00<007ooOol0ogooG7oo
00<007ooOol0ogooJgoo00<007ooOol0Dgoo0005Ool20004Ool2000JOol40004Ool2000>Ool00`00
Oomoo`3oOomLOol00`00Oomoo`3oOom[Ool00`00Oomoo`1COol000Eoo`P001]oo`P000moo`03001o
ogoo0?mooeaoo`03001oogoo0?moof]oo`03001oogoo05=oo`001goo10007goo1@0047oo00<007oo
Ool0ogooG7oo00<007ooOol0ogooJgoo00<007ooOol0Dgoo000oOol00`00Oomoo`3oOomLOol00`00
Oomoo`3oOom[Ool00`00Oomoo`1COol003moo`03001oogoo0?mooeaoo`03001oogoo0?moof]oo`03
001oogoo05=oo`00?goo00<007ooOol0ogooG7oo00<007ooOol0ogooJgoo00<007ooOol0Dgoo000o
Ool4003oOomKOol00`00Oomoo`3oOom[Ool00`00Oomoo`1COol003moo`03001oogoo0?mooeaoo`03
001oogoo0?moof]oo`03001oogoo05=oo`00?goo00<007ooOol0ogooG7oo00<007ooOol0ogooJWoo
00<007ooOol0E7oo000oOol00`00Oomoo`3oOomLOol00`00Oomoo`3oOomZOol00`00Oomoo`1DOol0
03moo`03001oogoo0?mooeaoo`03001oogoo0?moofYoo`03001oogoo05Aoo`00?goo00<007ooOol0
ogooG7oo00<007ooOol0ogooJWoo00<007ooOol0E7oo000oOol00`00Oomoo`3oOomMOol00`00Oomo
o`3oOomYOol00`00Oomoo`1DOol003moo`03001oogoo0?mooeeoo`03001oogoo0?moofUoo`03001o
ogoo05Aoo`00?goo00<007ooOol0ogooGGoo00<007ooOol0ogooJGoo00<007ooOol0E7oo000oOol0
0`00Oomoo`3oOomMOol00`00Oomoo`3oOomYOol00`00Oomoo`1DOol003moo`03001oogoo0?mooeeo
o`03001oogoo0?moofQoo`03001oogoo05Eoo`00?goo00<007ooOol0ogooGGoo00<007ooOol0ogoo
J7oo00<007ooOol0EGoo000oOol00`00Oomoo`3oOomMOol00`00Oomoo`3oOomXOol00`00Oomoo`1E
Ool003moo`@00?mooeaoo`03001oogoo0?moofQoo`03001oogoo05Eoo`00?goo00<007ooOol0ogoo
GGoo00<007ooOol0ogooJ7oo00<007ooOol0EGoo000oOol00`00Oomoo`3oOomMOol00`00Oomoo`3o
OomXOol00`00Oomoo`1EOol003moo`03001oogoo0?mooeioo`03001oogoo0?moofMoo`03001oogoo
05Eoo`00?goo00<007ooOol0ogooGWoo00<007ooOol0ogooIgoo00<007ooOol0EGoo000oOol00`00
Oomoo`3oOomNOol00`00Oomoo`3oOomVOol00`00Oomoo`1FOol003moo`03001oogoo0?mooeioo`03
001oogoo0?moofIoo`03001oogoo05Ioo`00?goo00<007ooOol0ogooGWoo00<007ooOol0ogooIWoo
00<007ooOol0EWoo000oOol00`00Oomoo`3oOomNOol00`00Oomoo`3oOomVOol00`00Oomoo`1FOol0
03moo`03001oogoo0?mooeioo`03001oogoo0?moofIoo`03001oogoo05Ioo`00?goo00<007ooOol0
ogooGWoo00<007ooOol0ogooIWoo00<007ooOol0EWoo000oOol00`00Oomoo`3oOomNOol00`00Oomo
o`3oOomVOol00`00Oomoo`1FOol003moo`03001oogoo0?mooemoo`03001oogoo0?moofEoo`03001o
ogoo05Ioo`00?goo00<007ooOol0ogooGgoo00<007ooOol0ogooIGoo00<007ooOol0EWoo000oOol4
003oOomNOol00`00Oomoo`3oOomUOol00`00Oomoo`1FOol003moo`03001oogoo0?mooemoo`03001o
ogoo0?moofEoo`03001oogoo05Ioo`00?goo00<007ooOol0ogooGgoo00<007ooOol0ogooIGoo00<0
07ooOol0EWoo000oOol00`00Oomoo`3oOomOOol00`00Oomoo`3oOomUOol00`00Oomoo`1FOol003mo
o`03001oogoo0?mooemoo`03001oogoo0?moofEoo`03001oogoo05Ioo`00?goo00<007ooOol0ogoo
Ggoo00<007ooOol0ogooIGoo00<007ooOol0EWoo000oOol00`00Oomoo`3oOomOOol00`00Oomoo`3o
OomUOol00`00Oomoo`1FOol003moo`03001oogoo0?mooemoo`03001oogoo0?moofEoo`03001oogoo
05Ioo`00?goo00<007ooOol0ogooH7oo00<007ooOol0ogooHgoo00<007ooOol0Egoo000oOol00`00
Oomoo`3oOomPOol00`00Oomoo`3oOomSOol00`00Oomoo`1GOol003moo`03001oogoo0?moof1oo`03
001oogoo0?moof=oo`03001oogoo05Moo`00?goo00<007ooOol0ogooH7oo00<007ooOol0ogooHgoo
00<007ooOol0Egoo000oOol00`00Oomoo`3oOomPOol00`00Oomoo`3oOomSOol00`00Oomoo`1GOol0
03moo`@00?mooemoo`03001oogoo0?moof=oo`03001oogoo05Moo`00?goo00<007ooOol0ogooH7oo
00<007ooOol0ogooHgoo00<007ooOol0Egoo000oOol00`00Oomoo`3oOomPOol00`00Oomoo`3oOomS
Ool00`00Oomoo`1GOol003moo`03001oogoo0?moof1oo`03001oogoo0?moof=oo`03001oogoo05Mo
o`00?goo00<007ooOol0ogooH7oo00<007ooOol0ogooHWoo00<007ooOol0F7oo000oOol00`00Oomo
o`3oOomPOol00`00Oomoo`3oOomROol00`00Oomoo`1HOol003moo`03001oogoo0?moof1oo`03001o
ogoo0?moof9oo`03001oogoo05Qoo`001goo10003Woo0`003Woo1@0047oo00<007ooOol0ogooH7oo
00<007ooOol0ogooHWoo00<007ooOol0F7oo0005Ool8000;Ool5000;Ool9000>Ool00`00Oomoo`3o
OomPOol00`00Oomoo`3oOomROol00`00Oomoo`1HOol000Eoo`8000Aoo`8000]oo`D000Yoo`@000Ao
o`<000eoo`03001oogoo0?moof1oo`03001oogoo0?moof9oo`03001oogoo05Qoo`0017oo0P001Woo
0P002Woo1@002Woo0P001goo0`0037oo00<007ooOol0ogooH7oo00<007ooOol0ogooHWoo00<007oo
Ool0F7oo0004Ool20006Ool2000;Ool3000EOol2000<Ool00`00Oomoo`3oOomPOol00`00Oomoo`3o
OomROol00`00Oomoo`1HOol000=oo`8000Qoo`80029oo`8000aoo`03001oogoo0?moof1oo`03001o
ogoo0?moof5oo`03001oogoo05Uoo`000goo0P0027oo0P008Woo0P0037oo00<007ooOol0ogooH7oo
00<007ooOol0ogooHGoo00<007ooOol0FGoo0003Ool20008Ool2000QOol3000<Ool6003oOomMOol0
0`00Oomoo`3oOomQOol00`00Oomoo`1IOol000=oo`8000Qoo`80021oo`<000eoo`03001oogoo0?mo
of5oo`03001oogoo0?moof1oo`03001oogoo05Uoo`000goo0P0027oo0P007Goo1@003Woo00<007oo
Ool0ogooHGoo00<007ooOol0ogooH7oo00<007ooOol0FGoo0003Ool20008Ool2000MOol4000?Ool0
0`00Oomoo`3oOomQOol00`00Oomoo`3oOomPOol00`00Oomoo`1IOol000=oo`8000Qoo`80021oo`80
00ioo`03001oogoo0?moof5oo`03001oogoo0?moof1oo`03001oogoo05Uoo`000goo0P0027oo0P00
8Goo0P003Goo00<007ooOol0ogooHGoo00<007ooOol0ogooH7oo00<007ooOol0FGoo0004Ool20006
Ool2000ROol2000=Ool00`00Oomoo`3oOomQOol00`00Oomoo`3oOomPOol00`00Oomoo`1IOol000Ao
o`8000Ioo`8001Yoo`8000Ioo`8000eoo`03001oogoo0?moof5oo`03001oogoo0?moof1oo`03001o
ogoo05Uoo`001Goo0P0017oo0P006goo0`0017oo0`003Goo00<007ooOol0ogooHGoo00<007ooOol0
ogooH7oo00<007ooOol0FGoo0005Ool8000LOol8000>Ool00`00Oomoo`3oOomQOol00`00Oomoo`3o
OomPOol00`00Oomoo`1IOol000Moo`@001moo`D0011oo`03001oogoo0?moof5oo`03001oogoo0?mo
of1oo`03001oogoo05Uoo`00?goo00<007ooOol0ogooHWoo00<007ooOol0ogooGgoo00<007ooOol0
FGoo000oOol00`00Oomoo`3oOomROol00`00Oomoo`3oOomOOol00`00Oomoo`1IOol003moo`@00?mo
of5oo`03001oogoo0?mooemoo`03001oogoo05Uoo`00?goo00<007ooOol0ogooHWoo00<007ooOol0
ogooGgoo00<007ooOol0FGoo000oOol00`00Oomoo`3oOomROol00`00Oomoo`3oOomNOol00`00Oomo
o`1JOol003moo`03001oogoo0?moof9oo`03001oogoo0?mooeioo`03001oogoo05Yoo`00?goo00<0
07ooOol0ogooHWoo00<007ooOol0ogooGWoo00<007ooOol0FWoo000oOol00`00Oomoo`3oOomROol0
0`00Oomoo`3oOomNOol00`00Oomoo`1JOol003moo`03001oogoo0?moof9oo`03001oogoo0?mooeio
o`03001oogoo05Yoo`00?goo00<007ooOol0ogooHWoo00<007ooOol0ogooGWoo00<007ooOol0FWoo
000oOol00`00Oomoo`3oOomSOol00`00Oomoo`3oOomMOol00`00Oomoo`1JOol003moo`03001oogoo
0?moof=oo`03001oogoo0?mooeeoo`03001oogoo05Yoo`00?goo00<007ooOol0ogooHgoo00<007oo
Ool0ogooGGoo00<007ooOol0FWoo000oOol00`00Oomoo`3oOomSOol00`00Oomoo`3oOomLOol00`00
Oomoo`1KOol003moo`03001oogoo0?moof=oo`03001oogoo0?mooeaoo`03001oogoo05]oo`00?goo
00<007ooOol0ogooHgoo00<007ooOol0ogooG7oo00<007ooOol0Fgoo000oOol4003oOomROol00`00
Oomoo`3oOomLOol00`00Oomoo`1KOol003moo`03001oogoo0?moof=oo`03001oogoo0?mooeaoo`03
001oogoo05]oo`00?goo00<007ooOol0ogooHgoo00<007ooOol0ogooG7oo00<007ooOol0Fgoo000o
Ool00`00Oomoo`3oOomSOol00`00Oomoo`3oOomLOol00`00Oomoo`1KOol003moo`03001oogoo0?mo
of=oo`03001oogoo0?mooeaoo`03001oogoo05]oo`00?goo00<007ooOol0ogooHgoo00<007ooOol0
ogooG7oo00<007ooOol0Fgoo000oOol00`00Oomoo`3oOomSOol00`00Oomoo`3oOomKOol00`00Oomo
o`1LOol003moo`03001oogoo0?moof=oo`03001oogoo0?mooe]oo`03001oogoo05aoo`00?goo00<0
07ooOol0ogooHgoo00<007ooOol0ogooFgoo00<007ooOol0G7oo000oOol00`00Oomoo`3oOomSOol0
0`00Oomoo`3oOomKOol00`00Oomoo`1LOol003moo`03001oogoo0?moof=oo`03001oogoo0?mooe]o
o`03001oogoo05aoo`00?goo00<007ooOol0ogooHgoo00<007ooOol0ogooFgoo00<007ooOol0G7oo
000oOol00`00Oomoo`3oOomSOol00`00Oomoo`3oOomKOol00`00Oomoo`1LOol003moo`@00?moof9o
o`03001oogoo0?mooe]oo`03001oogoo05aoo`00?goo00<007ooOol0ogooI7oo00<007ooOol0ogoo
FGoo00<007ooOol0GGoo000oOol00`00Oomoo`3oOomTOol00`00Oomoo`3oOomIOol00`00Oomoo`1M
Ool003moo`03001oogoo0?moofAoo`03001oogoo0?mooeUoo`03001oogoo05eoo`00?goo00<007oo
Ool0ogooI7oo00<007ooOol0ogooFGoo00<007ooOol0GGoo000oOol00`00Oomoo`3oOomTOol00`00
Oomoo`3oOomIOol00`00Oomoo`1MOol003moo`03001oogoo0?moofAoo`03001oogoo0?mooeUoo`03
001oogoo05eoo`00?goo00<007ooOol0ogooI7oo00<007ooOol0ogooFGoo00<007ooOol0GGoo000o
Ool00`00Oomoo`3oOomTOol00`00Oomoo`3oOomIOol00`00Oomoo`1MOol003moo`03001oogoo0?mo
ofAoo`03001oogoo0?mooeUoo`03001oogoo05eoo`00?goo00<007ooOol0ogooI7oo00<007ooOol0
ogooFGoo00<007ooOol0GGoo000oOol00`00Oomoo`3oOomUOol00`00Oomoo`3oOomHOol00`00Oomo
o`1MOol003moo`03001oogoo0?moofEoo`03001oogoo0?mooeQoo`03001oogoo05eoo`00?goo00<0
07ooOol0ogooIGoo00<007ooOol0ogooF7oo00<007ooOol0GGoo000oOol4003oOomTOol00`00Oomo
o`3oOomHOol00`00Oomoo`1MOol003moo`03001oogoo0?moofEoo`03001oogoo0?mooeQoo`03001o
ogoo05eoo`00?goo00<007ooOol0ogooIGoo00<007ooOol0ogooF7oo00<007ooOol0GGoo000oOol0
0`00Oomoo`3oOomUOol00`00Oomoo`3oOomHOol00`00Oomoo`1MOol003moo`03001oogoo0?moofEo
o`03001oogoo0?mooeMoo`03001oogoo05ioo`00?goo00<007ooOol0ogooIGoo00<007ooOol0ogoo
Egoo00<007ooOol0GWoo0007Ool4000>Ool3000@Ool7000<Ool00`00Oomoo`3oOomUOol00`00Oomo
o`3oOomGOol00`00Oomoo`1NOol000Eoo`P000]oo`D000moo`L000aoo`03001oogoo0?moofIoo`03
001oogoo0?mooeIoo`03001oogoo05ioo`001Goo0P0017oo0P002goo1@004Woo0P003Woo00<007oo
Ool0ogooIWoo00<007ooOol0ogooEWoo00<007ooOol0GWoo0004Ool20006Ool2000:Ool5000BOol2
000>Ool00`00Oomoo`3oOomVOol00`00Oomoo`3oOomFOol00`00Oomoo`1NOol000Aoo`8000Ioo`80
00]oo`<001=oo`8000ioo`03001oogoo0?moofIoo`03001oogoo0?mooeIoo`03001oogoo05ioo`00
0goo0P0027oo0P0067oo300037oo00<007ooOol0ogooIWoo00<007ooOol0ogooEWoo00<007ooOol0
GWoo0003Ool20008Ool2000HOol<000<Ool00`00Oomoo`3oOomVOol00`00Oomoo`3oOomEOol00`00
Oomoo`1OOol000=oo`8000Qoo`8001Qoo`8000Ioo`800003Ool007oo00]oo`H00?moof=oo`03001o
ogoo0?mooeEoo`03001oogoo05moo`000goo0P0027oo0P006Goo0P001Goo0P003Woo00<007ooOol0
ogooIWoo00<007ooOol0ogooEGoo00<007ooOol0Ggoo0003Ool20008Ool2000IOol30004Ool2000>
Ool00`00Oomoo`3oOomVOol00`00Oomoo`3oOomEOol00`00Oomoo`1OOol000=oo`8000Qoo`8001Yo
o`8000Aoo`8000ioo`03001oogoo0?moofIoo`03001oogoo0?mooeEoo`03001oogoo05moo`000goo
0P0027oo0P006goo0P000goo0P003Woo00<007ooOol0ogooIWoo00<007ooOol0ogooEGoo00<007oo
Ool0Ggoo0003Ool20008Ool2000KOol30002Ool2000>Ool00`00Oomoo`3oOomVOol00`00Oomoo`3o
OomEOol00`00Oomoo`1OOol000Aoo`8000Ioo`8001eoo`80009oo`8000ioo`03001oogoo0?moofIo
o`03001oogoo0?mooeEoo`03001oogoo05moo`0017oo0P001Woo0P007Woo0P0000=oo`0000003Woo
00<007ooOol0ogooIWoo00<007ooOol0ogooE7oo00<007ooOol0H7oo0005Ool20004Ool2000POol4
000>Ool00`00Oomoo`3oOomVOol00`00Oomoo`3oOomDOol00`00Oomoo`1POol000Eoo`P0021oo`@0
00ioo`03001oogoo0?moofIoo`03001oogoo0?mooeAoo`03001oogoo061oo`001goo10008goo0`00
3Woo00<007ooOol0ogooIWoo00<007ooOol0ogooE7oo00<007ooOol0H7oo000oOol00`00Oomoo`3o
OomVOol00`00Oomoo`3oOomDOol00`00Oomoo`1POol003moo`03001oogoo0?moofMoo`03001oogoo
0?mooe=oo`03001oogoo061oo`00?goo00<007ooOol0ogooIgoo00<007ooOol0ogooDgoo00<007oo
Ool0H7oo000oOol4003oOomVOol00`00Oomoo`3oOomCOol00`00Oomoo`1POol003moo`03001oogoo
0?moofMoo`03001oogoo0?mooe=oo`03001oogoo061oo`00?goo00<007ooOol0ogooIgoo00<007oo
Ool0ogooDgoo00<007ooOol0H7oo000oOol00`00Oomoo`3oOomWOol00`00Oomoo`3oOomCOol00`00
Oomoo`1POol003moo`03001oogoo0?moofMoo`03001oogoo0?mooe=oo`03001oogoo061oo`00?goo
00<007ooOol0ogooIgoo00<007ooOol0ogooDgoo00<007ooOol0H7oo000oOol00`00Oomoo`3oOomW
Ool00`00Oomoo`3oOomCOol00`00Oomoo`1POol003moo`03001oogoo0?moofQoo`03001oogoo0?mo
oe9oo`03001oogoo061oo`00?goo00<007ooOol0ogooJ7oo00<007ooOol0ogooDGoo00<007ooOol0
HGoo000oOol00`00Oomoo`3oOomXOol00`00Oomoo`3oOomAOol00`00Oomoo`1QOol003moo`03001o
ogoo0?moofQoo`03001oogoo0?mooe5oo`03001oogoo065oo`00?goo00<007ooOol0ogooJ7oo00<0
07ooOol0ogooDGoo00<007ooOol0HGoo000oOol00`00Oomoo`3oOomXOol00`00Oomoo`3oOomAOol0
0`00Oomoo`1QOol003moo`@00?moofMoo`03001oogoo0?mooe5oo`03001oogoo065oo`00?goo00<0
07ooOol0ogooJ7oo00<007ooOol0ogooDGoo00<007ooOol0HGoo000oOol00`00Oomoo`3oOomXOol0
0`00Oomoo`3oOomAOol00`00Oomoo`1QOol003moo`03001oogoo0?moofUoo`03001oogoo0?moodmo
o`03001oogoo069oo`00?goo00<007ooOol0ogooJGoo00<007ooOol0ogooCgoo00<007ooOol0HWoo
000oOol00`00Oomoo`3oOomYOol00`00Oomoo`3oOom?Ool00`00Oomoo`1ROol003moo`03001oogoo
0?moofUoo`03001oogoo0?moodmoo`03001oogoo069oo`00?goo00<007ooOol0ogooJGoo00<007oo
Ool0ogooCgoo00<007ooOol0HWoo000oOol00`00Oomoo`3oOomYOol00`00Oomoo`3oOom?Ool00`00
Oomoo`1ROol003moo`03001oogoo0?moofUoo`03001oogoo0?moodmoo`03001oogoo069oo`00?goo
00<007ooOol0ogooJGoo00<007ooOol0ogooCWoo00<007ooOol0Hgoo000oOol00`00Oomoo`3oOomY
Ool00`00Oomoo`3oOom>Ool00`00Oomoo`1SOol003moo`03001oogoo0?moofUoo`03001oogoo0?mo
odioo`03001oogoo06=oo`00?goo00<007ooOol0ogooJGoo00<007ooOol0ogooCWoo00<007ooOol0
Hgoo000oOol4003oOomXOol00`00Oomoo`3oOom>Ool00`00Oomoo`1SOol003moo`03001oogoo0?mo
ofUoo`03001oogoo0?moodioo`03001oogoo06=oo`00?goo00<007ooOol0ogooJGoo00<007ooOol0
ogooCWoo00<007ooOol0Hgoo000oOol00`00Oomoo`3oOomYOol00`00Oomoo`3oOom>Ool00`00Oomo
o`1SOol003moo`03001oogoo0?moofUoo`03001oogoo0?moodioo`03001oogoo06=oo`00?goo00<0
07ooOol0ogooJGoo00<007ooOol0ogooCWoo00<007ooOol0Hgoo000oOol00`00Oomoo`3oOomYOol0
0`00Oomoo`3oOom>Ool00`00Oomoo`1SOol003moo`03001oogoo0?moofYoo`03001oogoo0?moodeo
o`03001oogoo06=oo`00?goo00<007ooOol0ogooJWoo00<007ooOol0ogooCGoo00<007ooOol0Hgoo
000oOol00`00Oomoo`3oOomZOol00`00Oomoo`3oOom=Ool00`00Oomoo`1SOol003moo`03001oogoo
0?moofYoo`03001oogoo0?moodaoo`03001oogoo06Aoo`00?goo00<007ooOol0ogooJWoo00<007oo
Ool0ogooC7oo00<007ooOol0I7oo000oOol00`00Oomoo`3oOomZOol00`00Oomoo`3oOom<Ool00`00
Oomoo`1TOol003moo`@00?moofUoo`03001oogoo0?moodaoo`03001oogoo06Aoo`00?goo00<007oo
Ool0ogooJWoo00<007ooOol0ogooC7oo00<007ooOol0I7oo000oOol00`00Oomoo`3oOom[Ool00`00
Oomoo`3oOom;Ool00`00Oomoo`1TOol003moo`03001oogoo0?moof]oo`03001oogoo0?mood]oo`03
001oogoo06Aoo`00?goo00<007ooOol0ogooJgoo00<007ooOol0ogooBWoo00<007ooOol0IGoo000o
Ool00`00Oomoo`3oOom[Ool00`00Oomoo`3oOom:Ool00`00Oomoo`1UOol000Moo`@000ioo`<000eo
o`H0011oo`03001oogoo0?moof]oo`03001oogoo0?moodYoo`03001oogoo06Eoo`001Goo20002goo
1@002Woo2P003Woo00<007ooOol0ogooJgoo00<007ooOol0ogooBWoo00<007ooOol0IGoo0005Ool2
0004Ool2000;Ool5000:Ool30005Ool3000=Ool00`00Oomoo`3oOom[Ool00`00Oomoo`3oOom:Ool0
0`00Oomoo`1UOol000Aoo`8000Ioo`8000Yoo`D001=oo`8000eoo`03001oogoo0?moof]oo`03001o
ogoo0?moodYoo`03001oogoo06Eoo`0017oo0P001Woo0P002goo0`005Goo0P0037oo00<007ooOol0
ogooK7oo00<007ooOol0ogooBGoo00<007ooOol0IGoo0003Ool20008Ool2000ROol2000<Ool00`00
Oomoo`3oOom/Ool00`00Oomoo`3oOom8Ool00`00Oomoo`1VOol000=oo`8000Qoo`80029oo`8000ao
o`03001oogoo0?moofaoo`03001oogoo0?moodQoo`03001oogoo06Ioo`000goo0P0027oo0P008Woo
0P0037oo1P00ogooJGoo00<007ooOol0ogooB7oo00<007ooOol0IWoo0003Ool20008Ool2000ROol2
000<Ool00`00Oomoo`3oOom/Ool00`00Oomoo`3oOom8Ool00`00Oomoo`1VOol000=oo`8000Qoo`80
025oo`8000eoo`03001oogoo0?moofaoo`03001oogoo0?moodQoo`03001oogoo06Ioo`000goo0P00
27oo0P006Goo0P001Goo0`003Goo00<007ooOol0ogooK7oo00<007ooOol0ogooB7oo00<007ooOol0
IWoo0003Ool20008Ool2000IOol9000>Ool00`00Oomoo`3oOom]Ool00`00Oomoo`3oOom7Ool00`00
Oomoo`1VOol000=oo`8000Qoo`8001Uoo`800003Ool0000000<000moo`03001oogoo0?moofeoo`03
001oogoo0?moodMoo`03001oogoo06Ioo`0017oo0P001Woo0P006Woo0P005Goo00<007ooOol0ogoo
KGoo00<007ooOol0ogooAgoo00<007ooOol0IWoo0004Ool20006Ool2000JOol2000EOol00`00Oomo
o`3oOom]Ool00`00Oomoo`3oOom7Ool00`00Oomoo`1VOol000Eoo`8000Aoo`8001]oo`8001Eoo`03
001oogoo0?moofeoo`03001oogoo0?moodMoo`03001oogoo06Ioo`001Goo20006goo2P003Goo00<0
07ooOol0ogooKGoo00<007ooOol0ogooAgoo00<007ooOol0IWoo0007Ool4000MOol:000=Ool00`00
Oomoo`3oOom]Ool00`00Oomoo`3oOom7Ool00`00Oomoo`1VOol003moo`03001oogoo0?moofeoo`03
001oogoo0?moodIoo`03001oogoo06Moo`00?goo00<007ooOol0ogooKGoo00<007ooOol0ogooAWoo
00<007ooOol0Igoo000oOol00`00Oomoo`3oOom]Ool00`00Oomoo`3oOom6Ool00`00Oomoo`1WOol0
03moo`@00?moofaoo`03001oogoo0?moodIoo`03001oogoo06Moo`00?goo00<007ooOol0ogooKGoo
00<007ooOol0ogooAWoo00<007ooOol0Igoo000oOol00`00Oomoo`3oOom]Ool00`00Oomoo`3oOom6
Ool00`00Oomoo`1WOol003moo`03001oogoo0?moofeoo`03001oogoo0?moodEoo`03001oogoo06Qo
o`00?goo00<007ooOol0ogooKWoo00<007ooOol0ogooA7oo00<007ooOol0J7oo000oOol00`00Oomo
o`3oOom^Ool00`00Oomoo`3oOom4Ool00`00Oomoo`1XOol003moo`03001oogoo0?moofioo`03001o
ogoo0?moodAoo`03001oogoo06Qoo`00?goo00<007ooOol0ogooKWoo00<007ooOol0ogooA7oo00<0
07ooOol0J7oo000oOol00`00Oomoo`3oOom^Ool00`00Oomoo`3oOom4Ool00`00Oomoo`1XOol003mo
o`03001oogoo0?moofioo`03001oogoo0?mood=oo`03001oogoo06Uoo`00?goo00<007ooOol0ogoo
KWoo00<007ooOol0ogoo@goo00<007ooOol0JGoo000oOol00`00Oomoo`3oOom_Ool00`00Oomoo`3o
Oom2Ool00`00Oomoo`1YOol003moo`03001oogoo0?moofmoo`03001oogoo0?mood9oo`03001oogoo
06Uoo`00?goo1000ogooKWoo00<007ooOol0ogoo@Woo00<007ooOol0JGoo000oOol00`00Oomoo`3o
Oom_Ool00`00Oomoo`3oOom2Ool00`00Oomoo`1YOol003moo`03001oogoo0?moofmoo`03001oogoo
0?mood5oo`03001oogoo06Yoo`00?goo00<007ooOol0ogooKgoo00<007ooOol0ogoo@Goo00<007oo
Ool0JWoo000oOol00`00Oomoo`3oOom`Ool00`00Oomoo`3oOom0Ool00`00Oomoo`1ZOol003moo`03
001oogoo0?moog1oo`03001oogoo0?mood1oo`03001oogoo06Yoo`00?goo00<007ooOol0ogooL7oo
00<007ooOol0ogoo@7oo00<007ooOol0JWoo000oOol00`00Oomoo`3oOom`Ool00`00Oomoo`3oOom0
Ool00`00Oomoo`1ZOol003moo`03001oogoo0?moog1oo`03001oogoo0?mood1oo`03001oogoo06Yo
o`00?goo00<007ooOol0ogooL7oo00<007ooOol0ogoo@7oo00<007ooOol0JWoo000oOol00`00Oomo
o`3oOom`Ool00`00Oomoo`3oOom0Ool00`00Oomoo`1ZOol003moo`03001oogoo0?moog1oo`03001o
ogoo0?mood1oo`03001oogoo06Yoo`00?goo00<007ooOol0ogooL7oo00<007ooOol0ogoo?goo00<0
07ooOol0Jgoo000oOol00`00Oomoo`3oOom`Ool00`00Oomoo`3oOoloOol00`00Oomoo`1[Ool003mo
o`@00?moofmoo`03001oogoo0?moocmoo`03001oogoo06]oo`00?goo00<007ooOol0ogooLGoo00<0
07ooOol0ogoo?Woo00<007ooOol0Jgoo000oOol00`00Oomoo`3oOomaOol00`00Oomoo`3oOolnOol0
0`00Oomoo`1[Ool003moo`03001oogoo0?moog5oo`03001oogoo0?mooceoo`03001oogoo06aoo`00
?goo00<007ooOol0ogooLGoo00<007ooOol0ogoo?Goo00<007ooOol0K7oo000oOol00`00Oomoo`3o
OomaOol00`00Oomoo`3oOolmOol00`00Oomoo`1/Ool003moo`03001oogoo0?moog9oo`03001oogoo
0?moocaoo`03001oogoo06aoo`00?goo00<007ooOol0ogooLWoo00<007ooOol0ogoo?7oo00<007oo
Ool0K7oo000oOol00`00Oomoo`3oOombOol00`00Oomoo`3oOolkOol00`00Oomoo`1]Ool003moo`03
001oogoo0?moog9oo`03001oogoo0?mooc]oo`03001oogoo06eoo`00?goo00<007ooOol0ogooLWoo
00<007ooOol0ogoo>goo00<007ooOol0KGoo000oOol00`00Oomoo`3oOomcOol00`00Oomoo`3oOolj
Ool00`00Oomoo`1]Ool003moo`03001oogoo0?moog=oo`03001oogoo0?moocYoo`03001oogoo06eo
o`00?goo1000ogooLWoo00<007ooOol0ogoo>Woo00<007ooOol0KGoo000oOol00`00Oomoo`3oOomc
Ool00`00Oomoo`3oOoljOol00`00Oomoo`1]Ool003moo`03001oogoo0?moog=oo`03001oogoo0?mo
ocYoo`03001oogoo06eoo`00?goo00<007ooOol0ogooLgoo00<007ooOol0ogoo>Goo00<007ooOol0
KWoo000oOol00`00Oomoo`3oOomcOol00`00Oomoo`3oOoliOol00`00Oomoo`1^Ool003moo`03001o
ogoo0?moog=oo`03001oogoo0?moocUoo`03001oogoo06ioo`00?goo00<007ooOol0ogooLgoo00<0
07ooOol0ogoo57oo100087oo00<007ooOol0Kgoo0007Ool4000>Ool3000?Ool5000?Ool00`00Oomo
o`3oOomdOol00`00Oomoo`3oOolCOol01000Oomoo`0087oo00<007ooOol0Kgoo0005Ool8000;Ool5
000<Ool8000>Ool00`00Oomoo`3oOomdOol00`00Oomoo`3oOolBOol00`00Oomoo`02Ool00`00Oomo
o`0MOol00`00Oomoo`1_Ool000Eoo`8000Aoo`8000]oo`D000aoo`8000Aoo`<000eoo`03001oogoo
0?moogAoo`03001oogoo0?mooa9oo`03001oogoo009oo`03001oogoo01aoo`03001oogoo071oo`00
17oo0P001Woo0P002Woo1@002goo0P001Woo0`0037oo00<007ooOol0ogooMGoo00<007ooOol0oGoo
0P0047oo00<007ooOol017oo00<007ooOol06goo00<007ooOol0L7oo0004Ool20006Ool2000;Ool3
000;Ool20008Ool2000<Ool00`00Oomoo`3oOomeOol00`00Oomoo`3lOol200000goo001oo`0=Ool0
0`00Oomoo`06Ool00`00Oomoo`0JOol00`00Oomoo`1`Ool000=oo`8000Qoo`8001Qoo`8000Qoo`80
00aoo`03001oogoo0?moogEoo`03001oogoo0?]oo`03001oogoo009oo`03001oogoo00]oo`03001o
ogoo00Ioo`03001oogoo01Yoo`03001oogoo071oo`000goo0P0027oo0P0067oo0P0027oo0P0037oo
00<007ooOol0ogooMGoo00<007ooOol0ngoo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol0
1goo00<007ooOol06Woo00<007ooOol0L7oo0003Ool20008Ool2000HOol20008Ool2000<Ool6003o
OomcOol00`00Oomoo`3iOol00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomo
o`0;Ool00`00Oomoo`0;Ool00`00Oomoo`1`Ool000=oo`8000Qoo`8001Qoo`<000Ioo`<000aoo`03
001oogoo0?moogIoo`03001oogoo0?Uoo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo00Qo
o`03001oogoo00Uoo`800003Ool0000000Yoo`03001oogoo075oo`000goo0P0027oo0P0067oo1000
17oo0`003Goo00<007ooOol0ogooMWoo00<007ooOol0jGoo100037oo00<007ooOol01Goo00<007oo
Ool027oo00<007ooOol02Goo00<007ooOol01goo00<007ooOol00goo0P001goo00<007ooOol0LWoo
0003Ool20008Ool2000HOol200000goo00000005000>Ool00`00Oomoo`3oOomfOol00`00Oomoo`3X
Ool01000Oomoogoo0P002Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol02goo00<007oo
Ool017oo0P001goo00<007ooOol01Goo00<007ooOol0LWoo0003Ool20008Ool2000IOol00`00Oomo
o`05000?Ool00`00Oomoo`3oOomfOol00`00Oomoo`3WOol00`00Oomoo`04Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`07Ool2
0004Ool00`00Oomoo`1cOol000=oo`8000Qoo`8001Uoo`8001Eoo`03001oogoo0?moogIoo`03001o
ogoo0>Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo00Ioo`03001o
ogoo00aoo`04001oogooOol2000<Ool200000goo0000001eOol000Aoo`8000Ioo`8001Yoo`<001Ao
o`03001oogoo0?moogMoo`03001oogoo0=Eoo`H000Uoo`8000Qoo`03001oogoo00Aoo`03001oogoo
00Yoo`03001oogoo00Aoo`03001oogoo00ioo`<000moo`8007Moo`0017oo0P001Woo0P006goo0`00
4goo00<007ooOol0ogooMgoo00<007ooOol0dgoo0P001Woo0P001Woo00<007ooOol027oo00<007oo
Ool017oo00<007ooOol02Woo00<007ooOol00goo00<007ooOol0VWoo0005Ool20004Ool2000MOol3
000BOol00`00Oomoo`3oOomgOol00`00Oomoo`34Ool50008Ool2000:Ool20002Ool2000<Ool20004
Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`2JOol000Eoo`P001ioo`P000aoo`03001o
ogoo0?moogQoo`03001oogoo0<5oo`8000Aoo`@0009oo`@000eoo`80011oo`04001oo`00000>Ool0
0`00Oomoo`02Ool00`00Oomoo`2JOol000Moo`@0029oo`H000aoo`03001oogoo0?moogQoo`03001o
ogoo0;=oo`H000Moo`03001oogoo00Moo`@0029oo`80015oo`04001oogoo002MOol003moo`03001o
ogoo0?moogUoo`03001oogoo0:Moo`8000Qoo`8000Eoo`<00004Ool000000014Ool2002NOol003mo
o`03001oogoo0?moogUoo`03001oogoo0:Eoo`800003Ool00000008000=oo`8000Yoo`800>Ioo`00
?goo1000ogooN7oo00<007ooOol0V7oo1@001Goo0`001goo1000lgoo000oOol00`00Oomoo`3oOomi
Ool00`00Oomoo`2FOol30004Ool6003oOol1Ool003moo`03001oogoo0?moogYoo`03001oogoo08Yo
o`/00?moo`ioo`00?goo00<007ooOol0ogooNWoo00<007ooOol0QGoo1@00ogoo6Goo000oOol00`00
Oomoo`3oOomkOol00`00Oomoo`1iOol;003oOolNOol003moo`03001oogoo0?moog]oo`03001oogoo
06moo`/00?moobQoo`00?goo00<007ooOol0ogooO7oo00<007ooOol0Hgoo2`00ogoo<goo000oOol0
0`00Oomoo`3oOommOol00`00Oomoo`1NOol4003oOolnOol003moo`03001oogoo0?moogeoo`03001o
ogoo05Aoo`X00?mood9oo`00?goo00<007ooOol0ogooOGoo00<007ooOol0BWoo2`00ogooBgoo000o
Ool00`00Oomoo`3oOomnOol00`00Oomoo`0oOol;003oOomEOol003moo`03001oogoo0?moogmoo`80
03Ioo`X00?mooemoo`00?goo00<007ooOol0ogooP7oo00<007ooOol0;7oo2@00ogooJ7oo000oOol0
0`00Oomoo`3oOon1Ool3000SOol8003oOomaOol003moo`@00?mooh9oo`8001Qoo`X00?moogUoo`00
?goo00<007ooOol0ogooQGoo0P0037oo2`00ogooPWoo000oOol00`00Oomoo`3oOon7Ool=003oOon<
Ool003moo`03001oogoo0?mooomooomoob5oo`00?goo00<007ooOol0ogooogooogoo8Goo000oOol0
0`00Oomoo`3oOoooOoooOolQOol003moo`03001oogoo0?mooomooomoob5oo`00?goo00<007ooOol0
ogooogooogoo8Goo000oOol00`00Oomoo`3oOoooOoooOolQOol003moo`03001oogoo0?mooomooomo
ob5oo`00?goo00<007ooOol0ogooogooogoo8Goo000oOol00`00Oomoo`3oOoooOoooOolQOol003mo
o`03001oogoo0?mooomooomoob5oo`00?goo1000ogooogooogoo87oo000oOol00`00Oomoo`3oOooo
OoooOolQOol003moo`03001oogoo0?mooomooomoob5oo`00?goo00<007ooOol0ogooogooogoo8Goo
000oOol00`00Oomoo`3oOoooOoooOolQOol003moo`03001oogoo0?mooomooomoob5oo`00?goo00<0
07ooOol0ogooogooogoo8Goo000oOol00`00Oomoo`3oOoooOoooOolQOol003moo`03001oogoo0?mo
oomooomoob5oo`00?goo00<007ooOol0ogooogooogoo8Goo000oOol00`00Oomoo`3oOoooOoooOolQ
Ool003moo`03001oogoo0?mooomooomoob5oo`00?goo00<007ooOol0ogooogooogoo8Goo000oOol0
0`00Oomoo`3oOoooOoooOolQOol003moo`@00?mooomooomoob1oo`00?goo00<007ooOol0ogooogoo
ogoo8Goo000oOol00`00Oomoo`3oOoooOoooOolQOol003moo`03001oogoo0?mooomooomoob5oo`00
?goo00<007ooOol0ogooogooogoo8Goo000oOol00`00Oomoo`3oOoooOoooOolQOol003moo`03001o
ogoo0?mooomooomoob5oo`00?goo00<007ooOol0ogooogooogoo8Goo000oOol00`00Oomoo`3oOooo
OoooOolQOol003moo`03001oogoo0?mooomooomoob5oo`00?goo00<007ooOol0ogooogooogoo8Goo
000oOol00`00Oomoo`3oOoooOoooOolQOol003moo`03001oogoo0?mooomooomoob5oo`00?goo00<0
07ooOol0ogooogooogoo8Goo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo0000\
\>"], "Graphics",
  CellLabel->"From (Dialog) In[48]:=",
  Evaluatable->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
and below the corresponding crosstalk on line 2, it has grown quite \
a bit :\
\>", "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P00025A000`40O003h00OogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo000[Ool4000>Ool3000:Ool<
003oOoooOoooOol=Ool002Uoo`P000]oo`D000Uoo``00?mooomooomoo`eoo`00:Goo0P0017oo0P00
2goo1@002Woo0`001Woo0P00ogooogooogoo3Goo000XOol20006Ool2000:Ool5000;Ool3003oOooo
OoooOolDOol002Qoo`8000Ioo`8000]oo`<000eoo`<00?mooomooomooa=oo`0057oo3@001Woo0P00
27oo0P006goo0`00ogooogooogoo4Woo000DOol=0006Ool20008Ool2000LOol3003oOoooOoooOolA
Ool001Aoo`d000Ioo`8000Qoo`8001eoo`<0011oo`D00?mooomoooYoo`009goo0P0027oo0P007Woo
0`003goo00<007ooOol0ogooogooo7oo000WOol20008Ool2000OOol3000>Ool00`00Oomoo`3oOooo
OoolOol002Moo`8000Qoo`80021oo`8000ioo`03001oogoo0?mooomoooaoo`009goo0P0027oo0P00
8Goo0P003Goo00<007ooOol0ogooogooo7oo000WOol20008Ool2000QOol2000=Ool00`00Oomoo`3o
OoooOoolOol002Qoo`8000Ioo`8001Uoo`8000Moo`8000eoo`03001oogoo0?mooomoooaoo`00:7oo
0P001Woo0P006Goo0`001Woo0P003Goo00<007ooOol0ogooogooo7oo000YOol20004Ool2000JOol4
0004Ool2000>Ool00`00Oomoo`3oOoooOoolOol002Uoo`P001]oo`P000moo`03001oogoo0?mooomo
ooaoo`00:goo10007goo1@0047oo00<007ooOol0ogooogooo7oo001SOol3003oOoooOoolOol006=o
o`03001oogoo0?mooomoooaoo`00Hgoo00<007ooOol0ogooogooo7oo001SOol00`00Oomoo`3oOooo
OoolOol006=oo`03001oogoo0?mooomoooaoo`00Hgoo00<007ooOol0ogooogooo7oo001SOol00`00
Oomoo`3oOoooOoolOol006=oo`03001oogoo0?mooomoooaoo`00Hgoo00<007ooOol0ogooogooo7oo
001SOol00`00Oomoo`3oOoooOoolOol006=oo`03001oogoo0?mooomoooaoo`00Hgoo00<007ooOol0
ogooogooo7oo001SOol3003oOoooOoolOol006=oo`03001oogoo0?mooomoooaoo`00Hgoo00<007oo
Ool0ogooogooo7oo001SOol00`00Oomoo`3oOoooOoolOol006=oo`03001oogoo0?moodmoo`03001o
ogoo0?moojYoo`00Hgoo00<007ooOol0ogooCgoo0P00ogooZgoo001SOol00`00Oomoo`3oOom>Ool0
1000Oomoo`00ogooZWoo001SOol00`00Oomoo`3oOom>Ool01000Oomoo`00ogooZWoo001SOol00`00
Oomoo`3oOom=Ool00`00Oomoo`02Ool00`00Oomoo`3oOonWOol006=oo`03001oogoo0?moodeoo`03
001oogoo009oo`03001oogoo0?moojMoo`00Hgoo00<007ooOol0ogooC7oo00<007ooOol00goo00<0
07ooOol0ogooYgoo001SOol3003oOom<Ool00`00Oomoo`03Ool00`00Oomoo`3oOonWOol006=oo`03
001oogoo0?moodaoo`03001oogoo00=oo`03001oogoo0?moojMoo`00Hgoo00<007ooOol0ogooC7oo
00<007ooOol00goo00<007ooOol0ogooYgoo001SOol00`00Oomoo`3oOom<Ool00`00Oomoo`04Ool0
0`00Oomoo`3oOonVOol006=oo`03001oogoo0?moodaoo`03001oogoo00Aoo`03001oogoo0?moojIo
o`00Hgoo00<007ooOol0ogooC7oo00<007ooOol017oo00<007ooOol0ogooYWoo001SOol00`00Oomo
o`3oOom<Ool00`00Oomoo`04Ool00`00Oomoo`3oOonVOol006=oo`03001oogoo0?mood]oo`03001o
ogoo00Ioo`03001oogoo0?moojEoo`00Hgoo00<007ooOol0ogooBgoo00<007ooOol01Woo00<007oo
Ool0ogooYGoo001SOol00`00Oomoo`3oOom;Ool00`00Oomoo`06Ool00`00Oomoo`3oOonUOol006=o
o`03001oogoo0?mood]oo`03001oogoo00Ioo`03001oogoo0?moojEoo`00Hgoo0`00ogooBgoo00<0
07ooOol01Woo00<007ooOol0ogooYGoo001SOol00`00Oomoo`3oOom:Ool00`00Oomoo`07Ool00`00
Oomoo`3oOonUOol006=oo`03001oogoo0?moodYoo`03001oogoo00Moo`03001oogoo0?moojEoo`00
Hgoo00<007ooOol0ogooBWoo00<007ooOol01goo00<007ooOol0ogooYGoo000IOol4000>Ool3000<
Ool:0009Ool6000@Ool00`00Oomoo`3oOom:Ool00`00Oomoo`07Ool00`00Oomoo`3oOonUOol001Mo
o`P000]oo`D000]oo`X000Moo`X000ioo`03001oogoo0?moodYoo`03001oogoo00Moo`03001oogoo
0?moojEoo`005goo0P0017oo0P002goo1@003goo0P002goo0`001Goo0`003Goo00<007ooOol0ogoo
BWoo00<007ooOol027oo00<007ooOol0ogooY7oo000FOol20006Ool2000:Ool5000?Ool2000DOol2
000=Ool00`00Oomoo`3oOom:Ool00`00Oomoo`08Ool00`00Oomoo`3oOonTOol001Ioo`8000Ioo`80
00]oo`<0011oo`8001Eoo`8000aoo`03001oogoo0?moodYoo`03001oogoo00Qoo`03001oogoo0?mo
ojAoo`000Woo3@001Woo0P0027oo0P007Goo0P005Goo0P0037oo00<007ooOol0ogooBWoo00<007oo
Ool027oo00<007ooOol0ogooY7oo0002Ool=0006Ool20008Ool2000MOol2000EOol2000<Ool00`00
Oomoo`3oOom:Ool00`00Oomoo`08Ool00`00Oomoo`3oOonTOol0009oo`d000Ioo`8000Qoo`8001eo
o`8001Eoo`8000aoo`D00?moodQoo`03001oogoo00Qoo`03001oogoo0?moojAoo`005Goo0P0027oo
0P007Goo0P005Goo0P0037oo00<007ooOol0ogooBWoo00<007ooOol02Goo00<007ooOol0ogooXgoo
000EOol20008Ool2000MOol2000DOol2000=Ool00`00Oomoo`3oOom:Ool00`00Oomoo`09Ool00`00
Oomoo`3oOonSOol001Eoo`8000Qoo`8001eoo`8000aoo`8000Eoo`<000eoo`03001oogoo0?moodUo
o`03001oogoo00Yoo`03001oogoo0?mooj=oo`005Goo0P0027oo0P007Goo0P0037oo2@003Woo00<0
07ooOol0ogooBGoo00<007ooOol02Woo00<007ooOol0ogooXgoo000EOol20008Ool2000MOol2000<
Ool200000goo00000003000?Ool00`00Oomoo`3oOom9Ool00`00Oomoo`0:Ool00`00Oomoo`3oOonS
Ool001Ioo`8000Ioo`8001ioo`8000aoo`8001Eoo`03001oogoo0?moodUoo`03001oogoo00Yoo`03
001oogoo0?mooj=oo`005Woo0P001Woo0P007Woo0P0037oo0P005Goo00<007ooOol0ogooBGoo00<0
07ooOol02goo00<007ooOol0ogooXWoo000GOol20004Ool2000KOol300000goo0000000<Ool2000E
Ool00`00Oomoo`3oOom9Ool00`00Oomoo`0;Ool00`00Oomoo`3oOonROol001Moo`P001]oo`H000ao
o`X000eoo`03001oogoo0?moodUoo`03001oogoo00]oo`03001oogoo0?mooj9oo`006Goo100087oo
0`0037oo2P003Goo00<007ooOol0ogooB7oo00<007ooOol037oo00<007ooOol0ogooXWoo001SOol0
0`00Oomoo`3oOom8Ool00`00Oomoo`0<Ool00`00Oomoo`3oOonROol006=oo`<00?moodQoo`03001o
ogoo00aoo`03001oogoo0?mooj9oo`00Hgoo00<007ooOol0ogooB7oo00<007ooOol037oo00<007oo
Ool0ogooXWoo001SOol00`00Oomoo`3oOom8Ool00`00Oomoo`0<Ool00`00Oomoo`3oOonROol006=o
o`03001oogoo0?moodQoo`03001oogoo00aoo`03001oogoo0?mooj9oo`00Hgoo00<007ooOol0ogoo
B7oo00<007ooOol037oo00<007ooOol0ogooXWoo001SOol00`00Oomoo`3oOom8Ool00`00Oomoo`0<
Ool00`00Oomoo`3oOonROol006=oo`03001oogoo0?moodMoo`03001oogoo00eoo`03001oogoo0?mo
oj9oo`00Hgoo00<007ooOol0ogooAgoo00<007ooOol03Goo00<007ooOol0ogooXWoo001SOol00`00
Oomoo`3oOom7Ool00`00Oomoo`0>Ool00`00Oomoo`3oOonQOol006=oo`03001oogoo0?moodMoo`03
001oogoo00ioo`03001oogoo0?mooj5oo`00Hgoo00<007ooOol0ogooAgoo00<007ooOol03Woo00<0
07ooOol0ogooXGoo001SOol3003oOom7Ool00`00Oomoo`0>Ool00`00Oomoo`3oOonQOol006=oo`03
001oogoo0?moodMoo`03001oogoo00ioo`03001oogoo0?mooj5oo`00Hgoo00<007ooOol0ogooAgoo
00<007ooOol03Woo00<007ooOol0ogooXGoo001SOol00`00Oomoo`3oOom7Ool00`00Oomoo`0>Ool0
0`00Oomoo`3oOonQOol006=oo`03001oogoo0?moodMoo`03001oogoo00moo`03001oogoo0?mooj1o
o`00Hgoo00<007ooOol0ogooAgoo00<007ooOol03goo00<007ooOol0ogooX7oo001SOol00`00Oomo
o`3oOom7Ool00`00Oomoo`0?Ool00`00Oomoo`3oOonPOol006=oo`03001oogoo0?moodMoo`03001o
ogoo00moo`03001oogoo0?mooj1oo`00Hgoo00<007ooOol0ogooAgoo00<007ooOol03goo00<007oo
Ool0ogooX7oo001SOol00`00Oomoo`3oOom7Ool00`00Oomoo`0?Ool00`00Oomoo`3oOonPOol006=o
o`03001oogoo0?moodMoo`03001oogoo00moo`03001oogoo0?mooj1oo`00Hgoo0`00ogooAWoo00<0
07ooOol04Goo00<007ooOol0ogooWgoo001SOol00`00Oomoo`3oOom6Ool00`00Oomoo`0AOol00`00
Oomoo`3oOonOOol006=oo`03001oogoo0?moodIoo`03001oogoo015oo`03001oogoo0?mooimoo`00
Hgoo00<007ooOol0ogooAWoo00<007ooOol04Goo00<007ooOol0ogooWgoo001SOol00`00Oomoo`3o
Oom6Ool00`00Oomoo`0AOol00`00Oomoo`3oOonOOol006=oo`03001oogoo0?moodIoo`03001oogoo
015oo`03001oogoo0?mooimoo`00Hgoo00<007ooOol0ogooAWoo00<007ooOol04Goo00<007ooOol0
ogooWgoo001SOol00`00Oomoo`3oOom6Ool00`00Oomoo`0AOol00`00Oomoo`3oOonOOol006=oo`03
001oogoo0?moodIoo`03001oogoo015oo`03001oogoo0?mooimoo`00Hgoo00<007ooOol0ogooAGoo
00<007ooOol04Woo00<007ooOol0ogooWgoo001SOol00`00Oomoo`3oOom5Ool00`00Oomoo`0BOol0
0`00Oomoo`3oOonOOol006=oo`<00?moodEoo`03001oogoo019oo`03001oogoo0?mooimoo`00Hgoo
00<007ooOol0ogooAGoo00<007ooOol04Woo00<007ooOol0ogooWgoo001SOol00`00Oomoo`3oOom5
Ool00`00Oomoo`0BOol00`00Oomoo`3oOonOOol006=oo`03001oogoo0?moodEoo`03001oogoo019o
o`03001oogoo0?mooimoo`00Hgoo00<007ooOol0ogooAGoo00<007ooOol04goo00<007ooOol0ogoo
WWoo000[Ool4000>Ool3000<Ool:000=Ool00`00Oomoo`3oOom5Ool00`00Oomoo`0COol00`00Oomo
o`3oOonNOol002Uoo`P000]oo`D000]oo`X000eoo`03001oogoo0?moodAoo`03001oogoo01Aoo`03
001oogoo0?mooiioo`00:Goo0P0017oo0P002goo1@003goo0P004Goo00<007ooOol0ogooA7oo00<0
07ooOol057oo00<007ooOol0ogooWWoo000XOol20006Ool2000:Ool5000?Ool2000AOol00`00Oomo
o`3oOom4Ool00`00Oomoo`0DOol00`00Oomoo`3oOonNOol002Qoo`8000Ioo`8000]oo`<0011oo`80
015oo`03001oogoo0?moodAoo`03001oogoo01Aoo`03001oogoo0?mooiioo`0057oo3@001Woo0P00
27oo0P007Goo0P004Goo00<007ooOol0ogooA7oo00<007ooOol057oo00<007ooOol0ogooWWoo000D
Ool=0006Ool20008Ool2000MOol2000AOol00`00Oomoo`3oOom4Ool00`00Oomoo`0EOol00`00Oomo
o`3oOonMOol001Aoo`d000Ioo`8000Qoo`8001eoo`80015oo`D00?mood9oo`03001oogoo01Eoo`03
001oogoo0?mooieoo`009goo0P0027oo0P007Goo0P004Goo00<007ooOol0ogooA7oo00<007ooOol0
5Goo00<007ooOol0ogooWGoo000WOol20008Ool2000MOol2000AOol00`00Oomoo`3oOom4Ool00`00
Oomoo`0EOol00`00Oomoo`3oOonMOol002Moo`8000Qoo`8001eoo`80015oo`03001oogoo0?moodAo
o`03001oogoo01Eoo`03001oogoo0?mooieoo`009goo0P0027oo0P007Goo0P004Goo00<007ooOol0
ogooA7oo00<007ooOol05Goo00<007ooOol0ogooWGoo000WOol20008Ool2000MOol2000AOol00`00
Oomoo`3oOom4Ool00`00Oomoo`0EOol00`00Oomoo`3oOonMOol002Qoo`8000Ioo`8001ioo`80015o
o`03001oogoo0?moodAoo`03001oogoo01Eoo`03001oogoo0?mooieoo`00:7oo0P001Woo0P007Woo
0P004Goo00<007ooOol0ogooA7oo00<007ooOol05Goo00<007ooOol0ogooWGoo000YOol20004Ool2
000KOol300000goo0000000AOol00`00Oomoo`3oOom4Ool00`00Oomoo`0EOol00`00Oomoo`3oOonM
Ool002Uoo`P001]oo`H0015oo`03001oogoo0?moodAoo`03001oogoo01Eoo`03001oogoo0?mooieo
o`00:goo100087oo0`004Goo00<007ooOol0ogooA7oo00<007ooOol05Goo00<007ooOol0ogooWGoo
001SOol3003oOom4Ool00`00Oomoo`0EOol00`00Oomoo`3oOonMOol006=oo`03001oogoo0?mood=o
o`03001oogoo01Ioo`03001oogoo0?mooieoo`00Hgoo00<007ooOol0ogoo@goo00<007ooOol05goo
00<007ooOol0ogooW7oo001SOol00`00Oomoo`3oOom3Ool00`00Oomoo`0GOol00`00Oomoo`3oOonL
Ool006=oo`03001oogoo0?mood=oo`03001oogoo01Moo`03001oogoo0?mooiaoo`00Hgoo00<007oo
Ool0ogoo@goo00<007ooOol05goo00<007ooOol0ogooW7oo001SOol00`00Oomoo`3oOom3Ool00`00
Oomoo`0GOol00`00Oomoo`3oOonLOol006=oo`03001oogoo0?mood=oo`03001oogoo01Moo`03001o
ogoo0?mooiaoo`00Hgoo00<007ooOol0ogoo@goo00<007ooOol05goo00<007ooOol0ogooW7oo001S
Ool00`00Oomoo`3oOom2Ool00`00Oomoo`0IOol00`00Oomoo`3oOonKOol006=oo`03001oogoo0?mo
od9oo`03001oogoo01Uoo`03001oogoo0?mooi]oo`00Hgoo0`00ogoo@Woo00<007ooOol06Goo00<0
07ooOol0ogooVgoo001SOol00`00Oomoo`3oOom2Ool00`00Oomoo`0IOol00`00Oomoo`3oOonKOol0
06=oo`03001oogoo0?mood9oo`03001oogoo01Uoo`03001oogoo0?mooi]oo`00Hgoo00<007ooOol0
ogoo@Woo00<007ooOol06Goo00<007ooOol0ogooVgoo001SOol00`00Oomoo`3oOom2Ool00`00Oomo
o`0JOol00`00Oomoo`3oOonJOol006=oo`03001oogoo0?mood9oo`03001oogoo01Yoo`03001oogoo
0?mooiYoo`00Hgoo00<007ooOol0ogoo@Woo00<007ooOol06Woo00<007ooOol0ogooVWoo001SOol0
0`00Oomoo`3oOom2Ool00`00Oomoo`0JOol00`00Oomoo`3oOonJOol006=oo`03001oogoo0?mood9o
o`03001oogoo01Yoo`03001oogoo0?mooiYoo`00Hgoo00<007ooOol0ogoo@Woo00<007ooOol06Woo
00<007ooOol0ogooVWoo001SOol00`00Oomoo`3oOom2Ool00`00Oomoo`0JOol00`00Oomoo`3oOonJ
Ool006=oo`<00?mood9oo`03001oogoo01Yoo`03001oogoo0?mooiYoo`00Hgoo00<007ooOol0ogoo
@Woo00<007ooOol06Woo00<007ooOol0ogooVWoo001SOol00`00Oomoo`3oOom2Ool00`00Oomoo`0J
Ool00`00Oomoo`3oOonJOol006=oo`03001oogoo0?mood9oo`03001oogoo01Yoo`03001oogoo0?mo
oiYoo`00Hgoo00<007ooOol0ogoo@Goo00<007ooOol06goo00<007ooOol0ogooVWoo001SOol00`00
Oomoo`3oOom1Ool00`00Oomoo`0KOol00`00Oomoo`3oOonJOol006=oo`03001oogoo0?mood5oo`03
001oogoo01aoo`03001oogoo0?mooiUoo`00Hgoo00<007ooOol0ogoo@Goo00<007ooOol077oo00<0
07ooOol0ogooVGoo001SOol00`00Oomoo`3oOom1Ool00`00Oomoo`0LOol00`00Oomoo`3oOonIOol0
06=oo`03001oogoo0?mood5oo`03001oogoo01aoo`03001oogoo0?mooiUoo`00Hgoo00<007ooOol0
ogoo@Goo00<007ooOol077oo00<007ooOol0ogooVGoo001SOol00`00Oomoo`3oOom0Ool00`00Oomo
o`0MOol00`00Oomoo`3oOonIOol006=oo`<00?mood1oo`03001oogoo01ioo`03001oogoo0?mooiQo
o`00Hgoo00<007ooOol0ogoo@7oo00<007ooOol07Woo00<007ooOol0ogooV7oo001SOol00`00Oomo
o`3oOom0Ool00`00Oomoo`0NOol00`00Oomoo`3oOonHOol006=oo`03001oogoo0?mood1oo`03001o
ogoo01ioo`03001oogoo0?mooiQoo`006Goo10003Woo0`003goo100037oo1P0047oo00<007ooOol0
ogoo@7oo00<007ooOol07Woo00<007ooOol0ogooV7oo000GOol8000;Ool5000<Ool80008Ool:000>
Ool00`00Oomoo`3oOom0Ool00`00Oomoo`0NOol00`00Oomoo`3oOonHOol001Moo`8000Aoo`8000]o
o`D000aoo`8000Aoo`8000Qoo`<000Eoo`<000eoo`03001oogoo0?moocmoo`03001oogoo021oo`03
001oogoo0?mooiMoo`005Woo0P001Woo0P002Woo1@002goo0P001Woo0P0047oo0P003Goo00<007oo
Ool0ogoo?goo00<007ooOol087oo00<007ooOol0ogooUgoo000FOol20006Ool2000;Ool3000<Ool2
0006Ool2000AOol2000<Ool00`00Oomoo`3oOoloOol00`00Oomoo`0POol00`00Oomoo`3oOonGOol0
009oo`d000Ioo`8000Qoo`8001Qoo`8000Qoo`80011oo`8000aoo`03001oogoo0?moocmoo`03001o
ogoo021oo`03001oogoo0?mooiMoo`000Woo3@001Woo0P0027oo0P0067oo0P0027oo0P0047oo0P00
37oo00<007ooOol0ogoo?goo00<007ooOol087oo00<007ooOol0ogooUgoo0002Ool=0006Ool20008
Ool2000HOol20008Ool2000@Ool2000<Ool5003oOolmOol00`00Oomoo`0POol00`00Oomoo`3oOonG
Ool001Eoo`8000Qoo`8001Qoo`8000Qoo`80011oo`8000aoo`03001oogoo0?moocmoo`03001oogoo
021oo`03001oogoo0?mooiMoo`005Goo0P0027oo0P0067oo0P0027oo0P003goo0P003Goo00<007oo
Ool0ogoo?goo00<007ooOol087oo00<007ooOol0ogooUgoo000EOol20008Ool2000HOol20008Ool2
0007Ool20005Ool3000=Ool00`00Oomoo`3oOoloOol00`00Oomoo`0POol00`00Oomoo`3oOonGOol0
01Eoo`8000Qoo`8001Qoo`8000Qoo`8000Moo`T000ioo`03001oogoo0?moocmoo`03001oogoo021o
o`03001oogoo0?mooiMoo`005Goo0P0027oo0P0067oo0P0027oo0P001goo0P0000=oo`0000000`00
3goo00<007ooOol0ogoo?goo00<007ooOol08Goo00<007ooOol0ogooUWoo000FOol20006Ool2000J
Ool20006Ool20008Ool2000EOol00`00Oomoo`3oOoloOol00`00Oomoo`0QOol00`00Oomoo`3oOonF
Ool001Ioo`8000Ioo`8001Yoo`8000Ioo`8000Qoo`8001Eoo`03001oogoo0?moocmoo`03001oogoo
025oo`03001oogoo0?mooiIoo`005goo0P0017oo0P0077oo0P0017oo0P002Goo0P005Goo00<007oo
Ool0ogoo?goo00<007ooOol08Goo00<007ooOol0ogooUWoo000GOol8000LOol80009Ool:000=Ool0
0`00Oomoo`3oOolnOol00`00Oomoo`0SOol00`00Oomoo`3oOonEOol001Uoo`@0021oo`@000]oo`X0
00eoo`03001oogoo0?moocioo`03001oogoo02=oo`03001oogoo0?mooiEoo`00Hgoo0`00ogoo?Woo
00<007ooOol08goo00<007ooOol0ogooUGoo001SOol00`00Oomoo`3oOolnOol00`00Oomoo`0SOol0
0`00Oomoo`3oOonEOol006=oo`03001oogoo0?moocioo`03001oogoo02=oo`03001oogoo0?mooiEo
o`00Hgoo00<007ooOol0ogoo?Woo00<007ooOol08goo00<007ooOol0ogooUGoo001SOol00`00Oomo
o`3oOolmOol00`00Oomoo`0TOol00`00Oomoo`3oOonEOol006=oo`03001oogoo0?mooceoo`03001o
ogoo02Aoo`03001oogoo0?mooiEoo`00Hgoo00<007ooOol0ogoo?Goo00<007ooOol097oo00<007oo
Ool0ogooUGoo001SOol00`00Oomoo`3oOolmOol00`00Oomoo`0UOol00`00Oomoo`3oOonDOol006=o
o`03001oogoo0?mooceoo`03001oogoo02Eoo`03001oogoo0?mooiAoo`00Hgoo00<007ooOol0ogoo
?7oo00<007ooOol09Woo00<007ooOol0ogooU7oo001SOol00`00Oomoo`3oOollOol00`00Oomoo`0W
Ool00`00Oomoo`3oOonCOol006=oo`<00?moocaoo`03001oogoo02Moo`03001oogoo0?mooi=oo`00
Hgoo00<007ooOol0ogoo?7oo00<007ooOol09goo00<007ooOol0ogooTgoo001SOol00`00Oomoo`3o
OollOol00`00Oomoo`0WOol00`00Oomoo`3oOonCOol006=oo`03001oogoo06aoo``000aoo`L000Yo
o`@000ioo`@005=oo``000]oo`D000eoo`@000ioo`@002Uoo`03001oogoo02Ioo``000Yoo`H000eo
o`@000ioo`@005Moo`D000ioo`@000ioo`@000ioo`@005Ioo`D000Uoo``000]oo`@000ioo`@000Uo
o`00Hgoo00<007ooOol0K7oo300037oo1`0027oo20002Woo2000DGoo30002Goo20002Woo20002Woo
20009goo00<007ooOol09Woo30002Goo20002Woo20002Woo2000Dgoo2@002Woo20002Woo20002Woo
2000DWoo2@001goo30002Goo20002Woo20001goo001SOol00`00Oomoo`1]Ool30006Ool2000?Ool2
000:Ool20004Ool2000:Ool20004Ool2001BOol30006Ool20009Ool20004Ool30009Ool20004Ool2
000:Ool20002Ool01000Ool000009goo00<007ooOol09goo0`001Woo0P0027oo0`0017oo0`002Goo
0P0017oo0P002Woo0P0017oo0P00DWoo100017oo0`002Goo0P0017oo0P002Woo0P0017oo0P002Woo
0P0017oo0P00DGoo100017oo0`001goo0`001Woo0P002Goo0P0017oo0P002Woo0P0017oo0P001goo
001SOol00`00Oomoo`1^Ool3000FOol20009Ool20006Ool20008Ool20006Ool2001BOol3000?Ool2
0006Ool30007Ool20006Ool20008Ool20003Ool00`00Oomoo`02000VOol00`00Oomoo`0XOol3000>
Ool30006Ool30007Ool20006Ool20008Ool20006Ool2001AOol20007Ool30007Ool20006Ool20008
Ool20006Ool20008Ool20006Ool2001@Ool20007Ool30007Ool3000?Ool20006Ool20008Ool20006
Ool20006Ool006=oo`03001oogoo06moo`<001Eoo`8000Uoo`8000Ioo`8000Qoo`8000Ioo`8005=o
o`<000eoo`8000Qoo`8000Moo`8000Ioo`8000Qoo`8000=oo`03001oogoo008002Ioo`03001oogoo
02Uoo`<000eoo`8000Qoo`8000Moo`8000Ioo`8000Qoo`8000Ioo`8005]oo`8000Moo`8000Ioo`80
00Qoo`8000Ioo`8000Qoo`8000Ioo`8001Yoo`<003eoo`8000Qoo`<000ioo`8000Ioo`8000Qoo`80
00Ioo`8000Ioo`00Hgoo00<007ooOol0L7oo0`0037oo30001Woo0P0027oo0P001Woo0P0027oo0P00
Dgoo0`0037oo0P0027oo0P001Woo0P0027oo0P001Woo0P000goo00<007ooOol00Woo0P009Goo00<0
07ooOol0:Woo0`0037oo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P00FWoo0P001Woo0P00
27oo0P001Woo0P0027oo0P001Woo0P0027oo0P0067oo00D007ooOomoo`0003aoo`8000Uoo`<000ao
o`8000Qoo`8000Ioo`8000Qoo`8000Eoo`00Hgoo00<007ooOol0LGoo0`002goo30001Woo0P0027oo
0P001Woo0P0027oo0P00E7oo0`002goo0P0027oo0P001Woo0P0027oo0P001Woo0P000goo00<007oo
Ool00Woo0P009Woo00<007ooOol0:Woo0`002goo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo
0P00FWoo0P001Woo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P0067oo00D007ooOomoo`00
03aoo`8000Yoo`<000]oo`8000Qoo`8000Ioo`8000Qoo`8000Eoo`00Hgoo00<007ooOol0LWoo0`00
2Woo0P001Woo0P0000=oo`00Ool01Goo0P0027oo0P001Woo0P0027oo0P00EGoo0`002Woo0P0027oo
0P001Woo0P0027oo0P001Woo0P000goo00<007ooOol00Woo0P009Woo00<007ooOol0:goo0`002Woo
0`001Woo0`001Woo0P0027oo0P001Woo0P0027oo0P00FGoo0`001Woo0P0027oo0P001Woo0P0027oo
0P001Woo0P0027oo0P0067oo00<007ooOol00Woo00<007ooOol0>7oo0`002goo0`002Woo0P0027oo
0P001Woo0P0027oo0P001Goo001SOol00`00Oomoo`1cOol3000:Ool20005Ool20008Ool20008Ool2
0006Ool20008Ool2001FOol30009Ool30006Ool30006Ool20008Ool20006Ool20003Ool00`00Oomo
o`02Ool2000VOol00`00Oomoo`0/Ool3000:Ool30004Ool30007Ool20008Ool20006Ool20008Ool2
001HOol30007Ool20008Ool20006Ool20008Ool20006Ool20008Ool2000GOol00`00Oomoo`04Ool0
0`00Oomoo`0fOol3000=Ool30009Ool20008Ool20006Ool20008Ool20005Ool006=oo`<007Aoo`<0
00Uoo`<000Aoo`8000Qoo`8000Qoo`8000Ioo`8000Qoo`8005Moo`<000Qoo`@000Aoo`<000Moo`80
00Qoo`8000Ioo`8000=oo`03001oogoo009oo`8002Moo`03001oogoo02aoo`<000Yoo`P000Qoo`80
00Qoo`8000Ioo`8000Qoo`8005Eoo`D000Qoo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`80
01Moo`03001oogoo00Aoo`03001oogoo03=oo`D000moo`<000Qoo`8000Qoo`8000Ioo`8000Qoo`80
00Eoo`00Hgoo00<007ooOol0MGoo0P002Woo0P0017oo0P0027oo0P0027oo0P001Woo0P0027oo0P00
F7oo0P0027oo0P0000=oo`0000001@001Goo0P0000=oo`00000027oo0P001Woo0P000Woo00<007oo
Ool00goo0P009goo00<007ooOol0;Goo0P002Woo200027oo0P0027oo0P001Woo0P0027oo0P00EGoo
10002Goo0P0027oo0P001Woo0P0027oo0P001Woo0P0027oo0P005Woo00<007ooOol01Goo00<007oo
Ool0<goo10004Goo0P0027oo0P0027oo0P001Woo0P0027oo0P001Goo001SOol00`00Oomoo`1fOol2
000:Ool20003Ool20008Ool20008Ool20006Ool20008Ool2001IOol20008Ool00`00Oomoo`050006
Ool00`00Ool000020008Ool20006Ool20002Ool00`00Oomoo`03Ool2000XOol00`00Oomoo`0]Ool2
0008Ool30004Ool30007Ool20008Ool20006Ool20008Ool2001HOol20008Ool20008Ool20006Ool2
0008Ool20006Ool20008Ool2000FOol00`00Oomoo`05Ool00`00Oomoo`0fOol2000AOol20007Ool2
0008Ool20006Ool20008Ool20005Ool006=oo`03001oogoo07Ioo`8000Yoo`<0009oo`8000Qoo`80
00Qoo`8000Ioo`8000Qoo`8005Uoo`8000Qoo`8000aoo`03001oo`00008000Qoo`8000Ioo`80009o
o`03001oogoo00=oo`8002Qoo`03001oogoo02eoo`8000Moo`8000Qoo`8000Ioo`8000Qoo`8000Io
o`8000Qoo`8005Uoo`8000Moo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8001Ioo`03001o
ogoo00Ioo`03001oogoo03Ioo`80011oo`8000Moo`8000Qoo`8000Ioo`8000Qoo`8000Eoo`00Hgoo
00<007ooOol0KGoo0P001goo0P002goo0P000Woo0P002Goo0P001Woo0P0027oo0P001Woo0P00DGoo
0P001goo0P0027oo0`002Woo00@007ooOomoo`<000Ioo`8000Qoo`800003Ool007oo00=oo`8002Uo
o`03001oogoo02Aoo`8000Moo`8000Moo`8000Qoo`8000Moo`8000Ioo`8000Qoo`8000Ioo`8005Yo
o`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8001Moo`03001oogoo00Ioo`03001o
ogoo03Ioo`8000Moo`8000Moo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Ioo`00Hgoo00<007oo
Ool0KGoo0`001Woo0P0037oo0P0000=oo`0000002Goo0P001Woo0P0027oo0P001Woo0P00DGoo0`00
1Woo0P002Goo0`002Goo00@007ooOomoo`<000Ioo`8000Qoo`800003Ool007oo00=oo`8002Uoo`03
001oogoo02Aoo`<000Ioo`8000Moo`8000Qoo`8000Moo`8000Ioo`8000Qoo`8000Ioo`80059oo`80
00Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8001Ioo`03001oogoo00Moo`03
001oogoo02ioo`8000Ioo`8000Moo`<000Ioo`8000Qoo`8000Ioo`8000Qoo`8000Ioo`8000Ioo`00
Hgoo00<007ooOol0KGoo100017oo0P003Woo10002Woo0P0017oo0P002Woo0P0017oo0P00DWoo1000
17oo0P002goo0`001goo00<007ooOol00Woo00@007oo000000Aoo`8000Yoo`<000=oo`8002Yoo`03
001oogoo02Aoo`@000Aoo`8000Uoo`<000Aoo`@000Qoo`8000Aoo`8000Yoo`8000Aoo`8005=oo`<0
00Aoo`<000Uoo`8000Aoo`8000Yoo`8000Aoo`8000Yoo`8000Aoo`8001Moo`03001oogoo00Qoo`03
001oogoo02eoo`<000Aoo`<000Moo`@000Aoo`8000Yoo`8000Aoo`8000Yoo`8000Aoo`8000Moo`00
Hgoo00<007ooOol0KWoo20003goo10002Woo20002Woo2000Dgoo20003Goo200000=oo`00Ool00goo
00<007oo00001`002Woo2000:goo00<007ooOol097oo20002Woo2P002Goo20002Woo2000E7oo2000
2Woo20002Woo20002Woo20005goo00<007ooOol027oo00<007ooOol0;Woo20002Goo20002goo2000
2Woo20001goo001SOol00`00Oomoo`1`Ool5000AOol3000<Ool4000>Ool4001GOol5000@Ool60000
0goo001oo`04Ool00`00Oomoo`04000>Ool4000^Ool00`00Oomoo`0UOol5000=Ool6000=Ool4000>
Ool4001GOol5000>Ool4000>Ool4000>Ool4000HOol00`00Oomoo`09Ool00`00Oomoo`0_Ool5000=
Ool5000>Ool4000>Ool40009Ool006=oo`03001oogoo0?mooamoo`03001oogoo00=oo`03001oogoo
019oo`03001oogoo02moo`03001oogoo0?moo`]oo`03001oogoo00Uoo`03001oogoo07=oo`00Hgoo
00<007ooOol0ogoo7goo00<007ooOol00goo00<007ooOol04Goo00<007ooOol0<7oo00<007ooOol0
ogoo2goo00<007ooOol02Goo00<007ooOol0Lgoo001SOol3003oOolOOol00`00Oomoo`03Ool00`00
Oomoo`0AOol00`00Oomoo`0aOol00`00Oomoo`3eOol00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00
Oomoo`1bOol006=oo`03001oogoo0?mooaioo`03001oogoo00Eoo`03001oogoo011oo`03001oogoo
039oo`03001oogoo0?=oo`04001oo`00000@Ool00`00Oomoo`0;Ool00`00Oomoo`1bOol006=oo`03
001oogoo0?mooaioo`03001oogoo00Eoo`03001oogoo011oo`03001oogoo03=oo`03001oogoo0?5o
o`05001oogooOol0000@Ool00`00Oomoo`0;Ool00`00Oomoo`1bOol006=oo`03001oogoo0?moo`eo
o`8000moo`03001oogoo00Eoo`03001oogoo00moo`03001oogoo03Aoo`03001oogoo0?1oo`03001o
ogoo00=oo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo079oo`00Hgoo00<007ooOol0ogoo
37oo00@007ooOol000ioo`03001oogoo00Eoo`03001oogoo00moo`03001oogoo03Eoo`03001oogoo
0>moo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo075oo`00Hgoo00<0
07ooOol0ogoo37oo00@007ooOol000eoo`03001oogoo00Moo`03001oogoo00ioo`03001oogoo03Io
o`03001oogoo0>ioo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo075o
o`00Hgoo00<007ooOol0ogoo2goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol01goo00<0
07ooOol03Woo00<007ooOol0=goo00<007ooOol0fgoo00<007ooOol03Woo00<007ooOol01Goo00<0
07ooOol037oo00<007ooOol037oo00<007ooOol0LGoo001SOol00`00Oomoo`3oOol:Ool00`00Oomo
o`03Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0=Ool00`00Oomoo`0iOol2001bOol3
0008Ool40009Ool2000:Ool3000oOol6000=Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomo
o`0=Ool00`00Oomoo`1`Ool006=oo`03001oogoo0?Uoo`<000eoo`03001oogoo00Aoo`03001oogoo
00Uoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo03Yoo`@005Yoo`8000Qoo`<000Qoo`04
001oogoo0007Ool01000Oomoo`001goo0P000Woo00<007ooOol01Woo00@007ooOol000Uoo`@0025o
o`D000]oo`8000Aoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00io
o`03001oogoo071oo`00Hgoo00<007ooOol0YGoo0P002Goo0P002Goo0`002Goo0P00;goo00D007oo
Oomoo`0000]oo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00eoo`03
001oogoo03eoo`@003Moo`<000Moo`@000Ioo`@000Ioo`80009oo`03001oogoo00Aoo`05001oogoo
Ool00006Ool01@00Oomoogoo00001Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo
00<007ooOol017oo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000Qoo`D000Moo`@0
00Moo`8000Aoo`8000Uoo`03001oogoo00Eoo`8000]oo`03001oogoo00Moo`03001oogoo00Yoo`03
001oogoo00ioo`03001oogoo071oo`00Hgoo00<007ooOol0QGoo0P0027oo0`001goo10001Woo0P00
0Woo00<007ooOol017oo0P000Woo00<007ooOol01Goo00@007ooOol000Qoo`04001oo`000009Ool3
000COol50009Ool00`00Oomoo`03Ool20009Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`0=Ool00`00Oomoo`11Oolc00000goo000000020002Ool20003Ool20003Ool2
0004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool20005Ool00`00Oomoo`03Ool70003Ool20006Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomoo`0>Ool0
0`00Oomoo`1`Ool006=oool00?l00=X002Eoo`00Hgoo00<007ooOol017oo0P001Goo0`001Goo0`00
1Goo0`000goo00<007oo00000P001Goo10001Goo0`001Goo10001Goo100017oo10001Goo10001Woo
10001Woo10001goo10001Woo1@001Goo1P0017oo0P000Woo0P0017oo0P000goo00<007ooOol00goo
00<007ooOol00Woo00<007ooOol00goo0P000goo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool017oo00@007ooOomoo`8000Ioo`D000Ioo`H000Moo`03001oogoo00=oo`8000Aoo`05001oogoo
Ool00007Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`0=Ool00`00Oomoo`0;Ool00`00Oomoo`0ROol00`00Oomoo`0QOol00`00Oomoo`0QOol00`00
Oomoo`0HOol00`00Oomoo`07Ool20008Ool40008Ool00`00Ool00007Ool01@00Oomoogoo000027oo
00<007ooOol00P001goo100037oo00<007ooOol08Goo0P000Woo00<007ooOol02goo00<007ooOol0
1Goo00<007ooOol01goo00<007oo00002goo00<007ooOol03goo00<007ooOol00Woo00<007ooOol0
8Goo00<007ooOol05goo1@001Goo00<007ooOol08goo001SOol00`00Oomoo`0QOol00`00Oomoo`0Q
Ool00`00Oomoo`0ROol00`00Oomoo`0NOol01000Oomoo`001Woo0P0027oo0`001goo0P0000=oo`00
Ool01Goo00<007oo00000Woo00<007ooOol01Goo00@007ooOol000Qoo`<000Qoo`03001oogoo01Io
o`03001oogoo008000Ioo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo
00Moo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo
029oo`03001oogoo025oo`03001oogoo025oo`03001oogoo029oo`03001oogoo00Qoo`03001oogoo
00Qoo`<000Qoo`@000Uoo`8001Uoo`03001oogoo025oo`@000moo`03001oogoo00=oo`03001oogoo
00Qoo`04001oogoo000:Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0QOol00`00Oomo
o`0DOol3000:Ool00`00Oomoo`0SOol006=oo`03001oogoo025oo`03001oogoo025oo`03001oogoo
029oo`03001oogoo025oo`03001oogoo01Yoo`03001oogoo00Eoo`03001oo`00008000Uoo`8001Ao
o`03001oogoo01Moo`<000Moo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Uoo`03001o
ogoo00Ioo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo00]oo`03001o
ogoo029oo`03001oogoo025oo`03001oogoo025oo`03001oogoo029oo`03001oogoo025oo`03001o
ogoo029oo`03001oogoo025oo`03001oogoo015oo`03001oogoo009oo`03001oogoo00Qoo`04001o
ogoo0009Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool00`00Oomoo`0QOol00`00Oomoo`0BOol2000=
Ool00`00Oomoo`0SOol006=oo`03001oogoo08ioo`03001oogoo071oo`03001oogoo009oo`03001o
ogoo00Uoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00aoo`03001o
ogoo07Qoo`03001oogoo08moo`03001oogoo019oo`@000moo`03001oogoo00Ioo`03001oogoo015o
o`03001oogoo03Uoo`03001oogoo00eoo`03001oogoo02=oo`00Hgoo00<007ooOol0SWoo00<007oo
Ool0LGoo100037oo00<007ooOol01Goo00<007ooOol00goo00<007ooOol017oo00<007ooOol02goo
00<007ooOol0NGoo00<007ooOol0Sgoo00<007ooOol09Goo00<007ooOol01Woo00<007ooOol04Goo
00<007ooOol0=goo0P0047oo00<007ooOol08goo001SOol00`00Oomoo`3oOolDOol00`00Oomoo`04
Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`3oOoldOol00`00Oomoo`06Ool00`00Oomo
o`0AOol00`00Oomoo`0gOol00`00Oomoo`0eOol006=oo`03001oogoo0?mooaAoo`03001oogoo00Ao
o`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo0?moocEoo`03001oogoo00Eoo`03001oogoo
015oo`03001oogoo03Ioo`03001oogoo03Ioo`00Hgoo00<007ooOol0ogoo57oo00<007ooOol00goo
00<007ooOol037oo00<007ooOol02Goo00<007ooOol0ogoo=Woo00<007ooOol01Goo00<007ooOol0
4Woo00<007ooOol0=7oo00<007ooOol0=goo001SOol00`00Oomoo`3oOolDOol00`00Oomoo`03Ool0
0`00Oomoo`0<Ool00`00Oomoo`09Ool00`00Oomoo`3oOolfOol00`00Oomoo`04Ool00`00Oomoo`0C
Ool00`00Oomoo`0cOol00`00Oomoo`0hOol006=oo`03001oogoo0?mooaAoo`03001oogoo00=oo`03
001oogoo00aoo`03001oogoo00Uoo`03001oogoo0?moocIoo`03001oogoo00Aoo`03001oogoo01=o
o`03001oogoo03=oo`03001oogoo03Qoo`00Hgoo0`00ogoo5Goo00D007ooOomoo`0000moo`03001o
ogoo00Uoo`03001oogoo0?moocIoo`03001oogoo00Aoo`03001oogoo01=oo`03001oogoo039oo`03
001oogoo03Uoo`00Hgoo00<007ooOol0ogoo5Woo00@007ooOol000moo`03001oogoo00Qoo`03001o
ogoo0?moocQoo`03001oogoo009oo`03001oogoo01Aoo`03001oogoo039oo`03001oogoo03Uoo`00
Hgoo00<007ooOol0ogoo5goo00<007oo00003goo00<007ooOol027oo00<007ooOol0ogoo>Goo00D0
07ooOomoo`0001Moo`03001oogoo031oo`03001oogoo03Yoo`00Hgoo00<007ooOol0ogoo5goo0P00
47oo00<007ooOol027oo00<007ooOol0ogoo>Goo00D007ooOomoo`0001Moo`03001oogoo02moo`03
001oogoo03]oo`00Hgoo00<007ooOol0ogoo:Goo00<007ooOol027oo00<007ooOol0ogoo>Woo0`00
67oo00<007ooOol0;goo00<007ooOol0>goo001SOol00`00Oomoo`3oOolZOol00`00Oomoo`07Ool0
0`00Oomoo`3oOomEOol00`00Oomoo`0_Ool00`00Oomoo`0kOol006=oo`03001oogoo0?moobYoo`03
001oogoo00Moo`03001oogoo0?mooeEoo`03001oogoo02moo`03001oogoo03]oo`00Hgoo00<007oo
Ool0ogoo:Woo00<007ooOol01goo00<007ooOol0ogooEGoo00<007ooOol0;Woo00<007ooOol0?7oo
001SOol00`00Oomoo`3oOolZOol00`00Oomoo`06Ool00`00Oomoo`3oOomFOol00`00Oomoo`0^Ool0
0`00Oomoo`0lOol006=oo`03001oogoo0?moob]oo`03001oogoo00Eoo`03001oogoo0?mooeIoo`03
001oogoo02eoo`03001oogoo03eoo`00Hgoo00<007ooOol0ogoo:goo00<007ooOol01Goo00<007oo
Ool0ogooEWoo00<007ooOol0;Goo00<007ooOol0?Goo001SOol00`00Oomoo`3oOol[Ool00`00Oomo
o`04Ool00`00Oomoo`3oOomGOol00`00Oomoo`0]Ool00`00Oomoo`0mOol006=oo`<00?moob]oo`03
001oogoo00Aoo`03001oogoo0?mooeMoo`03001oogoo02eoo`03001oogoo03eoo`00Hgoo00<007oo
Ool0ogoo;7oo00<007ooOol00goo00<007ooOol0ogooF7oo00<007ooOol0;7oo00<007ooOol0?Goo
001SOol00`00Oomoo`3oOol/Ool00`00Oomoo`03Ool00`00Oomoo`3oOomHOol00`00Oomoo`0[Ool0
0`00Oomoo`0nOol006=oo`03001oogoo0?moobaoo`03001oogoo00=oo`03001oogoo0?mooeQoo`03
001oogoo02]oo`03001oogoo03ioo`00Hgoo00<007ooOol0ogoo;7oo00<007ooOol00Woo00<007oo
Ool0ogooFGoo00<007ooOol0:Woo00<007ooOol0?goo001SOol00`00Oomoo`3oOol/Ool00`00Oomo
o`02Ool00`00Oomoo`3oOomIOol00`00Oomoo`0ZOol00`00Oomoo`0oOol006=oo`03001oogoo0?mo
obeoo`04001oogoo003oOomLOol00`00Oomoo`0ZOol00`00Oomoo`0oOol006=oo`03001oogoo0?mo
obioo`800?mooeioo`03001oogoo02Qoo`03001oogoo041oo`00Hgoo00<007ooOol0ogoo;goo00<0
07ooOol0ogooG7oo00<007ooOol0:7oo00<007ooOol0@7oo001SOol00`00Oomoo`3oOoooOon>Ool0
0`00Oomoo`0XOol00`00Oomoo`10Ool006=oo`03001oogoo0?mooomoohioo`03001oogoo02Qoo`03
001oogoo041oo`00Hgoo0`00ogooogooSWoo00<007ooOol0:7oo00<007ooOol0@7oo001SOol00`00
Oomoo`3oOoooOon>Ool00`00Oomoo`0XOol00`00Oomoo`10Ool006=oo`03001oogoo0?mooomoohio
o`03001oogoo02Qoo`03001oogoo041oo`00Hgoo00<007ooOol0ogooogooSWoo00<007ooOol09goo
00<007ooOol0@Goo001SOol00`00Oomoo`3oOoooOon>Ool00`00Oomoo`0WOol00`00Oomoo`11Ool0
06=oo`03001oogoo0?mooomoohioo`03001oogoo02Moo`03001oogoo045oo`00Hgoo00<007ooOol0
ogooogooSWoo00<007ooOol09goo00<007ooOol0@Goo001SOol00`00Oomoo`3oOoooOon>Ool00`00
Oomoo`0VOol00`00Oomoo`12Ool006=oo`03001oogoo0?mooomoohmoo`03001oogoo02Eoo`03001o
ogoo049oo`00Hgoo00<007ooOol0ogooogooSgoo00<007ooOol09Goo00<007ooOol0@Woo001SOol0
0`00Oomoo`3oOoooOon?Ool00`00Oomoo`0UOol00`00Oomoo`12Ool006=oo`<00?mooomoohmoo`03
001oogoo02Aoo`03001oogoo04=oo`00Hgoo00<007ooOol0ogooogooSgoo00<007ooOol097oo00<0
07ooOol0@goo001SOol00`00Oomoo`3oOoooOon?Ool00`00Oomoo`0TOol00`00Oomoo`13Ool006=o
o`03001oogoo0?mooomoohmoo`03001oogoo02Aoo`03001oogoo04=oo`006Goo10003Woo0`003goo
100037oo1P0047oo00<007ooOol0ogooogooT7oo00<007ooOol08goo00<007ooOol0@goo000GOol8
000;Ool5000<Ool80008Ool:000>Ool00`00Oomoo`3oOoooOon@Ool00`00Oomoo`0SOol00`00Oomo
o`13Ool001Moo`8000Aoo`8000]oo`D000aoo`8000Aoo`8000Qoo`<000Eoo`<000eoo`03001oogoo
0?mooomooi1oo`03001oogoo02=oo`03001oogoo04=oo`005Woo0P001Woo0P002Woo1@002goo0P00
1Woo0P0047oo0P003Goo00<007ooOol0ogooogooT7oo00<007ooOol08goo00<007ooOol0@goo000F
Ool20006Ool2000;Ool3000<Ool20006Ool2000AOol2000<Ool00`00Oomoo`3oOoooOon@Ool00`00
Oomoo`0ROol00`00Oomoo`14Ool001Eoo`8000Qoo`8001Qoo`8000Qoo`80011oo`8000aoo`03001o
ogoo0?mooomooi1oo`03001oogoo029oo`03001oogoo04Aoo`005Goo0P0027oo0P0067oo0P0027oo
0P0047oo0P0037oo00<007ooOol0ogooogooT7oo00<007ooOol08Woo00<007ooOol0A7oo000EOol2
0008Ool2000HOol20008Ool2000@Ool2000<Ool5003oOoooOon>Ool00`00Oomoo`0ROol00`00Oomo
o`14Ool001Eoo`8000Qoo`8001Qoo`8000Qoo`80011oo`8000aoo`03001oogoo0?mooomooi5oo`03
001oogoo025oo`03001oogoo04Aoo`005Goo0P0027oo0P0067oo0P0027oo0P003goo0P003Goo00<0
07ooOol0ogooogooTGoo00<007ooOol087oo00<007ooOol0AGoo000EOol20008Ool2000HOol20008
Ool20007Ool20005Ool3000=Ool00`00Oomoo`3oOoooOonAOol00`00Oomoo`0POol00`00Oomoo`15
Ool001Eoo`8000Qoo`8001Qoo`8000Qoo`8000Moo`T000ioo`03001oogoo0?mooomooi5oo`03001o
ogoo021oo`03001oogoo04Eoo`005Goo0P0027oo0P0067oo0P0027oo0P001goo0P0000=oo`000000
0`003goo00<007ooOol0ogooogooTGoo00<007ooOol087oo00<007ooOol0AGoo000FOol20006Ool2
000JOol20006Ool20008Ool2000EOol00`00Oomoo`3oOoooOonAOol00`00Oomoo`0POol00`00Oomo
o`15Ool001Ioo`8000Ioo`8001Yoo`8000Ioo`8000Qoo`8001Eoo`03001oogoo0?mooomooi5oo`03
001oogoo021oo`03001oogoo04Eoo`005goo0P0017oo0P0077oo0P0017oo0P002Goo0P005Goo00<0
07ooOol0ogooogooTGoo00<007ooOol087oo00<007ooOol0AGoo000GOol8000LOol80009Ool:000=
Ool00`00Oomoo`3oOoooOonAOol00`00Oomoo`0POol00`00Oomoo`15Ool001Uoo`@0021oo`@000]o
o`X000eoo`03001oogoo0?mooomooi5oo`03001oogoo021oo`03001oogoo04Eoo`00Hgoo00<007oo
Ool0ogooogooTGoo00<007ooOol087oo00<007ooOol0AGoo001SOol3003oOoooOonAOol00`00Oomo
o`0POol00`00Oomoo`15Ool006=oo`03001oogoo0?mooomooi5oo`03001oogoo01moo`03001oogoo
04Ioo`00Hgoo00<007ooOol0ogooogooTGoo00<007ooOol07goo00<007ooOol0AWoo001SOol00`00
Oomoo`3oOoooOonAOol00`00Oomoo`0OOol00`00Oomoo`16Ool006=oo`03001oogoo0?mooomooi5o
o`03001oogoo01moo`03001oogoo04Ioo`00Hgoo00<007ooOol0ogooogooTWoo00<007ooOol07Woo
00<007ooOol0AWoo001SOol00`00Oomoo`3oOoooOonBOol00`00Oomoo`0NOol00`00Oomoo`16Ool0
06=oo`03001oogoo0?mooomooi9oo`03001oogoo01eoo`03001oogoo04Moo`00Hgoo00<007ooOol0
ogooogooTWoo00<007ooOol07Goo00<007ooOol0Agoo001SOol00`00Oomoo`3oOoooOonBOol00`00
Oomoo`0MOol00`00Oomoo`17Ool006=oo`03001oogoo0?mooomooi9oo`03001oogoo01eoo`03001o
ogoo04Moo`00Hgoo0`00ogooogooTWoo00<007ooOol07Goo00<007ooOol0Agoo001SOol00`00Oomo
o`3oOoooOonBOol00`00Oomoo`0MOol00`00Oomoo`17Ool006=oo`03001oogoo0?mooomooi=oo`03
001oogoo01]oo`03001oogoo04Qoo`00Hgoo00<007ooOol0ogooogooTgoo00<007ooOol06goo00<0
07ooOol0B7oo001SOol00`00Oomoo`3oOoooOonCOol00`00Oomoo`0KOol00`00Oomoo`18Ool006=o
o`03001oogoo0?mooomooi=oo`03001oogoo01]oo`03001oogoo04Qoo`00Hgoo00<007ooOol0ogoo
ogooTgoo00<007ooOol06goo00<007ooOol0B7oo001SOol00`00Oomoo`3oOoooOonCOol00`00Oomo
o`0KOol00`00Oomoo`18Ool006=oo`03001oogoo0?mooomooi=oo`03001oogoo01]oo`03001oogoo
04Qoo`00Hgoo00<007ooOol0ogooogooTgoo00<007ooOol06goo00<007ooOol0B7oo001SOol00`00
Oomoo`3oOoooOonCOol00`00Oomoo`0KOol00`00Oomoo`18Ool006=oo`<00?mooomooiAoo`03001o
ogoo01Yoo`03001oogoo04Qoo`00Hgoo00<007ooOol0ogooogooU7oo00<007ooOol06Woo00<007oo
Ool0B7oo001SOol00`00Oomoo`3oOoooOonDOol00`00Oomoo`0JOol00`00Oomoo`18Ool006=oo`03
001oogoo0?mooomooiAoo`03001oogoo01Uoo`03001oogoo04Uoo`00Hgoo00<007ooOol0ogooogoo
U7oo00<007ooOol06Goo00<007ooOol0BGoo001SOol00`00Oomoo`3oOoooOonDOol00`00Oomoo`0I
Ool00`00Oomoo`19Ool006=oo`03001oogoo0?mooomooiAoo`03001oogoo01Uoo`03001oogoo04Uo
o`00Hgoo00<007ooOol0ogooogooU7oo00<007ooOol06Goo00<007ooOol0BGoo001SOol00`00Oomo
o`3oOoooOonDOol00`00Oomoo`0IOol00`00Oomoo`19Ool006=oo`03001oogoo0?mooomooiAoo`03
001oogoo01Uoo`03001oogoo04Uoo`00Hgoo00<007ooOol0ogooogooU7oo00<007ooOol067oo00<0
07ooOol0BWoo001SOol3003oOoooOonDOol00`00Oomoo`0HOol00`00Oomoo`1:Ool006=oo`03001o
ogoo0?mooomooiAoo`03001oogoo01Qoo`03001oogoo04Yoo`00Hgoo00<007ooOol0ogooogooU7oo
00<007ooOol067oo00<007ooOol0BWoo001SOol00`00Oomoo`3oOoooOonDOol00`00Oomoo`0HOol0
0`00Oomoo`1:Ool006=oo`03001oogoo0?mooomooiAoo`03001oogoo01Qoo`03001oogoo04Yoo`00
:goo10003Woo0`0037oo2P003Goo00<007ooOol0ogooogooU7oo00<007ooOol05goo00<007ooOol0
Bgoo000YOol8000;Ool5000;Ool:000=Ool00`00Oomoo`3oOoooOonDOol00`00Oomoo`0GOol00`00
Oomoo`1;Ool002Uoo`8000Aoo`8000]oo`D000moo`80015oo`03001oogoo0?mooomooiEoo`03001o
ogoo01Ioo`03001oogoo04]oo`00:7oo0P001Woo0P002Woo1@003goo0P004Goo00<007ooOol0ogoo
ogooUGoo00<007ooOol05Woo00<007ooOol0Bgoo000XOol20006Ool2000;Ool3000@Ool2000AOol0
0`00Oomoo`3oOoooOonEOol00`00Oomoo`0FOol00`00Oomoo`1;Ool002Moo`8000Qoo`8001eoo`80
015oo`03001oogoo0?mooomooiEoo`03001oogoo01Ioo`03001oogoo04]oo`009goo0P0027oo0P00
7Goo0P004Goo00<007ooOol0ogooogooUGoo00<007ooOol05Woo00<007ooOol0Bgoo000WOol20008
Ool2000MOol2000AOol5003oOoooOonCOol00`00Oomoo`0FOol00`00Oomoo`1;Ool002Moo`8000Qo
o`8001eoo`80015oo`03001oogoo0?mooomooiEoo`03001oogoo01Ioo`03001oogoo04]oo`009goo
0P0027oo0P007Goo0P004Goo00<007ooOol0ogooogooUGoo00<007ooOol05Woo00<007ooOol0Bgoo
000WOol20008Ool2000MOol2000AOol00`00Oomoo`3oOoooOonEOol00`00Oomoo`0FOol00`00Oomo
o`1;Ool002Moo`8000Qoo`8001eoo`80015oo`03001oogoo0?mooomooiIoo`03001oogoo01Eoo`03
001oogoo04]oo`009goo0P0027oo0P007Goo0P004Goo00<007ooOol0ogooogooUWoo00<007ooOol0
5Goo00<007ooOol0Bgoo000XOol20006Ool2000NOol2000AOol00`00Oomoo`3oOoooOonFOol00`00
Oomoo`0EOol00`00Oomoo`1;Ool002Qoo`8000Ioo`8001ioo`80015oo`03001oogoo0?mooomooiIo
o`03001oogoo01Aoo`03001oogoo04aoo`00:Goo0P0017oo0P006goo0`0000=oo`0000004Goo00<0
07ooOol0ogooogooUWoo00<007ooOol057oo00<007ooOol0C7oo000YOol8000KOol6000AOol00`00
Oomoo`3oOoooOonFOol00`00Oomoo`0DOol00`00Oomoo`1<Ool002]oo`@0021oo`<0015oo`03001o
ogoo0?mooomooiIoo`03001oogoo01Aoo`03001oogoo04aoo`00Hgoo0`00ogooogooUWoo00<007oo
Ool057oo00<007ooOol0C7oo001SOol00`00Oomoo`3oOoooOonFOol00`00Oomoo`0DOol00`00Oomo
o`1<Ool006=oo`03001oogoo0?mooomooiIoo`03001oogoo01Aoo`03001oogoo04aoo`00Hgoo00<0
07ooOol0ogooogooUWoo00<007ooOol04goo00<007ooOol0CGoo001SOol00`00Oomoo`3oOoooOonF
Ool00`00Oomoo`0COol00`00Oomoo`1=Ool006=oo`03001oogoo0?mooomooiIoo`03001oogoo01=o
o`03001oogoo04eoo`00Hgoo00<007ooOol0ogooogooUWoo00<007ooOol04goo00<007ooOol0CGoo
001SOol00`00Oomoo`3oOoooOonFOol00`00Oomoo`0COol00`00Oomoo`1=Ool006=oo`03001oogoo
0?mooomooiIoo`03001oogoo01=oo`03001oogoo04eoo`00Hgoo00<007ooOol0ogooogooUWoo00<0
07ooOol04goo00<007ooOol0CGoo001SOol00`00Oomoo`3oOoooOonFOol00`00Oomoo`0COol00`00
Oomoo`1=Ool006=oo`<00?mooomooiMoo`03001oogoo019oo`03001oogoo04eoo`00Hgoo00<007oo
Ool0ogooogooUgoo00<007ooOol04Woo00<007ooOol0CGoo001SOol00`00Oomoo`3oOoooOonGOol0
0`00Oomoo`0BOol00`00Oomoo`1=Ool006=oo`03001oogoo0?mooomooiMoo`03001oogoo019oo`03
001oogoo04eoo`00Hgoo00<007ooOol0ogooogooUgoo00<007ooOol04Woo00<007ooOol0CGoo001S
Ool00`00Oomoo`3oOoooOonGOol00`00Oomoo`0BOol00`00Oomoo`1=Ool006=oo`03001oogoo0?mo
oomooiMoo`03001oogoo019oo`03001oogoo04eoo`00Hgoo00<007ooOol0ogooogooUgoo00<007oo
Ool04Goo00<007ooOol0CWoo001SOol00`00Oomoo`3oOoooOonGOol00`00Oomoo`0AOol00`00Oomo
o`1>Ool006=oo`03001oogoo0?mooomooiQoo`03001oogoo011oo`03001oogoo04ioo`00Hgoo00<0
07ooOol0ogooogooV7oo00<007ooOol047oo00<007ooOol0CWoo001SOol3003oOoooOonHOol00`00
Oomoo`0@Ool00`00Oomoo`1>Ool006=oo`03001oogoo0?mooomooiQoo`03001oogoo011oo`03001o
ogoo04ioo`00Hgoo00<007ooOol0ogooogooV7oo00<007ooOol047oo00<007ooOol0CWoo001SOol0
0`00Oomoo`3oOoooOonHOol00`00Oomoo`0?Ool00`00Oomoo`1?Ool006=oo`03001oogoo0?mooomo
oiQoo`03001oogoo00moo`03001oogoo04moo`00Hgoo00<007ooOol0ogooogooV7oo00<007ooOol0
3goo00<007ooOol0Cgoo001SOol00`00Oomoo`3oOoooOonHOol00`00Oomoo`0?Ool00`00Oomoo`1?
Ool006=oo`03001oogoo0?mooomooiUoo`03001oogoo00ioo`03001oogoo04moo`00Hgoo00<007oo
Ool0ogooogooVGoo00<007ooOol03Woo00<007ooOol0Cgoo001SOol00`00Oomoo`3oOoooOonIOol0
0`00Oomoo`0>Ool00`00Oomoo`1?Ool006=oo`03001oogoo0?mooomooiUoo`03001oogoo00eoo`03
001oogoo051oo`00Hgoo00<007ooOol0ogooogooVGoo00<007ooOol03Goo00<007ooOol0D7oo001S
Ool3003oOoooOonIOol00`00Oomoo`0=Ool00`00Oomoo`1@Ool006=oo`03001oogoo0?mooomooiUo
o`03001oogoo00eoo`03001oogoo051oo`00Hgoo00<007ooOol0ogooogooVGoo00<007ooOol03Goo
00<007ooOol0D7oo001SOol00`00Oomoo`3oOoooOonIOol00`00Oomoo`0=Ool00`00Oomoo`1@Ool0
01Uoo`@000ioo`<000aoo`X000Uoo`H0011oo`03001oogoo0?mooomooiUoo`03001oogoo00eoo`03
001oogoo051oo`005goo20002goo1@002goo2P001goo2P003Woo00<007ooOol0ogooogooVGoo00<0
07ooOol03Goo00<007ooOol0D7oo000GOol20004Ool2000;Ool5000?Ool2000;Ool30005Ool3000=
Ool00`00Oomoo`3oOoooOonIOol00`00Oomoo`0=Ool00`00Oomoo`1@Ool001Ioo`8000Ioo`8000Yo
o`D000moo`8001Aoo`8000eoo`03001oogoo0?mooomooiUoo`03001oogoo00eoo`03001oogoo051o
o`005Woo0P001Woo0P002goo0`0047oo0P005Goo0P0037oo00<007ooOol0ogooogooVGoo00<007oo
Ool03Goo00<007ooOol0D7oo000EOol20008Ool2000MOol2000EOol2000<Ool00`00Oomoo`3oOooo
OonIOol00`00Oomoo`0=Ool00`00Oomoo`1@Ool001Eoo`8000Qoo`8001eoo`8001Eoo`8000aoo`03
001oogoo0?mooomooiUoo`03001oogoo00eoo`03001oogoo051oo`005Goo0P0027oo0P007Goo0P00
5Goo0P0037oo1@00ogooogooV7oo00<007ooOol02goo00<007ooOol0DGoo000EOol20008Ool2000M
Ool2000EOol2000<Ool00`00Oomoo`3oOoooOonJOol00`00Oomoo`0;Ool00`00Oomoo`1AOol001Eo
o`8000Qoo`8001eoo`8001Aoo`8000eoo`03001oogoo0?mooomooiYoo`03001oogoo00]oo`03001o
ogoo055oo`005Goo0P0027oo0P007Goo0P0037oo0P001Goo0`003Goo00<007ooOol0ogooogooVWoo
00<007ooOol02goo00<007ooOol0DGoo000EOol20008Ool2000MOol2000<Ool9000>Ool00`00Oomo
o`3oOoooOonJOol00`00Oomoo`0;Ool00`00Oomoo`1AOol001Eoo`8000Qoo`8001eoo`8000aoo`80
0003Ool0000000<000moo`03001oogoo0?mooomooiYoo`03001oogoo00]oo`03001oogoo055oo`00
5Woo0P001Woo0P007Woo0P0037oo0P005Goo00<007ooOol0ogooogooVWoo00<007ooOol02goo00<0
07ooOol0DGoo000FOol20006Ool2000NOol2000<Ool2000EOol00`00Oomoo`3oOoooOonKOol00`00
Oomoo`09Ool00`00Oomoo`1BOol001Moo`8000Aoo`8001]oo`<00003Ool0000000aoo`8001Eoo`03
001oogoo0?mooomooi]oo`03001oogoo00Uoo`03001oogoo059oo`005goo20006goo1P0037oo2P00
3Goo00<007ooOol0ogooogooVgoo00<007ooOol02Goo00<007ooOol0DWoo000IOol4000POol3000<
Ool:000=Ool00`00Oomoo`3oOoooOonKOol00`00Oomoo`09Ool00`00Oomoo`1BOol006=oo`<00?mo
oomooi]oo`03001oogoo00Uoo`03001oogoo059oo`00Hgoo00<007ooOol0ogooogooVgoo00<007oo
Ool027oo00<007ooOol0Dgoo001SOol00`00Oomoo`3oOoooOonKOol00`00Oomoo`08Ool00`00Oomo
o`1COol006=oo`03001oogoo0?mooomooiaoo`03001oogoo00Moo`03001oogoo05=oo`00Hgoo00<0
07ooOol0ogooogooW7oo00<007ooOol01goo00<007ooOol0Dgoo001SOol00`00Oomoo`3oOoooOonL
Ool00`00Oomoo`07Ool00`00Oomoo`1COol006=oo`03001oogoo0?mooomooiaoo`03001oogoo00Mo
o`03001oogoo05=oo`00Hgoo00<007ooOol0ogooogooW7oo00<007ooOol01goo00<007ooOol0Dgoo
001SOol00`00Oomoo`3oOoooOonLOol00`00Oomoo`07Ool00`00Oomoo`1COol006=oo`03001oogoo
0?mooomooiaoo`03001oogoo00Moo`03001oogoo05=oo`00Hgoo00<007ooOol0ogooogooW7oo00<0
07ooOol01goo00<007ooOol0Dgoo001SOol3003oOoooOonLOol00`00Oomoo`07Ool00`00Oomoo`1C
Ool006=oo`03001oogoo0?mooomooiaoo`03001oogoo00Ioo`03001oogoo05Aoo`00Hgoo00<007oo
Ool0ogooogooWGoo00<007ooOol01Goo00<007ooOol0E7oo001SOol00`00Oomoo`3oOoooOonMOol0
0`00Oomoo`05Ool00`00Oomoo`1DOol006=oo`03001oogoo0?mooomooieoo`03001oogoo00Eoo`03
001oogoo05Aoo`00Hgoo00<007ooOol0ogooogooWGoo00<007ooOol017oo00<007ooOol0EGoo001S
Ool00`00Oomoo`3oOoooOonMOol00`00Oomoo`04Ool00`00Oomoo`1EOol006=oo`03001oogoo0?mo
oomooiioo`03001oogoo00=oo`03001oogoo05Eoo`00Hgoo00<007ooOol0ogooogooWWoo00<007oo
Ool00goo00<007ooOol0EGoo001SOol00`00Oomoo`3oOoooOonNOol00`00Oomoo`03Ool00`00Oomo
o`1EOol006=oo`03001oogoo0?mooomooiioo`03001oogoo00=oo`03001oogoo05Eoo`00Hgoo00<0
07ooOol0ogooogooWWoo00<007ooOol00goo00<007ooOol0EGoo001SOol3003oOoooOonNOol00`00
Oomoo`02Ool00`00Oomoo`1FOol006=oo`03001oogoo0?mooomooimoo`05001oogooOol0001HOol0
06=oo`03001oogoo0?mooomooimoo`04001oogoo001IOol006=oo`03001oogoo0?mooomooj1oo`80
05Yoo`00Hgoo00<007ooOol0ogooogooo7oo001SOol00`00Oomoo`3oOoooOoolOol006=oo`03001o
ogoo0?mooomoooaoo`00Hgoo00<007ooOol0ogooogooo7oo001SOol00`00Oomoo`3oOoooOoolOol0
06=oo`03001oogoo0?mooomoooaoo`00Hgoo00<007ooOol0ogooogooo7oo001SOol3003oOoooOool
Ool006=oo`03001oogoo0?mooomoooaoo`00Hgoo00<007ooOol0ogooogooo7oo001SOol00`00Oomo
o`3oOoooOoolOol002]oo`@000ioo`<000Yoo``000eoo`03001oogoo0?mooomoooaoo`00:Goo2000
2goo1@002Goo30003Goo00<007ooOol0ogooogooo7oo000YOol20004Ool2000;Ool5000:Ool30006
Ool2000=Ool00`00Oomoo`3oOoooOoolOol002Qoo`8000Ioo`8000Yoo`D000]oo`<001Aoo`03001o
ogoo0?mooomoooaoo`00:7oo0P001Woo0P002goo0`003Goo0`004goo00<007ooOol0ogooogooo7oo
000WOol20008Ool2000KOol3000BOol00`00Oomoo`3oOoooOoolOol002Moo`8000Qoo`8001aoo`<0
015oo`03001oogoo0?mooomoooaoo`009goo0P0027oo0P007Goo0`0047oo1@00ogooogoonWoo000W
Ool20008Ool2000NOol3003oOoooOoooOol?Ool002Moo`8000Qoo`8001moo`<00?mooomooomoo`io
o`009goo0P0027oo0P0087oo0P00ogooogooogoo3Woo000WOol20008Ool2000QOol2003oOoooOooo
Ool=Ool002Moo`8000Qoo`80025oo`800?mooomooomoo`eoo`00:7oo0P001Woo0P006Goo0P001goo
0P00ogooogooogoo3Goo000XOol20006Ool2000IOol30006Ool2003oOoooOoooOol=Ool002Uoo`80
00Aoo`8001Yoo`@000Aoo`800?mooomooomoo`ioo`00:Goo20006goo2000ogooogooogoo3goo000[
Ool4000OOol5003oOoooOoooOol@Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOooo
OomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=o
o`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003o
OoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomo
oomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogoo
Hgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol0
0?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogoo
ogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00\
\>"], "Graphics",
  CellLabel->"From (Dialog) In[49]:=",
  Evaluatable->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "One can do many more interesting experiments with this notebook. Let's \
look as a last thing for now at u/i on line 1 as function of position along \
the wire. The following plot displays voltage/current after the first \
reflection of the pulse at the right end. Before reflection we have ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(u\_0\),
              "TraditionalForm"], "/", 
            FormBox[\(i\_0\),
              "TraditionalForm"]}], "=", 
          RowBox[{
            FormBox[\(Z\_0\),
              "TraditionalForm"], "=", \(\@\(0.6/65\)\)}]}], 
        TraditionalForm]]],
  "*1000\[NonBreakingSpace]\[CapitalOmega]\[NonBreakingSpace]=\
\[NonBreakingSpace]96\[NonBreakingSpace]\[CapitalOmega]. The line is \
terminated with ",
  Cell[BoxData[
      \(TraditionalForm\`Z\_x\)]],
  " = 220 \[CapitalOmega]. After reflection there  is a superposition  of the \
original pulse with the returning component: u\[NonBreakingSpace]=\
\[NonBreakingSpace]",
  Cell[BoxData[
      \(TraditionalForm\`u\_0\)]],
  "*(1+ (",
  Cell[BoxData[
      \(TraditionalForm\`Z\_x\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`Z\_0\)]],
  ")/\[NonBreakingSpace](",
  Cell[BoxData[
      \(TraditionalForm\`Z\_x\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`Z\_0\)]],
  ")),  i\[NonBreakingSpace]=\[NonBreakingSpace]",
  Cell[BoxData[
      \(TraditionalForm\`i\_0\)]],
  "*(1-\[NonBreakingSpace](",
  Cell[BoxData[
      \(TraditionalForm\`Z\_x\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`Z\_0\)]],
  ")/\[NonBreakingSpace](",
  Cell[BoxData[
      \(TraditionalForm\`Z\_x\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`Z\_0\)]],
  ")), so that u/i\[NonBreakingSpace]=\[NonBreakingSpace]",
  Cell[BoxData[
      \(TraditionalForm\`Z\_x\)]],
  "."
}], "Text",
  PageBreakAbove->True],

Cell[GraphicsData["PICT", "\<\
5H80;@0g0=h1E`0A0_l<0?ooool0=`0002d0005G0000gP000000000N00402P0]
03L0gP5G09X0003oPT00;@0g0=h1E`0000<0000004P0E@1804@0400@00<01@00
00080gRh0000000]03L0gP5G02d0=`3N0EL00009PGooPGoohGoo00V1Oon1OooQ
Ool02H5ooh5oon5oo`09PGooPGoohGoo00V1Oon1OooQOol02H5ooh5oon5oo`09
PGooPGoohGoo00V1Oon1OooQOol02H5ooh5oon5oo`0?j7oo0000PGooPGoongoo
00o/Ool00021Oon1OoogOol09?Ioo`@00000Ool00000oGoo0P00Oomoooh0085o
oh5ooo]oo`0QmGoo0`00Oomoo`00oGoo0000oGoo0000PGooPGoongoo027eOol3
001oogoo003nOol0003lOol00021Oon1OookOol08OEoo`<007ooOol00?ioo`00
0?aoo`00085ooh5ooo]oo`0Qm7oo1P00001oo`00Oomoo`00oWooo000PGooPGoo
oGoo00o_Ool00021Oon1OoodOol02H5ooh5oon5oo`09PGooPGoohGoo00V1Oon1
OooQOol02H5ooh5oon5oo`0O07oooP000GooOool003nOol10000085ooh5ooo5o
o`0R0000oWoo0P00Ool00?]oo`<007ooOol0085ooh5ooo9oo`0S0000oWoo0@00
Ooom003nOol3001oogoo0021Oon1OoobOol08Oioo`000?]oo`H007ooOol007oo
Ool0085ooh5ooo9oo`0X0WooOol00?Yoo`H007ooOol007ooOol00?ioooh0085o
oh5oooQoo`0`1Woo001oogoo001oo`00oWoo1P00Oomoo`00Oomoo`00oWoo0000
PGooPGoomWoo02;l0001Oomoooh00?eoo`400000oGoo0000PGooPGoomWoo00o]
Ool00021Oon1OoofOol03neoo`00085ooh5oooIoo`0AkGoo0@000021Oon1Ooog
Ool03neoo`00085ooh5oooIoo`0?kGoo0000PGooPGoomWoo00o]Ool00021Oon1
OoofOol03neoo`00085ooh5oooIoo`0DkGoo0@000021OooNOol0002KOol04^eo
o`00085oomioood009eoo`0HkGoo0000PGooggoo0000oGoo0000WWoo01k]Ool0
0021OooPOol0003kOol0003fOol0002[Ool09neoo`00085oomQoo`000?Yoooh0
009oo`00003jOol100000;Ioo`0VkGoo0000PGoohGoo0000n7oon@00o7oonP00
0GooOooe0032Ool05>eoo`400000PGoohWoo0000Ugoo00o]Ool00021Oon1Ooof
Ool04^eoo`00085oon9oo`0009Ioo`0BkGoo0000PGoohgoo0000UGoo00o]Ool0
0021Oon1OoofOol05>eoo`400000PGooiGoo0000U7oo00o]Ool00021Oon1Ooof
Ool0:01oooh00?eoo`400000oGoo0@00003mOol00021OooUOol0002COol0<`00
0?ioo``007ooOol007ooOol007ooOol007ooOol00?ioo`00085oonIoo`00099o
o`0`0000oWoo3000Oomoo`00Oomoo`00Oomoo`00Oomoo`00oWoo0000PGooPGoo
mWoo033nOol0003nOol9001oogoo001oogoo001oogoo003nOoon0021OooXOol0
002BOol0;P9oogoo003mOol9001oogoo001oogoo001oogoo003nOol00021Oon1
OoofOol0=A1oo`00Oomoo`00Oomoo`00Oomoo`00Oomoo`00Oomoo`00oWoo0000
PGooigoo0000TGoo02;l003nOol100000?eoo`400000oGoo0000PGooPGoomWoo
01;]Ool00021OooXOol0002@Ool04Neoo`400000PGooPGoomgoo00o]Ool00021
Oon1OoofOol04^eoo`00085oonUoo`0008moo`0?kGoo0000PGooPGoomWoo01;]
Ool00021OooZOol0002>Ool03neoo`00085ooh5oooIoo`0DkGoo0@000021Ooo[
Ool0002>Ool03neoo`00085ooh5oooIoo`0BkGoo0000PGoojgoo0000SGoo00o]
Ool00021Oon1OoofOol04^eoo`00085oonaoo`0008aoo`0AkGoo0@000021Oon1
OoogOol04^eoo`00085ooneoo`0008]oo`0?kGoo0000PGooPGoomWoo01;]Ool0
0021Ooo^Ool0002:Ool03neoo`00085ooh5oooIoo`0DkGoo0@000021Ooo`Ool0
0029Ool04^eoo`00085oonmoo`0008Uoo`0T0WooOol00?iooo`00?ioo`400000
oGoo0000PGooPGoomWoo02/2Ool00000oWoo0000ngoo0`00Oomoo`00oWoo0000
PGool7oo0000R7oo02/2Oomoo`00oWooo@00oWoo0`00Oomoo`00oWoo0000PGoo
lGoo0000Qgoo02/2Oomoo`00nWoo1P00Oomoo`00Oomoo`00oWoo0000PGoolWoo
0000QWoo02P2Oomoo`00nWoo1P00Oomoo`00Oomoo`00oWoooP00PGooPGoon7oo
0342Oomoo`00oWoo0000oWoo1P00Oomoo`00Oomoo`00oWoo0000PGoolgoo0000
QGoo02H0Ooon003nOoon003mOol100000?eoo`00085ooo=oo`0008Eoo`0?kGoo
0000PGooPGoomWoo01;]Ool00021OoodOol00024Ool05>eoo`400000PGoomWoo
0000Pgoo00o]Ool00021Oon1OoofOol04^eoo`00085oooIoo`00089oo`0BkGoo
0000PGoomgoo0000PGoo00o]Ool00021Oon1OoofOol05>eoo`400000PGoon7oo
0000PGoo00o]Ool00021Oon1OoofOol05Neoo`00085oooQoo`00085oo`1oo`0G
kGoo0000PGoonGoo0000PGoo0GooOol03neoo`00085ooh5oooIoo`0GkGoo0@00
0021OookOol00021OoonOol05Neoo`00085ooo]oo`00085oooeoo`0?kGoo0000
PGooPGoomWoo01G]Ool00021OoolOol00021OoolOol05Neoo`00085oooaoo`00
085oooaoo`0EkGoo0000PGoooGoo0000PGoongoo01S]Ool10000085oo`9oogoo
0021OoojOol05^eoo`00085oo`9oogoo0021OooiOol0:`9oogoo003lOol10000
0?eoo`400000oGoo0000PGoo0Goo0021OoohOol0<`9oo`00003mOol9001oogoo
001oogoo001oogoo003nOol10000089oo`00085oooMoo`0h0WooOol00?eoo`T0
07ooOol007ooOol007ooOol00?ioo`8007ooOooa002FOoon0021OoofOol0=`9o
ogoo003mOol9001oogoo001oogoo001oogoo003nOoon003aOonR003nOooh0021
OoocOol0<@9oogoo003mOol9001oogoo001oogoo001oogoo003nOol0002@Ooon
0021OooZOol0;P9oogoo003mOol9001oogoo001oogoo001oogoo003nOol00021
Oon1OoofOol09@1oooh00?eoo`400000oGoo0@00003mOol00021Oon1OoofOol0
3neoo`00085ooh5oooIoo`0AkGoo0@000021Oon1OoogOol03neoo`00085ooh5o
ooIoo`0?kGoo0000PGooPGoomWoo00o]Ool00021Oon1OoofOol03neoo`00085o
oh5oooIoo`0?kGoo0000PGooPGoomWoo017]Ool10000085ooh5oooMoo`0?kGoo
0000PGooPGoomWoo00o]Ool00021Oon1OoofOol03neoo`00085ooh5oooIoo`0?
kGoo0000PGooPGoomWoo017]Ool10000085ooh5oooMoo`0?kGoo0000PGooPGoo
mWoo00o]Ool00021Oon1OoofOol03neoo`00085ooh5oooIoo`0?kGoo0000PGoo
PGoomWoo017]Ool10000085ooh5oooMoo`0?kGoo0000PGooPGoomWoo01gkOool
003nOol100000?eoo`00085ooh5oooIoo`0Qngoo0000ngoo0`00Oomoo`00oWoo
0000PGooPGoomWoo027kOoom003nOol3001oogoo003nOol00021Oon1OoofOol0
8OMoo`H007ooOol007ooOol00?ioooh0085ooh5oooQoo`0Qmgoo1P00Oomoo`00
Oomoo`00oWoo0000PGooPGoomWoo02OkOol0003nOol6001oogoo001oogoo003n
Ool00021Oon1OoofOol07OYoooh00?eoo`400000oGoo0000PGooPGoomWoo00o]
Ool00021Oon1OoofOol03neoo`00085ooh5oooIoo`0AkGoo0@000021Oon1Ooog
Ool03neoo`00085ooh5oooIoo`0?kGoo0000PGooPGoomWoo00o]Ool00021Oon1
OoofOol03neoo`00085ooh5oooIoo`0AkGoo0@000021Oon1OoogOol03neoo`00
085ooh5oooIoo`0?kGoo0000PGooPGoomWoo00o]Ool00021Oon1OoofOol03neo
o`00085ooh5oooIoo`0AkGoo0@000021Oon1OoogOol03neoo`00085ooh5oooIo
o`0?kGoo0000PGooPGoomWoo00o]Ool00021Oon1OoofOol03neoo`00085ooh5o
ooIoo`0?kGoo0000PGooPGoomWoo017]Ool10000085ooh5oooMoo`0NkGoo0000
PGooUGoo0000oGoo0000ngoo0000kgoo01;]Ool00021Oon@Ool0003XOol0@>eo
o`00085oojUoood00?ioooh00?ioood0001oooh00?ioood0005oogoooP00oGoo
oP000GooOoom003lOol0hneoo`000?Yoo`000?Yoo`000?Uoo`000?Yoo`000?Yo
o`000?Yoo`000?Yoo`000?Yoo`000?Uoo`000?Yoo`000?Yoo`000?Yoo`000?Yo
o`000?Yoo`000?Uoo`000?Yoo`000?Yoo`000?Yoo`000?Yoo`000?Yoo`000?Yo
o`000?Uoo`000?Yoo`000?Yoo`000?Yoo`000?Aoo`D007ooOol007oo003nOol2
001oo`00nWoo0000oGoo0000ngoo0000oWoo0000oWoo1P00Oomoo`00Oomoo`00
oGoo05?bOon1002Z003iOol5001oogoo001oo`00oWoo0P00Oomoooh00?eoo`00
0?eoo`000?]oo`000?ioo`000?ioo`H007ooOol007ooOol00?eoo`1BPGooTgoo
1@00Oomoo`00Ool00?ioo`000?aoo`000?ioo`000?eoo`<007ooOol00?ioo`00
0?ioo`000?ioo`H007ooOol007ooOol00?eoo`18PGooTgoooP00oWoooP000Goo
Ooom0001Oomooo`00?ioo`<00000Oomooo`0005oogoooP000GooOoon0002Ool0
0000oWoo00b1OonCOol0003@Ool0385ooiAoooh00=5oo`1WbWooo000oWoo0@00
003SOol0003lOol100000?eoo`400000iWoo0000oWooo000oWoo0@00003XOoon
003mOol100000?eoo`400000igoooP000GooOool003nOol100000<Qoo`2?bWoo
0000ngoo0`00Oomoo`00iGoo0@00003mOol9001oogoo001oogoo001oogoo003X
Ool100000?ioo`000?]oo`<007ooOol00>Yoo`000?ioo``007ooOol007ooOol0
07ooOol007ooOol00>Uoo`000?ioo`8007oo003kOol3001oogoo0039Ool0S<Yo
ood00?ioo`<007ooOol00>Aoo`000?eoo`T007ooOol007ooOol007ooOol00>Mo
o`000?ioood00?ioo`<007ooOol00>Yoo`000?ioo``007ooOol007ooOol007oo
Ool007ooOol00>Uoo`000?ioo`4007ooo@00oWoo0`00Oomoo`00bGoo0876Ool6
001oogoo001oogoo003TOol0003mOol9001oogoo001oogoo001oogoo003WOol0
003jOol6001oogoo001oogoo003WOol0003nOol9001oogoo001oogoo001oogoo
003VOol0003kOol6001oogoo001oogoo0039Ool0PLIoo`H007ooOol007ooOol0
0>Aoo`000?eoo`T007ooOol007ooOol007ooOol00>Moo`000?Yoo`H007ooOol0
07ooOol00>Qoo`000?eoo`T007ooOol007ooOol007ooOol00>Moo`000?Yoo`H0
07ooOol007ooOol00<Uoo`2MbWoo0000oWoo1P00Oomoo`00Oomoo`00i7oo0000
oGoo2@00Oomoo`00Oomoo`00Oomoo`00igoo0000oWoo0000oWoo1P00Oomoo`00
Oomoo`00jGoo3`00Oomoo`00Oomoo`00Oomoo`00Oomoo`00Oomoo`00j7oo1@00
Oomoo`00Ool00?ioo`H007ooOol007ooOol00<Uoo`1WbGoooP00oGoo0@00003T
Ooon003mOol100000?eoo`400000igoooP00oWoooP00oGoo0@00003YOool003n
Ool100000?eoo`400000j7ooo0000GooOoon003mOol100000<Qoo`09PGooPGoo
hGoo00V1Oon1OooQOol02H5ooh5oon5oo`09PGooPGoohGoo00V1Oon1OooQOol0
2H5ooh5oon5oo`09PGooPGoohGoo00V1Oon1OooQOol0o`\>"], "Graphics",
  ImageSize->{288, 177},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[49]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conclusion", "Section"],

Cell[TextData[{
  "\tTools have been presented that allow the detailed analysis of crosstalk \
on coupled linear conductors within the time domain. They also let you \
determine the capacities and inductances of linear conductors of arbitrary \
shape. All you have to do is to adapt the contour and the height of the \
potential boundaries  and run the code example. The resulting values may be \
entered into the corresponding matrices of the telegraph equations to \
simulate and watch pulse propagation.\n\tA simple formula was derived that \
lets you calculate the ",
  StyleBox["exact potential of a line charge in a rectangular box ",
    FontSlant->"Italic"],
  StyleBox["and hence the capacity of a wire inside a rectangular shield.",
    FontVariations->{"CompatibilityType"->0}],
  "\n\tCrosstalk is a dynamic phenomenon. Although the coupling \[Dash] \
capacitive and inductive \[Dash] of the pigtail is surprisingly small, the \
amplitude of the crosstalk pulse grows considerably until it gets to an \
asymptotic value: In this case it reaches 2-3% after 1 m length and attains \
its equilibrium amplitude of well over 18% (even 30% if related to the damped \
pulse on line 1) after running about 13 m or 80\[NonBreakingSpace]necs. \n\t\
The ratio voltage/current is determined first by the impedance ",
  Cell[BoxData[
      \(TraditionalForm\`Z\_0\)]],
  ", after the pulse has suffered reflection at the end of the conductor, the \
ratio changes to ",
  Cell[BoxData[
      \(TraditionalForm\`Z\_x\)]],
  ", the value of the terminating resistor."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "Section",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "  (1)   Reisch: Elektronische Bauelemente, Springer, 1998\n  (2)   Unger: \
Elektromagnetische Wellen auf Leitungen, H\[UDoubleDot]thig, 4. Auflage, 1996\
\n  (3)   Press et. al.: Numerical Recipes in Fortran, Cambridge University \
Press, Second Edition, 1992\n  (4)   Ganzha,Vorozhtsov: Numerical Solutions \
for Partial Differential Equations, CRC Press, 1996\n  (5)   Simonyi: \
Theoretische Elektrotechnik, Barth, 10. Auflage,  1993\n  (6)   Jackson: \
Classical Electrodynamics, Wiley & Sons, Third Edition, 1998\n  (7)   K\
\[UDoubleDot]pfm\[UDoubleDot]ller, Kohn: Theoretische Elektrotechnik und \
Elektronik, Springer, 15. Auflage, 2000\n  (8)   Wolfram: The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Book, Wolfram Media, Inc.,  Fourth Edition,  1999\n  (9)   Wickham-Jones: \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Graphics, Springer, 1994\n(10)   with help from D. Zagier, MPI f\
\[UDoubleDot]r Mathematik, Bonn\n(11)   Johnson,Graham: High Speed Digital \
Design, Prentice Hall PTR, 1993"
}], "Reference",
  PageBreakBelow->Automatic]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 800}, {0, 580}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{787, 551},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, 9999},
Magnification->1,
StyleDefinitions -> "ArticleClassic.nb",
MacintoshSystemPageSetup->"\<\
0040004/0B`000003K@9[`00000=]0V_o`8=]0V_0@00004/0B`000000dX2D`01
0@00I00100000@0200000Gd0004000<fJ[0000000000051`I6H0I00000000000
00000000000000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 57, 0, 79, "Title"],
Cell[1787, 54, 93, 3, 37, "Subtitle"],
Cell[1883, 59, 161, 6, 107, "Subsubtitle"],
Cell[2047, 67, 1118, 21, 216, "Text"],
Cell[3168, 90, 453, 10, 242, "Text"],

Cell[CellGroupData[{
Cell[3646, 104, 55, 1, 49, "Section",
  PageBreakAbove->True],
Cell[3704, 107, 740, 21, 47, "Text"],
Cell[4447, 130, 341897, 5261, 295, 341805, 5258, "GraphicsData", "PICT", \
"NumberedFigure"],
Cell[346347, 5393, 191, 4, 25, "Caption"],
Cell[346541, 5399, 1156, 25, 125, "Text"],
Cell[347700, 5426, 562, 9, 59, "NumberedEquation"],
Cell[348265, 5437, 1897, 42, 164, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[350199, 5484, 57, 0, 49, "Section"],

Cell[CellGroupData[{
Cell[350281, 5488, 49, 0, 37, "Subsection"],

Cell[CellGroupData[{
Cell[350355, 5492, 55, 0, 28, "Subsubsection"],
Cell[350413, 5494, 1024, 18, 125, "Text"],
Cell[351440, 5514, 359, 7, 38, "NumberedEquation"],
Cell[351802, 5523, 52, 0, 21, "Text"],
Cell[351857, 5525, 640, 16, 67, "NumberedEquation"],
Cell[352500, 5543, 756, 25, 60, "Text"],
Cell[353259, 5570, 1281, 29, 98, "NumberedEquation"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[354589, 5605, 175, 6, 37, "Subsection",
  PageBreakAbove->True],
Cell[354767, 5613, 501, 12, 73, "Text"],

Cell[CellGroupData[{
Cell[355293, 5629, 502, 10, 101, "Input"],
Cell[355798, 5641, 490, 9, 120, "Output"]
}, Open  ]],
Cell[356303, 5653, 118, 3, 21, "Text"],

Cell[CellGroupData[{
Cell[356446, 5660, 398, 12, 51, "Input"],
Cell[356847, 5674, 267, 5, 42, "Output"]
}, Open  ]],
Cell[357129, 5682, 101, 3, 21, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[357267, 5690, 87, 1, 37, "Subsection",
  PageBreakAbove->True],
Cell[357357, 5693, 160, 5, 21, "Text"],
Cell[357520, 5700, 428, 16, 22, "NumberedEquation"],
Cell[357951, 5718, 945, 21, 86, "Text"],
Cell[358899, 5741, 434, 8, 42, "NumberedEquation"],
Cell[359336, 5751, 238, 7, 34, "Text"],
Cell[359577, 5760, 284, 9, 23, "NumberedEquation"],

Cell[CellGroupData[{
Cell[359886, 5773, 104, 4, 28, "Subsubsection"],
Cell[359993, 5779, 179, 5, 21, "Text"],
Cell[360175, 5786, 185, 3, 35, "NumberedEquation"],
Cell[360363, 5791, 32, 0, 21, "Text"],
Cell[360398, 5793, 736, 16, 38, "NumberedEquation"],
Cell[361137, 5811, 335, 6, 47, "Text"],
Cell[361475, 5819, 185, 3, 34, "NumberedEquation"],
Cell[361663, 5824, 176, 4, 34, "Text"],
Cell[361842, 5830, 570, 10, 67, "NumberedEquation"],
Cell[362415, 5842, 36, 0, 21, "Text"],
Cell[362454, 5844, 305, 6, 30, "NumberedEquation"],
Cell[362762, 5852, 240280, 3698, 230, 240188, 3695, "GraphicsData", "PICT", \
"NumberedFigure"],
Cell[603045, 9552, 106, 3, 19, "Caption"],
Cell[603154, 9557, 230, 6, 34, "Text"],
Cell[603387, 9565, 352, 6, 30, "NumberedEquation"],
Cell[603742, 9573, 250, 9, 21, "Text"],
Cell[603995, 9584, 285, 4, 52, "Text"],
Cell[604283, 9590, 232608, 3580, 230, 232516, 3577, "GraphicsData", "PICT", \
"NumberedFigure"],
Cell[836894, 13172, 164, 4, 25, "Caption"],
Cell[837061, 13178, 151, 6, 21, "Text",
  PageBreakAbove->True],
Cell[837215, 13186, 1072, 19, 98, "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{
Cell[838324, 13210, 104, 4, 28, "Subsubsection"],
Cell[838431, 13216, 232, 6, 34, "Text"],
Cell[838666, 13224, 664, 15, 36, "NumberedEquation"],
Cell[839333, 13241, 168, 8, 34, "Text"],
Cell[839504, 13251, 601, 13, 57, "NumberedEquation"],
Cell[840108, 13266, 218, 4, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[840363, 13275, 57, 0, 28, "Subsubsection"],
Cell[840423, 13277, 1334, 22, 131, "NumberedEquation"],
Cell[841760, 13301, 277, 5, 47, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[842074, 13311, 82, 1, 28, "Subsubsection",
  PageBreakAbove->True],
Cell[842159, 13314, 394, 8, 47, "Text"],
Cell[842556, 13324, 213934, 3293, 185, 213842, 3290, "GraphicsData", "PICT", \
"NumberedFigure"],
Cell[1056493, 16619, 201, 4, 25, "Caption"],
Cell[1056697, 16625, 170, 4, 34, "Text"],
Cell[1056870, 16631, 3010, 69, 92, "NumberedEquation"],
Cell[1059883, 16702, 129, 4, 34, "Text"],
Cell[1060015, 16708, 3186, 70, 108, "NumberedEquation"],
Cell[1063204, 16780, 59, 1, 21, "Text",
  PageBreakAbove->Automatic],
Cell[1063266, 16783, 3161, 68, 121, "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1066464, 16856, 53, 0, 28, "Subsubsection"],
Cell[1066520, 16858, 286, 6, 60, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1066855, 16870, 158, 5, 37, "Subsection",
  PageBreakAbove->Automatic],
Cell[1067016, 16877, 64, 0, 21, "Text"],
Cell[1067083, 16879, 286, 5, 47, "Text"],

Cell[CellGroupData[{
Cell[1067394, 16888, 36, 0, 28, "Subsubsection"],
Cell[1067433, 16890, 1188, 23, 207, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1068658, 16918, 51, 0, 28, "Subsubsection"],
Cell[1068712, 16920, 1541, 42, 204, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1070290, 16967, 73, 0, 28, "Subsubsection"],
Cell[1070366, 16969, 1347, 27, 316, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1071750, 17001, 49, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[1071824, 17005, 573, 13, 102, "Input"],
Cell[1072400, 17020, 33349, 416, 192, 33201, 411, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False]
}, Open  ]],
Cell[1105764, 17439, 133, 3, 21, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1105934, 17447, 114, 2, 28, "Subsubsection",
  PageBreakAbove->True],
Cell[1106051, 17451, 238, 5, 34, "Text"],

Cell[CellGroupData[{
Cell[1106314, 17460, 3829, 69, 613, "Input"],
Cell[1110146, 17531, 36339, 1727, 296, 20022, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1146488, 19260, 65, 2, 22, "Print"],
Cell[1146556, 19264, 36284, 1726, 296, 20040, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1182843, 20992, 65, 2, 24, "Print"],
Cell[1182911, 20996, 36173, 1726, 302, 20001, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1219087, 22724, 66, 2, 24, "Print"],
Cell[1219156, 22728, 36584, 1730, 302, 20020, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1255743, 24460, 66, 2, 24, "Print"],
Cell[1255812, 24464, 36852, 1734, 302, 20008, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1292667, 26200, 66, 2, 24, "Print"],
Cell[1292736, 26204, 36967, 1735, 302, 20006, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1329706, 27941, 66, 2, 24, "Print"],
Cell[1329775, 27945, 36978, 1735, 302, 20009, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1366756, 29682, 66, 2, 24, "Print"],
Cell[1366825, 29686, 37092, 1737, 302, 20013, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1403920, 31425, 66, 2, 24, "Print"],
Cell[1403989, 31429, 37061, 1736, 302, 20015, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1441053, 33167, 66, 2, 24, "Print"],
Cell[1441122, 33171, 36982, 1736, 302, 19984, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1478107, 34909, 66, 2, 24, "Print"],
Cell[1478176, 34913, 37028, 1736, 302, 20022, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1515207, 36651, 66, 2, 24, "Print"],
Cell[1515276, 36655, 36988, 1736, 302, 19998, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1552267, 38393, 66, 2, 24, "Print"],
Cell[1552336, 38397, 37026, 1736, 302, 20020, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1589365, 40135, 66, 2, 24, "Print"],
Cell[1589434, 40139, 37122, 1737, 302, 20007, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1626559, 41878, 66, 2, 24, "Print"],
Cell[1626628, 41882, 37188, 1738, 302, 20028, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1663819, 43622, 66, 2, 24, "Print"],
Cell[1663888, 43626, 37169, 1738, 302, 20009, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1701060, 45366, 66, 2, 24, "Print"],
Cell[1701129, 45370, 37002, 1736, 302, 19996, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1738134, 47108, 66, 2, 24, "Print"],
Cell[1738203, 47112, 36917, 1735, 302, 20004, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1775123, 48849, 66, 2, 24, "Print"],
Cell[1775192, 48853, 37020, 1736, 302, 20002, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1812215, 50591, 66, 2, 24, "Print"],
Cell[1812284, 50595, 37050, 1736, 302, 20000, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1849337, 52333, 66, 2, 24, "Print"],
Cell[1849406, 52337, 37175, 1738, 302, 20015, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1886584, 54077, 66, 2, 24, "Print"],
Cell[1886653, 54081, 37104, 1737, 302, 20013, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1923760, 55820, 66, 2, 24, "Print"],
Cell[1923829, 55824, 37036, 1736, 302, 20010, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1960868, 57562, 66, 2, 24, "Print"],
Cell[1960937, 57566, 37002, 1736, 302, 19996, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1997942, 59304, 66, 2, 24, "Print"],
Cell[1998011, 59308, 37020, 1736, 302, 20030, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2035034, 61046, 67, 2, 24, "Print"],
Cell[2035104, 61050, 36979, 1735, 302, 20014, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2072086, 62787, 67, 2, 24, "Print"],
Cell[2072156, 62791, 37014, 1736, 302, 20000, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2109173, 64529, 67, 2, 24, "Print"],
Cell[2109243, 64533, 37035, 1736, 302, 19989, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2146281, 66271, 67, 2, 24, "Print"],
Cell[2146351, 66275, 37064, 1737, 302, 20001, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2183418, 68014, 67, 2, 24, "Print"],
Cell[2183488, 68018, 37084, 1737, 302, 20013, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2220575, 69757, 67, 2, 24, "Print"],
Cell[2220645, 69761, 37085, 1737, 302, 20014, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2257733, 71500, 67, 2, 24, "Print"],
Cell[2257803, 71504, 37088, 1737, 302, 20025, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2294894, 73243, 67, 2, 24, "Print"],
Cell[2294964, 73247, 37030, 1736, 302, 20000, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2331997, 74985, 67, 2, 24, "Print"],
Cell[2332067, 74989, 37062, 1737, 302, 19999, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2369132, 76728, 67, 2, 24, "Print"],
Cell[2369202, 76732, 36987, 1736, 302, 19985, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2406192, 78470, 67, 2, 24, "Print"],
Cell[2406262, 78474, 36843, 1734, 302, 20003, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2443108, 80210, 67, 2, 24, "Print"],
Cell[2443178, 80214, 36627, 1731, 302, 20014, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2479808, 81947, 67, 2, 24, "Print"],
Cell[2479878, 81951, 36369, 1728, 302, 20023, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2516250, 83681, 67, 2, 24, "Print"],
Cell[2516320, 83685, 36109, 1724, 302, 20023, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2552432, 85411, 67, 2, 24, "Print"],
Cell[2552502, 85415, 35960, 1723, 302, 20027, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2588465, 87140, 67, 2, 24, "Print"],
Cell[2588535, 87144, 35714, 1715, 302, 19952, 1516, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2624252, 88861, 67, 2, 24, "Print"],
Cell[2624322, 88865, 35459, 1712, 302, 19960, 1516, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2659784, 90579, 67, 2, 24, "Print"],
Cell[2659854, 90583, 35486, 1714, 302, 19958, 1517, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2695343, 92299, 67, 2, 24, "Print"],
Cell[2695413, 92303, 35460, 1716, 302, 20026, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2730876, 94021, 67, 2, 24, "Print"],
Cell[2730946, 94025, 35459, 1716, 302, 20021, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2766408, 95743, 67, 2, 24, "Print"],
Cell[2766478, 95747, 35693, 1719, 302, 20012, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2802174, 97468, 67, 2, 24, "Print"],
Cell[2802244, 97472, 35927, 1722, 302, 20019, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2838174, 99196, 67, 2, 24, "Print"],
Cell[2838244, 99200, 36033, 1724, 302, 20015, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2874280, 100926, 67, 2, 24, "Print"],
Cell[2874350, 100930, 36037, 1724, 302, 20011, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2910390, 102656, 67, 2, 24, "Print"],
Cell[2910460, 102660, 36023, 1723, 302, 20022, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2946486, 104385, 67, 2, 24, "Print"],
Cell[2946556, 104389, 35925, 1722, 302, 20001, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2982484, 106113, 67, 2, 24, "Print"],
Cell[2982554, 106117, 35908, 1722, 302, 20000, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3018465, 107841, 67, 2, 24, "Print"],
Cell[3018535, 107845, 35947, 1723, 302, 20002, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3054485, 109570, 67, 2, 24, "Print"],
Cell[3054555, 109574, 35970, 1723, 302, 20005, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3090528, 111299, 67, 2, 24, "Print"],
Cell[3090598, 111303, 35843, 1722, 302, 19991, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3126444, 113027, 67, 2, 24, "Print"],
Cell[3126514, 113031, 35680, 1720, 302, 19994, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3162197, 114753, 67, 2, 24, "Print"],
Cell[3162267, 114757, 35586, 1718, 302, 19994, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3197856, 116477, 67, 2, 24, "Print"],
Cell[3197926, 116481, 35740, 1720, 302, 19982, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3233669, 118203, 67, 2, 24, "Print"],
Cell[3233739, 118207, 35698, 1720, 302, 19996, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3269440, 119929, 67, 2, 24, "Print"],
Cell[3269510, 119933, 35819, 1721, 302, 20000, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3305332, 121656, 67, 2, 24, "Print"],
Cell[3305402, 121660, 35870, 1722, 302, 20010, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3341275, 123384, 67, 2, 24, "Print"],
Cell[3341345, 123388, 35871, 1722, 302, 19979, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3377219, 125112, 67, 2, 24, "Print"],
Cell[3377289, 125116, 35781, 1721, 302, 19974, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3413073, 126839, 67, 2, 24, "Print"],
Cell[3413143, 126843, 35667, 1720, 302, 19981, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3448813, 128565, 67, 2, 24, "Print"],
Cell[3448883, 128569, 35693, 1720, 302, 19975, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3484579, 130291, 67, 2, 24, "Print"],
Cell[3484649, 130295, 35737, 1720, 302, 19983, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3520389, 132017, 67, 2, 24, "Print"],
Cell[3520459, 132021, 35864, 1722, 302, 20000, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3556326, 133745, 67, 2, 24, "Print"],
Cell[3556396, 133749, 35857, 1722, 302, 19989, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3592256, 135473, 67, 2, 24, "Print"],
Cell[3592326, 135477, 35960, 1723, 302, 19987, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3628289, 137202, 67, 2, 24, "Print"],
Cell[3628359, 137206, 35822, 1721, 302, 19979, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3664184, 138929, 67, 2, 24, "Print"],
Cell[3664254, 138933, 35801, 1721, 302, 20002, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3700058, 140656, 67, 2, 24, "Print"],
Cell[3700128, 140660, 35597, 1719, 302, 19980, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3735728, 142381, 67, 2, 24, "Print"],
Cell[3735798, 142385, 35738, 1720, 302, 19988, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3771539, 144107, 67, 2, 24, "Print"],
Cell[3771609, 144111, 35750, 1720, 302, 20000, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3807362, 145833, 67, 2, 24, "Print"],
Cell[3807432, 145837, 35786, 1721, 302, 19999, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3843221, 147560, 67, 2, 24, "Print"],
Cell[3843291, 147564, 35723, 1720, 302, 19997, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3879017, 149286, 67, 2, 24, "Print"],
Cell[3879087, 149290, 35686, 1720, 302, 20000, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3914776, 151012, 67, 2, 24, "Print"],
Cell[3914846, 151016, 35715, 1720, 302, 20005, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3950564, 152738, 67, 2, 24, "Print"],
Cell[3950634, 152742, 35665, 1719, 302, 20004, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3986302, 154463, 67, 2, 24, "Print"],
Cell[3986372, 154467, 35544, 1718, 302, 20004, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4021919, 156187, 67, 2, 24, "Print"],
Cell[4021989, 156191, 35479, 1717, 302, 20008, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4057471, 157910, 67, 2, 24, "Print"],
Cell[4057541, 157914, 35388, 1716, 302, 20014, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4092932, 159632, 67, 2, 24, "Print"],
Cell[4093002, 159636, 34991, 1707, 302, 19921, 1516, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4127996, 161345, 67, 2, 24, "Print"],
Cell[4128066, 161349, 34941, 1706, 302, 19924, 1516, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4163010, 163057, 67, 2, 24, "Print"],
Cell[4163080, 163061, 35326, 1714, 302, 19977, 1520, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4198409, 164777, 67, 2, 24, "Print"],
Cell[4198479, 164781, 35388, 1716, 302, 20010, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4233870, 166499, 67, 2, 24, "Print"],
Cell[4233940, 166503, 35468, 1717, 302, 20017, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4269411, 168222, 67, 2, 24, "Print"],
Cell[4269481, 168226, 35516, 1717, 302, 20013, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4305000, 169945, 67, 2, 24, "Print"],
Cell[4305070, 169949, 35693, 1720, 302, 20007, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4340766, 171671, 67, 2, 24, "Print"],
Cell[4340836, 171675, 35635, 1719, 302, 20002, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4376474, 173396, 67, 2, 24, "Print"],
Cell[4376544, 173400, 35739, 1720, 302, 20009, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4412286, 175122, 67, 2, 24, "Print"],
Cell[4412356, 175126, 35678, 1719, 302, 20001, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4448037, 176847, 67, 2, 24, "Print"],
Cell[4448107, 176851, 35707, 1720, 302, 19997, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4483817, 178573, 67, 2, 24, "Print"],
Cell[4483887, 178577, 35745, 1720, 302, 20003, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4519635, 180299, 67, 2, 24, "Print"],
Cell[4519705, 180303, 35685, 1720, 302, 19991, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4555393, 182025, 67, 2, 24, "Print"],
Cell[4555463, 182029, 35799, 1721, 302, 19996, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4591265, 183752, 67, 2, 24, "Print"],
Cell[4591335, 183756, 35810, 1721, 302, 19983, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4627148, 185479, 67, 2, 24, "Print"],
Cell[4627218, 185483, 35821, 1721, 302, 19998, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4663042, 187206, 67, 2, 24, "Print"],
Cell[4663112, 187210, 35680, 1720, 302, 19990, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4698795, 188932, 67, 2, 24, "Print"],
Cell[4698865, 188936, 35732, 1720, 302, 19982, 1521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4734600, 190658, 67, 2, 24, "Print"],
Cell[4734670, 190662, 93, 2, 32, "Output"],
Cell[4734766, 190666, 73, 2, 24, "Print"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4734900, 190675, 81, 1, 37, "Subsection",
  PageBreakAbove->True],
Cell[4734984, 190678, 583, 9, 73, "Text"],
Cell[4735570, 190689, 49229, 612, 302, 49077, 607, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[4784802, 191303, 692, 23, 47, "Text",
  PageBreakAbove->True],
Cell[4785497, 191328, 44802, 557, 302, 44650, 552, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[4830302, 191887, 517, 16, 34, "Text",
  PageBreakAbove->True],
Cell[4830822, 191905, 46681, 580, 302, 46529, 575, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[4877506, 192487, 475, 8, 60, "Text",
  PageBreakBelow->Automatic]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4878030, 192501, 94, 1, 49, "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[4878149, 192506, 32, 0, 37, "Subsection"],

Cell[CellGroupData[{
Cell[4878206, 192510, 116, 3, 28, "Subsubsection"],
Cell[4878325, 192515, 273, 7, 34, "Text"],
Cell[4878601, 192524, 1369, 64, 56, "NumberedEquation"],
Cell[4879973, 192590, 649, 23, 47, "Text"],
Cell[4880625, 192615, 928, 43, 22, "NumberedEquation"],
Cell[4881556, 192660, 211, 6, 34, "Text"],
Cell[4881770, 192668, 2271, 94, 54, "NumberedEquation"],
Cell[4884044, 192764, 134, 3, 21, "Text"],
Cell[4884181, 192769, 338, 13, 56, "NumberedEquation"],
Cell[4884522, 192784, 745, 14, 86, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4885304, 192803, 114, 3, 28, "Subsubsection"],
Cell[4885421, 192808, 380, 10, 34, "Text"],
Cell[4885804, 192820, 408, 15, 23, "NumberedEquation"],
Cell[4886215, 192837, 157, 3, 34, "Text"],
Cell[4886375, 192842, 304, 10, 24, "NumberedEquation"],
Cell[4886682, 192854, 843, 20, 86, "Text"],
Cell[4887528, 192876, 330, 8, 24, "NumberedEquation"],
Cell[4887861, 192886, 99, 3, 21, "Text"],
Cell[4887963, 192891, 528, 18, 24, "NumberedEquation"],
Cell[4888494, 192911, 391, 8, 47, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4888922, 192924, 70, 0, 28, "Subsubsection"],
Cell[4888995, 192926, 183, 4, 34, "Text"],
Cell[4889181, 192932, 417, 15, 22, "NumberedEquation"],
Cell[4889601, 192949, 303, 9, 21, "Text"],
Cell[4889907, 192960, 477, 15, 22, "NumberedEquation"],
Cell[4890387, 192977, 959, 19, 112, "Text"],
Cell[4891349, 192998, 360, 13, 23, "NumberedEquation"],
Cell[4891712, 193013, 403, 8, 60, "Text"],
Cell[4892118, 193023, 729, 23, 24, "NumberedEquation"],
Cell[4892850, 193048, 887, 14, 99, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4893786, 193068, 147, 5, 37, "Subsection",
  PageBreakAbove->True],
Cell[4893936, 193075, 63, 0, 21, "Text"],
Cell[4894002, 193077, 410, 7, 73, "Text"],

Cell[CellGroupData[{
Cell[4894437, 193088, 72, 1, 28, "Subsubsection"],
Cell[4894512, 193091, 234, 4, 34, "Text"],

Cell[CellGroupData[{
Cell[4894771, 193099, 823, 21, 202, "Input"],
Cell[4895597, 193122, 219, 4, 15, "Message"],
Cell[4895819, 193128, 219, 4, 15, "Message"],
Cell[4896041, 193134, 219, 4, 15, "Message"],
Cell[4896263, 193140, 192, 4, 23, "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4896504, 193150, 78, 1, 28, "Subsubsection"],
Cell[4896585, 193153, 362, 7, 76, "Input"],
Cell[4896950, 193162, 105, 3, 21, "Text"],
Cell[4897058, 193167, 313, 8, 59, "Input"],

Cell[CellGroupData[{
Cell[4897396, 193179, 474, 10, 88, "Input"],
Cell[4897873, 193191, 190837, 2360, 188, 190689, 2355, "GraphicsData", \
"Bitmap", "Graphics",
  Evaluatable->False],
Cell[5088713, 195553, 157, 4, 32, "Output"]
}, Open  ]],
Cell[5088885, 195560, 141, 4, 21, "Text",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[5089063, 195569, 44, 0, 28, "Subsubsection"],
Cell[5089110, 195571, 225, 5, 34, "Text"],

Cell[CellGroupData[{
Cell[5089360, 195580, 635, 19, 191, "Input"],
Cell[5089998, 195601, 221, 4, 15, "Message"],
Cell[5090222, 195607, 221, 4, 15, "Message"],
Cell[5090446, 195613, 221, 4, 15, "Message"],
Cell[5090670, 195619, 193, 4, 23, "Message"]
}, Open  ]],
Cell[5090878, 195626, 66, 1, 21, "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[5090969, 195631, 277, 10, 81, "Input"],
Cell[5091249, 195643, 254, 5, 24, "Print"],
Cell[5091506, 195650, 258, 5, 24, "Print"],
Cell[5091767, 195657, 79, 2, 32, "Output"]
}, Open  ]],
Cell[5091861, 195662, 150, 4, 34, "Text"],
Cell[5092014, 195668, 153, 4, 38, "Input"],
Cell[5092170, 195674, 46, 0, 21, "Text"],

Cell[CellGroupData[{
Cell[5092241, 195678, 241, 5, 51, "Input"],
Cell[5092485, 195685, 170247, 2106, 188, 170099, 2101, "GraphicsData", \
"Bitmap", "Graphics",
  Evaluatable->False]
}, Open  ]],
Cell[5262747, 197794, 55, 0, 21, "Text"],
Cell[5262805, 197796, 174, 5, 34, "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[5263004, 197805, 167, 4, 38, "Input"],
Cell[5263174, 197811, 243, 4, 41, "Message"],
Cell[5263420, 197817, 210, 4, 23, "Message"]
}, Open  ]],
Cell[5263645, 197824, 46, 0, 21, "Text"],

Cell[CellGroupData[{
Cell[5263716, 197828, 272, 9, 70, "Input"],
Cell[5263991, 197839, 259, 5, 24, "Print"],
Cell[5264253, 197846, 94, 2, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5264384, 197853, 208, 7, 48, "Input"],
Cell[5264595, 197862, 348899, 4311, 256, 348752, 4306, "GraphicsData", \
"Bitmap", "Graphics",
  Evaluatable->False],
Cell[5613497, 202175, 162, 4, 32, "Output"]
}, Open  ]],
Cell[5613674, 202182, 248, 5, 34, "Text",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[5613959, 202192, 76, 1, 28, "Subsubsection",
  PageBreakAbove->True],
Cell[5614038, 202195, 61, 0, 21, "Text"],

Cell[CellGroupData[{
Cell[5614124, 202199, 293, 7, 63, "Input"],
Cell[5614420, 202208, 162, 4, 32, "Output"]
}, Open  ]],
Cell[5614597, 202215, 123, 3, 21, "Text"],
Cell[5614723, 202220, 489, 11, 101, "Input"],
Cell[5615215, 202233, 154, 4, 21, "Text",
  PageBreakAbove->Automatic],
Cell[5615372, 202239, 1561, 27, 325, "Input"],
Cell[5616936, 202268, 140, 4, 38, "Input"],
Cell[5617079, 202274, 160, 6, 21, "Text",
  PageBreakAbove->True],
Cell[5617242, 202282, 743, 14, 138, "Input"],
Cell[5617988, 202298, 370, 7, 47, "Text",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{
Cell[5618383, 202309, 2475, 47, 435, "Input"],
Cell[5620861, 202358, 242312, 2996, 262, 242140, 2990, "GraphicsData", \
"Bitmap", "Graphics",
  Evaluatable->False,
  PageBreakAbove->True],
Cell[5863176, 205356, 155, 4, 32, "Output"]
}, Open  ]],
Cell[5863346, 205363, 248, 5, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5863631, 205373, 76, 1, 28, "Subsubsection"],
Cell[5863710, 205376, 210, 5, 47, "Text"],
Cell[5863923, 205383, 841, 18, 138, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5864801, 205406, 87, 1, 28, "Subsubsection",
  PageBreakAbove->True],
Cell[5864891, 205409, 130, 5, 21, "Text"],

Cell[CellGroupData[{
Cell[5865046, 205418, 333, 8, 67, "Input"],
Cell[5865382, 205428, 82, 2, 32, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5865513, 205436, 52, 0, 28, "Subsubsection"],
Cell[5865568, 205438, 3244, 100, 333, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5868861, 205544, 57, 1, 37, "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[5868943, 205549, 84, 1, 28, "Subsubsection"],
Cell[5869030, 205552, 384, 8, 60, "Text"],
Cell[5869417, 205562, 1377, 65, 54, "NumberedEquation"],
Cell[5870797, 205629, 487, 17, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5871321, 205651, 113, 3, 28, "Subsubsection"],
Cell[5871437, 205656, 192, 6, 21, "Text"],
Cell[5871632, 205664, 395, 15, 23, "NumberedEquation"],
Cell[5872030, 205681, 137, 3, 34, "Text"],
Cell[5872170, 205686, 304, 10, 24, "NumberedEquation"],
Cell[5872477, 205698, 616, 15, 60, "Text"],
Cell[5873096, 205715, 346, 10, 24, "NumberedEquation"],
Cell[5873445, 205727, 107, 3, 21, "Text"],
Cell[5873555, 205732, 537, 20, 24, "NumberedEquation"],
Cell[5874095, 205754, 182, 5, 21, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5874314, 205764, 113, 4, 28, "Subsubsection"],
Cell[5874430, 205770, 200, 8, 21, "Text"],
Cell[5874633, 205780, 209, 9, 22, "NumberedEquation"],
Cell[5874845, 205791, 245, 11, 21, "Text"],
Cell[5875093, 205804, 553, 25, 22, "NumberedEquation"],
Cell[5875649, 205831, 622, 19, 47, "Text"],
Cell[5876274, 205852, 181, 8, 22, "NumberedEquation"],
Cell[5876458, 205862, 731, 15, 86, "Text"],
Cell[5877192, 205879, 168, 7, 22, "NumberedEquation"],
Cell[5877363, 205888, 233, 6, 34, "Text"],
Cell[5877599, 205896, 500, 15, 22, "NumberedEquation"],
Cell[5878102, 205913, 278, 7, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5878429, 205926, 112, 4, 37, "Subsection"],
Cell[5878544, 205932, 63, 0, 21, "Text"],

Cell[CellGroupData[{
Cell[5878632, 205936, 72, 1, 28, "Subsubsection"],
Cell[5878707, 205939, 98, 3, 21, "Text"],

Cell[CellGroupData[{
Cell[5878830, 205946, 410, 12, 103, "Input"],
Cell[5879243, 205960, 220, 4, 15, "Message"],
Cell[5879466, 205966, 193, 4, 23, "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5879708, 205976, 78, 1, 28, "Subsubsection"],
Cell[5879789, 205979, 362, 7, 76, "Input"],
Cell[5880154, 205988, 547, 13, 60, "Text",
  PageBreakAbove->True],
Cell[5880704, 206003, 218870, 3368, 231, 218778, 3365, "GraphicsData", \
"PICT", "NumberedFigure"],
Cell[6099577, 209373, 109, 3, 19, "Caption"],
Cell[6099689, 209378, 396, 12, 34, "Text"],
Cell[6100088, 209392, 177, 7, 23, "NumberedEquation"],
Cell[6100268, 209401, 157, 7, 48, "Input"],
Cell[6100428, 209410, 205, 8, 21, "Text"],
Cell[6100636, 209420, 571, 12, 106, "Input"],
Cell[6101210, 209434, 759, 11, 99, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6102006, 209450, 68, 1, 28, "Subsubsection",
  PageBreakAbove->True],
Cell[6102077, 209453, 96, 3, 21, "Text"],

Cell[CellGroupData[{
Cell[6102198, 209460, 590, 18, 180, "Input"],
Cell[6102791, 209480, 221, 4, 15, "Message"],
Cell[6103015, 209486, 193, 4, 23, "Message"]
}, Open  ]],
Cell[6103223, 209493, 34, 0, 21, "Text"],

Cell[CellGroupData[{
Cell[6103282, 209497, 309, 11, 92, "Input"],
Cell[6103594, 209510, 256, 5, 24, "Print"],
Cell[6103853, 209517, 259, 5, 24, "Print"],
Cell[6104115, 209524, 94, 2, 32, "Output"]
}, Open  ]],
Cell[6104224, 209529, 65, 1, 21, "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[6104314, 209534, 265, 6, 63, "Input"],
Cell[6104582, 209542, 511512, 6319, 248, 511364, 6314, "GraphicsData", \
"Bitmap", "Graphics",
  Evaluatable->False]
}, Open  ]],
Cell[6616109, 215864, 120, 5, 47, "Text",
  PageBreakAbove->Automatic],
Cell[6616232, 215871, 272, 9, 70, "Input"],

Cell[CellGroupData[{
Cell[6616529, 215884, 215, 7, 48, "Input"],
Cell[6616747, 215893, 952890, 11768, 339, 952741, 11763, "GraphicsData", \
"Bitmap", "Graphics",
  Evaluatable->False]
}, Open  ]],
Cell[7569652, 227664, 266, 10, 21, "Text",
  PageBreakAbove->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[7569955, 227679, 76, 1, 28, "Subsubsection"],
Cell[7570034, 227682, 841, 18, 138, "Input"],
Cell[7570878, 227702, 148, 4, 39, "Input"],
Cell[7571029, 227708, 841, 25, 35, "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[7571895, 227737, 583, 12, 113, "Input"],
Cell[7572481, 227751, 729, 11, 82, "Output"],
Cell[7573213, 227764, 78, 2, 32, "Output"]
}, Open  ]],
Cell[7573306, 227769, 347, 6, 47, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7573690, 227780, 32, 0, 28, "Subsubsection"],
Cell[7573725, 227782, 452, 19, 21, "Text"],
Cell[7574180, 227803, 560, 18, 24, "NumberedEquation"],
Cell[7574743, 227823, 27, 0, 21, "Text"],

Cell[CellGroupData[{
Cell[7574795, 227827, 196, 6, 38, "Input"],
Cell[7574994, 227835, 82, 2, 32, "Output"]
}, Open  ]],
Cell[7575091, 227840, 98, 1, 21, "Text",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{
Cell[7575214, 227845, 150, 4, 50, "Input"],
Cell[7575367, 227851, 82, 2, 32, "Output"]
}, Open  ]],
Cell[7575464, 227856, 504, 17, 47, "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[7575993, 227877, 400, 9, 97, "Input"],
Cell[7576396, 227888, 38265, 476, 192, 38117, 471, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False]
}, Open  ]],
Cell[7614676, 228367, 76, 1, 21, "Text",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{
Cell[7614777, 228372, 347, 8, 83, "Input"],
Cell[7615127, 228382, 38379, 478, 192, 38231, 473, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False]
}, Open  ]],
Cell[7653521, 228863, 284, 9, 21, "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[7653830, 228876, 930, 19, 169, "Input"],
Cell[7654763, 228897, 28550, 357, 192, 28402, 352, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False]
}, Open  ]],
Cell[7683328, 229257, 490, 9, 60, "Text",
  PageBreakAbove->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7683867, 229272, 57, 0, 37, "Subsection"],

Cell[CellGroupData[{
Cell[7683949, 229276, 102, 3, 28, "Subsubsection"],
Cell[7684054, 229281, 551, 14, 60, "Text"],
Cell[7684608, 229297, 1228, 32, 78, "Text"],
Cell[7685839, 229331, 119, 3, 19, "Caption"],
Cell[7685961, 229336, 969, 14, 125, "Text"],
Cell[7686933, 229352, 427990, 6586, 302, 427898, 6583, "GraphicsData", \
"PICT", "NumberedFigure"],
Cell[8114926, 235940, 276, 5, 25, "Caption"],
Cell[8115205, 235947, 816, 16, 98, "Text"],
Cell[8116024, 235965, 1236, 27, 112, "Text"],
Cell[8117263, 235994, 1562, 34, 94, "Text",
  PageBreakAbove->True],
Cell[8118828, 236030, 134, 4, 21, "Text",
  PageBreakAbove->False],

Cell[CellGroupData[{
Cell[8118987, 236038, 1560, 31, 287, "Input",
  PageBreakAbove->False],
Cell[8120550, 236071, 252185, 3117, 198, 252063, 3113, "GraphicsData", \
"Bitmap", "Graphics",
  Evaluatable->False]
}, Open  ]],
Cell[8372750, 239191, 367, 7, 47, "Text",
  PageBreakBelow->True],
Cell[8373120, 239200, 888, 27, 99, "Text",
  PageBreakAbove->Automatic],
Cell[8374011, 239229, 811, 31, 22, "Text",
  PageBreakAbove->Automatic],
Cell[8374825, 239262, 1153, 31, 71, "Text"],
Cell[8375981, 239295, 130, 3, 19, "Caption"],
Cell[8376114, 239300, 133, 3, 21, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8376284, 239308, 71, 0, 28, "Subsubsection"],
Cell[8376358, 239310, 1792, 40, 164, "Text"],
Cell[8378153, 239352, 1413, 33, 164, "Text",
  PageBreakBelow->Automatic],
Cell[8379569, 239387, 152, 4, 21, "Text",
  PageBreakAbove->True],
Cell[8379724, 239393, 200, 3, 44, "Text"],
Cell[8379927, 239398, 272, 7, 34, "Text"],
Cell[8380202, 239407, 26386, 329, 192, 26267, 325, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[8406591, 239738, 264, 6, 60, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8406916, 239751, 59, 1, 49, "Section",
  PageBreakAbove->Automatic],
Cell[8406978, 239754, 118, 3, 21, "Text"],
Cell[8407099, 239759, 174529, 2686, 91, 174438, 2683, "GraphicsData", "PICT", \
"NumberedFigure"],
Cell[8581631, 242447, 123, 3, 19, "Caption"],
Cell[8581757, 242452, 557, 9, 73, "Text"],

Cell[CellGroupData[{
Cell[8582339, 242465, 164, 5, 37, "Subsection",
  PageBreakAbove->True],
Cell[8582506, 242472, 62, 0, 21, "Text"],

Cell[CellGroupData[{
Cell[8582593, 242476, 1598, 41, 400, "Input",
  PageBreakAbove->Automatic],
Cell[8584194, 242519, 219, 4, 15, "Message"],
Cell[8584416, 242525, 219, 4, 15, "Message"],
Cell[8584638, 242531, 219, 4, 15, "Message"],
Cell[8584860, 242537, 192, 4, 23, "Message"],
Cell[8585055, 242543, 173870, 2151, 188, 173699, 2145, "GraphicsData", \
"Bitmap", "Graphics",
  Evaluatable->False,
  PageBreakAbove->True]
}, Open  ]],
Cell[8758940, 244697, 103, 3, 21, "Text"],
Cell[8759046, 244702, 754, 21, 202, "Input"],

Cell[CellGroupData[{
Cell[8759825, 244727, 330, 7, 63, "Input",
  PageBreakAbove->Automatic],
Cell[8760158, 244736, 163099, 2018, 188, 162951, 2013, "GraphicsData", \
"Bitmap", "Graphics",
  Evaluatable->False]
}, Open  ]],
Cell[8923272, 246757, 96, 3, 21, "Text"],

Cell[CellGroupData[{
Cell[8923393, 246764, 413, 13, 103, "Input",
  PageBreakAbove->Automatic],
Cell[8923809, 246779, 243, 4, 41, "Message"],
Cell[8924055, 246785, 240, 4, 41, "Message"],
Cell[8924298, 246791, 243, 4, 41, "Message"],
Cell[8924544, 246797, 210, 4, 23, "Message"],
Cell[8924757, 246803, 255, 5, 24, "Print"],
Cell[8925015, 246810, 260, 5, 24, "Print"],
Cell[8925278, 246817, 258, 5, 24, "Print"],
Cell[8925539, 246824, 82, 2, 32, "Output"],
Cell[8925624, 246828, 434703, 5371, 256, 434556, 5366, "GraphicsData", \
"Bitmap", "Graphics",
  Evaluatable->False]
}, Open  ]],
Cell[9360342, 252202, 165, 4, 21, "Text",
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[9360532, 252210, 5351, 100, 1010, "Input"],
Cell[9365886, 252312, 162, 4, 32, "Output"],
Cell[9366051, 252318, 254292, 3143, 262, 254144, 3138, "GraphicsData", \
"Bitmap", "Graphics",
  Evaluatable->False],
Cell[9620346, 255463, 155, 4, 32, "Output"]
}, Open  ]],
Cell[9620516, 255470, 141, 3, 21, "Text"],

Cell[CellGroupData[{
Cell[9620682, 255477, 841, 18, 138, "Input"],
Cell[9621526, 255497, 83, 2, 32, "Output"]
}, Open  ]],
Cell[9621624, 255502, 4591, 135, 377, "Text",
  PageBreakAbove->Automatic],
Cell[9626218, 255639, 372, 16, 22, "NumberedEquation"],
Cell[9626593, 255657, 843, 19, 86, "Text"],
Cell[9627439, 255678, 588102, 9049, 423, 588006, 9046, "GraphicsData", \
"PICT", "NumberedFigure"],
Cell[10215544, 264729, 159, 4, 25, "Caption"],
Cell[10215706, 264735, 139, 3, 21, "Text"],
Cell[10215848, 264740, 209, 6, 27, "NumberedEquation"],
Cell[10216060, 264748, 180, 5, 34, "Text"],
Cell[10216243, 264755, 152, 4, 50, "Input"],
Cell[10216398, 264761, 123, 3, 21, "Text"],
Cell[10216524, 264766, 56, 1, 21, "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[10216605, 264771, 206, 6, 51, "Input"],
Cell[10216814, 264779, 215, 4, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10217066, 264788, 206, 6, 51, "Input"],
Cell[10217275, 264796, 211, 4, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10217523, 264805, 206, 6, 51, "Input"],
Cell[10217732, 264813, 206, 4, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10217975, 264822, 206, 6, 51, "Input"],
Cell[10218184, 264830, 212, 4, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10218433, 264839, 205, 6, 51, "Input"],
Cell[10218641, 264847, 212, 4, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10218890, 264856, 205, 6, 51, "Input"],
Cell[10219098, 264864, 212, 4, 42, "Output"]
}, Open  ]],
Cell[10219325, 264871, 55, 1, 21, "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[10219405, 264876, 203, 6, 51, "Input"],
Cell[10219611, 264884, 212, 4, 23, "Message"],
Cell[10219826, 264890, 1149, 19, 157, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10221012, 264914, 203, 6, 51, "Input"],
Cell[10221218, 264922, 212, 4, 23, "Message"],
Cell[10221433, 264928, 1102, 18, 144, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10222572, 264951, 203, 6, 51, "Input"],
Cell[10222778, 264959, 212, 4, 23, "Message"],
Cell[10222993, 264965, 1101, 19, 132, "Output"]
}, Open  ]],
Cell[10224109, 264987, 55, 1, 21, "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[10224189, 264992, 199, 6, 51, "Input"],
Cell[10224391, 265000, 214, 4, 23, "Message"],
Cell[10224608, 265006, 4946, 75, 519, "Output"]
}, Open  ]],
Cell[10229569, 265084, 286, 9, 21, "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[10229880, 265097, 355, 8, 63, "Input"],
Cell[10230238, 265107, 78, 2, 32, "Output"]
}, Open  ]],
Cell[10230331, 265112, 222, 6, 21, "Text"],

Cell[CellGroupData[{
Cell[10230578, 265122, 356, 8, 63, "Input"],
Cell[10230937, 265132, 78, 2, 32, "Output"]
}, Open  ]],
Cell[10231030, 265137, 294, 8, 34, "Text"],

Cell[CellGroupData[{
Cell[10231349, 265149, 356, 8, 63, "Input"],
Cell[10231708, 265159, 78, 2, 32, "Output"]
}, Open  ]],
Cell[10231801, 265164, 163, 5, 21, "Text"],

Cell[CellGroupData[{
Cell[10231989, 265173, 356, 8, 63, "Input"],
Cell[10232348, 265183, 78, 2, 32, "Output"]
}, Open  ]],
Cell[10232441, 265188, 263, 9, 34, "Text"],

Cell[CellGroupData[{
Cell[10232729, 265201, 385, 9, 63, "Input",
  PageBreakBelow->Automatic],
Cell[10233117, 265212, 107, 3, 32, "Output",
  PageBreakBelow->Automatic]
}, Open  ]],
Cell[10233239, 265218, 251, 8, 54, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10233527, 265231, 181, 7, 37, "Subsection",
  PageBreakAbove->Automatic],
Cell[10233711, 265240, 63, 0, 21, "Text"],
Cell[10233777, 265242, 136, 3, 21, "Text"],
Cell[10233916, 265247, 1037, 27, 268, "Input"],

Cell[CellGroupData[{
Cell[10234978, 265278, 778, 24, 246, "Input"],
Cell[10235759, 265304, 221, 4, 15, "Message"],
Cell[10235983, 265310, 193, 4, 23, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10236213, 265319, 293, 8, 51, "Input"],
Cell[10236509, 265329, 140261, 1736, 188, 140113, 1731, "GraphicsData", \
"Bitmap", "Graphics",
  Evaluatable->False]
}, Open  ]],
Cell[10376785, 267068, 62, 0, 21, "Text"],

Cell[CellGroupData[{
Cell[10376872, 267072, 365, 9, 70, "Input"],
Cell[10377240, 267083, 1306604, 16135, 342, 1306452, 16130, "GraphicsData", \
"Bitmap", "Graphics",
  Evaluatable->False]
}, Open  ]],
Cell[11683859, 283221, 155, 4, 21, "Text",
  PageBreakBelow->Automatic],
Cell[11684017, 283227, 870, 19, 138, "Input",
  PageBreakAbove->Automatic],
Cell[11684890, 283248, 149, 4, 39, "Input"],
Cell[11685042, 283254, 371, 8, 47, "Text"],

Cell[CellGroupData[{
Cell[11685438, 283266, 740, 15, 138, "Input"],
Cell[11686181, 283283, 1216, 18, 119, "Output"],
Cell[11687400, 283303, 79, 2, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11687516, 283310, 741, 15, 138, "Input"],
Cell[11688260, 283327, 1350, 20, 144, "Output"],
Cell[11689613, 283349, 83, 2, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11689733, 283356, 741, 15, 138, "Input"],
Cell[11690477, 283373, 1218, 18, 119, "Output"],
Cell[11691698, 283393, 78, 2, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11691813, 283400, 741, 15, 138, "Input"],
Cell[11692557, 283417, 1359, 21, 132, "Output"],
Cell[11693919, 283440, 83, 2, 32, "Output"]
}, Open  ]],
Cell[11694017, 283445, 93, 3, 21, "Text"],

Cell[CellGroupData[{
Cell[11694135, 283452, 197, 6, 38, "Input"],
Cell[11694335, 283460, 82, 2, 32, "Output"]
}, Open  ]],
Cell[11694432, 283465, 1966, 47, 268, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11696435, 283517, 168, 5, 37, "Subsection",
  PageBreakAbove->True],
Cell[11696606, 283524, 63, 0, 21, "Text"],
Cell[11696672, 283526, 2169, 45, 346, "Input"],
Cell[11698844, 283573, 43, 0, 21, "Text"],
Cell[11698890, 283575, 1572, 42, 197, "Input"],
Cell[11700465, 283619, 89, 1, 21, "Text",
  PageBreakAbove->True],
Cell[11700557, 283622, 1624, 33, 358, "Input"],
Cell[11702184, 283657, 70, 1, 21, "Text",
  PageBreakAbove->Automatic],

Cell[CellGroupData[{
Cell[11702279, 283662, 227, 6, 51, "Input"],
Cell[11702509, 283670, 47331, 589, 192, 47157, 583, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False,
  ImageCacheValid->False]
}, Open  ]],
Cell[11749855, 284262, 126, 3, 21, "Text"],
Cell[11749984, 284267, 146, 5, 21, "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[11750155, 284276, 4033, 73, 663, "Input"],
Cell[11754191, 284351, 43653, 1809, 302, 19718, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11797847, 286162, 66, 2, 24, "Print"],
Cell[11797916, 286166, 43788, 1811, 302, 19711, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11841707, 287979, 66, 2, 24, "Print"],
Cell[11841776, 287983, 20233, 1519, 302, 19710, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[11862012, 289504, 66, 2, 24, "Print"],
Cell[11862081, 289508, 20234, 1519, 302, 19711, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[11882318, 291029, 66, 2, 24, "Print"],
Cell[11882387, 291033, 20228, 1519, 302, 19705, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[11902618, 292554, 66, 2, 24, "Print"],
Cell[11902687, 292558, 20228, 1519, 302, 19705, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[11922918, 294079, 67, 2, 24, "Print"],
Cell[11922988, 294083, 20225, 1519, 302, 19702, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[11943216, 295604, 67, 2, 24, "Print"],
Cell[11943286, 295608, 20229, 1519, 302, 19706, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[11963518, 297129, 67, 2, 24, "Print"],
Cell[11963588, 297133, 20219, 1519, 302, 19696, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[11983810, 298654, 67, 2, 24, "Print"],
Cell[11983880, 298658, 20229, 1519, 302, 19706, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12004112, 300179, 67, 2, 24, "Print"],
Cell[12004182, 300183, 20216, 1519, 302, 19693, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12024401, 301704, 67, 2, 24, "Print"],
Cell[12024471, 301708, 20215, 1519, 302, 19692, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12044689, 303229, 67, 2, 24, "Print"],
Cell[12044759, 303233, 20215, 1519, 302, 19692, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12064977, 304754, 67, 2, 24, "Print"],
Cell[12065047, 304758, 20212, 1519, 302, 19689, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12085262, 306279, 67, 2, 24, "Print"],
Cell[12085332, 306283, 20215, 1519, 302, 19692, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12105550, 307804, 67, 2, 24, "Print"],
Cell[12105620, 307808, 20197, 1519, 302, 19674, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12125820, 309329, 67, 2, 24, "Print"],
Cell[12125890, 309333, 20196, 1519, 302, 19673, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12146089, 310854, 67, 2, 24, "Print"],
Cell[12146159, 310858, 20193, 1519, 302, 19670, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12166355, 312379, 67, 2, 24, "Print"],
Cell[12166425, 312383, 20200, 1519, 302, 19677, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12186628, 313904, 67, 2, 24, "Print"],
Cell[12186698, 313908, 20195, 1519, 302, 19672, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12206896, 315429, 67, 2, 24, "Print"],
Cell[12206966, 315433, 20190, 1519, 302, 19667, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12227159, 316954, 67, 2, 24, "Print"],
Cell[12227229, 316958, 20191, 1519, 302, 19668, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12247423, 318479, 67, 2, 24, "Print"],
Cell[12247493, 318483, 20184, 1519, 302, 19661, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12267680, 320004, 67, 2, 24, "Print"],
Cell[12267750, 320008, 20198, 1519, 302, 19675, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12287951, 321529, 67, 2, 24, "Print"],
Cell[12288021, 321533, 20182, 1519, 302, 19659, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12308206, 323054, 67, 2, 24, "Print"],
Cell[12308276, 323058, 20163, 1519, 302, 19640, 1509, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12328442, 324579, 67, 2, 24, "Print"],
Cell[12328512, 324583, 35441, 1709, 302, 19662, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12363956, 326294, 67, 2, 24, "Print"],
Cell[12364026, 326298, 35454, 1709, 302, 19643, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12399483, 328009, 67, 2, 24, "Print"],
Cell[12399553, 328013, 35505, 1710, 302, 19641, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12435061, 329725, 67, 2, 24, "Print"],
Cell[12435131, 329729, 35563, 1710, 302, 19647, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12470697, 331441, 67, 2, 24, "Print"],
Cell[12470767, 331445, 35552, 1710, 302, 19636, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12506322, 333157, 67, 2, 24, "Print"],
Cell[12506392, 333161, 35570, 1711, 302, 19609, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12541965, 334874, 67, 2, 24, "Print"],
Cell[12542035, 334878, 35578, 1710, 302, 19658, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12577616, 336590, 67, 2, 24, "Print"],
Cell[12577686, 336594, 35580, 1710, 302, 19660, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12613269, 338306, 67, 2, 24, "Print"],
Cell[12613339, 338310, 35579, 1711, 302, 19638, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12648921, 340023, 67, 2, 24, "Print"],
Cell[12648991, 340027, 35610, 1711, 302, 19645, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12684604, 341740, 67, 2, 24, "Print"],
Cell[12684674, 341744, 35530, 1710, 302, 19638, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12720207, 343456, 67, 2, 24, "Print"],
Cell[12720277, 343460, 35447, 1709, 302, 19656, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12755727, 345171, 67, 2, 24, "Print"],
Cell[12755797, 345175, 35332, 1708, 302, 19638, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12791132, 346885, 67, 2, 24, "Print"],
Cell[12791202, 346889, 35184, 1706, 302, 19640, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12826389, 348597, 67, 2, 24, "Print"],
Cell[12826459, 348601, 35033, 1704, 302, 19639, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12861495, 350307, 67, 2, 24, "Print"],
Cell[12861565, 350311, 34941, 1703, 302, 19600, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12896509, 352016, 67, 2, 24, "Print"],
Cell[12896579, 352020, 34980, 1703, 302, 19655, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12931562, 353725, 67, 2, 24, "Print"],
Cell[12931632, 353729, 34807, 1701, 302, 19648, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12966442, 355432, 67, 2, 24, "Print"],
Cell[12966512, 355436, 34834, 1701, 302, 19635, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13001349, 357139, 67, 2, 24, "Print"],
Cell[13001419, 357143, 34747, 1701, 302, 19584, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13036169, 358846, 67, 2, 24, "Print"],
Cell[13036239, 358850, 34850, 1701, 302, 19647, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13071092, 360553, 67, 2, 24, "Print"],
Cell[13071162, 360557, 34823, 1701, 302, 19644, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13105988, 362260, 67, 2, 24, "Print"],
Cell[13106058, 362264, 34828, 1701, 302, 19625, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13140889, 363967, 67, 2, 24, "Print"],
Cell[13140959, 363971, 34790, 1701, 302, 19595, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13175752, 365674, 67, 2, 24, "Print"],
Cell[13175822, 365678, 34919, 1702, 302, 19655, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13210744, 367382, 67, 2, 24, "Print"],
Cell[13210814, 367386, 34865, 1701, 302, 19662, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13245682, 369089, 67, 2, 24, "Print"],
Cell[13245752, 369093, 34884, 1702, 302, 19640, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13280639, 370797, 67, 2, 24, "Print"],
Cell[13280709, 370801, 34840, 1702, 302, 19588, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13315552, 372505, 67, 2, 24, "Print"],
Cell[13315622, 372509, 34847, 1701, 302, 19672, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13350472, 374212, 67, 2, 24, "Print"],
Cell[13350542, 374216, 34913, 1702, 302, 19657, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13385458, 375920, 67, 2, 24, "Print"],
Cell[13385528, 375924, 34890, 1702, 302, 19642, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13420421, 377628, 67, 2, 24, "Print"],
Cell[13420491, 377632, 34872, 1702, 302, 19636, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13455366, 379336, 67, 2, 24, "Print"],
Cell[13455436, 379340, 34852, 1702, 302, 19628, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13490291, 381044, 67, 2, 24, "Print"],
Cell[13490361, 381048, 34903, 1702, 302, 19643, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13525267, 382752, 68, 2, 24, "Print"],
Cell[13525338, 382756, 34855, 1702, 302, 19635, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13560196, 384460, 68, 2, 24, "Print"],
Cell[13560267, 384464, 34903, 1702, 302, 19651, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13595173, 386168, 68, 2, 24, "Print"],
Cell[13595244, 386172, 34866, 1702, 302, 19630, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13630113, 387876, 68, 2, 24, "Print"],
Cell[13630184, 387880, 34929, 1703, 302, 19628, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13665116, 389585, 68, 2, 24, "Print"],
Cell[13665187, 389589, 34939, 1703, 302, 19638, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13700129, 391294, 68, 2, 24, "Print"],
Cell[13700200, 391298, 34871, 1702, 302, 19627, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13735074, 393002, 68, 2, 24, "Print"],
Cell[13735145, 393006, 34921, 1703, 302, 19632, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13770069, 394711, 68, 2, 24, "Print"],
Cell[13770140, 394715, 34962, 1703, 302, 19633, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13805105, 396420, 68, 2, 24, "Print"],
Cell[13805176, 396424, 34900, 1702, 302, 19624, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13840079, 398128, 68, 2, 24, "Print"],
Cell[13840150, 398132, 34914, 1703, 302, 19613, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13875067, 399837, 68, 2, 24, "Print"],
Cell[13875138, 399841, 35074, 1704, 302, 19656, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13910215, 401547, 68, 2, 24, "Print"],
Cell[13910286, 401551, 35159, 1705, 302, 19632, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13945448, 403258, 68, 2, 24, "Print"],
Cell[13945519, 403262, 35154, 1705, 302, 19643, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13980676, 404969, 68, 2, 24, "Print"],
Cell[13980747, 404973, 35148, 1705, 302, 19633, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14015898, 406680, 68, 2, 24, "Print"],
Cell[14015969, 406684, 35208, 1706, 302, 19620, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14051180, 408392, 68, 2, 24, "Print"],
Cell[14051251, 408396, 35369, 1708, 302, 19643, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14086623, 410106, 68, 2, 24, "Print"],
Cell[14086694, 410110, 35345, 1708, 302, 19635, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14122042, 411820, 68, 2, 24, "Print"],
Cell[14122113, 411824, 35407, 1709, 302, 19616, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14157523, 413535, 68, 2, 24, "Print"],
Cell[14157594, 413539, 35220, 1706, 302, 19620, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14192817, 415247, 68, 2, 24, "Print"],
Cell[14192888, 415251, 35207, 1706, 302, 19631, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14228098, 416959, 68, 2, 24, "Print"],
Cell[14228169, 416963, 35185, 1706, 302, 19633, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14263357, 418671, 68, 2, 24, "Print"],
Cell[14263428, 418675, 35275, 1707, 302, 19630, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14298706, 420384, 68, 2, 24, "Print"],
Cell[14298777, 420388, 35319, 1707, 302, 19646, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14334099, 422097, 68, 2, 24, "Print"],
Cell[14334170, 422101, 35242, 1706, 302, 19642, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14369415, 423809, 68, 2, 24, "Print"],
Cell[14369486, 423813, 35258, 1707, 302, 19645, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14404747, 425522, 68, 2, 24, "Print"],
Cell[14404818, 425526, 35117, 1705, 302, 19642, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14439938, 427233, 68, 2, 24, "Print"],
Cell[14440009, 427237, 35168, 1705, 302, 19641, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14475180, 428944, 68, 2, 24, "Print"],
Cell[14475251, 428948, 35150, 1705, 302, 19635, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14510404, 430655, 68, 2, 24, "Print"],
Cell[14510475, 430659, 35238, 1706, 302, 19650, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14545716, 432367, 68, 2, 24, "Print"],
Cell[14545787, 432371, 35147, 1705, 302, 19628, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14580937, 434078, 68, 2, 24, "Print"],
Cell[14581008, 434082, 35152, 1705, 302, 19633, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14616163, 435789, 68, 2, 24, "Print"],
Cell[14616234, 435793, 35227, 1706, 302, 19631, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14651464, 437501, 68, 2, 24, "Print"],
Cell[14651535, 437505, 35237, 1706, 302, 19641, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14686775, 439213, 68, 2, 24, "Print"],
Cell[14686846, 439217, 35199, 1706, 302, 19635, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14722048, 440925, 68, 2, 24, "Print"],
Cell[14722119, 440929, 35264, 1707, 302, 19627, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14757386, 442638, 68, 2, 24, "Print"],
Cell[14757457, 442642, 35364, 1708, 302, 19638, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14792824, 444352, 68, 2, 24, "Print"],
Cell[14792895, 444356, 35280, 1707, 302, 19643, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14828178, 446065, 68, 2, 24, "Print"],
Cell[14828249, 446069, 35386, 1708, 302, 19644, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14863638, 447779, 68, 2, 24, "Print"],
Cell[14863709, 447783, 35387, 1708, 302, 19633, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14899099, 449493, 68, 2, 24, "Print"],
Cell[14899170, 449497, 35378, 1708, 302, 19636, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14934551, 451207, 68, 2, 24, "Print"],
Cell[14934622, 451211, 35358, 1708, 302, 19636, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14969983, 452921, 68, 2, 24, "Print"],
Cell[14970054, 452925, 35355, 1708, 302, 19641, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15005412, 454635, 68, 2, 24, "Print"],
Cell[15005483, 454639, 35461, 1709, 302, 19630, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15040947, 456350, 68, 2, 24, "Print"],
Cell[15041018, 456354, 35454, 1709, 302, 19623, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15076475, 458065, 68, 2, 24, "Print"],
Cell[15076546, 458069, 35553, 1710, 302, 19629, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15112102, 459781, 68, 2, 24, "Print"],
Cell[15112173, 459785, 35449, 1709, 302, 19642, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15147625, 461496, 68, 2, 24, "Print"],
Cell[15147696, 461500, 35402, 1709, 302, 19619, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15183101, 463211, 68, 2, 24, "Print"],
Cell[15183172, 463215, 35242, 1706, 302, 19638, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15218417, 464923, 68, 2, 24, "Print"],
Cell[15218488, 464927, 35145, 1705, 302, 19630, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15253636, 466634, 68, 2, 24, "Print"],
Cell[15253707, 466638, 34986, 1703, 302, 19625, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15288696, 468343, 68, 2, 24, "Print"],
Cell[15288767, 468347, 34824, 1701, 302, 19637, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15323594, 470050, 68, 2, 24, "Print"],
Cell[15323665, 470054, 34639, 1699, 302, 19602, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15358307, 471755, 68, 2, 24, "Print"],
Cell[15358378, 471759, 34469, 1697, 302, 19630, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15392850, 473458, 68, 2, 24, "Print"],
Cell[15392921, 473462, 34380, 1696, 302, 19642, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15427304, 475160, 68, 2, 24, "Print"],
Cell[15427375, 475164, 34455, 1697, 302, 19624, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15461833, 476863, 68, 2, 24, "Print"],
Cell[15461904, 476867, 34463, 1697, 302, 19636, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15496370, 478566, 68, 2, 24, "Print"],
Cell[15496441, 478570, 34413, 1697, 302, 19606, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15530857, 480269, 68, 2, 24, "Print"],
Cell[15530928, 480273, 34364, 1696, 302, 19638, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15565295, 481971, 68, 2, 24, "Print"],
Cell[15565366, 481975, 34422, 1696, 302, 19648, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15599791, 483673, 68, 2, 24, "Print"],
Cell[15599862, 483677, 34468, 1697, 302, 19653, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15634333, 485376, 68, 2, 24, "Print"],
Cell[15634404, 485380, 34403, 1696, 302, 19669, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15668810, 487078, 68, 2, 24, "Print"],
Cell[15668881, 487082, 34321, 1695, 302, 19644, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15703205, 488779, 68, 2, 24, "Print"],
Cell[15703276, 488783, 34356, 1695, 302, 19647, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15737635, 490480, 68, 2, 24, "Print"],
Cell[15737706, 490484, 34297, 1695, 302, 19636, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15772006, 492181, 68, 2, 24, "Print"],
Cell[15772077, 492185, 34412, 1696, 302, 19670, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15806492, 493883, 68, 2, 24, "Print"],
Cell[15806563, 493887, 34280, 1695, 302, 19639, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15840846, 495584, 68, 2, 24, "Print"],
Cell[15840917, 495588, 34353, 1695, 302, 19656, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15875273, 497285, 68, 2, 24, "Print"],
Cell[15875344, 497289, 34372, 1696, 302, 19638, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15909719, 498987, 68, 2, 24, "Print"],
Cell[15909790, 498991, 34359, 1696, 302, 19637, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15944152, 500689, 68, 2, 24, "Print"],
Cell[15944223, 500693, 34455, 1697, 302, 19644, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15978681, 502392, 68, 2, 24, "Print"],
Cell[15978752, 502396, 34370, 1696, 302, 19632, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16013125, 504094, 68, 2, 24, "Print"],
Cell[16013196, 504098, 34404, 1696, 302, 19646, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16047603, 505796, 68, 2, 24, "Print"],
Cell[16047674, 505800, 34404, 1696, 302, 19650, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16082081, 507498, 68, 2, 24, "Print"],
Cell[16082152, 507502, 34405, 1696, 302, 19643, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16116560, 509200, 68, 2, 24, "Print"],
Cell[16116631, 509204, 34418, 1696, 302, 19636, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16151052, 510902, 68, 2, 24, "Print"],
Cell[16151123, 510906, 34478, 1697, 302, 19643, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16185604, 512605, 68, 2, 24, "Print"],
Cell[16185675, 512609, 34427, 1697, 302, 19620, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16220105, 514308, 68, 2, 24, "Print"],
Cell[16220176, 514312, 34545, 1698, 302, 19653, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16254724, 516012, 68, 2, 24, "Print"],
Cell[16254795, 516016, 34675, 1699, 302, 19638, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16289473, 517717, 68, 2, 24, "Print"],
Cell[16289544, 517721, 34679, 1699, 302, 19646, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16324226, 519422, 68, 2, 24, "Print"],
Cell[16324297, 519426, 34679, 1700, 302, 19621, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16358979, 521128, 68, 2, 24, "Print"],
Cell[16359050, 521132, 34585, 1698, 302, 19625, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16393638, 522832, 68, 2, 24, "Print"],
Cell[16393709, 522836, 34630, 1699, 302, 19629, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16428342, 524537, 68, 2, 24, "Print"],
Cell[16428413, 524541, 34584, 1698, 302, 19628, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16463000, 526241, 68, 2, 24, "Print"],
Cell[16463071, 526245, 34581, 1698, 302, 19645, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16497655, 527945, 68, 2, 24, "Print"],
Cell[16497726, 527949, 34527, 1698, 302, 19635, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16532256, 529649, 68, 2, 24, "Print"],
Cell[16532327, 529653, 34554, 1698, 302, 19646, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16566884, 531353, 68, 2, 24, "Print"],
Cell[16566955, 531357, 34393, 1696, 302, 19627, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16601351, 533055, 68, 2, 24, "Print"],
Cell[16601422, 533059, 34482, 1697, 302, 19643, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16635907, 534758, 68, 2, 24, "Print"],
Cell[16635978, 534762, 34325, 1695, 302, 19636, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16670306, 536459, 68, 2, 24, "Print"],
Cell[16670377, 536463, 34315, 1695, 302, 19630, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16704695, 538160, 68, 2, 24, "Print"],
Cell[16704766, 538164, 34390, 1696, 302, 19636, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16739159, 539862, 68, 2, 24, "Print"],
Cell[16739230, 539866, 34345, 1695, 302, 19636, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16773578, 541563, 68, 2, 24, "Print"],
Cell[16773649, 541567, 34468, 1697, 302, 19625, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16808120, 543266, 68, 2, 24, "Print"],
Cell[16808191, 543270, 34585, 1698, 302, 19641, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16842779, 544970, 68, 2, 24, "Print"],
Cell[16842850, 544974, 34743, 1700, 302, 19637, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16877596, 546676, 68, 2, 24, "Print"],
Cell[16877667, 546680, 34860, 1702, 302, 19644, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16912530, 548384, 68, 2, 24, "Print"],
Cell[16912601, 548388, 34866, 1702, 302, 19626, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16947470, 550092, 68, 2, 24, "Print"],
Cell[16947541, 550096, 34940, 1703, 302, 19651, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16982484, 551801, 68, 2, 24, "Print"],
Cell[16982555, 551805, 34919, 1703, 302, 19630, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17017477, 553510, 68, 2, 24, "Print"],
Cell[17017548, 553514, 34904, 1702, 302, 19628, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17052455, 555218, 68, 2, 24, "Print"],
Cell[17052526, 555222, 34962, 1703, 302, 19629, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17087491, 556927, 68, 2, 24, "Print"],
Cell[17087562, 556931, 35017, 1704, 302, 19639, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17122582, 558637, 68, 2, 24, "Print"],
Cell[17122653, 558641, 35017, 1704, 302, 19639, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17157673, 560347, 68, 2, 24, "Print"],
Cell[17157744, 560351, 35091, 1705, 302, 19632, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17192838, 562058, 68, 2, 24, "Print"],
Cell[17192909, 562062, 35022, 1704, 302, 19632, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17227934, 563768, 68, 2, 24, "Print"],
Cell[17228005, 563772, 35143, 1706, 302, 19611, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17263151, 565480, 68, 2, 24, "Print"],
Cell[17263222, 565484, 35224, 1706, 302, 19644, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17298449, 567192, 68, 2, 24, "Print"],
Cell[17298520, 567196, 35163, 1705, 302, 19644, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17333686, 568903, 68, 2, 24, "Print"],
Cell[17333757, 568907, 35176, 1706, 302, 19628, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17368936, 570615, 68, 2, 24, "Print"],
Cell[17369007, 570619, 35305, 1707, 302, 19636, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17404315, 572328, 68, 2, 24, "Print"],
Cell[17404386, 572332, 35359, 1708, 302, 19637, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17439748, 574042, 68, 2, 24, "Print"],
Cell[17439819, 574046, 35344, 1708, 302, 19634, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17475166, 575756, 68, 2, 24, "Print"],
Cell[17475237, 575760, 35404, 1708, 302, 19646, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17510644, 577470, 68, 2, 24, "Print"],
Cell[17510715, 577474, 35410, 1708, 302, 19652, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17546128, 579184, 68, 2, 24, "Print"],
Cell[17546199, 579188, 35460, 1709, 302, 19633, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17581662, 580899, 68, 2, 24, "Print"],
Cell[17581733, 580903, 35466, 1709, 302, 19635, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17617202, 582614, 68, 2, 24, "Print"],
Cell[17617273, 582618, 35493, 1710, 302, 19629, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17652769, 584330, 68, 2, 24, "Print"],
Cell[17652840, 584334, 35592, 1711, 302, 19619, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17688435, 586047, 68, 2, 24, "Print"],
Cell[17688506, 586051, 35683, 1712, 302, 19633, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17724192, 587765, 68, 2, 24, "Print"],
Cell[17724263, 587769, 35642, 1711, 302, 19641, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17759908, 589482, 68, 2, 24, "Print"],
Cell[17759979, 589486, 35702, 1712, 302, 19632, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17795684, 591200, 68, 2, 24, "Print"],
Cell[17795755, 591204, 35735, 1713, 302, 19628, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17831493, 592919, 68, 2, 24, "Print"],
Cell[17831564, 592923, 35784, 1713, 302, 19645, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17867351, 594638, 68, 2, 24, "Print"],
Cell[17867422, 594642, 35832, 1714, 302, 19640, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17903257, 596358, 68, 2, 24, "Print"],
Cell[17903328, 596362, 35749, 1713, 302, 19618, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17939080, 598077, 68, 2, 24, "Print"],
Cell[17939151, 598081, 35693, 1712, 302, 19639, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17974847, 599795, 68, 2, 24, "Print"],
Cell[17974918, 599799, 35648, 1711, 302, 19663, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18010569, 601512, 68, 2, 24, "Print"],
Cell[18010640, 601516, 35414, 1708, 302, 19648, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18046057, 603226, 68, 2, 24, "Print"],
Cell[18046128, 603230, 35165, 1706, 302, 19625, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18081296, 604938, 68, 2, 24, "Print"],
Cell[18081367, 604942, 35130, 1705, 302, 19639, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18116500, 606649, 68, 2, 24, "Print"],
Cell[18116571, 606653, 35062, 1704, 302, 19636, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18151636, 608359, 68, 2, 24, "Print"],
Cell[18151707, 608363, 34969, 1703, 302, 19640, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18186679, 610068, 68, 2, 24, "Print"],
Cell[18186750, 610072, 34855, 1702, 302, 19631, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18221608, 611776, 68, 2, 24, "Print"],
Cell[18221679, 611780, 34787, 1701, 302, 19624, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18256469, 613483, 68, 2, 24, "Print"],
Cell[18256540, 613487, 34848, 1702, 302, 19640, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18291391, 615191, 68, 2, 24, "Print"],
Cell[18291462, 615195, 34815, 1701, 302, 19644, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18326280, 616898, 68, 2, 24, "Print"],
Cell[18326351, 616902, 34810, 1701, 302, 19655, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18361164, 618605, 68, 2, 24, "Print"],
Cell[18361235, 618609, 34799, 1701, 302, 19616, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18396037, 620312, 68, 2, 24, "Print"],
Cell[18396108, 620316, 34755, 1701, 302, 19616, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18430866, 622019, 68, 2, 24, "Print"],
Cell[18430937, 622023, 34823, 1701, 302, 19660, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18465763, 623726, 68, 2, 24, "Print"],
Cell[18465834, 623730, 34857, 1701, 302, 19654, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18500694, 625433, 68, 2, 24, "Print"],
Cell[18500765, 625437, 34864, 1702, 302, 19648, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18535632, 627141, 68, 2, 24, "Print"],
Cell[18535703, 627145, 34910, 1702, 302, 19646, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18570616, 628849, 68, 2, 24, "Print"],
Cell[18570687, 628853, 34865, 1702, 302, 19645, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18605555, 630557, 68, 2, 24, "Print"],
Cell[18605626, 630561, 34862, 1702, 302, 19638, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18640491, 632265, 68, 2, 24, "Print"],
Cell[18640562, 632269, 34881, 1702, 296, 19641, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18675446, 633973, 68, 2, 22, "Print"],
Cell[18675517, 633977, 34874, 1702, 296, 19634, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18710394, 635681, 68, 2, 22, "Print"],
Cell[18710465, 635685, 34920, 1702, 302, 19640, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18745388, 637389, 68, 2, 24, "Print"],
Cell[18745459, 637393, 34900, 1702, 302, 19624, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18780362, 639097, 68, 2, 24, "Print"],
Cell[18780433, 639101, 34892, 1702, 302, 19648, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18815328, 640805, 68, 2, 24, "Print"],
Cell[18815399, 640809, 34885, 1702, 302, 19625, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18850287, 642513, 68, 2, 24, "Print"],
Cell[18850358, 642517, 34940, 1703, 296, 19635, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18885301, 644222, 68, 2, 22, "Print"],
Cell[18885372, 644226, 34996, 1703, 296, 19631, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18920371, 645931, 68, 2, 24, "Print"],
Cell[18920442, 645935, 34996, 1703, 302, 19631, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18955441, 647640, 68, 2, 24, "Print"],
Cell[18955512, 647644, 35008, 1704, 302, 19634, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18990523, 649350, 68, 2, 24, "Print"],
Cell[18990594, 649354, 35068, 1704, 302, 19638, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19025665, 651060, 68, 2, 24, "Print"],
Cell[19025736, 651064, 35010, 1704, 302, 19620, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19060749, 652770, 68, 2, 24, "Print"],
Cell[19060820, 652774, 35002, 1703, 302, 19649, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19095825, 654479, 68, 2, 24, "Print"],
Cell[19095896, 654483, 34950, 1703, 302, 19657, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19130849, 656188, 68, 2, 24, "Print"],
Cell[19130920, 656192, 35138, 1705, 302, 19643, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19166061, 657899, 68, 2, 24, "Print"],
Cell[19166132, 657903, 35305, 1707, 302, 19632, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19201440, 659612, 68, 2, 24, "Print"],
Cell[19201511, 659616, 35305, 1707, 302, 19644, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19236819, 661325, 68, 2, 24, "Print"],
Cell[19236890, 661329, 35355, 1708, 302, 19625, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19272248, 663039, 68, 2, 24, "Print"],
Cell[19272319, 663043, 35571, 1711, 302, 19634, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19307893, 664756, 68, 2, 24, "Print"],
Cell[19307964, 664760, 35607, 1711, 302, 19638, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19343574, 666473, 68, 2, 24, "Print"],
Cell[19343645, 666477, 35651, 1712, 302, 19633, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19379299, 668191, 68, 2, 24, "Print"],
Cell[19379370, 668195, 35611, 1711, 302, 19630, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19414984, 669908, 68, 2, 24, "Print"],
Cell[19415055, 669912, 35499, 1710, 302, 19643, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19450557, 671624, 68, 2, 24, "Print"],
Cell[19450628, 671628, 35532, 1710, 302, 19644, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19486163, 673340, 68, 2, 24, "Print"],
Cell[19486234, 673344, 35535, 1710, 302, 19635, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19521772, 675056, 68, 2, 24, "Print"],
Cell[19521843, 675060, 35514, 1710, 302, 19634, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19557360, 676772, 68, 2, 24, "Print"],
Cell[19557431, 676776, 35562, 1710, 302, 19646, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19592996, 678488, 68, 2, 24, "Print"],
Cell[19593067, 678492, 35455, 1709, 302, 19628, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19628525, 680203, 68, 2, 24, "Print"],
Cell[19628596, 680207, 35396, 1709, 302, 19621, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19663995, 681918, 68, 2, 24, "Print"],
Cell[19664066, 681922, 35376, 1708, 302, 19634, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19699445, 683632, 68, 2, 24, "Print"],
Cell[19699516, 683636, 35373, 1708, 302, 19639, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19734892, 685346, 68, 2, 24, "Print"],
Cell[19734963, 685350, 35387, 1708, 302, 19633, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19770353, 687060, 68, 2, 24, "Print"],
Cell[19770424, 687064, 35357, 1708, 302, 19639, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19805784, 688774, 68, 2, 24, "Print"],
Cell[19805855, 688778, 35369, 1708, 302, 19635, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19841227, 690488, 68, 2, 24, "Print"],
Cell[19841298, 690492, 35379, 1708, 302, 19645, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19876680, 692202, 68, 2, 24, "Print"],
Cell[19876751, 692206, 35368, 1708, 302, 19634, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19912122, 693916, 68, 2, 24, "Print"],
Cell[19912193, 693920, 35381, 1708, 302, 19635, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19947577, 695630, 68, 2, 24, "Print"],
Cell[19947648, 695634, 35448, 1709, 302, 19637, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19983099, 697345, 68, 2, 24, "Print"],
Cell[19983170, 697349, 35404, 1708, 302, 19654, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20018577, 699059, 68, 2, 24, "Print"],
Cell[20018648, 699063, 35455, 1709, 302, 19620, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20054106, 700774, 68, 2, 24, "Print"],
Cell[20054177, 700778, 35562, 1710, 302, 19630, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20089742, 702490, 68, 2, 24, "Print"],
Cell[20089813, 702494, 35535, 1710, 302, 19631, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20125351, 704206, 68, 2, 24, "Print"],
Cell[20125422, 704210, 35441, 1709, 302, 19618, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20160866, 705921, 68, 2, 24, "Print"],
Cell[20160937, 705925, 35557, 1710, 302, 19649, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20196497, 707637, 68, 2, 24, "Print"],
Cell[20196568, 707641, 35523, 1710, 296, 19635, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20232094, 709353, 68, 2, 22, "Print"],
Cell[20232165, 709357, 35640, 1711, 296, 19631, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20267808, 711070, 68, 2, 24, "Print"],
Cell[20267879, 711074, 35564, 1710, 302, 19644, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20303446, 712786, 68, 2, 24, "Print"],
Cell[20303517, 712790, 35607, 1711, 302, 19638, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20339127, 714503, 68, 2, 24, "Print"],
Cell[20339198, 714507, 35657, 1711, 302, 19652, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20374858, 716220, 68, 2, 24, "Print"],
Cell[20374929, 716224, 35602, 1711, 302, 19633, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20410534, 717937, 68, 2, 24, "Print"],
Cell[20410605, 717941, 35487, 1708, 302, 19599, 1507, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20446095, 719651, 68, 2, 24, "Print"],
Cell[20446166, 719655, 35299, 1707, 302, 19626, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20481468, 721364, 68, 2, 24, "Print"],
Cell[20481539, 721368, 35196, 1706, 302, 19624, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20516738, 723076, 68, 2, 24, "Print"],
Cell[20516809, 723080, 35098, 1705, 302, 19635, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20551910, 724787, 68, 2, 24, "Print"],
Cell[20551981, 724791, 34720, 1700, 302, 19614, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20586704, 726493, 68, 2, 24, "Print"],
Cell[20586775, 726497, 34613, 1699, 302, 19632, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20621391, 728198, 68, 2, 24, "Print"],
Cell[20621462, 728202, 34505, 1697, 302, 19642, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20655970, 729901, 68, 2, 24, "Print"],
Cell[20656041, 729905, 34412, 1696, 302, 19626, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20690456, 731603, 68, 2, 24, "Print"],
Cell[20690527, 731607, 34505, 1697, 302, 19650, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20725035, 733306, 68, 2, 24, "Print"],
Cell[20725106, 733310, 34555, 1698, 302, 19639, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20759664, 735010, 68, 2, 24, "Print"],
Cell[20759735, 735014, 34543, 1698, 302, 19655, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20794281, 736714, 68, 2, 24, "Print"],
Cell[20794352, 736718, 34371, 1694, 302, 19585, 1507, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20828726, 738414, 68, 2, 24, "Print"],
Cell[20828797, 738418, 34508, 1697, 302, 19665, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20863308, 740117, 68, 2, 24, "Print"],
Cell[20863379, 740121, 34451, 1697, 296, 19612, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20897833, 741820, 68, 2, 22, "Print"],
Cell[20897904, 741824, 34491, 1697, 296, 19644, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20932398, 743523, 68, 2, 22, "Print"],
Cell[20932469, 743527, 34484, 1698, 296, 19568, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20966956, 745227, 68, 2, 24, "Print"],
Cell[20967027, 745231, 34398, 1696, 302, 19648, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21001428, 746929, 68, 2, 24, "Print"],
Cell[21001499, 746933, 34419, 1696, 302, 19625, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21035921, 748631, 68, 2, 24, "Print"],
Cell[21035992, 748635, 34438, 1696, 302, 19652, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21070433, 750333, 68, 2, 24, "Print"],
Cell[21070504, 750337, 34408, 1696, 302, 19646, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21104915, 752035, 68, 2, 24, "Print"],
Cell[21104986, 752039, 34471, 1697, 302, 19648, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21139460, 753738, 68, 2, 24, "Print"],
Cell[21139531, 753742, 34431, 1696, 302, 19649, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21173965, 755440, 68, 2, 24, "Print"],
Cell[21174036, 755444, 34394, 1696, 302, 19608, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21208433, 757142, 68, 2, 24, "Print"],
Cell[21208504, 757146, 34470, 1697, 302, 19651, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21242977, 758845, 68, 2, 24, "Print"],
Cell[21243048, 758849, 34423, 1696, 302, 19637, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21277474, 760547, 68, 2, 24, "Print"],
Cell[21277545, 760551, 34417, 1696, 302, 19631, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21311965, 762249, 68, 2, 24, "Print"],
Cell[21312036, 762253, 34535, 1698, 302, 19639, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21346574, 763953, 68, 2, 24, "Print"],
Cell[21346645, 763957, 34541, 1698, 302, 19629, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21381189, 765657, 68, 2, 24, "Print"],
Cell[21381260, 765661, 34645, 1699, 302, 19640, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21415908, 767362, 68, 2, 24, "Print"],
Cell[21415979, 767366, 34635, 1699, 302, 19638, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21450617, 769067, 68, 2, 24, "Print"],
Cell[21450688, 769071, 34486, 1697, 302, 19635, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21485177, 770770, 68, 2, 24, "Print"],
Cell[21485248, 770774, 34624, 1699, 302, 19639, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21519875, 772475, 68, 2, 24, "Print"],
Cell[21519946, 772479, 34672, 1699, 302, 19651, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21554621, 774180, 68, 2, 24, "Print"],
Cell[21554692, 774184, 34611, 1699, 302, 19622, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21589306, 775885, 68, 2, 24, "Print"],
Cell[21589377, 775889, 34728, 1700, 302, 19622, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21624108, 777591, 68, 2, 24, "Print"],
Cell[21624179, 777595, 34659, 1699, 302, 19630, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21658841, 779296, 68, 2, 24, "Print"],
Cell[21658912, 779300, 34553, 1698, 302, 19625, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21693468, 781000, 68, 2, 24, "Print"],
Cell[21693539, 781004, 34572, 1698, 302, 19644, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21728114, 782704, 68, 2, 24, "Print"],
Cell[21728185, 782708, 34626, 1699, 302, 19625, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21762814, 784409, 68, 2, 24, "Print"],
Cell[21762885, 784413, 34662, 1699, 302, 19625, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21797550, 786114, 68, 2, 24, "Print"],
Cell[21797621, 786118, 34641, 1699, 302, 19648, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21832265, 787819, 68, 2, 24, "Print"],
Cell[21832336, 787823, 34512, 1697, 302, 19633, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21866851, 789522, 68, 2, 24, "Print"],
Cell[21866922, 789526, 34552, 1698, 302, 19636, 1509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21901477, 791226, 68, 2, 24, "Print"],
Cell[21901548, 791230, 94, 2, 32, "Output"],
Cell[21901645, 791234, 73, 2, 24, "Print"]
}, Closed]],
Cell[21901733, 791239, 218, 5, 34, "Text",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[21901976, 791248, 116, 2, 22, "Input"],
Cell[21902095, 791252, 34742, 433, 192, 34594, 428, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[21936840, 791687, 155, 4, 32, "Output"]
}, Open  ]],
Cell[21937010, 791694, 161, 4, 34, "Text"],

Cell[CellGroupData[{
Cell[21937196, 791702, 152, 3, 34, "Input"],
Cell[21937351, 791707, 37492, 467, 192, 37344, 462, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[21974846, 792176, 155, 4, 32, "Output"]
}, Open  ]],
Cell[21975016, 792183, 296, 5, 47, "Text"],
Cell[21975315, 792190, 458, 8, 60, "Text",
  PageBreakAbove->True],
Cell[21975776, 792200, 29999, 374, 192, 29851, 369, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[22005778, 792576, 173, 6, 21, "Text"],
Cell[22005954, 792584, 410266, 6313, 331, 410174, 6310, "GraphicsData", \
"PICT", "NumberedFigure"],
Cell[22416223, 798899, 63, 0, 19, "Caption"],
Cell[22416289, 798901, 588, 9, 73, "Text"],
Cell[22416880, 798912, 169, 4, 34, "Text"],
Cell[22417052, 798918, 41045, 511, 192, 40888, 506, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[22458100, 799431, 101, 3, 21, "Text"],
Cell[22458204, 799436, 43920, 546, 192, 43763, 541, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[22502127, 799984, 1875, 59, 73, "Text",
  PageBreakAbove->True],
Cell[22504005, 800045, 7596, 118, 192, 7504, 115, "GraphicsData", "PICT", \
"Graphics"],
Cell[22511604, 800165, 155, 4, 32, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22511808, 800175, 29, 0, 49, "Section"],
Cell[22511840, 800177, 1575, 27, 177, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22513452, 800209, 58, 1, 49, "Section",
  PageBreakBelow->Automatic],
Cell[22513513, 800212, 1102, 20, 90, "Reference",
  PageBreakBelow->Automatic]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

